/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum CONFIGURATION {
    WIA_STATUS_END_OF_MEDIA,
    WIA_STATUS_WARMING_UP,
    WIA_STATUS_CALIBRATING,
    WIA_STATUS_RESERVING_NETWORK_DEVICE,
    WIA_STATUS_NETWORK_DEVICE_RESERVED,
    WIA_STATUS_CLEAR,
    WIA_STATUS_SKIP_ITEM,
    WIA_STATUS_NOT_HANDLED,
    WIA_ERROR_GENERAL_ERROR,
    WIA_ERROR_PAPER_JAM,
    WIA_ERROR_PAPER_EMPTY,
    WIA_ERROR_PAPER_PROBLEM,
    WIA_ERROR_OFFLINE,
    WIA_ERROR_BUSY,
    WIA_ERROR_WARMING_UP,
    WIA_ERROR_USER_INTERVENTION,
    WIA_ERROR_ITEM_DELETED,
    WIA_ERROR_DEVICE_COMMUNICATION,
    WIA_ERROR_INVALID_COMMAND,
    WIA_ERROR_INCORRECT_HARDWARE_SETTING,
    WIA_ERROR_DEVICE_LOCKED,
    WIA_ERROR_EXCEPTION_IN_DRIVER,
    WIA_ERROR_INVALID_DRIVER_RESPONSE,
    WIA_ERROR_COVER_OPEN,
    WIA_ERROR_LAMP_OFF,
    WIA_ERROR_DESTINATION,
    WIA_ERROR_NETWORK_RESERVATION_FAILED,
    WIA_ERROR_MULTI_FEED,
    WIA_S_NO_DEVICE_AVAILABLE,
    WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER,
}

impl CONFIGURATION {
    pub fn code(&self) -> u32 {
        return match self {
            CONFIGURATION::WIA_STATUS_END_OF_MEDIA => 0x00210001 as u32,
            CONFIGURATION::WIA_STATUS_WARMING_UP => 0x00210002 as u32,
            CONFIGURATION::WIA_STATUS_CALIBRATING => 0x00210003 as u32,
            CONFIGURATION::WIA_STATUS_RESERVING_NETWORK_DEVICE => 0x00210006 as u32,
            CONFIGURATION::WIA_STATUS_NETWORK_DEVICE_RESERVED => 0x00210007 as u32,
            CONFIGURATION::WIA_STATUS_CLEAR => 0x00210008 as u32,
            CONFIGURATION::WIA_STATUS_SKIP_ITEM => 0x00210009 as u32,
            CONFIGURATION::WIA_STATUS_NOT_HANDLED => 0x0021000A as u32,
            CONFIGURATION::WIA_ERROR_GENERAL_ERROR => 0x80210001 as u32,
            CONFIGURATION::WIA_ERROR_PAPER_JAM => 0x80210002 as u32,
            CONFIGURATION::WIA_ERROR_PAPER_EMPTY => 0x80210003 as u32,
            CONFIGURATION::WIA_ERROR_PAPER_PROBLEM => 0x80210004 as u32,
            CONFIGURATION::WIA_ERROR_OFFLINE => 0x80210005 as u32,
            CONFIGURATION::WIA_ERROR_BUSY => 0x80210006 as u32,
            CONFIGURATION::WIA_ERROR_WARMING_UP => 0x80210007 as u32,
            CONFIGURATION::WIA_ERROR_USER_INTERVENTION => 0x80210008 as u32,
            CONFIGURATION::WIA_ERROR_ITEM_DELETED => 0x80210009 as u32,
            CONFIGURATION::WIA_ERROR_DEVICE_COMMUNICATION => 0x8021000A as u32,
            CONFIGURATION::WIA_ERROR_INVALID_COMMAND => 0x8021000B as u32,
            CONFIGURATION::WIA_ERROR_INCORRECT_HARDWARE_SETTING => 0x8021000C as u32,
            CONFIGURATION::WIA_ERROR_DEVICE_LOCKED => 0x8021000D as u32,
            CONFIGURATION::WIA_ERROR_EXCEPTION_IN_DRIVER => 0x8021000E as u32,
            CONFIGURATION::WIA_ERROR_INVALID_DRIVER_RESPONSE => 0x8021000F as u32,
            CONFIGURATION::WIA_ERROR_COVER_OPEN => 0x80210010 as u32,
            CONFIGURATION::WIA_ERROR_LAMP_OFF => 0x80210011 as u32,
            CONFIGURATION::WIA_ERROR_DESTINATION => 0x80210012 as u32,
            CONFIGURATION::WIA_ERROR_NETWORK_RESERVATION_FAILED => 0x80210013 as u32,
            CONFIGURATION::WIA_ERROR_MULTI_FEED => 0x80210014 as u32,
            CONFIGURATION::WIA_S_NO_DEVICE_AVAILABLE => 0x80210015 as u32,
            CONFIGURATION::WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER => 0x80210015 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            CONFIGURATION::WIA_STATUS_END_OF_MEDIA => RawError::Kind(CONFIGURATION::WIA_STATUS_END_OF_MEDIA),
            CONFIGURATION::WIA_STATUS_WARMING_UP => RawError::Kind(CONFIGURATION::WIA_STATUS_WARMING_UP),
            CONFIGURATION::WIA_STATUS_CALIBRATING => RawError::Kind(CONFIGURATION::WIA_STATUS_CALIBRATING),
            CONFIGURATION::WIA_STATUS_RESERVING_NETWORK_DEVICE => RawError::Kind(CONFIGURATION::WIA_STATUS_RESERVING_NETWORK_DEVICE),
            CONFIGURATION::WIA_STATUS_NETWORK_DEVICE_RESERVED => RawError::Kind(CONFIGURATION::WIA_STATUS_NETWORK_DEVICE_RESERVED),
            CONFIGURATION::WIA_STATUS_CLEAR => RawError::Kind(CONFIGURATION::WIA_STATUS_CLEAR),
            CONFIGURATION::WIA_STATUS_SKIP_ITEM => RawError::Kind(CONFIGURATION::WIA_STATUS_SKIP_ITEM),
            CONFIGURATION::WIA_STATUS_NOT_HANDLED => RawError::Kind(CONFIGURATION::WIA_STATUS_NOT_HANDLED),
            CONFIGURATION::WIA_ERROR_GENERAL_ERROR => RawError::Kind(CONFIGURATION::WIA_ERROR_GENERAL_ERROR),
            CONFIGURATION::WIA_ERROR_PAPER_JAM => RawError::Kind(CONFIGURATION::WIA_ERROR_PAPER_JAM),
            CONFIGURATION::WIA_ERROR_PAPER_EMPTY => RawError::Kind(CONFIGURATION::WIA_ERROR_PAPER_EMPTY),
            CONFIGURATION::WIA_ERROR_PAPER_PROBLEM => RawError::Kind(CONFIGURATION::WIA_ERROR_PAPER_PROBLEM),
            CONFIGURATION::WIA_ERROR_OFFLINE => RawError::Kind(CONFIGURATION::WIA_ERROR_OFFLINE),
            CONFIGURATION::WIA_ERROR_BUSY => RawError::Kind(CONFIGURATION::WIA_ERROR_BUSY),
            CONFIGURATION::WIA_ERROR_WARMING_UP => RawError::Kind(CONFIGURATION::WIA_ERROR_WARMING_UP),
            CONFIGURATION::WIA_ERROR_USER_INTERVENTION => RawError::Kind(CONFIGURATION::WIA_ERROR_USER_INTERVENTION),
            CONFIGURATION::WIA_ERROR_ITEM_DELETED => RawError::Kind(CONFIGURATION::WIA_ERROR_ITEM_DELETED),
            CONFIGURATION::WIA_ERROR_DEVICE_COMMUNICATION => RawError::Kind(CONFIGURATION::WIA_ERROR_DEVICE_COMMUNICATION),
            CONFIGURATION::WIA_ERROR_INVALID_COMMAND => RawError::Kind(CONFIGURATION::WIA_ERROR_INVALID_COMMAND),
            CONFIGURATION::WIA_ERROR_INCORRECT_HARDWARE_SETTING => RawError::Kind(CONFIGURATION::WIA_ERROR_INCORRECT_HARDWARE_SETTING),
            CONFIGURATION::WIA_ERROR_DEVICE_LOCKED => RawError::Kind(CONFIGURATION::WIA_ERROR_DEVICE_LOCKED),
            CONFIGURATION::WIA_ERROR_EXCEPTION_IN_DRIVER => RawError::Kind(CONFIGURATION::WIA_ERROR_EXCEPTION_IN_DRIVER),
            CONFIGURATION::WIA_ERROR_INVALID_DRIVER_RESPONSE => RawError::Kind(CONFIGURATION::WIA_ERROR_INVALID_DRIVER_RESPONSE),
            CONFIGURATION::WIA_ERROR_COVER_OPEN => RawError::Kind(CONFIGURATION::WIA_ERROR_COVER_OPEN),
            CONFIGURATION::WIA_ERROR_LAMP_OFF => RawError::Kind(CONFIGURATION::WIA_ERROR_LAMP_OFF),
            CONFIGURATION::WIA_ERROR_DESTINATION => RawError::Kind(CONFIGURATION::WIA_ERROR_DESTINATION),
            CONFIGURATION::WIA_ERROR_NETWORK_RESERVATION_FAILED => RawError::Kind(CONFIGURATION::WIA_ERROR_NETWORK_RESERVATION_FAILED),
            CONFIGURATION::WIA_ERROR_MULTI_FEED => RawError::Kind(CONFIGURATION::WIA_ERROR_MULTI_FEED),
            CONFIGURATION::WIA_S_NO_DEVICE_AVAILABLE => RawError::Kind(CONFIGURATION::WIA_S_NO_DEVICE_AVAILABLE),
            CONFIGURATION::WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER => RawError::Kind(CONFIGURATION::WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            CONFIGURATION::WIA_STATUS_END_OF_MEDIA => "End of Media",
            CONFIGURATION::WIA_STATUS_WARMING_UP => "Warming Up",
            CONFIGURATION::WIA_STATUS_CALIBRATING => "Calibrating",
            CONFIGURATION::WIA_STATUS_RESERVING_NETWORK_DEVICE => "Reserving Network Device",
            CONFIGURATION::WIA_STATUS_NETWORK_DEVICE_RESERVED => "Network Device reserved",
            CONFIGURATION::WIA_STATUS_CLEAR => "Clear",
            CONFIGURATION::WIA_STATUS_SKIP_ITEM => "Skip Item",
            CONFIGURATION::WIA_STATUS_NOT_HANDLED => "Not Handled",
            CONFIGURATION::WIA_ERROR_GENERAL_ERROR => "An unknown error has occurred with the WIA device.",
            CONFIGURATION::WIA_ERROR_PAPER_JAM => "Paper is jammed in the scanner's document feeder.",
            CONFIGURATION::WIA_ERROR_PAPER_EMPTY => "There are no documents in the document feeder.",
            CONFIGURATION::WIA_ERROR_PAPER_PROBLEM => "An unspecified problem occurred with the scanner's document feeder.",
            CONFIGURATION::WIA_ERROR_OFFLINE => "The device is offline. Make sure the device is powered on and connected to the PC.",
            CONFIGURATION::WIA_ERROR_BUSY => "The device is busy. Close any apps that are using this device or wait for it to finish and then try again.",
            CONFIGURATION::WIA_ERROR_WARMING_UP => "The device is warming up.",
            CONFIGURATION::WIA_ERROR_USER_INTERVENTION => "There is a problem with the WIA device. Make sure that the device is turned on, online, and any cables are properly connected.",
            CONFIGURATION::WIA_ERROR_ITEM_DELETED => "The WIA device was deleted. It's no longer available.",
            CONFIGURATION::WIA_ERROR_DEVICE_COMMUNICATION => "Communication with the WIA device failed. Make sure that the device is powered on and connected to the PC. If the problem persists, disconnect and reconnect the device.",
            CONFIGURATION::WIA_ERROR_INVALID_COMMAND => "The device doesn't support this command.",
            CONFIGURATION::WIA_ERROR_INCORRECT_HARDWARE_SETTING => "There is an incorrect setting on the WIA device.",
            CONFIGURATION::WIA_ERROR_DEVICE_LOCKED => "The device is locked. Close any apps that are using this device or wait for it to finish and then try again.",
            CONFIGURATION::WIA_ERROR_EXCEPTION_IN_DRIVER => "The device driver threw an exception.",
            CONFIGURATION::WIA_ERROR_INVALID_DRIVER_RESPONSE => "The response from the driver is invalid.",
            CONFIGURATION::WIA_ERROR_COVER_OPEN => "One or more of the device's cover is open.",
            CONFIGURATION::WIA_ERROR_LAMP_OFF => "The scanner's lamp is off.",
            CONFIGURATION::WIA_ERROR_DESTINATION => "Undocumented",
            CONFIGURATION::WIA_ERROR_NETWORK_RESERVATION_FAILED => "Undocumented",
            CONFIGURATION::WIA_ERROR_MULTI_FEED => "A scan error occurred because of a multiple page feed condition. This feature is available with Windows 8 and later versions of Windows.",
            CONFIGURATION::WIA_S_NO_DEVICE_AVAILABLE => "No scanner device was found. Make sure the device is online, connected to the PC, and has the correct driver installed on the PC.",
            CONFIGURATION::WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER => "A scan job was interrupted because an Imprinter/Endorser item reached the maximum valid value for WIA_IPS_PRINTER_ENDORSER_COUNTER, and was reset to 0. This feature is available with Windows 8 and later versions of Windows.",
        }
    }

    pub fn from_name(name: &str) -> CONFIGURATION {
        return match name {
            "WIA_STATUS_END_OF_MEDIA" => CONFIGURATION::WIA_STATUS_END_OF_MEDIA,
            "WIA_STATUS_WARMING_UP" => CONFIGURATION::WIA_STATUS_WARMING_UP,
            "WIA_STATUS_CALIBRATING" => CONFIGURATION::WIA_STATUS_CALIBRATING,
            "WIA_STATUS_RESERVING_NETWORK_DEVICE" => CONFIGURATION::WIA_STATUS_RESERVING_NETWORK_DEVICE,
            "WIA_STATUS_NETWORK_DEVICE_RESERVED" => CONFIGURATION::WIA_STATUS_NETWORK_DEVICE_RESERVED,
            "WIA_STATUS_CLEAR" => CONFIGURATION::WIA_STATUS_CLEAR,
            "WIA_STATUS_SKIP_ITEM" => CONFIGURATION::WIA_STATUS_SKIP_ITEM,
            "WIA_STATUS_NOT_HANDLED" => CONFIGURATION::WIA_STATUS_NOT_HANDLED,
            "WIA_ERROR_GENERAL_ERROR" => CONFIGURATION::WIA_ERROR_GENERAL_ERROR,
            "WIA_ERROR_PAPER_JAM" => CONFIGURATION::WIA_ERROR_PAPER_JAM,
            "WIA_ERROR_PAPER_EMPTY" => CONFIGURATION::WIA_ERROR_PAPER_EMPTY,
            "WIA_ERROR_PAPER_PROBLEM" => CONFIGURATION::WIA_ERROR_PAPER_PROBLEM,
            "WIA_ERROR_OFFLINE" => CONFIGURATION::WIA_ERROR_OFFLINE,
            "WIA_ERROR_BUSY" => CONFIGURATION::WIA_ERROR_BUSY,
            "WIA_ERROR_WARMING_UP" => CONFIGURATION::WIA_ERROR_WARMING_UP,
            "WIA_ERROR_USER_INTERVENTION" => CONFIGURATION::WIA_ERROR_USER_INTERVENTION,
            "WIA_ERROR_ITEM_DELETED" => CONFIGURATION::WIA_ERROR_ITEM_DELETED,
            "WIA_ERROR_DEVICE_COMMUNICATION" => CONFIGURATION::WIA_ERROR_DEVICE_COMMUNICATION,
            "WIA_ERROR_INVALID_COMMAND" => CONFIGURATION::WIA_ERROR_INVALID_COMMAND,
            "WIA_ERROR_INCORRECT_HARDWARE_SETTING" => CONFIGURATION::WIA_ERROR_INCORRECT_HARDWARE_SETTING,
            "WIA_ERROR_DEVICE_LOCKED" => CONFIGURATION::WIA_ERROR_DEVICE_LOCKED,
            "WIA_ERROR_EXCEPTION_IN_DRIVER" => CONFIGURATION::WIA_ERROR_EXCEPTION_IN_DRIVER,
            "WIA_ERROR_INVALID_DRIVER_RESPONSE" => CONFIGURATION::WIA_ERROR_INVALID_DRIVER_RESPONSE,
            "WIA_ERROR_COVER_OPEN" => CONFIGURATION::WIA_ERROR_COVER_OPEN,
            "WIA_ERROR_LAMP_OFF" => CONFIGURATION::WIA_ERROR_LAMP_OFF,
            "WIA_ERROR_DESTINATION" => CONFIGURATION::WIA_ERROR_DESTINATION,
            "WIA_ERROR_NETWORK_RESERVATION_FAILED" => CONFIGURATION::WIA_ERROR_NETWORK_RESERVATION_FAILED,
            "WIA_ERROR_MULTI_FEED" => CONFIGURATION::WIA_ERROR_MULTI_FEED,
            "WIA_S_NO_DEVICE_AVAILABLE" => CONFIGURATION::WIA_S_NO_DEVICE_AVAILABLE,
            "WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER" => CONFIGURATION::WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER,
        }
    }
    pub fn from_code(code: u32) -> CONFIGURATION {
        return match code {
            0x00210001 => CONFIGURATION::WIA_STATUS_END_OF_MEDIA,
            0x00210002 => CONFIGURATION::WIA_STATUS_WARMING_UP,
            0x00210003 => CONFIGURATION::WIA_STATUS_CALIBRATING,
            0x00210006 => CONFIGURATION::WIA_STATUS_RESERVING_NETWORK_DEVICE,
            0x00210007 => CONFIGURATION::WIA_STATUS_NETWORK_DEVICE_RESERVED,
            0x00210008 => CONFIGURATION::WIA_STATUS_CLEAR,
            0x00210009 => CONFIGURATION::WIA_STATUS_SKIP_ITEM,
            0x0021000A => CONFIGURATION::WIA_STATUS_NOT_HANDLED,
            0x80210001 => CONFIGURATION::WIA_ERROR_GENERAL_ERROR,
            0x80210002 => CONFIGURATION::WIA_ERROR_PAPER_JAM,
            0x80210003 => CONFIGURATION::WIA_ERROR_PAPER_EMPTY,
            0x80210004 => CONFIGURATION::WIA_ERROR_PAPER_PROBLEM,
            0x80210005 => CONFIGURATION::WIA_ERROR_OFFLINE,
            0x80210006 => CONFIGURATION::WIA_ERROR_BUSY,
            0x80210007 => CONFIGURATION::WIA_ERROR_WARMING_UP,
            0x80210008 => CONFIGURATION::WIA_ERROR_USER_INTERVENTION,
            0x80210009 => CONFIGURATION::WIA_ERROR_ITEM_DELETED,
            0x8021000A => CONFIGURATION::WIA_ERROR_DEVICE_COMMUNICATION,
            0x8021000B => CONFIGURATION::WIA_ERROR_INVALID_COMMAND,
            0x8021000C => CONFIGURATION::WIA_ERROR_INCORRECT_HARDWARE_SETTING,
            0x8021000D => CONFIGURATION::WIA_ERROR_DEVICE_LOCKED,
            0x8021000E => CONFIGURATION::WIA_ERROR_EXCEPTION_IN_DRIVER,
            0x8021000F => CONFIGURATION::WIA_ERROR_INVALID_DRIVER_RESPONSE,
            0x80210010 => CONFIGURATION::WIA_ERROR_COVER_OPEN,
            0x80210011 => CONFIGURATION::WIA_ERROR_LAMP_OFF,
            0x80210012 => CONFIGURATION::WIA_ERROR_DESTINATION,
            0x80210013 => CONFIGURATION::WIA_ERROR_NETWORK_RESERVATION_FAILED,
            0x80210014 => CONFIGURATION::WIA_ERROR_MULTI_FEED,
            0x80210015 => CONFIGURATION::WIA_S_NO_DEVICE_AVAILABLE,
            0x80210015 => CONFIGURATION::WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER,
        }
    }
}
