/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum CONTROL {
    CTL_E_ILLEGALFUNCTIONCALL,
    CTL_E_OVERFLOW,
    CTL_E_OUTOFMEMORY,
    CTL_E_DIVISIONBYZERO,
    CTL_E_OUTOFSTRINGSPACE,
    CTL_E_OUTOFSTACKSPACE,
    CTL_E_BADFILENAMEORNUMBER,
    CTL_E_FILENOTFOUND,
    CTL_E_BADFILEMODE,
    CTL_E_FILEALREADYOPEN,
    CTL_E_DEVICEIOERROR,
    CTL_E_FILEALREADYEXISTS,
    CTL_E_BADRECORDLENGTH,
    CTL_E_DISKFULL,
    CTL_E_BADRECORDNUMBER,
    CTL_E_BADFILENAME,
    CTL_E_TOOMANYFILES,
    CTL_E_DEVICEUNAVAILABLE,
    CTL_E_PERMISSIONDENIED,
    CTL_E_DISKNOTREADY,
    CTL_E_PATHFILEACCESSERROR,
    CTL_E_PATHNOTFOUND,
    CTL_E_INVALIDPATTERNSTRING,
    CTL_E_INVALIDUSEOFNULL,
    CTL_E_INVALIDFILEFORMAT,
    CTL_E_INVALIDPROPERTYVALUE,
    CTL_E_INVALIDPROPERTYARRAYINDEX,
    CTL_E_SETNOTSUPPORTEDATRUNTIME,
    CTL_E_SETNOTSUPPORTED,
    CTL_E_NEEDPROPERTYARRAYINDEX,
    CTL_E_SETNOTPERMITTED,
    CTL_E_GETNOTSUPPORTEDATRUNTIME,
    CTL_E_GETNOTSUPPORTED,
    CTL_E_PROPERTYNOTFOUND,
    CTL_E_INVALIDCLIPBOARDFORMAT,
    CTL_E_INVALIDPICTURE,
    CTL_E_PRINTERERROR,
    CTL_E_CUSTOM_FIRST,
    CTL_E_CANTSAVEFILETOTEMP,
    CTL_E_SEARCHTEXTNOTFOUND,
    CTL_E_REPLACEMENTSTOOLONG,
    adErrProviderFailed,
    adErrInvalidArgument,
    adErrOpeningFile,
    adErrReadFile,
    adErrWriteFile,
    adErrNoCurrentRecord,
    adErrIllegalOperation,
    adErrCantChangeProvider,
    adErrInTransaction,
    adErrFeatureNotAvailable,
    adErrItemNotFound,
    adErrObjectInCollection,
    adErrObjectNotSet,
    adErrDataConversion,
    adErrObjectClosed,
    adErrObjectOpen,
    adErrProviderNotFound,
    adErrBoundToCommand,
    adErrInvalidParamInfo,
    adErrInvalidConnection,
    adErrNotReentrant,
    adErrStillExecuting,
    adErrOperationCancelled,
    adErrStillConnecting,
    adErrInvalidTransaction,
    adErrNotExecuting,
    adErrUnsafeOperation,
    adWrnSecurityDialog,
    adWrnSecurityDialogHeader,
    adErrIntegrityViolation,
    adErrPermissionDenied,
    adErrDataOverflow,
    adErrSchemaViolation,
    adErrSignMismatch,
    adErrCantConvertvalue,
    adErrCantCreate,
    adErrColumnNotOnThisRow,
    adErrURLDoesNotExist,
    adErrURLIntegrViolSetColumns,
    adErrTreePermissionDenied,
    adErrInvalidURL,
    adErrResourceLocked,
    adErrResourceExists,
    adErrCannotComplete,
    adErrVolumeNotFound,
    adErrOutOfSpace,
    adErrResourceOutOfScope,
    adErrUnavailable,
    adErrURLNamedRowDoesNotExist,
    adErrDelResOutOfScope,
    adErrPropInvalidColumn,
    adErrPropInvalidOption,
    adErrPropInvalidValue,
    adErrPropConflicting,
    adErrPropNotAllSettable,
    adErrPropNotSet,
    adErrPropNotSettable,
    adErrPropNotSupported,
    adErrCatalogNotSet,
    adErrCantChangeConnection,
    adErrFieldsUpdateFailed,
    adErrDenyNotSupported,
    adErrDenyTypeNotSupported,
    adErrProviderNotSpecified,
    adErrConnectionStringTooLong,
}

impl CONTROL {
    pub fn code(&self) -> u32 {
        return match self {
            CONTROL::CTL_E_ILLEGALFUNCTIONCALL => 0x800A0005 as u32,
            CONTROL::CTL_E_OVERFLOW => 0x800A0006 as u32,
            CONTROL::CTL_E_OUTOFMEMORY => 0x800A0007 as u32,
            CONTROL::CTL_E_DIVISIONBYZERO => 0x800A000B as u32,
            CONTROL::CTL_E_OUTOFSTRINGSPACE => 0x800A000E as u32,
            CONTROL::CTL_E_OUTOFSTACKSPACE => 0x800A001C as u32,
            CONTROL::CTL_E_BADFILENAMEORNUMBER => 0x800A0034 as u32,
            CONTROL::CTL_E_FILENOTFOUND => 0x800A0035 as u32,
            CONTROL::CTL_E_BADFILEMODE => 0x800A0036 as u32,
            CONTROL::CTL_E_FILEALREADYOPEN => 0x800A0037 as u32,
            CONTROL::CTL_E_DEVICEIOERROR => 0x800A0039 as u32,
            CONTROL::CTL_E_FILEALREADYEXISTS => 0x800A003A as u32,
            CONTROL::CTL_E_BADRECORDLENGTH => 0x800A003B as u32,
            CONTROL::CTL_E_DISKFULL => 0x800A003D as u32,
            CONTROL::CTL_E_BADRECORDNUMBER => 0x800A003F as u32,
            CONTROL::CTL_E_BADFILENAME => 0x800A0040 as u32,
            CONTROL::CTL_E_TOOMANYFILES => 0x800A0043 as u32,
            CONTROL::CTL_E_DEVICEUNAVAILABLE => 0x800A0044 as u32,
            CONTROL::CTL_E_PERMISSIONDENIED => 0x800A0046 as u32,
            CONTROL::CTL_E_DISKNOTREADY => 0x800A0047 as u32,
            CONTROL::CTL_E_PATHFILEACCESSERROR => 0x800A004B as u32,
            CONTROL::CTL_E_PATHNOTFOUND => 0x800A004C as u32,
            CONTROL::CTL_E_INVALIDPATTERNSTRING => 0x800A005D as u32,
            CONTROL::CTL_E_INVALIDUSEOFNULL => 0x800A005E as u32,
            CONTROL::CTL_E_INVALIDFILEFORMAT => 0x800A0141 as u32,
            CONTROL::CTL_E_INVALIDPROPERTYVALUE => 0x800A017C as u32,
            CONTROL::CTL_E_INVALIDPROPERTYARRAYINDEX => 0x800A017D as u32,
            CONTROL::CTL_E_SETNOTSUPPORTEDATRUNTIME => 0x800A017E as u32,
            CONTROL::CTL_E_SETNOTSUPPORTED => 0x800A017F as u32,
            CONTROL::CTL_E_NEEDPROPERTYARRAYINDEX => 0x800A0181 as u32,
            CONTROL::CTL_E_SETNOTPERMITTED => 0x800A0183 as u32,
            CONTROL::CTL_E_GETNOTSUPPORTEDATRUNTIME => 0x800A0189 as u32,
            CONTROL::CTL_E_GETNOTSUPPORTED => 0x800A018A as u32,
            CONTROL::CTL_E_PROPERTYNOTFOUND => 0x800A01A6 as u32,
            CONTROL::CTL_E_INVALIDCLIPBOARDFORMAT => 0x800A01CC as u32,
            CONTROL::CTL_E_INVALIDPICTURE => 0x800A01E1 as u32,
            CONTROL::CTL_E_PRINTERERROR => 0x800A01E2 as u32,
            CONTROL::CTL_E_CUSTOM_FIRST => 0x800A0258 as u32,
            CONTROL::CTL_E_CANTSAVEFILETOTEMP => 0x800A02DF as u32,
            CONTROL::CTL_E_SEARCHTEXTNOTFOUND => 0x800A02E8 as u32,
            CONTROL::CTL_E_REPLACEMENTSTOOLONG => 0x800A02EA as u32,
            CONTROL::adErrProviderFailed => 0x800A0BB8 as u32,
            CONTROL::adErrInvalidArgument => 0x800A0BB9 as u32,
            CONTROL::adErrOpeningFile => 0x800A0BBA as u32,
            CONTROL::adErrReadFile => 0x800A0BBB as u32,
            CONTROL::adErrWriteFile => 0x800A0BBC as u32,
            CONTROL::adErrNoCurrentRecord => 0x800A0BCD as u32,
            CONTROL::adErrIllegalOperation => 0x800A0C93 as u32,
            CONTROL::adErrCantChangeProvider => 0x800A0C94 as u32,
            CONTROL::adErrInTransaction => 0x800A0CAE as u32,
            CONTROL::adErrFeatureNotAvailable => 0x800A0CB3 as u32,
            CONTROL::adErrItemNotFound => 0x800A0CC1 as u32,
            CONTROL::adErrObjectInCollection => 0x800A0D27 as u32,
            CONTROL::adErrObjectNotSet => 0x800A0D5C as u32,
            CONTROL::adErrDataConversion => 0x800A0D5D as u32,
            CONTROL::adErrObjectClosed => 0x800A0E78 as u32,
            CONTROL::adErrObjectOpen => 0x800A0E79 as u32,
            CONTROL::adErrProviderNotFound => 0x800A0E7A as u32,
            CONTROL::adErrBoundToCommand => 0x800A0E7B as u32,
            CONTROL::adErrInvalidParamInfo => 0x800A0E7C as u32,
            CONTROL::adErrInvalidConnection => 0x800A0E7D as u32,
            CONTROL::adErrNotReentrant => 0x800A0E7E as u32,
            CONTROL::adErrStillExecuting => 0x800A0E7F as u32,
            CONTROL::adErrOperationCancelled => 0x800A0E80 as u32,
            CONTROL::adErrStillConnecting => 0x800A0E81 as u32,
            CONTROL::adErrInvalidTransaction => 0x800A0E82 as u32,
            CONTROL::adErrNotExecuting => 0x800A0E83 as u32,
            CONTROL::adErrUnsafeOperation => 0x800A0E84 as u32,
            CONTROL::adWrnSecurityDialog => 0x800A0E85 as u32,
            CONTROL::adWrnSecurityDialogHeader => 0x800A0E86 as u32,
            CONTROL::adErrIntegrityViolation => 0x800A0E87 as u32,
            CONTROL::adErrPermissionDenied => 0x800A0E88 as u32,
            CONTROL::adErrDataOverflow => 0x800A0E89 as u32,
            CONTROL::adErrSchemaViolation => 0x800A0E8A as u32,
            CONTROL::adErrSignMismatch => 0x800A0E8B as u32,
            CONTROL::adErrCantConvertvalue => 0x800A0E8C as u32,
            CONTROL::adErrCantCreate => 0x800A0E8D as u32,
            CONTROL::adErrColumnNotOnThisRow => 0x800A0E8E as u32,
            CONTROL::adErrURLDoesNotExist => 0x800A0E8F as u32,
            CONTROL::adErrURLIntegrViolSetColumns => 0x800A0E8F as u32,
            CONTROL::adErrTreePermissionDenied => 0x800A0E90 as u32,
            CONTROL::adErrInvalidURL => 0x800A0E91 as u32,
            CONTROL::adErrResourceLocked => 0x800A0E92 as u32,
            CONTROL::adErrResourceExists => 0x800A0E93 as u32,
            CONTROL::adErrCannotComplete => 0x800A0E94 as u32,
            CONTROL::adErrVolumeNotFound => 0x800A0E95 as u32,
            CONTROL::adErrOutOfSpace => 0x800A0E96 as u32,
            CONTROL::adErrResourceOutOfScope => 0x800A0E97 as u32,
            CONTROL::adErrUnavailable => 0x800A0E98 as u32,
            CONTROL::adErrURLNamedRowDoesNotExist => 0x800A0E99 as u32,
            CONTROL::adErrDelResOutOfScope => 0x800A0E9A as u32,
            CONTROL::adErrPropInvalidColumn => 0x800A0E9B as u32,
            CONTROL::adErrPropInvalidOption => 0x800A0E9C as u32,
            CONTROL::adErrPropInvalidValue => 0x800A0E9D as u32,
            CONTROL::adErrPropConflicting => 0x800A0E9E as u32,
            CONTROL::adErrPropNotAllSettable => 0x800A0E9F as u32,
            CONTROL::adErrPropNotSet => 0x800A0EA0 as u32,
            CONTROL::adErrPropNotSettable => 0x800A0EA1 as u32,
            CONTROL::adErrPropNotSupported => 0x800A0EA2 as u32,
            CONTROL::adErrCatalogNotSet => 0x800A0EA3 as u32,
            CONTROL::adErrCantChangeConnection => 0x800A0EA4 as u32,
            CONTROL::adErrFieldsUpdateFailed => 0x800A0EA5 as u32,
            CONTROL::adErrDenyNotSupported => 0x800A0EA6 as u32,
            CONTROL::adErrDenyTypeNotSupported => 0x800A0EA7 as u32,
            CONTROL::adErrProviderNotSpecified => 0x800A0EA9 as u32,
            CONTROL::adErrConnectionStringTooLong => 0x800A0EAA as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            CONTROL::CTL_E_ILLEGALFUNCTIONCALL => RawError::Kind(CONTROL::CTL_E_ILLEGALFUNCTIONCALL),
            CONTROL::CTL_E_OVERFLOW => RawError::Kind(CONTROL::CTL_E_OVERFLOW),
            CONTROL::CTL_E_OUTOFMEMORY => RawError::Kind(CONTROL::CTL_E_OUTOFMEMORY),
            CONTROL::CTL_E_DIVISIONBYZERO => RawError::Kind(CONTROL::CTL_E_DIVISIONBYZERO),
            CONTROL::CTL_E_OUTOFSTRINGSPACE => RawError::Kind(CONTROL::CTL_E_OUTOFSTRINGSPACE),
            CONTROL::CTL_E_OUTOFSTACKSPACE => RawError::Kind(CONTROL::CTL_E_OUTOFSTACKSPACE),
            CONTROL::CTL_E_BADFILENAMEORNUMBER => RawError::Kind(CONTROL::CTL_E_BADFILENAMEORNUMBER),
            CONTROL::CTL_E_FILENOTFOUND => RawError::Kind(CONTROL::CTL_E_FILENOTFOUND),
            CONTROL::CTL_E_BADFILEMODE => RawError::Kind(CONTROL::CTL_E_BADFILEMODE),
            CONTROL::CTL_E_FILEALREADYOPEN => RawError::Kind(CONTROL::CTL_E_FILEALREADYOPEN),
            CONTROL::CTL_E_DEVICEIOERROR => RawError::Kind(CONTROL::CTL_E_DEVICEIOERROR),
            CONTROL::CTL_E_FILEALREADYEXISTS => RawError::Kind(CONTROL::CTL_E_FILEALREADYEXISTS),
            CONTROL::CTL_E_BADRECORDLENGTH => RawError::Kind(CONTROL::CTL_E_BADRECORDLENGTH),
            CONTROL::CTL_E_DISKFULL => RawError::Kind(CONTROL::CTL_E_DISKFULL),
            CONTROL::CTL_E_BADRECORDNUMBER => RawError::Kind(CONTROL::CTL_E_BADRECORDNUMBER),
            CONTROL::CTL_E_BADFILENAME => RawError::Kind(CONTROL::CTL_E_BADFILENAME),
            CONTROL::CTL_E_TOOMANYFILES => RawError::Kind(CONTROL::CTL_E_TOOMANYFILES),
            CONTROL::CTL_E_DEVICEUNAVAILABLE => RawError::Kind(CONTROL::CTL_E_DEVICEUNAVAILABLE),
            CONTROL::CTL_E_PERMISSIONDENIED => RawError::Kind(CONTROL::CTL_E_PERMISSIONDENIED),
            CONTROL::CTL_E_DISKNOTREADY => RawError::Kind(CONTROL::CTL_E_DISKNOTREADY),
            CONTROL::CTL_E_PATHFILEACCESSERROR => RawError::Kind(CONTROL::CTL_E_PATHFILEACCESSERROR),
            CONTROL::CTL_E_PATHNOTFOUND => RawError::Kind(CONTROL::CTL_E_PATHNOTFOUND),
            CONTROL::CTL_E_INVALIDPATTERNSTRING => RawError::Kind(CONTROL::CTL_E_INVALIDPATTERNSTRING),
            CONTROL::CTL_E_INVALIDUSEOFNULL => RawError::Kind(CONTROL::CTL_E_INVALIDUSEOFNULL),
            CONTROL::CTL_E_INVALIDFILEFORMAT => RawError::Kind(CONTROL::CTL_E_INVALIDFILEFORMAT),
            CONTROL::CTL_E_INVALIDPROPERTYVALUE => RawError::Kind(CONTROL::CTL_E_INVALIDPROPERTYVALUE),
            CONTROL::CTL_E_INVALIDPROPERTYARRAYINDEX => RawError::Kind(CONTROL::CTL_E_INVALIDPROPERTYARRAYINDEX),
            CONTROL::CTL_E_SETNOTSUPPORTEDATRUNTIME => RawError::Kind(CONTROL::CTL_E_SETNOTSUPPORTEDATRUNTIME),
            CONTROL::CTL_E_SETNOTSUPPORTED => RawError::Kind(CONTROL::CTL_E_SETNOTSUPPORTED),
            CONTROL::CTL_E_NEEDPROPERTYARRAYINDEX => RawError::Kind(CONTROL::CTL_E_NEEDPROPERTYARRAYINDEX),
            CONTROL::CTL_E_SETNOTPERMITTED => RawError::Kind(CONTROL::CTL_E_SETNOTPERMITTED),
            CONTROL::CTL_E_GETNOTSUPPORTEDATRUNTIME => RawError::Kind(CONTROL::CTL_E_GETNOTSUPPORTEDATRUNTIME),
            CONTROL::CTL_E_GETNOTSUPPORTED => RawError::Kind(CONTROL::CTL_E_GETNOTSUPPORTED),
            CONTROL::CTL_E_PROPERTYNOTFOUND => RawError::Kind(CONTROL::CTL_E_PROPERTYNOTFOUND),
            CONTROL::CTL_E_INVALIDCLIPBOARDFORMAT => RawError::Kind(CONTROL::CTL_E_INVALIDCLIPBOARDFORMAT),
            CONTROL::CTL_E_INVALIDPICTURE => RawError::Kind(CONTROL::CTL_E_INVALIDPICTURE),
            CONTROL::CTL_E_PRINTERERROR => RawError::Kind(CONTROL::CTL_E_PRINTERERROR),
            CONTROL::CTL_E_CUSTOM_FIRST => RawError::Kind(CONTROL::CTL_E_CUSTOM_FIRST),
            CONTROL::CTL_E_CANTSAVEFILETOTEMP => RawError::Kind(CONTROL::CTL_E_CANTSAVEFILETOTEMP),
            CONTROL::CTL_E_SEARCHTEXTNOTFOUND => RawError::Kind(CONTROL::CTL_E_SEARCHTEXTNOTFOUND),
            CONTROL::CTL_E_REPLACEMENTSTOOLONG => RawError::Kind(CONTROL::CTL_E_REPLACEMENTSTOOLONG),
            CONTROL::adErrProviderFailed => RawError::Kind(CONTROL::adErrProviderFailed),
            CONTROL::adErrInvalidArgument => RawError::Kind(CONTROL::adErrInvalidArgument),
            CONTROL::adErrOpeningFile => RawError::Kind(CONTROL::adErrOpeningFile),
            CONTROL::adErrReadFile => RawError::Kind(CONTROL::adErrReadFile),
            CONTROL::adErrWriteFile => RawError::Kind(CONTROL::adErrWriteFile),
            CONTROL::adErrNoCurrentRecord => RawError::Kind(CONTROL::adErrNoCurrentRecord),
            CONTROL::adErrIllegalOperation => RawError::Kind(CONTROL::adErrIllegalOperation),
            CONTROL::adErrCantChangeProvider => RawError::Kind(CONTROL::adErrCantChangeProvider),
            CONTROL::adErrInTransaction => RawError::Kind(CONTROL::adErrInTransaction),
            CONTROL::adErrFeatureNotAvailable => RawError::Kind(CONTROL::adErrFeatureNotAvailable),
            CONTROL::adErrItemNotFound => RawError::Kind(CONTROL::adErrItemNotFound),
            CONTROL::adErrObjectInCollection => RawError::Kind(CONTROL::adErrObjectInCollection),
            CONTROL::adErrObjectNotSet => RawError::Kind(CONTROL::adErrObjectNotSet),
            CONTROL::adErrDataConversion => RawError::Kind(CONTROL::adErrDataConversion),
            CONTROL::adErrObjectClosed => RawError::Kind(CONTROL::adErrObjectClosed),
            CONTROL::adErrObjectOpen => RawError::Kind(CONTROL::adErrObjectOpen),
            CONTROL::adErrProviderNotFound => RawError::Kind(CONTROL::adErrProviderNotFound),
            CONTROL::adErrBoundToCommand => RawError::Kind(CONTROL::adErrBoundToCommand),
            CONTROL::adErrInvalidParamInfo => RawError::Kind(CONTROL::adErrInvalidParamInfo),
            CONTROL::adErrInvalidConnection => RawError::Kind(CONTROL::adErrInvalidConnection),
            CONTROL::adErrNotReentrant => RawError::Kind(CONTROL::adErrNotReentrant),
            CONTROL::adErrStillExecuting => RawError::Kind(CONTROL::adErrStillExecuting),
            CONTROL::adErrOperationCancelled => RawError::Kind(CONTROL::adErrOperationCancelled),
            CONTROL::adErrStillConnecting => RawError::Kind(CONTROL::adErrStillConnecting),
            CONTROL::adErrInvalidTransaction => RawError::Kind(CONTROL::adErrInvalidTransaction),
            CONTROL::adErrNotExecuting => RawError::Kind(CONTROL::adErrNotExecuting),
            CONTROL::adErrUnsafeOperation => RawError::Kind(CONTROL::adErrUnsafeOperation),
            CONTROL::adWrnSecurityDialog => RawError::Kind(CONTROL::adWrnSecurityDialog),
            CONTROL::adWrnSecurityDialogHeader => RawError::Kind(CONTROL::adWrnSecurityDialogHeader),
            CONTROL::adErrIntegrityViolation => RawError::Kind(CONTROL::adErrIntegrityViolation),
            CONTROL::adErrPermissionDenied => RawError::Kind(CONTROL::adErrPermissionDenied),
            CONTROL::adErrDataOverflow => RawError::Kind(CONTROL::adErrDataOverflow),
            CONTROL::adErrSchemaViolation => RawError::Kind(CONTROL::adErrSchemaViolation),
            CONTROL::adErrSignMismatch => RawError::Kind(CONTROL::adErrSignMismatch),
            CONTROL::adErrCantConvertvalue => RawError::Kind(CONTROL::adErrCantConvertvalue),
            CONTROL::adErrCantCreate => RawError::Kind(CONTROL::adErrCantCreate),
            CONTROL::adErrColumnNotOnThisRow => RawError::Kind(CONTROL::adErrColumnNotOnThisRow),
            CONTROL::adErrURLDoesNotExist => RawError::Kind(CONTROL::adErrURLDoesNotExist),
            CONTROL::adErrURLIntegrViolSetColumns => RawError::Kind(CONTROL::adErrURLIntegrViolSetColumns),
            CONTROL::adErrTreePermissionDenied => RawError::Kind(CONTROL::adErrTreePermissionDenied),
            CONTROL::adErrInvalidURL => RawError::Kind(CONTROL::adErrInvalidURL),
            CONTROL::adErrResourceLocked => RawError::Kind(CONTROL::adErrResourceLocked),
            CONTROL::adErrResourceExists => RawError::Kind(CONTROL::adErrResourceExists),
            CONTROL::adErrCannotComplete => RawError::Kind(CONTROL::adErrCannotComplete),
            CONTROL::adErrVolumeNotFound => RawError::Kind(CONTROL::adErrVolumeNotFound),
            CONTROL::adErrOutOfSpace => RawError::Kind(CONTROL::adErrOutOfSpace),
            CONTROL::adErrResourceOutOfScope => RawError::Kind(CONTROL::adErrResourceOutOfScope),
            CONTROL::adErrUnavailable => RawError::Kind(CONTROL::adErrUnavailable),
            CONTROL::adErrURLNamedRowDoesNotExist => RawError::Kind(CONTROL::adErrURLNamedRowDoesNotExist),
            CONTROL::adErrDelResOutOfScope => RawError::Kind(CONTROL::adErrDelResOutOfScope),
            CONTROL::adErrPropInvalidColumn => RawError::Kind(CONTROL::adErrPropInvalidColumn),
            CONTROL::adErrPropInvalidOption => RawError::Kind(CONTROL::adErrPropInvalidOption),
            CONTROL::adErrPropInvalidValue => RawError::Kind(CONTROL::adErrPropInvalidValue),
            CONTROL::adErrPropConflicting => RawError::Kind(CONTROL::adErrPropConflicting),
            CONTROL::adErrPropNotAllSettable => RawError::Kind(CONTROL::adErrPropNotAllSettable),
            CONTROL::adErrPropNotSet => RawError::Kind(CONTROL::adErrPropNotSet),
            CONTROL::adErrPropNotSettable => RawError::Kind(CONTROL::adErrPropNotSettable),
            CONTROL::adErrPropNotSupported => RawError::Kind(CONTROL::adErrPropNotSupported),
            CONTROL::adErrCatalogNotSet => RawError::Kind(CONTROL::adErrCatalogNotSet),
            CONTROL::adErrCantChangeConnection => RawError::Kind(CONTROL::adErrCantChangeConnection),
            CONTROL::adErrFieldsUpdateFailed => RawError::Kind(CONTROL::adErrFieldsUpdateFailed),
            CONTROL::adErrDenyNotSupported => RawError::Kind(CONTROL::adErrDenyNotSupported),
            CONTROL::adErrDenyTypeNotSupported => RawError::Kind(CONTROL::adErrDenyTypeNotSupported),
            CONTROL::adErrProviderNotSpecified => RawError::Kind(CONTROL::adErrProviderNotSpecified),
            CONTROL::adErrConnectionStringTooLong => RawError::Kind(CONTROL::adErrConnectionStringTooLong),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            CONTROL::CTL_E_ILLEGALFUNCTIONCALL => "DirectShow: The syntax in the function call was incorrect.",
            CONTROL::CTL_E_OVERFLOW => "DirectShow: The result is too large to be represented in function's return type.",
            CONTROL::CTL_E_OUTOFMEMORY => "DirectShow: There is insufficient memory to perform the requested operation.",
            CONTROL::CTL_E_DIVISIONBYZERO => "DirectShow: The function attempted to divide by zero.",
            CONTROL::CTL_E_OUTOFSTRINGSPACE => "DirectShow: There is insufficient string space to perform the requested operation. Certain operations (copying, for example) involve temporary strings that use up string space.",
            CONTROL::CTL_E_OUTOFSTACKSPACE => "DirectShow: There is insufficient string space to perform the requested operation. Each thread has its own stack while other resources, such as heap memory, are shared by all threads in the process. You must specify how much memory to allocate for a separate stack for each additional thread your program needs. The operating system will allocate additional stack space for the thread, if necessary, but you must specify a default value. If the operating system cannot allocate the necessary space, you receive this error.",
            CONTROL::CTL_E_BADFILENAMEORNUMBER => "DirectShow: The function attempted to access a file with a bad file name or number.",
            CONTROL::CTL_E_FILENOTFOUND => "DirectShow: The function attempted to access a file that could not be found.",
            CONTROL::CTL_E_BADFILEMODE => "DirectShow: The function attempted to perform an operation on a file that has an incompatible file mode. File modes are Append, Binary, Input, Output, or Random.",
            CONTROL::CTL_E_FILEALREADYOPEN => "DirectShow: The function attempted to open a file that was already open.",
            CONTROL::CTL_E_DEVICEIOERROR => "DirectShow: There was a device I/O error during the function execution.",
            CONTROL::CTL_E_FILEALREADYEXISTS => "DirectShow: The function attempted to create a file that already exists.",
            CONTROL::CTL_E_BADRECORDLENGTH => "DirectShow: The function attempted to access a file record that is incorrect. For example, it is assumed that a file opened for random access is composed of a set of identical-length records.",
            CONTROL::CTL_E_DISKFULL => "DirectShow: The function attempted to write to the disk, but the disk is full.",
            CONTROL::CTL_E_BADRECORDNUMBER => "DirectShow: The function attempted to access a file record that is incorrect. The record number is the position of the position in a recordset (a set of records in a data source).",
            CONTROL::CTL_E_BADFILENAME => "DirectShow: The function attempted to access a file name that is incorrect.",
            CONTROL::CTL_E_TOOMANYFILES => "DirectShow: The function attempted to open a file when too many files were already open.",
            CONTROL::CTL_E_DEVICEUNAVAILABLE => "DirectShow: The function attempted to access a device that was not available.",
            CONTROL::CTL_E_PERMISSIONDENIED => "DirectShow: The function attempted to access a file without the proper permission setting.",
            CONTROL::CTL_E_DISKNOTREADY => "DirectShow: The function attempted to access a file when the disk was not ready.",
            CONTROL::CTL_E_PATHFILEACCESSERROR => "DirectShow: The function attempted to access a file or path that was incorrect or had the wrong permissions.",
            CONTROL::CTL_E_PATHNOTFOUND => "DirectShow: The function attempted to access a file with an incorrect path.",
            CONTROL::CTL_E_INVALIDPATTERNSTRING => "DirectShow: The function was called with an invalid string.",
            CONTROL::CTL_E_INVALIDUSEOFNULL => "DirectShow: The function was called with an invalid NULL.",
            CONTROL::CTL_E_INVALIDFILEFORMAT => "DirectShow: The function attempted to perform an operation on a file that has an incompatible file format.",
            CONTROL::CTL_E_INVALIDPROPERTYVALUE => "DirectShow: The function was called with an invalid property value.",
            CONTROL::CTL_E_INVALIDPROPERTYARRAYINDEX => "DirectShow: The function was called with an invalid property array index.",
            CONTROL::CTL_E_SETNOTSUPPORTEDATRUNTIME => "DirectShow: The function attempted to set a property that cannot be set at run time.",
            CONTROL::CTL_E_SETNOTSUPPORTED => "DirectShow: The function attempted to set a property that cannot be set.",
            CONTROL::CTL_E_NEEDPROPERTYARRAYINDEX => "DirectShow: The function attempted to access a property that needs an array index without the array index.",
            CONTROL::CTL_E_SETNOTPERMITTED => "DirectShow: The function attempted to set a property without the proper permissions to set the property.",
            CONTROL::CTL_E_GETNOTSUPPORTEDATRUNTIME => "DirectShow: The function attempted to get a property that cannot be retrieved at run time.",
            CONTROL::CTL_E_GETNOTSUPPORTED => "DirectShow: The function attempted to get a property that cannot be retrieved.",
            CONTROL::CTL_E_PROPERTYNOTFOUND => "DirectShow: The function attempted to get a property that could not be found.",
            CONTROL::CTL_E_INVALIDCLIPBOARDFORMAT => "DirectShow: The function attempted an operation with an invalid Clipboard format.",
            CONTROL::CTL_E_INVALIDPICTURE => "DirectShow: The function attempted an operation with an invalid picture.",
            CONTROL::CTL_E_PRINTERERROR => "DirectShow: The function attempted to print, and there was a printer error.",
            CONTROL::CTL_E_CUSTOM_FIRST => "DirectShow: A custom error.",
            CONTROL::CTL_E_CANTSAVEFILETOTEMP => "DirectShow: The file cannot be saved to the TEMP directory.",
            CONTROL::CTL_E_SEARCHTEXTNOTFOUND => "DirectShow: The searched-for text cannot be found.",
            CONTROL::CTL_E_REPLACEMENTSTOOLONG => "DirectShow: The text replacement is too long.",
            CONTROL::adErrProviderFailed => "Error ADO: Provider failed to perform the requested operation.",
            CONTROL::adErrInvalidArgument => "Error ADO: Arguments are of the wrong type, are out of acceptable range, or are in conflict with one another.",
            CONTROL::adErrOpeningFile => "Error ADO: File could not be opened.",
            CONTROL::adErrReadFile => "Error ADO: File could not be read.",
            CONTROL::adErrWriteFile => "Error ADO: Write to file failed.",
            CONTROL::adErrNoCurrentRecord => "Error ADO: Either BOF or EOF is True, or the current record has been deleted. Requested operation requires a current record.",
            CONTROL::adErrIllegalOperation => "Error ADO: Operation is not allowed in this context.",
            CONTROL::adErrCantChangeProvider => "Error ADO: Supplied provider is different from the one already in use.",
            CONTROL::adErrInTransaction => "Error ADO: Connection object cannot be explicitly closed while in a transaction.",
            CONTROL::adErrFeatureNotAvailable => "Error ADO: Object or provider is not capable of performing requested operation.",
            CONTROL::adErrItemNotFound => "Error ADO: Item cannot be found in the collection corresponding to the requested name or ordinal.",
            CONTROL::adErrObjectInCollection => "Error ADO: Object is already in collection. Cannot append.",
            CONTROL::adErrObjectNotSet => "Error ADO: Object is no longer valid.",
            CONTROL::adErrDataConversion => "Error ADO: Application uses a value of the wrong type for the current operation.",
            CONTROL::adErrObjectClosed => "Error ADO: Operation is not allowed when the object is closed.",
            CONTROL::adErrObjectOpen => "Error ADO: Operation is not allowed when the object is open.",
            CONTROL::adErrProviderNotFound => "Error ADO: Provider cannot be found. It may not be properly installed.",
            CONTROL::adErrBoundToCommand => "Error ADO: Cannot change the ActiveConnection property of a Recordset object which has a Command object as its source.",
            CONTROL::adErrInvalidParamInfo => "Error ADO: Parameter object is improperly defined. Inconsistent or incomplete information was provided.",
            CONTROL::adErrInvalidConnection => "Error ADO: The connection cannot be used to perform this operation. It is either closed or invalid in this context.",
            CONTROL::adErrNotReentrant => "Error ADO: Operation cannot be performed while processing event.",
            CONTROL::adErrStillExecuting => "Error ADO: Operation cannot be performed while executing asynchronously.",
            CONTROL::adErrOperationCancelled => "Error ADO: Operation has been cancelled by the user.",
            CONTROL::adErrStillConnecting => "Error ADO: Operation cannot be performed while connecting aynchronously.",
            CONTROL::adErrInvalidTransaction => "Error ADO: Coordinating transaction is invalid or has not started.",
            CONTROL::adErrNotExecuting => "Error ADO: Operation cannot be performed while not executing.",
            CONTROL::adErrUnsafeOperation => "Error ADO: Safety settings on this computer prohibit accessing a data source on another domain.",
            CONTROL::adWrnSecurityDialog => "Error ADO: For internal use only. Don't use.",
            CONTROL::adWrnSecurityDialogHeader => "Error ADO: For internal use only. Don't use.",
            CONTROL::adErrIntegrityViolation => "Error ADO: Data value conflicts with the integrity constraints of the field.",
            CONTROL::adErrPermissionDenied => "Error ADO: Insufficent permission prevents writing to the field.",
            CONTROL::adErrDataOverflow => "Error ADO: Data value is too large to be represented by the field data type.",
            CONTROL::adErrSchemaViolation => "Error ADO: Data value conflicts with the data type or constraints of the field.",
            CONTROL::adErrSignMismatch => "Error ADO: Conversion failed because the data value was signed and the field data type used by the provider was unsigned.",
            CONTROL::adErrCantConvertvalue => "Error ADO: Data value cannot be converted for reasons other than sign mismatch or data overflow. For example, conversion would have truncated data.",
            CONTROL::adErrCantCreate => "Error ADO: Data value cannot be set or retrieved because the field data type was unknown, or the provider had insufficient resources to perform the operation.",
            CONTROL::adErrColumnNotOnThisRow => "Error ADO: Record does not contain this field.",
            CONTROL::adErrURLDoesNotExist => "Error ADO: Either the source URL or the parent of the destination URL does not exist.",
            CONTROL::adErrURLIntegrViolSetColumns => "Error ADO: Either the source URL or the parent of the destination URL violates the column integrity.",
            CONTROL::adErrTreePermissionDenied => "Error ADO: Permissions are insufficient to access tree or subtree.",
            CONTROL::adErrInvalidURL => "Error ADO: URL contains invalid characters. Make sure the URL is typed correctly.",
            CONTROL::adErrResourceLocked => "Error ADO: Object represented by the specified URL is locked by one or more other processes. Wait until the process has finished and attempt the operation again.",
            CONTROL::adErrResourceExists => "Error ADO: Copy operation cannot be performed. Object named by destination URL already exists. Specify adCopyOverwrite to replace the object.",
            CONTROL::adErrCannotComplete => "Error ADO: Server cannot complete the operation.",
            CONTROL::adErrVolumeNotFound => "Error ADO: Provider cannot locate the storage device indicated by the URL. Make sure the URL is typed correctly.",
            CONTROL::adErrOutOfSpace => "Error ADO: Operation cannot be performed. Provider cannot obtain enough storage space.",
            CONTROL::adErrResourceOutOfScope => "Error ADO: Source or destination URL is outside the scope of the current record.",
            CONTROL::adErrUnavailable => "Error ADO: Operation failed to complete and the status is unavailable. The field may be unavailable or the operation was not attempted.",
            CONTROL::adErrURLNamedRowDoesNotExist => "Error ADO: Record named by this URL does not exist.",
            CONTROL::adErrDelResOutOfScope => "Error ADO: URL of the object to be deleted is outside the scope of the current record.",
            CONTROL::adErrPropInvalidColumn => "Error ADO: Property cannot apply to the specified field.",
            CONTROL::adErrPropInvalidOption => "Error ADO: Property attribute is invalid.",
            CONTROL::adErrPropInvalidValue => "Error ADO: Property value is invalid. Make sure the value is typed correctly.",
            CONTROL::adErrPropConflicting => "Error ADO: Property value conflicts with a related property.",
            CONTROL::adErrPropNotAllSettable => "Error ADO: Property is read-only or cannot be set.",
            CONTROL::adErrPropNotSet => "Error ADO: Optional property value was not set.",
            CONTROL::adErrPropNotSettable => "Error ADO: Read-only property value was not set.",
            CONTROL::adErrPropNotSupported => "Error ADO: Provider does not support the property.",
            CONTROL::adErrCatalogNotSet => "Error ADO: Operation requires a valid ParentCatalog.",
            CONTROL::adErrCantChangeConnection => "Error ADO: Connection was denied. New connection you requested has different characteristics than the one already in use.",
            CONTROL::adErrFieldsUpdateFailed => "Error ADO: Fields update failed. For further information, examine the Status property of individual field objects.",
            CONTROL::adErrDenyNotSupported => "Error ADO: Provider does not support sharing restrictions.",
            CONTROL::adErrDenyTypeNotSupported => "Error ADO: Provider does not support the requested kind of sharing restriction.",
            CONTROL::adErrProviderNotSpecified => "Error ADO: Provider is not specified",
            CONTROL::adErrConnectionStringTooLong => "Error ADO: Connection string is too long",
        }
    }

    pub fn from_name(name: &str) -> CONTROL {
        return match name {
            "CTL_E_ILLEGALFUNCTIONCALL" => CONTROL::CTL_E_ILLEGALFUNCTIONCALL,
            "CTL_E_OVERFLOW" => CONTROL::CTL_E_OVERFLOW,
            "CTL_E_OUTOFMEMORY" => CONTROL::CTL_E_OUTOFMEMORY,
            "CTL_E_DIVISIONBYZERO" => CONTROL::CTL_E_DIVISIONBYZERO,
            "CTL_E_OUTOFSTRINGSPACE" => CONTROL::CTL_E_OUTOFSTRINGSPACE,
            "CTL_E_OUTOFSTACKSPACE" => CONTROL::CTL_E_OUTOFSTACKSPACE,
            "CTL_E_BADFILENAMEORNUMBER" => CONTROL::CTL_E_BADFILENAMEORNUMBER,
            "CTL_E_FILENOTFOUND" => CONTROL::CTL_E_FILENOTFOUND,
            "CTL_E_BADFILEMODE" => CONTROL::CTL_E_BADFILEMODE,
            "CTL_E_FILEALREADYOPEN" => CONTROL::CTL_E_FILEALREADYOPEN,
            "CTL_E_DEVICEIOERROR" => CONTROL::CTL_E_DEVICEIOERROR,
            "CTL_E_FILEALREADYEXISTS" => CONTROL::CTL_E_FILEALREADYEXISTS,
            "CTL_E_BADRECORDLENGTH" => CONTROL::CTL_E_BADRECORDLENGTH,
            "CTL_E_DISKFULL" => CONTROL::CTL_E_DISKFULL,
            "CTL_E_BADRECORDNUMBER" => CONTROL::CTL_E_BADRECORDNUMBER,
            "CTL_E_BADFILENAME" => CONTROL::CTL_E_BADFILENAME,
            "CTL_E_TOOMANYFILES" => CONTROL::CTL_E_TOOMANYFILES,
            "CTL_E_DEVICEUNAVAILABLE" => CONTROL::CTL_E_DEVICEUNAVAILABLE,
            "CTL_E_PERMISSIONDENIED" => CONTROL::CTL_E_PERMISSIONDENIED,
            "CTL_E_DISKNOTREADY" => CONTROL::CTL_E_DISKNOTREADY,
            "CTL_E_PATHFILEACCESSERROR" => CONTROL::CTL_E_PATHFILEACCESSERROR,
            "CTL_E_PATHNOTFOUND" => CONTROL::CTL_E_PATHNOTFOUND,
            "CTL_E_INVALIDPATTERNSTRING" => CONTROL::CTL_E_INVALIDPATTERNSTRING,
            "CTL_E_INVALIDUSEOFNULL" => CONTROL::CTL_E_INVALIDUSEOFNULL,
            "CTL_E_INVALIDFILEFORMAT" => CONTROL::CTL_E_INVALIDFILEFORMAT,
            "CTL_E_INVALIDPROPERTYVALUE" => CONTROL::CTL_E_INVALIDPROPERTYVALUE,
            "CTL_E_INVALIDPROPERTYARRAYINDEX" => CONTROL::CTL_E_INVALIDPROPERTYARRAYINDEX,
            "CTL_E_SETNOTSUPPORTEDATRUNTIME" => CONTROL::CTL_E_SETNOTSUPPORTEDATRUNTIME,
            "CTL_E_SETNOTSUPPORTED" => CONTROL::CTL_E_SETNOTSUPPORTED,
            "CTL_E_NEEDPROPERTYARRAYINDEX" => CONTROL::CTL_E_NEEDPROPERTYARRAYINDEX,
            "CTL_E_SETNOTPERMITTED" => CONTROL::CTL_E_SETNOTPERMITTED,
            "CTL_E_GETNOTSUPPORTEDATRUNTIME" => CONTROL::CTL_E_GETNOTSUPPORTEDATRUNTIME,
            "CTL_E_GETNOTSUPPORTED" => CONTROL::CTL_E_GETNOTSUPPORTED,
            "CTL_E_PROPERTYNOTFOUND" => CONTROL::CTL_E_PROPERTYNOTFOUND,
            "CTL_E_INVALIDCLIPBOARDFORMAT" => CONTROL::CTL_E_INVALIDCLIPBOARDFORMAT,
            "CTL_E_INVALIDPICTURE" => CONTROL::CTL_E_INVALIDPICTURE,
            "CTL_E_PRINTERERROR" => CONTROL::CTL_E_PRINTERERROR,
            "CTL_E_CUSTOM_FIRST" => CONTROL::CTL_E_CUSTOM_FIRST,
            "CTL_E_CANTSAVEFILETOTEMP" => CONTROL::CTL_E_CANTSAVEFILETOTEMP,
            "CTL_E_SEARCHTEXTNOTFOUND" => CONTROL::CTL_E_SEARCHTEXTNOTFOUND,
            "CTL_E_REPLACEMENTSTOOLONG" => CONTROL::CTL_E_REPLACEMENTSTOOLONG,
            "adErrProviderFailed" => CONTROL::adErrProviderFailed,
            "adErrInvalidArgument" => CONTROL::adErrInvalidArgument,
            "adErrOpeningFile" => CONTROL::adErrOpeningFile,
            "adErrReadFile" => CONTROL::adErrReadFile,
            "adErrWriteFile" => CONTROL::adErrWriteFile,
            "adErrNoCurrentRecord" => CONTROL::adErrNoCurrentRecord,
            "adErrIllegalOperation" => CONTROL::adErrIllegalOperation,
            "adErrCantChangeProvider" => CONTROL::adErrCantChangeProvider,
            "adErrInTransaction" => CONTROL::adErrInTransaction,
            "adErrFeatureNotAvailable" => CONTROL::adErrFeatureNotAvailable,
            "adErrItemNotFound" => CONTROL::adErrItemNotFound,
            "adErrObjectInCollection" => CONTROL::adErrObjectInCollection,
            "adErrObjectNotSet" => CONTROL::adErrObjectNotSet,
            "adErrDataConversion" => CONTROL::adErrDataConversion,
            "adErrObjectClosed" => CONTROL::adErrObjectClosed,
            "adErrObjectOpen" => CONTROL::adErrObjectOpen,
            "adErrProviderNotFound" => CONTROL::adErrProviderNotFound,
            "adErrBoundToCommand" => CONTROL::adErrBoundToCommand,
            "adErrInvalidParamInfo" => CONTROL::adErrInvalidParamInfo,
            "adErrInvalidConnection" => CONTROL::adErrInvalidConnection,
            "adErrNotReentrant" => CONTROL::adErrNotReentrant,
            "adErrStillExecuting" => CONTROL::adErrStillExecuting,
            "adErrOperationCancelled" => CONTROL::adErrOperationCancelled,
            "adErrStillConnecting" => CONTROL::adErrStillConnecting,
            "adErrInvalidTransaction" => CONTROL::adErrInvalidTransaction,
            "adErrNotExecuting" => CONTROL::adErrNotExecuting,
            "adErrUnsafeOperation" => CONTROL::adErrUnsafeOperation,
            "adWrnSecurityDialog" => CONTROL::adWrnSecurityDialog,
            "adWrnSecurityDialogHeader" => CONTROL::adWrnSecurityDialogHeader,
            "adErrIntegrityViolation" => CONTROL::adErrIntegrityViolation,
            "adErrPermissionDenied" => CONTROL::adErrPermissionDenied,
            "adErrDataOverflow" => CONTROL::adErrDataOverflow,
            "adErrSchemaViolation" => CONTROL::adErrSchemaViolation,
            "adErrSignMismatch" => CONTROL::adErrSignMismatch,
            "adErrCantConvertvalue" => CONTROL::adErrCantConvertvalue,
            "adErrCantCreate" => CONTROL::adErrCantCreate,
            "adErrColumnNotOnThisRow" => CONTROL::adErrColumnNotOnThisRow,
            "adErrURLDoesNotExist" => CONTROL::adErrURLDoesNotExist,
            "adErrURLIntegrViolSetColumns" => CONTROL::adErrURLIntegrViolSetColumns,
            "adErrTreePermissionDenied" => CONTROL::adErrTreePermissionDenied,
            "adErrInvalidURL" => CONTROL::adErrInvalidURL,
            "adErrResourceLocked" => CONTROL::adErrResourceLocked,
            "adErrResourceExists" => CONTROL::adErrResourceExists,
            "adErrCannotComplete" => CONTROL::adErrCannotComplete,
            "adErrVolumeNotFound" => CONTROL::adErrVolumeNotFound,
            "adErrOutOfSpace" => CONTROL::adErrOutOfSpace,
            "adErrResourceOutOfScope" => CONTROL::adErrResourceOutOfScope,
            "adErrUnavailable" => CONTROL::adErrUnavailable,
            "adErrURLNamedRowDoesNotExist" => CONTROL::adErrURLNamedRowDoesNotExist,
            "adErrDelResOutOfScope" => CONTROL::adErrDelResOutOfScope,
            "adErrPropInvalidColumn" => CONTROL::adErrPropInvalidColumn,
            "adErrPropInvalidOption" => CONTROL::adErrPropInvalidOption,
            "adErrPropInvalidValue" => CONTROL::adErrPropInvalidValue,
            "adErrPropConflicting" => CONTROL::adErrPropConflicting,
            "adErrPropNotAllSettable" => CONTROL::adErrPropNotAllSettable,
            "adErrPropNotSet" => CONTROL::adErrPropNotSet,
            "adErrPropNotSettable" => CONTROL::adErrPropNotSettable,
            "adErrPropNotSupported" => CONTROL::adErrPropNotSupported,
            "adErrCatalogNotSet" => CONTROL::adErrCatalogNotSet,
            "adErrCantChangeConnection" => CONTROL::adErrCantChangeConnection,
            "adErrFieldsUpdateFailed" => CONTROL::adErrFieldsUpdateFailed,
            "adErrDenyNotSupported" => CONTROL::adErrDenyNotSupported,
            "adErrDenyTypeNotSupported" => CONTROL::adErrDenyTypeNotSupported,
            "adErrProviderNotSpecified" => CONTROL::adErrProviderNotSpecified,
            "adErrConnectionStringTooLong" => CONTROL::adErrConnectionStringTooLong,
        }
    }
    pub fn from_code(code: u32) -> CONTROL {
        return match code {
            0x800A0005 => CONTROL::CTL_E_ILLEGALFUNCTIONCALL,
            0x800A0006 => CONTROL::CTL_E_OVERFLOW,
            0x800A0007 => CONTROL::CTL_E_OUTOFMEMORY,
            0x800A000B => CONTROL::CTL_E_DIVISIONBYZERO,
            0x800A000E => CONTROL::CTL_E_OUTOFSTRINGSPACE,
            0x800A001C => CONTROL::CTL_E_OUTOFSTACKSPACE,
            0x800A0034 => CONTROL::CTL_E_BADFILENAMEORNUMBER,
            0x800A0035 => CONTROL::CTL_E_FILENOTFOUND,
            0x800A0036 => CONTROL::CTL_E_BADFILEMODE,
            0x800A0037 => CONTROL::CTL_E_FILEALREADYOPEN,
            0x800A0039 => CONTROL::CTL_E_DEVICEIOERROR,
            0x800A003A => CONTROL::CTL_E_FILEALREADYEXISTS,
            0x800A003B => CONTROL::CTL_E_BADRECORDLENGTH,
            0x800A003D => CONTROL::CTL_E_DISKFULL,
            0x800A003F => CONTROL::CTL_E_BADRECORDNUMBER,
            0x800A0040 => CONTROL::CTL_E_BADFILENAME,
            0x800A0043 => CONTROL::CTL_E_TOOMANYFILES,
            0x800A0044 => CONTROL::CTL_E_DEVICEUNAVAILABLE,
            0x800A0046 => CONTROL::CTL_E_PERMISSIONDENIED,
            0x800A0047 => CONTROL::CTL_E_DISKNOTREADY,
            0x800A004B => CONTROL::CTL_E_PATHFILEACCESSERROR,
            0x800A004C => CONTROL::CTL_E_PATHNOTFOUND,
            0x800A005D => CONTROL::CTL_E_INVALIDPATTERNSTRING,
            0x800A005E => CONTROL::CTL_E_INVALIDUSEOFNULL,
            0x800A0141 => CONTROL::CTL_E_INVALIDFILEFORMAT,
            0x800A017C => CONTROL::CTL_E_INVALIDPROPERTYVALUE,
            0x800A017D => CONTROL::CTL_E_INVALIDPROPERTYARRAYINDEX,
            0x800A017E => CONTROL::CTL_E_SETNOTSUPPORTEDATRUNTIME,
            0x800A017F => CONTROL::CTL_E_SETNOTSUPPORTED,
            0x800A0181 => CONTROL::CTL_E_NEEDPROPERTYARRAYINDEX,
            0x800A0183 => CONTROL::CTL_E_SETNOTPERMITTED,
            0x800A0189 => CONTROL::CTL_E_GETNOTSUPPORTEDATRUNTIME,
            0x800A018A => CONTROL::CTL_E_GETNOTSUPPORTED,
            0x800A01A6 => CONTROL::CTL_E_PROPERTYNOTFOUND,
            0x800A01CC => CONTROL::CTL_E_INVALIDCLIPBOARDFORMAT,
            0x800A01E1 => CONTROL::CTL_E_INVALIDPICTURE,
            0x800A01E2 => CONTROL::CTL_E_PRINTERERROR,
            0x800A0258 => CONTROL::CTL_E_CUSTOM_FIRST,
            0x800A02DF => CONTROL::CTL_E_CANTSAVEFILETOTEMP,
            0x800A02E8 => CONTROL::CTL_E_SEARCHTEXTNOTFOUND,
            0x800A02EA => CONTROL::CTL_E_REPLACEMENTSTOOLONG,
            0x800A0BB8 => CONTROL::adErrProviderFailed,
            0x800A0BB9 => CONTROL::adErrInvalidArgument,
            0x800A0BBA => CONTROL::adErrOpeningFile,
            0x800A0BBB => CONTROL::adErrReadFile,
            0x800A0BBC => CONTROL::adErrWriteFile,
            0x800A0BCD => CONTROL::adErrNoCurrentRecord,
            0x800A0C93 => CONTROL::adErrIllegalOperation,
            0x800A0C94 => CONTROL::adErrCantChangeProvider,
            0x800A0CAE => CONTROL::adErrInTransaction,
            0x800A0CB3 => CONTROL::adErrFeatureNotAvailable,
            0x800A0CC1 => CONTROL::adErrItemNotFound,
            0x800A0D27 => CONTROL::adErrObjectInCollection,
            0x800A0D5C => CONTROL::adErrObjectNotSet,
            0x800A0D5D => CONTROL::adErrDataConversion,
            0x800A0E78 => CONTROL::adErrObjectClosed,
            0x800A0E79 => CONTROL::adErrObjectOpen,
            0x800A0E7A => CONTROL::adErrProviderNotFound,
            0x800A0E7B => CONTROL::adErrBoundToCommand,
            0x800A0E7C => CONTROL::adErrInvalidParamInfo,
            0x800A0E7D => CONTROL::adErrInvalidConnection,
            0x800A0E7E => CONTROL::adErrNotReentrant,
            0x800A0E7F => CONTROL::adErrStillExecuting,
            0x800A0E80 => CONTROL::adErrOperationCancelled,
            0x800A0E81 => CONTROL::adErrStillConnecting,
            0x800A0E82 => CONTROL::adErrInvalidTransaction,
            0x800A0E83 => CONTROL::adErrNotExecuting,
            0x800A0E84 => CONTROL::adErrUnsafeOperation,
            0x800A0E85 => CONTROL::adWrnSecurityDialog,
            0x800A0E86 => CONTROL::adWrnSecurityDialogHeader,
            0x800A0E87 => CONTROL::adErrIntegrityViolation,
            0x800A0E88 => CONTROL::adErrPermissionDenied,
            0x800A0E89 => CONTROL::adErrDataOverflow,
            0x800A0E8A => CONTROL::adErrSchemaViolation,
            0x800A0E8B => CONTROL::adErrSignMismatch,
            0x800A0E8C => CONTROL::adErrCantConvertvalue,
            0x800A0E8D => CONTROL::adErrCantCreate,
            0x800A0E8E => CONTROL::adErrColumnNotOnThisRow,
            0x800A0E8F => CONTROL::adErrURLDoesNotExist,
            0x800A0E8F => CONTROL::adErrURLIntegrViolSetColumns,
            0x800A0E90 => CONTROL::adErrTreePermissionDenied,
            0x800A0E91 => CONTROL::adErrInvalidURL,
            0x800A0E92 => CONTROL::adErrResourceLocked,
            0x800A0E93 => CONTROL::adErrResourceExists,
            0x800A0E94 => CONTROL::adErrCannotComplete,
            0x800A0E95 => CONTROL::adErrVolumeNotFound,
            0x800A0E96 => CONTROL::adErrOutOfSpace,
            0x800A0E97 => CONTROL::adErrResourceOutOfScope,
            0x800A0E98 => CONTROL::adErrUnavailable,
            0x800A0E99 => CONTROL::adErrURLNamedRowDoesNotExist,
            0x800A0E9A => CONTROL::adErrDelResOutOfScope,
            0x800A0E9B => CONTROL::adErrPropInvalidColumn,
            0x800A0E9C => CONTROL::adErrPropInvalidOption,
            0x800A0E9D => CONTROL::adErrPropInvalidValue,
            0x800A0E9E => CONTROL::adErrPropConflicting,
            0x800A0E9F => CONTROL::adErrPropNotAllSettable,
            0x800A0EA0 => CONTROL::adErrPropNotSet,
            0x800A0EA1 => CONTROL::adErrPropNotSettable,
            0x800A0EA2 => CONTROL::adErrPropNotSupported,
            0x800A0EA3 => CONTROL::adErrCatalogNotSet,
            0x800A0EA4 => CONTROL::adErrCantChangeConnection,
            0x800A0EA5 => CONTROL::adErrFieldsUpdateFailed,
            0x800A0EA6 => CONTROL::adErrDenyNotSupported,
            0x800A0EA7 => CONTROL::adErrDenyTypeNotSupported,
            0x800A0EA9 => CONTROL::adErrProviderNotSpecified,
            0x800A0EAA => CONTROL::adErrConnectionStringTooLong,
        }
    }
}
