/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum D2D {
    D2DERR_WRONG_STATE,
    D2DERR_NOT_INITIALIZED,
    D2DERR_UNSUPPORTED_OPERATION,
    D2DERR_SCANNER_FAILED,
    D2DERR_SCREEN_ACCESS_DENIED,
    D2DERR_DISPLAY_STATE_INVALID,
    D2DERR_ZERO_VECTOR,
    D2DERR_INTERNAL_ERROR,
    D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED,
    D2DERR_INVALID_CALL,
    D2DERR_NO_HARDWARE_DEVICE,
    D2DERR_RECREATE_TARGET,
    D2DERR_TOO_MANY_SHADER_ELEMENTS,
    D2DERR_SHADER_COMPILE_FAILED,
    D2DERR_MAX_TEXTURE_SIZE_EXCEEDED,
    D2DERR_UNSUPPORTED_VERSION,
    D2DERR_BAD_NUMBER,
    D2DERR_WRONG_FACTORY,
    D2DERR_LAYER_ALREADY_IN_USE,
    D2DERR_POP_CALL_DID_NOT_MATCH_PUSH,
    D2DERR_WRONG_RESOURCE_DOMAIN,
    D2DERR_PUSH_POP_UNBALANCED,
    D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT,
    D2DERR_INCOMPATIBLE_BRUSH_TYPES,
    D2DERR_WIN32_ERROR,
    D2DERR_TARGET_NOT_GDI_COMPATIBLE,
    D2DERR_TEXT_EFFECT_IS_WRONG_TYPE,
    D2DERR_TEXT_RENDERER_NOT_RELEASED,
    D2DERR_EXCEEDS_MAX_BITMAP_SIZE,
    D2DERR_INVALID_GRAPH_CONFIGURATION,
    D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION,
    D2DERR_CYCLIC_GRAPH,
    D2DERR_BITMAP_CANNOT_DRAW,
    D2DERR_OUTSTANDING_BITMAP_REFERENCES,
    D2DERR_ORIGINAL_TARGET_NOT_BOUND,
    D2DERR_INVALID_TARGET,
    D2DERR_BITMAP_BOUND_AS_TARGET,
    D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES,
    D2DERR_INTERMEDIATE_TOO_LARGE,
    D2DERR_EFFECT_IS_NOT_REGISTERED,
    D2DERR_INVALID_PROPERTY,
    D2DERR_NO_SUBPROPERTIES,
    D2DERR_PRINT_JOB_CLOSED,
    D2DERR_PRINT_FORMAT_NOT_SUPPORTED,
    D2DERR_TOO_MANY_TRANSFORM_INPUTS,
    D2DERR_INVALID_GLYPH_IMAGE,
}

impl D2D {
    pub fn code(&self) -> u32 {
        return match self {
            D2D::D2DERR_WRONG_STATE => 0x88990001 as u32,
            D2D::D2DERR_NOT_INITIALIZED => 0x88990002 as u32,
            D2D::D2DERR_UNSUPPORTED_OPERATION => 0x88990003 as u32,
            D2D::D2DERR_SCANNER_FAILED => 0x88990004 as u32,
            D2D::D2DERR_SCREEN_ACCESS_DENIED => 0x88990005 as u32,
            D2D::D2DERR_DISPLAY_STATE_INVALID => 0x88990006 as u32,
            D2D::D2DERR_ZERO_VECTOR => 0x88990007 as u32,
            D2D::D2DERR_INTERNAL_ERROR => 0x88990008 as u32,
            D2D::D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED => 0x88990009 as u32,
            D2D::D2DERR_INVALID_CALL => 0x8899000A as u32,
            D2D::D2DERR_NO_HARDWARE_DEVICE => 0x8899000B as u32,
            D2D::D2DERR_RECREATE_TARGET => 0x8899000C as u32,
            D2D::D2DERR_TOO_MANY_SHADER_ELEMENTS => 0x8899000D as u32,
            D2D::D2DERR_SHADER_COMPILE_FAILED => 0x8899000E as u32,
            D2D::D2DERR_MAX_TEXTURE_SIZE_EXCEEDED => 0x8899000F as u32,
            D2D::D2DERR_UNSUPPORTED_VERSION => 0x88990010 as u32,
            D2D::D2DERR_BAD_NUMBER => 0x88990011 as u32,
            D2D::D2DERR_WRONG_FACTORY => 0x88990012 as u32,
            D2D::D2DERR_LAYER_ALREADY_IN_USE => 0x88990013 as u32,
            D2D::D2DERR_POP_CALL_DID_NOT_MATCH_PUSH => 0x88990014 as u32,
            D2D::D2DERR_WRONG_RESOURCE_DOMAIN => 0x88990015 as u32,
            D2D::D2DERR_PUSH_POP_UNBALANCED => 0x88990016 as u32,
            D2D::D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT => 0x88990017 as u32,
            D2D::D2DERR_INCOMPATIBLE_BRUSH_TYPES => 0x88990018 as u32,
            D2D::D2DERR_WIN32_ERROR => 0x88990019 as u32,
            D2D::D2DERR_TARGET_NOT_GDI_COMPATIBLE => 0x8899001A as u32,
            D2D::D2DERR_TEXT_EFFECT_IS_WRONG_TYPE => 0x8899001B as u32,
            D2D::D2DERR_TEXT_RENDERER_NOT_RELEASED => 0x8899001C as u32,
            D2D::D2DERR_EXCEEDS_MAX_BITMAP_SIZE => 0x8899001D as u32,
            D2D::D2DERR_INVALID_GRAPH_CONFIGURATION => 0x8899001E as u32,
            D2D::D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION => 0x8899001F as u32,
            D2D::D2DERR_CYCLIC_GRAPH => 0x88990020 as u32,
            D2D::D2DERR_BITMAP_CANNOT_DRAW => 0x88990021 as u32,
            D2D::D2DERR_OUTSTANDING_BITMAP_REFERENCES => 0x88990022 as u32,
            D2D::D2DERR_ORIGINAL_TARGET_NOT_BOUND => 0x88990023 as u32,
            D2D::D2DERR_INVALID_TARGET => 0x88990024 as u32,
            D2D::D2DERR_BITMAP_BOUND_AS_TARGET => 0x88990025 as u32,
            D2D::D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES => 0x88990026 as u32,
            D2D::D2DERR_INTERMEDIATE_TOO_LARGE => 0x88990027 as u32,
            D2D::D2DERR_EFFECT_IS_NOT_REGISTERED => 0x88990028 as u32,
            D2D::D2DERR_INVALID_PROPERTY => 0x88990029 as u32,
            D2D::D2DERR_NO_SUBPROPERTIES => 0x8899002A as u32,
            D2D::D2DERR_PRINT_JOB_CLOSED => 0x8899002B as u32,
            D2D::D2DERR_PRINT_FORMAT_NOT_SUPPORTED => 0x8899002C as u32,
            D2D::D2DERR_TOO_MANY_TRANSFORM_INPUTS => 0x8899002D as u32,
            D2D::D2DERR_INVALID_GLYPH_IMAGE => 0x8899002E as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            D2D::D2DERR_WRONG_STATE => RawError::Kind(D2D::D2DERR_WRONG_STATE),
            D2D::D2DERR_NOT_INITIALIZED => RawError::Kind(D2D::D2DERR_NOT_INITIALIZED),
            D2D::D2DERR_UNSUPPORTED_OPERATION => RawError::Kind(D2D::D2DERR_UNSUPPORTED_OPERATION),
            D2D::D2DERR_SCANNER_FAILED => RawError::Kind(D2D::D2DERR_SCANNER_FAILED),
            D2D::D2DERR_SCREEN_ACCESS_DENIED => RawError::Kind(D2D::D2DERR_SCREEN_ACCESS_DENIED),
            D2D::D2DERR_DISPLAY_STATE_INVALID => RawError::Kind(D2D::D2DERR_DISPLAY_STATE_INVALID),
            D2D::D2DERR_ZERO_VECTOR => RawError::Kind(D2D::D2DERR_ZERO_VECTOR),
            D2D::D2DERR_INTERNAL_ERROR => RawError::Kind(D2D::D2DERR_INTERNAL_ERROR),
            D2D::D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED => RawError::Kind(D2D::D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED),
            D2D::D2DERR_INVALID_CALL => RawError::Kind(D2D::D2DERR_INVALID_CALL),
            D2D::D2DERR_NO_HARDWARE_DEVICE => RawError::Kind(D2D::D2DERR_NO_HARDWARE_DEVICE),
            D2D::D2DERR_RECREATE_TARGET => RawError::Kind(D2D::D2DERR_RECREATE_TARGET),
            D2D::D2DERR_TOO_MANY_SHADER_ELEMENTS => RawError::Kind(D2D::D2DERR_TOO_MANY_SHADER_ELEMENTS),
            D2D::D2DERR_SHADER_COMPILE_FAILED => RawError::Kind(D2D::D2DERR_SHADER_COMPILE_FAILED),
            D2D::D2DERR_MAX_TEXTURE_SIZE_EXCEEDED => RawError::Kind(D2D::D2DERR_MAX_TEXTURE_SIZE_EXCEEDED),
            D2D::D2DERR_UNSUPPORTED_VERSION => RawError::Kind(D2D::D2DERR_UNSUPPORTED_VERSION),
            D2D::D2DERR_BAD_NUMBER => RawError::Kind(D2D::D2DERR_BAD_NUMBER),
            D2D::D2DERR_WRONG_FACTORY => RawError::Kind(D2D::D2DERR_WRONG_FACTORY),
            D2D::D2DERR_LAYER_ALREADY_IN_USE => RawError::Kind(D2D::D2DERR_LAYER_ALREADY_IN_USE),
            D2D::D2DERR_POP_CALL_DID_NOT_MATCH_PUSH => RawError::Kind(D2D::D2DERR_POP_CALL_DID_NOT_MATCH_PUSH),
            D2D::D2DERR_WRONG_RESOURCE_DOMAIN => RawError::Kind(D2D::D2DERR_WRONG_RESOURCE_DOMAIN),
            D2D::D2DERR_PUSH_POP_UNBALANCED => RawError::Kind(D2D::D2DERR_PUSH_POP_UNBALANCED),
            D2D::D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT => RawError::Kind(D2D::D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT),
            D2D::D2DERR_INCOMPATIBLE_BRUSH_TYPES => RawError::Kind(D2D::D2DERR_INCOMPATIBLE_BRUSH_TYPES),
            D2D::D2DERR_WIN32_ERROR => RawError::Kind(D2D::D2DERR_WIN32_ERROR),
            D2D::D2DERR_TARGET_NOT_GDI_COMPATIBLE => RawError::Kind(D2D::D2DERR_TARGET_NOT_GDI_COMPATIBLE),
            D2D::D2DERR_TEXT_EFFECT_IS_WRONG_TYPE => RawError::Kind(D2D::D2DERR_TEXT_EFFECT_IS_WRONG_TYPE),
            D2D::D2DERR_TEXT_RENDERER_NOT_RELEASED => RawError::Kind(D2D::D2DERR_TEXT_RENDERER_NOT_RELEASED),
            D2D::D2DERR_EXCEEDS_MAX_BITMAP_SIZE => RawError::Kind(D2D::D2DERR_EXCEEDS_MAX_BITMAP_SIZE),
            D2D::D2DERR_INVALID_GRAPH_CONFIGURATION => RawError::Kind(D2D::D2DERR_INVALID_GRAPH_CONFIGURATION),
            D2D::D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION => RawError::Kind(D2D::D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION),
            D2D::D2DERR_CYCLIC_GRAPH => RawError::Kind(D2D::D2DERR_CYCLIC_GRAPH),
            D2D::D2DERR_BITMAP_CANNOT_DRAW => RawError::Kind(D2D::D2DERR_BITMAP_CANNOT_DRAW),
            D2D::D2DERR_OUTSTANDING_BITMAP_REFERENCES => RawError::Kind(D2D::D2DERR_OUTSTANDING_BITMAP_REFERENCES),
            D2D::D2DERR_ORIGINAL_TARGET_NOT_BOUND => RawError::Kind(D2D::D2DERR_ORIGINAL_TARGET_NOT_BOUND),
            D2D::D2DERR_INVALID_TARGET => RawError::Kind(D2D::D2DERR_INVALID_TARGET),
            D2D::D2DERR_BITMAP_BOUND_AS_TARGET => RawError::Kind(D2D::D2DERR_BITMAP_BOUND_AS_TARGET),
            D2D::D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES => RawError::Kind(D2D::D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES),
            D2D::D2DERR_INTERMEDIATE_TOO_LARGE => RawError::Kind(D2D::D2DERR_INTERMEDIATE_TOO_LARGE),
            D2D::D2DERR_EFFECT_IS_NOT_REGISTERED => RawError::Kind(D2D::D2DERR_EFFECT_IS_NOT_REGISTERED),
            D2D::D2DERR_INVALID_PROPERTY => RawError::Kind(D2D::D2DERR_INVALID_PROPERTY),
            D2D::D2DERR_NO_SUBPROPERTIES => RawError::Kind(D2D::D2DERR_NO_SUBPROPERTIES),
            D2D::D2DERR_PRINT_JOB_CLOSED => RawError::Kind(D2D::D2DERR_PRINT_JOB_CLOSED),
            D2D::D2DERR_PRINT_FORMAT_NOT_SUPPORTED => RawError::Kind(D2D::D2DERR_PRINT_FORMAT_NOT_SUPPORTED),
            D2D::D2DERR_TOO_MANY_TRANSFORM_INPUTS => RawError::Kind(D2D::D2DERR_TOO_MANY_TRANSFORM_INPUTS),
            D2D::D2DERR_INVALID_GLYPH_IMAGE => RawError::Kind(D2D::D2DERR_INVALID_GLYPH_IMAGE),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            D2D::D2DERR_WRONG_STATE => "The object was not in the correct state to process the method.",
            D2D::D2DERR_NOT_INITIALIZED => "The object has not yet been initialized.",
            D2D::D2DERR_UNSUPPORTED_OPERATION => "The requested operation is not supported.",
            D2D::D2DERR_SCANNER_FAILED => "The geometry scanner failed to process the data.",
            D2D::D2DERR_SCREEN_ACCESS_DENIED => "Direct2D could not access the screen.",
            D2D::D2DERR_DISPLAY_STATE_INVALID => "A valid display state could not be determined.",
            D2D::D2DERR_ZERO_VECTOR => "The supplied vector is zero.",
            D2D::D2DERR_INTERNAL_ERROR => "An internal error (Direct2D bug) occurred. On checked builds, we would assert. The application should close this instance of Direct2D and should consider restarting its process.",
            D2D::D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED => "The display format Direct2D needs to render is not supported by the hardware device.",
            D2D::D2DERR_INVALID_CALL => "A call to this method is invalid.",
            D2D::D2DERR_NO_HARDWARE_DEVICE => "No hardware rendering device is available for this operation.",
            D2D::D2DERR_RECREATE_TARGET => "There has been a presentation error that may be recoverable. The caller needs to recreate, rerender the entire frame, and reattempt present.",
            D2D::D2DERR_TOO_MANY_SHADER_ELEMENTS => "Shader construction failed because it was too complex.",
            D2D::D2DERR_SHADER_COMPILE_FAILED => "Shader compilation failed.",
            D2D::D2DERR_MAX_TEXTURE_SIZE_EXCEEDED => "Requested DirectX surface size exceeded maximum texture size.",
            D2D::D2DERR_UNSUPPORTED_VERSION => "The requested Direct2D version is not supported.",
            D2D::D2DERR_BAD_NUMBER => "Invalid number.",
            D2D::D2DERR_WRONG_FACTORY => "Objects used together must be created from the same factory instance.",
            D2D::D2DERR_LAYER_ALREADY_IN_USE => "A layer resource can only be in use once at any point in time.",
            D2D::D2DERR_POP_CALL_DID_NOT_MATCH_PUSH => "The pop call did not match the corresponding push call.",
            D2D::D2DERR_WRONG_RESOURCE_DOMAIN => "The resource was realized on the wrong render target.",
            D2D::D2DERR_PUSH_POP_UNBALANCED => "The push and pop calls were unbalanced.",
            D2D::D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT => "Attempt to copy from a render target while a layer or clip rect is applied.",
            D2D::D2DERR_INCOMPATIBLE_BRUSH_TYPES => "The brush types are incompatible for the call.",
            D2D::D2DERR_WIN32_ERROR => "An unknown win32 failure occurred.",
            D2D::D2DERR_TARGET_NOT_GDI_COMPATIBLE => "The render target is not compatible with GDI.",
            D2D::D2DERR_TEXT_EFFECT_IS_WRONG_TYPE => "A text client drawing effect object is of the wrong type.",
            D2D::D2DERR_TEXT_RENDERER_NOT_RELEASED => "The application is holding a reference to the IDWriteTextRenderer interface after the corresponding DrawText or DrawTextLayout call has returned. The IDWriteTextRenderer instance will be invalid.",
            D2D::D2DERR_EXCEEDS_MAX_BITMAP_SIZE => "The requested size is larger than the guaranteed supported texture size at the Direct3D device's current feature level.",
            D2D::D2DERR_INVALID_GRAPH_CONFIGURATION => "There was a configuration error in the graph.",
            D2D::D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION => "There was a internal configuration error in the graph.",
            D2D::D2DERR_CYCLIC_GRAPH => "There was a cycle in the graph.",
            D2D::D2DERR_BITMAP_CANNOT_DRAW => "Cannot draw with a bitmap that has the D2D1_BITMAP_OPTIONS_CANNOT_DRAW option.",
            D2D::D2DERR_OUTSTANDING_BITMAP_REFERENCES => "The operation cannot complete while there are outstanding references to the target bitmap.",
            D2D::D2DERR_ORIGINAL_TARGET_NOT_BOUND => "The operation failed because the original target is not currently bound as a target.",
            D2D::D2DERR_INVALID_TARGET => "Cannot set the image as a target because it is either an effect or is a bitmap that does not have the D2D1_BITMAP_OPTIONS_TARGET flag set.",
            D2D::D2DERR_BITMAP_BOUND_AS_TARGET => "Cannot draw with a bitmap that is currently bound as the target bitmap.",
            D2D::D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES => "D3D Device does not have sufficient capabilities to perform the requested action.",
            D2D::D2DERR_INTERMEDIATE_TOO_LARGE => "The graph could not be rendered with the context's current tiling settings.",
            D2D::D2DERR_EFFECT_IS_NOT_REGISTERED => "The CLSID provided to Unregister did not correspond to a registered effect.",
            D2D::D2DERR_INVALID_PROPERTY => "The specified property does not exist.",
            D2D::D2DERR_NO_SUBPROPERTIES => "The specified sub-property does not exist.",
            D2D::D2DERR_PRINT_JOB_CLOSED => "AddPage or Close called after print job is already closed.",
            D2D::D2DERR_PRINT_FORMAT_NOT_SUPPORTED => "Error during print control creation. Indicates that none of the package target types (representing printer formats) are supported by Direct2D print control.",
            D2D::D2DERR_TOO_MANY_TRANSFORM_INPUTS => "An effect attempted to use a transform with too many inputs.",
            D2D::D2DERR_INVALID_GLYPH_IMAGE => "An error was encountered while decoding or parsing the requested glyph image.",
        }
    }

    pub fn from_name(name: &str) -> D2D {
        return match name {
            "D2DERR_WRONG_STATE" => D2D::D2DERR_WRONG_STATE,
            "D2DERR_NOT_INITIALIZED" => D2D::D2DERR_NOT_INITIALIZED,
            "D2DERR_UNSUPPORTED_OPERATION" => D2D::D2DERR_UNSUPPORTED_OPERATION,
            "D2DERR_SCANNER_FAILED" => D2D::D2DERR_SCANNER_FAILED,
            "D2DERR_SCREEN_ACCESS_DENIED" => D2D::D2DERR_SCREEN_ACCESS_DENIED,
            "D2DERR_DISPLAY_STATE_INVALID" => D2D::D2DERR_DISPLAY_STATE_INVALID,
            "D2DERR_ZERO_VECTOR" => D2D::D2DERR_ZERO_VECTOR,
            "D2DERR_INTERNAL_ERROR" => D2D::D2DERR_INTERNAL_ERROR,
            "D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED" => D2D::D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED,
            "D2DERR_INVALID_CALL" => D2D::D2DERR_INVALID_CALL,
            "D2DERR_NO_HARDWARE_DEVICE" => D2D::D2DERR_NO_HARDWARE_DEVICE,
            "D2DERR_RECREATE_TARGET" => D2D::D2DERR_RECREATE_TARGET,
            "D2DERR_TOO_MANY_SHADER_ELEMENTS" => D2D::D2DERR_TOO_MANY_SHADER_ELEMENTS,
            "D2DERR_SHADER_COMPILE_FAILED" => D2D::D2DERR_SHADER_COMPILE_FAILED,
            "D2DERR_MAX_TEXTURE_SIZE_EXCEEDED" => D2D::D2DERR_MAX_TEXTURE_SIZE_EXCEEDED,
            "D2DERR_UNSUPPORTED_VERSION" => D2D::D2DERR_UNSUPPORTED_VERSION,
            "D2DERR_BAD_NUMBER" => D2D::D2DERR_BAD_NUMBER,
            "D2DERR_WRONG_FACTORY" => D2D::D2DERR_WRONG_FACTORY,
            "D2DERR_LAYER_ALREADY_IN_USE" => D2D::D2DERR_LAYER_ALREADY_IN_USE,
            "D2DERR_POP_CALL_DID_NOT_MATCH_PUSH" => D2D::D2DERR_POP_CALL_DID_NOT_MATCH_PUSH,
            "D2DERR_WRONG_RESOURCE_DOMAIN" => D2D::D2DERR_WRONG_RESOURCE_DOMAIN,
            "D2DERR_PUSH_POP_UNBALANCED" => D2D::D2DERR_PUSH_POP_UNBALANCED,
            "D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT" => D2D::D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT,
            "D2DERR_INCOMPATIBLE_BRUSH_TYPES" => D2D::D2DERR_INCOMPATIBLE_BRUSH_TYPES,
            "D2DERR_WIN32_ERROR" => D2D::D2DERR_WIN32_ERROR,
            "D2DERR_TARGET_NOT_GDI_COMPATIBLE" => D2D::D2DERR_TARGET_NOT_GDI_COMPATIBLE,
            "D2DERR_TEXT_EFFECT_IS_WRONG_TYPE" => D2D::D2DERR_TEXT_EFFECT_IS_WRONG_TYPE,
            "D2DERR_TEXT_RENDERER_NOT_RELEASED" => D2D::D2DERR_TEXT_RENDERER_NOT_RELEASED,
            "D2DERR_EXCEEDS_MAX_BITMAP_SIZE" => D2D::D2DERR_EXCEEDS_MAX_BITMAP_SIZE,
            "D2DERR_INVALID_GRAPH_CONFIGURATION" => D2D::D2DERR_INVALID_GRAPH_CONFIGURATION,
            "D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION" => D2D::D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION,
            "D2DERR_CYCLIC_GRAPH" => D2D::D2DERR_CYCLIC_GRAPH,
            "D2DERR_BITMAP_CANNOT_DRAW" => D2D::D2DERR_BITMAP_CANNOT_DRAW,
            "D2DERR_OUTSTANDING_BITMAP_REFERENCES" => D2D::D2DERR_OUTSTANDING_BITMAP_REFERENCES,
            "D2DERR_ORIGINAL_TARGET_NOT_BOUND" => D2D::D2DERR_ORIGINAL_TARGET_NOT_BOUND,
            "D2DERR_INVALID_TARGET" => D2D::D2DERR_INVALID_TARGET,
            "D2DERR_BITMAP_BOUND_AS_TARGET" => D2D::D2DERR_BITMAP_BOUND_AS_TARGET,
            "D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES" => D2D::D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES,
            "D2DERR_INTERMEDIATE_TOO_LARGE" => D2D::D2DERR_INTERMEDIATE_TOO_LARGE,
            "D2DERR_EFFECT_IS_NOT_REGISTERED" => D2D::D2DERR_EFFECT_IS_NOT_REGISTERED,
            "D2DERR_INVALID_PROPERTY" => D2D::D2DERR_INVALID_PROPERTY,
            "D2DERR_NO_SUBPROPERTIES" => D2D::D2DERR_NO_SUBPROPERTIES,
            "D2DERR_PRINT_JOB_CLOSED" => D2D::D2DERR_PRINT_JOB_CLOSED,
            "D2DERR_PRINT_FORMAT_NOT_SUPPORTED" => D2D::D2DERR_PRINT_FORMAT_NOT_SUPPORTED,
            "D2DERR_TOO_MANY_TRANSFORM_INPUTS" => D2D::D2DERR_TOO_MANY_TRANSFORM_INPUTS,
            "D2DERR_INVALID_GLYPH_IMAGE" => D2D::D2DERR_INVALID_GLYPH_IMAGE,
        }
    }
    pub fn from_code(code: u32) -> D2D {
        return match code {
            0x88990001 => D2D::D2DERR_WRONG_STATE,
            0x88990002 => D2D::D2DERR_NOT_INITIALIZED,
            0x88990003 => D2D::D2DERR_UNSUPPORTED_OPERATION,
            0x88990004 => D2D::D2DERR_SCANNER_FAILED,
            0x88990005 => D2D::D2DERR_SCREEN_ACCESS_DENIED,
            0x88990006 => D2D::D2DERR_DISPLAY_STATE_INVALID,
            0x88990007 => D2D::D2DERR_ZERO_VECTOR,
            0x88990008 => D2D::D2DERR_INTERNAL_ERROR,
            0x88990009 => D2D::D2DERR_DISPLAY_FORMAT_NOT_SUPPORTED,
            0x8899000A => D2D::D2DERR_INVALID_CALL,
            0x8899000B => D2D::D2DERR_NO_HARDWARE_DEVICE,
            0x8899000C => D2D::D2DERR_RECREATE_TARGET,
            0x8899000D => D2D::D2DERR_TOO_MANY_SHADER_ELEMENTS,
            0x8899000E => D2D::D2DERR_SHADER_COMPILE_FAILED,
            0x8899000F => D2D::D2DERR_MAX_TEXTURE_SIZE_EXCEEDED,
            0x88990010 => D2D::D2DERR_UNSUPPORTED_VERSION,
            0x88990011 => D2D::D2DERR_BAD_NUMBER,
            0x88990012 => D2D::D2DERR_WRONG_FACTORY,
            0x88990013 => D2D::D2DERR_LAYER_ALREADY_IN_USE,
            0x88990014 => D2D::D2DERR_POP_CALL_DID_NOT_MATCH_PUSH,
            0x88990015 => D2D::D2DERR_WRONG_RESOURCE_DOMAIN,
            0x88990016 => D2D::D2DERR_PUSH_POP_UNBALANCED,
            0x88990017 => D2D::D2DERR_RENDER_TARGET_HAS_LAYER_OR_CLIPRECT,
            0x88990018 => D2D::D2DERR_INCOMPATIBLE_BRUSH_TYPES,
            0x88990019 => D2D::D2DERR_WIN32_ERROR,
            0x8899001A => D2D::D2DERR_TARGET_NOT_GDI_COMPATIBLE,
            0x8899001B => D2D::D2DERR_TEXT_EFFECT_IS_WRONG_TYPE,
            0x8899001C => D2D::D2DERR_TEXT_RENDERER_NOT_RELEASED,
            0x8899001D => D2D::D2DERR_EXCEEDS_MAX_BITMAP_SIZE,
            0x8899001E => D2D::D2DERR_INVALID_GRAPH_CONFIGURATION,
            0x8899001F => D2D::D2DERR_INVALID_INTERNAL_GRAPH_CONFIGURATION,
            0x88990020 => D2D::D2DERR_CYCLIC_GRAPH,
            0x88990021 => D2D::D2DERR_BITMAP_CANNOT_DRAW,
            0x88990022 => D2D::D2DERR_OUTSTANDING_BITMAP_REFERENCES,
            0x88990023 => D2D::D2DERR_ORIGINAL_TARGET_NOT_BOUND,
            0x88990024 => D2D::D2DERR_INVALID_TARGET,
            0x88990025 => D2D::D2DERR_BITMAP_BOUND_AS_TARGET,
            0x88990026 => D2D::D2DERR_INSUFFICIENT_DEVICE_CAPABILITIES,
            0x88990027 => D2D::D2DERR_INTERMEDIATE_TOO_LARGE,
            0x88990028 => D2D::D2DERR_EFFECT_IS_NOT_REGISTERED,
            0x88990029 => D2D::D2DERR_INVALID_PROPERTY,
            0x8899002A => D2D::D2DERR_NO_SUBPROPERTIES,
            0x8899002B => D2D::D2DERR_PRINT_JOB_CLOSED,
            0x8899002C => D2D::D2DERR_PRINT_FORMAT_NOT_SUPPORTED,
            0x8899002D => D2D::D2DERR_TOO_MANY_TRANSFORM_INPUTS,
            0x8899002E => D2D::D2DERR_INVALID_GLYPH_IMAGE,
        }
    }
}
