/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum FVE {
    FVE_E_LOCKED_VOLUME,
    FVE_E_NOT_ENCRYPTED,
    FVE_E_NO_TPM_BIOS,
    FVE_E_NO_MBR_METRIC,
    FVE_E_NO_BOOTSECTOR_METRIC,
    FVE_E_NO_BOOTMGR_METRIC,
    FVE_E_WRONG_BOOTMGR,
    FVE_E_SECURE_KEY_REQUIRED,
    FVE_E_NOT_ACTIVATED,
    FVE_E_ACTION_NOT_ALLOWED,
    FVE_E_AD_SCHEMA_NOT_INSTALLED,
    FVE_E_AD_INVALID_DATATYPE,
    FVE_E_AD_INVALID_DATASIZE,
    FVE_E_AD_NO_VALUES,
    FVE_E_AD_ATTR_NOT_SET,
    FVE_E_AD_GUID_NOT_FOUND,
    FVE_E_BAD_INFORMATION,
    FVE_E_TOO_SMALL,
    FVE_E_SYSTEM_VOLUME,
    FVE_E_FAILED_WRONG_FS,
    FVE_E_BAD_PARTITION_SIZE,
    FVE_E_FAILED_BAD_FS,
    FVE_E_NOT_SUPPORTED,
    FVE_E_BAD_DATA,
    FVE_E_VOLUME_NOT_BOUND,
    FVE_E_TPM_NOT_OWNED,
    FVE_E_NOT_DATA_VOLUME,
    FVE_E_AD_INSUFFICIENT_BUFFER,
    FVE_E_CONV_READ,
    FVE_E_CONV_WRITE,
    FVE_E_KEY_REQUIRED,
    FVE_E_CLUSTERING_NOT_SUPPORTED,
    FVE_E_VOLUME_BOUND_ALREADY,
    FVE_E_OS_NOT_PROTECTED,
    FVE_E_PROTECTION_DISABLED,
    FVE_E_RECOVERY_KEY_REQUIRED,
    FVE_E_FOREIGN_VOLUME,
    FVE_E_OVERLAPPED_UPDATE,
    FVE_E_TPM_SRK_AUTH_NOT_ZERO,
    FVE_E_FAILED_SECTOR_SIZE,
    FVE_E_FAILED_AUTHENTICATION,
    FVE_E_NOT_OS_VOLUME,
    FVE_E_AUTOUNLOCK_ENABLED,
    FVE_E_WRONG_BOOTSECTOR,
    FVE_E_WRONG_SYSTEM_FS,
    FVE_E_POLICY_PASSWORD_REQUIRED,
    FVE_E_CANNOT_SET_FVEK_ENCRYPTED,
    FVE_E_CANNOT_ENCRYPT_NO_KEY,
    FVE_E_BOOTABLE_CDDVD,
    FVE_E_PROTECTOR_EXISTS,
    FVE_E_RELATIVE_PATH,
    FVE_E_PROTECTOR_NOT_FOUND,
    FVE_E_INVALID_KEY_FORMAT,
    FVE_E_INVALID_PASSWORD_FORMAT,
    FVE_E_FIPS_RNG_CHECK_FAILED,
    FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD,
    FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT,
    FVE_E_NOT_DECRYPTED,
    FVE_E_INVALID_PROTECTOR_TYPE,
    FVE_E_NO_PROTECTORS_TO_TEST,
    FVE_E_KEYFILE_NOT_FOUND,
    FVE_E_KEYFILE_INVALID,
    FVE_E_KEYFILE_NO_VMK,
    FVE_E_TPM_DISABLED,
    FVE_E_NOT_ALLOWED_IN_SAFE_MODE,
    FVE_E_TPM_INVALID_PCR,
    FVE_E_TPM_NO_VMK,
    FVE_E_PIN_INVALID,
    FVE_E_AUTH_INVALID_APPLICATION,
    FVE_E_AUTH_INVALID_CONFIG,
    FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED,
    FVE_E_FS_NOT_EXTENDED,
    FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED,
    FVE_E_NO_LICENSE,
    FVE_E_NOT_ON_STACK,
    FVE_E_FS_MOUNTED,
    FVE_E_TOKEN_NOT_IMPERSONATED,
    FVE_E_DRY_RUN_FAILED,
    FVE_E_REBOOT_REQUIRED,
    FVE_E_DEBUGGER_ENABLED,
    FVE_E_RAW_ACCESS,
    FVE_E_RAW_BLOCKED,
    FVE_E_BCD_APPLICATIONS_PATH_INCORRECT,
    FVE_E_NOT_ALLOWED_IN_VERSION,
    FVE_E_NO_AUTOUNLOCK_MASTER_KEY,
    FVE_E_MOR_FAILED,
    FVE_E_HIDDEN_VOLUME,
    FVE_E_TRANSIENT_STATE,
    FVE_E_PUBKEY_NOT_ALLOWED,
    FVE_E_VOLUME_HANDLE_OPEN,
    FVE_E_NO_FEATURE_LICENSE,
    FVE_E_INVALID_STARTUP_OPTIONS,
    FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED,
    FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED,
    FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED,
    FVE_E_POLICY_RECOVERY_KEY_REQUIRED,
    FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED,
    FVE_E_POLICY_STARTUP_PIN_REQUIRED,
    FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED,
    FVE_E_POLICY_STARTUP_KEY_REQUIRED,
    FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED,
    FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED,
    FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED,
    FVE_E_POLICY_STARTUP_TPM_REQUIRED,
    FVE_E_POLICY_INVALID_PIN_LENGTH,
    FVE_E_KEY_PROTECTOR_NOT_SUPPORTED,
    FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED,
    FVE_E_POLICY_PASSPHRASE_REQUIRED,
    FVE_E_FIPS_PREVENTS_PASSPHRASE,
    FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED,
    FVE_E_INVALID_BITLOCKER_OID,
    FVE_E_VOLUME_TOO_SMALL,
    FVE_E_DV_NOT_SUPPORTED_ON_FS,
    FVE_E_DV_NOT_ALLOWED_BY_GP,
    FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED,
    FVE_E_POLICY_USER_CERTIFICATE_REQUIRED,
    FVE_E_POLICY_USER_CERT_MUST_BE_HW,
    FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED,
    FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED,
    FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED,
    FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED,
    FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED,
    FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH,
    FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE,
    FVE_E_RECOVERY_PARTITION,
    FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON,
    FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON,
    FVE_E_NON_BITLOCKER_OID,
    FVE_E_POLICY_PROHIBITS_SELFSIGNED,
    FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED,
    FVE_E_CONV_RECOVERY_FAILED,
    FVE_E_VIRTUALIZED_SPACE_TOO_BIG,
    FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON,
    FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON,
    FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON,
    FVE_E_NON_BITLOCKER_KU,
    FVE_E_PRIVATEKEY_AUTH_FAILED,
    FVE_E_REMOVAL_OF_DRA_FAILED,
    FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME,
    FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME,
    FVE_E_FIPS_HASH_KDF_NOT_ALLOWED,
    FVE_E_ENH_PIN_INVALID,
    FVE_E_INVALID_PIN_CHARS,
    FVE_E_INVALID_DATUM_TYPE,
    FVE_E_EFI_ONLY,
    FVE_E_MULTIPLE_NKP_CERTS,
    FVE_E_REMOVAL_OF_NKP_FAILED,
    FVE_E_INVALID_NKP_CERT,
    FVE_E_NO_EXISTING_PIN,
    FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH,
    FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED,
    FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED,
    FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII,
    FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE,
    FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE,
    FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE,
    FVE_E_NO_EXISTING_PASSPHRASE,
    FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH,
    FVE_E_PASSPHRASE_TOO_LONG,
    FVE_E_NO_PASSPHRASE_WITH_TPM,
    FVE_E_NO_TPM_WITH_PASSPHRASE,
    FVE_E_NOT_ALLOWED_ON_CSV_STACK,
    FVE_E_NOT_ALLOWED_ON_CLUSTER,
    FVE_E_EDRIVE_NO_FAILOVER_TO_SW,
    FVE_E_EDRIVE_BAND_IN_USE,
    FVE_E_EDRIVE_DISALLOWED_BY_GP,
    FVE_E_EDRIVE_INCOMPATIBLE_VOLUME,
    FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING,
    FVE_E_EDRIVE_DV_NOT_SUPPORTED,
    FVE_E_NO_PREBOOT_KEYBOARD_DETECTED,
    FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED,
    FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE,
    FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE,
    FVE_E_WIPE_CANCEL_NOT_APPLICABLE,
    FVE_E_SECUREBOOT_DISABLED,
    FVE_E_SECUREBOOT_CONFIGURATION_INVALID,
    FVE_E_EDRIVE_DRY_RUN_FAILED,
    FVE_E_SHADOW_COPY_PRESENT,
    FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS,
    FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE,
    FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED,
    FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED,
    FVE_E_LIVEID_ACCOUNT_SUSPENDED,
    FVE_E_LIVEID_ACCOUNT_BLOCKED,
    FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES,
    FVE_E_DE_FIXED_DATA_NOT_SUPPORTED,
    FVE_E_DE_HARDWARE_NOT_COMPLIANT,
    FVE_E_DE_WINRE_NOT_CONFIGURED,
    FVE_E_DE_PROTECTION_SUSPENDED,
    FVE_E_DE_OS_VOLUME_NOT_PROTECTED,
    FVE_E_DE_DEVICE_LOCKEDOUT,
    FVE_E_DE_PROTECTION_NOT_YET_ENABLED,
    FVE_E_INVALID_PIN_CHARS_DETAILED,
    FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE,
    FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH,
    FVE_E_BUFFER_TOO_LARGE,
    FVE_E_NO_SUCH_CAPABILITY_ON_TARGET,
    FVE_E_DE_PREVENTED_FOR_OS,
    FVE_E_DE_VOLUME_OPTED_OUT,
    FVE_E_DE_VOLUME_NOT_SUPPORTED,
    FVE_E_EOW_NOT_SUPPORTED_IN_VERSION,
    FVE_E_ADBACKUP_NOT_ENABLED,
    FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT,
    FVE_E_NOT_DE_VOLUME,
    FVE_E_PROTECTION_CANNOT_BE_DISABLED,
    FVE_E_OSV_KSR_NOT_ALLOWED,
    FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE,
    FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE,
    FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE,
    FVE_E_KEY_ROTATION_NOT_SUPPORTED,
    FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON,
    FVE_E_KEY_ROTATION_NOT_ENABLED,
    FVE_E_DEVICE_NOT_JOINED,
    FVE_E_AAD_ENDPOINT_BUSY,
    FVE_E_INVALID_NBP_CERT,
    FVE_E_EDRIVE_BAND_ENUMERATION_FAILED,
    FVE_E_POLICY_ON_RDV_EXCLUSION_LIST,
    FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED,
    FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED,
    FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED,
    FVE_E_UPDATE_INVALID_CONFIG,
    FVE_E_AAD_SERVER_FAIL_RETRY_AFTER,
    FVE_E_AAD_SERVER_FAIL_BACKOFF,
    FVE_E_DATASET_FULL,
    FVE_E_METADATA_FULL,
}

impl FVE {
    pub fn code(&self) -> u32 {
        return match self {
            FVE::FVE_E_LOCKED_VOLUME => 0x80310000 as u32,
            FVE::FVE_E_NOT_ENCRYPTED => 0x80310001 as u32,
            FVE::FVE_E_NO_TPM_BIOS => 0x80310002 as u32,
            FVE::FVE_E_NO_MBR_METRIC => 0x80310003 as u32,
            FVE::FVE_E_NO_BOOTSECTOR_METRIC => 0x80310004 as u32,
            FVE::FVE_E_NO_BOOTMGR_METRIC => 0x80310005 as u32,
            FVE::FVE_E_WRONG_BOOTMGR => 0x80310006 as u32,
            FVE::FVE_E_SECURE_KEY_REQUIRED => 0x80310007 as u32,
            FVE::FVE_E_NOT_ACTIVATED => 0x80310008 as u32,
            FVE::FVE_E_ACTION_NOT_ALLOWED => 0x80310009 as u32,
            FVE::FVE_E_AD_SCHEMA_NOT_INSTALLED => 0x8031000A as u32,
            FVE::FVE_E_AD_INVALID_DATATYPE => 0x8031000B as u32,
            FVE::FVE_E_AD_INVALID_DATASIZE => 0x8031000C as u32,
            FVE::FVE_E_AD_NO_VALUES => 0x8031000D as u32,
            FVE::FVE_E_AD_ATTR_NOT_SET => 0x8031000E as u32,
            FVE::FVE_E_AD_GUID_NOT_FOUND => 0x8031000F as u32,
            FVE::FVE_E_BAD_INFORMATION => 0x80310010 as u32,
            FVE::FVE_E_TOO_SMALL => 0x80310011 as u32,
            FVE::FVE_E_SYSTEM_VOLUME => 0x80310012 as u32,
            FVE::FVE_E_FAILED_WRONG_FS => 0x80310013 as u32,
            FVE::FVE_E_BAD_PARTITION_SIZE => 0x80310014 as u32,
            FVE::FVE_E_FAILED_BAD_FS => 0x80310014 as u32,
            FVE::FVE_E_NOT_SUPPORTED => 0x80310015 as u32,
            FVE::FVE_E_BAD_DATA => 0x80310016 as u32,
            FVE::FVE_E_VOLUME_NOT_BOUND => 0x80310017 as u32,
            FVE::FVE_E_TPM_NOT_OWNED => 0x80310018 as u32,
            FVE::FVE_E_NOT_DATA_VOLUME => 0x80310019 as u32,
            FVE::FVE_E_AD_INSUFFICIENT_BUFFER => 0x8031001A as u32,
            FVE::FVE_E_CONV_READ => 0x8031001B as u32,
            FVE::FVE_E_CONV_WRITE => 0x8031001C as u32,
            FVE::FVE_E_KEY_REQUIRED => 0x8031001D as u32,
            FVE::FVE_E_CLUSTERING_NOT_SUPPORTED => 0x8031001E as u32,
            FVE::FVE_E_VOLUME_BOUND_ALREADY => 0x8031001F as u32,
            FVE::FVE_E_OS_NOT_PROTECTED => 0x80310020 as u32,
            FVE::FVE_E_PROTECTION_DISABLED => 0x80310021 as u32,
            FVE::FVE_E_RECOVERY_KEY_REQUIRED => 0x80310022 as u32,
            FVE::FVE_E_FOREIGN_VOLUME => 0x80310023 as u32,
            FVE::FVE_E_OVERLAPPED_UPDATE => 0x80310024 as u32,
            FVE::FVE_E_TPM_SRK_AUTH_NOT_ZERO => 0x80310025 as u32,
            FVE::FVE_E_FAILED_SECTOR_SIZE => 0x80310026 as u32,
            FVE::FVE_E_FAILED_AUTHENTICATION => 0x80310027 as u32,
            FVE::FVE_E_NOT_OS_VOLUME => 0x80310028 as u32,
            FVE::FVE_E_AUTOUNLOCK_ENABLED => 0x80310029 as u32,
            FVE::FVE_E_WRONG_BOOTSECTOR => 0x8031002A as u32,
            FVE::FVE_E_WRONG_SYSTEM_FS => 0x8031002B as u32,
            FVE::FVE_E_POLICY_PASSWORD_REQUIRED => 0x8031002C as u32,
            FVE::FVE_E_CANNOT_SET_FVEK_ENCRYPTED => 0x8031002D as u32,
            FVE::FVE_E_CANNOT_ENCRYPT_NO_KEY => 0x8031002E as u32,
            FVE::FVE_E_BOOTABLE_CDDVD => 0x80310030 as u32,
            FVE::FVE_E_PROTECTOR_EXISTS => 0x80310031 as u32,
            FVE::FVE_E_RELATIVE_PATH => 0x80310032 as u32,
            FVE::FVE_E_PROTECTOR_NOT_FOUND => 0x80310033 as u32,
            FVE::FVE_E_INVALID_KEY_FORMAT => 0x80310034 as u32,
            FVE::FVE_E_INVALID_PASSWORD_FORMAT => 0x80310035 as u32,
            FVE::FVE_E_FIPS_RNG_CHECK_FAILED => 0x80310036 as u32,
            FVE::FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD => 0x80310037 as u32,
            FVE::FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT => 0x80310038 as u32,
            FVE::FVE_E_NOT_DECRYPTED => 0x80310039 as u32,
            FVE::FVE_E_INVALID_PROTECTOR_TYPE => 0x8031003A as u32,
            FVE::FVE_E_NO_PROTECTORS_TO_TEST => 0x8031003B as u32,
            FVE::FVE_E_KEYFILE_NOT_FOUND => 0x8031003C as u32,
            FVE::FVE_E_KEYFILE_INVALID => 0x8031003D as u32,
            FVE::FVE_E_KEYFILE_NO_VMK => 0x8031003E as u32,
            FVE::FVE_E_TPM_DISABLED => 0x8031003F as u32,
            FVE::FVE_E_NOT_ALLOWED_IN_SAFE_MODE => 0x80310040 as u32,
            FVE::FVE_E_TPM_INVALID_PCR => 0x80310041 as u32,
            FVE::FVE_E_TPM_NO_VMK => 0x80310042 as u32,
            FVE::FVE_E_PIN_INVALID => 0x80310043 as u32,
            FVE::FVE_E_AUTH_INVALID_APPLICATION => 0x80310044 as u32,
            FVE::FVE_E_AUTH_INVALID_CONFIG => 0x80310045 as u32,
            FVE::FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED => 0x80310046 as u32,
            FVE::FVE_E_FS_NOT_EXTENDED => 0x80310047 as u32,
            FVE::FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED => 0x80310048 as u32,
            FVE::FVE_E_NO_LICENSE => 0x80310049 as u32,
            FVE::FVE_E_NOT_ON_STACK => 0x8031004A as u32,
            FVE::FVE_E_FS_MOUNTED => 0x8031004B as u32,
            FVE::FVE_E_TOKEN_NOT_IMPERSONATED => 0x8031004C as u32,
            FVE::FVE_E_DRY_RUN_FAILED => 0x8031004D as u32,
            FVE::FVE_E_REBOOT_REQUIRED => 0x8031004E as u32,
            FVE::FVE_E_DEBUGGER_ENABLED => 0x8031004F as u32,
            FVE::FVE_E_RAW_ACCESS => 0x80310050 as u32,
            FVE::FVE_E_RAW_BLOCKED => 0x80310051 as u32,
            FVE::FVE_E_BCD_APPLICATIONS_PATH_INCORRECT => 0x80310052 as u32,
            FVE::FVE_E_NOT_ALLOWED_IN_VERSION => 0x80310053 as u32,
            FVE::FVE_E_NO_AUTOUNLOCK_MASTER_KEY => 0x80310054 as u32,
            FVE::FVE_E_MOR_FAILED => 0x80310055 as u32,
            FVE::FVE_E_HIDDEN_VOLUME => 0x80310056 as u32,
            FVE::FVE_E_TRANSIENT_STATE => 0x80310057 as u32,
            FVE::FVE_E_PUBKEY_NOT_ALLOWED => 0x80310058 as u32,
            FVE::FVE_E_VOLUME_HANDLE_OPEN => 0x80310059 as u32,
            FVE::FVE_E_NO_FEATURE_LICENSE => 0x8031005A as u32,
            FVE::FVE_E_INVALID_STARTUP_OPTIONS => 0x8031005B as u32,
            FVE::FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED => 0x8031005C as u32,
            FVE::FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED => 0x8031005D as u32,
            FVE::FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED => 0x8031005E as u32,
            FVE::FVE_E_POLICY_RECOVERY_KEY_REQUIRED => 0x8031005F as u32,
            FVE::FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED => 0x80310060 as u32,
            FVE::FVE_E_POLICY_STARTUP_PIN_REQUIRED => 0x80310061 as u32,
            FVE::FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED => 0x80310062 as u32,
            FVE::FVE_E_POLICY_STARTUP_KEY_REQUIRED => 0x80310063 as u32,
            FVE::FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED => 0x80310064 as u32,
            FVE::FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED => 0x80310065 as u32,
            FVE::FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED => 0x80310066 as u32,
            FVE::FVE_E_POLICY_STARTUP_TPM_REQUIRED => 0x80310067 as u32,
            FVE::FVE_E_POLICY_INVALID_PIN_LENGTH => 0x80310068 as u32,
            FVE::FVE_E_KEY_PROTECTOR_NOT_SUPPORTED => 0x80310069 as u32,
            FVE::FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED => 0x8031006A as u32,
            FVE::FVE_E_POLICY_PASSPHRASE_REQUIRED => 0x8031006B as u32,
            FVE::FVE_E_FIPS_PREVENTS_PASSPHRASE => 0x8031006C as u32,
            FVE::FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED => 0x8031006D as u32,
            FVE::FVE_E_INVALID_BITLOCKER_OID => 0x8031006E as u32,
            FVE::FVE_E_VOLUME_TOO_SMALL => 0x8031006F as u32,
            FVE::FVE_E_DV_NOT_SUPPORTED_ON_FS => 0x80310070 as u32,
            FVE::FVE_E_DV_NOT_ALLOWED_BY_GP => 0x80310071 as u32,
            FVE::FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED => 0x80310072 as u32,
            FVE::FVE_E_POLICY_USER_CERTIFICATE_REQUIRED => 0x80310073 as u32,
            FVE::FVE_E_POLICY_USER_CERT_MUST_BE_HW => 0x80310074 as u32,
            FVE::FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED => 0x80310075 as u32,
            FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED => 0x80310076 as u32,
            FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED => 0x80310077 as u32,
            FVE::FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED => 0x80310078 as u32,
            FVE::FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED => 0x80310079 as u32,
            FVE::FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH => 0x80310080 as u32,
            FVE::FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE => 0x80310081 as u32,
            FVE::FVE_E_RECOVERY_PARTITION => 0x80310082 as u32,
            FVE::FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON => 0x80310083 as u32,
            FVE::FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON => 0x80310084 as u32,
            FVE::FVE_E_NON_BITLOCKER_OID => 0x80310085 as u32,
            FVE::FVE_E_POLICY_PROHIBITS_SELFSIGNED => 0x80310086 as u32,
            FVE::FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED => 0x80310087 as u32,
            FVE::FVE_E_CONV_RECOVERY_FAILED => 0x80310088 as u32,
            FVE::FVE_E_VIRTUALIZED_SPACE_TOO_BIG => 0x80310089 as u32,
            FVE::FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON => 0x80310090 as u32,
            FVE::FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON => 0x80310091 as u32,
            FVE::FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON => 0x80310092 as u32,
            FVE::FVE_E_NON_BITLOCKER_KU => 0x80310093 as u32,
            FVE::FVE_E_PRIVATEKEY_AUTH_FAILED => 0x80310094 as u32,
            FVE::FVE_E_REMOVAL_OF_DRA_FAILED => 0x80310095 as u32,
            FVE::FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME => 0x80310096 as u32,
            FVE::FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME => 0x80310097 as u32,
            FVE::FVE_E_FIPS_HASH_KDF_NOT_ALLOWED => 0x80310098 as u32,
            FVE::FVE_E_ENH_PIN_INVALID => 0x80310099 as u32,
            FVE::FVE_E_INVALID_PIN_CHARS => 0x8031009A as u32,
            FVE::FVE_E_INVALID_DATUM_TYPE => 0x8031009B as u32,
            FVE::FVE_E_EFI_ONLY => 0x8031009C as u32,
            FVE::FVE_E_MULTIPLE_NKP_CERTS => 0x8031009D as u32,
            FVE::FVE_E_REMOVAL_OF_NKP_FAILED => 0x8031009E as u32,
            FVE::FVE_E_INVALID_NKP_CERT => 0x8031009F as u32,
            FVE::FVE_E_NO_EXISTING_PIN => 0x803100A0 as u32,
            FVE::FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH => 0x803100A1 as u32,
            FVE::FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED => 0x803100A2 as u32,
            FVE::FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED => 0x803100A3 as u32,
            FVE::FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII => 0x803100A4 as u32,
            FVE::FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE => 0x803100A5 as u32,
            FVE::FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE => 0x803100A6 as u32,
            FVE::FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE => 0x803100A7 as u32,
            FVE::FVE_E_NO_EXISTING_PASSPHRASE => 0x803100A8 as u32,
            FVE::FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH => 0x803100A9 as u32,
            FVE::FVE_E_PASSPHRASE_TOO_LONG => 0x803100AA as u32,
            FVE::FVE_E_NO_PASSPHRASE_WITH_TPM => 0x803100AB as u32,
            FVE::FVE_E_NO_TPM_WITH_PASSPHRASE => 0x803100AC as u32,
            FVE::FVE_E_NOT_ALLOWED_ON_CSV_STACK => 0x803100AD as u32,
            FVE::FVE_E_NOT_ALLOWED_ON_CLUSTER => 0x803100AE as u32,
            FVE::FVE_E_EDRIVE_NO_FAILOVER_TO_SW => 0x803100AF as u32,
            FVE::FVE_E_EDRIVE_BAND_IN_USE => 0x803100B0 as u32,
            FVE::FVE_E_EDRIVE_DISALLOWED_BY_GP => 0x803100B1 as u32,
            FVE::FVE_E_EDRIVE_INCOMPATIBLE_VOLUME => 0x803100B2 as u32,
            FVE::FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING => 0x803100B3 as u32,
            FVE::FVE_E_EDRIVE_DV_NOT_SUPPORTED => 0x803100B4 as u32,
            FVE::FVE_E_NO_PREBOOT_KEYBOARD_DETECTED => 0x803100B5 as u32,
            FVE::FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED => 0x803100B6 as u32,
            FVE::FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE => 0x803100B7 as u32,
            FVE::FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE => 0x803100B8 as u32,
            FVE::FVE_E_WIPE_CANCEL_NOT_APPLICABLE => 0x803100B9 as u32,
            FVE::FVE_E_SECUREBOOT_DISABLED => 0x803100BA as u32,
            FVE::FVE_E_SECUREBOOT_CONFIGURATION_INVALID => 0x803100BB as u32,
            FVE::FVE_E_EDRIVE_DRY_RUN_FAILED => 0x803100BC as u32,
            FVE::FVE_E_SHADOW_COPY_PRESENT => 0x803100BD as u32,
            FVE::FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS => 0x803100BE as u32,
            FVE::FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE => 0x803100BF as u32,
            FVE::FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED => 0x803100C0 as u32,
            FVE::FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED => 0x803100C1 as u32,
            FVE::FVE_E_LIVEID_ACCOUNT_SUSPENDED => 0x803100C2 as u32,
            FVE::FVE_E_LIVEID_ACCOUNT_BLOCKED => 0x803100C3 as u32,
            FVE::FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES => 0x803100C4 as u32,
            FVE::FVE_E_DE_FIXED_DATA_NOT_SUPPORTED => 0x803100C5 as u32,
            FVE::FVE_E_DE_HARDWARE_NOT_COMPLIANT => 0x803100C6 as u32,
            FVE::FVE_E_DE_WINRE_NOT_CONFIGURED => 0x803100C7 as u32,
            FVE::FVE_E_DE_PROTECTION_SUSPENDED => 0x803100C8 as u32,
            FVE::FVE_E_DE_OS_VOLUME_NOT_PROTECTED => 0x803100C9 as u32,
            FVE::FVE_E_DE_DEVICE_LOCKEDOUT => 0x803100CA as u32,
            FVE::FVE_E_DE_PROTECTION_NOT_YET_ENABLED => 0x803100CB as u32,
            FVE::FVE_E_INVALID_PIN_CHARS_DETAILED => 0x803100CC as u32,
            FVE::FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE => 0x803100CD as u32,
            FVE::FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH => 0x803100CE as u32,
            FVE::FVE_E_BUFFER_TOO_LARGE => 0x803100CF as u32,
            FVE::FVE_E_NO_SUCH_CAPABILITY_ON_TARGET => 0x803100D0 as u32,
            FVE::FVE_E_DE_PREVENTED_FOR_OS => 0x803100D1 as u32,
            FVE::FVE_E_DE_VOLUME_OPTED_OUT => 0x803100D2 as u32,
            FVE::FVE_E_DE_VOLUME_NOT_SUPPORTED => 0x803100D3 as u32,
            FVE::FVE_E_EOW_NOT_SUPPORTED_IN_VERSION => 0x803100D4 as u32,
            FVE::FVE_E_ADBACKUP_NOT_ENABLED => 0x803100D5 as u32,
            FVE::FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT => 0x803100D6 as u32,
            FVE::FVE_E_NOT_DE_VOLUME => 0x803100D7 as u32,
            FVE::FVE_E_PROTECTION_CANNOT_BE_DISABLED => 0x803100D8 as u32,
            FVE::FVE_E_OSV_KSR_NOT_ALLOWED => 0x803100D9 as u32,
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE => 0x803100DA as u32,
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE => 0x803100DB as u32,
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE => 0x803100DC as u32,
            FVE::FVE_E_KEY_ROTATION_NOT_SUPPORTED => 0x803100DD as u32,
            FVE::FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON => 0x803100DE as u32,
            FVE::FVE_E_KEY_ROTATION_NOT_ENABLED => 0x803100DF as u32,
            FVE::FVE_E_DEVICE_NOT_JOINED => 0x803100E0 as u32,
            FVE::FVE_E_AAD_ENDPOINT_BUSY => 0x803100E1 as u32,
            FVE::FVE_E_INVALID_NBP_CERT => 0x803100E2 as u32,
            FVE::FVE_E_EDRIVE_BAND_ENUMERATION_FAILED => 0x803100E3 as u32,
            FVE::FVE_E_POLICY_ON_RDV_EXCLUSION_LIST => 0x803100E4 as u32,
            FVE::FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED => 0x803100E5 as u32,
            FVE::FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED => 0x803100E6 as u32,
            FVE::FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED => 0x803100E7 as u32,
            FVE::FVE_E_UPDATE_INVALID_CONFIG => 0x803100E8 as u32,
            FVE::FVE_E_AAD_SERVER_FAIL_RETRY_AFTER => 0x803100E9 as u32,
            FVE::FVE_E_AAD_SERVER_FAIL_BACKOFF => 0x803100EA as u32,
            FVE::FVE_E_DATASET_FULL => 0x803100EB as u32,
            FVE::FVE_E_METADATA_FULL => 0x803100EC as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            FVE::FVE_E_LOCKED_VOLUME => RawError::Kind(FVE::FVE_E_LOCKED_VOLUME),
            FVE::FVE_E_NOT_ENCRYPTED => RawError::Kind(FVE::FVE_E_NOT_ENCRYPTED),
            FVE::FVE_E_NO_TPM_BIOS => RawError::Kind(FVE::FVE_E_NO_TPM_BIOS),
            FVE::FVE_E_NO_MBR_METRIC => RawError::Kind(FVE::FVE_E_NO_MBR_METRIC),
            FVE::FVE_E_NO_BOOTSECTOR_METRIC => RawError::Kind(FVE::FVE_E_NO_BOOTSECTOR_METRIC),
            FVE::FVE_E_NO_BOOTMGR_METRIC => RawError::Kind(FVE::FVE_E_NO_BOOTMGR_METRIC),
            FVE::FVE_E_WRONG_BOOTMGR => RawError::Kind(FVE::FVE_E_WRONG_BOOTMGR),
            FVE::FVE_E_SECURE_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_SECURE_KEY_REQUIRED),
            FVE::FVE_E_NOT_ACTIVATED => RawError::Kind(FVE::FVE_E_NOT_ACTIVATED),
            FVE::FVE_E_ACTION_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_ACTION_NOT_ALLOWED),
            FVE::FVE_E_AD_SCHEMA_NOT_INSTALLED => RawError::Kind(FVE::FVE_E_AD_SCHEMA_NOT_INSTALLED),
            FVE::FVE_E_AD_INVALID_DATATYPE => RawError::Kind(FVE::FVE_E_AD_INVALID_DATATYPE),
            FVE::FVE_E_AD_INVALID_DATASIZE => RawError::Kind(FVE::FVE_E_AD_INVALID_DATASIZE),
            FVE::FVE_E_AD_NO_VALUES => RawError::Kind(FVE::FVE_E_AD_NO_VALUES),
            FVE::FVE_E_AD_ATTR_NOT_SET => RawError::Kind(FVE::FVE_E_AD_ATTR_NOT_SET),
            FVE::FVE_E_AD_GUID_NOT_FOUND => RawError::Kind(FVE::FVE_E_AD_GUID_NOT_FOUND),
            FVE::FVE_E_BAD_INFORMATION => RawError::Kind(FVE::FVE_E_BAD_INFORMATION),
            FVE::FVE_E_TOO_SMALL => RawError::Kind(FVE::FVE_E_TOO_SMALL),
            FVE::FVE_E_SYSTEM_VOLUME => RawError::Kind(FVE::FVE_E_SYSTEM_VOLUME),
            FVE::FVE_E_FAILED_WRONG_FS => RawError::Kind(FVE::FVE_E_FAILED_WRONG_FS),
            FVE::FVE_E_BAD_PARTITION_SIZE => RawError::Kind(FVE::FVE_E_BAD_PARTITION_SIZE),
            FVE::FVE_E_FAILED_BAD_FS => RawError::Kind(FVE::FVE_E_FAILED_BAD_FS),
            FVE::FVE_E_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_NOT_SUPPORTED),
            FVE::FVE_E_BAD_DATA => RawError::Kind(FVE::FVE_E_BAD_DATA),
            FVE::FVE_E_VOLUME_NOT_BOUND => RawError::Kind(FVE::FVE_E_VOLUME_NOT_BOUND),
            FVE::FVE_E_TPM_NOT_OWNED => RawError::Kind(FVE::FVE_E_TPM_NOT_OWNED),
            FVE::FVE_E_NOT_DATA_VOLUME => RawError::Kind(FVE::FVE_E_NOT_DATA_VOLUME),
            FVE::FVE_E_AD_INSUFFICIENT_BUFFER => RawError::Kind(FVE::FVE_E_AD_INSUFFICIENT_BUFFER),
            FVE::FVE_E_CONV_READ => RawError::Kind(FVE::FVE_E_CONV_READ),
            FVE::FVE_E_CONV_WRITE => RawError::Kind(FVE::FVE_E_CONV_WRITE),
            FVE::FVE_E_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_KEY_REQUIRED),
            FVE::FVE_E_CLUSTERING_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_CLUSTERING_NOT_SUPPORTED),
            FVE::FVE_E_VOLUME_BOUND_ALREADY => RawError::Kind(FVE::FVE_E_VOLUME_BOUND_ALREADY),
            FVE::FVE_E_OS_NOT_PROTECTED => RawError::Kind(FVE::FVE_E_OS_NOT_PROTECTED),
            FVE::FVE_E_PROTECTION_DISABLED => RawError::Kind(FVE::FVE_E_PROTECTION_DISABLED),
            FVE::FVE_E_RECOVERY_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_RECOVERY_KEY_REQUIRED),
            FVE::FVE_E_FOREIGN_VOLUME => RawError::Kind(FVE::FVE_E_FOREIGN_VOLUME),
            FVE::FVE_E_OVERLAPPED_UPDATE => RawError::Kind(FVE::FVE_E_OVERLAPPED_UPDATE),
            FVE::FVE_E_TPM_SRK_AUTH_NOT_ZERO => RawError::Kind(FVE::FVE_E_TPM_SRK_AUTH_NOT_ZERO),
            FVE::FVE_E_FAILED_SECTOR_SIZE => RawError::Kind(FVE::FVE_E_FAILED_SECTOR_SIZE),
            FVE::FVE_E_FAILED_AUTHENTICATION => RawError::Kind(FVE::FVE_E_FAILED_AUTHENTICATION),
            FVE::FVE_E_NOT_OS_VOLUME => RawError::Kind(FVE::FVE_E_NOT_OS_VOLUME),
            FVE::FVE_E_AUTOUNLOCK_ENABLED => RawError::Kind(FVE::FVE_E_AUTOUNLOCK_ENABLED),
            FVE::FVE_E_WRONG_BOOTSECTOR => RawError::Kind(FVE::FVE_E_WRONG_BOOTSECTOR),
            FVE::FVE_E_WRONG_SYSTEM_FS => RawError::Kind(FVE::FVE_E_WRONG_SYSTEM_FS),
            FVE::FVE_E_POLICY_PASSWORD_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_PASSWORD_REQUIRED),
            FVE::FVE_E_CANNOT_SET_FVEK_ENCRYPTED => RawError::Kind(FVE::FVE_E_CANNOT_SET_FVEK_ENCRYPTED),
            FVE::FVE_E_CANNOT_ENCRYPT_NO_KEY => RawError::Kind(FVE::FVE_E_CANNOT_ENCRYPT_NO_KEY),
            FVE::FVE_E_BOOTABLE_CDDVD => RawError::Kind(FVE::FVE_E_BOOTABLE_CDDVD),
            FVE::FVE_E_PROTECTOR_EXISTS => RawError::Kind(FVE::FVE_E_PROTECTOR_EXISTS),
            FVE::FVE_E_RELATIVE_PATH => RawError::Kind(FVE::FVE_E_RELATIVE_PATH),
            FVE::FVE_E_PROTECTOR_NOT_FOUND => RawError::Kind(FVE::FVE_E_PROTECTOR_NOT_FOUND),
            FVE::FVE_E_INVALID_KEY_FORMAT => RawError::Kind(FVE::FVE_E_INVALID_KEY_FORMAT),
            FVE::FVE_E_INVALID_PASSWORD_FORMAT => RawError::Kind(FVE::FVE_E_INVALID_PASSWORD_FORMAT),
            FVE::FVE_E_FIPS_RNG_CHECK_FAILED => RawError::Kind(FVE::FVE_E_FIPS_RNG_CHECK_FAILED),
            FVE::FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD => RawError::Kind(FVE::FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD),
            FVE::FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT => RawError::Kind(FVE::FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT),
            FVE::FVE_E_NOT_DECRYPTED => RawError::Kind(FVE::FVE_E_NOT_DECRYPTED),
            FVE::FVE_E_INVALID_PROTECTOR_TYPE => RawError::Kind(FVE::FVE_E_INVALID_PROTECTOR_TYPE),
            FVE::FVE_E_NO_PROTECTORS_TO_TEST => RawError::Kind(FVE::FVE_E_NO_PROTECTORS_TO_TEST),
            FVE::FVE_E_KEYFILE_NOT_FOUND => RawError::Kind(FVE::FVE_E_KEYFILE_NOT_FOUND),
            FVE::FVE_E_KEYFILE_INVALID => RawError::Kind(FVE::FVE_E_KEYFILE_INVALID),
            FVE::FVE_E_KEYFILE_NO_VMK => RawError::Kind(FVE::FVE_E_KEYFILE_NO_VMK),
            FVE::FVE_E_TPM_DISABLED => RawError::Kind(FVE::FVE_E_TPM_DISABLED),
            FVE::FVE_E_NOT_ALLOWED_IN_SAFE_MODE => RawError::Kind(FVE::FVE_E_NOT_ALLOWED_IN_SAFE_MODE),
            FVE::FVE_E_TPM_INVALID_PCR => RawError::Kind(FVE::FVE_E_TPM_INVALID_PCR),
            FVE::FVE_E_TPM_NO_VMK => RawError::Kind(FVE::FVE_E_TPM_NO_VMK),
            FVE::FVE_E_PIN_INVALID => RawError::Kind(FVE::FVE_E_PIN_INVALID),
            FVE::FVE_E_AUTH_INVALID_APPLICATION => RawError::Kind(FVE::FVE_E_AUTH_INVALID_APPLICATION),
            FVE::FVE_E_AUTH_INVALID_CONFIG => RawError::Kind(FVE::FVE_E_AUTH_INVALID_CONFIG),
            FVE::FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED),
            FVE::FVE_E_FS_NOT_EXTENDED => RawError::Kind(FVE::FVE_E_FS_NOT_EXTENDED),
            FVE::FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED),
            FVE::FVE_E_NO_LICENSE => RawError::Kind(FVE::FVE_E_NO_LICENSE),
            FVE::FVE_E_NOT_ON_STACK => RawError::Kind(FVE::FVE_E_NOT_ON_STACK),
            FVE::FVE_E_FS_MOUNTED => RawError::Kind(FVE::FVE_E_FS_MOUNTED),
            FVE::FVE_E_TOKEN_NOT_IMPERSONATED => RawError::Kind(FVE::FVE_E_TOKEN_NOT_IMPERSONATED),
            FVE::FVE_E_DRY_RUN_FAILED => RawError::Kind(FVE::FVE_E_DRY_RUN_FAILED),
            FVE::FVE_E_REBOOT_REQUIRED => RawError::Kind(FVE::FVE_E_REBOOT_REQUIRED),
            FVE::FVE_E_DEBUGGER_ENABLED => RawError::Kind(FVE::FVE_E_DEBUGGER_ENABLED),
            FVE::FVE_E_RAW_ACCESS => RawError::Kind(FVE::FVE_E_RAW_ACCESS),
            FVE::FVE_E_RAW_BLOCKED => RawError::Kind(FVE::FVE_E_RAW_BLOCKED),
            FVE::FVE_E_BCD_APPLICATIONS_PATH_INCORRECT => RawError::Kind(FVE::FVE_E_BCD_APPLICATIONS_PATH_INCORRECT),
            FVE::FVE_E_NOT_ALLOWED_IN_VERSION => RawError::Kind(FVE::FVE_E_NOT_ALLOWED_IN_VERSION),
            FVE::FVE_E_NO_AUTOUNLOCK_MASTER_KEY => RawError::Kind(FVE::FVE_E_NO_AUTOUNLOCK_MASTER_KEY),
            FVE::FVE_E_MOR_FAILED => RawError::Kind(FVE::FVE_E_MOR_FAILED),
            FVE::FVE_E_HIDDEN_VOLUME => RawError::Kind(FVE::FVE_E_HIDDEN_VOLUME),
            FVE::FVE_E_TRANSIENT_STATE => RawError::Kind(FVE::FVE_E_TRANSIENT_STATE),
            FVE::FVE_E_PUBKEY_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_PUBKEY_NOT_ALLOWED),
            FVE::FVE_E_VOLUME_HANDLE_OPEN => RawError::Kind(FVE::FVE_E_VOLUME_HANDLE_OPEN),
            FVE::FVE_E_NO_FEATURE_LICENSE => RawError::Kind(FVE::FVE_E_NO_FEATURE_LICENSE),
            FVE::FVE_E_INVALID_STARTUP_OPTIONS => RawError::Kind(FVE::FVE_E_INVALID_STARTUP_OPTIONS),
            FVE::FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED),
            FVE::FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED),
            FVE::FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED),
            FVE::FVE_E_POLICY_RECOVERY_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_RECOVERY_KEY_REQUIRED),
            FVE::FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED),
            FVE::FVE_E_POLICY_STARTUP_PIN_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_PIN_REQUIRED),
            FVE::FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED),
            FVE::FVE_E_POLICY_STARTUP_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_KEY_REQUIRED),
            FVE::FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED),
            FVE::FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED),
            FVE::FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED),
            FVE::FVE_E_POLICY_STARTUP_TPM_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_STARTUP_TPM_REQUIRED),
            FVE::FVE_E_POLICY_INVALID_PIN_LENGTH => RawError::Kind(FVE::FVE_E_POLICY_INVALID_PIN_LENGTH),
            FVE::FVE_E_KEY_PROTECTOR_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_KEY_PROTECTOR_NOT_SUPPORTED),
            FVE::FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED),
            FVE::FVE_E_POLICY_PASSPHRASE_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_PASSPHRASE_REQUIRED),
            FVE::FVE_E_FIPS_PREVENTS_PASSPHRASE => RawError::Kind(FVE::FVE_E_FIPS_PREVENTS_PASSPHRASE),
            FVE::FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED),
            FVE::FVE_E_INVALID_BITLOCKER_OID => RawError::Kind(FVE::FVE_E_INVALID_BITLOCKER_OID),
            FVE::FVE_E_VOLUME_TOO_SMALL => RawError::Kind(FVE::FVE_E_VOLUME_TOO_SMALL),
            FVE::FVE_E_DV_NOT_SUPPORTED_ON_FS => RawError::Kind(FVE::FVE_E_DV_NOT_SUPPORTED_ON_FS),
            FVE::FVE_E_DV_NOT_ALLOWED_BY_GP => RawError::Kind(FVE::FVE_E_DV_NOT_ALLOWED_BY_GP),
            FVE::FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED),
            FVE::FVE_E_POLICY_USER_CERTIFICATE_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_USER_CERTIFICATE_REQUIRED),
            FVE::FVE_E_POLICY_USER_CERT_MUST_BE_HW => RawError::Kind(FVE::FVE_E_POLICY_USER_CERT_MUST_BE_HW),
            FVE::FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED),
            FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED),
            FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED),
            FVE::FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED),
            FVE::FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED),
            FVE::FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH => RawError::Kind(FVE::FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH),
            FVE::FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE => RawError::Kind(FVE::FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE),
            FVE::FVE_E_RECOVERY_PARTITION => RawError::Kind(FVE::FVE_E_RECOVERY_PARTITION),
            FVE::FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON => RawError::Kind(FVE::FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON),
            FVE::FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON => RawError::Kind(FVE::FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON),
            FVE::FVE_E_NON_BITLOCKER_OID => RawError::Kind(FVE::FVE_E_NON_BITLOCKER_OID),
            FVE::FVE_E_POLICY_PROHIBITS_SELFSIGNED => RawError::Kind(FVE::FVE_E_POLICY_PROHIBITS_SELFSIGNED),
            FVE::FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED => RawError::Kind(FVE::FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED),
            FVE::FVE_E_CONV_RECOVERY_FAILED => RawError::Kind(FVE::FVE_E_CONV_RECOVERY_FAILED),
            FVE::FVE_E_VIRTUALIZED_SPACE_TOO_BIG => RawError::Kind(FVE::FVE_E_VIRTUALIZED_SPACE_TOO_BIG),
            FVE::FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON => RawError::Kind(FVE::FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON),
            FVE::FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON => RawError::Kind(FVE::FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON),
            FVE::FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON => RawError::Kind(FVE::FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON),
            FVE::FVE_E_NON_BITLOCKER_KU => RawError::Kind(FVE::FVE_E_NON_BITLOCKER_KU),
            FVE::FVE_E_PRIVATEKEY_AUTH_FAILED => RawError::Kind(FVE::FVE_E_PRIVATEKEY_AUTH_FAILED),
            FVE::FVE_E_REMOVAL_OF_DRA_FAILED => RawError::Kind(FVE::FVE_E_REMOVAL_OF_DRA_FAILED),
            FVE::FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME => RawError::Kind(FVE::FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME),
            FVE::FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME => RawError::Kind(FVE::FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME),
            FVE::FVE_E_FIPS_HASH_KDF_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_FIPS_HASH_KDF_NOT_ALLOWED),
            FVE::FVE_E_ENH_PIN_INVALID => RawError::Kind(FVE::FVE_E_ENH_PIN_INVALID),
            FVE::FVE_E_INVALID_PIN_CHARS => RawError::Kind(FVE::FVE_E_INVALID_PIN_CHARS),
            FVE::FVE_E_INVALID_DATUM_TYPE => RawError::Kind(FVE::FVE_E_INVALID_DATUM_TYPE),
            FVE::FVE_E_EFI_ONLY => RawError::Kind(FVE::FVE_E_EFI_ONLY),
            FVE::FVE_E_MULTIPLE_NKP_CERTS => RawError::Kind(FVE::FVE_E_MULTIPLE_NKP_CERTS),
            FVE::FVE_E_REMOVAL_OF_NKP_FAILED => RawError::Kind(FVE::FVE_E_REMOVAL_OF_NKP_FAILED),
            FVE::FVE_E_INVALID_NKP_CERT => RawError::Kind(FVE::FVE_E_INVALID_NKP_CERT),
            FVE::FVE_E_NO_EXISTING_PIN => RawError::Kind(FVE::FVE_E_NO_EXISTING_PIN),
            FVE::FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH => RawError::Kind(FVE::FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH),
            FVE::FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED => RawError::Kind(FVE::FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED),
            FVE::FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED => RawError::Kind(FVE::FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED),
            FVE::FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII => RawError::Kind(FVE::FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII),
            FVE::FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE => RawError::Kind(FVE::FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE),
            FVE::FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE => RawError::Kind(FVE::FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE),
            FVE::FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE => RawError::Kind(FVE::FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE),
            FVE::FVE_E_NO_EXISTING_PASSPHRASE => RawError::Kind(FVE::FVE_E_NO_EXISTING_PASSPHRASE),
            FVE::FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH => RawError::Kind(FVE::FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH),
            FVE::FVE_E_PASSPHRASE_TOO_LONG => RawError::Kind(FVE::FVE_E_PASSPHRASE_TOO_LONG),
            FVE::FVE_E_NO_PASSPHRASE_WITH_TPM => RawError::Kind(FVE::FVE_E_NO_PASSPHRASE_WITH_TPM),
            FVE::FVE_E_NO_TPM_WITH_PASSPHRASE => RawError::Kind(FVE::FVE_E_NO_TPM_WITH_PASSPHRASE),
            FVE::FVE_E_NOT_ALLOWED_ON_CSV_STACK => RawError::Kind(FVE::FVE_E_NOT_ALLOWED_ON_CSV_STACK),
            FVE::FVE_E_NOT_ALLOWED_ON_CLUSTER => RawError::Kind(FVE::FVE_E_NOT_ALLOWED_ON_CLUSTER),
            FVE::FVE_E_EDRIVE_NO_FAILOVER_TO_SW => RawError::Kind(FVE::FVE_E_EDRIVE_NO_FAILOVER_TO_SW),
            FVE::FVE_E_EDRIVE_BAND_IN_USE => RawError::Kind(FVE::FVE_E_EDRIVE_BAND_IN_USE),
            FVE::FVE_E_EDRIVE_DISALLOWED_BY_GP => RawError::Kind(FVE::FVE_E_EDRIVE_DISALLOWED_BY_GP),
            FVE::FVE_E_EDRIVE_INCOMPATIBLE_VOLUME => RawError::Kind(FVE::FVE_E_EDRIVE_INCOMPATIBLE_VOLUME),
            FVE::FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING => RawError::Kind(FVE::FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING),
            FVE::FVE_E_EDRIVE_DV_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_EDRIVE_DV_NOT_SUPPORTED),
            FVE::FVE_E_NO_PREBOOT_KEYBOARD_DETECTED => RawError::Kind(FVE::FVE_E_NO_PREBOOT_KEYBOARD_DETECTED),
            FVE::FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED => RawError::Kind(FVE::FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED),
            FVE::FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE => RawError::Kind(FVE::FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE),
            FVE::FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE => RawError::Kind(FVE::FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE),
            FVE::FVE_E_WIPE_CANCEL_NOT_APPLICABLE => RawError::Kind(FVE::FVE_E_WIPE_CANCEL_NOT_APPLICABLE),
            FVE::FVE_E_SECUREBOOT_DISABLED => RawError::Kind(FVE::FVE_E_SECUREBOOT_DISABLED),
            FVE::FVE_E_SECUREBOOT_CONFIGURATION_INVALID => RawError::Kind(FVE::FVE_E_SECUREBOOT_CONFIGURATION_INVALID),
            FVE::FVE_E_EDRIVE_DRY_RUN_FAILED => RawError::Kind(FVE::FVE_E_EDRIVE_DRY_RUN_FAILED),
            FVE::FVE_E_SHADOW_COPY_PRESENT => RawError::Kind(FVE::FVE_E_SHADOW_COPY_PRESENT),
            FVE::FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS => RawError::Kind(FVE::FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS),
            FVE::FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE => RawError::Kind(FVE::FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE),
            FVE::FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED => RawError::Kind(FVE::FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED),
            FVE::FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED => RawError::Kind(FVE::FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED),
            FVE::FVE_E_LIVEID_ACCOUNT_SUSPENDED => RawError::Kind(FVE::FVE_E_LIVEID_ACCOUNT_SUSPENDED),
            FVE::FVE_E_LIVEID_ACCOUNT_BLOCKED => RawError::Kind(FVE::FVE_E_LIVEID_ACCOUNT_BLOCKED),
            FVE::FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES => RawError::Kind(FVE::FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES),
            FVE::FVE_E_DE_FIXED_DATA_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_DE_FIXED_DATA_NOT_SUPPORTED),
            FVE::FVE_E_DE_HARDWARE_NOT_COMPLIANT => RawError::Kind(FVE::FVE_E_DE_HARDWARE_NOT_COMPLIANT),
            FVE::FVE_E_DE_WINRE_NOT_CONFIGURED => RawError::Kind(FVE::FVE_E_DE_WINRE_NOT_CONFIGURED),
            FVE::FVE_E_DE_PROTECTION_SUSPENDED => RawError::Kind(FVE::FVE_E_DE_PROTECTION_SUSPENDED),
            FVE::FVE_E_DE_OS_VOLUME_NOT_PROTECTED => RawError::Kind(FVE::FVE_E_DE_OS_VOLUME_NOT_PROTECTED),
            FVE::FVE_E_DE_DEVICE_LOCKEDOUT => RawError::Kind(FVE::FVE_E_DE_DEVICE_LOCKEDOUT),
            FVE::FVE_E_DE_PROTECTION_NOT_YET_ENABLED => RawError::Kind(FVE::FVE_E_DE_PROTECTION_NOT_YET_ENABLED),
            FVE::FVE_E_INVALID_PIN_CHARS_DETAILED => RawError::Kind(FVE::FVE_E_INVALID_PIN_CHARS_DETAILED),
            FVE::FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE => RawError::Kind(FVE::FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE),
            FVE::FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH => RawError::Kind(FVE::FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH),
            FVE::FVE_E_BUFFER_TOO_LARGE => RawError::Kind(FVE::FVE_E_BUFFER_TOO_LARGE),
            FVE::FVE_E_NO_SUCH_CAPABILITY_ON_TARGET => RawError::Kind(FVE::FVE_E_NO_SUCH_CAPABILITY_ON_TARGET),
            FVE::FVE_E_DE_PREVENTED_FOR_OS => RawError::Kind(FVE::FVE_E_DE_PREVENTED_FOR_OS),
            FVE::FVE_E_DE_VOLUME_OPTED_OUT => RawError::Kind(FVE::FVE_E_DE_VOLUME_OPTED_OUT),
            FVE::FVE_E_DE_VOLUME_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_DE_VOLUME_NOT_SUPPORTED),
            FVE::FVE_E_EOW_NOT_SUPPORTED_IN_VERSION => RawError::Kind(FVE::FVE_E_EOW_NOT_SUPPORTED_IN_VERSION),
            FVE::FVE_E_ADBACKUP_NOT_ENABLED => RawError::Kind(FVE::FVE_E_ADBACKUP_NOT_ENABLED),
            FVE::FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT => RawError::Kind(FVE::FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT),
            FVE::FVE_E_NOT_DE_VOLUME => RawError::Kind(FVE::FVE_E_NOT_DE_VOLUME),
            FVE::FVE_E_PROTECTION_CANNOT_BE_DISABLED => RawError::Kind(FVE::FVE_E_PROTECTION_CANNOT_BE_DISABLED),
            FVE::FVE_E_OSV_KSR_NOT_ALLOWED => RawError::Kind(FVE::FVE_E_OSV_KSR_NOT_ALLOWED),
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE => RawError::Kind(FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE),
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE => RawError::Kind(FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE),
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE => RawError::Kind(FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE),
            FVE::FVE_E_KEY_ROTATION_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_KEY_ROTATION_NOT_SUPPORTED),
            FVE::FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON => RawError::Kind(FVE::FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON),
            FVE::FVE_E_KEY_ROTATION_NOT_ENABLED => RawError::Kind(FVE::FVE_E_KEY_ROTATION_NOT_ENABLED),
            FVE::FVE_E_DEVICE_NOT_JOINED => RawError::Kind(FVE::FVE_E_DEVICE_NOT_JOINED),
            FVE::FVE_E_AAD_ENDPOINT_BUSY => RawError::Kind(FVE::FVE_E_AAD_ENDPOINT_BUSY),
            FVE::FVE_E_INVALID_NBP_CERT => RawError::Kind(FVE::FVE_E_INVALID_NBP_CERT),
            FVE::FVE_E_EDRIVE_BAND_ENUMERATION_FAILED => RawError::Kind(FVE::FVE_E_EDRIVE_BAND_ENUMERATION_FAILED),
            FVE::FVE_E_POLICY_ON_RDV_EXCLUSION_LIST => RawError::Kind(FVE::FVE_E_POLICY_ON_RDV_EXCLUSION_LIST),
            FVE::FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED),
            FVE::FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED),
            FVE::FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED => RawError::Kind(FVE::FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED),
            FVE::FVE_E_UPDATE_INVALID_CONFIG => RawError::Kind(FVE::FVE_E_UPDATE_INVALID_CONFIG),
            FVE::FVE_E_AAD_SERVER_FAIL_RETRY_AFTER => RawError::Kind(FVE::FVE_E_AAD_SERVER_FAIL_RETRY_AFTER),
            FVE::FVE_E_AAD_SERVER_FAIL_BACKOFF => RawError::Kind(FVE::FVE_E_AAD_SERVER_FAIL_BACKOFF),
            FVE::FVE_E_DATASET_FULL => RawError::Kind(FVE::FVE_E_DATASET_FULL),
            FVE::FVE_E_METADATA_FULL => RawError::Kind(FVE::FVE_E_METADATA_FULL),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            FVE::FVE_E_LOCKED_VOLUME => "This drive is locked by BitLocker Drive Encryption. You must unlock this drive from Control Panel.",
            FVE::FVE_E_NOT_ENCRYPTED => "This drive is not encrypted.",
            FVE::FVE_E_NO_TPM_BIOS => "The BIOS did not correctly communicate with the Trusted Platform Module (TPM). Contact the computer manufacturer for BIOS upgrade instructions.",
            FVE::FVE_E_NO_MBR_METRIC => "The BIOS did not correctly communicate with the master boot record (MBR). Contact the computer manufacturer for BIOS upgrade instructions.",
            FVE::FVE_E_NO_BOOTSECTOR_METRIC => "A required TPM measurement is missing. If there is a bootable CD or DVD in your computer, remove it, restart the computer, and turn on BitLocker again. If the problem persists, ensure the master boot record is up to date.",
            FVE::FVE_E_NO_BOOTMGR_METRIC => "The boot sector of this drive is not compatible with BitLocker Drive Encryption. Use the Bootrec.exe tool in the Windows Recovery Environment to update or repair the boot manager (BOOTMGR).",
            FVE::FVE_E_WRONG_BOOTMGR => "The boot manager of this operating system is not compatible with BitLocker Drive Encryption. Use the Bootrec.exe tool in the Windows Recovery Environment to update or repair the boot manager (BOOTMGR).",
            FVE::FVE_E_SECURE_KEY_REQUIRED => "At least one secure key protector is required for this operation to be performed.",
            FVE::FVE_E_NOT_ACTIVATED => "BitLocker Drive Encryption is not enabled on this drive. Turn on BitLocker.",
            FVE::FVE_E_ACTION_NOT_ALLOWED => "BitLocker Drive Encryption cannot perform the requested action. This condition may occur when two requests are issued at the same time. Wait a few moments and then try the action again.",
            FVE::FVE_E_AD_SCHEMA_NOT_INSTALLED => "The Active Directory Domain Services forest does not contain the required attributes and classes to host BitLocker Drive Encryption or Trusted Platform Module information. Contact your domain administrator to verify that any required BitLocker Active Directory schema extensions have been installed.",
            FVE::FVE_E_AD_INVALID_DATATYPE => "The type of the data obtained from Active Directory was not expected. The BitLocker recovery information may be missing or corrupted.",
            FVE::FVE_E_AD_INVALID_DATASIZE => "The size of the data obtained from Active Directory was not expected. The BitLocker recovery information may be missing or corrupted.",
            FVE::FVE_E_AD_NO_VALUES => "The attribute read from Active Directory does not contain any values. The BitLocker recovery information may be missing or corrupted.",
            FVE::FVE_E_AD_ATTR_NOT_SET => "The attribute was not set. Verify that you are logged on with a domain account that has the ability to write information to Active Directory objects.",
            FVE::FVE_E_AD_GUID_NOT_FOUND => "The specified attribute cannot be found in Active Directory Domain Services. Contact your domain administrator to verify that any required BitLocker Active Directory schema extensions have been installed.",
            FVE::FVE_E_BAD_INFORMATION => "The BitLocker metadata for the encrypted drive is not valid. You can attempt to repair the drive to restore access.",
            FVE::FVE_E_TOO_SMALL => "The drive cannot be encrypted because it does not have enough free space. Delete any unnecessary data on the drive to create additional free space and then try again.",
            FVE::FVE_E_SYSTEM_VOLUME => "The drive cannot be encrypted because it contains system boot information. Create a separate partition for use as the system drive that contains the boot information and a second partition for use as the operating system drive and then encrypt the operating system drive.",
            FVE::FVE_E_FAILED_WRONG_FS => "The drive cannot be encrypted because the file system is not supported.",
            FVE::FVE_E_BAD_PARTITION_SIZE => "The file system size is larger than the partition size in the partition table. This drive may be corrupt or may have been tampered with. To use it with BitLocker, you must reformat the partition.",
            FVE::FVE_E_FAILED_BAD_FS => "The file system is inconsistent. Run CHKDSK.",
            FVE::FVE_E_NOT_SUPPORTED => "This drive cannot be encrypted.",
            FVE::FVE_E_BAD_DATA => "The data is not valid.",
            FVE::FVE_E_VOLUME_NOT_BOUND => "The data drive specified is not set to automatically unlock on the current computer and cannot be unlocked automatically.",
            FVE::FVE_E_TPM_NOT_OWNED => "You must initialize the Trusted Platform Module (TPM) before you can use BitLocker Drive Encryption.",
            FVE::FVE_E_NOT_DATA_VOLUME => "The operation attempted cannot be performed on an operating system drive.",
            FVE::FVE_E_AD_INSUFFICIENT_BUFFER => "The buffer supplied to a function was insufficient to contain the returned data. Increase the buffer size before running the function again.",
            FVE::FVE_E_CONV_READ => "A read operation failed while converting the drive. The drive was not converted. Please re-enable BitLocker.",
            FVE::FVE_E_CONV_WRITE => "A write operation failed while converting the drive. The drive was not converted. Please re-enable BitLocker.",
            FVE::FVE_E_KEY_REQUIRED => "One or more BitLocker key protectors are required. You cannot delete the last key on this drive.",
            FVE::FVE_E_CLUSTERING_NOT_SUPPORTED => "Cluster configurations are not supported by BitLocker Drive Encryption.",
            FVE::FVE_E_VOLUME_BOUND_ALREADY => "The drive specified is already configured to be automatically unlocked on the current computer.",
            FVE::FVE_E_OS_NOT_PROTECTED => "The operating system drive is not protected by BitLocker Drive Encryption.",
            FVE::FVE_E_PROTECTION_DISABLED => "BitLocker Drive Encryption has been suspended on this drive. All BitLocker key protectors configured for this drive are effectively disabled, and the drive will be automatically unlocked using an unencrypted (clear) key.",
            FVE::FVE_E_RECOVERY_KEY_REQUIRED => "The drive you are attempting to lock does not have any key protectors available for encryption because BitLocker protection is currently suspended. Re-enable BitLocker to lock this drive.",
            FVE::FVE_E_FOREIGN_VOLUME => "BitLocker cannot use the Trusted Platform Module (TPM) to protect a data drive. TPM protection can only be used with the operating system drive.",
            FVE::FVE_E_OVERLAPPED_UPDATE => "The BitLocker metadata for the encrypted drive cannot be updated because it was locked for updating by another process. Please try this process again.",
            FVE::FVE_E_TPM_SRK_AUTH_NOT_ZERO => "The authorization data for the storage root key (SRK) of the Trusted Platform Module (TPM) is not zero and is therefore incompatible with BitLocker. Please initialize the TPM before attempting to use it with BitLocker.",
            FVE::FVE_E_FAILED_SECTOR_SIZE => "The drive encryption algorithm cannot be used on this sector size.",
            FVE::FVE_E_FAILED_AUTHENTICATION => "The drive cannot be unlocked with the key provided. Confirm that you have provided the correct key and try again.",
            FVE::FVE_E_NOT_OS_VOLUME => "The drive specified is not the operating system drive.",
            FVE::FVE_E_AUTOUNLOCK_ENABLED => "BitLocker Drive Encryption cannot be turned off on the operating system drive until the auto unlock feature has been disabled for the fixed data drives and removable data drives associated with this computer.",
            FVE::FVE_E_WRONG_BOOTSECTOR => "The system partition boot sector does not perform Trusted Platform Module (TPM) measurements. Use the Bootrec.exe tool in the Windows Recovery Environment to update or repair the boot sector.",
            FVE::FVE_E_WRONG_SYSTEM_FS => "BitLocker Drive Encryption operating system drives must be formatted with the NTFS file system in order to be encrypted. Convert the drive to NTFS, and then turn on BitLocker.",
            FVE::FVE_E_POLICY_PASSWORD_REQUIRED => "Group Policy settings require that a recovery password be specified before encrypting the drive.",
            FVE::FVE_E_CANNOT_SET_FVEK_ENCRYPTED => "The drive encryption algorithm and key cannot be set on a previously encrypted drive. To encrypt this drive with BitLocker Drive Encryption, remove the previous encryption and then turn on BitLocker.",
            FVE::FVE_E_CANNOT_ENCRYPT_NO_KEY => "BitLocker Drive Encryption cannot encrypt the specified drive because an encryption key is not available. Add a key protector to encrypt this drive.",
            FVE::FVE_E_BOOTABLE_CDDVD => "BitLocker Drive Encryption detected bootable media (CD or DVD) in the computer. Remove the media and restart the computer before configuring BitLocker.",
            FVE::FVE_E_PROTECTOR_EXISTS => "This key protector cannot be added. Only one key protector of this type is allowed for this drive.",
            FVE::FVE_E_RELATIVE_PATH => "The recovery password file was not found because a relative path was specified. Recovery passwords must be saved to a fully qualified path. Environment variables configured on the computer can be used in the path.",
            FVE::FVE_E_PROTECTOR_NOT_FOUND => "The specified key protector was not found on the drive. Try another key protector.",
            FVE::FVE_E_INVALID_KEY_FORMAT => "The recovery key provided is corrupt and cannot be used to access the drive. An alternative recovery method, such as recovery password, a data recovery agent, or a backup version of the recovery key must be used to recover access to the drive.",
            FVE::FVE_E_INVALID_PASSWORD_FORMAT => "The format of the recovery password provided is invalid. BitLocker recovery passwords are 48 digits. Verify that the recovery password is in the correct format and then try again.",
            FVE::FVE_E_FIPS_RNG_CHECK_FAILED => "The random number generator check test failed.",
            FVE::FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD => "The Group Policy setting requiring FIPS compliance prevents a local recovery password from being generated or used by BitLocker Drive Encryption. When operating in FIPS-compliant mode, BitLocker recovery options can be either a recovery key stored on a USB drive or recovery through a data recovery agent.",
            FVE::FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT => "The Group Policy setting requiring FIPS compliance prevents the recovery password from being saved to Active Directory. When operating in FIPS-compliant mode, BitLocker recovery options can be either a recovery key stored on a USB drive or recovery through a data recovery agent. Check your Group Policy settings configuration.",
            FVE::FVE_E_NOT_DECRYPTED => "The drive must be fully decrypted to complete this operation.",
            FVE::FVE_E_INVALID_PROTECTOR_TYPE => "The key protector specified cannot be used for this operation.",
            FVE::FVE_E_NO_PROTECTORS_TO_TEST => "No key protectors exist on the drive to perform the hardware test.",
            FVE::FVE_E_KEYFILE_NOT_FOUND => "The BitLocker startup key or recovery password cannot be found on the USB device. Verify that you have the correct USB device, that the USB device is plugged into the computer on an active USB port, restart the computer, and then try again. If the problem persists, contact the computer manufacturer for BIOS upgrade instructions.",
            FVE::FVE_E_KEYFILE_INVALID => "The BitLocker startup key or recovery password file provided is corrupt or invalid. Verify that you have the correct startup key or recovery password file and try again.",
            FVE::FVE_E_KEYFILE_NO_VMK => "The BitLocker encryption key cannot be obtained from the startup key or recovery password. Verify that you have the correct startup key or recovery password and try again.",
            FVE::FVE_E_TPM_DISABLED => "The Trusted Platform Module (TPM) is disabled. The TPM must be enabled, initialized, and have valid ownership before it can be used with BitLocker Drive Encryption.",
            FVE::FVE_E_NOT_ALLOWED_IN_SAFE_MODE => "The BitLocker configuration of the specified drive cannot be managed because this computer is currently operating in Safe Mode. While in Safe Mode, BitLocker Drive Encryption can only be used for recovery purposes.",
            FVE::FVE_E_TPM_INVALID_PCR => "The Trusted Platform Module (TPM) was unable to unlock the drive. Either the system boot information changed after choosing BitLocker settings or the PIN did not match. If the problem persists after several tries, there may be a hardware or firmware problem.",
            FVE::FVE_E_TPM_NO_VMK => "The BitLocker encryption key cannot be obtained from the Trusted Platform Module (TPM).",
            FVE::FVE_E_PIN_INVALID => "The BitLocker encryption key cannot be obtained from the Trusted Platform Module (TPM) and PIN.",
            FVE::FVE_E_AUTH_INVALID_APPLICATION => "A boot application has changed since BitLocker Drive Encryption was enabled.",
            FVE::FVE_E_AUTH_INVALID_CONFIG => "The Boot Configuration Data (BCD) settings have changed since BitLocker Drive Encryption was enabled.",
            FVE::FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED => "The Group Policy setting requiring FIPS compliance prohibits the use of unencrypted keys, which prevents BitLocker from being suspended on this drive. Please contact your domain administrator for more information.",
            FVE::FVE_E_FS_NOT_EXTENDED => "This drive cannot be encrypted by BitLocker Drive Encryption because the file system does not extend to the end of the drive. Repartition this drive and then try again.",
            FVE::FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED => "BitLocker Drive Encryption cannot be enabled on the operating system drive. Contact the computer manufacturer for BIOS upgrade instructions.",
            FVE::FVE_E_NO_LICENSE => "This version of Windows does not include BitLocker Drive Encryption. To use BitLocker Drive Encryption, please upgrade the operating system.",
            FVE::FVE_E_NOT_ON_STACK => "BitLocker Drive Encryption cannot be used because critical BitLocker system files are missing or corrupted. Use Windows Startup Repair to restore these files to your computer.",
            FVE::FVE_E_FS_MOUNTED => "The drive cannot be locked when the drive is in use.",
            FVE::FVE_E_TOKEN_NOT_IMPERSONATED => "The access token associated with the current thread is not an impersonated token.",
            FVE::FVE_E_DRY_RUN_FAILED => "The BitLocker encryption key cannot be obtained. Verify that the Trusted Platform Module (TPM) is enabled and ownership has been taken. If this computer does not have a TPM, verify that the USB drive is inserted and available.",
            FVE::FVE_E_REBOOT_REQUIRED => "You must restart your computer before continuing with BitLocker Drive Encryption.",
            FVE::FVE_E_DEBUGGER_ENABLED => "Drive encryption cannot occur while boot debugging is enabled. Use the bcdedit command-line tool to turn off boot debugging.",
            FVE::FVE_E_RAW_ACCESS => "No action was taken as BitLocker Drive Encryption is in raw access mode.",
            FVE::FVE_E_RAW_BLOCKED => "BitLocker Drive Encryption cannot enter raw access mode for this drive because the drive is currently in use.",
            FVE::FVE_E_BCD_APPLICATIONS_PATH_INCORRECT => "The path specified in the Boot Configuration Data (BCD) for a BitLocker Drive Encryption integrity-protected application is incorrect. Please verify and correct your BCD settings and try again.",
            FVE::FVE_E_NOT_ALLOWED_IN_VERSION => "BitLocker Drive Encryption can only be used for limited provisioning or recovery purposes when the computer is running in pre-installation or recovery environments.",
            FVE::FVE_E_NO_AUTOUNLOCK_MASTER_KEY => "The auto-unlock master key was not available from the operating system drive.",
            FVE::FVE_E_MOR_FAILED => "The system firmware failed to enable clearing of system memory when the computer was restarted.",
            FVE::FVE_E_HIDDEN_VOLUME => "The hidden drive cannot be encrypted.",
            FVE::FVE_E_TRANSIENT_STATE => "BitLocker encryption keys were ignored because the drive was in a transient state.",
            FVE::FVE_E_PUBKEY_NOT_ALLOWED => "Public key based protectors are not allowed on this drive.",
            FVE::FVE_E_VOLUME_HANDLE_OPEN => "BitLocker Drive Encryption is already performing an operation on this drive. Please complete all operations before continuing.",
            FVE::FVE_E_NO_FEATURE_LICENSE => "This version of Windows does not support this feature of BitLocker Drive Encryption. To use this feature, upgrade the operating system.",
            FVE::FVE_E_INVALID_STARTUP_OPTIONS => "The Group Policy settings for BitLocker startup options are in conflict and cannot be applied. Contact your system administrator for more information.",
            FVE::FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED => "Group Policy settings do not permit the creation of a recovery password.",
            FVE::FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED => "Group Policy settings require the creation of a recovery password.",
            FVE::FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED => "Group Policy settings do not permit the creation of a recovery key.",
            FVE::FVE_E_POLICY_RECOVERY_KEY_REQUIRED => "Group Policy settings require the creation of a recovery key.",
            FVE::FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED => "Group Policy settings do not permit the use of a PIN at startup. Please choose a different BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_PIN_REQUIRED => "Group Policy settings require the use of a PIN at startup. Please choose this BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED => "Group Policy settings do not permit the use of a startup key. Please choose a different BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_KEY_REQUIRED => "Group Policy settings require the use of a startup key. Please choose this BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED => "Group Policy settings do not permit the use of a startup key and PIN. Please choose a different BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED => "Group Policy settings require the use of a startup key and PIN. Please choose this BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED => "Group policy does not permit the use of TPM-only at startup. Please choose a different BitLocker startup option.",
            FVE::FVE_E_POLICY_STARTUP_TPM_REQUIRED => "Group Policy settings require the use of TPM-only at startup. Please choose this BitLocker startup option.",
            FVE::FVE_E_POLICY_INVALID_PIN_LENGTH => "The PIN provided does not meet minimum or maximum length requirements.",
            FVE::FVE_E_KEY_PROTECTOR_NOT_SUPPORTED => "The key protector is not supported by the version of BitLocker Drive Encryption currently on the drive. Upgrade the drive to add the key protector.",
            FVE::FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED => "Group Policy settings do not permit the creation of a password.",
            FVE::FVE_E_POLICY_PASSPHRASE_REQUIRED => "Group Policy settings require the creation of a password.",
            FVE::FVE_E_FIPS_PREVENTS_PASSPHRASE => "The Group Policy setting requiring FIPS compliance prevents passwords from being generated or used. Please contact your system administrator for more information.",
            FVE::FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED => "A password cannot be added to the operating system drive.",
            FVE::FVE_E_INVALID_BITLOCKER_OID => "The BitLocker object identifier (OID) on the drive appears to be invalid or corrupt. Use manage-BDE to reset the OID on this drive.",
            FVE::FVE_E_VOLUME_TOO_SMALL => "The drive is too small to be protected using BitLocker Drive Encryption.",
            FVE::FVE_E_DV_NOT_SUPPORTED_ON_FS => "The selected discovery drive type is incompatible with the file system on the drive. BitLocker To Go discovery drives must be created on FAT formatted drives.",
            FVE::FVE_E_DV_NOT_ALLOWED_BY_GP => "The selected discovery drive type is not allowed by the computer's Group Policy settings. Verify that Group Policy settings allow the creation of discovery drives for use with BitLocker To Go.",
            FVE::FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED => "Group Policy settings do not permit user certificates such as smart cards to be used with BitLocker Drive Encryption.",
            FVE::FVE_E_POLICY_USER_CERTIFICATE_REQUIRED => "Group Policy settings require that you have a valid user certificate, such as a smart card, to be used with BitLocker Drive Encryption.",
            FVE::FVE_E_POLICY_USER_CERT_MUST_BE_HW => "Group Policy settings requires that you use a smart card-based key protector with BitLocker Drive Encryption.",
            FVE::FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED => "Group Policy settings do not permit BitLocker-protected fixed data drives to be automatically unlocked.",
            FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED => "Group Policy settings do not permit BitLocker-protected removable data drives to be automatically unlocked.",
            FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED => "Group Policy settings do not permit you to configure BitLocker Drive Encryption on removable data drives.",
            FVE::FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED => "Group Policy settings do not permit you to turn on BitLocker Drive Encryption on removable data drives. Please contact your system administrator if you need to turn on BitLocker.",
            FVE::FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED => "Group Policy settings do not permit turning off BitLocker Drive Encryption on removable data drives. Please contact your system administrator if you need to turn off BitLocker.",
            FVE::FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH => "Your password does not meet minimum password length requirements. By default, passwords must be at least 8 characters in length. Check with your system administrator for the password length requirement in your organization.",
            FVE::FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE => "Your password does not meet the complexity requirements set by your system administrator. Try adding upper and lowercase characters, numbers, and symbols.",
            FVE::FVE_E_RECOVERY_PARTITION => "This drive cannot be encrypted because it is reserved for Windows System Recovery Options.",
            FVE::FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON => "BitLocker Drive Encryption cannot be applied to this drive because of conflicting Group Policy settings. BitLocker cannot be configured to automatically unlock fixed data drives when user recovery options are disabled. If you want BitLocker-protected fixed data drives to be automatically unlocked after key validation has occurred, please ask your system administrator to resolve the settings conflict before enabling BitLocker.",
            FVE::FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON => "BitLocker Drive Encryption cannot be applied to this drive because of conflicting Group Policy settings. BitLocker cannot be configured to automatically unlock removable data drives when user recovery option are disabled. If you want BitLocker-protected removable data drives to be automatically unlocked after key validation has occurred, please ask your system administrator to resolve the settings conflict before enabling BitLocker.",
            FVE::FVE_E_NON_BITLOCKER_OID => "The Enhanced Key Usage (EKU) attribute of the specified certificate does not permit it to be used for BitLocker Drive Encryption. BitLocker does not require that a certificate have an EKU attribute, but if one is configured it must be set to an object identifier (OID) that matches the OID configured for BitLocker.",
            FVE::FVE_E_POLICY_PROHIBITS_SELFSIGNED => "BitLocker Drive Encryption cannot be applied to this drive as currently configured because of Group Policy settings. The certificate you provided for drive encryption is self-signed. Current Group Policy settings do not permit the use of self-signed certificates. Obtain a new certificate from your certification authority before attempting to enable BitLocker.",
            FVE::FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED => "BitLocker Encryption cannot be applied to this drive because of conflicting Group Policy settings. When write access to drives not protected by BitLocker is denied, the use of a USB startup key cannot be required. Please have your system administrator resolve these policy conflicts before attempting to enable BitLocker.",
            FVE::FVE_E_CONV_RECOVERY_FAILED => "BitLocker Drive Encryption failed to recover from an abruptly terminated conversion. This could be due to either all conversion logs being corrupted or the media being write-protected.",
            FVE::FVE_E_VIRTUALIZED_SPACE_TOO_BIG => "The requested virtualization size is too big.",
            FVE::FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON => "BitLocker Drive Encryption cannot be applied to this drive because there are conflicting Group Policy settings for recovery options on operating system drives. Storing recovery information to Active Directory Domain Services cannot be required when the generation of recovery passwords is not permitted. Please have your system administrator resolve these policy conflicts before attempting to enable BitLocker.",
            FVE::FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON => "BitLocker Drive Encryption cannot be applied to this drive because there are conflicting Group Policy settings for recovery options on fixed data drives. Storing recovery information to Active Directory Domain Services cannot be required when the generation of recovery passwords is not permitted. Please have your system administrator resolve these policy conflicts before attempting to enable BitLocker.",
            FVE::FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON => "BitLocker Drive Encryption cannot be applied to this drive because there are conflicting Group Policy settings for recovery options on removable data drives. Storing recovery information to Active Directory Domain Services cannot be required when the generation of recovery passwords is not permitted. Please have your system administrator resolve these policy conflicts before attempting to enable BitLocker.",
            FVE::FVE_E_NON_BITLOCKER_KU => "The Key Usage (KU) attribute of the specified certificate does not permit it to be used for BitLocker Drive Encryption. BitLocker does not require that a certificate have a KU attribute, but if one is configured it must be set to either Key Encipherment or Key Agreement.",
            FVE::FVE_E_PRIVATEKEY_AUTH_FAILED => "The private key associated with the specified certificate cannot be authorized. The private key authorization was either not provided or the provided authorization was invalid.",
            FVE::FVE_E_REMOVAL_OF_DRA_FAILED => "Removal of the data recovery agent certificate must be done using the Certificates snap-in.",
            FVE::FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME => "This drive was encrypted using the version of BitLocker Drive Encryption included with Windows Vista and Windows Server 2008 which does not support organizational identifiers. To specify organizational identifiers for this drive upgrade the drive encryption to the latest version using the ",
            FVE::FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME => "The drive cannot be locked because it is automatically unlocked on this computer. Remove the automatic unlock protector to lock this drive.",
            FVE::FVE_E_FIPS_HASH_KDF_NOT_ALLOWED => "The default BitLocker Key Derivation Function SP800-56A for ECC smart cards is not supported by your smart card. The Group Policy setting requiring FIPS-compliance prevents BitLocker from using any other key derivation function for encryption. You have to use a FIPS compliant smart card in FIPS restricted environments.",
            FVE::FVE_E_ENH_PIN_INVALID => "The BitLocker encryption key could not be obtained from the Trusted Platform Module (TPM) and enhanced PIN. Try using a PIN containing only numerals.",
            FVE::FVE_E_INVALID_PIN_CHARS => "The requested TPM PIN contains invalid characters.",
            FVE::FVE_E_INVALID_DATUM_TYPE => "The management information stored on the drive contained an unknown type. If you are using an old version of Windows, try accessing the drive from the latest version.",
            FVE::FVE_E_EFI_ONLY => "The feature is only supported on EFI systems.",
            FVE::FVE_E_MULTIPLE_NKP_CERTS => "More than one Network Key Protector certificate has been found on the system.",
            FVE::FVE_E_REMOVAL_OF_NKP_FAILED => "Removal of the Network Key Protector certificate must be done using the Certificates snap-in.",
            FVE::FVE_E_INVALID_NKP_CERT => "An invalid certificate has been found in the Network Key Protector certificate store.",
            FVE::FVE_E_NO_EXISTING_PIN => "This drive isn't protected with a PIN.",
            FVE::FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH => "Please enter the correct current PIN.",
            FVE::FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED => "You must be logged on with an administrator account to change the PIN. Click the link to reset the PIN as an administrator.",
            FVE::FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED => "BitLocker has disabled PIN changes after too many failed requests. Click the link to reset the PIN as an administrator.",
            FVE::FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII => "Your system administrator requires that passwords contain only printable ASCII characters. This includes unaccented letters (A-Z, a-z), numbers (0-9), space, arithmetic signs, common punctuation, separators, and the following symbols: # $ & @ ^ _ ~ .",
            FVE::FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE => "BitLocker Drive Encryption only supports Used Space Only encryption on thin provisioned storage.",
            FVE::FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE => "BitLocker Drive Encryption does not support wiping free space on thin provisioned storage.",
            FVE::FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE => "The required authentication key length is not supported by the drive.",
            FVE::FVE_E_NO_EXISTING_PASSPHRASE => "This drive isn't protected with a password.",
            FVE::FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH => "Please enter the correct current password.",
            FVE::FVE_E_PASSPHRASE_TOO_LONG => "The password cannot exceed 256 characters.",
            FVE::FVE_E_NO_PASSPHRASE_WITH_TPM => "A password key protector cannot be added because a TPM protector exists on the drive.",
            FVE::FVE_E_NO_TPM_WITH_PASSPHRASE => "A TPM key protector cannot be added because a password protector exists on the drive.",
            FVE::FVE_E_NOT_ALLOWED_ON_CSV_STACK => "This command can only be performed from the coordinator node for the specified CSV volume.",
            FVE::FVE_E_NOT_ALLOWED_ON_CLUSTER => "This command cannot be performed on a volume when it is part of a cluster.",
            FVE::FVE_E_EDRIVE_NO_FAILOVER_TO_SW => "BitLocker did not revert to using BitLocker software encryption due to group policy configuration.",
            FVE::FVE_E_EDRIVE_BAND_IN_USE => "The drive cannot be managed by BitLocker because the drive's hardware encryption feature is already in use.",
            FVE::FVE_E_EDRIVE_DISALLOWED_BY_GP => "Group Policy settings do not allow the use of hardware-based encryption.",
            FVE::FVE_E_EDRIVE_INCOMPATIBLE_VOLUME => "The drive specified does not support hardware-based encryption.",
            FVE::FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING => "BitLocker cannot be upgraded during disk encryption or decryption.",
            FVE::FVE_E_EDRIVE_DV_NOT_SUPPORTED => "Discovery Volumes are not supported for volumes using hardware encryption.",
            FVE::FVE_E_NO_PREBOOT_KEYBOARD_DETECTED => "No pre-boot keyboard detected. The user may not be able to provide required input to unlock the volume.",
            FVE::FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED => "No pre-boot keyboard or Windows Recovery Environment detected. The user may not be able to provide required input to unlock the volume.",
            FVE::FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE => "Group Policy settings require the creation of a startup PIN, but a pre-boot keyboard is not available on this device. The user may not be able to provide required input to unlock the volume.",
            FVE::FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE => "Group Policy settings require the creation of a recovery password, but neither a pre-boot keyboard nor Windows Recovery Environment is available on this device. The user may not be able to provide required input to unlock the volume.",
            FVE::FVE_E_WIPE_CANCEL_NOT_APPLICABLE => "Wipe of free space is not currently taking place.",
            FVE::FVE_E_SECUREBOOT_DISABLED => "BitLocker cannot use Secure Boot for platform integrity because Secure Boot has been disabled.",
            FVE::FVE_E_SECUREBOOT_CONFIGURATION_INVALID => "BitLocker cannot use Secure Boot for platform integrity because the Secure Boot configuration does not meet the requirements for BitLocker.",
            FVE::FVE_E_EDRIVE_DRY_RUN_FAILED => "Your computer doesn't support BitLocker hardware-based encryption. Check with your computer manufacturer for firmware updates.",
            FVE::FVE_E_SHADOW_COPY_PRESENT => "BitLocker cannot be enabled on the volume because it contains a Volume Shadow Copy. Remove all Volume Shadow Copies before encrypting the volume.",
            FVE::FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS => "BitLocker Drive Encryption cannot be applied to this drive because the Group Policy setting for Enhanced Boot Configuration Data contains invalid data. Please have your system administrator resolve this invalid configuration before attempting to enable BitLocker.",
            FVE::FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE => "This PC's firmware is not capable of supporting hardware encryption.",
            FVE::FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED => "BitLocker has disabled password changes after too many failed requests. Click the link to reset the password as an administrator.",
            FVE::FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED => "You must be logged on with an administrator account to change the password. Click the link to reset the password as an administrator.",
            FVE::FVE_E_LIVEID_ACCOUNT_SUSPENDED => "BitLocker cannot save the recovery password because the specified Microsoft account is Suspended.",
            FVE::FVE_E_LIVEID_ACCOUNT_BLOCKED => "BitLocker cannot save the recovery password because the specified Microsoft account is Blocked.",
            FVE::FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES => "This PC is not provisioned to support device encryption. Please enable BitLocker on all volumes to comply with device encryption policy.",
            FVE::FVE_E_DE_FIXED_DATA_NOT_SUPPORTED => "This PC cannot support device encryption because unencrypted fixed data volumes are present.",
            FVE::FVE_E_DE_HARDWARE_NOT_COMPLIANT => "This PC does not meet the hardware requirements to support device encryption.",
            FVE::FVE_E_DE_WINRE_NOT_CONFIGURED => "This PC cannot support device encryption because WinRE is not properly configured.",
            FVE::FVE_E_DE_PROTECTION_SUSPENDED => "Protection is enabled on the volume but has been suspended. This is likely to have happened due to an update being applied to your system. Please try again after a reboot.",
            FVE::FVE_E_DE_OS_VOLUME_NOT_PROTECTED => "This PC is not provisioned to support device encryption.",
            FVE::FVE_E_DE_DEVICE_LOCKEDOUT => "Device Lock has been triggered due to too many incorrect password attempts.",
            FVE::FVE_E_DE_PROTECTION_NOT_YET_ENABLED => "Protection has not been enabled on the volume. Enabling protection requires a connected account. If you already have a connected account and are seeing this error, please refer to the event log for more information.",
            FVE::FVE_E_INVALID_PIN_CHARS_DETAILED => "Your PIN can only contain numbers from 0 to 9.",
            FVE::FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE => "BitLocker cannot use hardware replay protection because no counter is available on your PC.",
            FVE::FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH => "Device Lockout state validation failed due to counter mismatch.",
            FVE::FVE_E_BUFFER_TOO_LARGE => "The input buffer is too large.",
            FVE::FVE_E_NO_SUCH_CAPABILITY_ON_TARGET => "The target of an invocation does not support requested capability.",
            FVE::FVE_E_DE_PREVENTED_FOR_OS => "Device encryption is currently blocked by this PC's configuration.",
            FVE::FVE_E_DE_VOLUME_OPTED_OUT => "This drive has been opted out of device encryption.",
            FVE::FVE_E_DE_VOLUME_NOT_SUPPORTED => "Device encryption isn't available for this drive.",
            FVE::FVE_E_EOW_NOT_SUPPORTED_IN_VERSION => "The encrypt on write mode for BitLocker is not supported in this version of Windows. You can turn on BitLocker without using the encrypt on write mode.",
            FVE::FVE_E_ADBACKUP_NOT_ENABLED => "Group policy prevents you from backing up your recovery password to Active Directory for this drive type. For more info, contact your system administrator.",
            FVE::FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT => "Device encryption can't be turned off while this drive is being encrypted. Please try again later.",
            FVE::FVE_E_NOT_DE_VOLUME => "This action isn't supported because this drive isn't automatically managed with device encryption.",
            FVE::FVE_E_PROTECTION_CANNOT_BE_DISABLED => "BitLocker can't be suspended on this drive until the next restart.",
            FVE::FVE_E_OSV_KSR_NOT_ALLOWED => "BitLocker Drive Encryption policy does not allow KSR operation with protected OS volume.",
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE => "BitLocker recovery password rotation cannot be performed because backup policy for BitLocker recovery information is not set to required for the OS drive.",
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE => "BitLocker recovery password rotation cannot be performed because backup policy for BitLocker recovery information is not set to required for fixed data drives.",
            FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE => "BitLocker recovery password rotation cannot be performed because backup policy for BitLocker recovery information is not set to required for removable data drives",
            FVE::FVE_E_KEY_ROTATION_NOT_SUPPORTED => "BitLocker recovery password rotation not supported.",
            FVE::FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON => "A server issued BitLocker recovery password rotation was denied because requests must be 15 minutes apart.",
            FVE::FVE_E_KEY_ROTATION_NOT_ENABLED => "BitLocker recovery password key rotation policy is not enabled.",
            FVE::FVE_E_DEVICE_NOT_JOINED => "BitLocker recovery password key rotation could not be performed because the device is neither Azure AD joined nor Hybrid Azure AD joined.",
            FVE::FVE_E_AAD_ENDPOINT_BUSY => "BitLocker recovery key backup endpoint is busy and cannot perform requested operation. Please retry after sometime.",
            FVE::FVE_E_INVALID_NBP_CERT => "An invalid certificate has been found in the Network Boot Protector certificate store.",
            FVE::FVE_E_EDRIVE_BAND_ENUMERATION_FAILED => "BitLocker can't enable encryption on this hardware encrypting drive volume because the drive bands couldn't be enumerated.",
            FVE::FVE_E_POLICY_ON_RDV_EXCLUSION_LIST => "This removable data drive has been excluded from device encryption by BitLocker Drive Encryption policy.",
            FVE::FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED => "Adding BitLocker predicted TPM based protector is not supported.",
            FVE::FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED => "Registeration for TPM callback is not supported.",
            FVE::FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED => "Creating new TPM context is not supported.",
            FVE::FVE_E_UPDATE_INVALID_CONFIG => "The Secure Boot update was not applied due to a known incompatibility with the current BitLocker configuration.",
            FVE::FVE_E_AAD_SERVER_FAIL_RETRY_AFTER => "The AAD request has failed and it has been advised to backoff to prevent throttling. Device will retry soon.",
            FVE::FVE_E_AAD_SERVER_FAIL_BACKOFF => "The AAD request has failed due to server issues and it has been advised to backoff to prevent throttling. Device will retry soon.",
            FVE::FVE_E_DATASET_FULL => "This operation cannot be completed because dataset is full.",
            FVE::FVE_E_METADATA_FULL => "This operation cannot be completed because BitLocker Drive Encryption metadata area is full. Consider removing unnecessary key protectors for this drive.",
        }
    }

    pub fn from_name(name: &str) -> FVE {
        return match name {
            "FVE_E_LOCKED_VOLUME" => FVE::FVE_E_LOCKED_VOLUME,
            "FVE_E_NOT_ENCRYPTED" => FVE::FVE_E_NOT_ENCRYPTED,
            "FVE_E_NO_TPM_BIOS" => FVE::FVE_E_NO_TPM_BIOS,
            "FVE_E_NO_MBR_METRIC" => FVE::FVE_E_NO_MBR_METRIC,
            "FVE_E_NO_BOOTSECTOR_METRIC" => FVE::FVE_E_NO_BOOTSECTOR_METRIC,
            "FVE_E_NO_BOOTMGR_METRIC" => FVE::FVE_E_NO_BOOTMGR_METRIC,
            "FVE_E_WRONG_BOOTMGR" => FVE::FVE_E_WRONG_BOOTMGR,
            "FVE_E_SECURE_KEY_REQUIRED" => FVE::FVE_E_SECURE_KEY_REQUIRED,
            "FVE_E_NOT_ACTIVATED" => FVE::FVE_E_NOT_ACTIVATED,
            "FVE_E_ACTION_NOT_ALLOWED" => FVE::FVE_E_ACTION_NOT_ALLOWED,
            "FVE_E_AD_SCHEMA_NOT_INSTALLED" => FVE::FVE_E_AD_SCHEMA_NOT_INSTALLED,
            "FVE_E_AD_INVALID_DATATYPE" => FVE::FVE_E_AD_INVALID_DATATYPE,
            "FVE_E_AD_INVALID_DATASIZE" => FVE::FVE_E_AD_INVALID_DATASIZE,
            "FVE_E_AD_NO_VALUES" => FVE::FVE_E_AD_NO_VALUES,
            "FVE_E_AD_ATTR_NOT_SET" => FVE::FVE_E_AD_ATTR_NOT_SET,
            "FVE_E_AD_GUID_NOT_FOUND" => FVE::FVE_E_AD_GUID_NOT_FOUND,
            "FVE_E_BAD_INFORMATION" => FVE::FVE_E_BAD_INFORMATION,
            "FVE_E_TOO_SMALL" => FVE::FVE_E_TOO_SMALL,
            "FVE_E_SYSTEM_VOLUME" => FVE::FVE_E_SYSTEM_VOLUME,
            "FVE_E_FAILED_WRONG_FS" => FVE::FVE_E_FAILED_WRONG_FS,
            "FVE_E_BAD_PARTITION_SIZE" => FVE::FVE_E_BAD_PARTITION_SIZE,
            "FVE_E_FAILED_BAD_FS" => FVE::FVE_E_FAILED_BAD_FS,
            "FVE_E_NOT_SUPPORTED" => FVE::FVE_E_NOT_SUPPORTED,
            "FVE_E_BAD_DATA" => FVE::FVE_E_BAD_DATA,
            "FVE_E_VOLUME_NOT_BOUND" => FVE::FVE_E_VOLUME_NOT_BOUND,
            "FVE_E_TPM_NOT_OWNED" => FVE::FVE_E_TPM_NOT_OWNED,
            "FVE_E_NOT_DATA_VOLUME" => FVE::FVE_E_NOT_DATA_VOLUME,
            "FVE_E_AD_INSUFFICIENT_BUFFER" => FVE::FVE_E_AD_INSUFFICIENT_BUFFER,
            "FVE_E_CONV_READ" => FVE::FVE_E_CONV_READ,
            "FVE_E_CONV_WRITE" => FVE::FVE_E_CONV_WRITE,
            "FVE_E_KEY_REQUIRED" => FVE::FVE_E_KEY_REQUIRED,
            "FVE_E_CLUSTERING_NOT_SUPPORTED" => FVE::FVE_E_CLUSTERING_NOT_SUPPORTED,
            "FVE_E_VOLUME_BOUND_ALREADY" => FVE::FVE_E_VOLUME_BOUND_ALREADY,
            "FVE_E_OS_NOT_PROTECTED" => FVE::FVE_E_OS_NOT_PROTECTED,
            "FVE_E_PROTECTION_DISABLED" => FVE::FVE_E_PROTECTION_DISABLED,
            "FVE_E_RECOVERY_KEY_REQUIRED" => FVE::FVE_E_RECOVERY_KEY_REQUIRED,
            "FVE_E_FOREIGN_VOLUME" => FVE::FVE_E_FOREIGN_VOLUME,
            "FVE_E_OVERLAPPED_UPDATE" => FVE::FVE_E_OVERLAPPED_UPDATE,
            "FVE_E_TPM_SRK_AUTH_NOT_ZERO" => FVE::FVE_E_TPM_SRK_AUTH_NOT_ZERO,
            "FVE_E_FAILED_SECTOR_SIZE" => FVE::FVE_E_FAILED_SECTOR_SIZE,
            "FVE_E_FAILED_AUTHENTICATION" => FVE::FVE_E_FAILED_AUTHENTICATION,
            "FVE_E_NOT_OS_VOLUME" => FVE::FVE_E_NOT_OS_VOLUME,
            "FVE_E_AUTOUNLOCK_ENABLED" => FVE::FVE_E_AUTOUNLOCK_ENABLED,
            "FVE_E_WRONG_BOOTSECTOR" => FVE::FVE_E_WRONG_BOOTSECTOR,
            "FVE_E_WRONG_SYSTEM_FS" => FVE::FVE_E_WRONG_SYSTEM_FS,
            "FVE_E_POLICY_PASSWORD_REQUIRED" => FVE::FVE_E_POLICY_PASSWORD_REQUIRED,
            "FVE_E_CANNOT_SET_FVEK_ENCRYPTED" => FVE::FVE_E_CANNOT_SET_FVEK_ENCRYPTED,
            "FVE_E_CANNOT_ENCRYPT_NO_KEY" => FVE::FVE_E_CANNOT_ENCRYPT_NO_KEY,
            "FVE_E_BOOTABLE_CDDVD" => FVE::FVE_E_BOOTABLE_CDDVD,
            "FVE_E_PROTECTOR_EXISTS" => FVE::FVE_E_PROTECTOR_EXISTS,
            "FVE_E_RELATIVE_PATH" => FVE::FVE_E_RELATIVE_PATH,
            "FVE_E_PROTECTOR_NOT_FOUND" => FVE::FVE_E_PROTECTOR_NOT_FOUND,
            "FVE_E_INVALID_KEY_FORMAT" => FVE::FVE_E_INVALID_KEY_FORMAT,
            "FVE_E_INVALID_PASSWORD_FORMAT" => FVE::FVE_E_INVALID_PASSWORD_FORMAT,
            "FVE_E_FIPS_RNG_CHECK_FAILED" => FVE::FVE_E_FIPS_RNG_CHECK_FAILED,
            "FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD" => FVE::FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD,
            "FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT" => FVE::FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT,
            "FVE_E_NOT_DECRYPTED" => FVE::FVE_E_NOT_DECRYPTED,
            "FVE_E_INVALID_PROTECTOR_TYPE" => FVE::FVE_E_INVALID_PROTECTOR_TYPE,
            "FVE_E_NO_PROTECTORS_TO_TEST" => FVE::FVE_E_NO_PROTECTORS_TO_TEST,
            "FVE_E_KEYFILE_NOT_FOUND" => FVE::FVE_E_KEYFILE_NOT_FOUND,
            "FVE_E_KEYFILE_INVALID" => FVE::FVE_E_KEYFILE_INVALID,
            "FVE_E_KEYFILE_NO_VMK" => FVE::FVE_E_KEYFILE_NO_VMK,
            "FVE_E_TPM_DISABLED" => FVE::FVE_E_TPM_DISABLED,
            "FVE_E_NOT_ALLOWED_IN_SAFE_MODE" => FVE::FVE_E_NOT_ALLOWED_IN_SAFE_MODE,
            "FVE_E_TPM_INVALID_PCR" => FVE::FVE_E_TPM_INVALID_PCR,
            "FVE_E_TPM_NO_VMK" => FVE::FVE_E_TPM_NO_VMK,
            "FVE_E_PIN_INVALID" => FVE::FVE_E_PIN_INVALID,
            "FVE_E_AUTH_INVALID_APPLICATION" => FVE::FVE_E_AUTH_INVALID_APPLICATION,
            "FVE_E_AUTH_INVALID_CONFIG" => FVE::FVE_E_AUTH_INVALID_CONFIG,
            "FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED" => FVE::FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED,
            "FVE_E_FS_NOT_EXTENDED" => FVE::FVE_E_FS_NOT_EXTENDED,
            "FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED" => FVE::FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED,
            "FVE_E_NO_LICENSE" => FVE::FVE_E_NO_LICENSE,
            "FVE_E_NOT_ON_STACK" => FVE::FVE_E_NOT_ON_STACK,
            "FVE_E_FS_MOUNTED" => FVE::FVE_E_FS_MOUNTED,
            "FVE_E_TOKEN_NOT_IMPERSONATED" => FVE::FVE_E_TOKEN_NOT_IMPERSONATED,
            "FVE_E_DRY_RUN_FAILED" => FVE::FVE_E_DRY_RUN_FAILED,
            "FVE_E_REBOOT_REQUIRED" => FVE::FVE_E_REBOOT_REQUIRED,
            "FVE_E_DEBUGGER_ENABLED" => FVE::FVE_E_DEBUGGER_ENABLED,
            "FVE_E_RAW_ACCESS" => FVE::FVE_E_RAW_ACCESS,
            "FVE_E_RAW_BLOCKED" => FVE::FVE_E_RAW_BLOCKED,
            "FVE_E_BCD_APPLICATIONS_PATH_INCORRECT" => FVE::FVE_E_BCD_APPLICATIONS_PATH_INCORRECT,
            "FVE_E_NOT_ALLOWED_IN_VERSION" => FVE::FVE_E_NOT_ALLOWED_IN_VERSION,
            "FVE_E_NO_AUTOUNLOCK_MASTER_KEY" => FVE::FVE_E_NO_AUTOUNLOCK_MASTER_KEY,
            "FVE_E_MOR_FAILED" => FVE::FVE_E_MOR_FAILED,
            "FVE_E_HIDDEN_VOLUME" => FVE::FVE_E_HIDDEN_VOLUME,
            "FVE_E_TRANSIENT_STATE" => FVE::FVE_E_TRANSIENT_STATE,
            "FVE_E_PUBKEY_NOT_ALLOWED" => FVE::FVE_E_PUBKEY_NOT_ALLOWED,
            "FVE_E_VOLUME_HANDLE_OPEN" => FVE::FVE_E_VOLUME_HANDLE_OPEN,
            "FVE_E_NO_FEATURE_LICENSE" => FVE::FVE_E_NO_FEATURE_LICENSE,
            "FVE_E_INVALID_STARTUP_OPTIONS" => FVE::FVE_E_INVALID_STARTUP_OPTIONS,
            "FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED" => FVE::FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED,
            "FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED" => FVE::FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED,
            "FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED" => FVE::FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED,
            "FVE_E_POLICY_RECOVERY_KEY_REQUIRED" => FVE::FVE_E_POLICY_RECOVERY_KEY_REQUIRED,
            "FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED" => FVE::FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED,
            "FVE_E_POLICY_STARTUP_PIN_REQUIRED" => FVE::FVE_E_POLICY_STARTUP_PIN_REQUIRED,
            "FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED" => FVE::FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED,
            "FVE_E_POLICY_STARTUP_KEY_REQUIRED" => FVE::FVE_E_POLICY_STARTUP_KEY_REQUIRED,
            "FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED" => FVE::FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED,
            "FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED" => FVE::FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED,
            "FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED" => FVE::FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED,
            "FVE_E_POLICY_STARTUP_TPM_REQUIRED" => FVE::FVE_E_POLICY_STARTUP_TPM_REQUIRED,
            "FVE_E_POLICY_INVALID_PIN_LENGTH" => FVE::FVE_E_POLICY_INVALID_PIN_LENGTH,
            "FVE_E_KEY_PROTECTOR_NOT_SUPPORTED" => FVE::FVE_E_KEY_PROTECTOR_NOT_SUPPORTED,
            "FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED" => FVE::FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED,
            "FVE_E_POLICY_PASSPHRASE_REQUIRED" => FVE::FVE_E_POLICY_PASSPHRASE_REQUIRED,
            "FVE_E_FIPS_PREVENTS_PASSPHRASE" => FVE::FVE_E_FIPS_PREVENTS_PASSPHRASE,
            "FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED" => FVE::FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED,
            "FVE_E_INVALID_BITLOCKER_OID" => FVE::FVE_E_INVALID_BITLOCKER_OID,
            "FVE_E_VOLUME_TOO_SMALL" => FVE::FVE_E_VOLUME_TOO_SMALL,
            "FVE_E_DV_NOT_SUPPORTED_ON_FS" => FVE::FVE_E_DV_NOT_SUPPORTED_ON_FS,
            "FVE_E_DV_NOT_ALLOWED_BY_GP" => FVE::FVE_E_DV_NOT_ALLOWED_BY_GP,
            "FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED" => FVE::FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED,
            "FVE_E_POLICY_USER_CERTIFICATE_REQUIRED" => FVE::FVE_E_POLICY_USER_CERTIFICATE_REQUIRED,
            "FVE_E_POLICY_USER_CERT_MUST_BE_HW" => FVE::FVE_E_POLICY_USER_CERT_MUST_BE_HW,
            "FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED" => FVE::FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED,
            "FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED" => FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED,
            "FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED" => FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED,
            "FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED" => FVE::FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED,
            "FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED" => FVE::FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED,
            "FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH" => FVE::FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH,
            "FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE" => FVE::FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE,
            "FVE_E_RECOVERY_PARTITION" => FVE::FVE_E_RECOVERY_PARTITION,
            "FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON" => FVE::FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON,
            "FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON" => FVE::FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON,
            "FVE_E_NON_BITLOCKER_OID" => FVE::FVE_E_NON_BITLOCKER_OID,
            "FVE_E_POLICY_PROHIBITS_SELFSIGNED" => FVE::FVE_E_POLICY_PROHIBITS_SELFSIGNED,
            "FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED" => FVE::FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED,
            "FVE_E_CONV_RECOVERY_FAILED" => FVE::FVE_E_CONV_RECOVERY_FAILED,
            "FVE_E_VIRTUALIZED_SPACE_TOO_BIG" => FVE::FVE_E_VIRTUALIZED_SPACE_TOO_BIG,
            "FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON" => FVE::FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON,
            "FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON" => FVE::FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON,
            "FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON" => FVE::FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON,
            "FVE_E_NON_BITLOCKER_KU" => FVE::FVE_E_NON_BITLOCKER_KU,
            "FVE_E_PRIVATEKEY_AUTH_FAILED" => FVE::FVE_E_PRIVATEKEY_AUTH_FAILED,
            "FVE_E_REMOVAL_OF_DRA_FAILED" => FVE::FVE_E_REMOVAL_OF_DRA_FAILED,
            "FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME" => FVE::FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME,
            "FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME" => FVE::FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME,
            "FVE_E_FIPS_HASH_KDF_NOT_ALLOWED" => FVE::FVE_E_FIPS_HASH_KDF_NOT_ALLOWED,
            "FVE_E_ENH_PIN_INVALID" => FVE::FVE_E_ENH_PIN_INVALID,
            "FVE_E_INVALID_PIN_CHARS" => FVE::FVE_E_INVALID_PIN_CHARS,
            "FVE_E_INVALID_DATUM_TYPE" => FVE::FVE_E_INVALID_DATUM_TYPE,
            "FVE_E_EFI_ONLY" => FVE::FVE_E_EFI_ONLY,
            "FVE_E_MULTIPLE_NKP_CERTS" => FVE::FVE_E_MULTIPLE_NKP_CERTS,
            "FVE_E_REMOVAL_OF_NKP_FAILED" => FVE::FVE_E_REMOVAL_OF_NKP_FAILED,
            "FVE_E_INVALID_NKP_CERT" => FVE::FVE_E_INVALID_NKP_CERT,
            "FVE_E_NO_EXISTING_PIN" => FVE::FVE_E_NO_EXISTING_PIN,
            "FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH" => FVE::FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH,
            "FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED" => FVE::FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED,
            "FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED" => FVE::FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED,
            "FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII" => FVE::FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII,
            "FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE" => FVE::FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE,
            "FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE" => FVE::FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE,
            "FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE" => FVE::FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE,
            "FVE_E_NO_EXISTING_PASSPHRASE" => FVE::FVE_E_NO_EXISTING_PASSPHRASE,
            "FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH" => FVE::FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH,
            "FVE_E_PASSPHRASE_TOO_LONG" => FVE::FVE_E_PASSPHRASE_TOO_LONG,
            "FVE_E_NO_PASSPHRASE_WITH_TPM" => FVE::FVE_E_NO_PASSPHRASE_WITH_TPM,
            "FVE_E_NO_TPM_WITH_PASSPHRASE" => FVE::FVE_E_NO_TPM_WITH_PASSPHRASE,
            "FVE_E_NOT_ALLOWED_ON_CSV_STACK" => FVE::FVE_E_NOT_ALLOWED_ON_CSV_STACK,
            "FVE_E_NOT_ALLOWED_ON_CLUSTER" => FVE::FVE_E_NOT_ALLOWED_ON_CLUSTER,
            "FVE_E_EDRIVE_NO_FAILOVER_TO_SW" => FVE::FVE_E_EDRIVE_NO_FAILOVER_TO_SW,
            "FVE_E_EDRIVE_BAND_IN_USE" => FVE::FVE_E_EDRIVE_BAND_IN_USE,
            "FVE_E_EDRIVE_DISALLOWED_BY_GP" => FVE::FVE_E_EDRIVE_DISALLOWED_BY_GP,
            "FVE_E_EDRIVE_INCOMPATIBLE_VOLUME" => FVE::FVE_E_EDRIVE_INCOMPATIBLE_VOLUME,
            "FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING" => FVE::FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING,
            "FVE_E_EDRIVE_DV_NOT_SUPPORTED" => FVE::FVE_E_EDRIVE_DV_NOT_SUPPORTED,
            "FVE_E_NO_PREBOOT_KEYBOARD_DETECTED" => FVE::FVE_E_NO_PREBOOT_KEYBOARD_DETECTED,
            "FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED" => FVE::FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED,
            "FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE" => FVE::FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE,
            "FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE" => FVE::FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE,
            "FVE_E_WIPE_CANCEL_NOT_APPLICABLE" => FVE::FVE_E_WIPE_CANCEL_NOT_APPLICABLE,
            "FVE_E_SECUREBOOT_DISABLED" => FVE::FVE_E_SECUREBOOT_DISABLED,
            "FVE_E_SECUREBOOT_CONFIGURATION_INVALID" => FVE::FVE_E_SECUREBOOT_CONFIGURATION_INVALID,
            "FVE_E_EDRIVE_DRY_RUN_FAILED" => FVE::FVE_E_EDRIVE_DRY_RUN_FAILED,
            "FVE_E_SHADOW_COPY_PRESENT" => FVE::FVE_E_SHADOW_COPY_PRESENT,
            "FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS" => FVE::FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS,
            "FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE" => FVE::FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE,
            "FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED" => FVE::FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED,
            "FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED" => FVE::FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED,
            "FVE_E_LIVEID_ACCOUNT_SUSPENDED" => FVE::FVE_E_LIVEID_ACCOUNT_SUSPENDED,
            "FVE_E_LIVEID_ACCOUNT_BLOCKED" => FVE::FVE_E_LIVEID_ACCOUNT_BLOCKED,
            "FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES" => FVE::FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES,
            "FVE_E_DE_FIXED_DATA_NOT_SUPPORTED" => FVE::FVE_E_DE_FIXED_DATA_NOT_SUPPORTED,
            "FVE_E_DE_HARDWARE_NOT_COMPLIANT" => FVE::FVE_E_DE_HARDWARE_NOT_COMPLIANT,
            "FVE_E_DE_WINRE_NOT_CONFIGURED" => FVE::FVE_E_DE_WINRE_NOT_CONFIGURED,
            "FVE_E_DE_PROTECTION_SUSPENDED" => FVE::FVE_E_DE_PROTECTION_SUSPENDED,
            "FVE_E_DE_OS_VOLUME_NOT_PROTECTED" => FVE::FVE_E_DE_OS_VOLUME_NOT_PROTECTED,
            "FVE_E_DE_DEVICE_LOCKEDOUT" => FVE::FVE_E_DE_DEVICE_LOCKEDOUT,
            "FVE_E_DE_PROTECTION_NOT_YET_ENABLED" => FVE::FVE_E_DE_PROTECTION_NOT_YET_ENABLED,
            "FVE_E_INVALID_PIN_CHARS_DETAILED" => FVE::FVE_E_INVALID_PIN_CHARS_DETAILED,
            "FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE" => FVE::FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE,
            "FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH" => FVE::FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH,
            "FVE_E_BUFFER_TOO_LARGE" => FVE::FVE_E_BUFFER_TOO_LARGE,
            "FVE_E_NO_SUCH_CAPABILITY_ON_TARGET" => FVE::FVE_E_NO_SUCH_CAPABILITY_ON_TARGET,
            "FVE_E_DE_PREVENTED_FOR_OS" => FVE::FVE_E_DE_PREVENTED_FOR_OS,
            "FVE_E_DE_VOLUME_OPTED_OUT" => FVE::FVE_E_DE_VOLUME_OPTED_OUT,
            "FVE_E_DE_VOLUME_NOT_SUPPORTED" => FVE::FVE_E_DE_VOLUME_NOT_SUPPORTED,
            "FVE_E_EOW_NOT_SUPPORTED_IN_VERSION" => FVE::FVE_E_EOW_NOT_SUPPORTED_IN_VERSION,
            "FVE_E_ADBACKUP_NOT_ENABLED" => FVE::FVE_E_ADBACKUP_NOT_ENABLED,
            "FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT" => FVE::FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT,
            "FVE_E_NOT_DE_VOLUME" => FVE::FVE_E_NOT_DE_VOLUME,
            "FVE_E_PROTECTION_CANNOT_BE_DISABLED" => FVE::FVE_E_PROTECTION_CANNOT_BE_DISABLED,
            "FVE_E_OSV_KSR_NOT_ALLOWED" => FVE::FVE_E_OSV_KSR_NOT_ALLOWED,
            "FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE" => FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE,
            "FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE" => FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE,
            "FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE" => FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE,
            "FVE_E_KEY_ROTATION_NOT_SUPPORTED" => FVE::FVE_E_KEY_ROTATION_NOT_SUPPORTED,
            "FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON" => FVE::FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON,
            "FVE_E_KEY_ROTATION_NOT_ENABLED" => FVE::FVE_E_KEY_ROTATION_NOT_ENABLED,
            "FVE_E_DEVICE_NOT_JOINED" => FVE::FVE_E_DEVICE_NOT_JOINED,
            "FVE_E_AAD_ENDPOINT_BUSY" => FVE::FVE_E_AAD_ENDPOINT_BUSY,
            "FVE_E_INVALID_NBP_CERT" => FVE::FVE_E_INVALID_NBP_CERT,
            "FVE_E_EDRIVE_BAND_ENUMERATION_FAILED" => FVE::FVE_E_EDRIVE_BAND_ENUMERATION_FAILED,
            "FVE_E_POLICY_ON_RDV_EXCLUSION_LIST" => FVE::FVE_E_POLICY_ON_RDV_EXCLUSION_LIST,
            "FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED" => FVE::FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED,
            "FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED" => FVE::FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED,
            "FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED" => FVE::FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED,
            "FVE_E_UPDATE_INVALID_CONFIG" => FVE::FVE_E_UPDATE_INVALID_CONFIG,
            "FVE_E_AAD_SERVER_FAIL_RETRY_AFTER" => FVE::FVE_E_AAD_SERVER_FAIL_RETRY_AFTER,
            "FVE_E_AAD_SERVER_FAIL_BACKOFF" => FVE::FVE_E_AAD_SERVER_FAIL_BACKOFF,
            "FVE_E_DATASET_FULL" => FVE::FVE_E_DATASET_FULL,
            "FVE_E_METADATA_FULL" => FVE::FVE_E_METADATA_FULL,
        }
    }
    pub fn from_code(code: u32) -> FVE {
        return match code {
            0x80310000 => FVE::FVE_E_LOCKED_VOLUME,
            0x80310001 => FVE::FVE_E_NOT_ENCRYPTED,
            0x80310002 => FVE::FVE_E_NO_TPM_BIOS,
            0x80310003 => FVE::FVE_E_NO_MBR_METRIC,
            0x80310004 => FVE::FVE_E_NO_BOOTSECTOR_METRIC,
            0x80310005 => FVE::FVE_E_NO_BOOTMGR_METRIC,
            0x80310006 => FVE::FVE_E_WRONG_BOOTMGR,
            0x80310007 => FVE::FVE_E_SECURE_KEY_REQUIRED,
            0x80310008 => FVE::FVE_E_NOT_ACTIVATED,
            0x80310009 => FVE::FVE_E_ACTION_NOT_ALLOWED,
            0x8031000A => FVE::FVE_E_AD_SCHEMA_NOT_INSTALLED,
            0x8031000B => FVE::FVE_E_AD_INVALID_DATATYPE,
            0x8031000C => FVE::FVE_E_AD_INVALID_DATASIZE,
            0x8031000D => FVE::FVE_E_AD_NO_VALUES,
            0x8031000E => FVE::FVE_E_AD_ATTR_NOT_SET,
            0x8031000F => FVE::FVE_E_AD_GUID_NOT_FOUND,
            0x80310010 => FVE::FVE_E_BAD_INFORMATION,
            0x80310011 => FVE::FVE_E_TOO_SMALL,
            0x80310012 => FVE::FVE_E_SYSTEM_VOLUME,
            0x80310013 => FVE::FVE_E_FAILED_WRONG_FS,
            0x80310014 => FVE::FVE_E_BAD_PARTITION_SIZE,
            0x80310014 => FVE::FVE_E_FAILED_BAD_FS,
            0x80310015 => FVE::FVE_E_NOT_SUPPORTED,
            0x80310016 => FVE::FVE_E_BAD_DATA,
            0x80310017 => FVE::FVE_E_VOLUME_NOT_BOUND,
            0x80310018 => FVE::FVE_E_TPM_NOT_OWNED,
            0x80310019 => FVE::FVE_E_NOT_DATA_VOLUME,
            0x8031001A => FVE::FVE_E_AD_INSUFFICIENT_BUFFER,
            0x8031001B => FVE::FVE_E_CONV_READ,
            0x8031001C => FVE::FVE_E_CONV_WRITE,
            0x8031001D => FVE::FVE_E_KEY_REQUIRED,
            0x8031001E => FVE::FVE_E_CLUSTERING_NOT_SUPPORTED,
            0x8031001F => FVE::FVE_E_VOLUME_BOUND_ALREADY,
            0x80310020 => FVE::FVE_E_OS_NOT_PROTECTED,
            0x80310021 => FVE::FVE_E_PROTECTION_DISABLED,
            0x80310022 => FVE::FVE_E_RECOVERY_KEY_REQUIRED,
            0x80310023 => FVE::FVE_E_FOREIGN_VOLUME,
            0x80310024 => FVE::FVE_E_OVERLAPPED_UPDATE,
            0x80310025 => FVE::FVE_E_TPM_SRK_AUTH_NOT_ZERO,
            0x80310026 => FVE::FVE_E_FAILED_SECTOR_SIZE,
            0x80310027 => FVE::FVE_E_FAILED_AUTHENTICATION,
            0x80310028 => FVE::FVE_E_NOT_OS_VOLUME,
            0x80310029 => FVE::FVE_E_AUTOUNLOCK_ENABLED,
            0x8031002A => FVE::FVE_E_WRONG_BOOTSECTOR,
            0x8031002B => FVE::FVE_E_WRONG_SYSTEM_FS,
            0x8031002C => FVE::FVE_E_POLICY_PASSWORD_REQUIRED,
            0x8031002D => FVE::FVE_E_CANNOT_SET_FVEK_ENCRYPTED,
            0x8031002E => FVE::FVE_E_CANNOT_ENCRYPT_NO_KEY,
            0x80310030 => FVE::FVE_E_BOOTABLE_CDDVD,
            0x80310031 => FVE::FVE_E_PROTECTOR_EXISTS,
            0x80310032 => FVE::FVE_E_RELATIVE_PATH,
            0x80310033 => FVE::FVE_E_PROTECTOR_NOT_FOUND,
            0x80310034 => FVE::FVE_E_INVALID_KEY_FORMAT,
            0x80310035 => FVE::FVE_E_INVALID_PASSWORD_FORMAT,
            0x80310036 => FVE::FVE_E_FIPS_RNG_CHECK_FAILED,
            0x80310037 => FVE::FVE_E_FIPS_PREVENTS_RECOVERY_PASSWORD,
            0x80310038 => FVE::FVE_E_FIPS_PREVENTS_EXTERNAL_KEY_EXPORT,
            0x80310039 => FVE::FVE_E_NOT_DECRYPTED,
            0x8031003A => FVE::FVE_E_INVALID_PROTECTOR_TYPE,
            0x8031003B => FVE::FVE_E_NO_PROTECTORS_TO_TEST,
            0x8031003C => FVE::FVE_E_KEYFILE_NOT_FOUND,
            0x8031003D => FVE::FVE_E_KEYFILE_INVALID,
            0x8031003E => FVE::FVE_E_KEYFILE_NO_VMK,
            0x8031003F => FVE::FVE_E_TPM_DISABLED,
            0x80310040 => FVE::FVE_E_NOT_ALLOWED_IN_SAFE_MODE,
            0x80310041 => FVE::FVE_E_TPM_INVALID_PCR,
            0x80310042 => FVE::FVE_E_TPM_NO_VMK,
            0x80310043 => FVE::FVE_E_PIN_INVALID,
            0x80310044 => FVE::FVE_E_AUTH_INVALID_APPLICATION,
            0x80310045 => FVE::FVE_E_AUTH_INVALID_CONFIG,
            0x80310046 => FVE::FVE_E_FIPS_DISABLE_PROTECTION_NOT_ALLOWED,
            0x80310047 => FVE::FVE_E_FS_NOT_EXTENDED,
            0x80310048 => FVE::FVE_E_FIRMWARE_TYPE_NOT_SUPPORTED,
            0x80310049 => FVE::FVE_E_NO_LICENSE,
            0x8031004A => FVE::FVE_E_NOT_ON_STACK,
            0x8031004B => FVE::FVE_E_FS_MOUNTED,
            0x8031004C => FVE::FVE_E_TOKEN_NOT_IMPERSONATED,
            0x8031004D => FVE::FVE_E_DRY_RUN_FAILED,
            0x8031004E => FVE::FVE_E_REBOOT_REQUIRED,
            0x8031004F => FVE::FVE_E_DEBUGGER_ENABLED,
            0x80310050 => FVE::FVE_E_RAW_ACCESS,
            0x80310051 => FVE::FVE_E_RAW_BLOCKED,
            0x80310052 => FVE::FVE_E_BCD_APPLICATIONS_PATH_INCORRECT,
            0x80310053 => FVE::FVE_E_NOT_ALLOWED_IN_VERSION,
            0x80310054 => FVE::FVE_E_NO_AUTOUNLOCK_MASTER_KEY,
            0x80310055 => FVE::FVE_E_MOR_FAILED,
            0x80310056 => FVE::FVE_E_HIDDEN_VOLUME,
            0x80310057 => FVE::FVE_E_TRANSIENT_STATE,
            0x80310058 => FVE::FVE_E_PUBKEY_NOT_ALLOWED,
            0x80310059 => FVE::FVE_E_VOLUME_HANDLE_OPEN,
            0x8031005A => FVE::FVE_E_NO_FEATURE_LICENSE,
            0x8031005B => FVE::FVE_E_INVALID_STARTUP_OPTIONS,
            0x8031005C => FVE::FVE_E_POLICY_RECOVERY_PASSWORD_NOT_ALLOWED,
            0x8031005D => FVE::FVE_E_POLICY_RECOVERY_PASSWORD_REQUIRED,
            0x8031005E => FVE::FVE_E_POLICY_RECOVERY_KEY_NOT_ALLOWED,
            0x8031005F => FVE::FVE_E_POLICY_RECOVERY_KEY_REQUIRED,
            0x80310060 => FVE::FVE_E_POLICY_STARTUP_PIN_NOT_ALLOWED,
            0x80310061 => FVE::FVE_E_POLICY_STARTUP_PIN_REQUIRED,
            0x80310062 => FVE::FVE_E_POLICY_STARTUP_KEY_NOT_ALLOWED,
            0x80310063 => FVE::FVE_E_POLICY_STARTUP_KEY_REQUIRED,
            0x80310064 => FVE::FVE_E_POLICY_STARTUP_PIN_KEY_NOT_ALLOWED,
            0x80310065 => FVE::FVE_E_POLICY_STARTUP_PIN_KEY_REQUIRED,
            0x80310066 => FVE::FVE_E_POLICY_STARTUP_TPM_NOT_ALLOWED,
            0x80310067 => FVE::FVE_E_POLICY_STARTUP_TPM_REQUIRED,
            0x80310068 => FVE::FVE_E_POLICY_INVALID_PIN_LENGTH,
            0x80310069 => FVE::FVE_E_KEY_PROTECTOR_NOT_SUPPORTED,
            0x8031006A => FVE::FVE_E_POLICY_PASSPHRASE_NOT_ALLOWED,
            0x8031006B => FVE::FVE_E_POLICY_PASSPHRASE_REQUIRED,
            0x8031006C => FVE::FVE_E_FIPS_PREVENTS_PASSPHRASE,
            0x8031006D => FVE::FVE_E_OS_VOLUME_PASSPHRASE_NOT_ALLOWED,
            0x8031006E => FVE::FVE_E_INVALID_BITLOCKER_OID,
            0x8031006F => FVE::FVE_E_VOLUME_TOO_SMALL,
            0x80310070 => FVE::FVE_E_DV_NOT_SUPPORTED_ON_FS,
            0x80310071 => FVE::FVE_E_DV_NOT_ALLOWED_BY_GP,
            0x80310072 => FVE::FVE_E_POLICY_USER_CERTIFICATE_NOT_ALLOWED,
            0x80310073 => FVE::FVE_E_POLICY_USER_CERTIFICATE_REQUIRED,
            0x80310074 => FVE::FVE_E_POLICY_USER_CERT_MUST_BE_HW,
            0x80310075 => FVE::FVE_E_POLICY_USER_CONFIGURE_FDV_AUTOUNLOCK_NOT_ALLOWED,
            0x80310076 => FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_AUTOUNLOCK_NOT_ALLOWED,
            0x80310077 => FVE::FVE_E_POLICY_USER_CONFIGURE_RDV_NOT_ALLOWED,
            0x80310078 => FVE::FVE_E_POLICY_USER_ENABLE_RDV_NOT_ALLOWED,
            0x80310079 => FVE::FVE_E_POLICY_USER_DISABLE_RDV_NOT_ALLOWED,
            0x80310080 => FVE::FVE_E_POLICY_INVALID_PASSPHRASE_LENGTH,
            0x80310081 => FVE::FVE_E_POLICY_PASSPHRASE_TOO_SIMPLE,
            0x80310082 => FVE::FVE_E_RECOVERY_PARTITION,
            0x80310083 => FVE::FVE_E_POLICY_CONFLICT_FDV_RK_OFF_AUK_ON,
            0x80310084 => FVE::FVE_E_POLICY_CONFLICT_RDV_RK_OFF_AUK_ON,
            0x80310085 => FVE::FVE_E_NON_BITLOCKER_OID,
            0x80310086 => FVE::FVE_E_POLICY_PROHIBITS_SELFSIGNED,
            0x80310087 => FVE::FVE_E_POLICY_CONFLICT_RO_AND_STARTUP_KEY_REQUIRED,
            0x80310088 => FVE::FVE_E_CONV_RECOVERY_FAILED,
            0x80310089 => FVE::FVE_E_VIRTUALIZED_SPACE_TOO_BIG,
            0x80310090 => FVE::FVE_E_POLICY_CONFLICT_OSV_RP_OFF_ADB_ON,
            0x80310091 => FVE::FVE_E_POLICY_CONFLICT_FDV_RP_OFF_ADB_ON,
            0x80310092 => FVE::FVE_E_POLICY_CONFLICT_RDV_RP_OFF_ADB_ON,
            0x80310093 => FVE::FVE_E_NON_BITLOCKER_KU,
            0x80310094 => FVE::FVE_E_PRIVATEKEY_AUTH_FAILED,
            0x80310095 => FVE::FVE_E_REMOVAL_OF_DRA_FAILED,
            0x80310096 => FVE::FVE_E_OPERATION_NOT_SUPPORTED_ON_VISTA_VOLUME,
            0x80310097 => FVE::FVE_E_CANT_LOCK_AUTOUNLOCK_ENABLED_VOLUME,
            0x80310098 => FVE::FVE_E_FIPS_HASH_KDF_NOT_ALLOWED,
            0x80310099 => FVE::FVE_E_ENH_PIN_INVALID,
            0x8031009A => FVE::FVE_E_INVALID_PIN_CHARS,
            0x8031009B => FVE::FVE_E_INVALID_DATUM_TYPE,
            0x8031009C => FVE::FVE_E_EFI_ONLY,
            0x8031009D => FVE::FVE_E_MULTIPLE_NKP_CERTS,
            0x8031009E => FVE::FVE_E_REMOVAL_OF_NKP_FAILED,
            0x8031009F => FVE::FVE_E_INVALID_NKP_CERT,
            0x803100A0 => FVE::FVE_E_NO_EXISTING_PIN,
            0x803100A1 => FVE::FVE_E_PROTECTOR_CHANGE_PIN_MISMATCH,
            0x803100A2 => FVE::FVE_E_PIN_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED,
            0x803100A3 => FVE::FVE_E_PROTECTOR_CHANGE_MAX_PIN_CHANGE_ATTEMPTS_REACHED,
            0x803100A4 => FVE::FVE_E_POLICY_PASSPHRASE_REQUIRES_ASCII,
            0x803100A5 => FVE::FVE_E_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE,
            0x803100A6 => FVE::FVE_E_WIPE_NOT_ALLOWED_ON_TP_STORAGE,
            0x803100A7 => FVE::FVE_E_KEY_LENGTH_NOT_SUPPORTED_BY_EDRIVE,
            0x803100A8 => FVE::FVE_E_NO_EXISTING_PASSPHRASE,
            0x803100A9 => FVE::FVE_E_PROTECTOR_CHANGE_PASSPHRASE_MISMATCH,
            0x803100AA => FVE::FVE_E_PASSPHRASE_TOO_LONG,
            0x803100AB => FVE::FVE_E_NO_PASSPHRASE_WITH_TPM,
            0x803100AC => FVE::FVE_E_NO_TPM_WITH_PASSPHRASE,
            0x803100AD => FVE::FVE_E_NOT_ALLOWED_ON_CSV_STACK,
            0x803100AE => FVE::FVE_E_NOT_ALLOWED_ON_CLUSTER,
            0x803100AF => FVE::FVE_E_EDRIVE_NO_FAILOVER_TO_SW,
            0x803100B0 => FVE::FVE_E_EDRIVE_BAND_IN_USE,
            0x803100B1 => FVE::FVE_E_EDRIVE_DISALLOWED_BY_GP,
            0x803100B2 => FVE::FVE_E_EDRIVE_INCOMPATIBLE_VOLUME,
            0x803100B3 => FVE::FVE_E_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING,
            0x803100B4 => FVE::FVE_E_EDRIVE_DV_NOT_SUPPORTED,
            0x803100B5 => FVE::FVE_E_NO_PREBOOT_KEYBOARD_DETECTED,
            0x803100B6 => FVE::FVE_E_NO_PREBOOT_KEYBOARD_OR_WINRE_DETECTED,
            0x803100B7 => FVE::FVE_E_POLICY_REQUIRES_STARTUP_PIN_ON_TOUCH_DEVICE,
            0x803100B8 => FVE::FVE_E_POLICY_REQUIRES_RECOVERY_PASSWORD_ON_TOUCH_DEVICE,
            0x803100B9 => FVE::FVE_E_WIPE_CANCEL_NOT_APPLICABLE,
            0x803100BA => FVE::FVE_E_SECUREBOOT_DISABLED,
            0x803100BB => FVE::FVE_E_SECUREBOOT_CONFIGURATION_INVALID,
            0x803100BC => FVE::FVE_E_EDRIVE_DRY_RUN_FAILED,
            0x803100BD => FVE::FVE_E_SHADOW_COPY_PRESENT,
            0x803100BE => FVE::FVE_E_POLICY_INVALID_ENHANCED_BCD_SETTINGS,
            0x803100BF => FVE::FVE_E_EDRIVE_INCOMPATIBLE_FIRMWARE,
            0x803100C0 => FVE::FVE_E_PROTECTOR_CHANGE_MAX_PASSPHRASE_CHANGE_ATTEMPTS_REACHED,
            0x803100C1 => FVE::FVE_E_PASSPHRASE_PROTECTOR_CHANGE_BY_STD_USER_DISALLOWED,
            0x803100C2 => FVE::FVE_E_LIVEID_ACCOUNT_SUSPENDED,
            0x803100C3 => FVE::FVE_E_LIVEID_ACCOUNT_BLOCKED,
            0x803100C4 => FVE::FVE_E_NOT_PROVISIONED_ON_ALL_VOLUMES,
            0x803100C5 => FVE::FVE_E_DE_FIXED_DATA_NOT_SUPPORTED,
            0x803100C6 => FVE::FVE_E_DE_HARDWARE_NOT_COMPLIANT,
            0x803100C7 => FVE::FVE_E_DE_WINRE_NOT_CONFIGURED,
            0x803100C8 => FVE::FVE_E_DE_PROTECTION_SUSPENDED,
            0x803100C9 => FVE::FVE_E_DE_OS_VOLUME_NOT_PROTECTED,
            0x803100CA => FVE::FVE_E_DE_DEVICE_LOCKEDOUT,
            0x803100CB => FVE::FVE_E_DE_PROTECTION_NOT_YET_ENABLED,
            0x803100CC => FVE::FVE_E_INVALID_PIN_CHARS_DETAILED,
            0x803100CD => FVE::FVE_E_DEVICE_LOCKOUT_COUNTER_UNAVAILABLE,
            0x803100CE => FVE::FVE_E_DEVICELOCKOUT_COUNTER_MISMATCH,
            0x803100CF => FVE::FVE_E_BUFFER_TOO_LARGE,
            0x803100D0 => FVE::FVE_E_NO_SUCH_CAPABILITY_ON_TARGET,
            0x803100D1 => FVE::FVE_E_DE_PREVENTED_FOR_OS,
            0x803100D2 => FVE::FVE_E_DE_VOLUME_OPTED_OUT,
            0x803100D3 => FVE::FVE_E_DE_VOLUME_NOT_SUPPORTED,
            0x803100D4 => FVE::FVE_E_EOW_NOT_SUPPORTED_IN_VERSION,
            0x803100D5 => FVE::FVE_E_ADBACKUP_NOT_ENABLED,
            0x803100D6 => FVE::FVE_E_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT,
            0x803100D7 => FVE::FVE_E_NOT_DE_VOLUME,
            0x803100D8 => FVE::FVE_E_PROTECTION_CANNOT_BE_DISABLED,
            0x803100D9 => FVE::FVE_E_OSV_KSR_NOT_ALLOWED,
            0x803100DA => FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_OS_DRIVE,
            0x803100DB => FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_FIXED_DRIVE,
            0x803100DC => FVE::FVE_E_AD_BACKUP_REQUIRED_POLICY_NOT_SET_REMOVABLE_DRIVE,
            0x803100DD => FVE::FVE_E_KEY_ROTATION_NOT_SUPPORTED,
            0x803100DE => FVE::FVE_E_EXECUTE_REQUEST_SENT_TOO_SOON,
            0x803100DF => FVE::FVE_E_KEY_ROTATION_NOT_ENABLED,
            0x803100E0 => FVE::FVE_E_DEVICE_NOT_JOINED,
            0x803100E1 => FVE::FVE_E_AAD_ENDPOINT_BUSY,
            0x803100E2 => FVE::FVE_E_INVALID_NBP_CERT,
            0x803100E3 => FVE::FVE_E_EDRIVE_BAND_ENUMERATION_FAILED,
            0x803100E4 => FVE::FVE_E_POLICY_ON_RDV_EXCLUSION_LIST,
            0x803100E5 => FVE::FVE_E_PREDICTED_TPM_PROTECTOR_NOT_SUPPORTED,
            0x803100E6 => FVE::FVE_E_SETUP_TPM_CALLBACK_NOT_SUPPORTED,
            0x803100E7 => FVE::FVE_E_TPM_CONTEXT_SETUP_NOT_SUPPORTED,
            0x803100E8 => FVE::FVE_E_UPDATE_INVALID_CONFIG,
            0x803100E9 => FVE::FVE_E_AAD_SERVER_FAIL_RETRY_AFTER,
            0x803100EA => FVE::FVE_E_AAD_SERVER_FAIL_BACKOFF,
            0x803100EB => FVE::FVE_E_DATASET_FULL,
            0x803100EC => FVE::FVE_E_METADATA_FULL,
        }
    }
}
