/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum GRAPHICS {
    ERROR_MONITOR_NO_DESCRIPTOR,
    ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT,
    ERROR_GRAPHICS_MODE_NOT_PINNED,
    ERROR_GRAPHICS_NO_PREFERRED_MODE,
    ERROR_GRAPHICS_DATASET_IS_EMPTY,
    ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET,
    ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED,
    DWM_S_GDI_REDIRECTION_SURFACE,
    DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI,
    ERROR_GRAPHICS_PARTIAL_DATA_POPULATED,
    ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION,
    ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS,
    ERROR_GRAPHICS_LEADLINK_START_DEFERRED,
    ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY,
    ERROR_GRAPHICS_START_DEFERRED,
    ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS,
    ERROR_HUNG_DISPLAY_DRIVER_THREAD,
    DWM_E_COMPOSITIONDISABLED,
    DWM_E_REMOTING_NOT_SUPPORTED,
    DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE,
    DWM_E_NOT_QUEUING_PRESENTS,
    DWM_E_ADAPTER_NOT_FOUND,
    DWM_E_TEXTURE_TOO_LARGE,
    ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS,
    ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM,
    ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK,
    ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED,
    ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK,
    ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK,
    ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA,
    ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK,
    ERROR_MONITOR_INVALID_MANUFACTURE_DATE,
    ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER,
    ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER,
    ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER,
    ERROR_GRAPHICS_ADAPTER_WAS_RESET,
    ERROR_GRAPHICS_INVALID_DRIVER_MODEL,
    ERROR_GRAPHICS_PRESENT_MODE_CHANGED,
    ERROR_GRAPHICS_PRESENT_OCCLUDED,
    ERROR_GRAPHICS_PRESENT_DENIED,
    ERROR_GRAPHICS_CANNOTCOLORCONVERT,
    ERROR_GRAPHICS_DRIVER_MISMATCH,
    ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED,
    ERROR_GRAPHICS_PRESENT_UNOCCLUDED,
    ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE,
    ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED,
    ERROR_GRAPHICS_PRESENT_INVALID_WINDOW,
    ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND,
    ERROR_GRAPHICS_VAIL_STATE_CHANGED,
    ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN,
    ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED,
    ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE,
    ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE,
    ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE,
    ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS,
    ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED,
    ERROR_GRAPHICS_NO_VIDEO_MEMORY,
    ERROR_GRAPHICS_CANT_LOCK_MEMORY,
    ERROR_GRAPHICS_ALLOCATION_BUSY,
    ERROR_GRAPHICS_TOO_MANY_REFERENCES,
    ERROR_GRAPHICS_TRY_AGAIN_LATER,
    ERROR_GRAPHICS_TRY_AGAIN_NOW,
    ERROR_GRAPHICS_ALLOCATION_INVALID,
    ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE,
    ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED,
    ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION,
    ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE,
    ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION,
    ERROR_GRAPHICS_ALLOCATION_CLOSED,
    ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE,
    ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE,
    ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE,
    ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST,
    ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE,
    ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY,
    ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED,
    ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED,
    ERROR_GRAPHICS_INVALID_VIDPN,
    ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE,
    ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET,
    ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED,
    ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET,
    ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET,
    ERROR_GRAPHICS_INVALID_FREQUENCY,
    ERROR_GRAPHICS_INVALID_ACTIVE_REGION,
    ERROR_GRAPHICS_INVALID_TOTAL_REGION,
    ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE,
    ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE,
    ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET,
    ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY,
    ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET,
    ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET,
    ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET,
    ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET,
    ERROR_GRAPHICS_TARGET_ALREADY_IN_SET,
    ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH,
    ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY,
    ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET,
    ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE,
    ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET,
    ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET,
    ERROR_GRAPHICS_STALE_MODESET,
    ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET,
    ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE,
    ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN,
    ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE,
    ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION,
    ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES,
    ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY,
    ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE,
    ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET,
    ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET,
    ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR,
    ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET,
    ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET,
    ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE,
    ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE,
    ERROR_GRAPHICS_RESOURCES_NOT_RELATED,
    ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE,
    ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE,
    ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET,
    ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER,
    ERROR_GRAPHICS_NO_VIDPNMGR,
    ERROR_GRAPHICS_NO_ACTIVE_VIDPN,
    ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY,
    ERROR_GRAPHICS_MONITOR_NOT_CONNECTED,
    ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY,
    ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE,
    ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE,
    ERROR_GRAPHICS_INVALID_STRIDE,
    ERROR_GRAPHICS_INVALID_PIXELFORMAT,
    ERROR_GRAPHICS_INVALID_COLORBASIS,
    ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE,
    ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY,
    ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT,
    ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE,
    ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN,
    ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL,
    ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION,
    ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED,
    ERROR_GRAPHICS_INVALID_GAMMA_RAMP,
    ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED,
    ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED,
    ERROR_GRAPHICS_MODE_NOT_IN_MODESET,
    ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON,
    ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE,
    ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE,
    ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS,
    ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING,
    ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED,
    ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS,
    ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT,
    ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM,
    ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN,
    ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT,
    ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED,
    ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION,
    ERROR_GRAPHICS_INVALID_CLIENT_TYPE,
    ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET,
    ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED,
    ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED,
    ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER,
    ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED,
    ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED,
    ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY,
    ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED,
    ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON,
    ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE,
    ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER,
    ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED,
    ERROR_GRAPHICS_OPM_NOT_SUPPORTED,
    ERROR_GRAPHICS_COPP_NOT_SUPPORTED,
    ERROR_GRAPHICS_UAB_NOT_SUPPORTED,
    ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS,
    ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL,
    ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST,
    ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME,
    ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP,
    ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED,
    ERROR_GRAPHICS_OPM_INVALID_POINTER,
    ERROR_GRAPHICS_OPM_INTERNAL_ERROR,
    ERROR_GRAPHICS_OPM_INVALID_HANDLE,
    ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE,
    ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH,
    ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED,
    ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED,
    ERROR_GRAPHICS_PVP_HFS_FAILED,
    ERROR_GRAPHICS_OPM_INVALID_SRM,
    ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP,
    ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP,
    ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA,
    ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET,
    ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH,
    ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE,
    ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS,
    ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS,
    ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS,
    ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST,
    ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR,
    ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS,
    ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED,
    ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST,
    ERROR_GRAPHICS_I2C_NOT_SUPPORTED,
    ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST,
    ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA,
    ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA,
    ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED,
    ERROR_GRAPHICS_DDCCI_INVALID_DATA,
    ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE,
    ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING,
    ERROR_GRAPHICS_MCA_INTERNAL_ERROR,
    ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND,
    ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH,
    ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM,
    ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE,
    ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS,
    ERROR_GRAPHICS_PMEA_INVALID_MONITOR,
    ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE,
    ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE,
    ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION,
    ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION,
    ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH,
    ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION,
    ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED,
    ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE,
    ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED,
    ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME,
    ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP,
    ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED,
    ERROR_GRAPHICS_INVALID_POINTER,
    ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE,
    ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL,
    ERROR_GRAPHICS_INTERNAL_ERROR,
}

impl GRAPHICS {
    pub fn code(&self) -> u32 {
        return match self {
            GRAPHICS::ERROR_MONITOR_NO_DESCRIPTOR => 0x00261001 as u32,
            GRAPHICS::ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT => 0x00261002 as u32,
            GRAPHICS::ERROR_GRAPHICS_MODE_NOT_PINNED => 0x00262307 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_PREFERRED_MODE => 0x0026231E as u32,
            GRAPHICS::ERROR_GRAPHICS_DATASET_IS_EMPTY => 0x0026234B as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET => 0x0026234C as u32,
            GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED => 0x00262351 as u32,
            GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE => 0x00263005 as u32,
            GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI => 0x00263008 as u32,
            GRAPHICS::ERROR_GRAPHICS_PARTIAL_DATA_POPULATED => 0x4026200A as u32,
            GRAPHICS::ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION => 0x40262201 as u32,
            GRAPHICS::ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS => 0x4026242F as u32,
            GRAPHICS::ERROR_GRAPHICS_LEADLINK_START_DEFERRED => 0x40262437 as u32,
            GRAPHICS::ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY => 0x40262439 as u32,
            GRAPHICS::ERROR_GRAPHICS_START_DEFERRED => 0x4026243A as u32,
            GRAPHICS::ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS => 0x4026243C as u32,
            GRAPHICS::ERROR_HUNG_DISPLAY_DRIVER_THREAD => 0x80260001 as u32,
            GRAPHICS::DWM_E_COMPOSITIONDISABLED => 0x80263001 as u32,
            GRAPHICS::DWM_E_REMOTING_NOT_SUPPORTED => 0x80263002 as u32,
            GRAPHICS::DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE => 0x80263003 as u32,
            GRAPHICS::DWM_E_NOT_QUEUING_PRESENTS => 0x80263004 as u32,
            GRAPHICS::DWM_E_ADAPTER_NOT_FOUND => 0x80263005 as u32,
            GRAPHICS::DWM_E_TEXTURE_TOO_LARGE => 0x80263007 as u32,
            GRAPHICS::ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS => 0xC02605E8 as u32,
            GRAPHICS::ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM => 0xC0261003 as u32,
            GRAPHICS::ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK => 0xC0261004 as u32,
            GRAPHICS::ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED => 0xC0261005 as u32,
            GRAPHICS::ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK => 0xC0261006 as u32,
            GRAPHICS::ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK => 0xC0261007 as u32,
            GRAPHICS::ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA => 0xC0261008 as u32,
            GRAPHICS::ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK => 0xC0261009 as u32,
            GRAPHICS::ERROR_MONITOR_INVALID_MANUFACTURE_DATE => 0xC026100A as u32,
            GRAPHICS::ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER => 0xC0262000 as u32,
            GRAPHICS::ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER => 0xC0262001 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER => 0xC0262002 as u32,
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_WAS_RESET => 0xC0262003 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_DRIVER_MODEL => 0xC0262004 as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_MODE_CHANGED => 0xC0262005 as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_OCCLUDED => 0xC0262006 as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_DENIED => 0xC0262007 as u32,
            GRAPHICS::ERROR_GRAPHICS_CANNOTCOLORCONVERT => 0xC0262008 as u32,
            GRAPHICS::ERROR_GRAPHICS_DRIVER_MISMATCH => 0xC0262009 as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED => 0xC026200B as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_UNOCCLUDED => 0xC026200C as u32,
            GRAPHICS::ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE => 0xC026200D as u32,
            GRAPHICS::ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED => 0xC026200E as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_INVALID_WINDOW => 0xC026200F as u32,
            GRAPHICS::ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND => 0xC0262010 as u32,
            GRAPHICS::ERROR_GRAPHICS_VAIL_STATE_CHANGED => 0xC0262011 as u32,
            GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN => 0xC0262012 as u32,
            GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED => 0xC0262013 as u32,
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE => 0xC0262014 as u32,
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE => 0xC0262015 as u32,
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE => 0xC0262016 as u32,
            GRAPHICS::ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS => 0xC0262017 as u32,
            GRAPHICS::ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED => 0xC0262018 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_VIDEO_MEMORY => 0xC0262100 as u32,
            GRAPHICS::ERROR_GRAPHICS_CANT_LOCK_MEMORY => 0xC0262101 as u32,
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_BUSY => 0xC0262102 as u32,
            GRAPHICS::ERROR_GRAPHICS_TOO_MANY_REFERENCES => 0xC0262103 as u32,
            GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_LATER => 0xC0262104 as u32,
            GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_NOW => 0xC0262105 as u32,
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_INVALID => 0xC0262106 as u32,
            GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE => 0xC0262107 as u32,
            GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED => 0xC0262108 as u32,
            GRAPHICS::ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION => 0xC0262109 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE => 0xC0262110 as u32,
            GRAPHICS::ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION => 0xC0262111 as u32,
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CLOSED => 0xC0262112 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE => 0xC0262113 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE => 0xC0262114 as u32,
            GRAPHICS::ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE => 0xC0262115 as u32,
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST => 0xC0262116 as u32,
            GRAPHICS::ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE => 0xC0262200 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY => 0xC0262300 as u32,
            GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED => 0xC0262301 as u32,
            GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED => 0xC0262302 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN => 0xC0262303 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE => 0xC0262304 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET => 0xC0262305 as u32,
            GRAPHICS::ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED => 0xC0262306 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET => 0xC0262308 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET => 0xC0262309 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_FREQUENCY => 0xC026230A as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_ACTIVE_REGION => 0xC026230B as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_TOTAL_REGION => 0xC026230C as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE => 0xC0262310 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE => 0xC0262311 as u32,
            GRAPHICS::ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET => 0xC0262312 as u32,
            GRAPHICS::ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY => 0xC0262313 as u32,
            GRAPHICS::ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET => 0xC0262314 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET => 0xC0262315 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET => 0xC0262316 as u32,
            GRAPHICS::ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET => 0xC0262317 as u32,
            GRAPHICS::ERROR_GRAPHICS_TARGET_ALREADY_IN_SET => 0xC0262318 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH => 0xC0262319 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY => 0xC026231A as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET => 0xC026231B as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE => 0xC026231C as u32,
            GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET => 0xC026231D as u32,
            GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET => 0xC026231F as u32,
            GRAPHICS::ERROR_GRAPHICS_STALE_MODESET => 0xC0262320 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET => 0xC0262321 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE => 0xC0262322 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN => 0xC0262323 as u32,
            GRAPHICS::ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE => 0xC0262324 as u32,
            GRAPHICS::ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION => 0xC0262325 as u32,
            GRAPHICS::ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES => 0xC0262326 as u32,
            GRAPHICS::ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY => 0xC0262327 as u32,
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE => 0xC0262328 as u32,
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET => 0xC0262329 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET => 0xC026232A as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR => 0xC026232B as u32,
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET => 0xC026232C as u32,
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET => 0xC026232D as u32,
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE => 0xC026232E as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE => 0xC026232F as u32,
            GRAPHICS::ERROR_GRAPHICS_RESOURCES_NOT_RELATED => 0xC0262330 as u32,
            GRAPHICS::ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE => 0xC0262331 as u32,
            GRAPHICS::ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE => 0xC0262332 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET => 0xC0262333 as u32,
            GRAPHICS::ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER => 0xC0262334 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_VIDPNMGR => 0xC0262335 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_ACTIVE_VIDPN => 0xC0262336 as u32,
            GRAPHICS::ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY => 0xC0262337 as u32,
            GRAPHICS::ERROR_GRAPHICS_MONITOR_NOT_CONNECTED => 0xC0262338 as u32,
            GRAPHICS::ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY => 0xC0262339 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE => 0xC026233A as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE => 0xC026233B as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_STRIDE => 0xC026233C as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELFORMAT => 0xC026233D as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_COLORBASIS => 0xC026233E as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE => 0xC026233F as u32,
            GRAPHICS::ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY => 0xC0262340 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT => 0xC0262341 as u32,
            GRAPHICS::ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE => 0xC0262342 as u32,
            GRAPHICS::ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN => 0xC0262343 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL => 0xC0262344 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION => 0xC0262345 as u32,
            GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED => 0xC0262346 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_GAMMA_RAMP => 0xC0262347 as u32,
            GRAPHICS::ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED => 0xC0262348 as u32,
            GRAPHICS::ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED => 0xC0262349 as u32,
            GRAPHICS::ERROR_GRAPHICS_MODE_NOT_IN_MODESET => 0xC026234A as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON => 0xC026234D as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE => 0xC026234E as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE => 0xC026234F as u32,
            GRAPHICS::ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS => 0xC0262350 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING => 0xC0262352 as u32,
            GRAPHICS::ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED => 0xC0262353 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS => 0xC0262354 as u32,
            GRAPHICS::ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT => 0xC0262355 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM => 0xC0262356 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN => 0xC0262357 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT => 0xC0262358 as u32,
            GRAPHICS::ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED => 0xC0262359 as u32,
            GRAPHICS::ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION => 0xC026235A as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_CLIENT_TYPE => 0xC026235B as u32,
            GRAPHICS::ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET => 0xC026235C as u32,
            GRAPHICS::ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED => 0xC0262400 as u32,
            GRAPHICS::ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED => 0xC0262401 as u32,
            GRAPHICS::ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER => 0xC0262430 as u32,
            GRAPHICS::ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED => 0xC0262431 as u32,
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED => 0xC0262432 as u32,
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY => 0xC0262433 as u32,
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED => 0xC0262434 as u32,
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON => 0xC0262435 as u32,
            GRAPHICS::ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE => 0xC0262436 as u32,
            GRAPHICS::ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER => 0xC0262438 as u32,
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED => 0xC026243B as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_NOT_SUPPORTED => 0xC0262500 as u32,
            GRAPHICS::ERROR_GRAPHICS_COPP_NOT_SUPPORTED => 0xC0262501 as u32,
            GRAPHICS::ERROR_GRAPHICS_UAB_NOT_SUPPORTED => 0xC0262502 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS => 0xC0262503 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL => 0xC0262504 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST => 0xC0262505 as u32,
            GRAPHICS::ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME => 0xC0262506 as u32,
            GRAPHICS::ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP => 0xC0262507 as u32,
            GRAPHICS::ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED => 0xC0262508 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_POINTER => 0xC026250A as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INTERNAL_ERROR => 0xC026250B as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_HANDLE => 0xC026250C as u32,
            GRAPHICS::ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE => 0xC026250D as u32,
            GRAPHICS::ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH => 0xC026250E as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED => 0xC026250F as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED => 0xC0262510 as u32,
            GRAPHICS::ERROR_GRAPHICS_PVP_HFS_FAILED => 0xC0262511 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_SRM => 0xC0262512 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP => 0xC0262513 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP => 0xC0262514 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA => 0xC0262515 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET => 0xC0262516 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH => 0xC0262517 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE => 0xC0262518 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS => 0xC026251A as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS => 0xC026251B as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS => 0xC026251C as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST => 0xC026251D as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR => 0xC026251E as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS => 0xC026251F as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED => 0xC0262520 as u32,
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST => 0xC0262521 as u32,
            GRAPHICS::ERROR_GRAPHICS_I2C_NOT_SUPPORTED => 0xC0262580 as u32,
            GRAPHICS::ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST => 0xC0262581 as u32,
            GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA => 0xC0262582 as u32,
            GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA => 0xC0262583 as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED => 0xC0262584 as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_DATA => 0xC0262585 as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE => 0xC0262586 as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING => 0xC0262587 as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_INTERNAL_ERROR => 0xC0262588 as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND => 0xC0262589 as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH => 0xC026258A as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM => 0xC026258B as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE => 0xC026258C as u32,
            GRAPHICS::ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS => 0xC026258D as u32,
            GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_MONITOR => 0xC02625D6 as u32,
            GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE => 0xC02625D7 as u32,
            GRAPHICS::ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE => 0xC02625D8 as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION => 0xC02625D9 as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION => 0xC02625DA as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH => 0xC02625DB as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION => 0xC02625DC as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED => 0xC02625DE as u32,
            GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE => 0xC02625DF as u32,
            GRAPHICS::ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED => 0xC02625E0 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME => 0xC02625E1 as u32,
            GRAPHICS::ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP => 0xC02625E2 as u32,
            GRAPHICS::ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED => 0xC02625E3 as u32,
            GRAPHICS::ERROR_GRAPHICS_INVALID_POINTER => 0xC02625E4 as u32,
            GRAPHICS::ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE => 0xC02625E5 as u32,
            GRAPHICS::ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL => 0xC02625E6 as u32,
            GRAPHICS::ERROR_GRAPHICS_INTERNAL_ERROR => 0xC02625E7 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            GRAPHICS::ERROR_MONITOR_NO_DESCRIPTOR => RawError::Kind(GRAPHICS::ERROR_MONITOR_NO_DESCRIPTOR),
            GRAPHICS::ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT => RawError::Kind(GRAPHICS::ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT),
            GRAPHICS::ERROR_GRAPHICS_MODE_NOT_PINNED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MODE_NOT_PINNED),
            GRAPHICS::ERROR_GRAPHICS_NO_PREFERRED_MODE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_PREFERRED_MODE),
            GRAPHICS::ERROR_GRAPHICS_DATASET_IS_EMPTY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DATASET_IS_EMPTY),
            GRAPHICS::ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET),
            GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED),
            GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE => RawError::Kind(GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE),
            GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI => RawError::Kind(GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI),
            GRAPHICS::ERROR_GRAPHICS_PARTIAL_DATA_POPULATED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PARTIAL_DATA_POPULATED),
            GRAPHICS::ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION),
            GRAPHICS::ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS),
            GRAPHICS::ERROR_GRAPHICS_LEADLINK_START_DEFERRED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_LEADLINK_START_DEFERRED),
            GRAPHICS::ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY),
            GRAPHICS::ERROR_GRAPHICS_START_DEFERRED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_START_DEFERRED),
            GRAPHICS::ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS),
            GRAPHICS::ERROR_HUNG_DISPLAY_DRIVER_THREAD => RawError::Kind(GRAPHICS::ERROR_HUNG_DISPLAY_DRIVER_THREAD),
            GRAPHICS::DWM_E_COMPOSITIONDISABLED => RawError::Kind(GRAPHICS::DWM_E_COMPOSITIONDISABLED),
            GRAPHICS::DWM_E_REMOTING_NOT_SUPPORTED => RawError::Kind(GRAPHICS::DWM_E_REMOTING_NOT_SUPPORTED),
            GRAPHICS::DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE => RawError::Kind(GRAPHICS::DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE),
            GRAPHICS::DWM_E_NOT_QUEUING_PRESENTS => RawError::Kind(GRAPHICS::DWM_E_NOT_QUEUING_PRESENTS),
            GRAPHICS::DWM_E_ADAPTER_NOT_FOUND => RawError::Kind(GRAPHICS::DWM_E_ADAPTER_NOT_FOUND),
            GRAPHICS::DWM_E_TEXTURE_TOO_LARGE => RawError::Kind(GRAPHICS::DWM_E_TEXTURE_TOO_LARGE),
            GRAPHICS::ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS),
            GRAPHICS::ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM => RawError::Kind(GRAPHICS::ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM),
            GRAPHICS::ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK => RawError::Kind(GRAPHICS::ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK),
            GRAPHICS::ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED => RawError::Kind(GRAPHICS::ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED),
            GRAPHICS::ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK => RawError::Kind(GRAPHICS::ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK),
            GRAPHICS::ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK => RawError::Kind(GRAPHICS::ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK),
            GRAPHICS::ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA => RawError::Kind(GRAPHICS::ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA),
            GRAPHICS::ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK => RawError::Kind(GRAPHICS::ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK),
            GRAPHICS::ERROR_MONITOR_INVALID_MANUFACTURE_DATE => RawError::Kind(GRAPHICS::ERROR_MONITOR_INVALID_MANUFACTURE_DATE),
            GRAPHICS::ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER),
            GRAPHICS::ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER),
            GRAPHICS::ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER),
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_WAS_RESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ADAPTER_WAS_RESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_DRIVER_MODEL => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_DRIVER_MODEL),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_MODE_CHANGED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_MODE_CHANGED),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_OCCLUDED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_OCCLUDED),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_DENIED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_DENIED),
            GRAPHICS::ERROR_GRAPHICS_CANNOTCOLORCONVERT => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CANNOTCOLORCONVERT),
            GRAPHICS::ERROR_GRAPHICS_DRIVER_MISMATCH => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DRIVER_MISMATCH),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_UNOCCLUDED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_UNOCCLUDED),
            GRAPHICS::ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE),
            GRAPHICS::ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_INVALID_WINDOW => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_INVALID_WINDOW),
            GRAPHICS::ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND),
            GRAPHICS::ERROR_GRAPHICS_VAIL_STATE_CHANGED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VAIL_STATE_CHANGED),
            GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN),
            GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED),
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE),
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE),
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE),
            GRAPHICS::ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS),
            GRAPHICS::ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED),
            GRAPHICS::ERROR_GRAPHICS_NO_VIDEO_MEMORY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_VIDEO_MEMORY),
            GRAPHICS::ERROR_GRAPHICS_CANT_LOCK_MEMORY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CANT_LOCK_MEMORY),
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_BUSY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ALLOCATION_BUSY),
            GRAPHICS::ERROR_GRAPHICS_TOO_MANY_REFERENCES => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TOO_MANY_REFERENCES),
            GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_LATER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_LATER),
            GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_NOW => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_NOW),
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_INVALID => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ALLOCATION_INVALID),
            GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE),
            GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION),
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE),
            GRAPHICS::ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION),
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CLOSED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CLOSED),
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE),
            GRAPHICS::ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE),
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST),
            GRAPHICS::ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET),
            GRAPHICS::ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_FREQUENCY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_FREQUENCY),
            GRAPHICS::ERROR_GRAPHICS_INVALID_ACTIVE_REGION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_ACTIVE_REGION),
            GRAPHICS::ERROR_GRAPHICS_INVALID_TOTAL_REGION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_TOTAL_REGION),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE),
            GRAPHICS::ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET),
            GRAPHICS::ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_TARGET_ALREADY_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TARGET_ALREADY_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH),
            GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE),
            GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_STALE_MODESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_STALE_MODESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE),
            GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN),
            GRAPHICS::ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE),
            GRAPHICS::ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION),
            GRAPHICS::ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES),
            GRAPHICS::ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE),
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR),
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET),
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE),
            GRAPHICS::ERROR_GRAPHICS_RESOURCES_NOT_RELATED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_RESOURCES_NOT_RELATED),
            GRAPHICS::ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE),
            GRAPHICS::ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE),
            GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET),
            GRAPHICS::ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER),
            GRAPHICS::ERROR_GRAPHICS_NO_VIDPNMGR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_VIDPNMGR),
            GRAPHICS::ERROR_GRAPHICS_NO_ACTIVE_VIDPN => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_ACTIVE_VIDPN),
            GRAPHICS::ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_MONITOR_NOT_CONNECTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MONITOR_NOT_CONNECTED),
            GRAPHICS::ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_STRIDE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_STRIDE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELFORMAT => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELFORMAT),
            GRAPHICS::ERROR_GRAPHICS_INVALID_COLORBASIS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_COLORBASIS),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE),
            GRAPHICS::ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY),
            GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT),
            GRAPHICS::ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE),
            GRAPHICS::ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION),
            GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_INVALID_GAMMA_RAMP => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_GAMMA_RAMP),
            GRAPHICS::ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_MODE_NOT_IN_MODESET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MODE_NOT_IN_MODESET),
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE),
            GRAPHICS::ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE),
            GRAPHICS::ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS),
            GRAPHICS::ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING),
            GRAPHICS::ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED),
            GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS),
            GRAPHICS::ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN),
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT),
            GRAPHICS::ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED),
            GRAPHICS::ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION),
            GRAPHICS::ERROR_GRAPHICS_INVALID_CLIENT_TYPE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_CLIENT_TYPE),
            GRAPHICS::ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET),
            GRAPHICS::ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED),
            GRAPHICS::ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER),
            GRAPHICS::ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED),
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED),
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY),
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED),
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON),
            GRAPHICS::ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE),
            GRAPHICS::ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER),
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED),
            GRAPHICS::ERROR_GRAPHICS_OPM_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_COPP_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_COPP_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_UAB_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_UAB_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS),
            GRAPHICS::ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL),
            GRAPHICS::ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST),
            GRAPHICS::ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME),
            GRAPHICS::ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP),
            GRAPHICS::ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_POINTER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_POINTER),
            GRAPHICS::ERROR_GRAPHICS_OPM_INTERNAL_ERROR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INTERNAL_ERROR),
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_HANDLE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_HANDLE),
            GRAPHICS::ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE),
            GRAPHICS::ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH),
            GRAPHICS::ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED),
            GRAPHICS::ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED),
            GRAPHICS::ERROR_GRAPHICS_PVP_HFS_FAILED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PVP_HFS_FAILED),
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_SRM => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_SRM),
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP),
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP),
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA),
            GRAPHICS::ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET),
            GRAPHICS::ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH),
            GRAPHICS::ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE),
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS),
            GRAPHICS::ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS),
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS),
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST),
            GRAPHICS::ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR),
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS),
            GRAPHICS::ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST),
            GRAPHICS::ERROR_GRAPHICS_I2C_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_I2C_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST),
            GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA),
            GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_DATA => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_DATA),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE),
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING),
            GRAPHICS::ERROR_GRAPHICS_MCA_INTERNAL_ERROR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_INTERNAL_ERROR),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM),
            GRAPHICS::ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE),
            GRAPHICS::ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS),
            GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_MONITOR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_MONITOR),
            GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE),
            GRAPHICS::ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE),
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION),
            GRAPHICS::ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION),
            GRAPHICS::ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH),
            GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION),
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED),
            GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE),
            GRAPHICS::ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME),
            GRAPHICS::ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP),
            GRAPHICS::ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED),
            GRAPHICS::ERROR_GRAPHICS_INVALID_POINTER => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INVALID_POINTER),
            GRAPHICS::ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE),
            GRAPHICS::ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL),
            GRAPHICS::ERROR_GRAPHICS_INTERNAL_ERROR => RawError::Kind(GRAPHICS::ERROR_GRAPHICS_INTERNAL_ERROR),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            GRAPHICS::ERROR_MONITOR_NO_DESCRIPTOR => "Monitor descriptor could not be obtained.",
            GRAPHICS::ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT => "Format of the obtained monitor descriptor is not supported by this release.",
            GRAPHICS::ERROR_GRAPHICS_MODE_NOT_PINNED => "No mode is pinned on the specified VidPN source/target.",
            GRAPHICS::ERROR_GRAPHICS_NO_PREFERRED_MODE => "Specified mode set does not specify preference for one of its modes.",
            GRAPHICS::ERROR_GRAPHICS_DATASET_IS_EMPTY => "Specified data set (e.g. mode set, frequency range set, descriptor set, topology, etc.) is empty.",
            GRAPHICS::ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET => "Specified data set (e.g. mode set, frequency range set, descriptor set, topology, etc.) does not contain any more elements.",
            GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED => "Specified content transformation is not pinned on the specified VidPN present path.",
            GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE => "{GDI redirection surface was returned}",
            GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI => "{GDI redirection surface is either on a different adapter or in system memory. Perform blt via GDI}",
            GRAPHICS::ERROR_GRAPHICS_PARTIAL_DATA_POPULATED => "Specified buffer is not big enough to contain entire requested dataset. Partial data populated up to the size of the buffer. Caller needs to provide buffer of size as specified in the partially populated buffer's content (interface specific).",
            GRAPHICS::ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION => "Skip preparation of allocations referenced by the DMA buffer.",
            GRAPHICS::ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS => "Child device presence was not reliably detected.",
            GRAPHICS::ERROR_GRAPHICS_LEADLINK_START_DEFERRED => "Starting the leadlink adapter has been deferred temporarily.",
            GRAPHICS::ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY => "The display adapter is being polled for children too frequently at the same polling level.",
            GRAPHICS::ERROR_GRAPHICS_START_DEFERRED => "Starting the adapter has been deferred temporarily.",
            GRAPHICS::ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS => "We can depend on the child device presence returned by the driver.",
            GRAPHICS::ERROR_HUNG_DISPLAY_DRIVER_THREAD => "{Display Driver Stopped Responding}",
            GRAPHICS::DWM_E_COMPOSITIONDISABLED => "{Desktop composition is disabled}",
            GRAPHICS::DWM_E_REMOTING_NOT_SUPPORTED => "{Some desktop composition APIs are not supported while remoting}",
            GRAPHICS::DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE => "{No DWM redirection surface is available}",
            GRAPHICS::DWM_E_NOT_QUEUING_PRESENTS => "{DWM is not queuing presents for the specified window}",
            GRAPHICS::DWM_E_ADAPTER_NOT_FOUND => "{The adapter specified by the LUID is not found}",
            GRAPHICS::DWM_E_TEXTURE_TOO_LARGE => "{Redirection surface can not be created. The size of the surface is larger than what is supported on this machine}",
            GRAPHICS::ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS => "The function failed because the current session is changing its type. This function cannot be called when the current session is changing its type. There are currently three types of sessions: console, disconnected and remote.",
            GRAPHICS::ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM => "Checksum of the obtained monitor descriptor is invalid.",
            GRAPHICS::ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK => "Monitor descriptor contains an invalid standard timing block.",
            GRAPHICS::ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED => "WMI data block registration failed for one of the MSMonitorClass WMI subclasses.",
            GRAPHICS::ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK => "Provided monitor descriptor block is either corrupted or does not contain monitor's detailed serial number.",
            GRAPHICS::ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK => "Provided monitor descriptor block is either corrupted or does not contain monitor's user friendly name.",
            GRAPHICS::ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA => "There is no monitor descriptor data at the specified (offset, size) region.",
            GRAPHICS::ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK => "Monitor descriptor contains an invalid detailed timing block.",
            GRAPHICS::ERROR_MONITOR_INVALID_MANUFACTURE_DATE => "Monitor descriptor contains invalid manufacture date.",
            GRAPHICS::ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER => "Exclusive mode ownership is needed to create unmanaged primary allocation.",
            GRAPHICS::ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER => "The driver needs more DMA buffer space in order to complete the requested operation.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER => "Specified display adapter handle is invalid.",
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_WAS_RESET => "Specified display adapter and all of its state has been reset.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_DRIVER_MODEL => "The driver stack doesn't match the expected driver model.",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_MODE_CHANGED => "Present happened but ended up into the changed desktop mode",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_OCCLUDED => "Nothing to present due to desktop occlusion",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_DENIED => "Not able to present due to denial of desktop access",
            GRAPHICS::ERROR_GRAPHICS_CANNOTCOLORCONVERT => "Not able to present with color conversion",
            GRAPHICS::ERROR_GRAPHICS_DRIVER_MISMATCH => "The kernel driver detected a version mismatch between it and the user mode driver.",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED => "Present redirection is disabled (desktop windowing management subsystem is off).",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_UNOCCLUDED => "Previous exclusive VidPn source owner has released its ownership",
            GRAPHICS::ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE => "Window DC is not available for presentation",
            GRAPHICS::ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED => "Windowless present is disabled (desktop windowing management subsystem is off).",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_INVALID_WINDOW => "Window handle is invalid",
            GRAPHICS::ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND => "No buffer is bound to composition surface",
            GRAPHICS::ERROR_GRAPHICS_VAIL_STATE_CHANGED => "Vail state has been changed",
            GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN => "Notifying indirect display UMDF class driver to abandon current swapchain.",
            GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED => "Notifying indirect display UMDF class driver that indirect display device has been stopped.",
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE => "Failed to send Create Vail Super Wet Ink message.",
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE => "Failed to send Destroy Vail Super Wet Ink message.",
            GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE => "Failed to send Window Dpi message.",
            GRAPHICS::ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS => "Link configuration for the display timing is still in progress.",
            GRAPHICS::ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED => "The allocation for the MPO has been unpinned.",
            GRAPHICS::ERROR_GRAPHICS_NO_VIDEO_MEMORY => "Not enough video memory available to complete the operation.",
            GRAPHICS::ERROR_GRAPHICS_CANT_LOCK_MEMORY => "Couldn't probe and lock the underlying memory of an allocation.",
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_BUSY => "The allocation is currently busy.",
            GRAPHICS::ERROR_GRAPHICS_TOO_MANY_REFERENCES => "An object being referenced has reach the maximum reference count already and can't be reference further.",
            GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_LATER => "A problem couldn't be solved due to some currently existing condition. The problem should be tried again later.",
            GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_NOW => "A problem couldn't be solved due to some currently existing condition. The problem should be tried again immediately.",
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_INVALID => "The allocation is invalid.",
            GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE => "No more unswizzling aperture are currently available.",
            GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED => "The current allocation can't be unswizzled by an aperture.",
            GRAPHICS::ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION => "The request failed because a pinned allocation can't be evicted.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE => "The allocation can't be used from its current segment location for the specified operation.",
            GRAPHICS::ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION => "A locked allocation can't be used in the current command buffer.",
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CLOSED => "The allocation being referenced has been closed permanently.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE => "An invalid allocation instance is being referenced.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE => "An invalid allocation handle is being referenced.",
            GRAPHICS::ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE => "The allocation being referenced doesn't belong to the current device.",
            GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST => "The specified allocation lost its content.",
            GRAPHICS::ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE => "GPU exception is detected on the given device. The device is not able to be scheduled.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY => "Specified VidPN topology is invalid.",
            GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED => "Specified VidPN topology is valid but is not supported by this model of the display adapter.",
            GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED => "Specified VidPN topology is valid but is not supported by the display adapter at this time, due to current allocation of its resources.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN => "Specified VidPN handle is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE => "Specified video present source is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET => "Specified video present target is invalid.",
            GRAPHICS::ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED => "Specified VidPN modality is not supported (e.g. at least two of the pinned modes are not cofunctional).",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET => "Specified VidPN source mode set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET => "Specified VidPN target mode set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_FREQUENCY => "Specified video signal frequency is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_ACTIVE_REGION => "Specified video signal active region is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_TOTAL_REGION => "Specified video signal total region is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE => "Specified video present source mode is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE => "Specified video present target mode is invalid.",
            GRAPHICS::ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET => "Pinned mode must remain in the set on VidPN's cofunctional modality enumeration.",
            GRAPHICS::ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY => "Specified video present path is already in VidPN's topology.",
            GRAPHICS::ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET => "Specified mode is already in the mode set.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET => "Specified video present source set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET => "Specified video present target set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET => "Specified video present source is already in the video present source set.",
            GRAPHICS::ERROR_GRAPHICS_TARGET_ALREADY_IN_SET => "Specified video present target is already in the video present target set.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH => "Specified VidPN present path is invalid.",
            GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY => "Miniport has no recommendation for augmentation of the specified VidPN's topology.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET => "Specified monitor frequency range set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE => "Specified monitor frequency range is invalid.",
            GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET => "Specified frequency range is not in the specified monitor frequency range set.",
            GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET => "Specified frequency range is already in the specified monitor frequency range set.",
            GRAPHICS::ERROR_GRAPHICS_STALE_MODESET => "Specified mode set is stale. Please reacquire the new mode set.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET => "Specified monitor source mode set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE => "Specified monitor source mode is invalid.",
            GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN => "Miniport does not have any recommendation regarding the request to provide a functional VidPN given the current display adapter configuration.",
            GRAPHICS::ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE => "ID of the specified mode is already used by another mode in the set.",
            GRAPHICS::ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION => "System failed to determine a mode that is supported by both the display adapter and the monitor connected to it.",
            GRAPHICS::ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES => "Number of video present targets must be greater than or equal to the number of video present sources.",
            GRAPHICS::ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY => "Specified present path is not in VidPN's topology.",
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE => "Display adapter must have at least one video present source.",
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET => "Display adapter must have at least one video present target.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET => "Specified monitor descriptor set is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR => "Specified monitor descriptor is invalid.",
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET => "Specified descriptor is not in the specified monitor descriptor set.",
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET => "Specified descriptor is already in the specified monitor descriptor set.",
            GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE => "ID of the specified monitor descriptor is already used by another descriptor in the set.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE => "Specified video present target subset type is invalid.",
            GRAPHICS::ERROR_GRAPHICS_RESOURCES_NOT_RELATED => "Two or more of the specified resources are not related to each other, as defined by the interface semantics.",
            GRAPHICS::ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE => "ID of the specified video present source is already used by another source in the set.",
            GRAPHICS::ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE => "ID of the specified video present target is already used by another target in the set.",
            GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET => "Specified VidPN source cannot be used because there is no available VidPN target to connect it to.",
            GRAPHICS::ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER => "Newly arrived monitor could not be associated with a display adapter.",
            GRAPHICS::ERROR_GRAPHICS_NO_VIDPNMGR => "Display adapter in question does not have an associated VidPN manager.",
            GRAPHICS::ERROR_GRAPHICS_NO_ACTIVE_VIDPN => "VidPN manager of the display adapter in question does not have an active VidPN.",
            GRAPHICS::ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY => "Specified VidPN topology is stale. Please reacquire the new topology.",
            GRAPHICS::ERROR_GRAPHICS_MONITOR_NOT_CONNECTED => "There is no monitor connected on the specified video present target.",
            GRAPHICS::ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY => "Specified source is not part of the specified VidPN's topology.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE => "Specified primary surface size is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE => "Specified visible region size is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_STRIDE => "Specified stride is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELFORMAT => "Specified pixel format is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_COLORBASIS => "Specified color basis is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE => "Specified pixel value access mode is invalid.",
            GRAPHICS::ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY => "Specified target is not part of the specified VidPN's topology.",
            GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT => "Failed to acquire display mode management interface.",
            GRAPHICS::ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE => "Specified VidPN source is already owned by a DMM client and cannot be used until that client releases it.",
            GRAPHICS::ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN => "Specified VidPN is active and cannot be accessed.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL => "Specified VidPN present path importance ordinal is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION => "Specified VidPN present path content geometry transformation is invalid.",
            GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED => "Specified content geometry transformation is not supported on the respective VidPN present path.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_GAMMA_RAMP => "Specified gamma ramp is invalid.",
            GRAPHICS::ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED => "Specified gamma ramp is not supported on the respective VidPN present path.",
            GRAPHICS::ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED => "Multi-sampling is not supported on the respective VidPN present path.",
            GRAPHICS::ERROR_GRAPHICS_MODE_NOT_IN_MODESET => "Specified mode is not in the specified mode set.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON => "Specified VidPN topology recommendation reason is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE => "Specified VidPN present path content type is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE => "Specified VidPN present path copy protection type is invalid.",
            GRAPHICS::ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS => "No more than one unassigned mode set can exist at any given time for a given VidPN source/target.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING => "Specified scanline ordering type is invalid.",
            GRAPHICS::ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED => "Topology changes are not allowed for the specified VidPN.",
            GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS => "All available importance ordinals are already used in specified topology.",
            GRAPHICS::ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT => "Specified primary surface has a different private format attribute than the current primary surface",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM => "Specified mode pruning algorithm is invalid",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN => "Specified monitor capability origin is invalid.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT => "Specified monitor frequency range constraint is invalid.",
            GRAPHICS::ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED => "Maximum supported number of present paths has been reached.",
            GRAPHICS::ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION => "Miniport requested that augmentation be cancelled for the specified source of the specified VidPN's topology.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_CLIENT_TYPE => "Specified client type was not recognized.",
            GRAPHICS::ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET => "Client VidPN is not set on this adapter (e.g. no user mode initiated mode changes took place on this adapter yet).",
            GRAPHICS::ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED => "Specified display adapter child device already has an external device connected to it.",
            GRAPHICS::ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED => "Specified display adapter child device does not support descriptor exposure.",
            GRAPHICS::ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER => "The display adapter is not linked to any other adapters.",
            GRAPHICS::ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED => "Lead adapter in a linked configuration was not enumerated yet.",
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED => "Some chain adapters in a linked configuration were not enumerated yet.",
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY => "The chain of linked adapters is not ready to start because of an unknown failure.",
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED => "An attempt was made to start a lead link display adapter when the chain links were not started yet.",
            GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON => "An attempt was made to power up a lead link display adapter when the chain links were powered down.",
            GRAPHICS::ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE => "The adapter link was found to be in an inconsistent state. Not all adapters are in an expected PNP/Power state.",
            GRAPHICS::ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER => "The driver trying to start is not the same as the driver for the POSTed display adapter.",
            GRAPHICS::ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED => "An operation is being attempted that requires the display adapter to be in a quiescent state.",
            GRAPHICS::ERROR_GRAPHICS_OPM_NOT_SUPPORTED => "The driver does not support OPM.",
            GRAPHICS::ERROR_GRAPHICS_COPP_NOT_SUPPORTED => "The driver does not support COPP.",
            GRAPHICS::ERROR_GRAPHICS_UAB_NOT_SUPPORTED => "The driver does not support UAB.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS => "The specified encrypted parameters are invalid.",
            GRAPHICS::ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL => "An array passed to a function cannot hold all of the data that the function wants to put in it.",
            GRAPHICS::ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST => "The GDI display device passed to this function does not have any active video outputs.",
            GRAPHICS::ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME => "The protected video path (PVP) cannot find an actual GDI display device that corresponds to the passed-in GDI display device name.",
            GRAPHICS::ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP => "This function failed because the GDI display device passed to it was not attached to the Windows desktop.",
            GRAPHICS::ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED => "The PVP does not support mirroring display devices because they do not have video outputs.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_POINTER => "The function failed because an invalid pointer parameter was passed to it. A pointer parameter is invalid if it is null, it points to an invalid address, it points to a kernel mode address, or it is not correctly aligned.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INTERNAL_ERROR => "An internal error caused this operation to fail.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_HANDLE => "The function failed because the caller passed in an invalid OPM user mode handle.",
            GRAPHICS::ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE => "This function failed because the GDI device passed to it did not have any monitors associated with it.",
            GRAPHICS::ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH => "A certificate could not be returned because the certificate buffer passed to the function was too small.",
            GRAPHICS::ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED => "A video output could not be created because the frame buffer is in spanning mode.",
            GRAPHICS::ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED => "A video output could not be created because the frame buffer is in theater mode.",
            GRAPHICS::ERROR_GRAPHICS_PVP_HFS_FAILED => "The function failed because the display adapter's Hardware Functionality Scan failed to validate the graphics hardware.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_SRM => "The HDCP System Renewability Message passed to this function did not comply with section 5 of the HDCP 1.1 specification.",
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP => "The video output cannot enable the High-bandwidth Digital Content Protection (HDCP) System because it does not support HDCP.",
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP => "The video output cannot enable Analogue Copy Protection (ACP) because it does not support ACP.",
            GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA => "The video output cannot enable the Content Generation Management System Analogue (CGMS-A) protection technology because it does not support CGMS-A.",
            GRAPHICS::ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET => "The IOPMVideoOutput::GetInformation method cannot return the version of the SRM being used because the application never successfully passed an SRM to the video output.",
            GRAPHICS::ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH => "The IOPMVideoOutput::Configure method cannot enable the specified output protection technology because the output's screen resolution is too high.",
            GRAPHICS::ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE => "The IOPMVideoOutput::Configure method cannot enable HDCP because the display adapter's HDCP hardware is already being used by other physical outputs.",
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS => "The operating system asynchronously destroyed this OPM video output because the operating system's state changed. This error typically occurs because the monitor PDO associated with this video output was removed, the monitor PDO associated with this video output was stopped, the video output's session became a non-console session or the video output's desktop became an inactive desktop.",
            GRAPHICS::ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS => "The method failed because the session is changing its type. No IOPMVideoOutput methods can be called when a session is changing its type. There are currently three types of sessions: console, disconnected and remote.",
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS => "Either the IOPMVideoOutput::COPPCompatibleGetInformation, IOPMVideoOutput::GetInformation, or IOPMVideoOutput::Configure method failed. This error is returned when the caller tries to use a COPP specific command while the video output has OPM semantics only.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST => "The IOPMVideoOutput::GetInformation and IOPMVideoOutput::COPPCompatibleGetInformation methods return this error if the passed in sequence number is not the expected sequence number or the passed in OMAC value is invalid.",
            GRAPHICS::ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR => "The method failed because an unexpected error occurred inside of a display driver.",
            GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS => "Either the IOPMVideoOutput::COPPCompatibleGetInformation, IOPMVideoOutput::GetInformation, or IOPMVideoOutput::Configure method failed. This error is returned when the caller tries to use an OPM specific command while the video output has COPP semantics only.",
            GRAPHICS::ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED => "The IOPMVideoOutput::COPPCompatibleGetInformation or IOPMVideoOutput::Configure method failed because the display driver does not support the OPM_GET_ACP_AND_CGMSA_SIGNALING and OPM_SET_ACP_AND_CGMSA_SIGNALING GUIDs.",
            GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST => "The IOPMVideoOutput::Configure function returns this error code if the passed in sequence number is not the expected sequence number or the passed in OMAC value is invalid.",
            GRAPHICS::ERROR_GRAPHICS_I2C_NOT_SUPPORTED => "The monitor connected to the specified video output does not have an I2C bus.",
            GRAPHICS::ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST => "No device on the I2C bus has the specified address.",
            GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA => "An error occurred while transmitting data to the device on the I2C bus.",
            GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA => "An error occurred while receiving data from the device on the I2C bus.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED => "The monitor does not support the specified VCP code.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_DATA => "The data received from the monitor is invalid.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE => "The function failed because a monitor returned an invalid Timing Status byte when the operating system used the DDC/CI Get Timing Report & Timing Message command to get a timing report from a monitor.",
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING => "The monitor returned a DDC/CI capabilities string which did not comply with the ACCESS.bus 3.0, DDC/CI 1.1, or MCCS 2 Revision 1 specification.",
            GRAPHICS::ERROR_GRAPHICS_MCA_INTERNAL_ERROR => "An internal Monitor Configuration API error occurred.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND => "An operation failed because a DDC/CI message had an invalid value in its command field.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH => "An error occurred because the field length of a DDC/CI message contained an invalid value.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM => "An error occurred because the checksum field in a DDC/CI message did not match the message's computed checksum value. This error implies that the data was corrupted while it was being transmitted from a monitor to a computer.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE => "This function failed because an invalid monitor handle was passed to it.",
            GRAPHICS::ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS => "The operating system asynchronously destroyed the monitor which corresponds to this handle because the operating system's state changed. This error typically occurs because the monitor PDO associated with this handle was removed, the monitor PDO associated with this handle was stopped, or a display mode change occurred. A display mode change occurs when windows sends a WM_DISPLAYCHANGE windows message to applications.",
            GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_MONITOR => "The HMONITOR no longer exists, is not attached to the desktop, or corresponds to a mirroring device.",
            GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE => "The Direct3D (D3D) device's GDI display device no longer exists, is not attached to the desktop, or is a mirroring display device.",
            GRAPHICS::ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE => "A continuous VCP code's current value is greater than its maximum value. This error code indicates that a monitor returned an invalid value.",
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION => "The monitor's VCP Version (0xDF) VCP code returned an invalid version value.",
            GRAPHICS::ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION => "The monitor does not comply with the MCCS specification it claims to support.",
            GRAPHICS::ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH => "The MCCS version in a monitor's mccs_ver capability does not match the MCCS version the monitor reports when the VCP Version (0xDF) VCP code is used.",
            GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION => "The Monitor Configuration API only works with monitors which support the MCCS 1.0 specification, MCCS 2.0 specification or the MCCS 2.0 Revision 1 specification.",
            GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED => "The monitor returned an invalid monitor technology type. CRT, Plasma and LCD (TFT) are examples of monitor technology types. This error implies that the monitor violated the MCCS 2.0 or MCCS 2.0 Revision 1 specification.",
            GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE => "SetMonitorColorTemperature()'s caller passed a color temperature to it which the current monitor did not support. This error implies that the monitor violated the MCCS 2.0 or MCCS 2.0 Revision 1 specification.",
            GRAPHICS::ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED => "This function can only be used if a program is running in the local console session. It cannot be used if the program is running on a remote desktop session or on a terminal server session.",
            GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME => "This function cannot find an actual GDI display device which corresponds to the specified GDI display device name.",
            GRAPHICS::ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP => "The function failed because the specified GDI display device was not attached to the Windows desktop.",
            GRAPHICS::ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED => "This function does not support GDI mirroring display devices because GDI mirroring display devices do not have any physical monitors associated with them.",
            GRAPHICS::ERROR_GRAPHICS_INVALID_POINTER => "The function failed because an invalid pointer parameter was passed to it. A pointer parameter is invalid if it is NULL, points to an invalid address, points to a kernel mode address, or is not correctly aligned.",
            GRAPHICS::ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE => "The function failed because the specified GDI device did not have any monitors associated with it.",
            GRAPHICS::ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL => "An array passed to the function cannot hold all of the data that the function must copy into the array.",
            GRAPHICS::ERROR_GRAPHICS_INTERNAL_ERROR => "An internal error caused an operation to fail.",
        }
    }

    pub fn from_name(name: &str) -> GRAPHICS {
        return match name {
            "ERROR_MONITOR_NO_DESCRIPTOR" => GRAPHICS::ERROR_MONITOR_NO_DESCRIPTOR,
            "ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT" => GRAPHICS::ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT,
            "ERROR_GRAPHICS_MODE_NOT_PINNED" => GRAPHICS::ERROR_GRAPHICS_MODE_NOT_PINNED,
            "ERROR_GRAPHICS_NO_PREFERRED_MODE" => GRAPHICS::ERROR_GRAPHICS_NO_PREFERRED_MODE,
            "ERROR_GRAPHICS_DATASET_IS_EMPTY" => GRAPHICS::ERROR_GRAPHICS_DATASET_IS_EMPTY,
            "ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET" => GRAPHICS::ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET,
            "ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED" => GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED,
            "DWM_S_GDI_REDIRECTION_SURFACE" => GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE,
            "DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI" => GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI,
            "ERROR_GRAPHICS_PARTIAL_DATA_POPULATED" => GRAPHICS::ERROR_GRAPHICS_PARTIAL_DATA_POPULATED,
            "ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION" => GRAPHICS::ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION,
            "ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS" => GRAPHICS::ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS,
            "ERROR_GRAPHICS_LEADLINK_START_DEFERRED" => GRAPHICS::ERROR_GRAPHICS_LEADLINK_START_DEFERRED,
            "ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY" => GRAPHICS::ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY,
            "ERROR_GRAPHICS_START_DEFERRED" => GRAPHICS::ERROR_GRAPHICS_START_DEFERRED,
            "ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS" => GRAPHICS::ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS,
            "ERROR_HUNG_DISPLAY_DRIVER_THREAD" => GRAPHICS::ERROR_HUNG_DISPLAY_DRIVER_THREAD,
            "DWM_E_COMPOSITIONDISABLED" => GRAPHICS::DWM_E_COMPOSITIONDISABLED,
            "DWM_E_REMOTING_NOT_SUPPORTED" => GRAPHICS::DWM_E_REMOTING_NOT_SUPPORTED,
            "DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE" => GRAPHICS::DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE,
            "DWM_E_NOT_QUEUING_PRESENTS" => GRAPHICS::DWM_E_NOT_QUEUING_PRESENTS,
            "DWM_E_ADAPTER_NOT_FOUND" => GRAPHICS::DWM_E_ADAPTER_NOT_FOUND,
            "DWM_E_TEXTURE_TOO_LARGE" => GRAPHICS::DWM_E_TEXTURE_TOO_LARGE,
            "ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS" => GRAPHICS::ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS,
            "ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM" => GRAPHICS::ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM,
            "ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK" => GRAPHICS::ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK,
            "ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED" => GRAPHICS::ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED,
            "ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK" => GRAPHICS::ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK,
            "ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK" => GRAPHICS::ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK,
            "ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA" => GRAPHICS::ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA,
            "ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK" => GRAPHICS::ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK,
            "ERROR_MONITOR_INVALID_MANUFACTURE_DATE" => GRAPHICS::ERROR_MONITOR_INVALID_MANUFACTURE_DATE,
            "ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER" => GRAPHICS::ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER,
            "ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER" => GRAPHICS::ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER,
            "ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER" => GRAPHICS::ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER,
            "ERROR_GRAPHICS_ADAPTER_WAS_RESET" => GRAPHICS::ERROR_GRAPHICS_ADAPTER_WAS_RESET,
            "ERROR_GRAPHICS_INVALID_DRIVER_MODEL" => GRAPHICS::ERROR_GRAPHICS_INVALID_DRIVER_MODEL,
            "ERROR_GRAPHICS_PRESENT_MODE_CHANGED" => GRAPHICS::ERROR_GRAPHICS_PRESENT_MODE_CHANGED,
            "ERROR_GRAPHICS_PRESENT_OCCLUDED" => GRAPHICS::ERROR_GRAPHICS_PRESENT_OCCLUDED,
            "ERROR_GRAPHICS_PRESENT_DENIED" => GRAPHICS::ERROR_GRAPHICS_PRESENT_DENIED,
            "ERROR_GRAPHICS_CANNOTCOLORCONVERT" => GRAPHICS::ERROR_GRAPHICS_CANNOTCOLORCONVERT,
            "ERROR_GRAPHICS_DRIVER_MISMATCH" => GRAPHICS::ERROR_GRAPHICS_DRIVER_MISMATCH,
            "ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED" => GRAPHICS::ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED,
            "ERROR_GRAPHICS_PRESENT_UNOCCLUDED" => GRAPHICS::ERROR_GRAPHICS_PRESENT_UNOCCLUDED,
            "ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE" => GRAPHICS::ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE,
            "ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED" => GRAPHICS::ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED,
            "ERROR_GRAPHICS_PRESENT_INVALID_WINDOW" => GRAPHICS::ERROR_GRAPHICS_PRESENT_INVALID_WINDOW,
            "ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND" => GRAPHICS::ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND,
            "ERROR_GRAPHICS_VAIL_STATE_CHANGED" => GRAPHICS::ERROR_GRAPHICS_VAIL_STATE_CHANGED,
            "ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN" => GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN,
            "ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED" => GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED,
            "ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE" => GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE,
            "ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE" => GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE,
            "ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE" => GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE,
            "ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS" => GRAPHICS::ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS,
            "ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED" => GRAPHICS::ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED,
            "ERROR_GRAPHICS_NO_VIDEO_MEMORY" => GRAPHICS::ERROR_GRAPHICS_NO_VIDEO_MEMORY,
            "ERROR_GRAPHICS_CANT_LOCK_MEMORY" => GRAPHICS::ERROR_GRAPHICS_CANT_LOCK_MEMORY,
            "ERROR_GRAPHICS_ALLOCATION_BUSY" => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_BUSY,
            "ERROR_GRAPHICS_TOO_MANY_REFERENCES" => GRAPHICS::ERROR_GRAPHICS_TOO_MANY_REFERENCES,
            "ERROR_GRAPHICS_TRY_AGAIN_LATER" => GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_LATER,
            "ERROR_GRAPHICS_TRY_AGAIN_NOW" => GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_NOW,
            "ERROR_GRAPHICS_ALLOCATION_INVALID" => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_INVALID,
            "ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE" => GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE,
            "ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED" => GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED,
            "ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION" => GRAPHICS::ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION,
            "ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE" => GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE,
            "ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION" => GRAPHICS::ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION,
            "ERROR_GRAPHICS_ALLOCATION_CLOSED" => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CLOSED,
            "ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE" => GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE,
            "ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE" => GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE,
            "ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE" => GRAPHICS::ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE,
            "ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST" => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST,
            "ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE" => GRAPHICS::ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE,
            "ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY,
            "ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED,
            "ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED,
            "ERROR_GRAPHICS_INVALID_VIDPN" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN,
            "ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE,
            "ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET,
            "ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED,
            "ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET,
            "ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET,
            "ERROR_GRAPHICS_INVALID_FREQUENCY" => GRAPHICS::ERROR_GRAPHICS_INVALID_FREQUENCY,
            "ERROR_GRAPHICS_INVALID_ACTIVE_REGION" => GRAPHICS::ERROR_GRAPHICS_INVALID_ACTIVE_REGION,
            "ERROR_GRAPHICS_INVALID_TOTAL_REGION" => GRAPHICS::ERROR_GRAPHICS_INVALID_TOTAL_REGION,
            "ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE,
            "ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE,
            "ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET" => GRAPHICS::ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET,
            "ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY,
            "ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET" => GRAPHICS::ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET,
            "ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET,
            "ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET,
            "ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET" => GRAPHICS::ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET,
            "ERROR_GRAPHICS_TARGET_ALREADY_IN_SET" => GRAPHICS::ERROR_GRAPHICS_TARGET_ALREADY_IN_SET,
            "ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH,
            "ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY,
            "ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET,
            "ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE,
            "ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET" => GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET,
            "ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET" => GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET,
            "ERROR_GRAPHICS_STALE_MODESET" => GRAPHICS::ERROR_GRAPHICS_STALE_MODESET,
            "ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET,
            "ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE,
            "ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN" => GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN,
            "ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE" => GRAPHICS::ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE,
            "ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION" => GRAPHICS::ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION,
            "ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES" => GRAPHICS::ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES,
            "ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY,
            "ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE" => GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE,
            "ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET" => GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET,
            "ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET,
            "ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR,
            "ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET" => GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET,
            "ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET" => GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET,
            "ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE" => GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE,
            "ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE,
            "ERROR_GRAPHICS_RESOURCES_NOT_RELATED" => GRAPHICS::ERROR_GRAPHICS_RESOURCES_NOT_RELATED,
            "ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE" => GRAPHICS::ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE,
            "ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE" => GRAPHICS::ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE,
            "ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET" => GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET,
            "ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER" => GRAPHICS::ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER,
            "ERROR_GRAPHICS_NO_VIDPNMGR" => GRAPHICS::ERROR_GRAPHICS_NO_VIDPNMGR,
            "ERROR_GRAPHICS_NO_ACTIVE_VIDPN" => GRAPHICS::ERROR_GRAPHICS_NO_ACTIVE_VIDPN,
            "ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY,
            "ERROR_GRAPHICS_MONITOR_NOT_CONNECTED" => GRAPHICS::ERROR_GRAPHICS_MONITOR_NOT_CONNECTED,
            "ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY,
            "ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE" => GRAPHICS::ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE,
            "ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE" => GRAPHICS::ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE,
            "ERROR_GRAPHICS_INVALID_STRIDE" => GRAPHICS::ERROR_GRAPHICS_INVALID_STRIDE,
            "ERROR_GRAPHICS_INVALID_PIXELFORMAT" => GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELFORMAT,
            "ERROR_GRAPHICS_INVALID_COLORBASIS" => GRAPHICS::ERROR_GRAPHICS_INVALID_COLORBASIS,
            "ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE" => GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE,
            "ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY" => GRAPHICS::ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY,
            "ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT" => GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT,
            "ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE" => GRAPHICS::ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE,
            "ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN" => GRAPHICS::ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN,
            "ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL" => GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL,
            "ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION" => GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION,
            "ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED,
            "ERROR_GRAPHICS_INVALID_GAMMA_RAMP" => GRAPHICS::ERROR_GRAPHICS_INVALID_GAMMA_RAMP,
            "ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED,
            "ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED,
            "ERROR_GRAPHICS_MODE_NOT_IN_MODESET" => GRAPHICS::ERROR_GRAPHICS_MODE_NOT_IN_MODESET,
            "ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON" => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON,
            "ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE" => GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE,
            "ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE" => GRAPHICS::ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE,
            "ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS" => GRAPHICS::ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS,
            "ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING" => GRAPHICS::ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING,
            "ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED" => GRAPHICS::ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED,
            "ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS" => GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS,
            "ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT" => GRAPHICS::ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT,
            "ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM" => GRAPHICS::ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM,
            "ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN,
            "ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT" => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT,
            "ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED" => GRAPHICS::ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED,
            "ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION" => GRAPHICS::ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION,
            "ERROR_GRAPHICS_INVALID_CLIENT_TYPE" => GRAPHICS::ERROR_GRAPHICS_INVALID_CLIENT_TYPE,
            "ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET" => GRAPHICS::ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET,
            "ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED" => GRAPHICS::ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED,
            "ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED,
            "ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER" => GRAPHICS::ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER,
            "ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED" => GRAPHICS::ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED,
            "ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED" => GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED,
            "ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY" => GRAPHICS::ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY,
            "ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED" => GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED,
            "ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON" => GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON,
            "ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE" => GRAPHICS::ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE,
            "ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER" => GRAPHICS::ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER,
            "ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED" => GRAPHICS::ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED,
            "ERROR_GRAPHICS_OPM_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_OPM_NOT_SUPPORTED,
            "ERROR_GRAPHICS_COPP_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_COPP_NOT_SUPPORTED,
            "ERROR_GRAPHICS_UAB_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_UAB_NOT_SUPPORTED,
            "ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS" => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS,
            "ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL" => GRAPHICS::ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL,
            "ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST" => GRAPHICS::ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST,
            "ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME" => GRAPHICS::ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME,
            "ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP" => GRAPHICS::ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP,
            "ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED,
            "ERROR_GRAPHICS_OPM_INVALID_POINTER" => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_POINTER,
            "ERROR_GRAPHICS_OPM_INTERNAL_ERROR" => GRAPHICS::ERROR_GRAPHICS_OPM_INTERNAL_ERROR,
            "ERROR_GRAPHICS_OPM_INVALID_HANDLE" => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_HANDLE,
            "ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE" => GRAPHICS::ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE,
            "ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH" => GRAPHICS::ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH,
            "ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED" => GRAPHICS::ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED,
            "ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED" => GRAPHICS::ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED,
            "ERROR_GRAPHICS_PVP_HFS_FAILED" => GRAPHICS::ERROR_GRAPHICS_PVP_HFS_FAILED,
            "ERROR_GRAPHICS_OPM_INVALID_SRM" => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_SRM,
            "ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP" => GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP,
            "ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP" => GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP,
            "ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA" => GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA,
            "ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET" => GRAPHICS::ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET,
            "ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH" => GRAPHICS::ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH,
            "ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE" => GRAPHICS::ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE,
            "ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS" => GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS,
            "ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS" => GRAPHICS::ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS,
            "ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS" => GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS,
            "ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST" => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST,
            "ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR" => GRAPHICS::ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR,
            "ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS" => GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS,
            "ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED,
            "ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST" => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST,
            "ERROR_GRAPHICS_I2C_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_I2C_NOT_SUPPORTED,
            "ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST" => GRAPHICS::ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST,
            "ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA" => GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA,
            "ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA" => GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA,
            "ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED,
            "ERROR_GRAPHICS_DDCCI_INVALID_DATA" => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_DATA,
            "ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE" => GRAPHICS::ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE,
            "ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING" => GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING,
            "ERROR_GRAPHICS_MCA_INTERNAL_ERROR" => GRAPHICS::ERROR_GRAPHICS_MCA_INTERNAL_ERROR,
            "ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND" => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND,
            "ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH" => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH,
            "ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM" => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM,
            "ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE" => GRAPHICS::ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE,
            "ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS" => GRAPHICS::ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS,
            "ERROR_GRAPHICS_PMEA_INVALID_MONITOR" => GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_MONITOR,
            "ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE" => GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE,
            "ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE" => GRAPHICS::ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE,
            "ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION" => GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION,
            "ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION" => GRAPHICS::ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION,
            "ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH" => GRAPHICS::ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH,
            "ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION" => GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION,
            "ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED" => GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED,
            "ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE" => GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE,
            "ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED,
            "ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME" => GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME,
            "ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP" => GRAPHICS::ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP,
            "ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED" => GRAPHICS::ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED,
            "ERROR_GRAPHICS_INVALID_POINTER" => GRAPHICS::ERROR_GRAPHICS_INVALID_POINTER,
            "ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE" => GRAPHICS::ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE,
            "ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL" => GRAPHICS::ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL,
            "ERROR_GRAPHICS_INTERNAL_ERROR" => GRAPHICS::ERROR_GRAPHICS_INTERNAL_ERROR,
        }
    }
    pub fn from_code(code: u32) -> GRAPHICS {
        return match code {
            0x00261001 => GRAPHICS::ERROR_MONITOR_NO_DESCRIPTOR,
            0x00261002 => GRAPHICS::ERROR_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT,
            0x00262307 => GRAPHICS::ERROR_GRAPHICS_MODE_NOT_PINNED,
            0x0026231E => GRAPHICS::ERROR_GRAPHICS_NO_PREFERRED_MODE,
            0x0026234B => GRAPHICS::ERROR_GRAPHICS_DATASET_IS_EMPTY,
            0x0026234C => GRAPHICS::ERROR_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET,
            0x00262351 => GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED,
            0x00263005 => GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE,
            0x00263008 => GRAPHICS::DWM_S_GDI_REDIRECTION_SURFACE_BLT_VIA_GDI,
            0x4026200A => GRAPHICS::ERROR_GRAPHICS_PARTIAL_DATA_POPULATED,
            0x40262201 => GRAPHICS::ERROR_GRAPHICS_SKIP_ALLOCATION_PREPARATION,
            0x4026242F => GRAPHICS::ERROR_GRAPHICS_UNKNOWN_CHILD_STATUS,
            0x40262437 => GRAPHICS::ERROR_GRAPHICS_LEADLINK_START_DEFERRED,
            0x40262439 => GRAPHICS::ERROR_GRAPHICS_POLLING_TOO_FREQUENTLY,
            0x4026243A => GRAPHICS::ERROR_GRAPHICS_START_DEFERRED,
            0x4026243C => GRAPHICS::ERROR_GRAPHICS_DEPENDABLE_CHILD_STATUS,
            0x80260001 => GRAPHICS::ERROR_HUNG_DISPLAY_DRIVER_THREAD,
            0x80263001 => GRAPHICS::DWM_E_COMPOSITIONDISABLED,
            0x80263002 => GRAPHICS::DWM_E_REMOTING_NOT_SUPPORTED,
            0x80263003 => GRAPHICS::DWM_E_NO_REDIRECTION_SURFACE_AVAILABLE,
            0x80263004 => GRAPHICS::DWM_E_NOT_QUEUING_PRESENTS,
            0x80263005 => GRAPHICS::DWM_E_ADAPTER_NOT_FOUND,
            0x80263007 => GRAPHICS::DWM_E_TEXTURE_TOO_LARGE,
            0xC02605E8 => GRAPHICS::ERROR_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS,
            0xC0261003 => GRAPHICS::ERROR_MONITOR_INVALID_DESCRIPTOR_CHECKSUM,
            0xC0261004 => GRAPHICS::ERROR_MONITOR_INVALID_STANDARD_TIMING_BLOCK,
            0xC0261005 => GRAPHICS::ERROR_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED,
            0xC0261006 => GRAPHICS::ERROR_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK,
            0xC0261007 => GRAPHICS::ERROR_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK,
            0xC0261008 => GRAPHICS::ERROR_MONITOR_NO_MORE_DESCRIPTOR_DATA,
            0xC0261009 => GRAPHICS::ERROR_MONITOR_INVALID_DETAILED_TIMING_BLOCK,
            0xC026100A => GRAPHICS::ERROR_MONITOR_INVALID_MANUFACTURE_DATE,
            0xC0262000 => GRAPHICS::ERROR_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER,
            0xC0262001 => GRAPHICS::ERROR_GRAPHICS_INSUFFICIENT_DMA_BUFFER,
            0xC0262002 => GRAPHICS::ERROR_GRAPHICS_INVALID_DISPLAY_ADAPTER,
            0xC0262003 => GRAPHICS::ERROR_GRAPHICS_ADAPTER_WAS_RESET,
            0xC0262004 => GRAPHICS::ERROR_GRAPHICS_INVALID_DRIVER_MODEL,
            0xC0262005 => GRAPHICS::ERROR_GRAPHICS_PRESENT_MODE_CHANGED,
            0xC0262006 => GRAPHICS::ERROR_GRAPHICS_PRESENT_OCCLUDED,
            0xC0262007 => GRAPHICS::ERROR_GRAPHICS_PRESENT_DENIED,
            0xC0262008 => GRAPHICS::ERROR_GRAPHICS_CANNOTCOLORCONVERT,
            0xC0262009 => GRAPHICS::ERROR_GRAPHICS_DRIVER_MISMATCH,
            0xC026200B => GRAPHICS::ERROR_GRAPHICS_PRESENT_REDIRECTION_DISABLED,
            0xC026200C => GRAPHICS::ERROR_GRAPHICS_PRESENT_UNOCCLUDED,
            0xC026200D => GRAPHICS::ERROR_GRAPHICS_WINDOWDC_NOT_AVAILABLE,
            0xC026200E => GRAPHICS::ERROR_GRAPHICS_WINDOWLESS_PRESENT_DISABLED,
            0xC026200F => GRAPHICS::ERROR_GRAPHICS_PRESENT_INVALID_WINDOW,
            0xC0262010 => GRAPHICS::ERROR_GRAPHICS_PRESENT_BUFFER_NOT_BOUND,
            0xC0262011 => GRAPHICS::ERROR_GRAPHICS_VAIL_STATE_CHANGED,
            0xC0262012 => GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN,
            0xC0262013 => GRAPHICS::ERROR_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED,
            0xC0262014 => GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_CREATE_SUPERWETINK_MESSAGE,
            0xC0262015 => GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_DESTROY_SUPERWETINK_MESSAGE,
            0xC0262016 => GRAPHICS::ERROR_GRAPHICS_VAIL_FAILED_TO_SEND_COMPOSITION_WINDOW_DPI_MESSAGE,
            0xC0262017 => GRAPHICS::ERROR_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS,
            0xC0262018 => GRAPHICS::ERROR_GRAPHICS_MPO_ALLOCATION_UNPINNED,
            0xC0262100 => GRAPHICS::ERROR_GRAPHICS_NO_VIDEO_MEMORY,
            0xC0262101 => GRAPHICS::ERROR_GRAPHICS_CANT_LOCK_MEMORY,
            0xC0262102 => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_BUSY,
            0xC0262103 => GRAPHICS::ERROR_GRAPHICS_TOO_MANY_REFERENCES,
            0xC0262104 => GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_LATER,
            0xC0262105 => GRAPHICS::ERROR_GRAPHICS_TRY_AGAIN_NOW,
            0xC0262106 => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_INVALID,
            0xC0262107 => GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE,
            0xC0262108 => GRAPHICS::ERROR_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED,
            0xC0262109 => GRAPHICS::ERROR_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION,
            0xC0262110 => GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_USAGE,
            0xC0262111 => GRAPHICS::ERROR_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION,
            0xC0262112 => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CLOSED,
            0xC0262113 => GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_INSTANCE,
            0xC0262114 => GRAPHICS::ERROR_GRAPHICS_INVALID_ALLOCATION_HANDLE,
            0xC0262115 => GRAPHICS::ERROR_GRAPHICS_WRONG_ALLOCATION_DEVICE,
            0xC0262116 => GRAPHICS::ERROR_GRAPHICS_ALLOCATION_CONTENT_LOST,
            0xC0262200 => GRAPHICS::ERROR_GRAPHICS_GPU_EXCEPTION_ON_DEVICE,
            0xC0262300 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY,
            0xC0262301 => GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED,
            0xC0262302 => GRAPHICS::ERROR_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED,
            0xC0262303 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN,
            0xC0262304 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE,
            0xC0262305 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET,
            0xC0262306 => GRAPHICS::ERROR_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED,
            0xC0262308 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_SOURCEMODESET,
            0xC0262309 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGETMODESET,
            0xC026230A => GRAPHICS::ERROR_GRAPHICS_INVALID_FREQUENCY,
            0xC026230B => GRAPHICS::ERROR_GRAPHICS_INVALID_ACTIVE_REGION,
            0xC026230C => GRAPHICS::ERROR_GRAPHICS_INVALID_TOTAL_REGION,
            0xC0262310 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE,
            0xC0262311 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE,
            0xC0262312 => GRAPHICS::ERROR_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET,
            0xC0262313 => GRAPHICS::ERROR_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY,
            0xC0262314 => GRAPHICS::ERROR_GRAPHICS_MODE_ALREADY_IN_MODESET,
            0xC0262315 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET,
            0xC0262316 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET,
            0xC0262317 => GRAPHICS::ERROR_GRAPHICS_SOURCE_ALREADY_IN_SET,
            0xC0262318 => GRAPHICS::ERROR_GRAPHICS_TARGET_ALREADY_IN_SET,
            0xC0262319 => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_PRESENT_PATH,
            0xC026231A => GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY,
            0xC026231B => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET,
            0xC026231C => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE,
            0xC026231D => GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET,
            0xC026231F => GRAPHICS::ERROR_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET,
            0xC0262320 => GRAPHICS::ERROR_GRAPHICS_STALE_MODESET,
            0xC0262321 => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCEMODESET,
            0xC0262322 => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_SOURCE_MODE,
            0xC0262323 => GRAPHICS::ERROR_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN,
            0xC0262324 => GRAPHICS::ERROR_GRAPHICS_MODE_ID_MUST_BE_UNIQUE,
            0xC0262325 => GRAPHICS::ERROR_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION,
            0xC0262326 => GRAPHICS::ERROR_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES,
            0xC0262327 => GRAPHICS::ERROR_GRAPHICS_PATH_NOT_IN_TOPOLOGY,
            0xC0262328 => GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE,
            0xC0262329 => GRAPHICS::ERROR_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET,
            0xC026232A => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTORSET,
            0xC026232B => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITORDESCRIPTOR,
            0xC026232C => GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET,
            0xC026232D => GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET,
            0xC026232E => GRAPHICS::ERROR_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE,
            0xC026232F => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE,
            0xC0262330 => GRAPHICS::ERROR_GRAPHICS_RESOURCES_NOT_RELATED,
            0xC0262331 => GRAPHICS::ERROR_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE,
            0xC0262332 => GRAPHICS::ERROR_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE,
            0xC0262333 => GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET,
            0xC0262334 => GRAPHICS::ERROR_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER,
            0xC0262335 => GRAPHICS::ERROR_GRAPHICS_NO_VIDPNMGR,
            0xC0262336 => GRAPHICS::ERROR_GRAPHICS_NO_ACTIVE_VIDPN,
            0xC0262337 => GRAPHICS::ERROR_GRAPHICS_STALE_VIDPN_TOPOLOGY,
            0xC0262338 => GRAPHICS::ERROR_GRAPHICS_MONITOR_NOT_CONNECTED,
            0xC0262339 => GRAPHICS::ERROR_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY,
            0xC026233A => GRAPHICS::ERROR_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE,
            0xC026233B => GRAPHICS::ERROR_GRAPHICS_INVALID_VISIBLEREGION_SIZE,
            0xC026233C => GRAPHICS::ERROR_GRAPHICS_INVALID_STRIDE,
            0xC026233D => GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELFORMAT,
            0xC026233E => GRAPHICS::ERROR_GRAPHICS_INVALID_COLORBASIS,
            0xC026233F => GRAPHICS::ERROR_GRAPHICS_INVALID_PIXELVALUEACCESSMODE,
            0xC0262340 => GRAPHICS::ERROR_GRAPHICS_TARGET_NOT_IN_TOPOLOGY,
            0xC0262341 => GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT,
            0xC0262342 => GRAPHICS::ERROR_GRAPHICS_VIDPN_SOURCE_IN_USE,
            0xC0262343 => GRAPHICS::ERROR_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN,
            0xC0262344 => GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL,
            0xC0262345 => GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION,
            0xC0262346 => GRAPHICS::ERROR_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED,
            0xC0262347 => GRAPHICS::ERROR_GRAPHICS_INVALID_GAMMA_RAMP,
            0xC0262348 => GRAPHICS::ERROR_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED,
            0xC0262349 => GRAPHICS::ERROR_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED,
            0xC026234A => GRAPHICS::ERROR_GRAPHICS_MODE_NOT_IN_MODESET,
            0xC026234D => GRAPHICS::ERROR_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON,
            0xC026234E => GRAPHICS::ERROR_GRAPHICS_INVALID_PATH_CONTENT_TYPE,
            0xC026234F => GRAPHICS::ERROR_GRAPHICS_INVALID_COPYPROTECTION_TYPE,
            0xC0262350 => GRAPHICS::ERROR_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS,
            0xC0262352 => GRAPHICS::ERROR_GRAPHICS_INVALID_SCANLINE_ORDERING,
            0xC0262353 => GRAPHICS::ERROR_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED,
            0xC0262354 => GRAPHICS::ERROR_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS,
            0xC0262355 => GRAPHICS::ERROR_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT,
            0xC0262356 => GRAPHICS::ERROR_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM,
            0xC0262357 => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN,
            0xC0262358 => GRAPHICS::ERROR_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT,
            0xC0262359 => GRAPHICS::ERROR_GRAPHICS_MAX_NUM_PATHS_REACHED,
            0xC026235A => GRAPHICS::ERROR_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION,
            0xC026235B => GRAPHICS::ERROR_GRAPHICS_INVALID_CLIENT_TYPE,
            0xC026235C => GRAPHICS::ERROR_GRAPHICS_CLIENTVIDPN_NOT_SET,
            0xC0262400 => GRAPHICS::ERROR_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED,
            0xC0262401 => GRAPHICS::ERROR_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED,
            0xC0262430 => GRAPHICS::ERROR_GRAPHICS_NOT_A_LINKED_ADAPTER,
            0xC0262431 => GRAPHICS::ERROR_GRAPHICS_LEADLINK_NOT_ENUMERATED,
            0xC0262432 => GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_ENUMERATED,
            0xC0262433 => GRAPHICS::ERROR_GRAPHICS_ADAPTER_CHAIN_NOT_READY,
            0xC0262434 => GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_STARTED,
            0xC0262435 => GRAPHICS::ERROR_GRAPHICS_CHAINLINKS_NOT_POWERED_ON,
            0xC0262436 => GRAPHICS::ERROR_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE,
            0xC0262438 => GRAPHICS::ERROR_GRAPHICS_NOT_POST_DEVICE_DRIVER,
            0xC026243B => GRAPHICS::ERROR_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED,
            0xC0262500 => GRAPHICS::ERROR_GRAPHICS_OPM_NOT_SUPPORTED,
            0xC0262501 => GRAPHICS::ERROR_GRAPHICS_COPP_NOT_SUPPORTED,
            0xC0262502 => GRAPHICS::ERROR_GRAPHICS_UAB_NOT_SUPPORTED,
            0xC0262503 => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS,
            0xC0262504 => GRAPHICS::ERROR_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL,
            0xC0262505 => GRAPHICS::ERROR_GRAPHICS_OPM_NO_VIDEO_OUTPUTS_EXIST,
            0xC0262506 => GRAPHICS::ERROR_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME,
            0xC0262507 => GRAPHICS::ERROR_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP,
            0xC0262508 => GRAPHICS::ERROR_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED,
            0xC026250A => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_POINTER,
            0xC026250B => GRAPHICS::ERROR_GRAPHICS_OPM_INTERNAL_ERROR,
            0xC026250C => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_HANDLE,
            0xC026250D => GRAPHICS::ERROR_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE,
            0xC026250E => GRAPHICS::ERROR_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH,
            0xC026250F => GRAPHICS::ERROR_GRAPHICS_OPM_SPANNING_MODE_ENABLED,
            0xC0262510 => GRAPHICS::ERROR_GRAPHICS_OPM_THEATER_MODE_ENABLED,
            0xC0262511 => GRAPHICS::ERROR_GRAPHICS_PVP_HFS_FAILED,
            0xC0262512 => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_SRM,
            0xC0262513 => GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP,
            0xC0262514 => GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP,
            0xC0262515 => GRAPHICS::ERROR_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA,
            0xC0262516 => GRAPHICS::ERROR_GRAPHICS_OPM_HDCP_SRM_NEVER_SET,
            0xC0262517 => GRAPHICS::ERROR_GRAPHICS_OPM_RESOLUTION_TOO_HIGH,
            0xC0262518 => GRAPHICS::ERROR_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE,
            0xC026251A => GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_NO_LONGER_EXISTS,
            0xC026251B => GRAPHICS::ERROR_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS,
            0xC026251C => GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS,
            0xC026251D => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST,
            0xC026251E => GRAPHICS::ERROR_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR,
            0xC026251F => GRAPHICS::ERROR_GRAPHICS_OPM_VIDEO_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS,
            0xC0262520 => GRAPHICS::ERROR_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED,
            0xC0262521 => GRAPHICS::ERROR_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST,
            0xC0262580 => GRAPHICS::ERROR_GRAPHICS_I2C_NOT_SUPPORTED,
            0xC0262581 => GRAPHICS::ERROR_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST,
            0xC0262582 => GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA,
            0xC0262583 => GRAPHICS::ERROR_GRAPHICS_I2C_ERROR_RECEIVING_DATA,
            0xC0262584 => GRAPHICS::ERROR_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED,
            0xC0262585 => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_DATA,
            0xC0262586 => GRAPHICS::ERROR_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE,
            0xC0262587 => GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_CAPABILITIES_STRING,
            0xC0262588 => GRAPHICS::ERROR_GRAPHICS_MCA_INTERNAL_ERROR,
            0xC0262589 => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND,
            0xC026258A => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH,
            0xC026258B => GRAPHICS::ERROR_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM,
            0xC026258C => GRAPHICS::ERROR_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE,
            0xC026258D => GRAPHICS::ERROR_GRAPHICS_MONITOR_NO_LONGER_EXISTS,
            0xC02625D6 => GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_MONITOR,
            0xC02625D7 => GRAPHICS::ERROR_GRAPHICS_PMEA_INVALID_D3D_DEVICE,
            0xC02625D8 => GRAPHICS::ERROR_GRAPHICS_DDCCI_CURRENT_CURRENT_VALUE_GREATER_THAN_MAXIMUM_VALUE,
            0xC02625D9 => GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_VCP_VERSION,
            0xC02625DA => GRAPHICS::ERROR_GRAPHICS_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION,
            0xC02625DB => GRAPHICS::ERROR_GRAPHICS_MCA_MCCS_VERSION_MISMATCH,
            0xC02625DC => GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_MCCS_VERSION,
            0xC02625DE => GRAPHICS::ERROR_GRAPHICS_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED,
            0xC02625DF => GRAPHICS::ERROR_GRAPHICS_MCA_UNSUPPORTED_COLOR_TEMPERATURE,
            0xC02625E0 => GRAPHICS::ERROR_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED,
            0xC02625E1 => GRAPHICS::ERROR_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME,
            0xC02625E2 => GRAPHICS::ERROR_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP,
            0xC02625E3 => GRAPHICS::ERROR_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED,
            0xC02625E4 => GRAPHICS::ERROR_GRAPHICS_INVALID_POINTER,
            0xC02625E5 => GRAPHICS::ERROR_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE,
            0xC02625E6 => GRAPHICS::ERROR_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL,
            0xC02625E7 => GRAPHICS::ERROR_GRAPHICS_INTERNAL_ERROR,
        }
    }
}
