/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum MSMQ {
    MQ_ERROR,
    MQ_ERROR_PROPERTY,
    MQ_ERROR_QUEUE_NOT_FOUND,
    MQ_ERROR_QUEUE_NOT_ACTIVE,
    MQ_ERROR_QUEUE_EXISTS,
    MQ_ERROR_INVALID_PARAMETER,
    MQ_ERROR_INVALID_HANDLE,
    MQ_ERROR_OPERATION_CANCELLED,
    MQ_ERROR_SHARING_VIOLATION,
    MQ_ERROR_SERVICE_NOT_AVAILABLE,
    MQ_ERROR_MACHINE_NOT_FOUND,
    MQ_ERROR_ILLEGAL_SORT,
    MQ_ERROR_ILLEGAL_USER,
    MQ_ERROR_NO_DS,
    MQ_ERROR_ILLEGAL_QUEUE_PATHNAME,
    MQ_ERROR_ILLEGAL_PROPERTY_VALUE,
    MQ_ERROR_ILLEGAL_PROPERTY_VT,
    MQ_ERROR_BUFFER_OVERFLOW,
    MQ_ERROR_IO_TIMEOUT,
    MQ_ERROR_ILLEGAL_CURSOR_ACTION,
    MQ_ERROR_MESSAGE_ALREADY_RECEIVED,
    MQ_ERROR_ILLEGAL_FORMATNAME,
    MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL,
    MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION,
    MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR,
    MQ_ERROR_SENDERID_BUFFER_TOO_SMALL,
    MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL,
    MQ_ERROR_CANNOT_IMPERSONATE_CLIENT,
    MQ_ERROR_ACCESS_DENIED,
    MQ_ERROR_PRIVILEGE_NOT_HELD,
    MQ_ERROR_INSUFFICIENT_RESOURCES,
    MQ_ERROR_USER_BUFFER_TOO_SMALL,
    MQ_ERROR_MESSAGE_STORAGE_FAILED,
    MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL,
    MQ_ERROR_INVALID_CERTIFICATE,
    MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE,
    MQ_ERROR_INTERNAL_USER_CERT_EXIST,
    MQ_ERROR_NO_INTERNAL_USER_CERT,
    MQ_ERROR_CORRUPTED_SECURITY_DATA,
    MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE,
    MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION,
    MQ_ERROR_BAD_SECURITY_CONTEXT,
    MQ_ERROR_COULD_NOT_GET_USER_SID,
    MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO,
    MQ_ERROR_ILLEGAL_MQCOLUMNS,
    MQ_ERROR_ILLEGAL_PROPID,
    MQ_ERROR_ILLEGAL_RELATION,
    MQ_ERROR_ILLEGAL_PROPERTY_SIZE,
    MQ_ERROR_ILLEGAL_RESTRICTION_PROPID,
    MQ_ERROR_ILLEGAL_MQQUEUEPROPS,
    MQ_ERROR_PROPERTY_NOTALLOWED,
    MQ_ERROR_INSUFFICIENT_PROPERTIES,
    MQ_ERROR_MACHINE_EXISTS,
    MQ_ERROR_ILLEGAL_MQQMPROPS,
    MQ_ERROR_DS_IS_FULL,
    MQ_ERROR_DS_ERROR,
    MQ_ERROR_INVALID_OWNER,
    MQ_ERROR_UNSUPPORTED_ACCESS_MODE,
    MQ_ERROR_RESULT_BUFFER_TOO_SMALL,
    MQ_ERROR_DELETE_CN_IN_USE,
    MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER,
    MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE,
    MQ_ERROR_QUEUE_NOT_AVAILABLE,
    MQ_ERROR_DTC_CONNECT,
    MQ_ERROR_TRANSACTION_IMPORT,
    MQ_ERROR_TRANSACTION_USAGE,
    MQ_ERROR_TRANSACTION_SEQUENCE,
    MQ_ERROR_MISSING_CONNECTOR_TYPE,
    MQ_ERROR_STALE_HANDLE,
    MQ_ERROR_TRANSACTION_ENLIST,
    MQ_ERROR_QUEUE_DELETED,
    MQ_ERROR_ILLEGAL_CONTEXT,
    MQ_ERROR_ILLEGAL_SORT_PROPID,
    MQ_ERROR_LABEL_TOO_LONG,
    MQ_ERROR_LABEL_BUFFER_TOO_SMALL,
    MQ_ERROR_MQIS_SERVER_EMPTY,
    MQ_ERROR_MQIS_READONLY_MODE,
    MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL,
    MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL,
    MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL,
    MQ_ERROR_ILLEGAL_OPERATION,
    MQ_ERROR_WRITE_NOT_ALLOWED,
    MQ_ERROR_WKS_CANT_SERVE_CLIENT,
    MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW,
    MQ_CORRUPTED_QUEUE_WAS_DELETED,
    MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE,
    MQ_ERROR_UNSUPPORTED_OPERATION,
    MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED,
    MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR,
    MQ_ERROR_CERTIFICATE_NOT_PROVIDED,
    MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED,
    MQ_ERROR_CANNOT_CREATE_CERT_STORE,
    MQ_ERROR_CANNOT_OPEN_CERT_STORE,
    MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION,
    MQ_ERROR_CANNOT_GRANT_ADD_GUID,
    MQ_ERROR_CANNOT_LOAD_MSMQOCM,
    MQ_ERROR_NO_ENTRY_POINT_MSMQOCM,
    MQ_ERROR_NO_MSMQ_SERVERS_ON_DC,
    MQ_ERROR_CANNOT_JOIN_DOMAIN,
    MQ_ERROR_CANNOT_CREATE_ON_GC,
    MQ_ERROR_GUID_NOT_MATCHING,
    MQ_ERROR_PUBLIC_KEY_NOT_FOUND,
    MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST,
    MQ_ERROR_ILLEGAL_MQPRIVATEPROPS,
    MQ_ERROR_NO_GC_IN_DOMAIN,
    MQ_ERROR_NO_MSMQ_SERVERS_ON_GC,
    MQ_ERROR_CANNOT_GET_DN,
    MQ_ERROR_CANNOT_HASH_DATA_EX,
    MQ_ERROR_CANNOT_SIGN_DATA_EX,
    MQ_ERROR_CANNOT_CREATE_HASH_EX,
    MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX,
    MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS,
    MQ_ERROR_NO_MQUSER_OU,
    MQ_ERROR_CANNOT_LOAD_MQAD,
    MQ_ERROR_CANNOT_LOAD_MQDSSRV,
    MQ_ERROR_PROPERTIES_CONFLICT,
    MQ_ERROR_MESSAGE_NOT_FOUND,
    MQ_ERROR_CANT_RESOLVE_SITES,
    MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS,
    MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER,
    MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS,
    MQ_ERROR_MULTI_SORT_KEYS,
    MQ_ERROR_GC_NEEDED,
    MQ_ERROR_DS_BIND_ROOT_FOREST,
    MQ_ERROR_DS_LOCAL_USER,
    MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED,
    MQ_ERROR_BAD_XML_FORMAT,
    MQ_ERROR_UNSUPPORTED_CLASS,
    MQ_ERROR_UNINITIALIZED_OBJECT,
    MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS,
    MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS,
    MQ_ERROR_RESOLVE_ADDRESS,
    MQ_ERROR_TOO_MANY_PROPERTIES,
    MQ_ERROR_MESSAGE_NOT_AUTHENTICATED,
    MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION,
}

impl MSMQ {
    pub fn code(&self) -> u32 {
        return match self {
            MSMQ::MQ_ERROR => 0xC00E0001 as u32,
            MSMQ::MQ_ERROR_PROPERTY => 0xC00E0002 as u32,
            MSMQ::MQ_ERROR_QUEUE_NOT_FOUND => 0xC00E0003 as u32,
            MSMQ::MQ_ERROR_QUEUE_NOT_ACTIVE => 0xC00E0004 as u32,
            MSMQ::MQ_ERROR_QUEUE_EXISTS => 0xC00E0005 as u32,
            MSMQ::MQ_ERROR_INVALID_PARAMETER => 0xC00E0006 as u32,
            MSMQ::MQ_ERROR_INVALID_HANDLE => 0xC00E0007 as u32,
            MSMQ::MQ_ERROR_OPERATION_CANCELLED => 0xC00E0008 as u32,
            MSMQ::MQ_ERROR_SHARING_VIOLATION => 0xC00E0009 as u32,
            MSMQ::MQ_ERROR_SERVICE_NOT_AVAILABLE => 0xC00E000B as u32,
            MSMQ::MQ_ERROR_MACHINE_NOT_FOUND => 0xC00E000D as u32,
            MSMQ::MQ_ERROR_ILLEGAL_SORT => 0xC00E0010 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_USER => 0xC00E0011 as u32,
            MSMQ::MQ_ERROR_NO_DS => 0xC00E0013 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_QUEUE_PATHNAME => 0xC00E0014 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VALUE => 0xC00E0018 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VT => 0xC00E0019 as u32,
            MSMQ::MQ_ERROR_BUFFER_OVERFLOW => 0xC00E001A as u32,
            MSMQ::MQ_ERROR_IO_TIMEOUT => 0xC00E001B as u32,
            MSMQ::MQ_ERROR_ILLEGAL_CURSOR_ACTION => 0xC00E001C as u32,
            MSMQ::MQ_ERROR_MESSAGE_ALREADY_RECEIVED => 0xC00E001D as u32,
            MSMQ::MQ_ERROR_ILLEGAL_FORMATNAME => 0xC00E001E as u32,
            MSMQ::MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL => 0xC00E001F as u32,
            MSMQ::MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION => 0xC00E0020 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR => 0xC00E0021 as u32,
            MSMQ::MQ_ERROR_SENDERID_BUFFER_TOO_SMALL => 0xC00E0022 as u32,
            MSMQ::MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL => 0xC00E0023 as u32,
            MSMQ::MQ_ERROR_CANNOT_IMPERSONATE_CLIENT => 0xC00E0024 as u32,
            MSMQ::MQ_ERROR_ACCESS_DENIED => 0xC00E0025 as u32,
            MSMQ::MQ_ERROR_PRIVILEGE_NOT_HELD => 0xC00E0026 as u32,
            MSMQ::MQ_ERROR_INSUFFICIENT_RESOURCES => 0xC00E0027 as u32,
            MSMQ::MQ_ERROR_USER_BUFFER_TOO_SMALL => 0xC00E0028 as u32,
            MSMQ::MQ_ERROR_MESSAGE_STORAGE_FAILED => 0xC00E002A as u32,
            MSMQ::MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL => 0xC00E002B as u32,
            MSMQ::MQ_ERROR_INVALID_CERTIFICATE => 0xC00E002C as u32,
            MSMQ::MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE => 0xC00E002D as u32,
            MSMQ::MQ_ERROR_INTERNAL_USER_CERT_EXIST => 0xC00E002E as u32,
            MSMQ::MQ_ERROR_NO_INTERNAL_USER_CERT => 0xC00E002F as u32,
            MSMQ::MQ_ERROR_CORRUPTED_SECURITY_DATA => 0xC00E0030 as u32,
            MSMQ::MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE => 0xC00E0031 as u32,
            MSMQ::MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION => 0xC00E0033 as u32,
            MSMQ::MQ_ERROR_BAD_SECURITY_CONTEXT => 0xC00E0035 as u32,
            MSMQ::MQ_ERROR_COULD_NOT_GET_USER_SID => 0xC00E0036 as u32,
            MSMQ::MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO => 0xC00E0037 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_MQCOLUMNS => 0xC00E0038 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_PROPID => 0xC00E0039 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_RELATION => 0xC00E003A as u32,
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_SIZE => 0xC00E003B as u32,
            MSMQ::MQ_ERROR_ILLEGAL_RESTRICTION_PROPID => 0xC00E003C as u32,
            MSMQ::MQ_ERROR_ILLEGAL_MQQUEUEPROPS => 0xC00E003D as u32,
            MSMQ::MQ_ERROR_PROPERTY_NOTALLOWED => 0xC00E003E as u32,
            MSMQ::MQ_ERROR_INSUFFICIENT_PROPERTIES => 0xC00E003F as u32,
            MSMQ::MQ_ERROR_MACHINE_EXISTS => 0xC00E0040 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_MQQMPROPS => 0xC00E0041 as u32,
            MSMQ::MQ_ERROR_DS_IS_FULL => 0xC00E0042 as u32,
            MSMQ::MQ_ERROR_DS_ERROR => 0xC00E0043 as u32,
            MSMQ::MQ_ERROR_INVALID_OWNER => 0xC00E0044 as u32,
            MSMQ::MQ_ERROR_UNSUPPORTED_ACCESS_MODE => 0xC00E0045 as u32,
            MSMQ::MQ_ERROR_RESULT_BUFFER_TOO_SMALL => 0xC00E0046 as u32,
            MSMQ::MQ_ERROR_DELETE_CN_IN_USE => 0xC00E0048 as u32,
            MSMQ::MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER => 0xC00E0049 as u32,
            MSMQ::MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE => 0xC00E004A as u32,
            MSMQ::MQ_ERROR_QUEUE_NOT_AVAILABLE => 0xC00E004B as u32,
            MSMQ::MQ_ERROR_DTC_CONNECT => 0xC00E004C as u32,
            MSMQ::MQ_ERROR_TRANSACTION_IMPORT => 0xC00E004E as u32,
            MSMQ::MQ_ERROR_TRANSACTION_USAGE => 0xC00E0050 as u32,
            MSMQ::MQ_ERROR_TRANSACTION_SEQUENCE => 0xC00E0051 as u32,
            MSMQ::MQ_ERROR_MISSING_CONNECTOR_TYPE => 0xC00E0055 as u32,
            MSMQ::MQ_ERROR_STALE_HANDLE => 0xC00E0056 as u32,
            MSMQ::MQ_ERROR_TRANSACTION_ENLIST => 0xC00E0058 as u32,
            MSMQ::MQ_ERROR_QUEUE_DELETED => 0xC00E005A as u32,
            MSMQ::MQ_ERROR_ILLEGAL_CONTEXT => 0xC00E005B as u32,
            MSMQ::MQ_ERROR_ILLEGAL_SORT_PROPID => 0xC00E005C as u32,
            MSMQ::MQ_ERROR_LABEL_TOO_LONG => 0xC00E005D as u32,
            MSMQ::MQ_ERROR_LABEL_BUFFER_TOO_SMALL => 0xC00E005E as u32,
            MSMQ::MQ_ERROR_MQIS_SERVER_EMPTY => 0xC00E005F as u32,
            MSMQ::MQ_ERROR_MQIS_READONLY_MODE => 0xC00E0060 as u32,
            MSMQ::MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL => 0xC00E0061 as u32,
            MSMQ::MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL => 0xC00E0062 as u32,
            MSMQ::MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL => 0xC00E0063 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_OPERATION => 0xC00E0064 as u32,
            MSMQ::MQ_ERROR_WRITE_NOT_ALLOWED => 0xC00E0065 as u32,
            MSMQ::MQ_ERROR_WKS_CANT_SERVE_CLIENT => 0xC00E0066 as u32,
            MSMQ::MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW => 0xC00E0067 as u32,
            MSMQ::MQ_CORRUPTED_QUEUE_WAS_DELETED => 0xC00E0068 as u32,
            MSMQ::MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE => 0xC00E0069 as u32,
            MSMQ::MQ_ERROR_UNSUPPORTED_OPERATION => 0xC00E006A as u32,
            MSMQ::MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED => 0xC00E006B as u32,
            MSMQ::MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR => 0xC00E006C as u32,
            MSMQ::MQ_ERROR_CERTIFICATE_NOT_PROVIDED => 0xC00E006D as u32,
            MSMQ::MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED => 0xC00E006E as u32,
            MSMQ::MQ_ERROR_CANNOT_CREATE_CERT_STORE => 0xC00E006F as u32,
            MSMQ::MQ_ERROR_CANNOT_OPEN_CERT_STORE => 0xC00E0070 as u32,
            MSMQ::MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION => 0xC00E0071 as u32,
            MSMQ::MQ_ERROR_CANNOT_GRANT_ADD_GUID => 0xC00E0072 as u32,
            MSMQ::MQ_ERROR_CANNOT_LOAD_MSMQOCM => 0xC00E0073 as u32,
            MSMQ::MQ_ERROR_NO_ENTRY_POINT_MSMQOCM => 0xC00E0074 as u32,
            MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_DC => 0xC00E0075 as u32,
            MSMQ::MQ_ERROR_CANNOT_JOIN_DOMAIN => 0xC00E0076 as u32,
            MSMQ::MQ_ERROR_CANNOT_CREATE_ON_GC => 0xC00E0077 as u32,
            MSMQ::MQ_ERROR_GUID_NOT_MATCHING => 0xC00E0078 as u32,
            MSMQ::MQ_ERROR_PUBLIC_KEY_NOT_FOUND => 0xC00E0079 as u32,
            MSMQ::MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST => 0xC00E007A as u32,
            MSMQ::MQ_ERROR_ILLEGAL_MQPRIVATEPROPS => 0xC00E007B as u32,
            MSMQ::MQ_ERROR_NO_GC_IN_DOMAIN => 0xC00E007C as u32,
            MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_GC => 0xC00E007D as u32,
            MSMQ::MQ_ERROR_CANNOT_GET_DN => 0xC00E007E as u32,
            MSMQ::MQ_ERROR_CANNOT_HASH_DATA_EX => 0xC00E007F as u32,
            MSMQ::MQ_ERROR_CANNOT_SIGN_DATA_EX => 0xC00E0080 as u32,
            MSMQ::MQ_ERROR_CANNOT_CREATE_HASH_EX => 0xC00E0081 as u32,
            MSMQ::MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX => 0xC00E0082 as u32,
            MSMQ::MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS => 0xC00E0083 as u32,
            MSMQ::MQ_ERROR_NO_MQUSER_OU => 0xC00E0084 as u32,
            MSMQ::MQ_ERROR_CANNOT_LOAD_MQAD => 0xC00E0085 as u32,
            MSMQ::MQ_ERROR_CANNOT_LOAD_MQDSSRV => 0xC00E0086 as u32,
            MSMQ::MQ_ERROR_PROPERTIES_CONFLICT => 0xC00E0087 as u32,
            MSMQ::MQ_ERROR_MESSAGE_NOT_FOUND => 0xC00E0088 as u32,
            MSMQ::MQ_ERROR_CANT_RESOLVE_SITES => 0xC00E0089 as u32,
            MSMQ::MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS => 0xC00E008A as u32,
            MSMQ::MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER => 0xC00E008B as u32,
            MSMQ::MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS => 0xC00E008C as u32,
            MSMQ::MQ_ERROR_MULTI_SORT_KEYS => 0xC00E008D as u32,
            MSMQ::MQ_ERROR_GC_NEEDED => 0xC00E008E as u32,
            MSMQ::MQ_ERROR_DS_BIND_ROOT_FOREST => 0xC00E008F as u32,
            MSMQ::MQ_ERROR_DS_LOCAL_USER => 0xC00E0090 as u32,
            MSMQ::MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED => 0xC00E0091 as u32,
            MSMQ::MQ_ERROR_BAD_XML_FORMAT => 0xC00E0092 as u32,
            MSMQ::MQ_ERROR_UNSUPPORTED_CLASS => 0xC00E0093 as u32,
            MSMQ::MQ_ERROR_UNINITIALIZED_OBJECT => 0xC00E0094 as u32,
            MSMQ::MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS => 0xC00E0095 as u32,
            MSMQ::MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS => 0xC00E0096 as u32,
            MSMQ::MQ_ERROR_RESOLVE_ADDRESS => 0xC00E0099 as u32,
            MSMQ::MQ_ERROR_TOO_MANY_PROPERTIES => 0xC00E009A as u32,
            MSMQ::MQ_ERROR_MESSAGE_NOT_AUTHENTICATED => 0xC00E009B as u32,
            MSMQ::MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION => 0xC00E009C as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            MSMQ::MQ_ERROR => RawError::Kind(MSMQ::MQ_ERROR),
            MSMQ::MQ_ERROR_PROPERTY => RawError::Kind(MSMQ::MQ_ERROR_PROPERTY),
            MSMQ::MQ_ERROR_QUEUE_NOT_FOUND => RawError::Kind(MSMQ::MQ_ERROR_QUEUE_NOT_FOUND),
            MSMQ::MQ_ERROR_QUEUE_NOT_ACTIVE => RawError::Kind(MSMQ::MQ_ERROR_QUEUE_NOT_ACTIVE),
            MSMQ::MQ_ERROR_QUEUE_EXISTS => RawError::Kind(MSMQ::MQ_ERROR_QUEUE_EXISTS),
            MSMQ::MQ_ERROR_INVALID_PARAMETER => RawError::Kind(MSMQ::MQ_ERROR_INVALID_PARAMETER),
            MSMQ::MQ_ERROR_INVALID_HANDLE => RawError::Kind(MSMQ::MQ_ERROR_INVALID_HANDLE),
            MSMQ::MQ_ERROR_OPERATION_CANCELLED => RawError::Kind(MSMQ::MQ_ERROR_OPERATION_CANCELLED),
            MSMQ::MQ_ERROR_SHARING_VIOLATION => RawError::Kind(MSMQ::MQ_ERROR_SHARING_VIOLATION),
            MSMQ::MQ_ERROR_SERVICE_NOT_AVAILABLE => RawError::Kind(MSMQ::MQ_ERROR_SERVICE_NOT_AVAILABLE),
            MSMQ::MQ_ERROR_MACHINE_NOT_FOUND => RawError::Kind(MSMQ::MQ_ERROR_MACHINE_NOT_FOUND),
            MSMQ::MQ_ERROR_ILLEGAL_SORT => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_SORT),
            MSMQ::MQ_ERROR_ILLEGAL_USER => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_USER),
            MSMQ::MQ_ERROR_NO_DS => RawError::Kind(MSMQ::MQ_ERROR_NO_DS),
            MSMQ::MQ_ERROR_ILLEGAL_QUEUE_PATHNAME => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_QUEUE_PATHNAME),
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VALUE => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VALUE),
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VT => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VT),
            MSMQ::MQ_ERROR_BUFFER_OVERFLOW => RawError::Kind(MSMQ::MQ_ERROR_BUFFER_OVERFLOW),
            MSMQ::MQ_ERROR_IO_TIMEOUT => RawError::Kind(MSMQ::MQ_ERROR_IO_TIMEOUT),
            MSMQ::MQ_ERROR_ILLEGAL_CURSOR_ACTION => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_CURSOR_ACTION),
            MSMQ::MQ_ERROR_MESSAGE_ALREADY_RECEIVED => RawError::Kind(MSMQ::MQ_ERROR_MESSAGE_ALREADY_RECEIVED),
            MSMQ::MQ_ERROR_ILLEGAL_FORMATNAME => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_FORMATNAME),
            MSMQ::MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION => RawError::Kind(MSMQ::MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION),
            MSMQ::MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR),
            MSMQ::MQ_ERROR_SENDERID_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_SENDERID_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL),
            MSMQ::MQ_ERROR_CANNOT_IMPERSONATE_CLIENT => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_IMPERSONATE_CLIENT),
            MSMQ::MQ_ERROR_ACCESS_DENIED => RawError::Kind(MSMQ::MQ_ERROR_ACCESS_DENIED),
            MSMQ::MQ_ERROR_PRIVILEGE_NOT_HELD => RawError::Kind(MSMQ::MQ_ERROR_PRIVILEGE_NOT_HELD),
            MSMQ::MQ_ERROR_INSUFFICIENT_RESOURCES => RawError::Kind(MSMQ::MQ_ERROR_INSUFFICIENT_RESOURCES),
            MSMQ::MQ_ERROR_USER_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_USER_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_MESSAGE_STORAGE_FAILED => RawError::Kind(MSMQ::MQ_ERROR_MESSAGE_STORAGE_FAILED),
            MSMQ::MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_INVALID_CERTIFICATE => RawError::Kind(MSMQ::MQ_ERROR_INVALID_CERTIFICATE),
            MSMQ::MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE => RawError::Kind(MSMQ::MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE),
            MSMQ::MQ_ERROR_INTERNAL_USER_CERT_EXIST => RawError::Kind(MSMQ::MQ_ERROR_INTERNAL_USER_CERT_EXIST),
            MSMQ::MQ_ERROR_NO_INTERNAL_USER_CERT => RawError::Kind(MSMQ::MQ_ERROR_NO_INTERNAL_USER_CERT),
            MSMQ::MQ_ERROR_CORRUPTED_SECURITY_DATA => RawError::Kind(MSMQ::MQ_ERROR_CORRUPTED_SECURITY_DATA),
            MSMQ::MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE => RawError::Kind(MSMQ::MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE),
            MSMQ::MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION => RawError::Kind(MSMQ::MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION),
            MSMQ::MQ_ERROR_BAD_SECURITY_CONTEXT => RawError::Kind(MSMQ::MQ_ERROR_BAD_SECURITY_CONTEXT),
            MSMQ::MQ_ERROR_COULD_NOT_GET_USER_SID => RawError::Kind(MSMQ::MQ_ERROR_COULD_NOT_GET_USER_SID),
            MSMQ::MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO => RawError::Kind(MSMQ::MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO),
            MSMQ::MQ_ERROR_ILLEGAL_MQCOLUMNS => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_MQCOLUMNS),
            MSMQ::MQ_ERROR_ILLEGAL_PROPID => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_PROPID),
            MSMQ::MQ_ERROR_ILLEGAL_RELATION => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_RELATION),
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_SIZE => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_SIZE),
            MSMQ::MQ_ERROR_ILLEGAL_RESTRICTION_PROPID => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_RESTRICTION_PROPID),
            MSMQ::MQ_ERROR_ILLEGAL_MQQUEUEPROPS => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_MQQUEUEPROPS),
            MSMQ::MQ_ERROR_PROPERTY_NOTALLOWED => RawError::Kind(MSMQ::MQ_ERROR_PROPERTY_NOTALLOWED),
            MSMQ::MQ_ERROR_INSUFFICIENT_PROPERTIES => RawError::Kind(MSMQ::MQ_ERROR_INSUFFICIENT_PROPERTIES),
            MSMQ::MQ_ERROR_MACHINE_EXISTS => RawError::Kind(MSMQ::MQ_ERROR_MACHINE_EXISTS),
            MSMQ::MQ_ERROR_ILLEGAL_MQQMPROPS => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_MQQMPROPS),
            MSMQ::MQ_ERROR_DS_IS_FULL => RawError::Kind(MSMQ::MQ_ERROR_DS_IS_FULL),
            MSMQ::MQ_ERROR_DS_ERROR => RawError::Kind(MSMQ::MQ_ERROR_DS_ERROR),
            MSMQ::MQ_ERROR_INVALID_OWNER => RawError::Kind(MSMQ::MQ_ERROR_INVALID_OWNER),
            MSMQ::MQ_ERROR_UNSUPPORTED_ACCESS_MODE => RawError::Kind(MSMQ::MQ_ERROR_UNSUPPORTED_ACCESS_MODE),
            MSMQ::MQ_ERROR_RESULT_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_RESULT_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_DELETE_CN_IN_USE => RawError::Kind(MSMQ::MQ_ERROR_DELETE_CN_IN_USE),
            MSMQ::MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER => RawError::Kind(MSMQ::MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER),
            MSMQ::MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE => RawError::Kind(MSMQ::MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE),
            MSMQ::MQ_ERROR_QUEUE_NOT_AVAILABLE => RawError::Kind(MSMQ::MQ_ERROR_QUEUE_NOT_AVAILABLE),
            MSMQ::MQ_ERROR_DTC_CONNECT => RawError::Kind(MSMQ::MQ_ERROR_DTC_CONNECT),
            MSMQ::MQ_ERROR_TRANSACTION_IMPORT => RawError::Kind(MSMQ::MQ_ERROR_TRANSACTION_IMPORT),
            MSMQ::MQ_ERROR_TRANSACTION_USAGE => RawError::Kind(MSMQ::MQ_ERROR_TRANSACTION_USAGE),
            MSMQ::MQ_ERROR_TRANSACTION_SEQUENCE => RawError::Kind(MSMQ::MQ_ERROR_TRANSACTION_SEQUENCE),
            MSMQ::MQ_ERROR_MISSING_CONNECTOR_TYPE => RawError::Kind(MSMQ::MQ_ERROR_MISSING_CONNECTOR_TYPE),
            MSMQ::MQ_ERROR_STALE_HANDLE => RawError::Kind(MSMQ::MQ_ERROR_STALE_HANDLE),
            MSMQ::MQ_ERROR_TRANSACTION_ENLIST => RawError::Kind(MSMQ::MQ_ERROR_TRANSACTION_ENLIST),
            MSMQ::MQ_ERROR_QUEUE_DELETED => RawError::Kind(MSMQ::MQ_ERROR_QUEUE_DELETED),
            MSMQ::MQ_ERROR_ILLEGAL_CONTEXT => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_CONTEXT),
            MSMQ::MQ_ERROR_ILLEGAL_SORT_PROPID => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_SORT_PROPID),
            MSMQ::MQ_ERROR_LABEL_TOO_LONG => RawError::Kind(MSMQ::MQ_ERROR_LABEL_TOO_LONG),
            MSMQ::MQ_ERROR_LABEL_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_LABEL_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_MQIS_SERVER_EMPTY => RawError::Kind(MSMQ::MQ_ERROR_MQIS_SERVER_EMPTY),
            MSMQ::MQ_ERROR_MQIS_READONLY_MODE => RawError::Kind(MSMQ::MQ_ERROR_MQIS_READONLY_MODE),
            MSMQ::MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL => RawError::Kind(MSMQ::MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL),
            MSMQ::MQ_ERROR_ILLEGAL_OPERATION => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_OPERATION),
            MSMQ::MQ_ERROR_WRITE_NOT_ALLOWED => RawError::Kind(MSMQ::MQ_ERROR_WRITE_NOT_ALLOWED),
            MSMQ::MQ_ERROR_WKS_CANT_SERVE_CLIENT => RawError::Kind(MSMQ::MQ_ERROR_WKS_CANT_SERVE_CLIENT),
            MSMQ::MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW => RawError::Kind(MSMQ::MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW),
            MSMQ::MQ_CORRUPTED_QUEUE_WAS_DELETED => RawError::Kind(MSMQ::MQ_CORRUPTED_QUEUE_WAS_DELETED),
            MSMQ::MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE => RawError::Kind(MSMQ::MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE),
            MSMQ::MQ_ERROR_UNSUPPORTED_OPERATION => RawError::Kind(MSMQ::MQ_ERROR_UNSUPPORTED_OPERATION),
            MSMQ::MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED => RawError::Kind(MSMQ::MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED),
            MSMQ::MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR),
            MSMQ::MQ_ERROR_CERTIFICATE_NOT_PROVIDED => RawError::Kind(MSMQ::MQ_ERROR_CERTIFICATE_NOT_PROVIDED),
            MSMQ::MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED => RawError::Kind(MSMQ::MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED),
            MSMQ::MQ_ERROR_CANNOT_CREATE_CERT_STORE => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_CREATE_CERT_STORE),
            MSMQ::MQ_ERROR_CANNOT_OPEN_CERT_STORE => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_OPEN_CERT_STORE),
            MSMQ::MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION),
            MSMQ::MQ_ERROR_CANNOT_GRANT_ADD_GUID => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_GRANT_ADD_GUID),
            MSMQ::MQ_ERROR_CANNOT_LOAD_MSMQOCM => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_LOAD_MSMQOCM),
            MSMQ::MQ_ERROR_NO_ENTRY_POINT_MSMQOCM => RawError::Kind(MSMQ::MQ_ERROR_NO_ENTRY_POINT_MSMQOCM),
            MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_DC => RawError::Kind(MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_DC),
            MSMQ::MQ_ERROR_CANNOT_JOIN_DOMAIN => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_JOIN_DOMAIN),
            MSMQ::MQ_ERROR_CANNOT_CREATE_ON_GC => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_CREATE_ON_GC),
            MSMQ::MQ_ERROR_GUID_NOT_MATCHING => RawError::Kind(MSMQ::MQ_ERROR_GUID_NOT_MATCHING),
            MSMQ::MQ_ERROR_PUBLIC_KEY_NOT_FOUND => RawError::Kind(MSMQ::MQ_ERROR_PUBLIC_KEY_NOT_FOUND),
            MSMQ::MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST => RawError::Kind(MSMQ::MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST),
            MSMQ::MQ_ERROR_ILLEGAL_MQPRIVATEPROPS => RawError::Kind(MSMQ::MQ_ERROR_ILLEGAL_MQPRIVATEPROPS),
            MSMQ::MQ_ERROR_NO_GC_IN_DOMAIN => RawError::Kind(MSMQ::MQ_ERROR_NO_GC_IN_DOMAIN),
            MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_GC => RawError::Kind(MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_GC),
            MSMQ::MQ_ERROR_CANNOT_GET_DN => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_GET_DN),
            MSMQ::MQ_ERROR_CANNOT_HASH_DATA_EX => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_HASH_DATA_EX),
            MSMQ::MQ_ERROR_CANNOT_SIGN_DATA_EX => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_SIGN_DATA_EX),
            MSMQ::MQ_ERROR_CANNOT_CREATE_HASH_EX => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_CREATE_HASH_EX),
            MSMQ::MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX => RawError::Kind(MSMQ::MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX),
            MSMQ::MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS),
            MSMQ::MQ_ERROR_NO_MQUSER_OU => RawError::Kind(MSMQ::MQ_ERROR_NO_MQUSER_OU),
            MSMQ::MQ_ERROR_CANNOT_LOAD_MQAD => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_LOAD_MQAD),
            MSMQ::MQ_ERROR_CANNOT_LOAD_MQDSSRV => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_LOAD_MQDSSRV),
            MSMQ::MQ_ERROR_PROPERTIES_CONFLICT => RawError::Kind(MSMQ::MQ_ERROR_PROPERTIES_CONFLICT),
            MSMQ::MQ_ERROR_MESSAGE_NOT_FOUND => RawError::Kind(MSMQ::MQ_ERROR_MESSAGE_NOT_FOUND),
            MSMQ::MQ_ERROR_CANT_RESOLVE_SITES => RawError::Kind(MSMQ::MQ_ERROR_CANT_RESOLVE_SITES),
            MSMQ::MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS => RawError::Kind(MSMQ::MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS),
            MSMQ::MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER => RawError::Kind(MSMQ::MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER),
            MSMQ::MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS => RawError::Kind(MSMQ::MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS),
            MSMQ::MQ_ERROR_MULTI_SORT_KEYS => RawError::Kind(MSMQ::MQ_ERROR_MULTI_SORT_KEYS),
            MSMQ::MQ_ERROR_GC_NEEDED => RawError::Kind(MSMQ::MQ_ERROR_GC_NEEDED),
            MSMQ::MQ_ERROR_DS_BIND_ROOT_FOREST => RawError::Kind(MSMQ::MQ_ERROR_DS_BIND_ROOT_FOREST),
            MSMQ::MQ_ERROR_DS_LOCAL_USER => RawError::Kind(MSMQ::MQ_ERROR_DS_LOCAL_USER),
            MSMQ::MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED => RawError::Kind(MSMQ::MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED),
            MSMQ::MQ_ERROR_BAD_XML_FORMAT => RawError::Kind(MSMQ::MQ_ERROR_BAD_XML_FORMAT),
            MSMQ::MQ_ERROR_UNSUPPORTED_CLASS => RawError::Kind(MSMQ::MQ_ERROR_UNSUPPORTED_CLASS),
            MSMQ::MQ_ERROR_UNINITIALIZED_OBJECT => RawError::Kind(MSMQ::MQ_ERROR_UNINITIALIZED_OBJECT),
            MSMQ::MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS),
            MSMQ::MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS => RawError::Kind(MSMQ::MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS),
            MSMQ::MQ_ERROR_RESOLVE_ADDRESS => RawError::Kind(MSMQ::MQ_ERROR_RESOLVE_ADDRESS),
            MSMQ::MQ_ERROR_TOO_MANY_PROPERTIES => RawError::Kind(MSMQ::MQ_ERROR_TOO_MANY_PROPERTIES),
            MSMQ::MQ_ERROR_MESSAGE_NOT_AUTHENTICATED => RawError::Kind(MSMQ::MQ_ERROR_MESSAGE_NOT_AUTHENTICATED),
            MSMQ::MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION => RawError::Kind(MSMQ::MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            MSMQ::MQ_ERROR => "Generic error code.",
            MSMQ::MQ_ERROR_PROPERTY => "One or more of the properties passed are invalid.",
            MSMQ::MQ_ERROR_QUEUE_NOT_FOUND => "The queue does not exist or you do not have sufficient permissions to perform the operation.",
            MSMQ::MQ_ERROR_QUEUE_NOT_ACTIVE => "The queue is not open or may not exist.",
            MSMQ::MQ_ERROR_QUEUE_EXISTS => "A queue with the same path name already exists.",
            MSMQ::MQ_ERROR_INVALID_PARAMETER => "An invalid parameter was passed to a function.",
            MSMQ::MQ_ERROR_INVALID_HANDLE => "An invalid handle was passed to a function.",
            MSMQ::MQ_ERROR_OPERATION_CANCELLED => "The operation was canceled before it could be completed.",
            MSMQ::MQ_ERROR_SHARING_VIOLATION => "There is a sharing violation. The queue is already open for exclusive retrieval.",
            MSMQ::MQ_ERROR_SERVICE_NOT_AVAILABLE => "The Message Queuing service is not available",
            MSMQ::MQ_ERROR_MACHINE_NOT_FOUND => "The computer specified cannot be found.",
            MSMQ::MQ_ERROR_ILLEGAL_SORT => "The sort operation specified in MQLocateBegin is invalid (for example, there are duplicate columns).",
            MSMQ::MQ_ERROR_ILLEGAL_USER => "The user specified is not a valid user.",
            MSMQ::MQ_ERROR_NO_DS => "A connection with Active Directory Domain Services cannot be established. Verify that there are sufficient permissions to perform this operation.",
            MSMQ::MQ_ERROR_ILLEGAL_QUEUE_PATHNAME => "The queue path name specified is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VALUE => "The property value specified is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VT => "The VARTYPE value specified is invalid.",
            MSMQ::MQ_ERROR_BUFFER_OVERFLOW => "The buffer supplied to MQReceiveMessage for message property retrieval is too small. The message was not removed from the queue, but the part of the message property that was in the buffer was copied.",
            MSMQ::MQ_ERROR_IO_TIMEOUT => "The time specified for MQReceiveMessage to wait for the message elapsed.",
            MSMQ::MQ_ERROR_ILLEGAL_CURSOR_ACTION => "The MQ_ACTION_PEEK_NEXT value specified for MQReceiveMessage cannot be used with the current cursor position.",
            MSMQ::MQ_ERROR_MESSAGE_ALREADY_RECEIVED => "The message at which the cursor is currently pointing was removed from the queue by another process or by another call to MQReceiveMessage without the use of this cursor.",
            MSMQ::MQ_ERROR_ILLEGAL_FORMATNAME => "The format name specified is invalid.",
            MSMQ::MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL => "The format name buffer supplied to the API was too small to hold the format name.",
            MSMQ::MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION => "Operations of the type requested (for example, deleting a queue using a direct format name) are not supported for the format name specified.",
            MSMQ::MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR => "The specified security descriptor is invalid.",
            MSMQ::MQ_ERROR_SENDERID_BUFFER_TOO_SMALL => "The size of the buffer for the user ID property is too small.",
            MSMQ::MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL => "The size of the buffer passed to MQGetQueueSecurity is too small.",
            MSMQ::MQ_ERROR_CANNOT_IMPERSONATE_CLIENT => "The security credentials cannot be verified because the RPC server cannot impersonate the client application.",
            MSMQ::MQ_ERROR_ACCESS_DENIED => "Access is denied.",
            MSMQ::MQ_ERROR_PRIVILEGE_NOT_HELD => "The client does not have sufficient security privileges to perform the operation.",
            MSMQ::MQ_ERROR_INSUFFICIENT_RESOURCES => "There are insufficient resources to perform this operation.",
            MSMQ::MQ_ERROR_USER_BUFFER_TOO_SMALL => "The request failed because the user buffer is too small to hold the information returned.",
            MSMQ::MQ_ERROR_MESSAGE_STORAGE_FAILED => "A recoverable or journal message could not be stored. The message was not sent.",
            MSMQ::MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL => "The buffer for the user certificate property is too small.",
            MSMQ::MQ_ERROR_INVALID_CERTIFICATE => "The user certificate is invalid.",
            MSMQ::MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE => "The internal Message Queuing certificate is corrupted.",
            MSMQ::MQ_ERROR_INTERNAL_USER_CERT_EXIST => "An internal Message Queuing certificate already exists for this user.",
            MSMQ::MQ_ERROR_NO_INTERNAL_USER_CERT => "No internal Message Queuing certificate exists for the user.",
            MSMQ::MQ_ERROR_CORRUPTED_SECURITY_DATA => "A cryptographic function failed.",
            MSMQ::MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE => "The personal certificate store is corrupted.",
            MSMQ::MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION => "The computer does not support encryption operations.",
            MSMQ::MQ_ERROR_BAD_SECURITY_CONTEXT => "The security context is invalid.",
            MSMQ::MQ_ERROR_COULD_NOT_GET_USER_SID => "The SID cannot be obtained from the thread token.",
            MSMQ::MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO => "The account information for the user cannot be obtained.",
            MSMQ::MQ_ERROR_ILLEGAL_MQCOLUMNS => "The MQCOLUMNS parameter is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_PROPID => "A property identifier is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_RELATION => "A relationship parameter is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_SIZE => "The size of the buffer for the message identifier or correlation identifier is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_RESTRICTION_PROPID => "A property identifier specified in MQRESTRICTION is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_MQQUEUEPROPS => "Either the pointer to the MQQUEUEPROPS structure has a null value, or no properties are specified in it.",
            MSMQ::MQ_ERROR_PROPERTY_NOTALLOWED => "The property identifier specified (for example, PROPID_Q_INSTANCE in MQSetQueueProperties) is invalid for the operation requested.",
            MSMQ::MQ_ERROR_INSUFFICIENT_PROPERTIES => "Not all the properties required for the operation were specified for the input parameters.",
            MSMQ::MQ_ERROR_MACHINE_EXISTS => "The MSMQ Configuration (msmq) object already exists in Active Directory Domain Services.",
            MSMQ::MQ_ERROR_ILLEGAL_MQQMPROPS => "Either the pointer to the MQQMROPS structure has a null value, or no properties are specified in it.",
            MSMQ::MQ_ERROR_DS_IS_FULL => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_DS_ERROR => "There is an internal Active Directory Domain Services error.",
            MSMQ::MQ_ERROR_INVALID_OWNER => "The object owner is invalid (for example, MQCreateQueue failed because the QM object is invalid).",
            MSMQ::MQ_ERROR_UNSUPPORTED_ACCESS_MODE => "The access mode specified is unsupported.",
            MSMQ::MQ_ERROR_RESULT_BUFFER_TOO_SMALL => "The result buffer specified is too small.",
            MSMQ::MQ_ERROR_DELETE_CN_IN_USE => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER => "There was no response from the object owner.",
            MSMQ::MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE => "The object owner is not available.",
            MSMQ::MQ_ERROR_QUEUE_NOT_AVAILABLE => "An error occurred while reading from a queue located on a remote computer.",
            MSMQ::MQ_ERROR_DTC_CONNECT => "A connection cannot be established with the Distributed Transaction Coordinator.",
            MSMQ::MQ_ERROR_TRANSACTION_IMPORT => "The transaction specified cannot be imported.",
            MSMQ::MQ_ERROR_TRANSACTION_USAGE => "An attempted action cannot be performed within a transaction.",
            MSMQ::MQ_ERROR_TRANSACTION_SEQUENCE => "The transaction's operation sequence is incorrect.",
            MSMQ::MQ_ERROR_MISSING_CONNECTOR_TYPE => "The connector type message property is not specified. This property is required for sending an acknowledgment message or a secure message.",
            MSMQ::MQ_ERROR_STALE_HANDLE => "The Message Queuing service was restarted. Any open queue handles should be closed.",
            MSMQ::MQ_ERROR_TRANSACTION_ENLIST => "The transaction specified cannot be enlisted.",
            MSMQ::MQ_ERROR_QUEUE_DELETED => "The queue was deleted. Messages cannot be received anymore using this queue handle. The handle should be closed.",
            MSMQ::MQ_ERROR_ILLEGAL_CONTEXT => "The context parameter for MQLocateBegin is invalid.",
            MSMQ::MQ_ERROR_ILLEGAL_SORT_PROPID => "An invalid property identifier is specified in MQSORTSET.",
            MSMQ::MQ_ERROR_LABEL_TOO_LONG => "The message label is too long. Its length should be less than or equal to MQ_MAX_MSG_LABEL_LEN.",
            MSMQ::MQ_ERROR_LABEL_BUFFER_TOO_SMALL => "The label buffer supplied to the API is too small.",
            MSMQ::MQ_ERROR_MQIS_SERVER_EMPTY => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_MQIS_READONLY_MODE => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL => "The buffer passed for the symmetric key is too small.",
            MSMQ::MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL => "The buffer passed for the signature property is too small.",
            MSMQ::MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL => "The buffer passed for the provider name property is too small.",
            MSMQ::MQ_ERROR_ILLEGAL_OPERATION => "The operation is invalid for a foreign message queuing system.",
            MSMQ::MQ_ERROR_WRITE_NOT_ALLOWED => "Obsolete; another MQIS server is being installed. Write operations to the database are not allowed at this stage.",
            MSMQ::MQ_ERROR_WKS_CANT_SERVE_CLIENT => "Independent clients cannot support dependent clients. A Message Queuing server is required.",
            MSMQ::MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW => "The number of dependent clients served by the Message Queuing server reached its upper limit.",
            MSMQ::MQ_CORRUPTED_QUEUE_WAS_DELETED => "The file %1 for the queue %2 in the Lqs folder was deleted because it was corrupted.",
            MSMQ::MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE => "The remote computer is not available.",
            MSMQ::MQ_ERROR_UNSUPPORTED_OPERATION => "This operation is not supported for Message Queuing installed in workgroup mode.",
            MSMQ::MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED => "The cryptographic service provider %1 is not supported by Message Queuing.",
            MSMQ::MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR => "The security descriptors for the cryptographic keys cannot be set.",
            MSMQ::MQ_ERROR_CERTIFICATE_NOT_PROVIDED => "A user attempted to send an authenticated message without a certificate.",
            MSMQ::MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED => "The column PROPID_Q_PATHNAME_DNS is not supported for the MQLocateBegin API.",
            MSMQ::MQ_ERROR_CANNOT_CREATE_CERT_STORE => "A certificate store cannot be created for the internal certificate.",
            MSMQ::MQ_ERROR_CANNOT_OPEN_CERT_STORE => "The certificate store for the internal certificate cannot be opened.",
            MSMQ::MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION => "This operation is invalid for an MsmqServices object.",
            MSMQ::MQ_ERROR_CANNOT_GRANT_ADD_GUID => "The Add GUID permission cannot be granted to the current user.",
            MSMQ::MQ_ERROR_CANNOT_LOAD_MSMQOCM => "Obsolete: The dynamic-link library Msmqocm.dll cannot be loaded.",
            MSMQ::MQ_ERROR_NO_ENTRY_POINT_MSMQOCM => "An entry point cannot be located in Msmqocm.dll.",
            MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_DC => "Message Queuing servers cannot be found on domain controllers.",
            MSMQ::MQ_ERROR_CANNOT_JOIN_DOMAIN => "The computer joined the domain, but Message Queuing will continue to run in workgroup mode because it failed to register itself in Active Directory Domain Services.",
            MSMQ::MQ_ERROR_CANNOT_CREATE_ON_GC => "The object was not created on the Global Catalog server specified.",
            MSMQ::MQ_ERROR_GUID_NOT_MATCHING => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_PUBLIC_KEY_NOT_FOUND => "The public key for the computer %1 cannot be found.",
            MSMQ::MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST => "The public key for the computer %1 does not exist.",
            MSMQ::MQ_ERROR_ILLEGAL_MQPRIVATEPROPS => "The parameters in MQPRIVATEPROPS are invalid. Either the pointer to the MQPRIVATEPROPS structure has a null value, or no properties are specified in it.",
            MSMQ::MQ_ERROR_NO_GC_IN_DOMAIN => "Global Catalog servers cannot be found in the domain specified.",
            MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_GC => "No Message Queuing servers were found on Global Catalog servers.",
            MSMQ::MQ_ERROR_CANNOT_GET_DN => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_CANNOT_HASH_DATA_EX => "Data for an authenticated message cannot be hashed.",
            MSMQ::MQ_ERROR_CANNOT_SIGN_DATA_EX => "Data cannot be signed before sending an authenticated message.",
            MSMQ::MQ_ERROR_CANNOT_CREATE_HASH_EX => "A hash object cannot be created for an authenticated message.",
            MSMQ::MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX => "The signature of the message received is not valid.",
            MSMQ::MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS => "The object that will be deleted is owned by a primary site controller. The operation cannot be performed.",
            MSMQ::MQ_ERROR_NO_MQUSER_OU => "There is no MSMQ Users organizational unit object in Active Directory Domain Services for the domain. Please create one manually.",
            MSMQ::MQ_ERROR_CANNOT_LOAD_MQAD => "The dynamic-link library Mqad.dll cannot be loaded.",
            MSMQ::MQ_ERROR_CANNOT_LOAD_MQDSSRV => "Obsolete, kept for backward compatibility",
            MSMQ::MQ_ERROR_PROPERTIES_CONFLICT => "Two or more of the properties passed cannot co-exist. For example, you cannot set both PROPID_M_RESP_QUEUE and PROPID_M_RESP_FORMAT_NAME when sending a message.",
            MSMQ::MQ_ERROR_MESSAGE_NOT_FOUND => "The message does not exist or was removed from the queue.",
            MSMQ::MQ_ERROR_CANT_RESOLVE_SITES => "The sites where the computer resides cannot be resolved. Check that the subnets in your network are configured correctly in Active Directory Domain Services and that each site is configured with the appropriate subnet.",
            MSMQ::MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS => "This operation is not supported by dependent clients.",
            MSMQ::MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER => "This operation is not supported by the remote Message Queuing service. For example, MQReceiveMessageByLookupId is not supported by MSMQ 1.0/2.0.",
            MSMQ::MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS => "The object whose properties are being retrieved from Active Directory Domain Services does not belong to the class requested.",
            MSMQ::MQ_ERROR_MULTI_SORT_KEYS => "The value of cCol in MQSORTSET cannot be greater than 1. Active Directory Domain Services supports only a single sort key.",
            MSMQ::MQ_ERROR_GC_NEEDED => "An MSMQ Configuration (msmq) object with the GUID supplied cannot be created. By default, an Active Directory Domain Services forest does not support adding an object with a supplied GUID.",
            MSMQ::MQ_ERROR_DS_BIND_ROOT_FOREST => "Binding to the forest root failed. This error usually indicates a problem in the DNS configuration.",
            MSMQ::MQ_ERROR_DS_LOCAL_USER => "A local user is authenticated as an anonymous user and cannot access Active Directory Domain Services. You need to log on as a domain user to access Active Directory Domain Services.",
            MSMQ::MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED => "The column PROPID_Q_ADS_PATH is not supported for the MQLocateBegin API.",
            MSMQ::MQ_ERROR_BAD_XML_FORMAT => "The given property is not a valid XML document.",
            MSMQ::MQ_ERROR_UNSUPPORTED_CLASS => "The Active Directory Domain Services object specified is not an instance of a supported class.",
            MSMQ::MQ_ERROR_UNINITIALIZED_OBJECT => "The MSMQManagement object must be initialized before it is used.",
            MSMQ::MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS => "The object that will be created should be owned by a primary site controller. The operation cannot be performed.",
            MSMQ::MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS => "The object that will be updated is owned by a primary site controller. The operation cannot be performed.",
            MSMQ::MQ_ERROR_RESOLVE_ADDRESS => "Message Queuing is not able to resolve the address specified by the user. The address may be wrong or DNS look-up for address failed.",
            MSMQ::MQ_ERROR_TOO_MANY_PROPERTIES => "Too many properties passed to the function. Message Queuing can process up to 128 properties in one call.",
            MSMQ::MQ_ERROR_MESSAGE_NOT_AUTHENTICATED => "The queue only accepts authenticated messages.",
            MSMQ::MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION => "The message is currently being processed under a transaction. Till the transaction outcome is determined, the message cannot be processed in any other transaction.",
        }
    }

    pub fn from_name(name: &str) -> MSMQ {
        return match name {
            "MQ_ERROR" => MSMQ::MQ_ERROR,
            "MQ_ERROR_PROPERTY" => MSMQ::MQ_ERROR_PROPERTY,
            "MQ_ERROR_QUEUE_NOT_FOUND" => MSMQ::MQ_ERROR_QUEUE_NOT_FOUND,
            "MQ_ERROR_QUEUE_NOT_ACTIVE" => MSMQ::MQ_ERROR_QUEUE_NOT_ACTIVE,
            "MQ_ERROR_QUEUE_EXISTS" => MSMQ::MQ_ERROR_QUEUE_EXISTS,
            "MQ_ERROR_INVALID_PARAMETER" => MSMQ::MQ_ERROR_INVALID_PARAMETER,
            "MQ_ERROR_INVALID_HANDLE" => MSMQ::MQ_ERROR_INVALID_HANDLE,
            "MQ_ERROR_OPERATION_CANCELLED" => MSMQ::MQ_ERROR_OPERATION_CANCELLED,
            "MQ_ERROR_SHARING_VIOLATION" => MSMQ::MQ_ERROR_SHARING_VIOLATION,
            "MQ_ERROR_SERVICE_NOT_AVAILABLE" => MSMQ::MQ_ERROR_SERVICE_NOT_AVAILABLE,
            "MQ_ERROR_MACHINE_NOT_FOUND" => MSMQ::MQ_ERROR_MACHINE_NOT_FOUND,
            "MQ_ERROR_ILLEGAL_SORT" => MSMQ::MQ_ERROR_ILLEGAL_SORT,
            "MQ_ERROR_ILLEGAL_USER" => MSMQ::MQ_ERROR_ILLEGAL_USER,
            "MQ_ERROR_NO_DS" => MSMQ::MQ_ERROR_NO_DS,
            "MQ_ERROR_ILLEGAL_QUEUE_PATHNAME" => MSMQ::MQ_ERROR_ILLEGAL_QUEUE_PATHNAME,
            "MQ_ERROR_ILLEGAL_PROPERTY_VALUE" => MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VALUE,
            "MQ_ERROR_ILLEGAL_PROPERTY_VT" => MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VT,
            "MQ_ERROR_BUFFER_OVERFLOW" => MSMQ::MQ_ERROR_BUFFER_OVERFLOW,
            "MQ_ERROR_IO_TIMEOUT" => MSMQ::MQ_ERROR_IO_TIMEOUT,
            "MQ_ERROR_ILLEGAL_CURSOR_ACTION" => MSMQ::MQ_ERROR_ILLEGAL_CURSOR_ACTION,
            "MQ_ERROR_MESSAGE_ALREADY_RECEIVED" => MSMQ::MQ_ERROR_MESSAGE_ALREADY_RECEIVED,
            "MQ_ERROR_ILLEGAL_FORMATNAME" => MSMQ::MQ_ERROR_ILLEGAL_FORMATNAME,
            "MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL,
            "MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION" => MSMQ::MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION,
            "MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR" => MSMQ::MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR,
            "MQ_ERROR_SENDERID_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_SENDERID_BUFFER_TOO_SMALL,
            "MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL" => MSMQ::MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL,
            "MQ_ERROR_CANNOT_IMPERSONATE_CLIENT" => MSMQ::MQ_ERROR_CANNOT_IMPERSONATE_CLIENT,
            "MQ_ERROR_ACCESS_DENIED" => MSMQ::MQ_ERROR_ACCESS_DENIED,
            "MQ_ERROR_PRIVILEGE_NOT_HELD" => MSMQ::MQ_ERROR_PRIVILEGE_NOT_HELD,
            "MQ_ERROR_INSUFFICIENT_RESOURCES" => MSMQ::MQ_ERROR_INSUFFICIENT_RESOURCES,
            "MQ_ERROR_USER_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_USER_BUFFER_TOO_SMALL,
            "MQ_ERROR_MESSAGE_STORAGE_FAILED" => MSMQ::MQ_ERROR_MESSAGE_STORAGE_FAILED,
            "MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL,
            "MQ_ERROR_INVALID_CERTIFICATE" => MSMQ::MQ_ERROR_INVALID_CERTIFICATE,
            "MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE" => MSMQ::MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE,
            "MQ_ERROR_INTERNAL_USER_CERT_EXIST" => MSMQ::MQ_ERROR_INTERNAL_USER_CERT_EXIST,
            "MQ_ERROR_NO_INTERNAL_USER_CERT" => MSMQ::MQ_ERROR_NO_INTERNAL_USER_CERT,
            "MQ_ERROR_CORRUPTED_SECURITY_DATA" => MSMQ::MQ_ERROR_CORRUPTED_SECURITY_DATA,
            "MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE" => MSMQ::MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE,
            "MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION" => MSMQ::MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION,
            "MQ_ERROR_BAD_SECURITY_CONTEXT" => MSMQ::MQ_ERROR_BAD_SECURITY_CONTEXT,
            "MQ_ERROR_COULD_NOT_GET_USER_SID" => MSMQ::MQ_ERROR_COULD_NOT_GET_USER_SID,
            "MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO" => MSMQ::MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO,
            "MQ_ERROR_ILLEGAL_MQCOLUMNS" => MSMQ::MQ_ERROR_ILLEGAL_MQCOLUMNS,
            "MQ_ERROR_ILLEGAL_PROPID" => MSMQ::MQ_ERROR_ILLEGAL_PROPID,
            "MQ_ERROR_ILLEGAL_RELATION" => MSMQ::MQ_ERROR_ILLEGAL_RELATION,
            "MQ_ERROR_ILLEGAL_PROPERTY_SIZE" => MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_SIZE,
            "MQ_ERROR_ILLEGAL_RESTRICTION_PROPID" => MSMQ::MQ_ERROR_ILLEGAL_RESTRICTION_PROPID,
            "MQ_ERROR_ILLEGAL_MQQUEUEPROPS" => MSMQ::MQ_ERROR_ILLEGAL_MQQUEUEPROPS,
            "MQ_ERROR_PROPERTY_NOTALLOWED" => MSMQ::MQ_ERROR_PROPERTY_NOTALLOWED,
            "MQ_ERROR_INSUFFICIENT_PROPERTIES" => MSMQ::MQ_ERROR_INSUFFICIENT_PROPERTIES,
            "MQ_ERROR_MACHINE_EXISTS" => MSMQ::MQ_ERROR_MACHINE_EXISTS,
            "MQ_ERROR_ILLEGAL_MQQMPROPS" => MSMQ::MQ_ERROR_ILLEGAL_MQQMPROPS,
            "MQ_ERROR_DS_IS_FULL" => MSMQ::MQ_ERROR_DS_IS_FULL,
            "MQ_ERROR_DS_ERROR" => MSMQ::MQ_ERROR_DS_ERROR,
            "MQ_ERROR_INVALID_OWNER" => MSMQ::MQ_ERROR_INVALID_OWNER,
            "MQ_ERROR_UNSUPPORTED_ACCESS_MODE" => MSMQ::MQ_ERROR_UNSUPPORTED_ACCESS_MODE,
            "MQ_ERROR_RESULT_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_RESULT_BUFFER_TOO_SMALL,
            "MQ_ERROR_DELETE_CN_IN_USE" => MSMQ::MQ_ERROR_DELETE_CN_IN_USE,
            "MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER" => MSMQ::MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER,
            "MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE" => MSMQ::MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE,
            "MQ_ERROR_QUEUE_NOT_AVAILABLE" => MSMQ::MQ_ERROR_QUEUE_NOT_AVAILABLE,
            "MQ_ERROR_DTC_CONNECT" => MSMQ::MQ_ERROR_DTC_CONNECT,
            "MQ_ERROR_TRANSACTION_IMPORT" => MSMQ::MQ_ERROR_TRANSACTION_IMPORT,
            "MQ_ERROR_TRANSACTION_USAGE" => MSMQ::MQ_ERROR_TRANSACTION_USAGE,
            "MQ_ERROR_TRANSACTION_SEQUENCE" => MSMQ::MQ_ERROR_TRANSACTION_SEQUENCE,
            "MQ_ERROR_MISSING_CONNECTOR_TYPE" => MSMQ::MQ_ERROR_MISSING_CONNECTOR_TYPE,
            "MQ_ERROR_STALE_HANDLE" => MSMQ::MQ_ERROR_STALE_HANDLE,
            "MQ_ERROR_TRANSACTION_ENLIST" => MSMQ::MQ_ERROR_TRANSACTION_ENLIST,
            "MQ_ERROR_QUEUE_DELETED" => MSMQ::MQ_ERROR_QUEUE_DELETED,
            "MQ_ERROR_ILLEGAL_CONTEXT" => MSMQ::MQ_ERROR_ILLEGAL_CONTEXT,
            "MQ_ERROR_ILLEGAL_SORT_PROPID" => MSMQ::MQ_ERROR_ILLEGAL_SORT_PROPID,
            "MQ_ERROR_LABEL_TOO_LONG" => MSMQ::MQ_ERROR_LABEL_TOO_LONG,
            "MQ_ERROR_LABEL_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_LABEL_BUFFER_TOO_SMALL,
            "MQ_ERROR_MQIS_SERVER_EMPTY" => MSMQ::MQ_ERROR_MQIS_SERVER_EMPTY,
            "MQ_ERROR_MQIS_READONLY_MODE" => MSMQ::MQ_ERROR_MQIS_READONLY_MODE,
            "MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL,
            "MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL,
            "MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL" => MSMQ::MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL,
            "MQ_ERROR_ILLEGAL_OPERATION" => MSMQ::MQ_ERROR_ILLEGAL_OPERATION,
            "MQ_ERROR_WRITE_NOT_ALLOWED" => MSMQ::MQ_ERROR_WRITE_NOT_ALLOWED,
            "MQ_ERROR_WKS_CANT_SERVE_CLIENT" => MSMQ::MQ_ERROR_WKS_CANT_SERVE_CLIENT,
            "MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW" => MSMQ::MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW,
            "MQ_CORRUPTED_QUEUE_WAS_DELETED" => MSMQ::MQ_CORRUPTED_QUEUE_WAS_DELETED,
            "MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE" => MSMQ::MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE,
            "MQ_ERROR_UNSUPPORTED_OPERATION" => MSMQ::MQ_ERROR_UNSUPPORTED_OPERATION,
            "MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED" => MSMQ::MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED,
            "MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR" => MSMQ::MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR,
            "MQ_ERROR_CERTIFICATE_NOT_PROVIDED" => MSMQ::MQ_ERROR_CERTIFICATE_NOT_PROVIDED,
            "MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED" => MSMQ::MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED,
            "MQ_ERROR_CANNOT_CREATE_CERT_STORE" => MSMQ::MQ_ERROR_CANNOT_CREATE_CERT_STORE,
            "MQ_ERROR_CANNOT_OPEN_CERT_STORE" => MSMQ::MQ_ERROR_CANNOT_OPEN_CERT_STORE,
            "MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION" => MSMQ::MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION,
            "MQ_ERROR_CANNOT_GRANT_ADD_GUID" => MSMQ::MQ_ERROR_CANNOT_GRANT_ADD_GUID,
            "MQ_ERROR_CANNOT_LOAD_MSMQOCM" => MSMQ::MQ_ERROR_CANNOT_LOAD_MSMQOCM,
            "MQ_ERROR_NO_ENTRY_POINT_MSMQOCM" => MSMQ::MQ_ERROR_NO_ENTRY_POINT_MSMQOCM,
            "MQ_ERROR_NO_MSMQ_SERVERS_ON_DC" => MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_DC,
            "MQ_ERROR_CANNOT_JOIN_DOMAIN" => MSMQ::MQ_ERROR_CANNOT_JOIN_DOMAIN,
            "MQ_ERROR_CANNOT_CREATE_ON_GC" => MSMQ::MQ_ERROR_CANNOT_CREATE_ON_GC,
            "MQ_ERROR_GUID_NOT_MATCHING" => MSMQ::MQ_ERROR_GUID_NOT_MATCHING,
            "MQ_ERROR_PUBLIC_KEY_NOT_FOUND" => MSMQ::MQ_ERROR_PUBLIC_KEY_NOT_FOUND,
            "MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST" => MSMQ::MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST,
            "MQ_ERROR_ILLEGAL_MQPRIVATEPROPS" => MSMQ::MQ_ERROR_ILLEGAL_MQPRIVATEPROPS,
            "MQ_ERROR_NO_GC_IN_DOMAIN" => MSMQ::MQ_ERROR_NO_GC_IN_DOMAIN,
            "MQ_ERROR_NO_MSMQ_SERVERS_ON_GC" => MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_GC,
            "MQ_ERROR_CANNOT_GET_DN" => MSMQ::MQ_ERROR_CANNOT_GET_DN,
            "MQ_ERROR_CANNOT_HASH_DATA_EX" => MSMQ::MQ_ERROR_CANNOT_HASH_DATA_EX,
            "MQ_ERROR_CANNOT_SIGN_DATA_EX" => MSMQ::MQ_ERROR_CANNOT_SIGN_DATA_EX,
            "MQ_ERROR_CANNOT_CREATE_HASH_EX" => MSMQ::MQ_ERROR_CANNOT_CREATE_HASH_EX,
            "MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX" => MSMQ::MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX,
            "MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS" => MSMQ::MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS,
            "MQ_ERROR_NO_MQUSER_OU" => MSMQ::MQ_ERROR_NO_MQUSER_OU,
            "MQ_ERROR_CANNOT_LOAD_MQAD" => MSMQ::MQ_ERROR_CANNOT_LOAD_MQAD,
            "MQ_ERROR_CANNOT_LOAD_MQDSSRV" => MSMQ::MQ_ERROR_CANNOT_LOAD_MQDSSRV,
            "MQ_ERROR_PROPERTIES_CONFLICT" => MSMQ::MQ_ERROR_PROPERTIES_CONFLICT,
            "MQ_ERROR_MESSAGE_NOT_FOUND" => MSMQ::MQ_ERROR_MESSAGE_NOT_FOUND,
            "MQ_ERROR_CANT_RESOLVE_SITES" => MSMQ::MQ_ERROR_CANT_RESOLVE_SITES,
            "MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS" => MSMQ::MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS,
            "MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER" => MSMQ::MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER,
            "MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS" => MSMQ::MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS,
            "MQ_ERROR_MULTI_SORT_KEYS" => MSMQ::MQ_ERROR_MULTI_SORT_KEYS,
            "MQ_ERROR_GC_NEEDED" => MSMQ::MQ_ERROR_GC_NEEDED,
            "MQ_ERROR_DS_BIND_ROOT_FOREST" => MSMQ::MQ_ERROR_DS_BIND_ROOT_FOREST,
            "MQ_ERROR_DS_LOCAL_USER" => MSMQ::MQ_ERROR_DS_LOCAL_USER,
            "MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED" => MSMQ::MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED,
            "MQ_ERROR_BAD_XML_FORMAT" => MSMQ::MQ_ERROR_BAD_XML_FORMAT,
            "MQ_ERROR_UNSUPPORTED_CLASS" => MSMQ::MQ_ERROR_UNSUPPORTED_CLASS,
            "MQ_ERROR_UNINITIALIZED_OBJECT" => MSMQ::MQ_ERROR_UNINITIALIZED_OBJECT,
            "MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS" => MSMQ::MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS,
            "MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS" => MSMQ::MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS,
            "MQ_ERROR_RESOLVE_ADDRESS" => MSMQ::MQ_ERROR_RESOLVE_ADDRESS,
            "MQ_ERROR_TOO_MANY_PROPERTIES" => MSMQ::MQ_ERROR_TOO_MANY_PROPERTIES,
            "MQ_ERROR_MESSAGE_NOT_AUTHENTICATED" => MSMQ::MQ_ERROR_MESSAGE_NOT_AUTHENTICATED,
            "MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION" => MSMQ::MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION,
        }
    }
    pub fn from_code(code: u32) -> MSMQ {
        return match code {
            0xC00E0001 => MSMQ::MQ_ERROR,
            0xC00E0002 => MSMQ::MQ_ERROR_PROPERTY,
            0xC00E0003 => MSMQ::MQ_ERROR_QUEUE_NOT_FOUND,
            0xC00E0004 => MSMQ::MQ_ERROR_QUEUE_NOT_ACTIVE,
            0xC00E0005 => MSMQ::MQ_ERROR_QUEUE_EXISTS,
            0xC00E0006 => MSMQ::MQ_ERROR_INVALID_PARAMETER,
            0xC00E0007 => MSMQ::MQ_ERROR_INVALID_HANDLE,
            0xC00E0008 => MSMQ::MQ_ERROR_OPERATION_CANCELLED,
            0xC00E0009 => MSMQ::MQ_ERROR_SHARING_VIOLATION,
            0xC00E000B => MSMQ::MQ_ERROR_SERVICE_NOT_AVAILABLE,
            0xC00E000D => MSMQ::MQ_ERROR_MACHINE_NOT_FOUND,
            0xC00E0010 => MSMQ::MQ_ERROR_ILLEGAL_SORT,
            0xC00E0011 => MSMQ::MQ_ERROR_ILLEGAL_USER,
            0xC00E0013 => MSMQ::MQ_ERROR_NO_DS,
            0xC00E0014 => MSMQ::MQ_ERROR_ILLEGAL_QUEUE_PATHNAME,
            0xC00E0018 => MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VALUE,
            0xC00E0019 => MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_VT,
            0xC00E001A => MSMQ::MQ_ERROR_BUFFER_OVERFLOW,
            0xC00E001B => MSMQ::MQ_ERROR_IO_TIMEOUT,
            0xC00E001C => MSMQ::MQ_ERROR_ILLEGAL_CURSOR_ACTION,
            0xC00E001D => MSMQ::MQ_ERROR_MESSAGE_ALREADY_RECEIVED,
            0xC00E001E => MSMQ::MQ_ERROR_ILLEGAL_FORMATNAME,
            0xC00E001F => MSMQ::MQ_ERROR_FORMATNAME_BUFFER_TOO_SMALL,
            0xC00E0020 => MSMQ::MQ_ERROR_UNSUPPORTED_FORMATNAME_OPERATION,
            0xC00E0021 => MSMQ::MQ_ERROR_ILLEGAL_SECURITY_DESCRIPTOR,
            0xC00E0022 => MSMQ::MQ_ERROR_SENDERID_BUFFER_TOO_SMALL,
            0xC00E0023 => MSMQ::MQ_ERROR_SECURITY_DESCRIPTOR_TOO_SMALL,
            0xC00E0024 => MSMQ::MQ_ERROR_CANNOT_IMPERSONATE_CLIENT,
            0xC00E0025 => MSMQ::MQ_ERROR_ACCESS_DENIED,
            0xC00E0026 => MSMQ::MQ_ERROR_PRIVILEGE_NOT_HELD,
            0xC00E0027 => MSMQ::MQ_ERROR_INSUFFICIENT_RESOURCES,
            0xC00E0028 => MSMQ::MQ_ERROR_USER_BUFFER_TOO_SMALL,
            0xC00E002A => MSMQ::MQ_ERROR_MESSAGE_STORAGE_FAILED,
            0xC00E002B => MSMQ::MQ_ERROR_SENDER_CERT_BUFFER_TOO_SMALL,
            0xC00E002C => MSMQ::MQ_ERROR_INVALID_CERTIFICATE,
            0xC00E002D => MSMQ::MQ_ERROR_CORRUPTED_INTERNAL_CERTIFICATE,
            0xC00E002E => MSMQ::MQ_ERROR_INTERNAL_USER_CERT_EXIST,
            0xC00E002F => MSMQ::MQ_ERROR_NO_INTERNAL_USER_CERT,
            0xC00E0030 => MSMQ::MQ_ERROR_CORRUPTED_SECURITY_DATA,
            0xC00E0031 => MSMQ::MQ_ERROR_CORRUPTED_PERSONAL_CERT_STORE,
            0xC00E0033 => MSMQ::MQ_ERROR_COMPUTER_DOES_NOT_SUPPORT_ENCRYPTION,
            0xC00E0035 => MSMQ::MQ_ERROR_BAD_SECURITY_CONTEXT,
            0xC00E0036 => MSMQ::MQ_ERROR_COULD_NOT_GET_USER_SID,
            0xC00E0037 => MSMQ::MQ_ERROR_COULD_NOT_GET_ACCOUNT_INFO,
            0xC00E0038 => MSMQ::MQ_ERROR_ILLEGAL_MQCOLUMNS,
            0xC00E0039 => MSMQ::MQ_ERROR_ILLEGAL_PROPID,
            0xC00E003A => MSMQ::MQ_ERROR_ILLEGAL_RELATION,
            0xC00E003B => MSMQ::MQ_ERROR_ILLEGAL_PROPERTY_SIZE,
            0xC00E003C => MSMQ::MQ_ERROR_ILLEGAL_RESTRICTION_PROPID,
            0xC00E003D => MSMQ::MQ_ERROR_ILLEGAL_MQQUEUEPROPS,
            0xC00E003E => MSMQ::MQ_ERROR_PROPERTY_NOTALLOWED,
            0xC00E003F => MSMQ::MQ_ERROR_INSUFFICIENT_PROPERTIES,
            0xC00E0040 => MSMQ::MQ_ERROR_MACHINE_EXISTS,
            0xC00E0041 => MSMQ::MQ_ERROR_ILLEGAL_MQQMPROPS,
            0xC00E0042 => MSMQ::MQ_ERROR_DS_IS_FULL,
            0xC00E0043 => MSMQ::MQ_ERROR_DS_ERROR,
            0xC00E0044 => MSMQ::MQ_ERROR_INVALID_OWNER,
            0xC00E0045 => MSMQ::MQ_ERROR_UNSUPPORTED_ACCESS_MODE,
            0xC00E0046 => MSMQ::MQ_ERROR_RESULT_BUFFER_TOO_SMALL,
            0xC00E0048 => MSMQ::MQ_ERROR_DELETE_CN_IN_USE,
            0xC00E0049 => MSMQ::MQ_ERROR_NO_RESPONSE_FROM_OBJECT_SERVER,
            0xC00E004A => MSMQ::MQ_ERROR_OBJECT_SERVER_NOT_AVAILABLE,
            0xC00E004B => MSMQ::MQ_ERROR_QUEUE_NOT_AVAILABLE,
            0xC00E004C => MSMQ::MQ_ERROR_DTC_CONNECT,
            0xC00E004E => MSMQ::MQ_ERROR_TRANSACTION_IMPORT,
            0xC00E0050 => MSMQ::MQ_ERROR_TRANSACTION_USAGE,
            0xC00E0051 => MSMQ::MQ_ERROR_TRANSACTION_SEQUENCE,
            0xC00E0055 => MSMQ::MQ_ERROR_MISSING_CONNECTOR_TYPE,
            0xC00E0056 => MSMQ::MQ_ERROR_STALE_HANDLE,
            0xC00E0058 => MSMQ::MQ_ERROR_TRANSACTION_ENLIST,
            0xC00E005A => MSMQ::MQ_ERROR_QUEUE_DELETED,
            0xC00E005B => MSMQ::MQ_ERROR_ILLEGAL_CONTEXT,
            0xC00E005C => MSMQ::MQ_ERROR_ILLEGAL_SORT_PROPID,
            0xC00E005D => MSMQ::MQ_ERROR_LABEL_TOO_LONG,
            0xC00E005E => MSMQ::MQ_ERROR_LABEL_BUFFER_TOO_SMALL,
            0xC00E005F => MSMQ::MQ_ERROR_MQIS_SERVER_EMPTY,
            0xC00E0060 => MSMQ::MQ_ERROR_MQIS_READONLY_MODE,
            0xC00E0061 => MSMQ::MQ_ERROR_SYMM_KEY_BUFFER_TOO_SMALL,
            0xC00E0062 => MSMQ::MQ_ERROR_SIGNATURE_BUFFER_TOO_SMALL,
            0xC00E0063 => MSMQ::MQ_ERROR_PROV_NAME_BUFFER_TOO_SMALL,
            0xC00E0064 => MSMQ::MQ_ERROR_ILLEGAL_OPERATION,
            0xC00E0065 => MSMQ::MQ_ERROR_WRITE_NOT_ALLOWED,
            0xC00E0066 => MSMQ::MQ_ERROR_WKS_CANT_SERVE_CLIENT,
            0xC00E0067 => MSMQ::MQ_ERROR_DEPEND_WKS_LICENSE_OVERFLOW,
            0xC00E0068 => MSMQ::MQ_CORRUPTED_QUEUE_WAS_DELETED,
            0xC00E0069 => MSMQ::MQ_ERROR_REMOTE_MACHINE_NOT_AVAILABLE,
            0xC00E006A => MSMQ::MQ_ERROR_UNSUPPORTED_OPERATION,
            0xC00E006B => MSMQ::MQ_ERROR_ENCRYPTION_PROVIDER_NOT_SUPPORTED,
            0xC00E006C => MSMQ::MQ_ERROR_CANNOT_SET_CRYPTO_SEC_DESCR,
            0xC00E006D => MSMQ::MQ_ERROR_CERTIFICATE_NOT_PROVIDED,
            0xC00E006E => MSMQ::MQ_ERROR_Q_DNS_PROPERTY_NOT_SUPPORTED,
            0xC00E006F => MSMQ::MQ_ERROR_CANNOT_CREATE_CERT_STORE,
            0xC00E0070 => MSMQ::MQ_ERROR_CANNOT_OPEN_CERT_STORE,
            0xC00E0071 => MSMQ::MQ_ERROR_ILLEGAL_ENTERPRISE_OPERATION,
            0xC00E0072 => MSMQ::MQ_ERROR_CANNOT_GRANT_ADD_GUID,
            0xC00E0073 => MSMQ::MQ_ERROR_CANNOT_LOAD_MSMQOCM,
            0xC00E0074 => MSMQ::MQ_ERROR_NO_ENTRY_POINT_MSMQOCM,
            0xC00E0075 => MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_DC,
            0xC00E0076 => MSMQ::MQ_ERROR_CANNOT_JOIN_DOMAIN,
            0xC00E0077 => MSMQ::MQ_ERROR_CANNOT_CREATE_ON_GC,
            0xC00E0078 => MSMQ::MQ_ERROR_GUID_NOT_MATCHING,
            0xC00E0079 => MSMQ::MQ_ERROR_PUBLIC_KEY_NOT_FOUND,
            0xC00E007A => MSMQ::MQ_ERROR_PUBLIC_KEY_DOES_NOT_EXIST,
            0xC00E007B => MSMQ::MQ_ERROR_ILLEGAL_MQPRIVATEPROPS,
            0xC00E007C => MSMQ::MQ_ERROR_NO_GC_IN_DOMAIN,
            0xC00E007D => MSMQ::MQ_ERROR_NO_MSMQ_SERVERS_ON_GC,
            0xC00E007E => MSMQ::MQ_ERROR_CANNOT_GET_DN,
            0xC00E007F => MSMQ::MQ_ERROR_CANNOT_HASH_DATA_EX,
            0xC00E0080 => MSMQ::MQ_ERROR_CANNOT_SIGN_DATA_EX,
            0xC00E0081 => MSMQ::MQ_ERROR_CANNOT_CREATE_HASH_EX,
            0xC00E0082 => MSMQ::MQ_ERROR_FAIL_VERIFY_SIGNATURE_EX,
            0xC00E0083 => MSMQ::MQ_ERROR_CANNOT_DELETE_PSC_OBJECTS,
            0xC00E0084 => MSMQ::MQ_ERROR_NO_MQUSER_OU,
            0xC00E0085 => MSMQ::MQ_ERROR_CANNOT_LOAD_MQAD,
            0xC00E0086 => MSMQ::MQ_ERROR_CANNOT_LOAD_MQDSSRV,
            0xC00E0087 => MSMQ::MQ_ERROR_PROPERTIES_CONFLICT,
            0xC00E0088 => MSMQ::MQ_ERROR_MESSAGE_NOT_FOUND,
            0xC00E0089 => MSMQ::MQ_ERROR_CANT_RESOLVE_SITES,
            0xC00E008A => MSMQ::MQ_ERROR_NOT_SUPPORTED_BY_DEPENDENT_CLIENTS,
            0xC00E008B => MSMQ::MQ_ERROR_OPERATION_NOT_SUPPORTED_BY_REMOTE_COMPUTER,
            0xC00E008C => MSMQ::MQ_ERROR_NOT_A_CORRECT_OBJECT_CLASS,
            0xC00E008D => MSMQ::MQ_ERROR_MULTI_SORT_KEYS,
            0xC00E008E => MSMQ::MQ_ERROR_GC_NEEDED,
            0xC00E008F => MSMQ::MQ_ERROR_DS_BIND_ROOT_FOREST,
            0xC00E0090 => MSMQ::MQ_ERROR_DS_LOCAL_USER,
            0xC00E0091 => MSMQ::MQ_ERROR_Q_ADS_PROPERTY_NOT_SUPPORTED,
            0xC00E0092 => MSMQ::MQ_ERROR_BAD_XML_FORMAT,
            0xC00E0093 => MSMQ::MQ_ERROR_UNSUPPORTED_CLASS,
            0xC00E0094 => MSMQ::MQ_ERROR_UNINITIALIZED_OBJECT,
            0xC00E0095 => MSMQ::MQ_ERROR_CANNOT_CREATE_PSC_OBJECTS,
            0xC00E0096 => MSMQ::MQ_ERROR_CANNOT_UPDATE_PSC_OBJECTS,
            0xC00E0099 => MSMQ::MQ_ERROR_RESOLVE_ADDRESS,
            0xC00E009A => MSMQ::MQ_ERROR_TOO_MANY_PROPERTIES,
            0xC00E009B => MSMQ::MQ_ERROR_MESSAGE_NOT_AUTHENTICATED,
            0xC00E009C => MSMQ::MQ_ERROR_MESSAGE_LOCKED_UNDER_TRANSACTION,
        }
    }
}
