/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum NULL {
    ERROR_SUCCESS,
    PDH_CSTATUS_VALID_DATA,
    SUCCESS,
    NERR_Success,
    S_OK,
    NOERROR,
    S_FALSE,
    E_NOTIMPL,
    E_OUTOFMEMORY,
    E_INVALIDARG,
    E_NOINTERFACE,
    E_POINTER,
    E_HANDLE,
    E_ABORT,
    E_FAIL,
    E_ACCESSDENIED,
    E_PENDING,
    E_BOUNDS,
    E_CHANGED_STATE,
    E_ILLEGAL_STATE_CHANGE,
    E_ILLEGAL_METHOD_CALL,
    RO_E_METADATA_NAME_NOT_FOUND,
    RO_E_METADATA_NAME_IS_NAMESPACE,
    RO_E_METADATA_INVALID_TYPE_FORMAT,
    RO_E_INVALID_METADATA_FILE,
    RO_E_CLOSED,
    RO_E_EXCLUSIVE_WRITE,
    RO_E_CHANGE_NOTIFICATION_IN_PROGRESS,
    RO_E_ERROR_STRING_NOT_FOUND,
    E_STRING_NOT_NULL_TERMINATED,
    E_ILLEGAL_DELEGATE_ASSIGNMENT,
    E_ASYNC_OPERATION_NOT_STARTED,
    E_APPLICATION_EXITING,
    E_APPLICATION_VIEW_EXITING,
    RO_E_MUST_BE_AGILE,
    RO_E_UNSUPPORTED_FROM_MTA,
    RO_E_COMMITTED,
    RO_E_BLOCKED_CROSS_ASTA_CALL,
    RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER,
    RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER,
    PDH_CSTATUS_NO_MACHINE,
    PDH_CSTATUS_NO_INSTANCE,
    PDH_MORE_DATA,
    PDH_CSTATUS_ITEM_NOT_VALIDATED,
    PDH_RETRY,
    PDH_NO_DATA,
    PDH_CALC_NEGATIVE_DENOMINATOR,
    PDH_CALC_NEGATIVE_TIMEBASE,
    PDH_CALC_NEGATIVE_VALUE,
    PDH_DIALOG_CANCELLED,
    PDH_END_OF_LOG_FILE,
    PDH_ASYNC_QUERY_TIMEOUT,
    PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE,
    PDH_UNABLE_MAP_NAME_FILES,
    PDH_PLA_VALIDATION_WARNING,
    DDERR_UNSUPPORTED,
    DDERR_GENERIC,
    CO_E_INIT_TLS,
    CO_E_INIT_SHARED_ALLOCATOR,
    CO_E_INIT_MEMORY_ALLOCATOR,
    CO_E_INIT_CLASS_CACHE,
    CO_E_INIT_RPC_CHANNEL,
    CO_E_INIT_TLS_SET_CHANNEL_CONTROL,
    CO_E_INIT_TLS_CHANNEL_CONTROL,
    CO_E_INIT_UNACCEPTED_USER_ALLOCATOR,
    CO_E_INIT_SCM_MUTEX_EXISTS,
    CO_E_INIT_SCM_FILE_MAPPING_EXISTS,
    CO_E_INIT_SCM_MAP_VIEW_OF_FILE,
    CO_E_INIT_SCM_EXEC_FAILURE,
    CO_E_INIT_ONLY_SINGLE_THREADED,
    CO_E_CANT_REMOTE,
    CO_E_BAD_SERVER_NAME,
    CO_E_WRONG_SERVER_IDENTITY,
    CO_E_OLE1DDE_DISABLED,
    CO_E_RUNAS_SYNTAX,
    CO_E_CREATEPROCESS_FAILURE,
    CO_E_RUNAS_CREATEPROCESS_FAILURE,
    CO_E_RUNAS_LOGON_FAILURE,
    CO_E_LAUNCH_PERMSSION_DENIED,
    CO_E_START_SERVICE_FAILURE,
    CO_E_REMOTE_COMMUNICATION_FAILURE,
    CO_E_SERVER_START_TIMEOUT,
    CO_E_CLSREG_INCONSISTENT,
    CO_E_IIDREG_INCONSISTENT,
    CO_E_NOT_SUPPORTED,
    CO_E_RELOAD_DLL,
    CO_E_MSI_ERROR,
    CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT,
    CO_E_SERVER_PAUSED,
    CO_E_SERVER_NOT_PAUSED,
    CO_E_CLASS_DISABLED,
    CO_E_CLRNOTAVAILABLE,
    CO_E_ASYNC_WORK_REJECTED,
    CO_E_SERVER_INIT_TIMEOUT,
    CO_E_NO_SECCTX_IN_ACTIVATE,
    CO_E_TRACKER_CONFIG,
    CO_E_THREADPOOL_CONFIG,
    CO_E_SXS_CONFIG,
    CO_E_MALFORMED_SPN,
    CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN,
    CO_E_PREMATURE_STUB_RUNDOWN,
    E_UNEXPECTED,
    PDH_CSTATUS_NO_OBJECT,
    PDH_CSTATUS_NO_COUNTER,
    PDH_CSTATUS_INVALID_DATA,
    PDH_MEMORY_ALLOCATION_FAILURE,
    PDH_INVALID_HANDLE,
    PDH_INVALID_ARGUMENT,
    PDH_FUNCTION_NOT_FOUND,
    PDH_CSTATUS_NO_COUNTERNAME,
    PDH_CSTATUS_BAD_COUNTERNAME,
    PDH_INVALID_BUFFER,
    PDH_INSUFFICIENT_BUFFER,
    PDH_CANNOT_CONNECT_MACHINE,
    PDH_INVALID_PATH,
    PDH_INVALID_INSTANCE,
    PDH_INVALID_DATA,
    PDH_NO_DIALOG_DATA,
    PDH_CANNOT_READ_NAME_STRINGS,
    PDH_LOG_FILE_CREATE_ERROR,
    PDH_LOG_FILE_OPEN_ERROR,
    PDH_LOG_TYPE_NOT_FOUND,
    PDH_NO_MORE_DATA,
    PDH_ENTRY_NOT_IN_LOG_FILE,
    PDH_DATA_SOURCE_IS_LOG_FILE,
    PDH_DATA_SOURCE_IS_REAL_TIME,
    PDH_UNABLE_READ_LOG_HEADER,
    PDH_FILE_NOT_FOUND,
    PDH_FILE_ALREADY_EXISTS,
    PDH_NOT_IMPLEMENTED,
    PDH_STRING_NOT_FOUND,
    PDH_UNKNOWN_LOG_FORMAT,
    PDH_UNKNOWN_LOGSVC_COMMAND,
    PDH_LOGSVC_QUERY_NOT_FOUND,
    PDH_LOGSVC_NOT_OPENED,
    PDH_WBEM_ERROR,
    PDH_ACCESS_DENIED,
    PDH_LOG_FILE_TOO_SMALL,
    PDH_INVALID_DATASOURCE,
    PDH_INVALID_SQLDB,
    PDH_NO_COUNTERS,
    PDH_SQL_ALLOC_FAILED,
    PDH_SQL_ALLOCCON_FAILED,
    PDH_SQL_EXEC_DIRECT_FAILED,
    PDH_SQL_FETCH_FAILED,
    PDH_SQL_ROWCOUNT_FAILED,
    PDH_SQL_MORE_RESULTS_FAILED,
    PDH_SQL_CONNECT_FAILED,
    PDH_SQL_BIND_FAILED,
    PDH_CANNOT_CONNECT_WMI_SERVER,
    PDH_PLA_COLLECTION_ALREADY_RUNNING,
    PDH_PLA_ERROR_SCHEDULE_OVERLAP,
    PDH_PLA_COLLECTION_NOT_FOUND,
    PDH_PLA_ERROR_SCHEDULE_ELAPSED,
    PDH_PLA_ERROR_NOSTART,
    PDH_PLA_ERROR_ALREADY_EXISTS,
    PDH_PLA_ERROR_TYPE_MISMATCH,
    PDH_PLA_ERROR_FILEPATH,
    PDH_PLA_SERVICE_ERROR,
    PDH_PLA_VALIDATION_ERROR,
    PDH_PLA_ERROR_NAME_TOO_LONG,
    PDH_INVALID_SQL_LOG_FORMAT,
    PDH_COUNTER_ALREADY_IN_QUERY,
    PDH_BINARY_LOG_CORRUPT,
    PDH_LOG_SAMPLE_TOO_SMALL,
    PDH_OS_LATER_VERSION,
    PDH_OS_EARLIER_VERSION,
    PDH_INCORRECT_APPEND_TIME,
    PDH_UNMATCHED_APPEND_COUNTER,
    PDH_SQL_ALTER_DETAIL_FAILED,
    PDH_QUERY_PERF_DATA_TIMEOUT,
}

impl NULL {
    pub fn code(&self) -> u32 {
        return match self {
            NULL::ERROR_SUCCESS => 0x00000000 as u32,
            NULL::PDH_CSTATUS_VALID_DATA => 0x00000000 as u32,
            NULL::SUCCESS => 0x00000000 as u32,
            NULL::NERR_Success => 0x00000000 as u32,
            NULL::S_OK => 0x00000000 as u32,
            NULL::NOERROR => 0x00000000 as u32,
            NULL::S_FALSE => 0x00000001 as u32,
            NULL::E_NOTIMPL => 0x80000001 as u32,
            NULL::E_OUTOFMEMORY => 0x80000002 as u32,
            NULL::E_INVALIDARG => 0x80000003 as u32,
            NULL::E_NOINTERFACE => 0x80000004 as u32,
            NULL::E_POINTER => 0x80000005 as u32,
            NULL::E_HANDLE => 0x80000006 as u32,
            NULL::E_ABORT => 0x80000007 as u32,
            NULL::E_FAIL => 0x80000008 as u32,
            NULL::E_ACCESSDENIED => 0x80000009 as u32,
            NULL::E_PENDING => 0x8000000A as u32,
            NULL::E_BOUNDS => 0x8000000B as u32,
            NULL::E_CHANGED_STATE => 0x8000000C as u32,
            NULL::E_ILLEGAL_STATE_CHANGE => 0x8000000D as u32,
            NULL::E_ILLEGAL_METHOD_CALL => 0x8000000E as u32,
            NULL::RO_E_METADATA_NAME_NOT_FOUND => 0x8000000F as u32,
            NULL::RO_E_METADATA_NAME_IS_NAMESPACE => 0x80000010 as u32,
            NULL::RO_E_METADATA_INVALID_TYPE_FORMAT => 0x80000011 as u32,
            NULL::RO_E_INVALID_METADATA_FILE => 0x80000012 as u32,
            NULL::RO_E_CLOSED => 0x80000013 as u32,
            NULL::RO_E_EXCLUSIVE_WRITE => 0x80000014 as u32,
            NULL::RO_E_CHANGE_NOTIFICATION_IN_PROGRESS => 0x80000015 as u32,
            NULL::RO_E_ERROR_STRING_NOT_FOUND => 0x80000016 as u32,
            NULL::E_STRING_NOT_NULL_TERMINATED => 0x80000017 as u32,
            NULL::E_ILLEGAL_DELEGATE_ASSIGNMENT => 0x80000018 as u32,
            NULL::E_ASYNC_OPERATION_NOT_STARTED => 0x80000019 as u32,
            NULL::E_APPLICATION_EXITING => 0x8000001A as u32,
            NULL::E_APPLICATION_VIEW_EXITING => 0x8000001B as u32,
            NULL::RO_E_MUST_BE_AGILE => 0x8000001C as u32,
            NULL::RO_E_UNSUPPORTED_FROM_MTA => 0x8000001D as u32,
            NULL::RO_E_COMMITTED => 0x8000001E as u32,
            NULL::RO_E_BLOCKED_CROSS_ASTA_CALL => 0x8000001F as u32,
            NULL::RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER => 0x80000020 as u32,
            NULL::RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER => 0x80000021 as u32,
            NULL::PDH_CSTATUS_NO_MACHINE => 0x800007D0 as u32,
            NULL::PDH_CSTATUS_NO_INSTANCE => 0x800007D1 as u32,
            NULL::PDH_MORE_DATA => 0x800007D2 as u32,
            NULL::PDH_CSTATUS_ITEM_NOT_VALIDATED => 0x800007D3 as u32,
            NULL::PDH_RETRY => 0x800007D4 as u32,
            NULL::PDH_NO_DATA => 0x800007D5 as u32,
            NULL::PDH_CALC_NEGATIVE_DENOMINATOR => 0x800007D6 as u32,
            NULL::PDH_CALC_NEGATIVE_TIMEBASE => 0x800007D7 as u32,
            NULL::PDH_CALC_NEGATIVE_VALUE => 0x800007D8 as u32,
            NULL::PDH_DIALOG_CANCELLED => 0x800007D9 as u32,
            NULL::PDH_END_OF_LOG_FILE => 0x800007DA as u32,
            NULL::PDH_ASYNC_QUERY_TIMEOUT => 0x800007DB as u32,
            NULL::PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE => 0x800007DC as u32,
            NULL::PDH_UNABLE_MAP_NAME_FILES => 0x80000BD5 as u32,
            NULL::PDH_PLA_VALIDATION_WARNING => 0x80000BF3 as u32,
            NULL::DDERR_UNSUPPORTED => 0x80004001 as u32,
            NULL::DDERR_GENERIC => 0x80004005 as u32,
            NULL::CO_E_INIT_TLS => 0x80004006 as u32,
            NULL::CO_E_INIT_SHARED_ALLOCATOR => 0x80004007 as u32,
            NULL::CO_E_INIT_MEMORY_ALLOCATOR => 0x80004008 as u32,
            NULL::CO_E_INIT_CLASS_CACHE => 0x80004009 as u32,
            NULL::CO_E_INIT_RPC_CHANNEL => 0x8000400A as u32,
            NULL::CO_E_INIT_TLS_SET_CHANNEL_CONTROL => 0x8000400B as u32,
            NULL::CO_E_INIT_TLS_CHANNEL_CONTROL => 0x8000400C as u32,
            NULL::CO_E_INIT_UNACCEPTED_USER_ALLOCATOR => 0x8000400D as u32,
            NULL::CO_E_INIT_SCM_MUTEX_EXISTS => 0x8000400E as u32,
            NULL::CO_E_INIT_SCM_FILE_MAPPING_EXISTS => 0x8000400F as u32,
            NULL::CO_E_INIT_SCM_MAP_VIEW_OF_FILE => 0x80004010 as u32,
            NULL::CO_E_INIT_SCM_EXEC_FAILURE => 0x80004011 as u32,
            NULL::CO_E_INIT_ONLY_SINGLE_THREADED => 0x80004012 as u32,
            NULL::CO_E_CANT_REMOTE => 0x80004013 as u32,
            NULL::CO_E_BAD_SERVER_NAME => 0x80004014 as u32,
            NULL::CO_E_WRONG_SERVER_IDENTITY => 0x80004015 as u32,
            NULL::CO_E_OLE1DDE_DISABLED => 0x80004016 as u32,
            NULL::CO_E_RUNAS_SYNTAX => 0x80004017 as u32,
            NULL::CO_E_CREATEPROCESS_FAILURE => 0x80004018 as u32,
            NULL::CO_E_RUNAS_CREATEPROCESS_FAILURE => 0x80004019 as u32,
            NULL::CO_E_RUNAS_LOGON_FAILURE => 0x8000401A as u32,
            NULL::CO_E_LAUNCH_PERMSSION_DENIED => 0x8000401B as u32,
            NULL::CO_E_START_SERVICE_FAILURE => 0x8000401C as u32,
            NULL::CO_E_REMOTE_COMMUNICATION_FAILURE => 0x8000401D as u32,
            NULL::CO_E_SERVER_START_TIMEOUT => 0x8000401E as u32,
            NULL::CO_E_CLSREG_INCONSISTENT => 0x8000401F as u32,
            NULL::CO_E_IIDREG_INCONSISTENT => 0x80004020 as u32,
            NULL::CO_E_NOT_SUPPORTED => 0x80004021 as u32,
            NULL::CO_E_RELOAD_DLL => 0x80004022 as u32,
            NULL::CO_E_MSI_ERROR => 0x80004023 as u32,
            NULL::CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT => 0x80004024 as u32,
            NULL::CO_E_SERVER_PAUSED => 0x80004025 as u32,
            NULL::CO_E_SERVER_NOT_PAUSED => 0x80004026 as u32,
            NULL::CO_E_CLASS_DISABLED => 0x80004027 as u32,
            NULL::CO_E_CLRNOTAVAILABLE => 0x80004028 as u32,
            NULL::CO_E_ASYNC_WORK_REJECTED => 0x80004029 as u32,
            NULL::CO_E_SERVER_INIT_TIMEOUT => 0x8000402A as u32,
            NULL::CO_E_NO_SECCTX_IN_ACTIVATE => 0x8000402B as u32,
            NULL::CO_E_TRACKER_CONFIG => 0x80004030 as u32,
            NULL::CO_E_THREADPOOL_CONFIG => 0x80004031 as u32,
            NULL::CO_E_SXS_CONFIG => 0x80004032 as u32,
            NULL::CO_E_MALFORMED_SPN => 0x80004033 as u32,
            NULL::CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN => 0x80004034 as u32,
            NULL::CO_E_PREMATURE_STUB_RUNDOWN => 0x80004035 as u32,
            NULL::E_UNEXPECTED => 0x8000FFFF as u32,
            NULL::PDH_CSTATUS_NO_OBJECT => 0xC0000BB8 as u32,
            NULL::PDH_CSTATUS_NO_COUNTER => 0xC0000BB9 as u32,
            NULL::PDH_CSTATUS_INVALID_DATA => 0xC0000BBA as u32,
            NULL::PDH_MEMORY_ALLOCATION_FAILURE => 0xC0000BBB as u32,
            NULL::PDH_INVALID_HANDLE => 0xC0000BBC as u32,
            NULL::PDH_INVALID_ARGUMENT => 0xC0000BBD as u32,
            NULL::PDH_FUNCTION_NOT_FOUND => 0xC0000BBE as u32,
            NULL::PDH_CSTATUS_NO_COUNTERNAME => 0xC0000BBF as u32,
            NULL::PDH_CSTATUS_BAD_COUNTERNAME => 0xC0000BC0 as u32,
            NULL::PDH_INVALID_BUFFER => 0xC0000BC1 as u32,
            NULL::PDH_INSUFFICIENT_BUFFER => 0xC0000BC2 as u32,
            NULL::PDH_CANNOT_CONNECT_MACHINE => 0xC0000BC3 as u32,
            NULL::PDH_INVALID_PATH => 0xC0000BC4 as u32,
            NULL::PDH_INVALID_INSTANCE => 0xC0000BC5 as u32,
            NULL::PDH_INVALID_DATA => 0xC0000BC6 as u32,
            NULL::PDH_NO_DIALOG_DATA => 0xC0000BC7 as u32,
            NULL::PDH_CANNOT_READ_NAME_STRINGS => 0xC0000BC8 as u32,
            NULL::PDH_LOG_FILE_CREATE_ERROR => 0xC0000BC9 as u32,
            NULL::PDH_LOG_FILE_OPEN_ERROR => 0xC0000BCA as u32,
            NULL::PDH_LOG_TYPE_NOT_FOUND => 0xC0000BCB as u32,
            NULL::PDH_NO_MORE_DATA => 0xC0000BCC as u32,
            NULL::PDH_ENTRY_NOT_IN_LOG_FILE => 0xC0000BCD as u32,
            NULL::PDH_DATA_SOURCE_IS_LOG_FILE => 0xC0000BCE as u32,
            NULL::PDH_DATA_SOURCE_IS_REAL_TIME => 0xC0000BCF as u32,
            NULL::PDH_UNABLE_READ_LOG_HEADER => 0xC0000BD0 as u32,
            NULL::PDH_FILE_NOT_FOUND => 0xC0000BD1 as u32,
            NULL::PDH_FILE_ALREADY_EXISTS => 0xC0000BD2 as u32,
            NULL::PDH_NOT_IMPLEMENTED => 0xC0000BD3 as u32,
            NULL::PDH_STRING_NOT_FOUND => 0xC0000BD4 as u32,
            NULL::PDH_UNKNOWN_LOG_FORMAT => 0xC0000BD6 as u32,
            NULL::PDH_UNKNOWN_LOGSVC_COMMAND => 0xC0000BD7 as u32,
            NULL::PDH_LOGSVC_QUERY_NOT_FOUND => 0xC0000BD8 as u32,
            NULL::PDH_LOGSVC_NOT_OPENED => 0xC0000BD9 as u32,
            NULL::PDH_WBEM_ERROR => 0xC0000BDA as u32,
            NULL::PDH_ACCESS_DENIED => 0xC0000BDB as u32,
            NULL::PDH_LOG_FILE_TOO_SMALL => 0xC0000BDC as u32,
            NULL::PDH_INVALID_DATASOURCE => 0xC0000BDD as u32,
            NULL::PDH_INVALID_SQLDB => 0xC0000BDE as u32,
            NULL::PDH_NO_COUNTERS => 0xC0000BDF as u32,
            NULL::PDH_SQL_ALLOC_FAILED => 0xC0000BE0 as u32,
            NULL::PDH_SQL_ALLOCCON_FAILED => 0xC0000BE1 as u32,
            NULL::PDH_SQL_EXEC_DIRECT_FAILED => 0xC0000BE2 as u32,
            NULL::PDH_SQL_FETCH_FAILED => 0xC0000BE3 as u32,
            NULL::PDH_SQL_ROWCOUNT_FAILED => 0xC0000BE4 as u32,
            NULL::PDH_SQL_MORE_RESULTS_FAILED => 0xC0000BE5 as u32,
            NULL::PDH_SQL_CONNECT_FAILED => 0xC0000BE6 as u32,
            NULL::PDH_SQL_BIND_FAILED => 0xC0000BE7 as u32,
            NULL::PDH_CANNOT_CONNECT_WMI_SERVER => 0xC0000BE8 as u32,
            NULL::PDH_PLA_COLLECTION_ALREADY_RUNNING => 0xC0000BE9 as u32,
            NULL::PDH_PLA_ERROR_SCHEDULE_OVERLAP => 0xC0000BEA as u32,
            NULL::PDH_PLA_COLLECTION_NOT_FOUND => 0xC0000BEB as u32,
            NULL::PDH_PLA_ERROR_SCHEDULE_ELAPSED => 0xC0000BEC as u32,
            NULL::PDH_PLA_ERROR_NOSTART => 0xC0000BED as u32,
            NULL::PDH_PLA_ERROR_ALREADY_EXISTS => 0xC0000BEE as u32,
            NULL::PDH_PLA_ERROR_TYPE_MISMATCH => 0xC0000BEF as u32,
            NULL::PDH_PLA_ERROR_FILEPATH => 0xC0000BF0 as u32,
            NULL::PDH_PLA_SERVICE_ERROR => 0xC0000BF1 as u32,
            NULL::PDH_PLA_VALIDATION_ERROR => 0xC0000BF2 as u32,
            NULL::PDH_PLA_ERROR_NAME_TOO_LONG => 0xC0000BF4 as u32,
            NULL::PDH_INVALID_SQL_LOG_FORMAT => 0xC0000BF5 as u32,
            NULL::PDH_COUNTER_ALREADY_IN_QUERY => 0xC0000BF6 as u32,
            NULL::PDH_BINARY_LOG_CORRUPT => 0xC0000BF7 as u32,
            NULL::PDH_LOG_SAMPLE_TOO_SMALL => 0xC0000BF8 as u32,
            NULL::PDH_OS_LATER_VERSION => 0xC0000BF9 as u32,
            NULL::PDH_OS_EARLIER_VERSION => 0xC0000BFA as u32,
            NULL::PDH_INCORRECT_APPEND_TIME => 0xC0000BFB as u32,
            NULL::PDH_UNMATCHED_APPEND_COUNTER => 0xC0000BFC as u32,
            NULL::PDH_SQL_ALTER_DETAIL_FAILED => 0xC0000BFD as u32,
            NULL::PDH_QUERY_PERF_DATA_TIMEOUT => 0xC0000BFE as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            NULL::ERROR_SUCCESS => RawError::Kind(NULL::ERROR_SUCCESS),
            NULL::PDH_CSTATUS_VALID_DATA => RawError::Kind(NULL::PDH_CSTATUS_VALID_DATA),
            NULL::SUCCESS => RawError::Kind(NULL::SUCCESS),
            NULL::NERR_Success => RawError::Kind(NULL::NERR_Success),
            NULL::S_OK => RawError::Kind(NULL::S_OK),
            NULL::NOERROR => RawError::Kind(NULL::NOERROR),
            NULL::S_FALSE => RawError::Kind(NULL::S_FALSE),
            NULL::E_NOTIMPL => RawError::Kind(NULL::E_NOTIMPL),
            NULL::E_OUTOFMEMORY => RawError::Kind(NULL::E_OUTOFMEMORY),
            NULL::E_INVALIDARG => RawError::Kind(NULL::E_INVALIDARG),
            NULL::E_NOINTERFACE => RawError::Kind(NULL::E_NOINTERFACE),
            NULL::E_POINTER => RawError::Kind(NULL::E_POINTER),
            NULL::E_HANDLE => RawError::Kind(NULL::E_HANDLE),
            NULL::E_ABORT => RawError::Kind(NULL::E_ABORT),
            NULL::E_FAIL => RawError::Kind(NULL::E_FAIL),
            NULL::E_ACCESSDENIED => RawError::Kind(NULL::E_ACCESSDENIED),
            NULL::E_PENDING => RawError::Kind(NULL::E_PENDING),
            NULL::E_BOUNDS => RawError::Kind(NULL::E_BOUNDS),
            NULL::E_CHANGED_STATE => RawError::Kind(NULL::E_CHANGED_STATE),
            NULL::E_ILLEGAL_STATE_CHANGE => RawError::Kind(NULL::E_ILLEGAL_STATE_CHANGE),
            NULL::E_ILLEGAL_METHOD_CALL => RawError::Kind(NULL::E_ILLEGAL_METHOD_CALL),
            NULL::RO_E_METADATA_NAME_NOT_FOUND => RawError::Kind(NULL::RO_E_METADATA_NAME_NOT_FOUND),
            NULL::RO_E_METADATA_NAME_IS_NAMESPACE => RawError::Kind(NULL::RO_E_METADATA_NAME_IS_NAMESPACE),
            NULL::RO_E_METADATA_INVALID_TYPE_FORMAT => RawError::Kind(NULL::RO_E_METADATA_INVALID_TYPE_FORMAT),
            NULL::RO_E_INVALID_METADATA_FILE => RawError::Kind(NULL::RO_E_INVALID_METADATA_FILE),
            NULL::RO_E_CLOSED => RawError::Kind(NULL::RO_E_CLOSED),
            NULL::RO_E_EXCLUSIVE_WRITE => RawError::Kind(NULL::RO_E_EXCLUSIVE_WRITE),
            NULL::RO_E_CHANGE_NOTIFICATION_IN_PROGRESS => RawError::Kind(NULL::RO_E_CHANGE_NOTIFICATION_IN_PROGRESS),
            NULL::RO_E_ERROR_STRING_NOT_FOUND => RawError::Kind(NULL::RO_E_ERROR_STRING_NOT_FOUND),
            NULL::E_STRING_NOT_NULL_TERMINATED => RawError::Kind(NULL::E_STRING_NOT_NULL_TERMINATED),
            NULL::E_ILLEGAL_DELEGATE_ASSIGNMENT => RawError::Kind(NULL::E_ILLEGAL_DELEGATE_ASSIGNMENT),
            NULL::E_ASYNC_OPERATION_NOT_STARTED => RawError::Kind(NULL::E_ASYNC_OPERATION_NOT_STARTED),
            NULL::E_APPLICATION_EXITING => RawError::Kind(NULL::E_APPLICATION_EXITING),
            NULL::E_APPLICATION_VIEW_EXITING => RawError::Kind(NULL::E_APPLICATION_VIEW_EXITING),
            NULL::RO_E_MUST_BE_AGILE => RawError::Kind(NULL::RO_E_MUST_BE_AGILE),
            NULL::RO_E_UNSUPPORTED_FROM_MTA => RawError::Kind(NULL::RO_E_UNSUPPORTED_FROM_MTA),
            NULL::RO_E_COMMITTED => RawError::Kind(NULL::RO_E_COMMITTED),
            NULL::RO_E_BLOCKED_CROSS_ASTA_CALL => RawError::Kind(NULL::RO_E_BLOCKED_CROSS_ASTA_CALL),
            NULL::RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER => RawError::Kind(NULL::RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER),
            NULL::RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER => RawError::Kind(NULL::RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER),
            NULL::PDH_CSTATUS_NO_MACHINE => RawError::Kind(NULL::PDH_CSTATUS_NO_MACHINE),
            NULL::PDH_CSTATUS_NO_INSTANCE => RawError::Kind(NULL::PDH_CSTATUS_NO_INSTANCE),
            NULL::PDH_MORE_DATA => RawError::Kind(NULL::PDH_MORE_DATA),
            NULL::PDH_CSTATUS_ITEM_NOT_VALIDATED => RawError::Kind(NULL::PDH_CSTATUS_ITEM_NOT_VALIDATED),
            NULL::PDH_RETRY => RawError::Kind(NULL::PDH_RETRY),
            NULL::PDH_NO_DATA => RawError::Kind(NULL::PDH_NO_DATA),
            NULL::PDH_CALC_NEGATIVE_DENOMINATOR => RawError::Kind(NULL::PDH_CALC_NEGATIVE_DENOMINATOR),
            NULL::PDH_CALC_NEGATIVE_TIMEBASE => RawError::Kind(NULL::PDH_CALC_NEGATIVE_TIMEBASE),
            NULL::PDH_CALC_NEGATIVE_VALUE => RawError::Kind(NULL::PDH_CALC_NEGATIVE_VALUE),
            NULL::PDH_DIALOG_CANCELLED => RawError::Kind(NULL::PDH_DIALOG_CANCELLED),
            NULL::PDH_END_OF_LOG_FILE => RawError::Kind(NULL::PDH_END_OF_LOG_FILE),
            NULL::PDH_ASYNC_QUERY_TIMEOUT => RawError::Kind(NULL::PDH_ASYNC_QUERY_TIMEOUT),
            NULL::PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE => RawError::Kind(NULL::PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE),
            NULL::PDH_UNABLE_MAP_NAME_FILES => RawError::Kind(NULL::PDH_UNABLE_MAP_NAME_FILES),
            NULL::PDH_PLA_VALIDATION_WARNING => RawError::Kind(NULL::PDH_PLA_VALIDATION_WARNING),
            NULL::DDERR_UNSUPPORTED => RawError::Kind(NULL::DDERR_UNSUPPORTED),
            NULL::DDERR_GENERIC => RawError::Kind(NULL::DDERR_GENERIC),
            NULL::CO_E_INIT_TLS => RawError::Kind(NULL::CO_E_INIT_TLS),
            NULL::CO_E_INIT_SHARED_ALLOCATOR => RawError::Kind(NULL::CO_E_INIT_SHARED_ALLOCATOR),
            NULL::CO_E_INIT_MEMORY_ALLOCATOR => RawError::Kind(NULL::CO_E_INIT_MEMORY_ALLOCATOR),
            NULL::CO_E_INIT_CLASS_CACHE => RawError::Kind(NULL::CO_E_INIT_CLASS_CACHE),
            NULL::CO_E_INIT_RPC_CHANNEL => RawError::Kind(NULL::CO_E_INIT_RPC_CHANNEL),
            NULL::CO_E_INIT_TLS_SET_CHANNEL_CONTROL => RawError::Kind(NULL::CO_E_INIT_TLS_SET_CHANNEL_CONTROL),
            NULL::CO_E_INIT_TLS_CHANNEL_CONTROL => RawError::Kind(NULL::CO_E_INIT_TLS_CHANNEL_CONTROL),
            NULL::CO_E_INIT_UNACCEPTED_USER_ALLOCATOR => RawError::Kind(NULL::CO_E_INIT_UNACCEPTED_USER_ALLOCATOR),
            NULL::CO_E_INIT_SCM_MUTEX_EXISTS => RawError::Kind(NULL::CO_E_INIT_SCM_MUTEX_EXISTS),
            NULL::CO_E_INIT_SCM_FILE_MAPPING_EXISTS => RawError::Kind(NULL::CO_E_INIT_SCM_FILE_MAPPING_EXISTS),
            NULL::CO_E_INIT_SCM_MAP_VIEW_OF_FILE => RawError::Kind(NULL::CO_E_INIT_SCM_MAP_VIEW_OF_FILE),
            NULL::CO_E_INIT_SCM_EXEC_FAILURE => RawError::Kind(NULL::CO_E_INIT_SCM_EXEC_FAILURE),
            NULL::CO_E_INIT_ONLY_SINGLE_THREADED => RawError::Kind(NULL::CO_E_INIT_ONLY_SINGLE_THREADED),
            NULL::CO_E_CANT_REMOTE => RawError::Kind(NULL::CO_E_CANT_REMOTE),
            NULL::CO_E_BAD_SERVER_NAME => RawError::Kind(NULL::CO_E_BAD_SERVER_NAME),
            NULL::CO_E_WRONG_SERVER_IDENTITY => RawError::Kind(NULL::CO_E_WRONG_SERVER_IDENTITY),
            NULL::CO_E_OLE1DDE_DISABLED => RawError::Kind(NULL::CO_E_OLE1DDE_DISABLED),
            NULL::CO_E_RUNAS_SYNTAX => RawError::Kind(NULL::CO_E_RUNAS_SYNTAX),
            NULL::CO_E_CREATEPROCESS_FAILURE => RawError::Kind(NULL::CO_E_CREATEPROCESS_FAILURE),
            NULL::CO_E_RUNAS_CREATEPROCESS_FAILURE => RawError::Kind(NULL::CO_E_RUNAS_CREATEPROCESS_FAILURE),
            NULL::CO_E_RUNAS_LOGON_FAILURE => RawError::Kind(NULL::CO_E_RUNAS_LOGON_FAILURE),
            NULL::CO_E_LAUNCH_PERMSSION_DENIED => RawError::Kind(NULL::CO_E_LAUNCH_PERMSSION_DENIED),
            NULL::CO_E_START_SERVICE_FAILURE => RawError::Kind(NULL::CO_E_START_SERVICE_FAILURE),
            NULL::CO_E_REMOTE_COMMUNICATION_FAILURE => RawError::Kind(NULL::CO_E_REMOTE_COMMUNICATION_FAILURE),
            NULL::CO_E_SERVER_START_TIMEOUT => RawError::Kind(NULL::CO_E_SERVER_START_TIMEOUT),
            NULL::CO_E_CLSREG_INCONSISTENT => RawError::Kind(NULL::CO_E_CLSREG_INCONSISTENT),
            NULL::CO_E_IIDREG_INCONSISTENT => RawError::Kind(NULL::CO_E_IIDREG_INCONSISTENT),
            NULL::CO_E_NOT_SUPPORTED => RawError::Kind(NULL::CO_E_NOT_SUPPORTED),
            NULL::CO_E_RELOAD_DLL => RawError::Kind(NULL::CO_E_RELOAD_DLL),
            NULL::CO_E_MSI_ERROR => RawError::Kind(NULL::CO_E_MSI_ERROR),
            NULL::CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT => RawError::Kind(NULL::CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT),
            NULL::CO_E_SERVER_PAUSED => RawError::Kind(NULL::CO_E_SERVER_PAUSED),
            NULL::CO_E_SERVER_NOT_PAUSED => RawError::Kind(NULL::CO_E_SERVER_NOT_PAUSED),
            NULL::CO_E_CLASS_DISABLED => RawError::Kind(NULL::CO_E_CLASS_DISABLED),
            NULL::CO_E_CLRNOTAVAILABLE => RawError::Kind(NULL::CO_E_CLRNOTAVAILABLE),
            NULL::CO_E_ASYNC_WORK_REJECTED => RawError::Kind(NULL::CO_E_ASYNC_WORK_REJECTED),
            NULL::CO_E_SERVER_INIT_TIMEOUT => RawError::Kind(NULL::CO_E_SERVER_INIT_TIMEOUT),
            NULL::CO_E_NO_SECCTX_IN_ACTIVATE => RawError::Kind(NULL::CO_E_NO_SECCTX_IN_ACTIVATE),
            NULL::CO_E_TRACKER_CONFIG => RawError::Kind(NULL::CO_E_TRACKER_CONFIG),
            NULL::CO_E_THREADPOOL_CONFIG => RawError::Kind(NULL::CO_E_THREADPOOL_CONFIG),
            NULL::CO_E_SXS_CONFIG => RawError::Kind(NULL::CO_E_SXS_CONFIG),
            NULL::CO_E_MALFORMED_SPN => RawError::Kind(NULL::CO_E_MALFORMED_SPN),
            NULL::CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN => RawError::Kind(NULL::CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN),
            NULL::CO_E_PREMATURE_STUB_RUNDOWN => RawError::Kind(NULL::CO_E_PREMATURE_STUB_RUNDOWN),
            NULL::E_UNEXPECTED => RawError::Kind(NULL::E_UNEXPECTED),
            NULL::PDH_CSTATUS_NO_OBJECT => RawError::Kind(NULL::PDH_CSTATUS_NO_OBJECT),
            NULL::PDH_CSTATUS_NO_COUNTER => RawError::Kind(NULL::PDH_CSTATUS_NO_COUNTER),
            NULL::PDH_CSTATUS_INVALID_DATA => RawError::Kind(NULL::PDH_CSTATUS_INVALID_DATA),
            NULL::PDH_MEMORY_ALLOCATION_FAILURE => RawError::Kind(NULL::PDH_MEMORY_ALLOCATION_FAILURE),
            NULL::PDH_INVALID_HANDLE => RawError::Kind(NULL::PDH_INVALID_HANDLE),
            NULL::PDH_INVALID_ARGUMENT => RawError::Kind(NULL::PDH_INVALID_ARGUMENT),
            NULL::PDH_FUNCTION_NOT_FOUND => RawError::Kind(NULL::PDH_FUNCTION_NOT_FOUND),
            NULL::PDH_CSTATUS_NO_COUNTERNAME => RawError::Kind(NULL::PDH_CSTATUS_NO_COUNTERNAME),
            NULL::PDH_CSTATUS_BAD_COUNTERNAME => RawError::Kind(NULL::PDH_CSTATUS_BAD_COUNTERNAME),
            NULL::PDH_INVALID_BUFFER => RawError::Kind(NULL::PDH_INVALID_BUFFER),
            NULL::PDH_INSUFFICIENT_BUFFER => RawError::Kind(NULL::PDH_INSUFFICIENT_BUFFER),
            NULL::PDH_CANNOT_CONNECT_MACHINE => RawError::Kind(NULL::PDH_CANNOT_CONNECT_MACHINE),
            NULL::PDH_INVALID_PATH => RawError::Kind(NULL::PDH_INVALID_PATH),
            NULL::PDH_INVALID_INSTANCE => RawError::Kind(NULL::PDH_INVALID_INSTANCE),
            NULL::PDH_INVALID_DATA => RawError::Kind(NULL::PDH_INVALID_DATA),
            NULL::PDH_NO_DIALOG_DATA => RawError::Kind(NULL::PDH_NO_DIALOG_DATA),
            NULL::PDH_CANNOT_READ_NAME_STRINGS => RawError::Kind(NULL::PDH_CANNOT_READ_NAME_STRINGS),
            NULL::PDH_LOG_FILE_CREATE_ERROR => RawError::Kind(NULL::PDH_LOG_FILE_CREATE_ERROR),
            NULL::PDH_LOG_FILE_OPEN_ERROR => RawError::Kind(NULL::PDH_LOG_FILE_OPEN_ERROR),
            NULL::PDH_LOG_TYPE_NOT_FOUND => RawError::Kind(NULL::PDH_LOG_TYPE_NOT_FOUND),
            NULL::PDH_NO_MORE_DATA => RawError::Kind(NULL::PDH_NO_MORE_DATA),
            NULL::PDH_ENTRY_NOT_IN_LOG_FILE => RawError::Kind(NULL::PDH_ENTRY_NOT_IN_LOG_FILE),
            NULL::PDH_DATA_SOURCE_IS_LOG_FILE => RawError::Kind(NULL::PDH_DATA_SOURCE_IS_LOG_FILE),
            NULL::PDH_DATA_SOURCE_IS_REAL_TIME => RawError::Kind(NULL::PDH_DATA_SOURCE_IS_REAL_TIME),
            NULL::PDH_UNABLE_READ_LOG_HEADER => RawError::Kind(NULL::PDH_UNABLE_READ_LOG_HEADER),
            NULL::PDH_FILE_NOT_FOUND => RawError::Kind(NULL::PDH_FILE_NOT_FOUND),
            NULL::PDH_FILE_ALREADY_EXISTS => RawError::Kind(NULL::PDH_FILE_ALREADY_EXISTS),
            NULL::PDH_NOT_IMPLEMENTED => RawError::Kind(NULL::PDH_NOT_IMPLEMENTED),
            NULL::PDH_STRING_NOT_FOUND => RawError::Kind(NULL::PDH_STRING_NOT_FOUND),
            NULL::PDH_UNKNOWN_LOG_FORMAT => RawError::Kind(NULL::PDH_UNKNOWN_LOG_FORMAT),
            NULL::PDH_UNKNOWN_LOGSVC_COMMAND => RawError::Kind(NULL::PDH_UNKNOWN_LOGSVC_COMMAND),
            NULL::PDH_LOGSVC_QUERY_NOT_FOUND => RawError::Kind(NULL::PDH_LOGSVC_QUERY_NOT_FOUND),
            NULL::PDH_LOGSVC_NOT_OPENED => RawError::Kind(NULL::PDH_LOGSVC_NOT_OPENED),
            NULL::PDH_WBEM_ERROR => RawError::Kind(NULL::PDH_WBEM_ERROR),
            NULL::PDH_ACCESS_DENIED => RawError::Kind(NULL::PDH_ACCESS_DENIED),
            NULL::PDH_LOG_FILE_TOO_SMALL => RawError::Kind(NULL::PDH_LOG_FILE_TOO_SMALL),
            NULL::PDH_INVALID_DATASOURCE => RawError::Kind(NULL::PDH_INVALID_DATASOURCE),
            NULL::PDH_INVALID_SQLDB => RawError::Kind(NULL::PDH_INVALID_SQLDB),
            NULL::PDH_NO_COUNTERS => RawError::Kind(NULL::PDH_NO_COUNTERS),
            NULL::PDH_SQL_ALLOC_FAILED => RawError::Kind(NULL::PDH_SQL_ALLOC_FAILED),
            NULL::PDH_SQL_ALLOCCON_FAILED => RawError::Kind(NULL::PDH_SQL_ALLOCCON_FAILED),
            NULL::PDH_SQL_EXEC_DIRECT_FAILED => RawError::Kind(NULL::PDH_SQL_EXEC_DIRECT_FAILED),
            NULL::PDH_SQL_FETCH_FAILED => RawError::Kind(NULL::PDH_SQL_FETCH_FAILED),
            NULL::PDH_SQL_ROWCOUNT_FAILED => RawError::Kind(NULL::PDH_SQL_ROWCOUNT_FAILED),
            NULL::PDH_SQL_MORE_RESULTS_FAILED => RawError::Kind(NULL::PDH_SQL_MORE_RESULTS_FAILED),
            NULL::PDH_SQL_CONNECT_FAILED => RawError::Kind(NULL::PDH_SQL_CONNECT_FAILED),
            NULL::PDH_SQL_BIND_FAILED => RawError::Kind(NULL::PDH_SQL_BIND_FAILED),
            NULL::PDH_CANNOT_CONNECT_WMI_SERVER => RawError::Kind(NULL::PDH_CANNOT_CONNECT_WMI_SERVER),
            NULL::PDH_PLA_COLLECTION_ALREADY_RUNNING => RawError::Kind(NULL::PDH_PLA_COLLECTION_ALREADY_RUNNING),
            NULL::PDH_PLA_ERROR_SCHEDULE_OVERLAP => RawError::Kind(NULL::PDH_PLA_ERROR_SCHEDULE_OVERLAP),
            NULL::PDH_PLA_COLLECTION_NOT_FOUND => RawError::Kind(NULL::PDH_PLA_COLLECTION_NOT_FOUND),
            NULL::PDH_PLA_ERROR_SCHEDULE_ELAPSED => RawError::Kind(NULL::PDH_PLA_ERROR_SCHEDULE_ELAPSED),
            NULL::PDH_PLA_ERROR_NOSTART => RawError::Kind(NULL::PDH_PLA_ERROR_NOSTART),
            NULL::PDH_PLA_ERROR_ALREADY_EXISTS => RawError::Kind(NULL::PDH_PLA_ERROR_ALREADY_EXISTS),
            NULL::PDH_PLA_ERROR_TYPE_MISMATCH => RawError::Kind(NULL::PDH_PLA_ERROR_TYPE_MISMATCH),
            NULL::PDH_PLA_ERROR_FILEPATH => RawError::Kind(NULL::PDH_PLA_ERROR_FILEPATH),
            NULL::PDH_PLA_SERVICE_ERROR => RawError::Kind(NULL::PDH_PLA_SERVICE_ERROR),
            NULL::PDH_PLA_VALIDATION_ERROR => RawError::Kind(NULL::PDH_PLA_VALIDATION_ERROR),
            NULL::PDH_PLA_ERROR_NAME_TOO_LONG => RawError::Kind(NULL::PDH_PLA_ERROR_NAME_TOO_LONG),
            NULL::PDH_INVALID_SQL_LOG_FORMAT => RawError::Kind(NULL::PDH_INVALID_SQL_LOG_FORMAT),
            NULL::PDH_COUNTER_ALREADY_IN_QUERY => RawError::Kind(NULL::PDH_COUNTER_ALREADY_IN_QUERY),
            NULL::PDH_BINARY_LOG_CORRUPT => RawError::Kind(NULL::PDH_BINARY_LOG_CORRUPT),
            NULL::PDH_LOG_SAMPLE_TOO_SMALL => RawError::Kind(NULL::PDH_LOG_SAMPLE_TOO_SMALL),
            NULL::PDH_OS_LATER_VERSION => RawError::Kind(NULL::PDH_OS_LATER_VERSION),
            NULL::PDH_OS_EARLIER_VERSION => RawError::Kind(NULL::PDH_OS_EARLIER_VERSION),
            NULL::PDH_INCORRECT_APPEND_TIME => RawError::Kind(NULL::PDH_INCORRECT_APPEND_TIME),
            NULL::PDH_UNMATCHED_APPEND_COUNTER => RawError::Kind(NULL::PDH_UNMATCHED_APPEND_COUNTER),
            NULL::PDH_SQL_ALTER_DETAIL_FAILED => RawError::Kind(NULL::PDH_SQL_ALTER_DETAIL_FAILED),
            NULL::PDH_QUERY_PERF_DATA_TIMEOUT => RawError::Kind(NULL::PDH_QUERY_PERF_DATA_TIMEOUT),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            NULL::ERROR_SUCCESS => "The operation completed successfully.",
            NULL::PDH_CSTATUS_VALID_DATA => "The returned data is valid.",
            NULL::SUCCESS => "The operation completed successfully.",
            NULL::NERR_Success => "The operation completed successfully.",
            NULL::S_OK => "Success. Numerically equivalent to NOERROR.",
            NULL::NOERROR => "No error. Numerically equivalent to S_OK.",
            NULL::S_FALSE => "Success. Condition was FALSE.",
            NULL::E_NOTIMPL => "Not implemented",
            NULL::E_OUTOFMEMORY => "Ran out of memory",
            NULL::E_INVALIDARG => "One or more arguments are invalid",
            NULL::E_NOINTERFACE => "No such interface supported",
            NULL::E_POINTER => "Invalid pointer",
            NULL::E_HANDLE => "Invalid handle",
            NULL::E_ABORT => "Operation aborted",
            NULL::E_FAIL => "Unspecified error",
            NULL::E_ACCESSDENIED => "General access denied error",
            NULL::E_PENDING => "The data necessary to complete this operation is not yet available.",
            NULL::E_BOUNDS => "The operation attempted to access data outside the valid range",
            NULL::E_CHANGED_STATE => "A concurrent or interleaved operation changed the state of the object, invalidating this operation.",
            NULL::E_ILLEGAL_STATE_CHANGE => "An illegal state change was requested.",
            NULL::E_ILLEGAL_METHOD_CALL => "A method was called at an unexpected time.",
            NULL::RO_E_METADATA_NAME_NOT_FOUND => "Typename or Namespace was not found in metadata file.",
            NULL::RO_E_METADATA_NAME_IS_NAMESPACE => "Name is an existing namespace rather than a typename.",
            NULL::RO_E_METADATA_INVALID_TYPE_FORMAT => "Typename has an invalid format.",
            NULL::RO_E_INVALID_METADATA_FILE => "Metadata file is invalid or corrupted.",
            NULL::RO_E_CLOSED => "The object has been closed.",
            NULL::RO_E_EXCLUSIVE_WRITE => "Only one thread may access the object during a write operation.",
            NULL::RO_E_CHANGE_NOTIFICATION_IN_PROGRESS => "Operation is prohibited during change notification.",
            NULL::RO_E_ERROR_STRING_NOT_FOUND => "The text associated with this error code could not be found.",
            NULL::E_STRING_NOT_NULL_TERMINATED => "String not null terminated.",
            NULL::E_ILLEGAL_DELEGATE_ASSIGNMENT => "A delegate was assigned when not allowed.",
            NULL::E_ASYNC_OPERATION_NOT_STARTED => "An async operation was not properly started.",
            NULL::E_APPLICATION_EXITING => "The application is exiting and cannot service this request",
            NULL::E_APPLICATION_VIEW_EXITING => "The application view is exiting and cannot service this request",
            NULL::RO_E_MUST_BE_AGILE => "The object must support the IAgileObject interface",
            NULL::RO_E_UNSUPPORTED_FROM_MTA => "Activating a single-threaded class from MTA is not supported",
            NULL::RO_E_COMMITTED => "The object has been committed.",
            NULL::RO_E_BLOCKED_CROSS_ASTA_CALL => "A COM call to an ASTA was blocked because the call chain originated in or passed through another ASTA. This call pattern is deadlock-prone and disallowed by apartment call control.",
            NULL::RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER => "A universal application process cannot activate a packaged WinRT server that is declared to run full trust.",
            NULL::RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER => "A full trust packaged application process cannot activate a packaged WinRT server unless it is also declared to run full trust.",
            NULL::PDH_CSTATUS_NO_MACHINE => "Unable to connect to the specified computer, or the computer is offline.",
            NULL::PDH_CSTATUS_NO_INSTANCE => "The specified instance is not present.",
            NULL::PDH_MORE_DATA => "There is more data to return than would fit in the supplied buffer. Allocate a larger buffer and call the function again.",
            NULL::PDH_CSTATUS_ITEM_NOT_VALIDATED => "The data item has been added to the query but has not been validated nor accessed. No other status information on this data item is available.",
            NULL::PDH_RETRY => "The selected operation should be retried.",
            NULL::PDH_NO_DATA => "No data to return.",
            NULL::PDH_CALC_NEGATIVE_DENOMINATOR => "A counter with a negative denominator value was detected.",
            NULL::PDH_CALC_NEGATIVE_TIMEBASE => "A counter with a negative time base value was detected.",
            NULL::PDH_CALC_NEGATIVE_VALUE => "A counter with a negative value was detected.",
            NULL::PDH_DIALOG_CANCELLED => "The user canceled the dialog box.",
            NULL::PDH_END_OF_LOG_FILE => "The end of the log file was reached.",
            NULL::PDH_ASYNC_QUERY_TIMEOUT => "A time-out occurred while waiting for the asynchronous counter collection thread to end.",
            NULL::PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE => "Cannot change set default real-time data source. There are real-time query sessions collecting counter data.",
            NULL::PDH_UNABLE_MAP_NAME_FILES => "Unable to map to the performance counter name data files. The data will be read from the registry and stored locally.",
            NULL::PDH_PLA_VALIDATION_WARNING => "The information passed is not valid.",
            NULL::DDERR_UNSUPPORTED => "The operation is not supported.",
            NULL::DDERR_GENERIC => "There is an undefined error condition.",
            NULL::CO_E_INIT_TLS => "Thread local storage failure",
            NULL::CO_E_INIT_SHARED_ALLOCATOR => "Get shared memory allocator failure",
            NULL::CO_E_INIT_MEMORY_ALLOCATOR => "Get memory allocator failure",
            NULL::CO_E_INIT_CLASS_CACHE => "Unable to initialize class cache",
            NULL::CO_E_INIT_RPC_CHANNEL => "Unable to initialize RPC services",
            NULL::CO_E_INIT_TLS_SET_CHANNEL_CONTROL => "Cannot set thread local storage channel control",
            NULL::CO_E_INIT_TLS_CHANNEL_CONTROL => "Could not allocate thread local storage channel control",
            NULL::CO_E_INIT_UNACCEPTED_USER_ALLOCATOR => "The user supplied memory allocator is unacceptable",
            NULL::CO_E_INIT_SCM_MUTEX_EXISTS => "The OLE service mutex already exists",
            NULL::CO_E_INIT_SCM_FILE_MAPPING_EXISTS => "The OLE service file mapping already exists",
            NULL::CO_E_INIT_SCM_MAP_VIEW_OF_FILE => "Unable to map view of file for OLE service",
            NULL::CO_E_INIT_SCM_EXEC_FAILURE => "Failure attempting to launch OLE service",
            NULL::CO_E_INIT_ONLY_SINGLE_THREADED => "There was an attempt to call CoInitialize a second time while single threaded",
            NULL::CO_E_CANT_REMOTE => "A Remote activation was necessary but was not allowed",
            NULL::CO_E_BAD_SERVER_NAME => "A Remote activation was necessary but the server name provided was invalid",
            NULL::CO_E_WRONG_SERVER_IDENTITY => "The class is configured to run as a security id different from the caller",
            NULL::CO_E_OLE1DDE_DISABLED => "Use of Ole1 services requiring DDE windows is disabled",
            NULL::CO_E_RUNAS_SYNTAX => "A RunAs specification must be <domain name>\\<user name> or simply <user name>",
            NULL::CO_E_CREATEPROCESS_FAILURE => "The server process could not be started. The pathname may be incorrect.",
            NULL::CO_E_RUNAS_CREATEPROCESS_FAILURE => "The server process could not be started as the configured identity. The pathname may be incorrect or unavailable.",
            NULL::CO_E_RUNAS_LOGON_FAILURE => "The server process could not be started because the configured identity is incorrect. Check the username and password.",
            NULL::CO_E_LAUNCH_PERMSSION_DENIED => "The client is not allowed to launch this server.",
            NULL::CO_E_START_SERVICE_FAILURE => "The service providing this server could not be started.",
            NULL::CO_E_REMOTE_COMMUNICATION_FAILURE => "This computer was unable to communicate with the computer providing the server.",
            NULL::CO_E_SERVER_START_TIMEOUT => "The server did not respond after being launched.",
            NULL::CO_E_CLSREG_INCONSISTENT => "The registration information for this server is inconsistent or incomplete.",
            NULL::CO_E_IIDREG_INCONSISTENT => "The registration information for this interface is inconsistent or incomplete.",
            NULL::CO_E_NOT_SUPPORTED => "The operation attempted is not supported.",
            NULL::CO_E_RELOAD_DLL => "A dll must be loaded.",
            NULL::CO_E_MSI_ERROR => "A Microsoft Software Installer error was encountered.",
            NULL::CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT => "The specified activation could not occur in the client context as specified.",
            NULL::CO_E_SERVER_PAUSED => "Activations on the server are paused.",
            NULL::CO_E_SERVER_NOT_PAUSED => "Activations on the server are not paused.",
            NULL::CO_E_CLASS_DISABLED => "The component or application containing the component has been disabled.",
            NULL::CO_E_CLRNOTAVAILABLE => "The common language runtime is not available",
            NULL::CO_E_ASYNC_WORK_REJECTED => "The thread-pool rejected the submitted asynchronous work.",
            NULL::CO_E_SERVER_INIT_TIMEOUT => "The server started, but did not finish initializing in a timely fashion.",
            NULL::CO_E_NO_SECCTX_IN_ACTIVATE => "Unable to complete the call since there is no COM+ security context inside IObjectControl.Activate.",
            NULL::CO_E_TRACKER_CONFIG => "The provided tracker configuration is invalid",
            NULL::CO_E_THREADPOOL_CONFIG => "The provided thread pool configuration is invalid",
            NULL::CO_E_SXS_CONFIG => "The provided side-by-side configuration is invalid",
            NULL::CO_E_MALFORMED_SPN => "The server principal name (SPN) obtained during security negotiation is malformed.",
            NULL::CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN => "The caller failed to revoke a per-apartment registration before apartment shutdown.",
            NULL::CO_E_PREMATURE_STUB_RUNDOWN => "The object has been rundown by the stub manager while there are external clients.",
            NULL::E_UNEXPECTED => "Catastrophic failure",
            NULL::PDH_CSTATUS_NO_OBJECT => "The specified object is not found on the system.",
            NULL::PDH_CSTATUS_NO_COUNTER => "The specified counter could not be found.",
            NULL::PDH_CSTATUS_INVALID_DATA => "The returned data is not valid.",
            NULL::PDH_MEMORY_ALLOCATION_FAILURE => "A PDH function could not allocate enough temporary memory to complete the operation. Close some applications or extend the page file and retry the function.",
            NULL::PDH_INVALID_HANDLE => "The handle is not a valid PDH object.",
            NULL::PDH_INVALID_ARGUMENT => "A required argument is missing or incorrect.",
            NULL::PDH_FUNCTION_NOT_FOUND => "Unable to find the specified function.",
            NULL::PDH_CSTATUS_NO_COUNTERNAME => "No counter was specified.",
            NULL::PDH_CSTATUS_BAD_COUNTERNAME => "Unable to parse the counter path. Check the format and syntax of the specified path.",
            NULL::PDH_INVALID_BUFFER => "The buffer passed by the caller is not valid.",
            NULL::PDH_INSUFFICIENT_BUFFER => "The requested data is larger than the buffer supplied. Unable to return the requested data.",
            NULL::PDH_CANNOT_CONNECT_MACHINE => "Unable to connect to the requested computer.",
            NULL::PDH_INVALID_PATH => "The specified counter path could not be interpreted.",
            NULL::PDH_INVALID_INSTANCE => "The instance name could not be read from the specified counter path.",
            NULL::PDH_INVALID_DATA => "The data is not valid.",
            NULL::PDH_NO_DIALOG_DATA => "The dialog box data block was missing or not valid.",
            NULL::PDH_CANNOT_READ_NAME_STRINGS => "Unable to read the counter and/or help text from the specified computer.",
            NULL::PDH_LOG_FILE_CREATE_ERROR => "Unable to create the specified log file.",
            NULL::PDH_LOG_FILE_OPEN_ERROR => "Unable to open the specified log file.",
            NULL::PDH_LOG_TYPE_NOT_FOUND => "The specified log file type has not been installed on this system.",
            NULL::PDH_NO_MORE_DATA => "No more data is available.",
            NULL::PDH_ENTRY_NOT_IN_LOG_FILE => "The specified record was not found in the log file.",
            NULL::PDH_DATA_SOURCE_IS_LOG_FILE => "The specified data source is a log file.",
            NULL::PDH_DATA_SOURCE_IS_REAL_TIME => "The specified data source is the current activity.",
            NULL::PDH_UNABLE_READ_LOG_HEADER => "The log file header could not be read.",
            NULL::PDH_FILE_NOT_FOUND => "Unable to find the specified file.",
            NULL::PDH_FILE_ALREADY_EXISTS => "There is already a file with the specified file name.",
            NULL::PDH_NOT_IMPLEMENTED => "The function referenced has not been implemented.",
            NULL::PDH_STRING_NOT_FOUND => "Unable to find the specified string in the list of performance name and help text strings.",
            NULL::PDH_UNKNOWN_LOG_FORMAT => "The format of the specified log file is not recognized by the PDH DLL.",
            NULL::PDH_UNKNOWN_LOGSVC_COMMAND => "The specified Log Service command value is not recognized.",
            NULL::PDH_LOGSVC_QUERY_NOT_FOUND => "The specified query from the Log Service could not be found or could not be opened.",
            NULL::PDH_LOGSVC_NOT_OPENED => "The Performance Data Log Service key could not be opened. This may be due to insufficient privilege or because the service has not been installed.",
            NULL::PDH_WBEM_ERROR => "An error occurred while accessing the WBEM data store.",
            NULL::PDH_ACCESS_DENIED => "Unable to access the desired computer or service. Check the permissions and authentication of the log service or the interactive user session against those on the computer or service being monitored.",
            NULL::PDH_LOG_FILE_TOO_SMALL => "The maximum log file size specified is too small to log the selected counters. No data will be recorded in this log file. Specify a smaller set of counters to log or a larger file size and retry this call.",
            NULL::PDH_INVALID_DATASOURCE => "Cannot connect to ODBC DataSource Name.",
            NULL::PDH_INVALID_SQLDB => "SQL Database does not contain a valid set of tables for Perfmon.",
            NULL::PDH_NO_COUNTERS => "No counters were found for this Perfmon SQL Log Set.",
            NULL::PDH_SQL_ALLOC_FAILED => "Call to SQLAllocStmt failed with %1.",
            NULL::PDH_SQL_ALLOCCON_FAILED => "Call to SQLAllocConnect failed with %1.",
            NULL::PDH_SQL_EXEC_DIRECT_FAILED => "Call to SQLExecDirect failed with %1.",
            NULL::PDH_SQL_FETCH_FAILED => "Call to SQLFetch failed with %1.",
            NULL::PDH_SQL_ROWCOUNT_FAILED => "Call to SQLRowCount failed with %1.",
            NULL::PDH_SQL_MORE_RESULTS_FAILED => "Call to SQLMoreResults failed with %1.",
            NULL::PDH_SQL_CONNECT_FAILED => "Call to SQLConnect failed with %1.",
            NULL::PDH_SQL_BIND_FAILED => "Call to SQLBindCol failed with %1.",
            NULL::PDH_CANNOT_CONNECT_WMI_SERVER => "Unable to connect to the WMI server on requested computer.",
            NULL::PDH_PLA_COLLECTION_ALREADY_RUNNING => "Collection '%1!s!' is already running.",
            NULL::PDH_PLA_ERROR_SCHEDULE_OVERLAP => "The specified start time is after the end time.",
            NULL::PDH_PLA_COLLECTION_NOT_FOUND => "Collection '%1!s!' does not exist.",
            NULL::PDH_PLA_ERROR_SCHEDULE_ELAPSED => "The specified end time has already elapsed.",
            NULL::PDH_PLA_ERROR_NOSTART => "Collection '%1!s!' did not start; check the application event log for any errors.",
            NULL::PDH_PLA_ERROR_ALREADY_EXISTS => "Collection '%1!s!' already exists.",
            NULL::PDH_PLA_ERROR_TYPE_MISMATCH => "There is a mismatch in the settings type.",
            NULL::PDH_PLA_ERROR_FILEPATH => "The information specified does not resolve to a valid path name.",
            NULL::PDH_PLA_SERVICE_ERROR => "The 'Performance Logs & Alerts' service did not respond.",
            NULL::PDH_PLA_VALIDATION_ERROR => "The information passed is not valid.",
            NULL::PDH_PLA_ERROR_NAME_TOO_LONG => "The name supplied is too long.",
            NULL::PDH_INVALID_SQL_LOG_FORMAT => "SQL log format is incorrect. Correct format is 'SQL:&<DSN-name&>!&<LogSet-Name&>'.",
            NULL::PDH_COUNTER_ALREADY_IN_QUERY => "Performance counter in PdhAddCounter call has already been added in the performance query. This counter is ignored.",
            NULL::PDH_BINARY_LOG_CORRUPT => "Unable to read counter information and data from input binary log files.",
            NULL::PDH_LOG_SAMPLE_TOO_SMALL => "At least one of the input binary log files contain fewer than two data samples.",
            NULL::PDH_OS_LATER_VERSION => "The version of the operating system on the computer named %1 is later than that on the local computer. This operation is not available from the local computer.",
            NULL::PDH_OS_EARLIER_VERSION => "%1 supports %2 or later. Check the operating system version on the computer named %3.",
            NULL::PDH_INCORRECT_APPEND_TIME => "The output file must contain earlier data than the file to be appended.",
            NULL::PDH_UNMATCHED_APPEND_COUNTER => "Both files must have identical counters in order to append.",
            NULL::PDH_SQL_ALTER_DETAIL_FAILED => "Cannot alter CounterDetail table layout in SQL database.",
            NULL::PDH_QUERY_PERF_DATA_TIMEOUT => "System is busy. A time-out occurred when collecting counter data. Please retry later or increase the CollectTime registry value.",
        }
    }

    pub fn from_name(name: &str) -> NULL {
        return match name {
            "ERROR_SUCCESS" => NULL::ERROR_SUCCESS,
            "PDH_CSTATUS_VALID_DATA" => NULL::PDH_CSTATUS_VALID_DATA,
            "SUCCESS" => NULL::SUCCESS,
            "NERR_Success" => NULL::NERR_Success,
            "S_OK" => NULL::S_OK,
            "NOERROR" => NULL::NOERROR,
            "S_FALSE" => NULL::S_FALSE,
            "E_NOTIMPL" => NULL::E_NOTIMPL,
            "E_OUTOFMEMORY" => NULL::E_OUTOFMEMORY,
            "E_INVALIDARG" => NULL::E_INVALIDARG,
            "E_NOINTERFACE" => NULL::E_NOINTERFACE,
            "E_POINTER" => NULL::E_POINTER,
            "E_HANDLE" => NULL::E_HANDLE,
            "E_ABORT" => NULL::E_ABORT,
            "E_FAIL" => NULL::E_FAIL,
            "E_ACCESSDENIED" => NULL::E_ACCESSDENIED,
            "E_PENDING" => NULL::E_PENDING,
            "E_BOUNDS" => NULL::E_BOUNDS,
            "E_CHANGED_STATE" => NULL::E_CHANGED_STATE,
            "E_ILLEGAL_STATE_CHANGE" => NULL::E_ILLEGAL_STATE_CHANGE,
            "E_ILLEGAL_METHOD_CALL" => NULL::E_ILLEGAL_METHOD_CALL,
            "RO_E_METADATA_NAME_NOT_FOUND" => NULL::RO_E_METADATA_NAME_NOT_FOUND,
            "RO_E_METADATA_NAME_IS_NAMESPACE" => NULL::RO_E_METADATA_NAME_IS_NAMESPACE,
            "RO_E_METADATA_INVALID_TYPE_FORMAT" => NULL::RO_E_METADATA_INVALID_TYPE_FORMAT,
            "RO_E_INVALID_METADATA_FILE" => NULL::RO_E_INVALID_METADATA_FILE,
            "RO_E_CLOSED" => NULL::RO_E_CLOSED,
            "RO_E_EXCLUSIVE_WRITE" => NULL::RO_E_EXCLUSIVE_WRITE,
            "RO_E_CHANGE_NOTIFICATION_IN_PROGRESS" => NULL::RO_E_CHANGE_NOTIFICATION_IN_PROGRESS,
            "RO_E_ERROR_STRING_NOT_FOUND" => NULL::RO_E_ERROR_STRING_NOT_FOUND,
            "E_STRING_NOT_NULL_TERMINATED" => NULL::E_STRING_NOT_NULL_TERMINATED,
            "E_ILLEGAL_DELEGATE_ASSIGNMENT" => NULL::E_ILLEGAL_DELEGATE_ASSIGNMENT,
            "E_ASYNC_OPERATION_NOT_STARTED" => NULL::E_ASYNC_OPERATION_NOT_STARTED,
            "E_APPLICATION_EXITING" => NULL::E_APPLICATION_EXITING,
            "E_APPLICATION_VIEW_EXITING" => NULL::E_APPLICATION_VIEW_EXITING,
            "RO_E_MUST_BE_AGILE" => NULL::RO_E_MUST_BE_AGILE,
            "RO_E_UNSUPPORTED_FROM_MTA" => NULL::RO_E_UNSUPPORTED_FROM_MTA,
            "RO_E_COMMITTED" => NULL::RO_E_COMMITTED,
            "RO_E_BLOCKED_CROSS_ASTA_CALL" => NULL::RO_E_BLOCKED_CROSS_ASTA_CALL,
            "RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER" => NULL::RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER,
            "RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER" => NULL::RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER,
            "PDH_CSTATUS_NO_MACHINE" => NULL::PDH_CSTATUS_NO_MACHINE,
            "PDH_CSTATUS_NO_INSTANCE" => NULL::PDH_CSTATUS_NO_INSTANCE,
            "PDH_MORE_DATA" => NULL::PDH_MORE_DATA,
            "PDH_CSTATUS_ITEM_NOT_VALIDATED" => NULL::PDH_CSTATUS_ITEM_NOT_VALIDATED,
            "PDH_RETRY" => NULL::PDH_RETRY,
            "PDH_NO_DATA" => NULL::PDH_NO_DATA,
            "PDH_CALC_NEGATIVE_DENOMINATOR" => NULL::PDH_CALC_NEGATIVE_DENOMINATOR,
            "PDH_CALC_NEGATIVE_TIMEBASE" => NULL::PDH_CALC_NEGATIVE_TIMEBASE,
            "PDH_CALC_NEGATIVE_VALUE" => NULL::PDH_CALC_NEGATIVE_VALUE,
            "PDH_DIALOG_CANCELLED" => NULL::PDH_DIALOG_CANCELLED,
            "PDH_END_OF_LOG_FILE" => NULL::PDH_END_OF_LOG_FILE,
            "PDH_ASYNC_QUERY_TIMEOUT" => NULL::PDH_ASYNC_QUERY_TIMEOUT,
            "PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE" => NULL::PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE,
            "PDH_UNABLE_MAP_NAME_FILES" => NULL::PDH_UNABLE_MAP_NAME_FILES,
            "PDH_PLA_VALIDATION_WARNING" => NULL::PDH_PLA_VALIDATION_WARNING,
            "DDERR_UNSUPPORTED" => NULL::DDERR_UNSUPPORTED,
            "DDERR_GENERIC" => NULL::DDERR_GENERIC,
            "CO_E_INIT_TLS" => NULL::CO_E_INIT_TLS,
            "CO_E_INIT_SHARED_ALLOCATOR" => NULL::CO_E_INIT_SHARED_ALLOCATOR,
            "CO_E_INIT_MEMORY_ALLOCATOR" => NULL::CO_E_INIT_MEMORY_ALLOCATOR,
            "CO_E_INIT_CLASS_CACHE" => NULL::CO_E_INIT_CLASS_CACHE,
            "CO_E_INIT_RPC_CHANNEL" => NULL::CO_E_INIT_RPC_CHANNEL,
            "CO_E_INIT_TLS_SET_CHANNEL_CONTROL" => NULL::CO_E_INIT_TLS_SET_CHANNEL_CONTROL,
            "CO_E_INIT_TLS_CHANNEL_CONTROL" => NULL::CO_E_INIT_TLS_CHANNEL_CONTROL,
            "CO_E_INIT_UNACCEPTED_USER_ALLOCATOR" => NULL::CO_E_INIT_UNACCEPTED_USER_ALLOCATOR,
            "CO_E_INIT_SCM_MUTEX_EXISTS" => NULL::CO_E_INIT_SCM_MUTEX_EXISTS,
            "CO_E_INIT_SCM_FILE_MAPPING_EXISTS" => NULL::CO_E_INIT_SCM_FILE_MAPPING_EXISTS,
            "CO_E_INIT_SCM_MAP_VIEW_OF_FILE" => NULL::CO_E_INIT_SCM_MAP_VIEW_OF_FILE,
            "CO_E_INIT_SCM_EXEC_FAILURE" => NULL::CO_E_INIT_SCM_EXEC_FAILURE,
            "CO_E_INIT_ONLY_SINGLE_THREADED" => NULL::CO_E_INIT_ONLY_SINGLE_THREADED,
            "CO_E_CANT_REMOTE" => NULL::CO_E_CANT_REMOTE,
            "CO_E_BAD_SERVER_NAME" => NULL::CO_E_BAD_SERVER_NAME,
            "CO_E_WRONG_SERVER_IDENTITY" => NULL::CO_E_WRONG_SERVER_IDENTITY,
            "CO_E_OLE1DDE_DISABLED" => NULL::CO_E_OLE1DDE_DISABLED,
            "CO_E_RUNAS_SYNTAX" => NULL::CO_E_RUNAS_SYNTAX,
            "CO_E_CREATEPROCESS_FAILURE" => NULL::CO_E_CREATEPROCESS_FAILURE,
            "CO_E_RUNAS_CREATEPROCESS_FAILURE" => NULL::CO_E_RUNAS_CREATEPROCESS_FAILURE,
            "CO_E_RUNAS_LOGON_FAILURE" => NULL::CO_E_RUNAS_LOGON_FAILURE,
            "CO_E_LAUNCH_PERMSSION_DENIED" => NULL::CO_E_LAUNCH_PERMSSION_DENIED,
            "CO_E_START_SERVICE_FAILURE" => NULL::CO_E_START_SERVICE_FAILURE,
            "CO_E_REMOTE_COMMUNICATION_FAILURE" => NULL::CO_E_REMOTE_COMMUNICATION_FAILURE,
            "CO_E_SERVER_START_TIMEOUT" => NULL::CO_E_SERVER_START_TIMEOUT,
            "CO_E_CLSREG_INCONSISTENT" => NULL::CO_E_CLSREG_INCONSISTENT,
            "CO_E_IIDREG_INCONSISTENT" => NULL::CO_E_IIDREG_INCONSISTENT,
            "CO_E_NOT_SUPPORTED" => NULL::CO_E_NOT_SUPPORTED,
            "CO_E_RELOAD_DLL" => NULL::CO_E_RELOAD_DLL,
            "CO_E_MSI_ERROR" => NULL::CO_E_MSI_ERROR,
            "CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT" => NULL::CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT,
            "CO_E_SERVER_PAUSED" => NULL::CO_E_SERVER_PAUSED,
            "CO_E_SERVER_NOT_PAUSED" => NULL::CO_E_SERVER_NOT_PAUSED,
            "CO_E_CLASS_DISABLED" => NULL::CO_E_CLASS_DISABLED,
            "CO_E_CLRNOTAVAILABLE" => NULL::CO_E_CLRNOTAVAILABLE,
            "CO_E_ASYNC_WORK_REJECTED" => NULL::CO_E_ASYNC_WORK_REJECTED,
            "CO_E_SERVER_INIT_TIMEOUT" => NULL::CO_E_SERVER_INIT_TIMEOUT,
            "CO_E_NO_SECCTX_IN_ACTIVATE" => NULL::CO_E_NO_SECCTX_IN_ACTIVATE,
            "CO_E_TRACKER_CONFIG" => NULL::CO_E_TRACKER_CONFIG,
            "CO_E_THREADPOOL_CONFIG" => NULL::CO_E_THREADPOOL_CONFIG,
            "CO_E_SXS_CONFIG" => NULL::CO_E_SXS_CONFIG,
            "CO_E_MALFORMED_SPN" => NULL::CO_E_MALFORMED_SPN,
            "CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN" => NULL::CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN,
            "CO_E_PREMATURE_STUB_RUNDOWN" => NULL::CO_E_PREMATURE_STUB_RUNDOWN,
            "E_UNEXPECTED" => NULL::E_UNEXPECTED,
            "PDH_CSTATUS_NO_OBJECT" => NULL::PDH_CSTATUS_NO_OBJECT,
            "PDH_CSTATUS_NO_COUNTER" => NULL::PDH_CSTATUS_NO_COUNTER,
            "PDH_CSTATUS_INVALID_DATA" => NULL::PDH_CSTATUS_INVALID_DATA,
            "PDH_MEMORY_ALLOCATION_FAILURE" => NULL::PDH_MEMORY_ALLOCATION_FAILURE,
            "PDH_INVALID_HANDLE" => NULL::PDH_INVALID_HANDLE,
            "PDH_INVALID_ARGUMENT" => NULL::PDH_INVALID_ARGUMENT,
            "PDH_FUNCTION_NOT_FOUND" => NULL::PDH_FUNCTION_NOT_FOUND,
            "PDH_CSTATUS_NO_COUNTERNAME" => NULL::PDH_CSTATUS_NO_COUNTERNAME,
            "PDH_CSTATUS_BAD_COUNTERNAME" => NULL::PDH_CSTATUS_BAD_COUNTERNAME,
            "PDH_INVALID_BUFFER" => NULL::PDH_INVALID_BUFFER,
            "PDH_INSUFFICIENT_BUFFER" => NULL::PDH_INSUFFICIENT_BUFFER,
            "PDH_CANNOT_CONNECT_MACHINE" => NULL::PDH_CANNOT_CONNECT_MACHINE,
            "PDH_INVALID_PATH" => NULL::PDH_INVALID_PATH,
            "PDH_INVALID_INSTANCE" => NULL::PDH_INVALID_INSTANCE,
            "PDH_INVALID_DATA" => NULL::PDH_INVALID_DATA,
            "PDH_NO_DIALOG_DATA" => NULL::PDH_NO_DIALOG_DATA,
            "PDH_CANNOT_READ_NAME_STRINGS" => NULL::PDH_CANNOT_READ_NAME_STRINGS,
            "PDH_LOG_FILE_CREATE_ERROR" => NULL::PDH_LOG_FILE_CREATE_ERROR,
            "PDH_LOG_FILE_OPEN_ERROR" => NULL::PDH_LOG_FILE_OPEN_ERROR,
            "PDH_LOG_TYPE_NOT_FOUND" => NULL::PDH_LOG_TYPE_NOT_FOUND,
            "PDH_NO_MORE_DATA" => NULL::PDH_NO_MORE_DATA,
            "PDH_ENTRY_NOT_IN_LOG_FILE" => NULL::PDH_ENTRY_NOT_IN_LOG_FILE,
            "PDH_DATA_SOURCE_IS_LOG_FILE" => NULL::PDH_DATA_SOURCE_IS_LOG_FILE,
            "PDH_DATA_SOURCE_IS_REAL_TIME" => NULL::PDH_DATA_SOURCE_IS_REAL_TIME,
            "PDH_UNABLE_READ_LOG_HEADER" => NULL::PDH_UNABLE_READ_LOG_HEADER,
            "PDH_FILE_NOT_FOUND" => NULL::PDH_FILE_NOT_FOUND,
            "PDH_FILE_ALREADY_EXISTS" => NULL::PDH_FILE_ALREADY_EXISTS,
            "PDH_NOT_IMPLEMENTED" => NULL::PDH_NOT_IMPLEMENTED,
            "PDH_STRING_NOT_FOUND" => NULL::PDH_STRING_NOT_FOUND,
            "PDH_UNKNOWN_LOG_FORMAT" => NULL::PDH_UNKNOWN_LOG_FORMAT,
            "PDH_UNKNOWN_LOGSVC_COMMAND" => NULL::PDH_UNKNOWN_LOGSVC_COMMAND,
            "PDH_LOGSVC_QUERY_NOT_FOUND" => NULL::PDH_LOGSVC_QUERY_NOT_FOUND,
            "PDH_LOGSVC_NOT_OPENED" => NULL::PDH_LOGSVC_NOT_OPENED,
            "PDH_WBEM_ERROR" => NULL::PDH_WBEM_ERROR,
            "PDH_ACCESS_DENIED" => NULL::PDH_ACCESS_DENIED,
            "PDH_LOG_FILE_TOO_SMALL" => NULL::PDH_LOG_FILE_TOO_SMALL,
            "PDH_INVALID_DATASOURCE" => NULL::PDH_INVALID_DATASOURCE,
            "PDH_INVALID_SQLDB" => NULL::PDH_INVALID_SQLDB,
            "PDH_NO_COUNTERS" => NULL::PDH_NO_COUNTERS,
            "PDH_SQL_ALLOC_FAILED" => NULL::PDH_SQL_ALLOC_FAILED,
            "PDH_SQL_ALLOCCON_FAILED" => NULL::PDH_SQL_ALLOCCON_FAILED,
            "PDH_SQL_EXEC_DIRECT_FAILED" => NULL::PDH_SQL_EXEC_DIRECT_FAILED,
            "PDH_SQL_FETCH_FAILED" => NULL::PDH_SQL_FETCH_FAILED,
            "PDH_SQL_ROWCOUNT_FAILED" => NULL::PDH_SQL_ROWCOUNT_FAILED,
            "PDH_SQL_MORE_RESULTS_FAILED" => NULL::PDH_SQL_MORE_RESULTS_FAILED,
            "PDH_SQL_CONNECT_FAILED" => NULL::PDH_SQL_CONNECT_FAILED,
            "PDH_SQL_BIND_FAILED" => NULL::PDH_SQL_BIND_FAILED,
            "PDH_CANNOT_CONNECT_WMI_SERVER" => NULL::PDH_CANNOT_CONNECT_WMI_SERVER,
            "PDH_PLA_COLLECTION_ALREADY_RUNNING" => NULL::PDH_PLA_COLLECTION_ALREADY_RUNNING,
            "PDH_PLA_ERROR_SCHEDULE_OVERLAP" => NULL::PDH_PLA_ERROR_SCHEDULE_OVERLAP,
            "PDH_PLA_COLLECTION_NOT_FOUND" => NULL::PDH_PLA_COLLECTION_NOT_FOUND,
            "PDH_PLA_ERROR_SCHEDULE_ELAPSED" => NULL::PDH_PLA_ERROR_SCHEDULE_ELAPSED,
            "PDH_PLA_ERROR_NOSTART" => NULL::PDH_PLA_ERROR_NOSTART,
            "PDH_PLA_ERROR_ALREADY_EXISTS" => NULL::PDH_PLA_ERROR_ALREADY_EXISTS,
            "PDH_PLA_ERROR_TYPE_MISMATCH" => NULL::PDH_PLA_ERROR_TYPE_MISMATCH,
            "PDH_PLA_ERROR_FILEPATH" => NULL::PDH_PLA_ERROR_FILEPATH,
            "PDH_PLA_SERVICE_ERROR" => NULL::PDH_PLA_SERVICE_ERROR,
            "PDH_PLA_VALIDATION_ERROR" => NULL::PDH_PLA_VALIDATION_ERROR,
            "PDH_PLA_ERROR_NAME_TOO_LONG" => NULL::PDH_PLA_ERROR_NAME_TOO_LONG,
            "PDH_INVALID_SQL_LOG_FORMAT" => NULL::PDH_INVALID_SQL_LOG_FORMAT,
            "PDH_COUNTER_ALREADY_IN_QUERY" => NULL::PDH_COUNTER_ALREADY_IN_QUERY,
            "PDH_BINARY_LOG_CORRUPT" => NULL::PDH_BINARY_LOG_CORRUPT,
            "PDH_LOG_SAMPLE_TOO_SMALL" => NULL::PDH_LOG_SAMPLE_TOO_SMALL,
            "PDH_OS_LATER_VERSION" => NULL::PDH_OS_LATER_VERSION,
            "PDH_OS_EARLIER_VERSION" => NULL::PDH_OS_EARLIER_VERSION,
            "PDH_INCORRECT_APPEND_TIME" => NULL::PDH_INCORRECT_APPEND_TIME,
            "PDH_UNMATCHED_APPEND_COUNTER" => NULL::PDH_UNMATCHED_APPEND_COUNTER,
            "PDH_SQL_ALTER_DETAIL_FAILED" => NULL::PDH_SQL_ALTER_DETAIL_FAILED,
            "PDH_QUERY_PERF_DATA_TIMEOUT" => NULL::PDH_QUERY_PERF_DATA_TIMEOUT,
        }
    }
    pub fn from_code(code: u32) -> NULL {
        return match code {
            0x00000000 => NULL::ERROR_SUCCESS,
            0x00000000 => NULL::PDH_CSTATUS_VALID_DATA,
            0x00000000 => NULL::SUCCESS,
            0x00000000 => NULL::NERR_Success,
            0x00000000 => NULL::S_OK,
            0x00000000 => NULL::NOERROR,
            0x00000001 => NULL::S_FALSE,
            0x80000001 => NULL::E_NOTIMPL,
            0x80000002 => NULL::E_OUTOFMEMORY,
            0x80000003 => NULL::E_INVALIDARG,
            0x80000004 => NULL::E_NOINTERFACE,
            0x80000005 => NULL::E_POINTER,
            0x80000006 => NULL::E_HANDLE,
            0x80000007 => NULL::E_ABORT,
            0x80000008 => NULL::E_FAIL,
            0x80000009 => NULL::E_ACCESSDENIED,
            0x8000000A => NULL::E_PENDING,
            0x8000000B => NULL::E_BOUNDS,
            0x8000000C => NULL::E_CHANGED_STATE,
            0x8000000D => NULL::E_ILLEGAL_STATE_CHANGE,
            0x8000000E => NULL::E_ILLEGAL_METHOD_CALL,
            0x8000000F => NULL::RO_E_METADATA_NAME_NOT_FOUND,
            0x80000010 => NULL::RO_E_METADATA_NAME_IS_NAMESPACE,
            0x80000011 => NULL::RO_E_METADATA_INVALID_TYPE_FORMAT,
            0x80000012 => NULL::RO_E_INVALID_METADATA_FILE,
            0x80000013 => NULL::RO_E_CLOSED,
            0x80000014 => NULL::RO_E_EXCLUSIVE_WRITE,
            0x80000015 => NULL::RO_E_CHANGE_NOTIFICATION_IN_PROGRESS,
            0x80000016 => NULL::RO_E_ERROR_STRING_NOT_FOUND,
            0x80000017 => NULL::E_STRING_NOT_NULL_TERMINATED,
            0x80000018 => NULL::E_ILLEGAL_DELEGATE_ASSIGNMENT,
            0x80000019 => NULL::E_ASYNC_OPERATION_NOT_STARTED,
            0x8000001A => NULL::E_APPLICATION_EXITING,
            0x8000001B => NULL::E_APPLICATION_VIEW_EXITING,
            0x8000001C => NULL::RO_E_MUST_BE_AGILE,
            0x8000001D => NULL::RO_E_UNSUPPORTED_FROM_MTA,
            0x8000001E => NULL::RO_E_COMMITTED,
            0x8000001F => NULL::RO_E_BLOCKED_CROSS_ASTA_CALL,
            0x80000020 => NULL::RO_E_CANNOT_ACTIVATE_FULL_TRUST_SERVER,
            0x80000021 => NULL::RO_E_CANNOT_ACTIVATE_UNIVERSAL_APPLICATION_SERVER,
            0x800007D0 => NULL::PDH_CSTATUS_NO_MACHINE,
            0x800007D1 => NULL::PDH_CSTATUS_NO_INSTANCE,
            0x800007D2 => NULL::PDH_MORE_DATA,
            0x800007D3 => NULL::PDH_CSTATUS_ITEM_NOT_VALIDATED,
            0x800007D4 => NULL::PDH_RETRY,
            0x800007D5 => NULL::PDH_NO_DATA,
            0x800007D6 => NULL::PDH_CALC_NEGATIVE_DENOMINATOR,
            0x800007D7 => NULL::PDH_CALC_NEGATIVE_TIMEBASE,
            0x800007D8 => NULL::PDH_CALC_NEGATIVE_VALUE,
            0x800007D9 => NULL::PDH_DIALOG_CANCELLED,
            0x800007DA => NULL::PDH_END_OF_LOG_FILE,
            0x800007DB => NULL::PDH_ASYNC_QUERY_TIMEOUT,
            0x800007DC => NULL::PDH_CANNOT_SET_DEFAULT_REALTIME_DATASOURCE,
            0x80000BD5 => NULL::PDH_UNABLE_MAP_NAME_FILES,
            0x80000BF3 => NULL::PDH_PLA_VALIDATION_WARNING,
            0x80004001 => NULL::DDERR_UNSUPPORTED,
            0x80004005 => NULL::DDERR_GENERIC,
            0x80004006 => NULL::CO_E_INIT_TLS,
            0x80004007 => NULL::CO_E_INIT_SHARED_ALLOCATOR,
            0x80004008 => NULL::CO_E_INIT_MEMORY_ALLOCATOR,
            0x80004009 => NULL::CO_E_INIT_CLASS_CACHE,
            0x8000400A => NULL::CO_E_INIT_RPC_CHANNEL,
            0x8000400B => NULL::CO_E_INIT_TLS_SET_CHANNEL_CONTROL,
            0x8000400C => NULL::CO_E_INIT_TLS_CHANNEL_CONTROL,
            0x8000400D => NULL::CO_E_INIT_UNACCEPTED_USER_ALLOCATOR,
            0x8000400E => NULL::CO_E_INIT_SCM_MUTEX_EXISTS,
            0x8000400F => NULL::CO_E_INIT_SCM_FILE_MAPPING_EXISTS,
            0x80004010 => NULL::CO_E_INIT_SCM_MAP_VIEW_OF_FILE,
            0x80004011 => NULL::CO_E_INIT_SCM_EXEC_FAILURE,
            0x80004012 => NULL::CO_E_INIT_ONLY_SINGLE_THREADED,
            0x80004013 => NULL::CO_E_CANT_REMOTE,
            0x80004014 => NULL::CO_E_BAD_SERVER_NAME,
            0x80004015 => NULL::CO_E_WRONG_SERVER_IDENTITY,
            0x80004016 => NULL::CO_E_OLE1DDE_DISABLED,
            0x80004017 => NULL::CO_E_RUNAS_SYNTAX,
            0x80004018 => NULL::CO_E_CREATEPROCESS_FAILURE,
            0x80004019 => NULL::CO_E_RUNAS_CREATEPROCESS_FAILURE,
            0x8000401A => NULL::CO_E_RUNAS_LOGON_FAILURE,
            0x8000401B => NULL::CO_E_LAUNCH_PERMSSION_DENIED,
            0x8000401C => NULL::CO_E_START_SERVICE_FAILURE,
            0x8000401D => NULL::CO_E_REMOTE_COMMUNICATION_FAILURE,
            0x8000401E => NULL::CO_E_SERVER_START_TIMEOUT,
            0x8000401F => NULL::CO_E_CLSREG_INCONSISTENT,
            0x80004020 => NULL::CO_E_IIDREG_INCONSISTENT,
            0x80004021 => NULL::CO_E_NOT_SUPPORTED,
            0x80004022 => NULL::CO_E_RELOAD_DLL,
            0x80004023 => NULL::CO_E_MSI_ERROR,
            0x80004024 => NULL::CO_E_ATTEMPT_TO_CREATE_OUTSIDE_CLIENT_CONTEXT,
            0x80004025 => NULL::CO_E_SERVER_PAUSED,
            0x80004026 => NULL::CO_E_SERVER_NOT_PAUSED,
            0x80004027 => NULL::CO_E_CLASS_DISABLED,
            0x80004028 => NULL::CO_E_CLRNOTAVAILABLE,
            0x80004029 => NULL::CO_E_ASYNC_WORK_REJECTED,
            0x8000402A => NULL::CO_E_SERVER_INIT_TIMEOUT,
            0x8000402B => NULL::CO_E_NO_SECCTX_IN_ACTIVATE,
            0x80004030 => NULL::CO_E_TRACKER_CONFIG,
            0x80004031 => NULL::CO_E_THREADPOOL_CONFIG,
            0x80004032 => NULL::CO_E_SXS_CONFIG,
            0x80004033 => NULL::CO_E_MALFORMED_SPN,
            0x80004034 => NULL::CO_E_UNREVOKED_REGISTRATION_ON_APARTMENT_SHUTDOWN,
            0x80004035 => NULL::CO_E_PREMATURE_STUB_RUNDOWN,
            0x8000FFFF => NULL::E_UNEXPECTED,
            0xC0000BB8 => NULL::PDH_CSTATUS_NO_OBJECT,
            0xC0000BB9 => NULL::PDH_CSTATUS_NO_COUNTER,
            0xC0000BBA => NULL::PDH_CSTATUS_INVALID_DATA,
            0xC0000BBB => NULL::PDH_MEMORY_ALLOCATION_FAILURE,
            0xC0000BBC => NULL::PDH_INVALID_HANDLE,
            0xC0000BBD => NULL::PDH_INVALID_ARGUMENT,
            0xC0000BBE => NULL::PDH_FUNCTION_NOT_FOUND,
            0xC0000BBF => NULL::PDH_CSTATUS_NO_COUNTERNAME,
            0xC0000BC0 => NULL::PDH_CSTATUS_BAD_COUNTERNAME,
            0xC0000BC1 => NULL::PDH_INVALID_BUFFER,
            0xC0000BC2 => NULL::PDH_INSUFFICIENT_BUFFER,
            0xC0000BC3 => NULL::PDH_CANNOT_CONNECT_MACHINE,
            0xC0000BC4 => NULL::PDH_INVALID_PATH,
            0xC0000BC5 => NULL::PDH_INVALID_INSTANCE,
            0xC0000BC6 => NULL::PDH_INVALID_DATA,
            0xC0000BC7 => NULL::PDH_NO_DIALOG_DATA,
            0xC0000BC8 => NULL::PDH_CANNOT_READ_NAME_STRINGS,
            0xC0000BC9 => NULL::PDH_LOG_FILE_CREATE_ERROR,
            0xC0000BCA => NULL::PDH_LOG_FILE_OPEN_ERROR,
            0xC0000BCB => NULL::PDH_LOG_TYPE_NOT_FOUND,
            0xC0000BCC => NULL::PDH_NO_MORE_DATA,
            0xC0000BCD => NULL::PDH_ENTRY_NOT_IN_LOG_FILE,
            0xC0000BCE => NULL::PDH_DATA_SOURCE_IS_LOG_FILE,
            0xC0000BCF => NULL::PDH_DATA_SOURCE_IS_REAL_TIME,
            0xC0000BD0 => NULL::PDH_UNABLE_READ_LOG_HEADER,
            0xC0000BD1 => NULL::PDH_FILE_NOT_FOUND,
            0xC0000BD2 => NULL::PDH_FILE_ALREADY_EXISTS,
            0xC0000BD3 => NULL::PDH_NOT_IMPLEMENTED,
            0xC0000BD4 => NULL::PDH_STRING_NOT_FOUND,
            0xC0000BD6 => NULL::PDH_UNKNOWN_LOG_FORMAT,
            0xC0000BD7 => NULL::PDH_UNKNOWN_LOGSVC_COMMAND,
            0xC0000BD8 => NULL::PDH_LOGSVC_QUERY_NOT_FOUND,
            0xC0000BD9 => NULL::PDH_LOGSVC_NOT_OPENED,
            0xC0000BDA => NULL::PDH_WBEM_ERROR,
            0xC0000BDB => NULL::PDH_ACCESS_DENIED,
            0xC0000BDC => NULL::PDH_LOG_FILE_TOO_SMALL,
            0xC0000BDD => NULL::PDH_INVALID_DATASOURCE,
            0xC0000BDE => NULL::PDH_INVALID_SQLDB,
            0xC0000BDF => NULL::PDH_NO_COUNTERS,
            0xC0000BE0 => NULL::PDH_SQL_ALLOC_FAILED,
            0xC0000BE1 => NULL::PDH_SQL_ALLOCCON_FAILED,
            0xC0000BE2 => NULL::PDH_SQL_EXEC_DIRECT_FAILED,
            0xC0000BE3 => NULL::PDH_SQL_FETCH_FAILED,
            0xC0000BE4 => NULL::PDH_SQL_ROWCOUNT_FAILED,
            0xC0000BE5 => NULL::PDH_SQL_MORE_RESULTS_FAILED,
            0xC0000BE6 => NULL::PDH_SQL_CONNECT_FAILED,
            0xC0000BE7 => NULL::PDH_SQL_BIND_FAILED,
            0xC0000BE8 => NULL::PDH_CANNOT_CONNECT_WMI_SERVER,
            0xC0000BE9 => NULL::PDH_PLA_COLLECTION_ALREADY_RUNNING,
            0xC0000BEA => NULL::PDH_PLA_ERROR_SCHEDULE_OVERLAP,
            0xC0000BEB => NULL::PDH_PLA_COLLECTION_NOT_FOUND,
            0xC0000BEC => NULL::PDH_PLA_ERROR_SCHEDULE_ELAPSED,
            0xC0000BED => NULL::PDH_PLA_ERROR_NOSTART,
            0xC0000BEE => NULL::PDH_PLA_ERROR_ALREADY_EXISTS,
            0xC0000BEF => NULL::PDH_PLA_ERROR_TYPE_MISMATCH,
            0xC0000BF0 => NULL::PDH_PLA_ERROR_FILEPATH,
            0xC0000BF1 => NULL::PDH_PLA_SERVICE_ERROR,
            0xC0000BF2 => NULL::PDH_PLA_VALIDATION_ERROR,
            0xC0000BF4 => NULL::PDH_PLA_ERROR_NAME_TOO_LONG,
            0xC0000BF5 => NULL::PDH_INVALID_SQL_LOG_FORMAT,
            0xC0000BF6 => NULL::PDH_COUNTER_ALREADY_IN_QUERY,
            0xC0000BF7 => NULL::PDH_BINARY_LOG_CORRUPT,
            0xC0000BF8 => NULL::PDH_LOG_SAMPLE_TOO_SMALL,
            0xC0000BF9 => NULL::PDH_OS_LATER_VERSION,
            0xC0000BFA => NULL::PDH_OS_EARLIER_VERSION,
            0xC0000BFB => NULL::PDH_INCORRECT_APPEND_TIME,
            0xC0000BFC => NULL::PDH_UNMATCHED_APPEND_COUNTER,
            0xC0000BFD => NULL::PDH_SQL_ALTER_DETAIL_FAILED,
            0xC0000BFE => NULL::PDH_QUERY_PERF_DATA_TIMEOUT,
        }
    }
}
