/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum P2P {
    PEER_S_GRAPH_DATA_CREATED,
    PEER_S_NO_EVENT_DATA,
    PEER_S_NO_CONNECTIVITY,
    PEER_S_ALREADY_A_MEMBER,
    PEER_S_ALREADY_CONNECTED,
    PEER_S_SUBSCRIPTION_EXISTS,
    PEER_E_IPV6_NOT_INSTALLED,
    PEER_E_NOT_INITIALIZED,
    PEER_E_CANNOT_START_SERVICE,
    PEER_E_NOT_LICENSED,
    PEER_E_INVALID_GRAPH,
    PEER_E_DBNAME_CHANGED,
    PEER_E_DUPLICATE_GRAPH,
    PEER_E_GRAPH_NOT_READY,
    PEER_E_GRAPH_SHUTTING_DOWN,
    PEER_E_GRAPH_IN_USE,
    PEER_E_INVALID_DATABASE,
    PEER_E_TOO_MANY_ATTRIBUTES,
    PEER_E_CONNECTION_NOT_FOUND,
    PEER_E_CONNECT_SELF,
    PEER_E_ALREADY_LISTENING,
    PEER_E_NODE_NOT_FOUND,
    PEER_E_CONNECTION_FAILED,
    PEER_E_CONNECTION_NOT_AUTHENTICATED,
    PEER_E_CONNECTION_REFUSED,
    PEER_E_CLASSIFIER_TOO_LONG,
    PEER_E_TOO_MANY_IDENTITIES,
    PEER_E_NO_KEY_ACCESS,
    PEER_E_GROUPS_EXIST,
    PEER_E_RECORD_NOT_FOUND,
    PEER_E_DATABASE_ACCESSDENIED,
    PEER_E_DBINITIALIZATION_FAILED,
    PEER_E_MAX_RECORD_SIZE_EXCEEDED,
    PEER_E_DATABASE_ALREADY_PRESENT,
    PEER_E_DATABASE_NOT_PRESENT,
    PEER_E_IDENTITY_NOT_FOUND,
    PEER_E_EVENT_HANDLE_NOT_FOUND,
    PEER_E_INVALID_SEARCH,
    PEER_E_INVALID_ATTRIBUTES,
    PEER_E_INVITATION_NOT_TRUSTED,
    PEER_E_CHAIN_TOO_LONG,
    PEER_E_INVALID_TIME_PERIOD,
    PEER_E_CIRCULAR_CHAIN_DETECTED,
    PEER_E_CERT_STORE_CORRUPTED,
    PEER_E_NO_CLOUD,
    PEER_E_CLOUD_NAME_AMBIGUOUS,
    PEER_E_INVALID_RECORD,
    PEER_E_NOT_AUTHORIZED,
    PEER_E_PASSWORD_DOES_NOT_MEET_POLICY,
    PEER_E_DEFERRED_VALIDATION,
    PEER_E_INVALID_GROUP_PROPERTIES,
    PEER_E_INVALID_PEER_NAME,
    PEER_E_INVALID_CLASSIFIER,
    PEER_E_INVALID_FRIENDLY_NAME,
    PEER_E_INVALID_ROLE_PROPERTY,
    PEER_E_INVALID_CLASSIFIER_PROPERTY,
    PEER_E_INVALID_RECORD_EXPIRATION,
    PEER_E_INVALID_CREDENTIAL_INFO,
    PEER_E_INVALID_CREDENTIAL,
    PEER_E_INVALID_RECORD_SIZE,
    PEER_E_UNSUPPORTED_VERSION,
    PEER_E_GROUP_NOT_READY,
    PEER_E_GROUP_IN_USE,
    PEER_E_INVALID_GROUP,
    PEER_E_NO_MEMBERS_FOUND,
    PEER_E_NO_MEMBER_CONNECTIONS,
    PEER_E_UNABLE_TO_LISTEN,
    PEER_E_IDENTITY_DELETED,
    PEER_E_SERVICE_NOT_AVAILABLE,
    PEER_E_CANNOT_CONVERT_PEER_NAME,
    PEER_E_INVALID_PEER_HOST_NAME,
    PEER_E_NO_MORE,
    PEER_E_PNRP_DUPLICATE_PEER_NAME,
    PEER_E_CONTACT_NOT_FOUND,
    PEER_E_INVITE_CANCELLED,
    PEER_E_INVITE_RESPONSE_NOT_AVAILABLE,
    PEER_E_NOT_SIGNED_IN,
    PEER_E_PRIVACY_DECLINED,
    PEER_E_TIMEOUT,
    PEER_E_INVALID_ADDRESS,
    PEER_E_FW_EXCEPTION_DISABLED,
    PEER_E_FW_BLOCKED_BY_POLICY,
    PEER_E_FW_BLOCKED_BY_SHIELDS_UP,
    PEER_E_FW_DECLINED,
}

impl P2P {
    pub fn code(&self) -> u32 {
        return match self {
            P2P::PEER_S_GRAPH_DATA_CREATED => 0x00630001 as u32,
            P2P::PEER_S_NO_EVENT_DATA => 0x00630002 as u32,
            P2P::PEER_S_NO_CONNECTIVITY => 0x00630005 as u32,
            P2P::PEER_S_ALREADY_A_MEMBER => 0x00630006 as u32,
            P2P::PEER_S_ALREADY_CONNECTED => 0x00632000 as u32,
            P2P::PEER_S_SUBSCRIPTION_EXISTS => 0x00636000 as u32,
            P2P::PEER_E_IPV6_NOT_INSTALLED => 0x80630001 as u32,
            P2P::PEER_E_NOT_INITIALIZED => 0x80630002 as u32,
            P2P::PEER_E_CANNOT_START_SERVICE => 0x80630003 as u32,
            P2P::PEER_E_NOT_LICENSED => 0x80630004 as u32,
            P2P::PEER_E_INVALID_GRAPH => 0x80630010 as u32,
            P2P::PEER_E_DBNAME_CHANGED => 0x80630011 as u32,
            P2P::PEER_E_DUPLICATE_GRAPH => 0x80630012 as u32,
            P2P::PEER_E_GRAPH_NOT_READY => 0x80630013 as u32,
            P2P::PEER_E_GRAPH_SHUTTING_DOWN => 0x80630014 as u32,
            P2P::PEER_E_GRAPH_IN_USE => 0x80630015 as u32,
            P2P::PEER_E_INVALID_DATABASE => 0x80630016 as u32,
            P2P::PEER_E_TOO_MANY_ATTRIBUTES => 0x80630017 as u32,
            P2P::PEER_E_CONNECTION_NOT_FOUND => 0x80630103 as u32,
            P2P::PEER_E_CONNECT_SELF => 0x80630106 as u32,
            P2P::PEER_E_ALREADY_LISTENING => 0x80630107 as u32,
            P2P::PEER_E_NODE_NOT_FOUND => 0x80630108 as u32,
            P2P::PEER_E_CONNECTION_FAILED => 0x80630109 as u32,
            P2P::PEER_E_CONNECTION_NOT_AUTHENTICATED => 0x8063010A as u32,
            P2P::PEER_E_CONNECTION_REFUSED => 0x8063010B as u32,
            P2P::PEER_E_CLASSIFIER_TOO_LONG => 0x80630201 as u32,
            P2P::PEER_E_TOO_MANY_IDENTITIES => 0x80630202 as u32,
            P2P::PEER_E_NO_KEY_ACCESS => 0x80630203 as u32,
            P2P::PEER_E_GROUPS_EXIST => 0x80630204 as u32,
            P2P::PEER_E_RECORD_NOT_FOUND => 0x80630301 as u32,
            P2P::PEER_E_DATABASE_ACCESSDENIED => 0x80630302 as u32,
            P2P::PEER_E_DBINITIALIZATION_FAILED => 0x80630303 as u32,
            P2P::PEER_E_MAX_RECORD_SIZE_EXCEEDED => 0x80630304 as u32,
            P2P::PEER_E_DATABASE_ALREADY_PRESENT => 0x80630305 as u32,
            P2P::PEER_E_DATABASE_NOT_PRESENT => 0x80630306 as u32,
            P2P::PEER_E_IDENTITY_NOT_FOUND => 0x80630401 as u32,
            P2P::PEER_E_EVENT_HANDLE_NOT_FOUND => 0x80630501 as u32,
            P2P::PEER_E_INVALID_SEARCH => 0x80630601 as u32,
            P2P::PEER_E_INVALID_ATTRIBUTES => 0x80630602 as u32,
            P2P::PEER_E_INVITATION_NOT_TRUSTED => 0x80630701 as u32,
            P2P::PEER_E_CHAIN_TOO_LONG => 0x80630703 as u32,
            P2P::PEER_E_INVALID_TIME_PERIOD => 0x80630705 as u32,
            P2P::PEER_E_CIRCULAR_CHAIN_DETECTED => 0x80630706 as u32,
            P2P::PEER_E_CERT_STORE_CORRUPTED => 0x80630801 as u32,
            P2P::PEER_E_NO_CLOUD => 0x80631001 as u32,
            P2P::PEER_E_CLOUD_NAME_AMBIGUOUS => 0x80631005 as u32,
            P2P::PEER_E_INVALID_RECORD => 0x80632010 as u32,
            P2P::PEER_E_NOT_AUTHORIZED => 0x80632020 as u32,
            P2P::PEER_E_PASSWORD_DOES_NOT_MEET_POLICY => 0x80632021 as u32,
            P2P::PEER_E_DEFERRED_VALIDATION => 0x80632030 as u32,
            P2P::PEER_E_INVALID_GROUP_PROPERTIES => 0x80632040 as u32,
            P2P::PEER_E_INVALID_PEER_NAME => 0x80632050 as u32,
            P2P::PEER_E_INVALID_CLASSIFIER => 0x80632060 as u32,
            P2P::PEER_E_INVALID_FRIENDLY_NAME => 0x80632070 as u32,
            P2P::PEER_E_INVALID_ROLE_PROPERTY => 0x80632071 as u32,
            P2P::PEER_E_INVALID_CLASSIFIER_PROPERTY => 0x80632072 as u32,
            P2P::PEER_E_INVALID_RECORD_EXPIRATION => 0x80632080 as u32,
            P2P::PEER_E_INVALID_CREDENTIAL_INFO => 0x80632081 as u32,
            P2P::PEER_E_INVALID_CREDENTIAL => 0x80632082 as u32,
            P2P::PEER_E_INVALID_RECORD_SIZE => 0x80632083 as u32,
            P2P::PEER_E_UNSUPPORTED_VERSION => 0x80632090 as u32,
            P2P::PEER_E_GROUP_NOT_READY => 0x80632091 as u32,
            P2P::PEER_E_GROUP_IN_USE => 0x80632092 as u32,
            P2P::PEER_E_INVALID_GROUP => 0x80632093 as u32,
            P2P::PEER_E_NO_MEMBERS_FOUND => 0x80632094 as u32,
            P2P::PEER_E_NO_MEMBER_CONNECTIONS => 0x80632095 as u32,
            P2P::PEER_E_UNABLE_TO_LISTEN => 0x80632096 as u32,
            P2P::PEER_E_IDENTITY_DELETED => 0x806320A0 as u32,
            P2P::PEER_E_SERVICE_NOT_AVAILABLE => 0x806320A1 as u32,
            P2P::PEER_E_CANNOT_CONVERT_PEER_NAME => 0x80634001 as u32,
            P2P::PEER_E_INVALID_PEER_HOST_NAME => 0x80634002 as u32,
            P2P::PEER_E_NO_MORE => 0x80634003 as u32,
            P2P::PEER_E_PNRP_DUPLICATE_PEER_NAME => 0x80634005 as u32,
            P2P::PEER_E_CONTACT_NOT_FOUND => 0x80636001 as u32,
            P2P::PEER_E_INVITE_CANCELLED => 0x80637000 as u32,
            P2P::PEER_E_INVITE_RESPONSE_NOT_AVAILABLE => 0x80637001 as u32,
            P2P::PEER_E_NOT_SIGNED_IN => 0x80637003 as u32,
            P2P::PEER_E_PRIVACY_DECLINED => 0x80637004 as u32,
            P2P::PEER_E_TIMEOUT => 0x80637005 as u32,
            P2P::PEER_E_INVALID_ADDRESS => 0x80637007 as u32,
            P2P::PEER_E_FW_EXCEPTION_DISABLED => 0x80637008 as u32,
            P2P::PEER_E_FW_BLOCKED_BY_POLICY => 0x80637009 as u32,
            P2P::PEER_E_FW_BLOCKED_BY_SHIELDS_UP => 0x8063700A as u32,
            P2P::PEER_E_FW_DECLINED => 0x8063700B as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            P2P::PEER_S_GRAPH_DATA_CREATED => RawError::Kind(P2P::PEER_S_GRAPH_DATA_CREATED),
            P2P::PEER_S_NO_EVENT_DATA => RawError::Kind(P2P::PEER_S_NO_EVENT_DATA),
            P2P::PEER_S_NO_CONNECTIVITY => RawError::Kind(P2P::PEER_S_NO_CONNECTIVITY),
            P2P::PEER_S_ALREADY_A_MEMBER => RawError::Kind(P2P::PEER_S_ALREADY_A_MEMBER),
            P2P::PEER_S_ALREADY_CONNECTED => RawError::Kind(P2P::PEER_S_ALREADY_CONNECTED),
            P2P::PEER_S_SUBSCRIPTION_EXISTS => RawError::Kind(P2P::PEER_S_SUBSCRIPTION_EXISTS),
            P2P::PEER_E_IPV6_NOT_INSTALLED => RawError::Kind(P2P::PEER_E_IPV6_NOT_INSTALLED),
            P2P::PEER_E_NOT_INITIALIZED => RawError::Kind(P2P::PEER_E_NOT_INITIALIZED),
            P2P::PEER_E_CANNOT_START_SERVICE => RawError::Kind(P2P::PEER_E_CANNOT_START_SERVICE),
            P2P::PEER_E_NOT_LICENSED => RawError::Kind(P2P::PEER_E_NOT_LICENSED),
            P2P::PEER_E_INVALID_GRAPH => RawError::Kind(P2P::PEER_E_INVALID_GRAPH),
            P2P::PEER_E_DBNAME_CHANGED => RawError::Kind(P2P::PEER_E_DBNAME_CHANGED),
            P2P::PEER_E_DUPLICATE_GRAPH => RawError::Kind(P2P::PEER_E_DUPLICATE_GRAPH),
            P2P::PEER_E_GRAPH_NOT_READY => RawError::Kind(P2P::PEER_E_GRAPH_NOT_READY),
            P2P::PEER_E_GRAPH_SHUTTING_DOWN => RawError::Kind(P2P::PEER_E_GRAPH_SHUTTING_DOWN),
            P2P::PEER_E_GRAPH_IN_USE => RawError::Kind(P2P::PEER_E_GRAPH_IN_USE),
            P2P::PEER_E_INVALID_DATABASE => RawError::Kind(P2P::PEER_E_INVALID_DATABASE),
            P2P::PEER_E_TOO_MANY_ATTRIBUTES => RawError::Kind(P2P::PEER_E_TOO_MANY_ATTRIBUTES),
            P2P::PEER_E_CONNECTION_NOT_FOUND => RawError::Kind(P2P::PEER_E_CONNECTION_NOT_FOUND),
            P2P::PEER_E_CONNECT_SELF => RawError::Kind(P2P::PEER_E_CONNECT_SELF),
            P2P::PEER_E_ALREADY_LISTENING => RawError::Kind(P2P::PEER_E_ALREADY_LISTENING),
            P2P::PEER_E_NODE_NOT_FOUND => RawError::Kind(P2P::PEER_E_NODE_NOT_FOUND),
            P2P::PEER_E_CONNECTION_FAILED => RawError::Kind(P2P::PEER_E_CONNECTION_FAILED),
            P2P::PEER_E_CONNECTION_NOT_AUTHENTICATED => RawError::Kind(P2P::PEER_E_CONNECTION_NOT_AUTHENTICATED),
            P2P::PEER_E_CONNECTION_REFUSED => RawError::Kind(P2P::PEER_E_CONNECTION_REFUSED),
            P2P::PEER_E_CLASSIFIER_TOO_LONG => RawError::Kind(P2P::PEER_E_CLASSIFIER_TOO_LONG),
            P2P::PEER_E_TOO_MANY_IDENTITIES => RawError::Kind(P2P::PEER_E_TOO_MANY_IDENTITIES),
            P2P::PEER_E_NO_KEY_ACCESS => RawError::Kind(P2P::PEER_E_NO_KEY_ACCESS),
            P2P::PEER_E_GROUPS_EXIST => RawError::Kind(P2P::PEER_E_GROUPS_EXIST),
            P2P::PEER_E_RECORD_NOT_FOUND => RawError::Kind(P2P::PEER_E_RECORD_NOT_FOUND),
            P2P::PEER_E_DATABASE_ACCESSDENIED => RawError::Kind(P2P::PEER_E_DATABASE_ACCESSDENIED),
            P2P::PEER_E_DBINITIALIZATION_FAILED => RawError::Kind(P2P::PEER_E_DBINITIALIZATION_FAILED),
            P2P::PEER_E_MAX_RECORD_SIZE_EXCEEDED => RawError::Kind(P2P::PEER_E_MAX_RECORD_SIZE_EXCEEDED),
            P2P::PEER_E_DATABASE_ALREADY_PRESENT => RawError::Kind(P2P::PEER_E_DATABASE_ALREADY_PRESENT),
            P2P::PEER_E_DATABASE_NOT_PRESENT => RawError::Kind(P2P::PEER_E_DATABASE_NOT_PRESENT),
            P2P::PEER_E_IDENTITY_NOT_FOUND => RawError::Kind(P2P::PEER_E_IDENTITY_NOT_FOUND),
            P2P::PEER_E_EVENT_HANDLE_NOT_FOUND => RawError::Kind(P2P::PEER_E_EVENT_HANDLE_NOT_FOUND),
            P2P::PEER_E_INVALID_SEARCH => RawError::Kind(P2P::PEER_E_INVALID_SEARCH),
            P2P::PEER_E_INVALID_ATTRIBUTES => RawError::Kind(P2P::PEER_E_INVALID_ATTRIBUTES),
            P2P::PEER_E_INVITATION_NOT_TRUSTED => RawError::Kind(P2P::PEER_E_INVITATION_NOT_TRUSTED),
            P2P::PEER_E_CHAIN_TOO_LONG => RawError::Kind(P2P::PEER_E_CHAIN_TOO_LONG),
            P2P::PEER_E_INVALID_TIME_PERIOD => RawError::Kind(P2P::PEER_E_INVALID_TIME_PERIOD),
            P2P::PEER_E_CIRCULAR_CHAIN_DETECTED => RawError::Kind(P2P::PEER_E_CIRCULAR_CHAIN_DETECTED),
            P2P::PEER_E_CERT_STORE_CORRUPTED => RawError::Kind(P2P::PEER_E_CERT_STORE_CORRUPTED),
            P2P::PEER_E_NO_CLOUD => RawError::Kind(P2P::PEER_E_NO_CLOUD),
            P2P::PEER_E_CLOUD_NAME_AMBIGUOUS => RawError::Kind(P2P::PEER_E_CLOUD_NAME_AMBIGUOUS),
            P2P::PEER_E_INVALID_RECORD => RawError::Kind(P2P::PEER_E_INVALID_RECORD),
            P2P::PEER_E_NOT_AUTHORIZED => RawError::Kind(P2P::PEER_E_NOT_AUTHORIZED),
            P2P::PEER_E_PASSWORD_DOES_NOT_MEET_POLICY => RawError::Kind(P2P::PEER_E_PASSWORD_DOES_NOT_MEET_POLICY),
            P2P::PEER_E_DEFERRED_VALIDATION => RawError::Kind(P2P::PEER_E_DEFERRED_VALIDATION),
            P2P::PEER_E_INVALID_GROUP_PROPERTIES => RawError::Kind(P2P::PEER_E_INVALID_GROUP_PROPERTIES),
            P2P::PEER_E_INVALID_PEER_NAME => RawError::Kind(P2P::PEER_E_INVALID_PEER_NAME),
            P2P::PEER_E_INVALID_CLASSIFIER => RawError::Kind(P2P::PEER_E_INVALID_CLASSIFIER),
            P2P::PEER_E_INVALID_FRIENDLY_NAME => RawError::Kind(P2P::PEER_E_INVALID_FRIENDLY_NAME),
            P2P::PEER_E_INVALID_ROLE_PROPERTY => RawError::Kind(P2P::PEER_E_INVALID_ROLE_PROPERTY),
            P2P::PEER_E_INVALID_CLASSIFIER_PROPERTY => RawError::Kind(P2P::PEER_E_INVALID_CLASSIFIER_PROPERTY),
            P2P::PEER_E_INVALID_RECORD_EXPIRATION => RawError::Kind(P2P::PEER_E_INVALID_RECORD_EXPIRATION),
            P2P::PEER_E_INVALID_CREDENTIAL_INFO => RawError::Kind(P2P::PEER_E_INVALID_CREDENTIAL_INFO),
            P2P::PEER_E_INVALID_CREDENTIAL => RawError::Kind(P2P::PEER_E_INVALID_CREDENTIAL),
            P2P::PEER_E_INVALID_RECORD_SIZE => RawError::Kind(P2P::PEER_E_INVALID_RECORD_SIZE),
            P2P::PEER_E_UNSUPPORTED_VERSION => RawError::Kind(P2P::PEER_E_UNSUPPORTED_VERSION),
            P2P::PEER_E_GROUP_NOT_READY => RawError::Kind(P2P::PEER_E_GROUP_NOT_READY),
            P2P::PEER_E_GROUP_IN_USE => RawError::Kind(P2P::PEER_E_GROUP_IN_USE),
            P2P::PEER_E_INVALID_GROUP => RawError::Kind(P2P::PEER_E_INVALID_GROUP),
            P2P::PEER_E_NO_MEMBERS_FOUND => RawError::Kind(P2P::PEER_E_NO_MEMBERS_FOUND),
            P2P::PEER_E_NO_MEMBER_CONNECTIONS => RawError::Kind(P2P::PEER_E_NO_MEMBER_CONNECTIONS),
            P2P::PEER_E_UNABLE_TO_LISTEN => RawError::Kind(P2P::PEER_E_UNABLE_TO_LISTEN),
            P2P::PEER_E_IDENTITY_DELETED => RawError::Kind(P2P::PEER_E_IDENTITY_DELETED),
            P2P::PEER_E_SERVICE_NOT_AVAILABLE => RawError::Kind(P2P::PEER_E_SERVICE_NOT_AVAILABLE),
            P2P::PEER_E_CANNOT_CONVERT_PEER_NAME => RawError::Kind(P2P::PEER_E_CANNOT_CONVERT_PEER_NAME),
            P2P::PEER_E_INVALID_PEER_HOST_NAME => RawError::Kind(P2P::PEER_E_INVALID_PEER_HOST_NAME),
            P2P::PEER_E_NO_MORE => RawError::Kind(P2P::PEER_E_NO_MORE),
            P2P::PEER_E_PNRP_DUPLICATE_PEER_NAME => RawError::Kind(P2P::PEER_E_PNRP_DUPLICATE_PEER_NAME),
            P2P::PEER_E_CONTACT_NOT_FOUND => RawError::Kind(P2P::PEER_E_CONTACT_NOT_FOUND),
            P2P::PEER_E_INVITE_CANCELLED => RawError::Kind(P2P::PEER_E_INVITE_CANCELLED),
            P2P::PEER_E_INVITE_RESPONSE_NOT_AVAILABLE => RawError::Kind(P2P::PEER_E_INVITE_RESPONSE_NOT_AVAILABLE),
            P2P::PEER_E_NOT_SIGNED_IN => RawError::Kind(P2P::PEER_E_NOT_SIGNED_IN),
            P2P::PEER_E_PRIVACY_DECLINED => RawError::Kind(P2P::PEER_E_PRIVACY_DECLINED),
            P2P::PEER_E_TIMEOUT => RawError::Kind(P2P::PEER_E_TIMEOUT),
            P2P::PEER_E_INVALID_ADDRESS => RawError::Kind(P2P::PEER_E_INVALID_ADDRESS),
            P2P::PEER_E_FW_EXCEPTION_DISABLED => RawError::Kind(P2P::PEER_E_FW_EXCEPTION_DISABLED),
            P2P::PEER_E_FW_BLOCKED_BY_POLICY => RawError::Kind(P2P::PEER_E_FW_BLOCKED_BY_POLICY),
            P2P::PEER_E_FW_BLOCKED_BY_SHIELDS_UP => RawError::Kind(P2P::PEER_E_FW_BLOCKED_BY_SHIELDS_UP),
            P2P::PEER_E_FW_DECLINED => RawError::Kind(P2P::PEER_E_FW_DECLINED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            P2P::PEER_S_GRAPH_DATA_CREATED => "The graph data was created.",
            P2P::PEER_S_NO_EVENT_DATA => "There is not more event data.",
            P2P::PEER_S_NO_CONNECTIVITY => "No connectivity.",
            P2P::PEER_S_ALREADY_A_MEMBER => "Already a member.",
            P2P::PEER_S_ALREADY_CONNECTED => "The graph is already connect.",
            P2P::PEER_S_SUBSCRIPTION_EXISTS => "The subscription already exists.",
            P2P::PEER_E_IPV6_NOT_INSTALLED => "The IPv6 protocol is not installed.",
            P2P::PEER_E_NOT_INITIALIZED => "The component has not been initialized.",
            P2P::PEER_E_CANNOT_START_SERVICE => "The required service cannot be started.",
            P2P::PEER_E_NOT_LICENSED => "The P2P protocol is not licensed to run on this OS.",
            P2P::PEER_E_INVALID_GRAPH => "The graph handle is invalid.",
            P2P::PEER_E_DBNAME_CHANGED => "The graph database name has changed.",
            P2P::PEER_E_DUPLICATE_GRAPH => "A graph with the same ID already exists.",
            P2P::PEER_E_GRAPH_NOT_READY => "The graph is not ready.",
            P2P::PEER_E_GRAPH_SHUTTING_DOWN => "The graph is shutting down.",
            P2P::PEER_E_GRAPH_IN_USE => "The graph is still in use.",
            P2P::PEER_E_INVALID_DATABASE => "The graph database is corrupt.",
            P2P::PEER_E_TOO_MANY_ATTRIBUTES => "Too many attributes have been used.",
            P2P::PEER_E_CONNECTION_NOT_FOUND => "The connection can not be found.",
            P2P::PEER_E_CONNECT_SELF => "The peer attempted to connect to itself.",
            P2P::PEER_E_ALREADY_LISTENING => "The peer is already listening for connections.",
            P2P::PEER_E_NODE_NOT_FOUND => "The node was not found.",
            P2P::PEER_E_CONNECTION_FAILED => "The Connection attempt failed.",
            P2P::PEER_E_CONNECTION_NOT_AUTHENTICATED => "The peer connection could not be authenticated.",
            P2P::PEER_E_CONNECTION_REFUSED => "The connection was refused.",
            P2P::PEER_E_CLASSIFIER_TOO_LONG => "The peer name classifier is too long.",
            P2P::PEER_E_TOO_MANY_IDENTITIES => "The maximum number of identities have been created.",
            P2P::PEER_E_NO_KEY_ACCESS => "Unable to access a key.",
            P2P::PEER_E_GROUPS_EXIST => "The group already exists.",
            P2P::PEER_E_RECORD_NOT_FOUND => "The requested record could not be found.",
            P2P::PEER_E_DATABASE_ACCESSDENIED => "Access to the database was denied.",
            P2P::PEER_E_DBINITIALIZATION_FAILED => "The Database could not be initialized.",
            P2P::PEER_E_MAX_RECORD_SIZE_EXCEEDED => "The record is too big.",
            P2P::PEER_E_DATABASE_ALREADY_PRESENT => "The database already exists.",
            P2P::PEER_E_DATABASE_NOT_PRESENT => "The database could not be found.",
            P2P::PEER_E_IDENTITY_NOT_FOUND => "The identity could not be found.",
            P2P::PEER_E_EVENT_HANDLE_NOT_FOUND => "The event handle could not be found.",
            P2P::PEER_E_INVALID_SEARCH => "Invalid search.",
            P2P::PEER_E_INVALID_ATTRIBUTES => "The search attributes are invalid.",
            P2P::PEER_E_INVITATION_NOT_TRUSTED => "The invitation is not trusted.",
            P2P::PEER_E_CHAIN_TOO_LONG => "The certchain is too long.",
            P2P::PEER_E_INVALID_TIME_PERIOD => "The time period is invalid.",
            P2P::PEER_E_CIRCULAR_CHAIN_DETECTED => "A circular cert chain was detected.",
            P2P::PEER_E_CERT_STORE_CORRUPTED => "The certstore is corrupted.",
            P2P::PEER_E_NO_CLOUD => "The specified PNRP cloud does not exist.",
            P2P::PEER_E_CLOUD_NAME_AMBIGUOUS => "The cloud name is ambiguous.",
            P2P::PEER_E_INVALID_RECORD => "The record is invalid.",
            P2P::PEER_E_NOT_AUTHORIZED => "Not authorized.",
            P2P::PEER_E_PASSWORD_DOES_NOT_MEET_POLICY => "The password does not meet policy requirements.",
            P2P::PEER_E_DEFERRED_VALIDATION => "The record validation has been deferred.",
            P2P::PEER_E_INVALID_GROUP_PROPERTIES => "The group properties are invalid.",
            P2P::PEER_E_INVALID_PEER_NAME => "The peername is invalid.",
            P2P::PEER_E_INVALID_CLASSIFIER => "The classifier is invalid.",
            P2P::PEER_E_INVALID_FRIENDLY_NAME => "The friendly name is invalid.",
            P2P::PEER_E_INVALID_ROLE_PROPERTY => "Invalid role property.",
            P2P::PEER_E_INVALID_CLASSIFIER_PROPERTY => "Invalid classifier property.",
            P2P::PEER_E_INVALID_RECORD_EXPIRATION => "Invalid record expiration.",
            P2P::PEER_E_INVALID_CREDENTIAL_INFO => "Invalid credential info.",
            P2P::PEER_E_INVALID_CREDENTIAL => "Invalid credential.",
            P2P::PEER_E_INVALID_RECORD_SIZE => "Invalid record size.",
            P2P::PEER_E_UNSUPPORTED_VERSION => "Unsupported version.",
            P2P::PEER_E_GROUP_NOT_READY => "The group is not ready.",
            P2P::PEER_E_GROUP_IN_USE => "The group is still in use.",
            P2P::PEER_E_INVALID_GROUP => "The group is invalid.",
            P2P::PEER_E_NO_MEMBERS_FOUND => "No members were found.",
            P2P::PEER_E_NO_MEMBER_CONNECTIONS => "There are no member connections.",
            P2P::PEER_E_UNABLE_TO_LISTEN => "Unable to listen.",
            P2P::PEER_E_IDENTITY_DELETED => "The identity does not exist.",
            P2P::PEER_E_SERVICE_NOT_AVAILABLE => "The service is not available.",
            P2P::PEER_E_CANNOT_CONVERT_PEER_NAME => "The peername could not be converted to a DNS pnrp name.",
            P2P::PEER_E_INVALID_PEER_HOST_NAME => "Invalid peer host name.",
            P2P::PEER_E_NO_MORE => "No more data could be found.",
            P2P::PEER_E_PNRP_DUPLICATE_PEER_NAME => "The existing peer name is already registered.",
            P2P::PEER_E_CONTACT_NOT_FOUND => "THe contact could not be found.",
            P2P::PEER_E_INVITE_CANCELLED => "The app invite request was cancelled by the user.",
            P2P::PEER_E_INVITE_RESPONSE_NOT_AVAILABLE => "No response of the invite was received.",
            P2P::PEER_E_NOT_SIGNED_IN => "User is not signed into serverless presence.",
            P2P::PEER_E_PRIVACY_DECLINED => "The user declined the privacy policy prompt.",
            P2P::PEER_E_TIMEOUT => "A timeout occurred.",
            P2P::PEER_E_INVALID_ADDRESS => "The address is invalid.",
            P2P::PEER_E_FW_EXCEPTION_DISABLED => "A required firewall exception is disabled.",
            P2P::PEER_E_FW_BLOCKED_BY_POLICY => "The service is blocked by a firewall policy.",
            P2P::PEER_E_FW_BLOCKED_BY_SHIELDS_UP => "Firewall exceptions are disabled.",
            P2P::PEER_E_FW_DECLINED => "The user declined to enable the firewall exceptions.",
        }
    }

    pub fn from_name(name: &str) -> P2P {
        return match name {
            "PEER_S_GRAPH_DATA_CREATED" => P2P::PEER_S_GRAPH_DATA_CREATED,
            "PEER_S_NO_EVENT_DATA" => P2P::PEER_S_NO_EVENT_DATA,
            "PEER_S_NO_CONNECTIVITY" => P2P::PEER_S_NO_CONNECTIVITY,
            "PEER_S_ALREADY_A_MEMBER" => P2P::PEER_S_ALREADY_A_MEMBER,
            "PEER_S_ALREADY_CONNECTED" => P2P::PEER_S_ALREADY_CONNECTED,
            "PEER_S_SUBSCRIPTION_EXISTS" => P2P::PEER_S_SUBSCRIPTION_EXISTS,
            "PEER_E_IPV6_NOT_INSTALLED" => P2P::PEER_E_IPV6_NOT_INSTALLED,
            "PEER_E_NOT_INITIALIZED" => P2P::PEER_E_NOT_INITIALIZED,
            "PEER_E_CANNOT_START_SERVICE" => P2P::PEER_E_CANNOT_START_SERVICE,
            "PEER_E_NOT_LICENSED" => P2P::PEER_E_NOT_LICENSED,
            "PEER_E_INVALID_GRAPH" => P2P::PEER_E_INVALID_GRAPH,
            "PEER_E_DBNAME_CHANGED" => P2P::PEER_E_DBNAME_CHANGED,
            "PEER_E_DUPLICATE_GRAPH" => P2P::PEER_E_DUPLICATE_GRAPH,
            "PEER_E_GRAPH_NOT_READY" => P2P::PEER_E_GRAPH_NOT_READY,
            "PEER_E_GRAPH_SHUTTING_DOWN" => P2P::PEER_E_GRAPH_SHUTTING_DOWN,
            "PEER_E_GRAPH_IN_USE" => P2P::PEER_E_GRAPH_IN_USE,
            "PEER_E_INVALID_DATABASE" => P2P::PEER_E_INVALID_DATABASE,
            "PEER_E_TOO_MANY_ATTRIBUTES" => P2P::PEER_E_TOO_MANY_ATTRIBUTES,
            "PEER_E_CONNECTION_NOT_FOUND" => P2P::PEER_E_CONNECTION_NOT_FOUND,
            "PEER_E_CONNECT_SELF" => P2P::PEER_E_CONNECT_SELF,
            "PEER_E_ALREADY_LISTENING" => P2P::PEER_E_ALREADY_LISTENING,
            "PEER_E_NODE_NOT_FOUND" => P2P::PEER_E_NODE_NOT_FOUND,
            "PEER_E_CONNECTION_FAILED" => P2P::PEER_E_CONNECTION_FAILED,
            "PEER_E_CONNECTION_NOT_AUTHENTICATED" => P2P::PEER_E_CONNECTION_NOT_AUTHENTICATED,
            "PEER_E_CONNECTION_REFUSED" => P2P::PEER_E_CONNECTION_REFUSED,
            "PEER_E_CLASSIFIER_TOO_LONG" => P2P::PEER_E_CLASSIFIER_TOO_LONG,
            "PEER_E_TOO_MANY_IDENTITIES" => P2P::PEER_E_TOO_MANY_IDENTITIES,
            "PEER_E_NO_KEY_ACCESS" => P2P::PEER_E_NO_KEY_ACCESS,
            "PEER_E_GROUPS_EXIST" => P2P::PEER_E_GROUPS_EXIST,
            "PEER_E_RECORD_NOT_FOUND" => P2P::PEER_E_RECORD_NOT_FOUND,
            "PEER_E_DATABASE_ACCESSDENIED" => P2P::PEER_E_DATABASE_ACCESSDENIED,
            "PEER_E_DBINITIALIZATION_FAILED" => P2P::PEER_E_DBINITIALIZATION_FAILED,
            "PEER_E_MAX_RECORD_SIZE_EXCEEDED" => P2P::PEER_E_MAX_RECORD_SIZE_EXCEEDED,
            "PEER_E_DATABASE_ALREADY_PRESENT" => P2P::PEER_E_DATABASE_ALREADY_PRESENT,
            "PEER_E_DATABASE_NOT_PRESENT" => P2P::PEER_E_DATABASE_NOT_PRESENT,
            "PEER_E_IDENTITY_NOT_FOUND" => P2P::PEER_E_IDENTITY_NOT_FOUND,
            "PEER_E_EVENT_HANDLE_NOT_FOUND" => P2P::PEER_E_EVENT_HANDLE_NOT_FOUND,
            "PEER_E_INVALID_SEARCH" => P2P::PEER_E_INVALID_SEARCH,
            "PEER_E_INVALID_ATTRIBUTES" => P2P::PEER_E_INVALID_ATTRIBUTES,
            "PEER_E_INVITATION_NOT_TRUSTED" => P2P::PEER_E_INVITATION_NOT_TRUSTED,
            "PEER_E_CHAIN_TOO_LONG" => P2P::PEER_E_CHAIN_TOO_LONG,
            "PEER_E_INVALID_TIME_PERIOD" => P2P::PEER_E_INVALID_TIME_PERIOD,
            "PEER_E_CIRCULAR_CHAIN_DETECTED" => P2P::PEER_E_CIRCULAR_CHAIN_DETECTED,
            "PEER_E_CERT_STORE_CORRUPTED" => P2P::PEER_E_CERT_STORE_CORRUPTED,
            "PEER_E_NO_CLOUD" => P2P::PEER_E_NO_CLOUD,
            "PEER_E_CLOUD_NAME_AMBIGUOUS" => P2P::PEER_E_CLOUD_NAME_AMBIGUOUS,
            "PEER_E_INVALID_RECORD" => P2P::PEER_E_INVALID_RECORD,
            "PEER_E_NOT_AUTHORIZED" => P2P::PEER_E_NOT_AUTHORIZED,
            "PEER_E_PASSWORD_DOES_NOT_MEET_POLICY" => P2P::PEER_E_PASSWORD_DOES_NOT_MEET_POLICY,
            "PEER_E_DEFERRED_VALIDATION" => P2P::PEER_E_DEFERRED_VALIDATION,
            "PEER_E_INVALID_GROUP_PROPERTIES" => P2P::PEER_E_INVALID_GROUP_PROPERTIES,
            "PEER_E_INVALID_PEER_NAME" => P2P::PEER_E_INVALID_PEER_NAME,
            "PEER_E_INVALID_CLASSIFIER" => P2P::PEER_E_INVALID_CLASSIFIER,
            "PEER_E_INVALID_FRIENDLY_NAME" => P2P::PEER_E_INVALID_FRIENDLY_NAME,
            "PEER_E_INVALID_ROLE_PROPERTY" => P2P::PEER_E_INVALID_ROLE_PROPERTY,
            "PEER_E_INVALID_CLASSIFIER_PROPERTY" => P2P::PEER_E_INVALID_CLASSIFIER_PROPERTY,
            "PEER_E_INVALID_RECORD_EXPIRATION" => P2P::PEER_E_INVALID_RECORD_EXPIRATION,
            "PEER_E_INVALID_CREDENTIAL_INFO" => P2P::PEER_E_INVALID_CREDENTIAL_INFO,
            "PEER_E_INVALID_CREDENTIAL" => P2P::PEER_E_INVALID_CREDENTIAL,
            "PEER_E_INVALID_RECORD_SIZE" => P2P::PEER_E_INVALID_RECORD_SIZE,
            "PEER_E_UNSUPPORTED_VERSION" => P2P::PEER_E_UNSUPPORTED_VERSION,
            "PEER_E_GROUP_NOT_READY" => P2P::PEER_E_GROUP_NOT_READY,
            "PEER_E_GROUP_IN_USE" => P2P::PEER_E_GROUP_IN_USE,
            "PEER_E_INVALID_GROUP" => P2P::PEER_E_INVALID_GROUP,
            "PEER_E_NO_MEMBERS_FOUND" => P2P::PEER_E_NO_MEMBERS_FOUND,
            "PEER_E_NO_MEMBER_CONNECTIONS" => P2P::PEER_E_NO_MEMBER_CONNECTIONS,
            "PEER_E_UNABLE_TO_LISTEN" => P2P::PEER_E_UNABLE_TO_LISTEN,
            "PEER_E_IDENTITY_DELETED" => P2P::PEER_E_IDENTITY_DELETED,
            "PEER_E_SERVICE_NOT_AVAILABLE" => P2P::PEER_E_SERVICE_NOT_AVAILABLE,
            "PEER_E_CANNOT_CONVERT_PEER_NAME" => P2P::PEER_E_CANNOT_CONVERT_PEER_NAME,
            "PEER_E_INVALID_PEER_HOST_NAME" => P2P::PEER_E_INVALID_PEER_HOST_NAME,
            "PEER_E_NO_MORE" => P2P::PEER_E_NO_MORE,
            "PEER_E_PNRP_DUPLICATE_PEER_NAME" => P2P::PEER_E_PNRP_DUPLICATE_PEER_NAME,
            "PEER_E_CONTACT_NOT_FOUND" => P2P::PEER_E_CONTACT_NOT_FOUND,
            "PEER_E_INVITE_CANCELLED" => P2P::PEER_E_INVITE_CANCELLED,
            "PEER_E_INVITE_RESPONSE_NOT_AVAILABLE" => P2P::PEER_E_INVITE_RESPONSE_NOT_AVAILABLE,
            "PEER_E_NOT_SIGNED_IN" => P2P::PEER_E_NOT_SIGNED_IN,
            "PEER_E_PRIVACY_DECLINED" => P2P::PEER_E_PRIVACY_DECLINED,
            "PEER_E_TIMEOUT" => P2P::PEER_E_TIMEOUT,
            "PEER_E_INVALID_ADDRESS" => P2P::PEER_E_INVALID_ADDRESS,
            "PEER_E_FW_EXCEPTION_DISABLED" => P2P::PEER_E_FW_EXCEPTION_DISABLED,
            "PEER_E_FW_BLOCKED_BY_POLICY" => P2P::PEER_E_FW_BLOCKED_BY_POLICY,
            "PEER_E_FW_BLOCKED_BY_SHIELDS_UP" => P2P::PEER_E_FW_BLOCKED_BY_SHIELDS_UP,
            "PEER_E_FW_DECLINED" => P2P::PEER_E_FW_DECLINED,
        }
    }
    pub fn from_code(code: u32) -> P2P {
        return match code {
            0x00630001 => P2P::PEER_S_GRAPH_DATA_CREATED,
            0x00630002 => P2P::PEER_S_NO_EVENT_DATA,
            0x00630005 => P2P::PEER_S_NO_CONNECTIVITY,
            0x00630006 => P2P::PEER_S_ALREADY_A_MEMBER,
            0x00632000 => P2P::PEER_S_ALREADY_CONNECTED,
            0x00636000 => P2P::PEER_S_SUBSCRIPTION_EXISTS,
            0x80630001 => P2P::PEER_E_IPV6_NOT_INSTALLED,
            0x80630002 => P2P::PEER_E_NOT_INITIALIZED,
            0x80630003 => P2P::PEER_E_CANNOT_START_SERVICE,
            0x80630004 => P2P::PEER_E_NOT_LICENSED,
            0x80630010 => P2P::PEER_E_INVALID_GRAPH,
            0x80630011 => P2P::PEER_E_DBNAME_CHANGED,
            0x80630012 => P2P::PEER_E_DUPLICATE_GRAPH,
            0x80630013 => P2P::PEER_E_GRAPH_NOT_READY,
            0x80630014 => P2P::PEER_E_GRAPH_SHUTTING_DOWN,
            0x80630015 => P2P::PEER_E_GRAPH_IN_USE,
            0x80630016 => P2P::PEER_E_INVALID_DATABASE,
            0x80630017 => P2P::PEER_E_TOO_MANY_ATTRIBUTES,
            0x80630103 => P2P::PEER_E_CONNECTION_NOT_FOUND,
            0x80630106 => P2P::PEER_E_CONNECT_SELF,
            0x80630107 => P2P::PEER_E_ALREADY_LISTENING,
            0x80630108 => P2P::PEER_E_NODE_NOT_FOUND,
            0x80630109 => P2P::PEER_E_CONNECTION_FAILED,
            0x8063010A => P2P::PEER_E_CONNECTION_NOT_AUTHENTICATED,
            0x8063010B => P2P::PEER_E_CONNECTION_REFUSED,
            0x80630201 => P2P::PEER_E_CLASSIFIER_TOO_LONG,
            0x80630202 => P2P::PEER_E_TOO_MANY_IDENTITIES,
            0x80630203 => P2P::PEER_E_NO_KEY_ACCESS,
            0x80630204 => P2P::PEER_E_GROUPS_EXIST,
            0x80630301 => P2P::PEER_E_RECORD_NOT_FOUND,
            0x80630302 => P2P::PEER_E_DATABASE_ACCESSDENIED,
            0x80630303 => P2P::PEER_E_DBINITIALIZATION_FAILED,
            0x80630304 => P2P::PEER_E_MAX_RECORD_SIZE_EXCEEDED,
            0x80630305 => P2P::PEER_E_DATABASE_ALREADY_PRESENT,
            0x80630306 => P2P::PEER_E_DATABASE_NOT_PRESENT,
            0x80630401 => P2P::PEER_E_IDENTITY_NOT_FOUND,
            0x80630501 => P2P::PEER_E_EVENT_HANDLE_NOT_FOUND,
            0x80630601 => P2P::PEER_E_INVALID_SEARCH,
            0x80630602 => P2P::PEER_E_INVALID_ATTRIBUTES,
            0x80630701 => P2P::PEER_E_INVITATION_NOT_TRUSTED,
            0x80630703 => P2P::PEER_E_CHAIN_TOO_LONG,
            0x80630705 => P2P::PEER_E_INVALID_TIME_PERIOD,
            0x80630706 => P2P::PEER_E_CIRCULAR_CHAIN_DETECTED,
            0x80630801 => P2P::PEER_E_CERT_STORE_CORRUPTED,
            0x80631001 => P2P::PEER_E_NO_CLOUD,
            0x80631005 => P2P::PEER_E_CLOUD_NAME_AMBIGUOUS,
            0x80632010 => P2P::PEER_E_INVALID_RECORD,
            0x80632020 => P2P::PEER_E_NOT_AUTHORIZED,
            0x80632021 => P2P::PEER_E_PASSWORD_DOES_NOT_MEET_POLICY,
            0x80632030 => P2P::PEER_E_DEFERRED_VALIDATION,
            0x80632040 => P2P::PEER_E_INVALID_GROUP_PROPERTIES,
            0x80632050 => P2P::PEER_E_INVALID_PEER_NAME,
            0x80632060 => P2P::PEER_E_INVALID_CLASSIFIER,
            0x80632070 => P2P::PEER_E_INVALID_FRIENDLY_NAME,
            0x80632071 => P2P::PEER_E_INVALID_ROLE_PROPERTY,
            0x80632072 => P2P::PEER_E_INVALID_CLASSIFIER_PROPERTY,
            0x80632080 => P2P::PEER_E_INVALID_RECORD_EXPIRATION,
            0x80632081 => P2P::PEER_E_INVALID_CREDENTIAL_INFO,
            0x80632082 => P2P::PEER_E_INVALID_CREDENTIAL,
            0x80632083 => P2P::PEER_E_INVALID_RECORD_SIZE,
            0x80632090 => P2P::PEER_E_UNSUPPORTED_VERSION,
            0x80632091 => P2P::PEER_E_GROUP_NOT_READY,
            0x80632092 => P2P::PEER_E_GROUP_IN_USE,
            0x80632093 => P2P::PEER_E_INVALID_GROUP,
            0x80632094 => P2P::PEER_E_NO_MEMBERS_FOUND,
            0x80632095 => P2P::PEER_E_NO_MEMBER_CONNECTIONS,
            0x80632096 => P2P::PEER_E_UNABLE_TO_LISTEN,
            0x806320A0 => P2P::PEER_E_IDENTITY_DELETED,
            0x806320A1 => P2P::PEER_E_SERVICE_NOT_AVAILABLE,
            0x80634001 => P2P::PEER_E_CANNOT_CONVERT_PEER_NAME,
            0x80634002 => P2P::PEER_E_INVALID_PEER_HOST_NAME,
            0x80634003 => P2P::PEER_E_NO_MORE,
            0x80634005 => P2P::PEER_E_PNRP_DUPLICATE_PEER_NAME,
            0x80636001 => P2P::PEER_E_CONTACT_NOT_FOUND,
            0x80637000 => P2P::PEER_E_INVITE_CANCELLED,
            0x80637001 => P2P::PEER_E_INVITE_RESPONSE_NOT_AVAILABLE,
            0x80637003 => P2P::PEER_E_NOT_SIGNED_IN,
            0x80637004 => P2P::PEER_E_PRIVACY_DECLINED,
            0x80637005 => P2P::PEER_E_TIMEOUT,
            0x80637007 => P2P::PEER_E_INVALID_ADDRESS,
            0x80637008 => P2P::PEER_E_FW_EXCEPTION_DISABLED,
            0x80637009 => P2P::PEER_E_FW_BLOCKED_BY_POLICY,
            0x8063700A => P2P::PEER_E_FW_BLOCKED_BY_SHIELDS_UP,
            0x8063700B => P2P::PEER_E_FW_DECLINED,
        }
    }
}
