/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum RPC {
    RPC_E_CALL_REJECTED,
    RPC_E_CALL_CANCELED,
    RPC_E_CANTPOST_INSENDCALL,
    RPC_E_CANTCALLOUT_INASYNCCALL,
    RPC_E_CANTCALLOUT_INEXTERNALCALL,
    RPC_E_CONNECTION_TERMINATED,
    RPC_E_SERVER_DIED,
    RPC_E_CLIENT_DIED,
    RPC_E_INVALID_DATAPACKET,
    RPC_E_CANTTRANSMIT_CALL,
    RPC_E_CLIENT_CANTMARSHAL_DATA,
    RPC_E_CLIENT_CANTUNMARSHAL_DATA,
    RPC_E_SERVER_CANTMARSHAL_DATA,
    RPC_E_SERVER_CANTUNMARSHAL_DATA,
    RPC_E_INVALID_DATA,
    RPC_E_INVALID_PARAMETER,
    RPC_E_CANTCALLOUT_AGAIN,
    RPC_E_SERVER_DIED_DNE,
    RPC_E_SYS_CALL_FAILED,
    RPC_E_OUT_OF_RESOURCES,
    RPC_E_ATTEMPTED_MULTITHREAD,
    RPC_E_NOT_REGISTERED,
    RPC_E_FAULT,
    RPC_E_SERVERFAULT,
    RPC_E_CHANGED_MODE,
    RPC_E_INVALIDMETHOD,
    RPC_E_DISCONNECTED,
    RPC_E_RETRY,
    RPC_E_SERVERCALL_RETRYLATER,
    RPC_E_SERVERCALL_REJECTED,
    RPC_E_INVALID_CALLDATA,
    RPC_E_CANTCALLOUT_ININPUTSYNCCALL,
    RPC_E_WRONG_THREAD,
    RPC_E_THREAD_NOT_INIT,
    RPC_E_VERSION_MISMATCH,
    RPC_E_INVALID_HEADER,
    RPC_E_INVALID_EXTENSION,
    RPC_E_INVALID_IPID,
    RPC_E_INVALID_OBJECT,
    RPC_S_CALLPENDING,
    RPC_S_WAITONTIMER,
    RPC_E_CALL_COMPLETE,
    RPC_E_UNSECURE_CALL,
    RPC_E_TOO_LATE,
    RPC_E_NO_GOOD_SECURITY_PACKAGES,
    RPC_E_ACCESS_DENIED,
    RPC_E_REMOTE_DISABLED,
    RPC_E_INVALID_OBJREF,
    RPC_E_NO_CONTEXT,
    RPC_E_TIMEOUT,
    RPC_E_NO_SYNC,
    RPC_E_FULLSIC_REQUIRED,
    RPC_E_INVALID_STD_NAME,
    CO_E_FAILEDTOIMPERSONATE,
    CO_E_FAILEDTOGETSECCTX,
    CO_E_FAILEDTOOPENTHREADTOKEN,
    CO_E_FAILEDTOGETTOKENINFO,
    CO_E_TRUSTEEDOESNTMATCHCLIENT,
    CO_E_FAILEDTOQUERYCLIENTBLANKET,
    CO_E_FAILEDTOSETDACL,
    CO_E_ACCESSCHECKFAILED,
    CO_E_NETACCESSAPIFAILED,
    CO_E_WRONGTRUSTEENAMESYNTAX,
    CO_E_INVALIDSID,
    CO_E_CONVERSIONFAILED,
    CO_E_NOMATCHINGSIDFOUND,
    CO_E_LOOKUPACCSIDFAILED,
    CO_E_NOMATCHINGNAMEFOUND,
    CO_E_LOOKUPACCNAMEFAILED,
    CO_E_SETSERLHNDLFAILED,
    CO_E_FAILEDTOGETWINDIR,
    CO_E_PATHTOOLONG,
    CO_E_FAILEDTOGENUUID,
    CO_E_FAILEDTOCREATEFILE,
    CO_E_FAILEDTOCLOSEHANDLE,
    CO_E_EXCEEDSYSACLLIMIT,
    CO_E_ACESINWRONGORDER,
    CO_E_INCOMPATIBLESTREAMVERSION,
    CO_E_FAILEDTOOPENPROCESSTOKEN,
    CO_E_DECODEFAILED,
    CO_E_ACNOTINITIALIZED,
    CO_E_CANCEL_DISABLED,
    RPC_E_UNEXPECTED,
}

impl RPC {
    pub fn code(&self) -> u32 {
        return match self {
            RPC::RPC_E_CALL_REJECTED => 0x80010001 as u32,
            RPC::RPC_E_CALL_CANCELED => 0x80010002 as u32,
            RPC::RPC_E_CANTPOST_INSENDCALL => 0x80010003 as u32,
            RPC::RPC_E_CANTCALLOUT_INASYNCCALL => 0x80010004 as u32,
            RPC::RPC_E_CANTCALLOUT_INEXTERNALCALL => 0x80010005 as u32,
            RPC::RPC_E_CONNECTION_TERMINATED => 0x80010006 as u32,
            RPC::RPC_E_SERVER_DIED => 0x80010007 as u32,
            RPC::RPC_E_CLIENT_DIED => 0x80010008 as u32,
            RPC::RPC_E_INVALID_DATAPACKET => 0x80010009 as u32,
            RPC::RPC_E_CANTTRANSMIT_CALL => 0x8001000A as u32,
            RPC::RPC_E_CLIENT_CANTMARSHAL_DATA => 0x8001000B as u32,
            RPC::RPC_E_CLIENT_CANTUNMARSHAL_DATA => 0x8001000C as u32,
            RPC::RPC_E_SERVER_CANTMARSHAL_DATA => 0x8001000D as u32,
            RPC::RPC_E_SERVER_CANTUNMARSHAL_DATA => 0x8001000E as u32,
            RPC::RPC_E_INVALID_DATA => 0x8001000F as u32,
            RPC::RPC_E_INVALID_PARAMETER => 0x80010010 as u32,
            RPC::RPC_E_CANTCALLOUT_AGAIN => 0x80010011 as u32,
            RPC::RPC_E_SERVER_DIED_DNE => 0x80010012 as u32,
            RPC::RPC_E_SYS_CALL_FAILED => 0x80010100 as u32,
            RPC::RPC_E_OUT_OF_RESOURCES => 0x80010101 as u32,
            RPC::RPC_E_ATTEMPTED_MULTITHREAD => 0x80010102 as u32,
            RPC::RPC_E_NOT_REGISTERED => 0x80010103 as u32,
            RPC::RPC_E_FAULT => 0x80010104 as u32,
            RPC::RPC_E_SERVERFAULT => 0x80010105 as u32,
            RPC::RPC_E_CHANGED_MODE => 0x80010106 as u32,
            RPC::RPC_E_INVALIDMETHOD => 0x80010107 as u32,
            RPC::RPC_E_DISCONNECTED => 0x80010108 as u32,
            RPC::RPC_E_RETRY => 0x80010109 as u32,
            RPC::RPC_E_SERVERCALL_RETRYLATER => 0x8001010A as u32,
            RPC::RPC_E_SERVERCALL_REJECTED => 0x8001010B as u32,
            RPC::RPC_E_INVALID_CALLDATA => 0x8001010C as u32,
            RPC::RPC_E_CANTCALLOUT_ININPUTSYNCCALL => 0x8001010D as u32,
            RPC::RPC_E_WRONG_THREAD => 0x8001010E as u32,
            RPC::RPC_E_THREAD_NOT_INIT => 0x8001010F as u32,
            RPC::RPC_E_VERSION_MISMATCH => 0x80010110 as u32,
            RPC::RPC_E_INVALID_HEADER => 0x80010111 as u32,
            RPC::RPC_E_INVALID_EXTENSION => 0x80010112 as u32,
            RPC::RPC_E_INVALID_IPID => 0x80010113 as u32,
            RPC::RPC_E_INVALID_OBJECT => 0x80010114 as u32,
            RPC::RPC_S_CALLPENDING => 0x80010115 as u32,
            RPC::RPC_S_WAITONTIMER => 0x80010116 as u32,
            RPC::RPC_E_CALL_COMPLETE => 0x80010117 as u32,
            RPC::RPC_E_UNSECURE_CALL => 0x80010118 as u32,
            RPC::RPC_E_TOO_LATE => 0x80010119 as u32,
            RPC::RPC_E_NO_GOOD_SECURITY_PACKAGES => 0x8001011A as u32,
            RPC::RPC_E_ACCESS_DENIED => 0x8001011B as u32,
            RPC::RPC_E_REMOTE_DISABLED => 0x8001011C as u32,
            RPC::RPC_E_INVALID_OBJREF => 0x8001011D as u32,
            RPC::RPC_E_NO_CONTEXT => 0x8001011E as u32,
            RPC::RPC_E_TIMEOUT => 0x8001011F as u32,
            RPC::RPC_E_NO_SYNC => 0x80010120 as u32,
            RPC::RPC_E_FULLSIC_REQUIRED => 0x80010121 as u32,
            RPC::RPC_E_INVALID_STD_NAME => 0x80010122 as u32,
            RPC::CO_E_FAILEDTOIMPERSONATE => 0x80010123 as u32,
            RPC::CO_E_FAILEDTOGETSECCTX => 0x80010124 as u32,
            RPC::CO_E_FAILEDTOOPENTHREADTOKEN => 0x80010125 as u32,
            RPC::CO_E_FAILEDTOGETTOKENINFO => 0x80010126 as u32,
            RPC::CO_E_TRUSTEEDOESNTMATCHCLIENT => 0x80010127 as u32,
            RPC::CO_E_FAILEDTOQUERYCLIENTBLANKET => 0x80010128 as u32,
            RPC::CO_E_FAILEDTOSETDACL => 0x80010129 as u32,
            RPC::CO_E_ACCESSCHECKFAILED => 0x8001012A as u32,
            RPC::CO_E_NETACCESSAPIFAILED => 0x8001012B as u32,
            RPC::CO_E_WRONGTRUSTEENAMESYNTAX => 0x8001012C as u32,
            RPC::CO_E_INVALIDSID => 0x8001012D as u32,
            RPC::CO_E_CONVERSIONFAILED => 0x8001012E as u32,
            RPC::CO_E_NOMATCHINGSIDFOUND => 0x8001012F as u32,
            RPC::CO_E_LOOKUPACCSIDFAILED => 0x80010130 as u32,
            RPC::CO_E_NOMATCHINGNAMEFOUND => 0x80010131 as u32,
            RPC::CO_E_LOOKUPACCNAMEFAILED => 0x80010132 as u32,
            RPC::CO_E_SETSERLHNDLFAILED => 0x80010133 as u32,
            RPC::CO_E_FAILEDTOGETWINDIR => 0x80010134 as u32,
            RPC::CO_E_PATHTOOLONG => 0x80010135 as u32,
            RPC::CO_E_FAILEDTOGENUUID => 0x80010136 as u32,
            RPC::CO_E_FAILEDTOCREATEFILE => 0x80010137 as u32,
            RPC::CO_E_FAILEDTOCLOSEHANDLE => 0x80010138 as u32,
            RPC::CO_E_EXCEEDSYSACLLIMIT => 0x80010139 as u32,
            RPC::CO_E_ACESINWRONGORDER => 0x8001013A as u32,
            RPC::CO_E_INCOMPATIBLESTREAMVERSION => 0x8001013B as u32,
            RPC::CO_E_FAILEDTOOPENPROCESSTOKEN => 0x8001013C as u32,
            RPC::CO_E_DECODEFAILED => 0x8001013D as u32,
            RPC::CO_E_ACNOTINITIALIZED => 0x8001013F as u32,
            RPC::CO_E_CANCEL_DISABLED => 0x80010140 as u32,
            RPC::RPC_E_UNEXPECTED => 0x8001FFFF as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            RPC::RPC_E_CALL_REJECTED => RawError::Kind(RPC::RPC_E_CALL_REJECTED),
            RPC::RPC_E_CALL_CANCELED => RawError::Kind(RPC::RPC_E_CALL_CANCELED),
            RPC::RPC_E_CANTPOST_INSENDCALL => RawError::Kind(RPC::RPC_E_CANTPOST_INSENDCALL),
            RPC::RPC_E_CANTCALLOUT_INASYNCCALL => RawError::Kind(RPC::RPC_E_CANTCALLOUT_INASYNCCALL),
            RPC::RPC_E_CANTCALLOUT_INEXTERNALCALL => RawError::Kind(RPC::RPC_E_CANTCALLOUT_INEXTERNALCALL),
            RPC::RPC_E_CONNECTION_TERMINATED => RawError::Kind(RPC::RPC_E_CONNECTION_TERMINATED),
            RPC::RPC_E_SERVER_DIED => RawError::Kind(RPC::RPC_E_SERVER_DIED),
            RPC::RPC_E_CLIENT_DIED => RawError::Kind(RPC::RPC_E_CLIENT_DIED),
            RPC::RPC_E_INVALID_DATAPACKET => RawError::Kind(RPC::RPC_E_INVALID_DATAPACKET),
            RPC::RPC_E_CANTTRANSMIT_CALL => RawError::Kind(RPC::RPC_E_CANTTRANSMIT_CALL),
            RPC::RPC_E_CLIENT_CANTMARSHAL_DATA => RawError::Kind(RPC::RPC_E_CLIENT_CANTMARSHAL_DATA),
            RPC::RPC_E_CLIENT_CANTUNMARSHAL_DATA => RawError::Kind(RPC::RPC_E_CLIENT_CANTUNMARSHAL_DATA),
            RPC::RPC_E_SERVER_CANTMARSHAL_DATA => RawError::Kind(RPC::RPC_E_SERVER_CANTMARSHAL_DATA),
            RPC::RPC_E_SERVER_CANTUNMARSHAL_DATA => RawError::Kind(RPC::RPC_E_SERVER_CANTUNMARSHAL_DATA),
            RPC::RPC_E_INVALID_DATA => RawError::Kind(RPC::RPC_E_INVALID_DATA),
            RPC::RPC_E_INVALID_PARAMETER => RawError::Kind(RPC::RPC_E_INVALID_PARAMETER),
            RPC::RPC_E_CANTCALLOUT_AGAIN => RawError::Kind(RPC::RPC_E_CANTCALLOUT_AGAIN),
            RPC::RPC_E_SERVER_DIED_DNE => RawError::Kind(RPC::RPC_E_SERVER_DIED_DNE),
            RPC::RPC_E_SYS_CALL_FAILED => RawError::Kind(RPC::RPC_E_SYS_CALL_FAILED),
            RPC::RPC_E_OUT_OF_RESOURCES => RawError::Kind(RPC::RPC_E_OUT_OF_RESOURCES),
            RPC::RPC_E_ATTEMPTED_MULTITHREAD => RawError::Kind(RPC::RPC_E_ATTEMPTED_MULTITHREAD),
            RPC::RPC_E_NOT_REGISTERED => RawError::Kind(RPC::RPC_E_NOT_REGISTERED),
            RPC::RPC_E_FAULT => RawError::Kind(RPC::RPC_E_FAULT),
            RPC::RPC_E_SERVERFAULT => RawError::Kind(RPC::RPC_E_SERVERFAULT),
            RPC::RPC_E_CHANGED_MODE => RawError::Kind(RPC::RPC_E_CHANGED_MODE),
            RPC::RPC_E_INVALIDMETHOD => RawError::Kind(RPC::RPC_E_INVALIDMETHOD),
            RPC::RPC_E_DISCONNECTED => RawError::Kind(RPC::RPC_E_DISCONNECTED),
            RPC::RPC_E_RETRY => RawError::Kind(RPC::RPC_E_RETRY),
            RPC::RPC_E_SERVERCALL_RETRYLATER => RawError::Kind(RPC::RPC_E_SERVERCALL_RETRYLATER),
            RPC::RPC_E_SERVERCALL_REJECTED => RawError::Kind(RPC::RPC_E_SERVERCALL_REJECTED),
            RPC::RPC_E_INVALID_CALLDATA => RawError::Kind(RPC::RPC_E_INVALID_CALLDATA),
            RPC::RPC_E_CANTCALLOUT_ININPUTSYNCCALL => RawError::Kind(RPC::RPC_E_CANTCALLOUT_ININPUTSYNCCALL),
            RPC::RPC_E_WRONG_THREAD => RawError::Kind(RPC::RPC_E_WRONG_THREAD),
            RPC::RPC_E_THREAD_NOT_INIT => RawError::Kind(RPC::RPC_E_THREAD_NOT_INIT),
            RPC::RPC_E_VERSION_MISMATCH => RawError::Kind(RPC::RPC_E_VERSION_MISMATCH),
            RPC::RPC_E_INVALID_HEADER => RawError::Kind(RPC::RPC_E_INVALID_HEADER),
            RPC::RPC_E_INVALID_EXTENSION => RawError::Kind(RPC::RPC_E_INVALID_EXTENSION),
            RPC::RPC_E_INVALID_IPID => RawError::Kind(RPC::RPC_E_INVALID_IPID),
            RPC::RPC_E_INVALID_OBJECT => RawError::Kind(RPC::RPC_E_INVALID_OBJECT),
            RPC::RPC_S_CALLPENDING => RawError::Kind(RPC::RPC_S_CALLPENDING),
            RPC::RPC_S_WAITONTIMER => RawError::Kind(RPC::RPC_S_WAITONTIMER),
            RPC::RPC_E_CALL_COMPLETE => RawError::Kind(RPC::RPC_E_CALL_COMPLETE),
            RPC::RPC_E_UNSECURE_CALL => RawError::Kind(RPC::RPC_E_UNSECURE_CALL),
            RPC::RPC_E_TOO_LATE => RawError::Kind(RPC::RPC_E_TOO_LATE),
            RPC::RPC_E_NO_GOOD_SECURITY_PACKAGES => RawError::Kind(RPC::RPC_E_NO_GOOD_SECURITY_PACKAGES),
            RPC::RPC_E_ACCESS_DENIED => RawError::Kind(RPC::RPC_E_ACCESS_DENIED),
            RPC::RPC_E_REMOTE_DISABLED => RawError::Kind(RPC::RPC_E_REMOTE_DISABLED),
            RPC::RPC_E_INVALID_OBJREF => RawError::Kind(RPC::RPC_E_INVALID_OBJREF),
            RPC::RPC_E_NO_CONTEXT => RawError::Kind(RPC::RPC_E_NO_CONTEXT),
            RPC::RPC_E_TIMEOUT => RawError::Kind(RPC::RPC_E_TIMEOUT),
            RPC::RPC_E_NO_SYNC => RawError::Kind(RPC::RPC_E_NO_SYNC),
            RPC::RPC_E_FULLSIC_REQUIRED => RawError::Kind(RPC::RPC_E_FULLSIC_REQUIRED),
            RPC::RPC_E_INVALID_STD_NAME => RawError::Kind(RPC::RPC_E_INVALID_STD_NAME),
            RPC::CO_E_FAILEDTOIMPERSONATE => RawError::Kind(RPC::CO_E_FAILEDTOIMPERSONATE),
            RPC::CO_E_FAILEDTOGETSECCTX => RawError::Kind(RPC::CO_E_FAILEDTOGETSECCTX),
            RPC::CO_E_FAILEDTOOPENTHREADTOKEN => RawError::Kind(RPC::CO_E_FAILEDTOOPENTHREADTOKEN),
            RPC::CO_E_FAILEDTOGETTOKENINFO => RawError::Kind(RPC::CO_E_FAILEDTOGETTOKENINFO),
            RPC::CO_E_TRUSTEEDOESNTMATCHCLIENT => RawError::Kind(RPC::CO_E_TRUSTEEDOESNTMATCHCLIENT),
            RPC::CO_E_FAILEDTOQUERYCLIENTBLANKET => RawError::Kind(RPC::CO_E_FAILEDTOQUERYCLIENTBLANKET),
            RPC::CO_E_FAILEDTOSETDACL => RawError::Kind(RPC::CO_E_FAILEDTOSETDACL),
            RPC::CO_E_ACCESSCHECKFAILED => RawError::Kind(RPC::CO_E_ACCESSCHECKFAILED),
            RPC::CO_E_NETACCESSAPIFAILED => RawError::Kind(RPC::CO_E_NETACCESSAPIFAILED),
            RPC::CO_E_WRONGTRUSTEENAMESYNTAX => RawError::Kind(RPC::CO_E_WRONGTRUSTEENAMESYNTAX),
            RPC::CO_E_INVALIDSID => RawError::Kind(RPC::CO_E_INVALIDSID),
            RPC::CO_E_CONVERSIONFAILED => RawError::Kind(RPC::CO_E_CONVERSIONFAILED),
            RPC::CO_E_NOMATCHINGSIDFOUND => RawError::Kind(RPC::CO_E_NOMATCHINGSIDFOUND),
            RPC::CO_E_LOOKUPACCSIDFAILED => RawError::Kind(RPC::CO_E_LOOKUPACCSIDFAILED),
            RPC::CO_E_NOMATCHINGNAMEFOUND => RawError::Kind(RPC::CO_E_NOMATCHINGNAMEFOUND),
            RPC::CO_E_LOOKUPACCNAMEFAILED => RawError::Kind(RPC::CO_E_LOOKUPACCNAMEFAILED),
            RPC::CO_E_SETSERLHNDLFAILED => RawError::Kind(RPC::CO_E_SETSERLHNDLFAILED),
            RPC::CO_E_FAILEDTOGETWINDIR => RawError::Kind(RPC::CO_E_FAILEDTOGETWINDIR),
            RPC::CO_E_PATHTOOLONG => RawError::Kind(RPC::CO_E_PATHTOOLONG),
            RPC::CO_E_FAILEDTOGENUUID => RawError::Kind(RPC::CO_E_FAILEDTOGENUUID),
            RPC::CO_E_FAILEDTOCREATEFILE => RawError::Kind(RPC::CO_E_FAILEDTOCREATEFILE),
            RPC::CO_E_FAILEDTOCLOSEHANDLE => RawError::Kind(RPC::CO_E_FAILEDTOCLOSEHANDLE),
            RPC::CO_E_EXCEEDSYSACLLIMIT => RawError::Kind(RPC::CO_E_EXCEEDSYSACLLIMIT),
            RPC::CO_E_ACESINWRONGORDER => RawError::Kind(RPC::CO_E_ACESINWRONGORDER),
            RPC::CO_E_INCOMPATIBLESTREAMVERSION => RawError::Kind(RPC::CO_E_INCOMPATIBLESTREAMVERSION),
            RPC::CO_E_FAILEDTOOPENPROCESSTOKEN => RawError::Kind(RPC::CO_E_FAILEDTOOPENPROCESSTOKEN),
            RPC::CO_E_DECODEFAILED => RawError::Kind(RPC::CO_E_DECODEFAILED),
            RPC::CO_E_ACNOTINITIALIZED => RawError::Kind(RPC::CO_E_ACNOTINITIALIZED),
            RPC::CO_E_CANCEL_DISABLED => RawError::Kind(RPC::CO_E_CANCEL_DISABLED),
            RPC::RPC_E_UNEXPECTED => RawError::Kind(RPC::RPC_E_UNEXPECTED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            RPC::RPC_E_CALL_REJECTED => "Call was rejected by callee.",
            RPC::RPC_E_CALL_CANCELED => "Call was canceled by the message filter.",
            RPC::RPC_E_CANTPOST_INSENDCALL => "The caller is dispatching an intertask SendMessage call and cannot call out via PostMessage.",
            RPC::RPC_E_CANTCALLOUT_INASYNCCALL => "The caller is dispatching an asynchronous call and cannot make an outgoing call on behalf of this call.",
            RPC::RPC_E_CANTCALLOUT_INEXTERNALCALL => "It is illegal to call out while inside message filter.",
            RPC::RPC_E_CONNECTION_TERMINATED => "The connection terminated or is in a bogus state and cannot be used any more. Other connections are still valid.",
            RPC::RPC_E_SERVER_DIED => "The callee (server [not server application]) is not available and disappeared; all connections are invalid. The call may have executed.",
            RPC::RPC_E_CLIENT_DIED => "The caller (client) disappeared while the callee (server) was processing a call.",
            RPC::RPC_E_INVALID_DATAPACKET => "The data packet with the marshalled parameter data is incorrect.",
            RPC::RPC_E_CANTTRANSMIT_CALL => "The call was not transmitted properly; the message queue was full and was not emptied after yielding.",
            RPC::RPC_E_CLIENT_CANTMARSHAL_DATA => "The client (caller) cannot marshall the parameter data - low memory, etc.",
            RPC::RPC_E_CLIENT_CANTUNMARSHAL_DATA => "The client (caller) cannot unmarshall the return data - low memory, etc.",
            RPC::RPC_E_SERVER_CANTMARSHAL_DATA => "The server (callee) cannot marshall the return data - low memory, etc.",
            RPC::RPC_E_SERVER_CANTUNMARSHAL_DATA => "The server (callee) cannot unmarshall the parameter data - low memory, etc.",
            RPC::RPC_E_INVALID_DATA => "Received data is invalid; could be server or client data.",
            RPC::RPC_E_INVALID_PARAMETER => "A particular parameter is invalid and cannot be (un)marshalled.",
            RPC::RPC_E_CANTCALLOUT_AGAIN => "There is no second outgoing call on same channel in DDE conversation.",
            RPC::RPC_E_SERVER_DIED_DNE => "The callee (server [not server application]) is not available and disappeared; all connections are invalid. The call did not execute.",
            RPC::RPC_E_SYS_CALL_FAILED => "System call failed.",
            RPC::RPC_E_OUT_OF_RESOURCES => "Could not allocate some required resource (memory, events, ...)",
            RPC::RPC_E_ATTEMPTED_MULTITHREAD => "Attempted to make calls on more than one thread in single threaded mode.",
            RPC::RPC_E_NOT_REGISTERED => "The requested interface is not registered on the server object.",
            RPC::RPC_E_FAULT => "RPC could not call the server or could not return the results of calling the server.",
            RPC::RPC_E_SERVERFAULT => "The server threw an exception.",
            RPC::RPC_E_CHANGED_MODE => "Cannot change thread mode after it is set.",
            RPC::RPC_E_INVALIDMETHOD => "The method called does not exist on the server.",
            RPC::RPC_E_DISCONNECTED => "The object invoked has disconnected from its clients.",
            RPC::RPC_E_RETRY => "The object invoked chose not to process the call now. Try again later.",
            RPC::RPC_E_SERVERCALL_RETRYLATER => "The message filter indicated that the application is busy.",
            RPC::RPC_E_SERVERCALL_REJECTED => "The message filter rejected the call.",
            RPC::RPC_E_INVALID_CALLDATA => "A call control interfaces was called with invalid data.",
            RPC::RPC_E_CANTCALLOUT_ININPUTSYNCCALL => "An outgoing call cannot be made since the application is dispatching an input-synchronous call.",
            RPC::RPC_E_WRONG_THREAD => "The application called an interface that was marshalled for a different thread.",
            RPC::RPC_E_THREAD_NOT_INIT => "CoInitialize has not been called on the current thread.",
            RPC::RPC_E_VERSION_MISMATCH => "The version of OLE on the client and server machines does not match.",
            RPC::RPC_E_INVALID_HEADER => "OLE received a packet with an invalid header.",
            RPC::RPC_E_INVALID_EXTENSION => "OLE received a packet with an invalid extension.",
            RPC::RPC_E_INVALID_IPID => "The requested object or interface does not exist.",
            RPC::RPC_E_INVALID_OBJECT => "The requested object does not exist.",
            RPC::RPC_S_CALLPENDING => "OLE has sent a request and is waiting for a reply.",
            RPC::RPC_S_WAITONTIMER => "OLE is waiting before retrying a request.",
            RPC::RPC_E_CALL_COMPLETE => "Call context cannot be accessed after call completed.",
            RPC::RPC_E_UNSECURE_CALL => "Impersonate on unsecure calls is not supported.",
            RPC::RPC_E_TOO_LATE => "Security must be initialized before any interfaces are marshalled or unmarshalled. It cannot be changed once initialized.",
            RPC::RPC_E_NO_GOOD_SECURITY_PACKAGES => "No security packages are installed on this machine or the user is not logged on or there are no compatible security packages between the client and server.",
            RPC::RPC_E_ACCESS_DENIED => "Access is denied.",
            RPC::RPC_E_REMOTE_DISABLED => "Remote calls are not allowed for this process.",
            RPC::RPC_E_INVALID_OBJREF => "The marshaled interface data packet (OBJREF) has an invalid or unknown format.",
            RPC::RPC_E_NO_CONTEXT => "No context is associated with this call. This happens for some custom marshalled calls and on the client side of the call.",
            RPC::RPC_E_TIMEOUT => "This operation returned because the timeout period expired.",
            RPC::RPC_E_NO_SYNC => "There are no synchronize objects to wait on.",
            RPC::RPC_E_FULLSIC_REQUIRED => "Full subject issuer chain SSL principal name expected from the server.",
            RPC::RPC_E_INVALID_STD_NAME => "Principal name is not a valid MSSTD name.",
            RPC::CO_E_FAILEDTOIMPERSONATE => "Unable to impersonate DCOM client",
            RPC::CO_E_FAILEDTOGETSECCTX => "Unable to obtain server's security context",
            RPC::CO_E_FAILEDTOOPENTHREADTOKEN => "Unable to open the access token of the current thread",
            RPC::CO_E_FAILEDTOGETTOKENINFO => "Unable to obtain user info from an access token",
            RPC::CO_E_TRUSTEEDOESNTMATCHCLIENT => "The client who called IAccessControl::IsAccessPermitted was not the trustee provided to the method",
            RPC::CO_E_FAILEDTOQUERYCLIENTBLANKET => "Unable to obtain the client's security blanket",
            RPC::CO_E_FAILEDTOSETDACL => "Unable to set a discretionary ACL into a security descriptor",
            RPC::CO_E_ACCESSCHECKFAILED => "The system function, AccessCheck, returned false",
            RPC::CO_E_NETACCESSAPIFAILED => "Either NetAccessDel or NetAccessAdd returned an error code.",
            RPC::CO_E_WRONGTRUSTEENAMESYNTAX => "One of the trustee strings provided by the user did not conform to the <Domain>\<Name> syntax and it was not the ",
            RPC::CO_E_INVALIDSID => "One of the security identifiers provided by the user was invalid",
            RPC::CO_E_CONVERSIONFAILED => "Unable to convert a wide character trustee string to a multibyte trustee string",
            RPC::CO_E_NOMATCHINGSIDFOUND => "Unable to find a security identifier that corresponds to a trustee string provided by the user",
            RPC::CO_E_LOOKUPACCSIDFAILED => "The system function, LookupAccountSID, failed",
            RPC::CO_E_NOMATCHINGNAMEFOUND => "Unable to find a trustee name that corresponds to a security identifier provided by the user",
            RPC::CO_E_LOOKUPACCNAMEFAILED => "The system function, LookupAccountName, failed",
            RPC::CO_E_SETSERLHNDLFAILED => "Unable to set or reset a serialization handle",
            RPC::CO_E_FAILEDTOGETWINDIR => "Unable to obtain the Windows directory",
            RPC::CO_E_PATHTOOLONG => "Path too long",
            RPC::CO_E_FAILEDTOGENUUID => "Unable to generate a uuid.",
            RPC::CO_E_FAILEDTOCREATEFILE => "Unable to create file",
            RPC::CO_E_FAILEDTOCLOSEHANDLE => "Unable to close a serialization handle or a file handle.",
            RPC::CO_E_EXCEEDSYSACLLIMIT => "The number of ACEs in an ACL exceeds the system limit.",
            RPC::CO_E_ACESINWRONGORDER => "Not all the DENY_ACCESS ACEs are arranged in front of the GRANT_ACCESS ACEs in the stream.",
            RPC::CO_E_INCOMPATIBLESTREAMVERSION => "The version of ACL format in the stream is not supported by this implementation of IAccessControl",
            RPC::CO_E_FAILEDTOOPENPROCESSTOKEN => "Unable to open the access token of the server process",
            RPC::CO_E_DECODEFAILED => "Unable to decode the ACL in the stream provided by the user",
            RPC::CO_E_ACNOTINITIALIZED => "The COM IAccessControl object is not initialized",
            RPC::CO_E_CANCEL_DISABLED => "Call Cancellation is disabled",
            RPC::RPC_E_UNEXPECTED => "An internal error occurred.",
        }
    }

    pub fn from_name(name: &str) -> RPC {
        return match name {
            "RPC_E_CALL_REJECTED" => RPC::RPC_E_CALL_REJECTED,
            "RPC_E_CALL_CANCELED" => RPC::RPC_E_CALL_CANCELED,
            "RPC_E_CANTPOST_INSENDCALL" => RPC::RPC_E_CANTPOST_INSENDCALL,
            "RPC_E_CANTCALLOUT_INASYNCCALL" => RPC::RPC_E_CANTCALLOUT_INASYNCCALL,
            "RPC_E_CANTCALLOUT_INEXTERNALCALL" => RPC::RPC_E_CANTCALLOUT_INEXTERNALCALL,
            "RPC_E_CONNECTION_TERMINATED" => RPC::RPC_E_CONNECTION_TERMINATED,
            "RPC_E_SERVER_DIED" => RPC::RPC_E_SERVER_DIED,
            "RPC_E_CLIENT_DIED" => RPC::RPC_E_CLIENT_DIED,
            "RPC_E_INVALID_DATAPACKET" => RPC::RPC_E_INVALID_DATAPACKET,
            "RPC_E_CANTTRANSMIT_CALL" => RPC::RPC_E_CANTTRANSMIT_CALL,
            "RPC_E_CLIENT_CANTMARSHAL_DATA" => RPC::RPC_E_CLIENT_CANTMARSHAL_DATA,
            "RPC_E_CLIENT_CANTUNMARSHAL_DATA" => RPC::RPC_E_CLIENT_CANTUNMARSHAL_DATA,
            "RPC_E_SERVER_CANTMARSHAL_DATA" => RPC::RPC_E_SERVER_CANTMARSHAL_DATA,
            "RPC_E_SERVER_CANTUNMARSHAL_DATA" => RPC::RPC_E_SERVER_CANTUNMARSHAL_DATA,
            "RPC_E_INVALID_DATA" => RPC::RPC_E_INVALID_DATA,
            "RPC_E_INVALID_PARAMETER" => RPC::RPC_E_INVALID_PARAMETER,
            "RPC_E_CANTCALLOUT_AGAIN" => RPC::RPC_E_CANTCALLOUT_AGAIN,
            "RPC_E_SERVER_DIED_DNE" => RPC::RPC_E_SERVER_DIED_DNE,
            "RPC_E_SYS_CALL_FAILED" => RPC::RPC_E_SYS_CALL_FAILED,
            "RPC_E_OUT_OF_RESOURCES" => RPC::RPC_E_OUT_OF_RESOURCES,
            "RPC_E_ATTEMPTED_MULTITHREAD" => RPC::RPC_E_ATTEMPTED_MULTITHREAD,
            "RPC_E_NOT_REGISTERED" => RPC::RPC_E_NOT_REGISTERED,
            "RPC_E_FAULT" => RPC::RPC_E_FAULT,
            "RPC_E_SERVERFAULT" => RPC::RPC_E_SERVERFAULT,
            "RPC_E_CHANGED_MODE" => RPC::RPC_E_CHANGED_MODE,
            "RPC_E_INVALIDMETHOD" => RPC::RPC_E_INVALIDMETHOD,
            "RPC_E_DISCONNECTED" => RPC::RPC_E_DISCONNECTED,
            "RPC_E_RETRY" => RPC::RPC_E_RETRY,
            "RPC_E_SERVERCALL_RETRYLATER" => RPC::RPC_E_SERVERCALL_RETRYLATER,
            "RPC_E_SERVERCALL_REJECTED" => RPC::RPC_E_SERVERCALL_REJECTED,
            "RPC_E_INVALID_CALLDATA" => RPC::RPC_E_INVALID_CALLDATA,
            "RPC_E_CANTCALLOUT_ININPUTSYNCCALL" => RPC::RPC_E_CANTCALLOUT_ININPUTSYNCCALL,
            "RPC_E_WRONG_THREAD" => RPC::RPC_E_WRONG_THREAD,
            "RPC_E_THREAD_NOT_INIT" => RPC::RPC_E_THREAD_NOT_INIT,
            "RPC_E_VERSION_MISMATCH" => RPC::RPC_E_VERSION_MISMATCH,
            "RPC_E_INVALID_HEADER" => RPC::RPC_E_INVALID_HEADER,
            "RPC_E_INVALID_EXTENSION" => RPC::RPC_E_INVALID_EXTENSION,
            "RPC_E_INVALID_IPID" => RPC::RPC_E_INVALID_IPID,
            "RPC_E_INVALID_OBJECT" => RPC::RPC_E_INVALID_OBJECT,
            "RPC_S_CALLPENDING" => RPC::RPC_S_CALLPENDING,
            "RPC_S_WAITONTIMER" => RPC::RPC_S_WAITONTIMER,
            "RPC_E_CALL_COMPLETE" => RPC::RPC_E_CALL_COMPLETE,
            "RPC_E_UNSECURE_CALL" => RPC::RPC_E_UNSECURE_CALL,
            "RPC_E_TOO_LATE" => RPC::RPC_E_TOO_LATE,
            "RPC_E_NO_GOOD_SECURITY_PACKAGES" => RPC::RPC_E_NO_GOOD_SECURITY_PACKAGES,
            "RPC_E_ACCESS_DENIED" => RPC::RPC_E_ACCESS_DENIED,
            "RPC_E_REMOTE_DISABLED" => RPC::RPC_E_REMOTE_DISABLED,
            "RPC_E_INVALID_OBJREF" => RPC::RPC_E_INVALID_OBJREF,
            "RPC_E_NO_CONTEXT" => RPC::RPC_E_NO_CONTEXT,
            "RPC_E_TIMEOUT" => RPC::RPC_E_TIMEOUT,
            "RPC_E_NO_SYNC" => RPC::RPC_E_NO_SYNC,
            "RPC_E_FULLSIC_REQUIRED" => RPC::RPC_E_FULLSIC_REQUIRED,
            "RPC_E_INVALID_STD_NAME" => RPC::RPC_E_INVALID_STD_NAME,
            "CO_E_FAILEDTOIMPERSONATE" => RPC::CO_E_FAILEDTOIMPERSONATE,
            "CO_E_FAILEDTOGETSECCTX" => RPC::CO_E_FAILEDTOGETSECCTX,
            "CO_E_FAILEDTOOPENTHREADTOKEN" => RPC::CO_E_FAILEDTOOPENTHREADTOKEN,
            "CO_E_FAILEDTOGETTOKENINFO" => RPC::CO_E_FAILEDTOGETTOKENINFO,
            "CO_E_TRUSTEEDOESNTMATCHCLIENT" => RPC::CO_E_TRUSTEEDOESNTMATCHCLIENT,
            "CO_E_FAILEDTOQUERYCLIENTBLANKET" => RPC::CO_E_FAILEDTOQUERYCLIENTBLANKET,
            "CO_E_FAILEDTOSETDACL" => RPC::CO_E_FAILEDTOSETDACL,
            "CO_E_ACCESSCHECKFAILED" => RPC::CO_E_ACCESSCHECKFAILED,
            "CO_E_NETACCESSAPIFAILED" => RPC::CO_E_NETACCESSAPIFAILED,
            "CO_E_WRONGTRUSTEENAMESYNTAX" => RPC::CO_E_WRONGTRUSTEENAMESYNTAX,
            "CO_E_INVALIDSID" => RPC::CO_E_INVALIDSID,
            "CO_E_CONVERSIONFAILED" => RPC::CO_E_CONVERSIONFAILED,
            "CO_E_NOMATCHINGSIDFOUND" => RPC::CO_E_NOMATCHINGSIDFOUND,
            "CO_E_LOOKUPACCSIDFAILED" => RPC::CO_E_LOOKUPACCSIDFAILED,
            "CO_E_NOMATCHINGNAMEFOUND" => RPC::CO_E_NOMATCHINGNAMEFOUND,
            "CO_E_LOOKUPACCNAMEFAILED" => RPC::CO_E_LOOKUPACCNAMEFAILED,
            "CO_E_SETSERLHNDLFAILED" => RPC::CO_E_SETSERLHNDLFAILED,
            "CO_E_FAILEDTOGETWINDIR" => RPC::CO_E_FAILEDTOGETWINDIR,
            "CO_E_PATHTOOLONG" => RPC::CO_E_PATHTOOLONG,
            "CO_E_FAILEDTOGENUUID" => RPC::CO_E_FAILEDTOGENUUID,
            "CO_E_FAILEDTOCREATEFILE" => RPC::CO_E_FAILEDTOCREATEFILE,
            "CO_E_FAILEDTOCLOSEHANDLE" => RPC::CO_E_FAILEDTOCLOSEHANDLE,
            "CO_E_EXCEEDSYSACLLIMIT" => RPC::CO_E_EXCEEDSYSACLLIMIT,
            "CO_E_ACESINWRONGORDER" => RPC::CO_E_ACESINWRONGORDER,
            "CO_E_INCOMPATIBLESTREAMVERSION" => RPC::CO_E_INCOMPATIBLESTREAMVERSION,
            "CO_E_FAILEDTOOPENPROCESSTOKEN" => RPC::CO_E_FAILEDTOOPENPROCESSTOKEN,
            "CO_E_DECODEFAILED" => RPC::CO_E_DECODEFAILED,
            "CO_E_ACNOTINITIALIZED" => RPC::CO_E_ACNOTINITIALIZED,
            "CO_E_CANCEL_DISABLED" => RPC::CO_E_CANCEL_DISABLED,
            "RPC_E_UNEXPECTED" => RPC::RPC_E_UNEXPECTED,
        }
    }
    pub fn from_code(code: u32) -> RPC {
        return match code {
            0x80010001 => RPC::RPC_E_CALL_REJECTED,
            0x80010002 => RPC::RPC_E_CALL_CANCELED,
            0x80010003 => RPC::RPC_E_CANTPOST_INSENDCALL,
            0x80010004 => RPC::RPC_E_CANTCALLOUT_INASYNCCALL,
            0x80010005 => RPC::RPC_E_CANTCALLOUT_INEXTERNALCALL,
            0x80010006 => RPC::RPC_E_CONNECTION_TERMINATED,
            0x80010007 => RPC::RPC_E_SERVER_DIED,
            0x80010008 => RPC::RPC_E_CLIENT_DIED,
            0x80010009 => RPC::RPC_E_INVALID_DATAPACKET,
            0x8001000A => RPC::RPC_E_CANTTRANSMIT_CALL,
            0x8001000B => RPC::RPC_E_CLIENT_CANTMARSHAL_DATA,
            0x8001000C => RPC::RPC_E_CLIENT_CANTUNMARSHAL_DATA,
            0x8001000D => RPC::RPC_E_SERVER_CANTMARSHAL_DATA,
            0x8001000E => RPC::RPC_E_SERVER_CANTUNMARSHAL_DATA,
            0x8001000F => RPC::RPC_E_INVALID_DATA,
            0x80010010 => RPC::RPC_E_INVALID_PARAMETER,
            0x80010011 => RPC::RPC_E_CANTCALLOUT_AGAIN,
            0x80010012 => RPC::RPC_E_SERVER_DIED_DNE,
            0x80010100 => RPC::RPC_E_SYS_CALL_FAILED,
            0x80010101 => RPC::RPC_E_OUT_OF_RESOURCES,
            0x80010102 => RPC::RPC_E_ATTEMPTED_MULTITHREAD,
            0x80010103 => RPC::RPC_E_NOT_REGISTERED,
            0x80010104 => RPC::RPC_E_FAULT,
            0x80010105 => RPC::RPC_E_SERVERFAULT,
            0x80010106 => RPC::RPC_E_CHANGED_MODE,
            0x80010107 => RPC::RPC_E_INVALIDMETHOD,
            0x80010108 => RPC::RPC_E_DISCONNECTED,
            0x80010109 => RPC::RPC_E_RETRY,
            0x8001010A => RPC::RPC_E_SERVERCALL_RETRYLATER,
            0x8001010B => RPC::RPC_E_SERVERCALL_REJECTED,
            0x8001010C => RPC::RPC_E_INVALID_CALLDATA,
            0x8001010D => RPC::RPC_E_CANTCALLOUT_ININPUTSYNCCALL,
            0x8001010E => RPC::RPC_E_WRONG_THREAD,
            0x8001010F => RPC::RPC_E_THREAD_NOT_INIT,
            0x80010110 => RPC::RPC_E_VERSION_MISMATCH,
            0x80010111 => RPC::RPC_E_INVALID_HEADER,
            0x80010112 => RPC::RPC_E_INVALID_EXTENSION,
            0x80010113 => RPC::RPC_E_INVALID_IPID,
            0x80010114 => RPC::RPC_E_INVALID_OBJECT,
            0x80010115 => RPC::RPC_S_CALLPENDING,
            0x80010116 => RPC::RPC_S_WAITONTIMER,
            0x80010117 => RPC::RPC_E_CALL_COMPLETE,
            0x80010118 => RPC::RPC_E_UNSECURE_CALL,
            0x80010119 => RPC::RPC_E_TOO_LATE,
            0x8001011A => RPC::RPC_E_NO_GOOD_SECURITY_PACKAGES,
            0x8001011B => RPC::RPC_E_ACCESS_DENIED,
            0x8001011C => RPC::RPC_E_REMOTE_DISABLED,
            0x8001011D => RPC::RPC_E_INVALID_OBJREF,
            0x8001011E => RPC::RPC_E_NO_CONTEXT,
            0x8001011F => RPC::RPC_E_TIMEOUT,
            0x80010120 => RPC::RPC_E_NO_SYNC,
            0x80010121 => RPC::RPC_E_FULLSIC_REQUIRED,
            0x80010122 => RPC::RPC_E_INVALID_STD_NAME,
            0x80010123 => RPC::CO_E_FAILEDTOIMPERSONATE,
            0x80010124 => RPC::CO_E_FAILEDTOGETSECCTX,
            0x80010125 => RPC::CO_E_FAILEDTOOPENTHREADTOKEN,
            0x80010126 => RPC::CO_E_FAILEDTOGETTOKENINFO,
            0x80010127 => RPC::CO_E_TRUSTEEDOESNTMATCHCLIENT,
            0x80010128 => RPC::CO_E_FAILEDTOQUERYCLIENTBLANKET,
            0x80010129 => RPC::CO_E_FAILEDTOSETDACL,
            0x8001012A => RPC::CO_E_ACCESSCHECKFAILED,
            0x8001012B => RPC::CO_E_NETACCESSAPIFAILED,
            0x8001012C => RPC::CO_E_WRONGTRUSTEENAMESYNTAX,
            0x8001012D => RPC::CO_E_INVALIDSID,
            0x8001012E => RPC::CO_E_CONVERSIONFAILED,
            0x8001012F => RPC::CO_E_NOMATCHINGSIDFOUND,
            0x80010130 => RPC::CO_E_LOOKUPACCSIDFAILED,
            0x80010131 => RPC::CO_E_NOMATCHINGNAMEFOUND,
            0x80010132 => RPC::CO_E_LOOKUPACCNAMEFAILED,
            0x80010133 => RPC::CO_E_SETSERLHNDLFAILED,
            0x80010134 => RPC::CO_E_FAILEDTOGETWINDIR,
            0x80010135 => RPC::CO_E_PATHTOOLONG,
            0x80010136 => RPC::CO_E_FAILEDTOGENUUID,
            0x80010137 => RPC::CO_E_FAILEDTOCREATEFILE,
            0x80010138 => RPC::CO_E_FAILEDTOCLOSEHANDLE,
            0x80010139 => RPC::CO_E_EXCEEDSYSACLLIMIT,
            0x8001013A => RPC::CO_E_ACESINWRONGORDER,
            0x8001013B => RPC::CO_E_INCOMPATIBLESTREAMVERSION,
            0x8001013C => RPC::CO_E_FAILEDTOOPENPROCESSTOKEN,
            0x8001013D => RPC::CO_E_DECODEFAILED,
            0x8001013F => RPC::CO_E_ACNOTINITIALIZED,
            0x80010140 => RPC::CO_E_CANCEL_DISABLED,
            0x8001FFFF => RPC::RPC_E_UNEXPECTED,
        }
    }
}
