/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum RTC_INTERFACE {
    RTC_S_ROAMING_NOT_SUPPORTED,
    RTC_E_SIP_CODECS_DO_NOT_MATCH,
    RTC_E_SIP_STREAM_PRESENT,
    RTC_E_SIP_STREAM_NOT_PRESENT,
    RTC_E_SIP_NO_STREAM,
    RTC_E_SIP_PARSE_FAILED,
    RTC_E_SIP_HEADER_NOT_PRESENT,
    RTC_E_SDP_NOT_PRESENT,
    RTC_E_SDP_PARSE_FAILED,
    RTC_E_SDP_UPDATE_FAILED,
    RTC_E_SDP_MULTICAST,
    RTC_E_SDP_CONNECTION_ADDR,
    RTC_E_SDP_NO_MEDIA,
    RTC_E_SIP_TIMEOUT,
    RTC_E_SDP_FAILED_TO_BUILD,
    RTC_E_SIP_INVITE_TRANSACTION_PENDING,
    RTC_E_SIP_AUTH_HEADER_SENT,
    RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED,
    RTC_E_SIP_AUTH_FAILED,
    RTC_E_INVALID_SIP_URL,
    RTC_E_DESTINATION_ADDRESS_LOCAL,
    RTC_E_INVALID_ADDRESS_LOCAL,
    RTC_E_DESTINATION_ADDRESS_MULTICAST,
    RTC_E_INVALID_PROXY_ADDRESS,
    RTC_E_SIP_TRANSPORT_NOT_SUPPORTED,
    RTC_E_SIP_NEED_MORE_DATA,
    RTC_E_SIP_CALL_DISCONNECTED,
    RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT,
    RTC_E_SIP_UDP_SIZE_EXCEEDED,
    RTC_E_SIP_SSL_TUNNEL_FAILED,
    RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT,
    RTC_E_SIP_STACK_SHUTDOWN,
    RTC_E_MEDIA_CONTROLLER_STATE,
    RTC_E_MEDIA_NEED_TERMINAL,
    RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE,
    RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE,
    RTC_E_START_STREAM,
    RTC_E_MEDIA_AEC,
    RTC_E_CLIENT_NOT_INITIALIZED,
    RTC_E_CLIENT_ALREADY_INITIALIZED,
    RTC_E_CLIENT_ALREADY_SHUT_DOWN,
    RTC_E_PRESENCE_NOT_ENABLED,
    RTC_E_INVALID_SESSION_TYPE,
    RTC_E_INVALID_SESSION_STATE,
    RTC_E_NO_PROFILE,
    RTC_E_LOCAL_PHONE_NEEDED,
    RTC_E_NO_DEVICE,
    RTC_E_INVALID_PROFILE,
    RTC_E_PROFILE_NO_PROVISION,
    RTC_E_PROFILE_NO_KEY,
    RTC_E_PROFILE_NO_NAME,
    RTC_E_PROFILE_NO_USER,
    RTC_E_PROFILE_NO_USER_URI,
    RTC_E_PROFILE_NO_SERVER,
    RTC_E_PROFILE_NO_SERVER_ADDRESS,
    RTC_E_PROFILE_NO_SERVER_PROTOCOL,
    RTC_E_PROFILE_INVALID_SERVER_PROTOCOL,
    RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD,
    RTC_E_PROFILE_INVALID_SERVER_ROLE,
    RTC_E_PROFILE_MULTIPLE_REGISTRARS,
    RTC_E_PROFILE_INVALID_SESSION,
    RTC_E_PROFILE_INVALID_SESSION_PARTY,
    RTC_E_PROFILE_INVALID_SESSION_TYPE,
    RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS,
    RTC_E_BASIC_AUTH_SET_TLS,
    RTC_E_SIP_HIGH_SECURITY_SET_TLS,
    RTC_E_PROFILE_SERVER_UNAUTHORIZED,
    RTC_E_DUPLICATE_REALM,
    RTC_E_POLICY_NOT_ALLOW,
    RTC_E_PORT_MAPPING_UNAVAILABLE,
    RTC_E_PORT_MAPPING_FAILED,
    RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE,
    RTC_E_SECURITY_LEVEL_NOT_DEFINED,
    RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT,
    RTC_E_DUPLICATE_BUDDY,
    RTC_E_DUPLICATE_WATCHER,
    RTC_E_MALFORMED_XML,
    RTC_E_ROAMING_OPERATION_INTERRUPTED,
    RTC_E_ROAMING_FAILED,
    RTC_E_INVALID_BUDDY_LIST,
    RTC_E_INVALID_ACL_LIST,
    RTC_E_NO_GROUP,
    RTC_E_DUPLICATE_GROUP,
    RTC_E_TOO_MANY_GROUPS,
    RTC_E_NO_BUDDY,
    RTC_E_NO_WATCHER,
    RTC_E_NO_REALM,
    RTC_E_NO_TRANSPORT,
    RTC_E_NOT_EXIST,
    RTC_E_INVALID_PREFERENCE_LIST,
    RTC_E_MAX_PENDING_OPERATIONS,
    RTC_E_TOO_MANY_RETRIES,
    RTC_E_INVALID_PORTRANGE,
    RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED,
    RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION,
    RTC_E_SIP_PARTY_ALREADY_IN_SESSION,
    RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS,
    RTC_E_INVALID_OBJECT_STATE,
    RTC_E_PRESENCE_ENABLED,
    RTC_E_ROAMING_ENABLED,
    RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION,
    RTC_E_SIP_INVALID_CERTIFICATE,
    RTC_E_SIP_DNS_FAIL,
    RTC_E_SIP_TCP_FAIL,
    RTC_E_TOO_SMALL_EXPIRES_VALUE,
    RTC_E_SIP_TLS_FAIL,
    RTC_E_NOT_PRESENCE_PROFILE,
    RTC_E_SIP_INVITEE_PARTY_TIMEOUT,
    RTC_E_SIP_AUTH_TIME_SKEW,
    RTC_E_INVALID_REGISTRATION_STATE,
    RTC_E_MEDIA_DISABLED,
    RTC_E_MEDIA_ENABLED,
    RTC_E_REFER_NOT_ACCEPTED,
    RTC_E_REFER_NOT_ALLOWED,
    RTC_E_REFER_NOT_EXIST,
    RTC_E_SIP_HOLD_OPERATION_PENDING,
    RTC_E_SIP_UNHOLD_OPERATION_PENDING,
    RTC_E_MEDIA_SESSION_NOT_EXIST,
    RTC_E_MEDIA_SESSION_IN_HOLD,
    RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE,
    RTC_E_MAX_REDIRECTS,
    RTC_E_REDIRECT_PROCESSING_FAILED,
    RTC_E_LISTENING_SOCKET_NOT_EXIST,
    RTC_E_INVALID_LISTEN_SOCKET,
    RTC_E_PORT_MANAGER_ALREADY_SET,
    RTC_E_SECURITY_LEVEL_ALREADY_SET,
    RTC_E_UDP_NOT_SUPPORTED,
    RTC_E_SIP_REFER_OPERATION_PENDING,
    RTC_E_PLATFORM_NOT_SUPPORTED,
    RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION,
    RTC_E_NOT_ALLOWED,
    RTC_E_REGISTRATION_DEACTIVATED,
    RTC_E_REGISTRATION_REJECTED,
    RTC_E_REGISTRATION_UNREGISTERED,
}

impl RTC_INTERFACE {
    pub fn code(&self) -> u32 {
        return match self {
            RTC_INTERFACE::RTC_S_ROAMING_NOT_SUPPORTED => 0x00EE0041 as u32,
            RTC_INTERFACE::RTC_E_SIP_CODECS_DO_NOT_MATCH => 0x80EE0000 as u32,
            RTC_INTERFACE::RTC_E_SIP_STREAM_PRESENT => 0x80EE0001 as u32,
            RTC_INTERFACE::RTC_E_SIP_STREAM_NOT_PRESENT => 0x80EE0002 as u32,
            RTC_INTERFACE::RTC_E_SIP_NO_STREAM => 0x80EE0003 as u32,
            RTC_INTERFACE::RTC_E_SIP_PARSE_FAILED => 0x80EE0004 as u32,
            RTC_INTERFACE::RTC_E_SIP_HEADER_NOT_PRESENT => 0x80EE0005 as u32,
            RTC_INTERFACE::RTC_E_SDP_NOT_PRESENT => 0x80EE0006 as u32,
            RTC_INTERFACE::RTC_E_SDP_PARSE_FAILED => 0x80EE0007 as u32,
            RTC_INTERFACE::RTC_E_SDP_UPDATE_FAILED => 0x80EE0008 as u32,
            RTC_INTERFACE::RTC_E_SDP_MULTICAST => 0x80EE0009 as u32,
            RTC_INTERFACE::RTC_E_SDP_CONNECTION_ADDR => 0x80EE000A as u32,
            RTC_INTERFACE::RTC_E_SDP_NO_MEDIA => 0x80EE000B as u32,
            RTC_INTERFACE::RTC_E_SIP_TIMEOUT => 0x80EE000C as u32,
            RTC_INTERFACE::RTC_E_SDP_FAILED_TO_BUILD => 0x80EE000D as u32,
            RTC_INTERFACE::RTC_E_SIP_INVITE_TRANSACTION_PENDING => 0x80EE000E as u32,
            RTC_INTERFACE::RTC_E_SIP_AUTH_HEADER_SENT => 0x80EE000F as u32,
            RTC_INTERFACE::RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED => 0x80EE0010 as u32,
            RTC_INTERFACE::RTC_E_SIP_AUTH_FAILED => 0x80EE0011 as u32,
            RTC_INTERFACE::RTC_E_INVALID_SIP_URL => 0x80EE0012 as u32,
            RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_LOCAL => 0x80EE0013 as u32,
            RTC_INTERFACE::RTC_E_INVALID_ADDRESS_LOCAL => 0x80EE0014 as u32,
            RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_MULTICAST => 0x80EE0015 as u32,
            RTC_INTERFACE::RTC_E_INVALID_PROXY_ADDRESS => 0x80EE0016 as u32,
            RTC_INTERFACE::RTC_E_SIP_TRANSPORT_NOT_SUPPORTED => 0x80EE0017 as u32,
            RTC_INTERFACE::RTC_E_SIP_NEED_MORE_DATA => 0x80EE0018 as u32,
            RTC_INTERFACE::RTC_E_SIP_CALL_DISCONNECTED => 0x80EE0019 as u32,
            RTC_INTERFACE::RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT => 0x80EE001A as u32,
            RTC_INTERFACE::RTC_E_SIP_UDP_SIZE_EXCEEDED => 0x80EE001B as u32,
            RTC_INTERFACE::RTC_E_SIP_SSL_TUNNEL_FAILED => 0x80EE001C as u32,
            RTC_INTERFACE::RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT => 0x80EE001D as u32,
            RTC_INTERFACE::RTC_E_SIP_STACK_SHUTDOWN => 0x80EE001E as u32,
            RTC_INTERFACE::RTC_E_MEDIA_CONTROLLER_STATE => 0x80EE001F as u32,
            RTC_INTERFACE::RTC_E_MEDIA_NEED_TERMINAL => 0x80EE0020 as u32,
            RTC_INTERFACE::RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE => 0x80EE0021 as u32,
            RTC_INTERFACE::RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE => 0x80EE0022 as u32,
            RTC_INTERFACE::RTC_E_START_STREAM => 0x80EE0023 as u32,
            RTC_INTERFACE::RTC_E_MEDIA_AEC => 0x80EE0024 as u32,
            RTC_INTERFACE::RTC_E_CLIENT_NOT_INITIALIZED => 0x80EE0025 as u32,
            RTC_INTERFACE::RTC_E_CLIENT_ALREADY_INITIALIZED => 0x80EE0026 as u32,
            RTC_INTERFACE::RTC_E_CLIENT_ALREADY_SHUT_DOWN => 0x80EE0027 as u32,
            RTC_INTERFACE::RTC_E_PRESENCE_NOT_ENABLED => 0x80EE0028 as u32,
            RTC_INTERFACE::RTC_E_INVALID_SESSION_TYPE => 0x80EE0029 as u32,
            RTC_INTERFACE::RTC_E_INVALID_SESSION_STATE => 0x80EE002A as u32,
            RTC_INTERFACE::RTC_E_NO_PROFILE => 0x80EE002B as u32,
            RTC_INTERFACE::RTC_E_LOCAL_PHONE_NEEDED => 0x80EE002C as u32,
            RTC_INTERFACE::RTC_E_NO_DEVICE => 0x80EE002D as u32,
            RTC_INTERFACE::RTC_E_INVALID_PROFILE => 0x80EE002E as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_PROVISION => 0x80EE002F as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_KEY => 0x80EE0030 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_NAME => 0x80EE0031 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_USER => 0x80EE0032 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_USER_URI => 0x80EE0033 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER => 0x80EE0034 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_ADDRESS => 0x80EE0035 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_PROTOCOL => 0x80EE0036 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_PROTOCOL => 0x80EE0037 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD => 0x80EE0038 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_ROLE => 0x80EE0039 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_MULTIPLE_REGISTRARS => 0x80EE003A as u32,
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION => 0x80EE003B as u32,
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_PARTY => 0x80EE003C as u32,
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_TYPE => 0x80EE003D as u32,
            RTC_INTERFACE::RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS => 0x80EE003E as u32,
            RTC_INTERFACE::RTC_E_BASIC_AUTH_SET_TLS => 0x80EE003F as u32,
            RTC_INTERFACE::RTC_E_SIP_HIGH_SECURITY_SET_TLS => 0x80EE0040 as u32,
            RTC_INTERFACE::RTC_E_PROFILE_SERVER_UNAUTHORIZED => 0x80EE0042 as u32,
            RTC_INTERFACE::RTC_E_DUPLICATE_REALM => 0x80EE0043 as u32,
            RTC_INTERFACE::RTC_E_POLICY_NOT_ALLOW => 0x80EE0044 as u32,
            RTC_INTERFACE::RTC_E_PORT_MAPPING_UNAVAILABLE => 0x80EE0045 as u32,
            RTC_INTERFACE::RTC_E_PORT_MAPPING_FAILED => 0x80EE0046 as u32,
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE => 0x80EE0047 as u32,
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_DEFINED => 0x80EE0048 as u32,
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT => 0x80EE0049 as u32,
            RTC_INTERFACE::RTC_E_DUPLICATE_BUDDY => 0x80EE004A as u32,
            RTC_INTERFACE::RTC_E_DUPLICATE_WATCHER => 0x80EE004B as u32,
            RTC_INTERFACE::RTC_E_MALFORMED_XML => 0x80EE004C as u32,
            RTC_INTERFACE::RTC_E_ROAMING_OPERATION_INTERRUPTED => 0x80EE004D as u32,
            RTC_INTERFACE::RTC_E_ROAMING_FAILED => 0x80EE004E as u32,
            RTC_INTERFACE::RTC_E_INVALID_BUDDY_LIST => 0x80EE004F as u32,
            RTC_INTERFACE::RTC_E_INVALID_ACL_LIST => 0x80EE0050 as u32,
            RTC_INTERFACE::RTC_E_NO_GROUP => 0x80EE0051 as u32,
            RTC_INTERFACE::RTC_E_DUPLICATE_GROUP => 0x80EE0052 as u32,
            RTC_INTERFACE::RTC_E_TOO_MANY_GROUPS => 0x80EE0053 as u32,
            RTC_INTERFACE::RTC_E_NO_BUDDY => 0x80EE0054 as u32,
            RTC_INTERFACE::RTC_E_NO_WATCHER => 0x80EE0055 as u32,
            RTC_INTERFACE::RTC_E_NO_REALM => 0x80EE0056 as u32,
            RTC_INTERFACE::RTC_E_NO_TRANSPORT => 0x80EE0057 as u32,
            RTC_INTERFACE::RTC_E_NOT_EXIST => 0x80EE0058 as u32,
            RTC_INTERFACE::RTC_E_INVALID_PREFERENCE_LIST => 0x80EE0059 as u32,
            RTC_INTERFACE::RTC_E_MAX_PENDING_OPERATIONS => 0x80EE005A as u32,
            RTC_INTERFACE::RTC_E_TOO_MANY_RETRIES => 0x80EE005B as u32,
            RTC_INTERFACE::RTC_E_INVALID_PORTRANGE => 0x80EE005C as u32,
            RTC_INTERFACE::RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED => 0x80EE005D as u32,
            RTC_INTERFACE::RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION => 0x80EE005E as u32,
            RTC_INTERFACE::RTC_E_SIP_PARTY_ALREADY_IN_SESSION => 0x80EE005F as u32,
            RTC_INTERFACE::RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS => 0x80EE0060 as u32,
            RTC_INTERFACE::RTC_E_INVALID_OBJECT_STATE => 0x80EE0061 as u32,
            RTC_INTERFACE::RTC_E_PRESENCE_ENABLED => 0x80EE0062 as u32,
            RTC_INTERFACE::RTC_E_ROAMING_ENABLED => 0x80EE0063 as u32,
            RTC_INTERFACE::RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION => 0x80EE0064 as u32,
            RTC_INTERFACE::RTC_E_SIP_INVALID_CERTIFICATE => 0x80EE0065 as u32,
            RTC_INTERFACE::RTC_E_SIP_DNS_FAIL => 0x80EE0066 as u32,
            RTC_INTERFACE::RTC_E_SIP_TCP_FAIL => 0x80EE0067 as u32,
            RTC_INTERFACE::RTC_E_TOO_SMALL_EXPIRES_VALUE => 0x80EE0068 as u32,
            RTC_INTERFACE::RTC_E_SIP_TLS_FAIL => 0x80EE0069 as u32,
            RTC_INTERFACE::RTC_E_NOT_PRESENCE_PROFILE => 0x80EE006A as u32,
            RTC_INTERFACE::RTC_E_SIP_INVITEE_PARTY_TIMEOUT => 0x80EE006B as u32,
            RTC_INTERFACE::RTC_E_SIP_AUTH_TIME_SKEW => 0x80EE006C as u32,
            RTC_INTERFACE::RTC_E_INVALID_REGISTRATION_STATE => 0x80EE006D as u32,
            RTC_INTERFACE::RTC_E_MEDIA_DISABLED => 0x80EE006E as u32,
            RTC_INTERFACE::RTC_E_MEDIA_ENABLED => 0x80EE006F as u32,
            RTC_INTERFACE::RTC_E_REFER_NOT_ACCEPTED => 0x80EE0070 as u32,
            RTC_INTERFACE::RTC_E_REFER_NOT_ALLOWED => 0x80EE0071 as u32,
            RTC_INTERFACE::RTC_E_REFER_NOT_EXIST => 0x80EE0072 as u32,
            RTC_INTERFACE::RTC_E_SIP_HOLD_OPERATION_PENDING => 0x80EE0073 as u32,
            RTC_INTERFACE::RTC_E_SIP_UNHOLD_OPERATION_PENDING => 0x80EE0074 as u32,
            RTC_INTERFACE::RTC_E_MEDIA_SESSION_NOT_EXIST => 0x80EE0075 as u32,
            RTC_INTERFACE::RTC_E_MEDIA_SESSION_IN_HOLD => 0x80EE0076 as u32,
            RTC_INTERFACE::RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE => 0x80EE0077 as u32,
            RTC_INTERFACE::RTC_E_MAX_REDIRECTS => 0x80EE0078 as u32,
            RTC_INTERFACE::RTC_E_REDIRECT_PROCESSING_FAILED => 0x80EE0079 as u32,
            RTC_INTERFACE::RTC_E_LISTENING_SOCKET_NOT_EXIST => 0x80EE007A as u32,
            RTC_INTERFACE::RTC_E_INVALID_LISTEN_SOCKET => 0x80EE007B as u32,
            RTC_INTERFACE::RTC_E_PORT_MANAGER_ALREADY_SET => 0x80EE007C as u32,
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_ALREADY_SET => 0x80EE007D as u32,
            RTC_INTERFACE::RTC_E_UDP_NOT_SUPPORTED => 0x80EE007E as u32,
            RTC_INTERFACE::RTC_E_SIP_REFER_OPERATION_PENDING => 0x80EE007F as u32,
            RTC_INTERFACE::RTC_E_PLATFORM_NOT_SUPPORTED => 0x80EE0080 as u32,
            RTC_INTERFACE::RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION => 0x80EE0081 as u32,
            RTC_INTERFACE::RTC_E_NOT_ALLOWED => 0x80EE0082 as u32,
            RTC_INTERFACE::RTC_E_REGISTRATION_DEACTIVATED => 0x80EE0083 as u32,
            RTC_INTERFACE::RTC_E_REGISTRATION_REJECTED => 0x80EE0084 as u32,
            RTC_INTERFACE::RTC_E_REGISTRATION_UNREGISTERED => 0x80EE0085 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            RTC_INTERFACE::RTC_S_ROAMING_NOT_SUPPORTED => RawError::Kind(RTC_INTERFACE::RTC_S_ROAMING_NOT_SUPPORTED),
            RTC_INTERFACE::RTC_E_SIP_CODECS_DO_NOT_MATCH => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_CODECS_DO_NOT_MATCH),
            RTC_INTERFACE::RTC_E_SIP_STREAM_PRESENT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_STREAM_PRESENT),
            RTC_INTERFACE::RTC_E_SIP_STREAM_NOT_PRESENT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_STREAM_NOT_PRESENT),
            RTC_INTERFACE::RTC_E_SIP_NO_STREAM => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_NO_STREAM),
            RTC_INTERFACE::RTC_E_SIP_PARSE_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_PARSE_FAILED),
            RTC_INTERFACE::RTC_E_SIP_HEADER_NOT_PRESENT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_HEADER_NOT_PRESENT),
            RTC_INTERFACE::RTC_E_SDP_NOT_PRESENT => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_NOT_PRESENT),
            RTC_INTERFACE::RTC_E_SDP_PARSE_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_PARSE_FAILED),
            RTC_INTERFACE::RTC_E_SDP_UPDATE_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_UPDATE_FAILED),
            RTC_INTERFACE::RTC_E_SDP_MULTICAST => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_MULTICAST),
            RTC_INTERFACE::RTC_E_SDP_CONNECTION_ADDR => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_CONNECTION_ADDR),
            RTC_INTERFACE::RTC_E_SDP_NO_MEDIA => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_NO_MEDIA),
            RTC_INTERFACE::RTC_E_SIP_TIMEOUT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_TIMEOUT),
            RTC_INTERFACE::RTC_E_SDP_FAILED_TO_BUILD => RawError::Kind(RTC_INTERFACE::RTC_E_SDP_FAILED_TO_BUILD),
            RTC_INTERFACE::RTC_E_SIP_INVITE_TRANSACTION_PENDING => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_INVITE_TRANSACTION_PENDING),
            RTC_INTERFACE::RTC_E_SIP_AUTH_HEADER_SENT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_AUTH_HEADER_SENT),
            RTC_INTERFACE::RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED),
            RTC_INTERFACE::RTC_E_SIP_AUTH_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_AUTH_FAILED),
            RTC_INTERFACE::RTC_E_INVALID_SIP_URL => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_SIP_URL),
            RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_LOCAL => RawError::Kind(RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_LOCAL),
            RTC_INTERFACE::RTC_E_INVALID_ADDRESS_LOCAL => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_ADDRESS_LOCAL),
            RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_MULTICAST => RawError::Kind(RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_MULTICAST),
            RTC_INTERFACE::RTC_E_INVALID_PROXY_ADDRESS => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_PROXY_ADDRESS),
            RTC_INTERFACE::RTC_E_SIP_TRANSPORT_NOT_SUPPORTED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_TRANSPORT_NOT_SUPPORTED),
            RTC_INTERFACE::RTC_E_SIP_NEED_MORE_DATA => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_NEED_MORE_DATA),
            RTC_INTERFACE::RTC_E_SIP_CALL_DISCONNECTED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_CALL_DISCONNECTED),
            RTC_INTERFACE::RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT),
            RTC_INTERFACE::RTC_E_SIP_UDP_SIZE_EXCEEDED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_UDP_SIZE_EXCEEDED),
            RTC_INTERFACE::RTC_E_SIP_SSL_TUNNEL_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_SSL_TUNNEL_FAILED),
            RTC_INTERFACE::RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT),
            RTC_INTERFACE::RTC_E_SIP_STACK_SHUTDOWN => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_STACK_SHUTDOWN),
            RTC_INTERFACE::RTC_E_MEDIA_CONTROLLER_STATE => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_CONTROLLER_STATE),
            RTC_INTERFACE::RTC_E_MEDIA_NEED_TERMINAL => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_NEED_TERMINAL),
            RTC_INTERFACE::RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE),
            RTC_INTERFACE::RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE),
            RTC_INTERFACE::RTC_E_START_STREAM => RawError::Kind(RTC_INTERFACE::RTC_E_START_STREAM),
            RTC_INTERFACE::RTC_E_MEDIA_AEC => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_AEC),
            RTC_INTERFACE::RTC_E_CLIENT_NOT_INITIALIZED => RawError::Kind(RTC_INTERFACE::RTC_E_CLIENT_NOT_INITIALIZED),
            RTC_INTERFACE::RTC_E_CLIENT_ALREADY_INITIALIZED => RawError::Kind(RTC_INTERFACE::RTC_E_CLIENT_ALREADY_INITIALIZED),
            RTC_INTERFACE::RTC_E_CLIENT_ALREADY_SHUT_DOWN => RawError::Kind(RTC_INTERFACE::RTC_E_CLIENT_ALREADY_SHUT_DOWN),
            RTC_INTERFACE::RTC_E_PRESENCE_NOT_ENABLED => RawError::Kind(RTC_INTERFACE::RTC_E_PRESENCE_NOT_ENABLED),
            RTC_INTERFACE::RTC_E_INVALID_SESSION_TYPE => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_SESSION_TYPE),
            RTC_INTERFACE::RTC_E_INVALID_SESSION_STATE => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_SESSION_STATE),
            RTC_INTERFACE::RTC_E_NO_PROFILE => RawError::Kind(RTC_INTERFACE::RTC_E_NO_PROFILE),
            RTC_INTERFACE::RTC_E_LOCAL_PHONE_NEEDED => RawError::Kind(RTC_INTERFACE::RTC_E_LOCAL_PHONE_NEEDED),
            RTC_INTERFACE::RTC_E_NO_DEVICE => RawError::Kind(RTC_INTERFACE::RTC_E_NO_DEVICE),
            RTC_INTERFACE::RTC_E_INVALID_PROFILE => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_PROFILE),
            RTC_INTERFACE::RTC_E_PROFILE_NO_PROVISION => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_PROVISION),
            RTC_INTERFACE::RTC_E_PROFILE_NO_KEY => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_KEY),
            RTC_INTERFACE::RTC_E_PROFILE_NO_NAME => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_NAME),
            RTC_INTERFACE::RTC_E_PROFILE_NO_USER => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_USER),
            RTC_INTERFACE::RTC_E_PROFILE_NO_USER_URI => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_USER_URI),
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER),
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_ADDRESS => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_ADDRESS),
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_PROTOCOL => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_PROTOCOL),
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_PROTOCOL => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_PROTOCOL),
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD),
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_ROLE => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_ROLE),
            RTC_INTERFACE::RTC_E_PROFILE_MULTIPLE_REGISTRARS => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_MULTIPLE_REGISTRARS),
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION),
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_PARTY => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_PARTY),
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_TYPE => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_TYPE),
            RTC_INTERFACE::RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS => RawError::Kind(RTC_INTERFACE::RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS),
            RTC_INTERFACE::RTC_E_BASIC_AUTH_SET_TLS => RawError::Kind(RTC_INTERFACE::RTC_E_BASIC_AUTH_SET_TLS),
            RTC_INTERFACE::RTC_E_SIP_HIGH_SECURITY_SET_TLS => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_HIGH_SECURITY_SET_TLS),
            RTC_INTERFACE::RTC_E_PROFILE_SERVER_UNAUTHORIZED => RawError::Kind(RTC_INTERFACE::RTC_E_PROFILE_SERVER_UNAUTHORIZED),
            RTC_INTERFACE::RTC_E_DUPLICATE_REALM => RawError::Kind(RTC_INTERFACE::RTC_E_DUPLICATE_REALM),
            RTC_INTERFACE::RTC_E_POLICY_NOT_ALLOW => RawError::Kind(RTC_INTERFACE::RTC_E_POLICY_NOT_ALLOW),
            RTC_INTERFACE::RTC_E_PORT_MAPPING_UNAVAILABLE => RawError::Kind(RTC_INTERFACE::RTC_E_PORT_MAPPING_UNAVAILABLE),
            RTC_INTERFACE::RTC_E_PORT_MAPPING_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_PORT_MAPPING_FAILED),
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE => RawError::Kind(RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE),
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_DEFINED => RawError::Kind(RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_DEFINED),
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT => RawError::Kind(RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT),
            RTC_INTERFACE::RTC_E_DUPLICATE_BUDDY => RawError::Kind(RTC_INTERFACE::RTC_E_DUPLICATE_BUDDY),
            RTC_INTERFACE::RTC_E_DUPLICATE_WATCHER => RawError::Kind(RTC_INTERFACE::RTC_E_DUPLICATE_WATCHER),
            RTC_INTERFACE::RTC_E_MALFORMED_XML => RawError::Kind(RTC_INTERFACE::RTC_E_MALFORMED_XML),
            RTC_INTERFACE::RTC_E_ROAMING_OPERATION_INTERRUPTED => RawError::Kind(RTC_INTERFACE::RTC_E_ROAMING_OPERATION_INTERRUPTED),
            RTC_INTERFACE::RTC_E_ROAMING_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_ROAMING_FAILED),
            RTC_INTERFACE::RTC_E_INVALID_BUDDY_LIST => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_BUDDY_LIST),
            RTC_INTERFACE::RTC_E_INVALID_ACL_LIST => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_ACL_LIST),
            RTC_INTERFACE::RTC_E_NO_GROUP => RawError::Kind(RTC_INTERFACE::RTC_E_NO_GROUP),
            RTC_INTERFACE::RTC_E_DUPLICATE_GROUP => RawError::Kind(RTC_INTERFACE::RTC_E_DUPLICATE_GROUP),
            RTC_INTERFACE::RTC_E_TOO_MANY_GROUPS => RawError::Kind(RTC_INTERFACE::RTC_E_TOO_MANY_GROUPS),
            RTC_INTERFACE::RTC_E_NO_BUDDY => RawError::Kind(RTC_INTERFACE::RTC_E_NO_BUDDY),
            RTC_INTERFACE::RTC_E_NO_WATCHER => RawError::Kind(RTC_INTERFACE::RTC_E_NO_WATCHER),
            RTC_INTERFACE::RTC_E_NO_REALM => RawError::Kind(RTC_INTERFACE::RTC_E_NO_REALM),
            RTC_INTERFACE::RTC_E_NO_TRANSPORT => RawError::Kind(RTC_INTERFACE::RTC_E_NO_TRANSPORT),
            RTC_INTERFACE::RTC_E_NOT_EXIST => RawError::Kind(RTC_INTERFACE::RTC_E_NOT_EXIST),
            RTC_INTERFACE::RTC_E_INVALID_PREFERENCE_LIST => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_PREFERENCE_LIST),
            RTC_INTERFACE::RTC_E_MAX_PENDING_OPERATIONS => RawError::Kind(RTC_INTERFACE::RTC_E_MAX_PENDING_OPERATIONS),
            RTC_INTERFACE::RTC_E_TOO_MANY_RETRIES => RawError::Kind(RTC_INTERFACE::RTC_E_TOO_MANY_RETRIES),
            RTC_INTERFACE::RTC_E_INVALID_PORTRANGE => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_PORTRANGE),
            RTC_INTERFACE::RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED),
            RTC_INTERFACE::RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION),
            RTC_INTERFACE::RTC_E_SIP_PARTY_ALREADY_IN_SESSION => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_PARTY_ALREADY_IN_SESSION),
            RTC_INTERFACE::RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS),
            RTC_INTERFACE::RTC_E_INVALID_OBJECT_STATE => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_OBJECT_STATE),
            RTC_INTERFACE::RTC_E_PRESENCE_ENABLED => RawError::Kind(RTC_INTERFACE::RTC_E_PRESENCE_ENABLED),
            RTC_INTERFACE::RTC_E_ROAMING_ENABLED => RawError::Kind(RTC_INTERFACE::RTC_E_ROAMING_ENABLED),
            RTC_INTERFACE::RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION),
            RTC_INTERFACE::RTC_E_SIP_INVALID_CERTIFICATE => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_INVALID_CERTIFICATE),
            RTC_INTERFACE::RTC_E_SIP_DNS_FAIL => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_DNS_FAIL),
            RTC_INTERFACE::RTC_E_SIP_TCP_FAIL => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_TCP_FAIL),
            RTC_INTERFACE::RTC_E_TOO_SMALL_EXPIRES_VALUE => RawError::Kind(RTC_INTERFACE::RTC_E_TOO_SMALL_EXPIRES_VALUE),
            RTC_INTERFACE::RTC_E_SIP_TLS_FAIL => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_TLS_FAIL),
            RTC_INTERFACE::RTC_E_NOT_PRESENCE_PROFILE => RawError::Kind(RTC_INTERFACE::RTC_E_NOT_PRESENCE_PROFILE),
            RTC_INTERFACE::RTC_E_SIP_INVITEE_PARTY_TIMEOUT => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_INVITEE_PARTY_TIMEOUT),
            RTC_INTERFACE::RTC_E_SIP_AUTH_TIME_SKEW => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_AUTH_TIME_SKEW),
            RTC_INTERFACE::RTC_E_INVALID_REGISTRATION_STATE => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_REGISTRATION_STATE),
            RTC_INTERFACE::RTC_E_MEDIA_DISABLED => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_DISABLED),
            RTC_INTERFACE::RTC_E_MEDIA_ENABLED => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_ENABLED),
            RTC_INTERFACE::RTC_E_REFER_NOT_ACCEPTED => RawError::Kind(RTC_INTERFACE::RTC_E_REFER_NOT_ACCEPTED),
            RTC_INTERFACE::RTC_E_REFER_NOT_ALLOWED => RawError::Kind(RTC_INTERFACE::RTC_E_REFER_NOT_ALLOWED),
            RTC_INTERFACE::RTC_E_REFER_NOT_EXIST => RawError::Kind(RTC_INTERFACE::RTC_E_REFER_NOT_EXIST),
            RTC_INTERFACE::RTC_E_SIP_HOLD_OPERATION_PENDING => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_HOLD_OPERATION_PENDING),
            RTC_INTERFACE::RTC_E_SIP_UNHOLD_OPERATION_PENDING => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_UNHOLD_OPERATION_PENDING),
            RTC_INTERFACE::RTC_E_MEDIA_SESSION_NOT_EXIST => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_SESSION_NOT_EXIST),
            RTC_INTERFACE::RTC_E_MEDIA_SESSION_IN_HOLD => RawError::Kind(RTC_INTERFACE::RTC_E_MEDIA_SESSION_IN_HOLD),
            RTC_INTERFACE::RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE => RawError::Kind(RTC_INTERFACE::RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE),
            RTC_INTERFACE::RTC_E_MAX_REDIRECTS => RawError::Kind(RTC_INTERFACE::RTC_E_MAX_REDIRECTS),
            RTC_INTERFACE::RTC_E_REDIRECT_PROCESSING_FAILED => RawError::Kind(RTC_INTERFACE::RTC_E_REDIRECT_PROCESSING_FAILED),
            RTC_INTERFACE::RTC_E_LISTENING_SOCKET_NOT_EXIST => RawError::Kind(RTC_INTERFACE::RTC_E_LISTENING_SOCKET_NOT_EXIST),
            RTC_INTERFACE::RTC_E_INVALID_LISTEN_SOCKET => RawError::Kind(RTC_INTERFACE::RTC_E_INVALID_LISTEN_SOCKET),
            RTC_INTERFACE::RTC_E_PORT_MANAGER_ALREADY_SET => RawError::Kind(RTC_INTERFACE::RTC_E_PORT_MANAGER_ALREADY_SET),
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_ALREADY_SET => RawError::Kind(RTC_INTERFACE::RTC_E_SECURITY_LEVEL_ALREADY_SET),
            RTC_INTERFACE::RTC_E_UDP_NOT_SUPPORTED => RawError::Kind(RTC_INTERFACE::RTC_E_UDP_NOT_SUPPORTED),
            RTC_INTERFACE::RTC_E_SIP_REFER_OPERATION_PENDING => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_REFER_OPERATION_PENDING),
            RTC_INTERFACE::RTC_E_PLATFORM_NOT_SUPPORTED => RawError::Kind(RTC_INTERFACE::RTC_E_PLATFORM_NOT_SUPPORTED),
            RTC_INTERFACE::RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION => RawError::Kind(RTC_INTERFACE::RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION),
            RTC_INTERFACE::RTC_E_NOT_ALLOWED => RawError::Kind(RTC_INTERFACE::RTC_E_NOT_ALLOWED),
            RTC_INTERFACE::RTC_E_REGISTRATION_DEACTIVATED => RawError::Kind(RTC_INTERFACE::RTC_E_REGISTRATION_DEACTIVATED),
            RTC_INTERFACE::RTC_E_REGISTRATION_REJECTED => RawError::Kind(RTC_INTERFACE::RTC_E_REGISTRATION_REJECTED),
            RTC_INTERFACE::RTC_E_REGISTRATION_UNREGISTERED => RawError::Kind(RTC_INTERFACE::RTC_E_REGISTRATION_UNREGISTERED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            RTC_INTERFACE::RTC_S_ROAMING_NOT_SUPPORTED => "Server does not support this type of roaming.",
            RTC_INTERFACE::RTC_E_SIP_CODECS_DO_NOT_MATCH => "No matching codecs with peer.",
            RTC_INTERFACE::RTC_E_SIP_STREAM_PRESENT => "Parsing SIP failed The stream to be started is already present.",
            RTC_INTERFACE::RTC_E_SIP_STREAM_NOT_PRESENT => "The stream to be stopped is not present.",
            RTC_INTERFACE::RTC_E_SIP_NO_STREAM => "No stream is active.",
            RTC_INTERFACE::RTC_E_SIP_PARSE_FAILED => "Parsing SIP failed.",
            RTC_INTERFACE::RTC_E_SIP_HEADER_NOT_PRESENT => "The SIP header is not present in the message.",
            RTC_INTERFACE::RTC_E_SDP_NOT_PRESENT => "SDP is not present in the SIP message.",
            RTC_INTERFACE::RTC_E_SDP_PARSE_FAILED => "Parsing SDP failed.",
            RTC_INTERFACE::RTC_E_SDP_UPDATE_FAILED => "SDP does not match the previous one.",
            RTC_INTERFACE::RTC_E_SDP_MULTICAST => "Multicast is not supported.",
            RTC_INTERFACE::RTC_E_SDP_CONNECTION_ADDR => "Media does not contain connection address.",
            RTC_INTERFACE::RTC_E_SDP_NO_MEDIA => "No media is available for the session.",
            RTC_INTERFACE::RTC_E_SIP_TIMEOUT => "SIP Transaction timed out.",
            RTC_INTERFACE::RTC_E_SDP_FAILED_TO_BUILD => "Failed to build SDP blob.",
            RTC_INTERFACE::RTC_E_SIP_INVITE_TRANSACTION_PENDING => "Currently processing another INVITE transaction.",
            RTC_INTERFACE::RTC_E_SIP_AUTH_HEADER_SENT => "Authorization header was sent in a previous request.",
            RTC_INTERFACE::RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED => "The Authentication type requested is not supported.",
            RTC_INTERFACE::RTC_E_SIP_AUTH_FAILED => "Authentication Failed.",
            RTC_INTERFACE::RTC_E_INVALID_SIP_URL => "The SIP URL is not valid.",
            RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_LOCAL => "The Destination Address belongs to the local machine.",
            RTC_INTERFACE::RTC_E_INVALID_ADDRESS_LOCAL => "The Local Address is invalid, check the profile.",
            RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_MULTICAST => "The Destination Address is a multicast address.",
            RTC_INTERFACE::RTC_E_INVALID_PROXY_ADDRESS => "The Proxy Address is not valid.",
            RTC_INTERFACE::RTC_E_SIP_TRANSPORT_NOT_SUPPORTED => "The Transport specified is not supported.",
            RTC_INTERFACE::RTC_E_SIP_NEED_MORE_DATA => "Need more data for parsing a whole SIP message.",
            RTC_INTERFACE::RTC_E_SIP_CALL_DISCONNECTED => "The Call has been disconnected.",
            RTC_INTERFACE::RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT => "The Request destination address is not known.",
            RTC_INTERFACE::RTC_E_SIP_UDP_SIZE_EXCEEDED => "The sip message size is greater than the UDP message size allowed.",
            RTC_INTERFACE::RTC_E_SIP_SSL_TUNNEL_FAILED => "Cannot establish SSL tunnel to Http proxy.",
            RTC_INTERFACE::RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT => "Timeout during SSL Negotiation.",
            RTC_INTERFACE::RTC_E_SIP_STACK_SHUTDOWN => "Sip Stack is already shutdown.",
            RTC_INTERFACE::RTC_E_MEDIA_CONTROLLER_STATE => "Operation not allowed in current media controller state.",
            RTC_INTERFACE::RTC_E_MEDIA_NEED_TERMINAL => "Can not find device.",
            RTC_INTERFACE::RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE => "Audio device is not available.",
            RTC_INTERFACE::RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE => "Video device is not available.",
            RTC_INTERFACE::RTC_E_START_STREAM => "Can not start stream.",
            RTC_INTERFACE::RTC_E_MEDIA_AEC => "Failed to enable acoustic echo cancellation.",
            RTC_INTERFACE::RTC_E_CLIENT_NOT_INITIALIZED => "Client not initialized.",
            RTC_INTERFACE::RTC_E_CLIENT_ALREADY_INITIALIZED => "Client already initialized.",
            RTC_INTERFACE::RTC_E_CLIENT_ALREADY_SHUT_DOWN => "Client already shut down.",
            RTC_INTERFACE::RTC_E_PRESENCE_NOT_ENABLED => "Presence not enabled.",
            RTC_INTERFACE::RTC_E_INVALID_SESSION_TYPE => "Invalid session type.",
            RTC_INTERFACE::RTC_E_INVALID_SESSION_STATE => "Invalid session state.",
            RTC_INTERFACE::RTC_E_NO_PROFILE => "No valid profile for this operation.",
            RTC_INTERFACE::RTC_E_LOCAL_PHONE_NEEDED => "A local phone number is needed.",
            RTC_INTERFACE::RTC_E_NO_DEVICE => "No preferred device.",
            RTC_INTERFACE::RTC_E_INVALID_PROFILE => "Invalid profile.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_PROVISION => "No provision tag in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_KEY => "No profile key.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_NAME => "No profile name.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_USER => "No user tag in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_USER_URI => "No user URI in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER => "No server tag in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_ADDRESS => "Server tag missing address in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_PROTOCOL => "Server tag missing protocol in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_PROTOCOL => "Invalid server protocol in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD => "Invalid server authentication method in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_ROLE => "Invalid server role in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_MULTIPLE_REGISTRARS => "Multiple registrar servers in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION => "Invalid session tag in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_PARTY => "Invalid session party in profile.",
            RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_TYPE => "Invalid session type in profile.",
            RTC_INTERFACE::RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS => "The operation failed because of too many participants in the session.",
            RTC_INTERFACE::RTC_E_BASIC_AUTH_SET_TLS => "Must set transport to TLS if Basic Auth is allowed.",
            RTC_INTERFACE::RTC_E_SIP_HIGH_SECURITY_SET_TLS => "Must set transport to TLS if high security mode is needed.",
            RTC_INTERFACE::RTC_E_PROFILE_SERVER_UNAUTHORIZED => "Server address does not match an authorized domain in profile.",
            RTC_INTERFACE::RTC_E_DUPLICATE_REALM => "Duplicate realm exists in an enabled profile.",
            RTC_INTERFACE::RTC_E_POLICY_NOT_ALLOW => "Current policy settings do not allow this action.",
            RTC_INTERFACE::RTC_E_PORT_MAPPING_UNAVAILABLE => "Port mapping can not be obtained from the port manager.",
            RTC_INTERFACE::RTC_E_PORT_MAPPING_FAILED => "Port mapping failure returned from the port manager.",
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE => "The local and remote security levels are not compatible.",
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_DEFINED => "The security level is not defined.",
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT => "Participant could not support the requested security level.",
            RTC_INTERFACE::RTC_E_DUPLICATE_BUDDY => "Buddy already exists.",
            RTC_INTERFACE::RTC_E_DUPLICATE_WATCHER => "Watcher already exists.",
            RTC_INTERFACE::RTC_E_MALFORMED_XML => "Malformed XML.",
            RTC_INTERFACE::RTC_E_ROAMING_OPERATION_INTERRUPTED => "Roaming operation interrupted. It may succeed or fail.",
            RTC_INTERFACE::RTC_E_ROAMING_FAILED => "Roaming session failed.",
            RTC_INTERFACE::RTC_E_INVALID_BUDDY_LIST => "Buddy list is invalid.",
            RTC_INTERFACE::RTC_E_INVALID_ACL_LIST => "ACL list is invalid.",
            RTC_INTERFACE::RTC_E_NO_GROUP => "Group does not exist.",
            RTC_INTERFACE::RTC_E_DUPLICATE_GROUP => "Group already exists.",
            RTC_INTERFACE::RTC_E_TOO_MANY_GROUPS => "Max number of groups has been reached.",
            RTC_INTERFACE::RTC_E_NO_BUDDY => "Buddy does not exist.",
            RTC_INTERFACE::RTC_E_NO_WATCHER => "Watcher does not exist.",
            RTC_INTERFACE::RTC_E_NO_REALM => "No realm is set.",
            RTC_INTERFACE::RTC_E_NO_TRANSPORT => "Server can not be specified without a transport protocol.",
            RTC_INTERFACE::RTC_E_NOT_EXIST => "The required item does not exist.",
            RTC_INTERFACE::RTC_E_INVALID_PREFERENCE_LIST => "Preference list is invalid.",
            RTC_INTERFACE::RTC_E_MAX_PENDING_OPERATIONS => "Maximum number of pending operations reached.",
            RTC_INTERFACE::RTC_E_TOO_MANY_RETRIES => "Too many attempts to resend a request.",
            RTC_INTERFACE::RTC_E_INVALID_PORTRANGE => "Invalid port range.",
            RTC_INTERFACE::RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED => "Call connection has not been established.",
            RTC_INTERFACE::RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION => "Adding additional parties to two party session failed.",
            RTC_INTERFACE::RTC_E_SIP_PARTY_ALREADY_IN_SESSION => "Party already exists in session.",
            RTC_INTERFACE::RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS => "Join operation is in progress for another party.",
            RTC_INTERFACE::RTC_E_INVALID_OBJECT_STATE => "Object state does not allow to perform this operation.",
            RTC_INTERFACE::RTC_E_PRESENCE_ENABLED => "Presence is enabled.",
            RTC_INTERFACE::RTC_E_ROAMING_ENABLED => "Roaming is enabled.",
            RTC_INTERFACE::RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION => "Incompatible TLS encryption.",
            RTC_INTERFACE::RTC_E_SIP_INVALID_CERTIFICATE => "Invalid certificate.",
            RTC_INTERFACE::RTC_E_SIP_DNS_FAIL => "DNS lookup fails.",
            RTC_INTERFACE::RTC_E_SIP_TCP_FAIL => "Fails to make a TCP connection.",
            RTC_INTERFACE::RTC_E_TOO_SMALL_EXPIRES_VALUE => "Expires value received from the server is too small.",
            RTC_INTERFACE::RTC_E_SIP_TLS_FAIL => "Fails to make a TLS connection.",
            RTC_INTERFACE::RTC_E_NOT_PRESENCE_PROFILE => "A presence profile must be used.",
            RTC_INTERFACE::RTC_E_SIP_INVITEE_PARTY_TIMEOUT => "Invitee connection fails.",
            RTC_INTERFACE::RTC_E_SIP_AUTH_TIME_SKEW => "Authentication failure because of time skew between client and server.",
            RTC_INTERFACE::RTC_E_INVALID_REGISTRATION_STATE => "Invalid registration state.",
            RTC_INTERFACE::RTC_E_MEDIA_DISABLED => "Media is disabled.",
            RTC_INTERFACE::RTC_E_MEDIA_ENABLED => "Media is enabled.",
            RTC_INTERFACE::RTC_E_REFER_NOT_ACCEPTED => "Refer has not been accepted.",
            RTC_INTERFACE::RTC_E_REFER_NOT_ALLOWED => "Refer operation is not allowed in this session.",
            RTC_INTERFACE::RTC_E_REFER_NOT_EXIST => "Refer session does not exist or has finished.",
            RTC_INTERFACE::RTC_E_SIP_HOLD_OPERATION_PENDING => "Currently an hold operation is pending.",
            RTC_INTERFACE::RTC_E_SIP_UNHOLD_OPERATION_PENDING => "Currently an unhold operation is pending.",
            RTC_INTERFACE::RTC_E_MEDIA_SESSION_NOT_EXIST => "Media session does not exist.",
            RTC_INTERFACE::RTC_E_MEDIA_SESSION_IN_HOLD => "Media session is in hold.",
            RTC_INTERFACE::RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE => "Another media session is active.",
            RTC_INTERFACE::RTC_E_MAX_REDIRECTS => "Too many redirects.",
            RTC_INTERFACE::RTC_E_REDIRECT_PROCESSING_FAILED => "Processing redirect failed.",
            RTC_INTERFACE::RTC_E_LISTENING_SOCKET_NOT_EXIST => "Listening socket does not exist.",
            RTC_INTERFACE::RTC_E_INVALID_LISTEN_SOCKET => "Specified address and port is invalid.",
            RTC_INTERFACE::RTC_E_PORT_MANAGER_ALREADY_SET => "Port manager already set.",
            RTC_INTERFACE::RTC_E_SECURITY_LEVEL_ALREADY_SET => "The security level has already been set for this Media type can and can not be changed.",
            RTC_INTERFACE::RTC_E_UDP_NOT_SUPPORTED => "This feature is not supported when one of the server in profile has UDP transport.",
            RTC_INTERFACE::RTC_E_SIP_REFER_OPERATION_PENDING => "Currently a refer operation is pending.",
            RTC_INTERFACE::RTC_E_PLATFORM_NOT_SUPPORTED => "This operation is not supported on this Windows Platform.",
            RTC_INTERFACE::RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION => "A peer participant cannot be added to a multiparty session.",
            RTC_INTERFACE::RTC_E_NOT_ALLOWED => "This action is not allowed.",
            RTC_INTERFACE::RTC_E_REGISTRATION_DEACTIVATED => "The user is being moved.",
            RTC_INTERFACE::RTC_E_REGISTRATION_REJECTED => "The user's account was disabled or deleted or the SIP URI changed.",
            RTC_INTERFACE::RTC_E_REGISTRATION_UNREGISTERED => "The user was logged out because the user logged in elsewhere.",
        }
    }

    pub fn from_name(name: &str) -> RTC_INTERFACE {
        return match name {
            "RTC_S_ROAMING_NOT_SUPPORTED" => RTC_INTERFACE::RTC_S_ROAMING_NOT_SUPPORTED,
            "RTC_E_SIP_CODECS_DO_NOT_MATCH" => RTC_INTERFACE::RTC_E_SIP_CODECS_DO_NOT_MATCH,
            "RTC_E_SIP_STREAM_PRESENT" => RTC_INTERFACE::RTC_E_SIP_STREAM_PRESENT,
            "RTC_E_SIP_STREAM_NOT_PRESENT" => RTC_INTERFACE::RTC_E_SIP_STREAM_NOT_PRESENT,
            "RTC_E_SIP_NO_STREAM" => RTC_INTERFACE::RTC_E_SIP_NO_STREAM,
            "RTC_E_SIP_PARSE_FAILED" => RTC_INTERFACE::RTC_E_SIP_PARSE_FAILED,
            "RTC_E_SIP_HEADER_NOT_PRESENT" => RTC_INTERFACE::RTC_E_SIP_HEADER_NOT_PRESENT,
            "RTC_E_SDP_NOT_PRESENT" => RTC_INTERFACE::RTC_E_SDP_NOT_PRESENT,
            "RTC_E_SDP_PARSE_FAILED" => RTC_INTERFACE::RTC_E_SDP_PARSE_FAILED,
            "RTC_E_SDP_UPDATE_FAILED" => RTC_INTERFACE::RTC_E_SDP_UPDATE_FAILED,
            "RTC_E_SDP_MULTICAST" => RTC_INTERFACE::RTC_E_SDP_MULTICAST,
            "RTC_E_SDP_CONNECTION_ADDR" => RTC_INTERFACE::RTC_E_SDP_CONNECTION_ADDR,
            "RTC_E_SDP_NO_MEDIA" => RTC_INTERFACE::RTC_E_SDP_NO_MEDIA,
            "RTC_E_SIP_TIMEOUT" => RTC_INTERFACE::RTC_E_SIP_TIMEOUT,
            "RTC_E_SDP_FAILED_TO_BUILD" => RTC_INTERFACE::RTC_E_SDP_FAILED_TO_BUILD,
            "RTC_E_SIP_INVITE_TRANSACTION_PENDING" => RTC_INTERFACE::RTC_E_SIP_INVITE_TRANSACTION_PENDING,
            "RTC_E_SIP_AUTH_HEADER_SENT" => RTC_INTERFACE::RTC_E_SIP_AUTH_HEADER_SENT,
            "RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED" => RTC_INTERFACE::RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED,
            "RTC_E_SIP_AUTH_FAILED" => RTC_INTERFACE::RTC_E_SIP_AUTH_FAILED,
            "RTC_E_INVALID_SIP_URL" => RTC_INTERFACE::RTC_E_INVALID_SIP_URL,
            "RTC_E_DESTINATION_ADDRESS_LOCAL" => RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_LOCAL,
            "RTC_E_INVALID_ADDRESS_LOCAL" => RTC_INTERFACE::RTC_E_INVALID_ADDRESS_LOCAL,
            "RTC_E_DESTINATION_ADDRESS_MULTICAST" => RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_MULTICAST,
            "RTC_E_INVALID_PROXY_ADDRESS" => RTC_INTERFACE::RTC_E_INVALID_PROXY_ADDRESS,
            "RTC_E_SIP_TRANSPORT_NOT_SUPPORTED" => RTC_INTERFACE::RTC_E_SIP_TRANSPORT_NOT_SUPPORTED,
            "RTC_E_SIP_NEED_MORE_DATA" => RTC_INTERFACE::RTC_E_SIP_NEED_MORE_DATA,
            "RTC_E_SIP_CALL_DISCONNECTED" => RTC_INTERFACE::RTC_E_SIP_CALL_DISCONNECTED,
            "RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT" => RTC_INTERFACE::RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT,
            "RTC_E_SIP_UDP_SIZE_EXCEEDED" => RTC_INTERFACE::RTC_E_SIP_UDP_SIZE_EXCEEDED,
            "RTC_E_SIP_SSL_TUNNEL_FAILED" => RTC_INTERFACE::RTC_E_SIP_SSL_TUNNEL_FAILED,
            "RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT" => RTC_INTERFACE::RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT,
            "RTC_E_SIP_STACK_SHUTDOWN" => RTC_INTERFACE::RTC_E_SIP_STACK_SHUTDOWN,
            "RTC_E_MEDIA_CONTROLLER_STATE" => RTC_INTERFACE::RTC_E_MEDIA_CONTROLLER_STATE,
            "RTC_E_MEDIA_NEED_TERMINAL" => RTC_INTERFACE::RTC_E_MEDIA_NEED_TERMINAL,
            "RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE" => RTC_INTERFACE::RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE,
            "RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE" => RTC_INTERFACE::RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE,
            "RTC_E_START_STREAM" => RTC_INTERFACE::RTC_E_START_STREAM,
            "RTC_E_MEDIA_AEC" => RTC_INTERFACE::RTC_E_MEDIA_AEC,
            "RTC_E_CLIENT_NOT_INITIALIZED" => RTC_INTERFACE::RTC_E_CLIENT_NOT_INITIALIZED,
            "RTC_E_CLIENT_ALREADY_INITIALIZED" => RTC_INTERFACE::RTC_E_CLIENT_ALREADY_INITIALIZED,
            "RTC_E_CLIENT_ALREADY_SHUT_DOWN" => RTC_INTERFACE::RTC_E_CLIENT_ALREADY_SHUT_DOWN,
            "RTC_E_PRESENCE_NOT_ENABLED" => RTC_INTERFACE::RTC_E_PRESENCE_NOT_ENABLED,
            "RTC_E_INVALID_SESSION_TYPE" => RTC_INTERFACE::RTC_E_INVALID_SESSION_TYPE,
            "RTC_E_INVALID_SESSION_STATE" => RTC_INTERFACE::RTC_E_INVALID_SESSION_STATE,
            "RTC_E_NO_PROFILE" => RTC_INTERFACE::RTC_E_NO_PROFILE,
            "RTC_E_LOCAL_PHONE_NEEDED" => RTC_INTERFACE::RTC_E_LOCAL_PHONE_NEEDED,
            "RTC_E_NO_DEVICE" => RTC_INTERFACE::RTC_E_NO_DEVICE,
            "RTC_E_INVALID_PROFILE" => RTC_INTERFACE::RTC_E_INVALID_PROFILE,
            "RTC_E_PROFILE_NO_PROVISION" => RTC_INTERFACE::RTC_E_PROFILE_NO_PROVISION,
            "RTC_E_PROFILE_NO_KEY" => RTC_INTERFACE::RTC_E_PROFILE_NO_KEY,
            "RTC_E_PROFILE_NO_NAME" => RTC_INTERFACE::RTC_E_PROFILE_NO_NAME,
            "RTC_E_PROFILE_NO_USER" => RTC_INTERFACE::RTC_E_PROFILE_NO_USER,
            "RTC_E_PROFILE_NO_USER_URI" => RTC_INTERFACE::RTC_E_PROFILE_NO_USER_URI,
            "RTC_E_PROFILE_NO_SERVER" => RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER,
            "RTC_E_PROFILE_NO_SERVER_ADDRESS" => RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_ADDRESS,
            "RTC_E_PROFILE_NO_SERVER_PROTOCOL" => RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_PROTOCOL,
            "RTC_E_PROFILE_INVALID_SERVER_PROTOCOL" => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_PROTOCOL,
            "RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD" => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD,
            "RTC_E_PROFILE_INVALID_SERVER_ROLE" => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_ROLE,
            "RTC_E_PROFILE_MULTIPLE_REGISTRARS" => RTC_INTERFACE::RTC_E_PROFILE_MULTIPLE_REGISTRARS,
            "RTC_E_PROFILE_INVALID_SESSION" => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION,
            "RTC_E_PROFILE_INVALID_SESSION_PARTY" => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_PARTY,
            "RTC_E_PROFILE_INVALID_SESSION_TYPE" => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_TYPE,
            "RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS" => RTC_INTERFACE::RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS,
            "RTC_E_BASIC_AUTH_SET_TLS" => RTC_INTERFACE::RTC_E_BASIC_AUTH_SET_TLS,
            "RTC_E_SIP_HIGH_SECURITY_SET_TLS" => RTC_INTERFACE::RTC_E_SIP_HIGH_SECURITY_SET_TLS,
            "RTC_E_PROFILE_SERVER_UNAUTHORIZED" => RTC_INTERFACE::RTC_E_PROFILE_SERVER_UNAUTHORIZED,
            "RTC_E_DUPLICATE_REALM" => RTC_INTERFACE::RTC_E_DUPLICATE_REALM,
            "RTC_E_POLICY_NOT_ALLOW" => RTC_INTERFACE::RTC_E_POLICY_NOT_ALLOW,
            "RTC_E_PORT_MAPPING_UNAVAILABLE" => RTC_INTERFACE::RTC_E_PORT_MAPPING_UNAVAILABLE,
            "RTC_E_PORT_MAPPING_FAILED" => RTC_INTERFACE::RTC_E_PORT_MAPPING_FAILED,
            "RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE" => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE,
            "RTC_E_SECURITY_LEVEL_NOT_DEFINED" => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_DEFINED,
            "RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT" => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT,
            "RTC_E_DUPLICATE_BUDDY" => RTC_INTERFACE::RTC_E_DUPLICATE_BUDDY,
            "RTC_E_DUPLICATE_WATCHER" => RTC_INTERFACE::RTC_E_DUPLICATE_WATCHER,
            "RTC_E_MALFORMED_XML" => RTC_INTERFACE::RTC_E_MALFORMED_XML,
            "RTC_E_ROAMING_OPERATION_INTERRUPTED" => RTC_INTERFACE::RTC_E_ROAMING_OPERATION_INTERRUPTED,
            "RTC_E_ROAMING_FAILED" => RTC_INTERFACE::RTC_E_ROAMING_FAILED,
            "RTC_E_INVALID_BUDDY_LIST" => RTC_INTERFACE::RTC_E_INVALID_BUDDY_LIST,
            "RTC_E_INVALID_ACL_LIST" => RTC_INTERFACE::RTC_E_INVALID_ACL_LIST,
            "RTC_E_NO_GROUP" => RTC_INTERFACE::RTC_E_NO_GROUP,
            "RTC_E_DUPLICATE_GROUP" => RTC_INTERFACE::RTC_E_DUPLICATE_GROUP,
            "RTC_E_TOO_MANY_GROUPS" => RTC_INTERFACE::RTC_E_TOO_MANY_GROUPS,
            "RTC_E_NO_BUDDY" => RTC_INTERFACE::RTC_E_NO_BUDDY,
            "RTC_E_NO_WATCHER" => RTC_INTERFACE::RTC_E_NO_WATCHER,
            "RTC_E_NO_REALM" => RTC_INTERFACE::RTC_E_NO_REALM,
            "RTC_E_NO_TRANSPORT" => RTC_INTERFACE::RTC_E_NO_TRANSPORT,
            "RTC_E_NOT_EXIST" => RTC_INTERFACE::RTC_E_NOT_EXIST,
            "RTC_E_INVALID_PREFERENCE_LIST" => RTC_INTERFACE::RTC_E_INVALID_PREFERENCE_LIST,
            "RTC_E_MAX_PENDING_OPERATIONS" => RTC_INTERFACE::RTC_E_MAX_PENDING_OPERATIONS,
            "RTC_E_TOO_MANY_RETRIES" => RTC_INTERFACE::RTC_E_TOO_MANY_RETRIES,
            "RTC_E_INVALID_PORTRANGE" => RTC_INTERFACE::RTC_E_INVALID_PORTRANGE,
            "RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED" => RTC_INTERFACE::RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED,
            "RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION" => RTC_INTERFACE::RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION,
            "RTC_E_SIP_PARTY_ALREADY_IN_SESSION" => RTC_INTERFACE::RTC_E_SIP_PARTY_ALREADY_IN_SESSION,
            "RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS" => RTC_INTERFACE::RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS,
            "RTC_E_INVALID_OBJECT_STATE" => RTC_INTERFACE::RTC_E_INVALID_OBJECT_STATE,
            "RTC_E_PRESENCE_ENABLED" => RTC_INTERFACE::RTC_E_PRESENCE_ENABLED,
            "RTC_E_ROAMING_ENABLED" => RTC_INTERFACE::RTC_E_ROAMING_ENABLED,
            "RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION" => RTC_INTERFACE::RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION,
            "RTC_E_SIP_INVALID_CERTIFICATE" => RTC_INTERFACE::RTC_E_SIP_INVALID_CERTIFICATE,
            "RTC_E_SIP_DNS_FAIL" => RTC_INTERFACE::RTC_E_SIP_DNS_FAIL,
            "RTC_E_SIP_TCP_FAIL" => RTC_INTERFACE::RTC_E_SIP_TCP_FAIL,
            "RTC_E_TOO_SMALL_EXPIRES_VALUE" => RTC_INTERFACE::RTC_E_TOO_SMALL_EXPIRES_VALUE,
            "RTC_E_SIP_TLS_FAIL" => RTC_INTERFACE::RTC_E_SIP_TLS_FAIL,
            "RTC_E_NOT_PRESENCE_PROFILE" => RTC_INTERFACE::RTC_E_NOT_PRESENCE_PROFILE,
            "RTC_E_SIP_INVITEE_PARTY_TIMEOUT" => RTC_INTERFACE::RTC_E_SIP_INVITEE_PARTY_TIMEOUT,
            "RTC_E_SIP_AUTH_TIME_SKEW" => RTC_INTERFACE::RTC_E_SIP_AUTH_TIME_SKEW,
            "RTC_E_INVALID_REGISTRATION_STATE" => RTC_INTERFACE::RTC_E_INVALID_REGISTRATION_STATE,
            "RTC_E_MEDIA_DISABLED" => RTC_INTERFACE::RTC_E_MEDIA_DISABLED,
            "RTC_E_MEDIA_ENABLED" => RTC_INTERFACE::RTC_E_MEDIA_ENABLED,
            "RTC_E_REFER_NOT_ACCEPTED" => RTC_INTERFACE::RTC_E_REFER_NOT_ACCEPTED,
            "RTC_E_REFER_NOT_ALLOWED" => RTC_INTERFACE::RTC_E_REFER_NOT_ALLOWED,
            "RTC_E_REFER_NOT_EXIST" => RTC_INTERFACE::RTC_E_REFER_NOT_EXIST,
            "RTC_E_SIP_HOLD_OPERATION_PENDING" => RTC_INTERFACE::RTC_E_SIP_HOLD_OPERATION_PENDING,
            "RTC_E_SIP_UNHOLD_OPERATION_PENDING" => RTC_INTERFACE::RTC_E_SIP_UNHOLD_OPERATION_PENDING,
            "RTC_E_MEDIA_SESSION_NOT_EXIST" => RTC_INTERFACE::RTC_E_MEDIA_SESSION_NOT_EXIST,
            "RTC_E_MEDIA_SESSION_IN_HOLD" => RTC_INTERFACE::RTC_E_MEDIA_SESSION_IN_HOLD,
            "RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE" => RTC_INTERFACE::RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE,
            "RTC_E_MAX_REDIRECTS" => RTC_INTERFACE::RTC_E_MAX_REDIRECTS,
            "RTC_E_REDIRECT_PROCESSING_FAILED" => RTC_INTERFACE::RTC_E_REDIRECT_PROCESSING_FAILED,
            "RTC_E_LISTENING_SOCKET_NOT_EXIST" => RTC_INTERFACE::RTC_E_LISTENING_SOCKET_NOT_EXIST,
            "RTC_E_INVALID_LISTEN_SOCKET" => RTC_INTERFACE::RTC_E_INVALID_LISTEN_SOCKET,
            "RTC_E_PORT_MANAGER_ALREADY_SET" => RTC_INTERFACE::RTC_E_PORT_MANAGER_ALREADY_SET,
            "RTC_E_SECURITY_LEVEL_ALREADY_SET" => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_ALREADY_SET,
            "RTC_E_UDP_NOT_SUPPORTED" => RTC_INTERFACE::RTC_E_UDP_NOT_SUPPORTED,
            "RTC_E_SIP_REFER_OPERATION_PENDING" => RTC_INTERFACE::RTC_E_SIP_REFER_OPERATION_PENDING,
            "RTC_E_PLATFORM_NOT_SUPPORTED" => RTC_INTERFACE::RTC_E_PLATFORM_NOT_SUPPORTED,
            "RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION" => RTC_INTERFACE::RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION,
            "RTC_E_NOT_ALLOWED" => RTC_INTERFACE::RTC_E_NOT_ALLOWED,
            "RTC_E_REGISTRATION_DEACTIVATED" => RTC_INTERFACE::RTC_E_REGISTRATION_DEACTIVATED,
            "RTC_E_REGISTRATION_REJECTED" => RTC_INTERFACE::RTC_E_REGISTRATION_REJECTED,
            "RTC_E_REGISTRATION_UNREGISTERED" => RTC_INTERFACE::RTC_E_REGISTRATION_UNREGISTERED,
        }
    }
    pub fn from_code(code: u32) -> RTC_INTERFACE {
        return match code {
            0x00EE0041 => RTC_INTERFACE::RTC_S_ROAMING_NOT_SUPPORTED,
            0x80EE0000 => RTC_INTERFACE::RTC_E_SIP_CODECS_DO_NOT_MATCH,
            0x80EE0001 => RTC_INTERFACE::RTC_E_SIP_STREAM_PRESENT,
            0x80EE0002 => RTC_INTERFACE::RTC_E_SIP_STREAM_NOT_PRESENT,
            0x80EE0003 => RTC_INTERFACE::RTC_E_SIP_NO_STREAM,
            0x80EE0004 => RTC_INTERFACE::RTC_E_SIP_PARSE_FAILED,
            0x80EE0005 => RTC_INTERFACE::RTC_E_SIP_HEADER_NOT_PRESENT,
            0x80EE0006 => RTC_INTERFACE::RTC_E_SDP_NOT_PRESENT,
            0x80EE0007 => RTC_INTERFACE::RTC_E_SDP_PARSE_FAILED,
            0x80EE0008 => RTC_INTERFACE::RTC_E_SDP_UPDATE_FAILED,
            0x80EE0009 => RTC_INTERFACE::RTC_E_SDP_MULTICAST,
            0x80EE000A => RTC_INTERFACE::RTC_E_SDP_CONNECTION_ADDR,
            0x80EE000B => RTC_INTERFACE::RTC_E_SDP_NO_MEDIA,
            0x80EE000C => RTC_INTERFACE::RTC_E_SIP_TIMEOUT,
            0x80EE000D => RTC_INTERFACE::RTC_E_SDP_FAILED_TO_BUILD,
            0x80EE000E => RTC_INTERFACE::RTC_E_SIP_INVITE_TRANSACTION_PENDING,
            0x80EE000F => RTC_INTERFACE::RTC_E_SIP_AUTH_HEADER_SENT,
            0x80EE0010 => RTC_INTERFACE::RTC_E_SIP_AUTH_TYPE_NOT_SUPPORTED,
            0x80EE0011 => RTC_INTERFACE::RTC_E_SIP_AUTH_FAILED,
            0x80EE0012 => RTC_INTERFACE::RTC_E_INVALID_SIP_URL,
            0x80EE0013 => RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_LOCAL,
            0x80EE0014 => RTC_INTERFACE::RTC_E_INVALID_ADDRESS_LOCAL,
            0x80EE0015 => RTC_INTERFACE::RTC_E_DESTINATION_ADDRESS_MULTICAST,
            0x80EE0016 => RTC_INTERFACE::RTC_E_INVALID_PROXY_ADDRESS,
            0x80EE0017 => RTC_INTERFACE::RTC_E_SIP_TRANSPORT_NOT_SUPPORTED,
            0x80EE0018 => RTC_INTERFACE::RTC_E_SIP_NEED_MORE_DATA,
            0x80EE0019 => RTC_INTERFACE::RTC_E_SIP_CALL_DISCONNECTED,
            0x80EE001A => RTC_INTERFACE::RTC_E_SIP_REQUEST_DESTINATION_ADDR_NOT_PRESENT,
            0x80EE001B => RTC_INTERFACE::RTC_E_SIP_UDP_SIZE_EXCEEDED,
            0x80EE001C => RTC_INTERFACE::RTC_E_SIP_SSL_TUNNEL_FAILED,
            0x80EE001D => RTC_INTERFACE::RTC_E_SIP_SSL_NEGOTIATION_TIMEOUT,
            0x80EE001E => RTC_INTERFACE::RTC_E_SIP_STACK_SHUTDOWN,
            0x80EE001F => RTC_INTERFACE::RTC_E_MEDIA_CONTROLLER_STATE,
            0x80EE0020 => RTC_INTERFACE::RTC_E_MEDIA_NEED_TERMINAL,
            0x80EE0021 => RTC_INTERFACE::RTC_E_MEDIA_AUDIO_DEVICE_NOT_AVAILABLE,
            0x80EE0022 => RTC_INTERFACE::RTC_E_MEDIA_VIDEO_DEVICE_NOT_AVAILABLE,
            0x80EE0023 => RTC_INTERFACE::RTC_E_START_STREAM,
            0x80EE0024 => RTC_INTERFACE::RTC_E_MEDIA_AEC,
            0x80EE0025 => RTC_INTERFACE::RTC_E_CLIENT_NOT_INITIALIZED,
            0x80EE0026 => RTC_INTERFACE::RTC_E_CLIENT_ALREADY_INITIALIZED,
            0x80EE0027 => RTC_INTERFACE::RTC_E_CLIENT_ALREADY_SHUT_DOWN,
            0x80EE0028 => RTC_INTERFACE::RTC_E_PRESENCE_NOT_ENABLED,
            0x80EE0029 => RTC_INTERFACE::RTC_E_INVALID_SESSION_TYPE,
            0x80EE002A => RTC_INTERFACE::RTC_E_INVALID_SESSION_STATE,
            0x80EE002B => RTC_INTERFACE::RTC_E_NO_PROFILE,
            0x80EE002C => RTC_INTERFACE::RTC_E_LOCAL_PHONE_NEEDED,
            0x80EE002D => RTC_INTERFACE::RTC_E_NO_DEVICE,
            0x80EE002E => RTC_INTERFACE::RTC_E_INVALID_PROFILE,
            0x80EE002F => RTC_INTERFACE::RTC_E_PROFILE_NO_PROVISION,
            0x80EE0030 => RTC_INTERFACE::RTC_E_PROFILE_NO_KEY,
            0x80EE0031 => RTC_INTERFACE::RTC_E_PROFILE_NO_NAME,
            0x80EE0032 => RTC_INTERFACE::RTC_E_PROFILE_NO_USER,
            0x80EE0033 => RTC_INTERFACE::RTC_E_PROFILE_NO_USER_URI,
            0x80EE0034 => RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER,
            0x80EE0035 => RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_ADDRESS,
            0x80EE0036 => RTC_INTERFACE::RTC_E_PROFILE_NO_SERVER_PROTOCOL,
            0x80EE0037 => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_PROTOCOL,
            0x80EE0038 => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_AUTHMETHOD,
            0x80EE0039 => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SERVER_ROLE,
            0x80EE003A => RTC_INTERFACE::RTC_E_PROFILE_MULTIPLE_REGISTRARS,
            0x80EE003B => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION,
            0x80EE003C => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_PARTY,
            0x80EE003D => RTC_INTERFACE::RTC_E_PROFILE_INVALID_SESSION_TYPE,
            0x80EE003E => RTC_INTERFACE::RTC_E_OPERATION_WITH_TOO_MANY_PARTICIPANTS,
            0x80EE003F => RTC_INTERFACE::RTC_E_BASIC_AUTH_SET_TLS,
            0x80EE0040 => RTC_INTERFACE::RTC_E_SIP_HIGH_SECURITY_SET_TLS,
            0x80EE0042 => RTC_INTERFACE::RTC_E_PROFILE_SERVER_UNAUTHORIZED,
            0x80EE0043 => RTC_INTERFACE::RTC_E_DUPLICATE_REALM,
            0x80EE0044 => RTC_INTERFACE::RTC_E_POLICY_NOT_ALLOW,
            0x80EE0045 => RTC_INTERFACE::RTC_E_PORT_MAPPING_UNAVAILABLE,
            0x80EE0046 => RTC_INTERFACE::RTC_E_PORT_MAPPING_FAILED,
            0x80EE0047 => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_COMPATIBLE,
            0x80EE0048 => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_DEFINED,
            0x80EE0049 => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_NOT_SUPPORTED_BY_PARTICIPANT,
            0x80EE004A => RTC_INTERFACE::RTC_E_DUPLICATE_BUDDY,
            0x80EE004B => RTC_INTERFACE::RTC_E_DUPLICATE_WATCHER,
            0x80EE004C => RTC_INTERFACE::RTC_E_MALFORMED_XML,
            0x80EE004D => RTC_INTERFACE::RTC_E_ROAMING_OPERATION_INTERRUPTED,
            0x80EE004E => RTC_INTERFACE::RTC_E_ROAMING_FAILED,
            0x80EE004F => RTC_INTERFACE::RTC_E_INVALID_BUDDY_LIST,
            0x80EE0050 => RTC_INTERFACE::RTC_E_INVALID_ACL_LIST,
            0x80EE0051 => RTC_INTERFACE::RTC_E_NO_GROUP,
            0x80EE0052 => RTC_INTERFACE::RTC_E_DUPLICATE_GROUP,
            0x80EE0053 => RTC_INTERFACE::RTC_E_TOO_MANY_GROUPS,
            0x80EE0054 => RTC_INTERFACE::RTC_E_NO_BUDDY,
            0x80EE0055 => RTC_INTERFACE::RTC_E_NO_WATCHER,
            0x80EE0056 => RTC_INTERFACE::RTC_E_NO_REALM,
            0x80EE0057 => RTC_INTERFACE::RTC_E_NO_TRANSPORT,
            0x80EE0058 => RTC_INTERFACE::RTC_E_NOT_EXIST,
            0x80EE0059 => RTC_INTERFACE::RTC_E_INVALID_PREFERENCE_LIST,
            0x80EE005A => RTC_INTERFACE::RTC_E_MAX_PENDING_OPERATIONS,
            0x80EE005B => RTC_INTERFACE::RTC_E_TOO_MANY_RETRIES,
            0x80EE005C => RTC_INTERFACE::RTC_E_INVALID_PORTRANGE,
            0x80EE005D => RTC_INTERFACE::RTC_E_SIP_CALL_CONNECTION_NOT_ESTABLISHED,
            0x80EE005E => RTC_INTERFACE::RTC_E_SIP_ADDITIONAL_PARTY_IN_TWO_PARTY_SESSION,
            0x80EE005F => RTC_INTERFACE::RTC_E_SIP_PARTY_ALREADY_IN_SESSION,
            0x80EE0060 => RTC_INTERFACE::RTC_E_SIP_OTHER_PARTY_JOIN_IN_PROGRESS,
            0x80EE0061 => RTC_INTERFACE::RTC_E_INVALID_OBJECT_STATE,
            0x80EE0062 => RTC_INTERFACE::RTC_E_PRESENCE_ENABLED,
            0x80EE0063 => RTC_INTERFACE::RTC_E_ROAMING_ENABLED,
            0x80EE0064 => RTC_INTERFACE::RTC_E_SIP_TLS_INCOMPATIBLE_ENCRYPTION,
            0x80EE0065 => RTC_INTERFACE::RTC_E_SIP_INVALID_CERTIFICATE,
            0x80EE0066 => RTC_INTERFACE::RTC_E_SIP_DNS_FAIL,
            0x80EE0067 => RTC_INTERFACE::RTC_E_SIP_TCP_FAIL,
            0x80EE0068 => RTC_INTERFACE::RTC_E_TOO_SMALL_EXPIRES_VALUE,
            0x80EE0069 => RTC_INTERFACE::RTC_E_SIP_TLS_FAIL,
            0x80EE006A => RTC_INTERFACE::RTC_E_NOT_PRESENCE_PROFILE,
            0x80EE006B => RTC_INTERFACE::RTC_E_SIP_INVITEE_PARTY_TIMEOUT,
            0x80EE006C => RTC_INTERFACE::RTC_E_SIP_AUTH_TIME_SKEW,
            0x80EE006D => RTC_INTERFACE::RTC_E_INVALID_REGISTRATION_STATE,
            0x80EE006E => RTC_INTERFACE::RTC_E_MEDIA_DISABLED,
            0x80EE006F => RTC_INTERFACE::RTC_E_MEDIA_ENABLED,
            0x80EE0070 => RTC_INTERFACE::RTC_E_REFER_NOT_ACCEPTED,
            0x80EE0071 => RTC_INTERFACE::RTC_E_REFER_NOT_ALLOWED,
            0x80EE0072 => RTC_INTERFACE::RTC_E_REFER_NOT_EXIST,
            0x80EE0073 => RTC_INTERFACE::RTC_E_SIP_HOLD_OPERATION_PENDING,
            0x80EE0074 => RTC_INTERFACE::RTC_E_SIP_UNHOLD_OPERATION_PENDING,
            0x80EE0075 => RTC_INTERFACE::RTC_E_MEDIA_SESSION_NOT_EXIST,
            0x80EE0076 => RTC_INTERFACE::RTC_E_MEDIA_SESSION_IN_HOLD,
            0x80EE0077 => RTC_INTERFACE::RTC_E_ANOTHER_MEDIA_SESSION_ACTIVE,
            0x80EE0078 => RTC_INTERFACE::RTC_E_MAX_REDIRECTS,
            0x80EE0079 => RTC_INTERFACE::RTC_E_REDIRECT_PROCESSING_FAILED,
            0x80EE007A => RTC_INTERFACE::RTC_E_LISTENING_SOCKET_NOT_EXIST,
            0x80EE007B => RTC_INTERFACE::RTC_E_INVALID_LISTEN_SOCKET,
            0x80EE007C => RTC_INTERFACE::RTC_E_PORT_MANAGER_ALREADY_SET,
            0x80EE007D => RTC_INTERFACE::RTC_E_SECURITY_LEVEL_ALREADY_SET,
            0x80EE007E => RTC_INTERFACE::RTC_E_UDP_NOT_SUPPORTED,
            0x80EE007F => RTC_INTERFACE::RTC_E_SIP_REFER_OPERATION_PENDING,
            0x80EE0080 => RTC_INTERFACE::RTC_E_PLATFORM_NOT_SUPPORTED,
            0x80EE0081 => RTC_INTERFACE::RTC_E_SIP_PEER_PARTICIPANT_IN_MULTIPARTY_SESSION,
            0x80EE0082 => RTC_INTERFACE::RTC_E_NOT_ALLOWED,
            0x80EE0083 => RTC_INTERFACE::RTC_E_REGISTRATION_DEACTIVATED,
            0x80EE0084 => RTC_INTERFACE::RTC_E_REGISTRATION_REJECTED,
            0x80EE0085 => RTC_INTERFACE::RTC_E_REGISTRATION_UNREGISTERED,
        }
    }
}
