/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum SCARD {
    SCARD_F_INTERNAL_ERROR,
    SCARD_E_CANCELLED,
    SCARD_E_INVALID_HANDLE,
    SCARD_E_INVALID_PARAMETER,
    SCARD_E_INVALID_TARGET,
    SCARD_E_NO_MEMORY,
    SCARD_F_WAITED_TOO_LONG,
    SCARD_E_INSUFFICIENT_BUFFER,
    SCARD_E_UNKNOWN_READER,
    SCARD_E_TIMEOUT,
    SCARD_E_SHARING_VIOLATION,
    SCARD_E_NO_SMARTCARD,
    SCARD_E_UNKNOWN_CARD,
    SCARD_E_CANT_DISPOSE,
    SCARD_E_PROTO_MISMATCH,
    SCARD_E_NOT_READY,
    SCARD_E_INVALID_VALUE,
    SCARD_E_SYSTEM_CANCELLED,
    SCARD_F_COMM_ERROR,
    SCARD_F_UNKNOWN_ERROR,
    SCARD_E_INVALID_ATR,
    SCARD_E_NOT_TRANSACTED,
    SCARD_E_READER_UNAVAILABLE,
    SCARD_P_SHUTDOWN,
    SCARD_E_PCI_TOO_SMALL,
    SCARD_E_READER_UNSUPPORTED,
    SCARD_E_DUPLICATE_READER,
    SCARD_E_CARD_UNSUPPORTED,
    SCARD_E_NO_SERVICE,
    SCARD_E_SERVICE_STOPPED,
    SCARD_E_UNEXPECTED,
    SCARD_E_ICC_INSTALLATION,
    SCARD_E_ICC_CREATEORDER,
    SCARD_E_UNSUPPORTED_FEATURE,
    SCARD_E_DIR_NOT_FOUND,
    SCARD_E_FILE_NOT_FOUND,
    SCARD_E_NO_DIR,
    SCARD_E_NO_FILE,
    SCARD_E_NO_ACCESS,
    SCARD_E_WRITE_TOO_MANY,
    SCARD_E_BAD_SEEK,
    SCARD_E_INVALID_CHV,
    SCARD_E_UNKNOWN_RES_MNG,
    SCARD_E_NO_SUCH_CERTIFICATE,
    SCARD_E_CERTIFICATE_UNAVAILABLE,
    SCARD_E_NO_READERS_AVAILABLE,
    SCARD_E_COMM_DATA_LOST,
    SCARD_E_NO_KEY_CONTAINER,
    SCARD_E_SERVER_TOO_BUSY,
    SCARD_E_PIN_CACHE_EXPIRED,
    SCARD_E_NO_PIN_CACHE,
    SCARD_E_READ_ONLY_CARD,
    SCARD_W_UNSUPPORTED_CARD,
    SCARD_W_UNRESPONSIVE_CARD,
    SCARD_W_UNPOWERED_CARD,
    SCARD_W_RESET_CARD,
    SCARD_W_REMOVED_CARD,
    SCARD_W_SECURITY_VIOLATION,
    SCARD_W_WRONG_CHV,
    SCARD_W_CHV_BLOCKED,
    SCARD_W_EOF,
    SCARD_W_CANCELLED_BY_USER,
    SCARD_W_CARD_NOT_AUTHENTICATED,
    SCARD_W_CACHE_ITEM_NOT_FOUND,
    SCARD_W_CACHE_ITEM_STALE,
    SCARD_W_CACHE_ITEM_TOO_BIG,
}

impl SCARD {
    pub fn code(&self) -> u32 {
        return match self {
            SCARD::SCARD_F_INTERNAL_ERROR => 0x80100001 as u32,
            SCARD::SCARD_E_CANCELLED => 0x80100002 as u32,
            SCARD::SCARD_E_INVALID_HANDLE => 0x80100003 as u32,
            SCARD::SCARD_E_INVALID_PARAMETER => 0x80100004 as u32,
            SCARD::SCARD_E_INVALID_TARGET => 0x80100005 as u32,
            SCARD::SCARD_E_NO_MEMORY => 0x80100006 as u32,
            SCARD::SCARD_F_WAITED_TOO_LONG => 0x80100007 as u32,
            SCARD::SCARD_E_INSUFFICIENT_BUFFER => 0x80100008 as u32,
            SCARD::SCARD_E_UNKNOWN_READER => 0x80100009 as u32,
            SCARD::SCARD_E_TIMEOUT => 0x8010000A as u32,
            SCARD::SCARD_E_SHARING_VIOLATION => 0x8010000B as u32,
            SCARD::SCARD_E_NO_SMARTCARD => 0x8010000C as u32,
            SCARD::SCARD_E_UNKNOWN_CARD => 0x8010000D as u32,
            SCARD::SCARD_E_CANT_DISPOSE => 0x8010000E as u32,
            SCARD::SCARD_E_PROTO_MISMATCH => 0x8010000F as u32,
            SCARD::SCARD_E_NOT_READY => 0x80100010 as u32,
            SCARD::SCARD_E_INVALID_VALUE => 0x80100011 as u32,
            SCARD::SCARD_E_SYSTEM_CANCELLED => 0x80100012 as u32,
            SCARD::SCARD_F_COMM_ERROR => 0x80100013 as u32,
            SCARD::SCARD_F_UNKNOWN_ERROR => 0x80100014 as u32,
            SCARD::SCARD_E_INVALID_ATR => 0x80100015 as u32,
            SCARD::SCARD_E_NOT_TRANSACTED => 0x80100016 as u32,
            SCARD::SCARD_E_READER_UNAVAILABLE => 0x80100017 as u32,
            SCARD::SCARD_P_SHUTDOWN => 0x80100018 as u32,
            SCARD::SCARD_E_PCI_TOO_SMALL => 0x80100019 as u32,
            SCARD::SCARD_E_READER_UNSUPPORTED => 0x8010001A as u32,
            SCARD::SCARD_E_DUPLICATE_READER => 0x8010001B as u32,
            SCARD::SCARD_E_CARD_UNSUPPORTED => 0x8010001C as u32,
            SCARD::SCARD_E_NO_SERVICE => 0x8010001D as u32,
            SCARD::SCARD_E_SERVICE_STOPPED => 0x8010001E as u32,
            SCARD::SCARD_E_UNEXPECTED => 0x8010001F as u32,
            SCARD::SCARD_E_ICC_INSTALLATION => 0x80100020 as u32,
            SCARD::SCARD_E_ICC_CREATEORDER => 0x80100021 as u32,
            SCARD::SCARD_E_UNSUPPORTED_FEATURE => 0x80100022 as u32,
            SCARD::SCARD_E_DIR_NOT_FOUND => 0x80100023 as u32,
            SCARD::SCARD_E_FILE_NOT_FOUND => 0x80100024 as u32,
            SCARD::SCARD_E_NO_DIR => 0x80100025 as u32,
            SCARD::SCARD_E_NO_FILE => 0x80100026 as u32,
            SCARD::SCARD_E_NO_ACCESS => 0x80100027 as u32,
            SCARD::SCARD_E_WRITE_TOO_MANY => 0x80100028 as u32,
            SCARD::SCARD_E_BAD_SEEK => 0x80100029 as u32,
            SCARD::SCARD_E_INVALID_CHV => 0x8010002A as u32,
            SCARD::SCARD_E_UNKNOWN_RES_MNG => 0x8010002B as u32,
            SCARD::SCARD_E_NO_SUCH_CERTIFICATE => 0x8010002C as u32,
            SCARD::SCARD_E_CERTIFICATE_UNAVAILABLE => 0x8010002D as u32,
            SCARD::SCARD_E_NO_READERS_AVAILABLE => 0x8010002E as u32,
            SCARD::SCARD_E_COMM_DATA_LOST => 0x8010002F as u32,
            SCARD::SCARD_E_NO_KEY_CONTAINER => 0x80100030 as u32,
            SCARD::SCARD_E_SERVER_TOO_BUSY => 0x80100031 as u32,
            SCARD::SCARD_E_PIN_CACHE_EXPIRED => 0x80100032 as u32,
            SCARD::SCARD_E_NO_PIN_CACHE => 0x80100033 as u32,
            SCARD::SCARD_E_READ_ONLY_CARD => 0x80100034 as u32,
            SCARD::SCARD_W_UNSUPPORTED_CARD => 0x80100065 as u32,
            SCARD::SCARD_W_UNRESPONSIVE_CARD => 0x80100066 as u32,
            SCARD::SCARD_W_UNPOWERED_CARD => 0x80100067 as u32,
            SCARD::SCARD_W_RESET_CARD => 0x80100068 as u32,
            SCARD::SCARD_W_REMOVED_CARD => 0x80100069 as u32,
            SCARD::SCARD_W_SECURITY_VIOLATION => 0x8010006A as u32,
            SCARD::SCARD_W_WRONG_CHV => 0x8010006B as u32,
            SCARD::SCARD_W_CHV_BLOCKED => 0x8010006C as u32,
            SCARD::SCARD_W_EOF => 0x8010006D as u32,
            SCARD::SCARD_W_CANCELLED_BY_USER => 0x8010006E as u32,
            SCARD::SCARD_W_CARD_NOT_AUTHENTICATED => 0x8010006F as u32,
            SCARD::SCARD_W_CACHE_ITEM_NOT_FOUND => 0x80100070 as u32,
            SCARD::SCARD_W_CACHE_ITEM_STALE => 0x80100071 as u32,
            SCARD::SCARD_W_CACHE_ITEM_TOO_BIG => 0x80100072 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            SCARD::SCARD_F_INTERNAL_ERROR => RawError::Kind(SCARD::SCARD_F_INTERNAL_ERROR),
            SCARD::SCARD_E_CANCELLED => RawError::Kind(SCARD::SCARD_E_CANCELLED),
            SCARD::SCARD_E_INVALID_HANDLE => RawError::Kind(SCARD::SCARD_E_INVALID_HANDLE),
            SCARD::SCARD_E_INVALID_PARAMETER => RawError::Kind(SCARD::SCARD_E_INVALID_PARAMETER),
            SCARD::SCARD_E_INVALID_TARGET => RawError::Kind(SCARD::SCARD_E_INVALID_TARGET),
            SCARD::SCARD_E_NO_MEMORY => RawError::Kind(SCARD::SCARD_E_NO_MEMORY),
            SCARD::SCARD_F_WAITED_TOO_LONG => RawError::Kind(SCARD::SCARD_F_WAITED_TOO_LONG),
            SCARD::SCARD_E_INSUFFICIENT_BUFFER => RawError::Kind(SCARD::SCARD_E_INSUFFICIENT_BUFFER),
            SCARD::SCARD_E_UNKNOWN_READER => RawError::Kind(SCARD::SCARD_E_UNKNOWN_READER),
            SCARD::SCARD_E_TIMEOUT => RawError::Kind(SCARD::SCARD_E_TIMEOUT),
            SCARD::SCARD_E_SHARING_VIOLATION => RawError::Kind(SCARD::SCARD_E_SHARING_VIOLATION),
            SCARD::SCARD_E_NO_SMARTCARD => RawError::Kind(SCARD::SCARD_E_NO_SMARTCARD),
            SCARD::SCARD_E_UNKNOWN_CARD => RawError::Kind(SCARD::SCARD_E_UNKNOWN_CARD),
            SCARD::SCARD_E_CANT_DISPOSE => RawError::Kind(SCARD::SCARD_E_CANT_DISPOSE),
            SCARD::SCARD_E_PROTO_MISMATCH => RawError::Kind(SCARD::SCARD_E_PROTO_MISMATCH),
            SCARD::SCARD_E_NOT_READY => RawError::Kind(SCARD::SCARD_E_NOT_READY),
            SCARD::SCARD_E_INVALID_VALUE => RawError::Kind(SCARD::SCARD_E_INVALID_VALUE),
            SCARD::SCARD_E_SYSTEM_CANCELLED => RawError::Kind(SCARD::SCARD_E_SYSTEM_CANCELLED),
            SCARD::SCARD_F_COMM_ERROR => RawError::Kind(SCARD::SCARD_F_COMM_ERROR),
            SCARD::SCARD_F_UNKNOWN_ERROR => RawError::Kind(SCARD::SCARD_F_UNKNOWN_ERROR),
            SCARD::SCARD_E_INVALID_ATR => RawError::Kind(SCARD::SCARD_E_INVALID_ATR),
            SCARD::SCARD_E_NOT_TRANSACTED => RawError::Kind(SCARD::SCARD_E_NOT_TRANSACTED),
            SCARD::SCARD_E_READER_UNAVAILABLE => RawError::Kind(SCARD::SCARD_E_READER_UNAVAILABLE),
            SCARD::SCARD_P_SHUTDOWN => RawError::Kind(SCARD::SCARD_P_SHUTDOWN),
            SCARD::SCARD_E_PCI_TOO_SMALL => RawError::Kind(SCARD::SCARD_E_PCI_TOO_SMALL),
            SCARD::SCARD_E_READER_UNSUPPORTED => RawError::Kind(SCARD::SCARD_E_READER_UNSUPPORTED),
            SCARD::SCARD_E_DUPLICATE_READER => RawError::Kind(SCARD::SCARD_E_DUPLICATE_READER),
            SCARD::SCARD_E_CARD_UNSUPPORTED => RawError::Kind(SCARD::SCARD_E_CARD_UNSUPPORTED),
            SCARD::SCARD_E_NO_SERVICE => RawError::Kind(SCARD::SCARD_E_NO_SERVICE),
            SCARD::SCARD_E_SERVICE_STOPPED => RawError::Kind(SCARD::SCARD_E_SERVICE_STOPPED),
            SCARD::SCARD_E_UNEXPECTED => RawError::Kind(SCARD::SCARD_E_UNEXPECTED),
            SCARD::SCARD_E_ICC_INSTALLATION => RawError::Kind(SCARD::SCARD_E_ICC_INSTALLATION),
            SCARD::SCARD_E_ICC_CREATEORDER => RawError::Kind(SCARD::SCARD_E_ICC_CREATEORDER),
            SCARD::SCARD_E_UNSUPPORTED_FEATURE => RawError::Kind(SCARD::SCARD_E_UNSUPPORTED_FEATURE),
            SCARD::SCARD_E_DIR_NOT_FOUND => RawError::Kind(SCARD::SCARD_E_DIR_NOT_FOUND),
            SCARD::SCARD_E_FILE_NOT_FOUND => RawError::Kind(SCARD::SCARD_E_FILE_NOT_FOUND),
            SCARD::SCARD_E_NO_DIR => RawError::Kind(SCARD::SCARD_E_NO_DIR),
            SCARD::SCARD_E_NO_FILE => RawError::Kind(SCARD::SCARD_E_NO_FILE),
            SCARD::SCARD_E_NO_ACCESS => RawError::Kind(SCARD::SCARD_E_NO_ACCESS),
            SCARD::SCARD_E_WRITE_TOO_MANY => RawError::Kind(SCARD::SCARD_E_WRITE_TOO_MANY),
            SCARD::SCARD_E_BAD_SEEK => RawError::Kind(SCARD::SCARD_E_BAD_SEEK),
            SCARD::SCARD_E_INVALID_CHV => RawError::Kind(SCARD::SCARD_E_INVALID_CHV),
            SCARD::SCARD_E_UNKNOWN_RES_MNG => RawError::Kind(SCARD::SCARD_E_UNKNOWN_RES_MNG),
            SCARD::SCARD_E_NO_SUCH_CERTIFICATE => RawError::Kind(SCARD::SCARD_E_NO_SUCH_CERTIFICATE),
            SCARD::SCARD_E_CERTIFICATE_UNAVAILABLE => RawError::Kind(SCARD::SCARD_E_CERTIFICATE_UNAVAILABLE),
            SCARD::SCARD_E_NO_READERS_AVAILABLE => RawError::Kind(SCARD::SCARD_E_NO_READERS_AVAILABLE),
            SCARD::SCARD_E_COMM_DATA_LOST => RawError::Kind(SCARD::SCARD_E_COMM_DATA_LOST),
            SCARD::SCARD_E_NO_KEY_CONTAINER => RawError::Kind(SCARD::SCARD_E_NO_KEY_CONTAINER),
            SCARD::SCARD_E_SERVER_TOO_BUSY => RawError::Kind(SCARD::SCARD_E_SERVER_TOO_BUSY),
            SCARD::SCARD_E_PIN_CACHE_EXPIRED => RawError::Kind(SCARD::SCARD_E_PIN_CACHE_EXPIRED),
            SCARD::SCARD_E_NO_PIN_CACHE => RawError::Kind(SCARD::SCARD_E_NO_PIN_CACHE),
            SCARD::SCARD_E_READ_ONLY_CARD => RawError::Kind(SCARD::SCARD_E_READ_ONLY_CARD),
            SCARD::SCARD_W_UNSUPPORTED_CARD => RawError::Kind(SCARD::SCARD_W_UNSUPPORTED_CARD),
            SCARD::SCARD_W_UNRESPONSIVE_CARD => RawError::Kind(SCARD::SCARD_W_UNRESPONSIVE_CARD),
            SCARD::SCARD_W_UNPOWERED_CARD => RawError::Kind(SCARD::SCARD_W_UNPOWERED_CARD),
            SCARD::SCARD_W_RESET_CARD => RawError::Kind(SCARD::SCARD_W_RESET_CARD),
            SCARD::SCARD_W_REMOVED_CARD => RawError::Kind(SCARD::SCARD_W_REMOVED_CARD),
            SCARD::SCARD_W_SECURITY_VIOLATION => RawError::Kind(SCARD::SCARD_W_SECURITY_VIOLATION),
            SCARD::SCARD_W_WRONG_CHV => RawError::Kind(SCARD::SCARD_W_WRONG_CHV),
            SCARD::SCARD_W_CHV_BLOCKED => RawError::Kind(SCARD::SCARD_W_CHV_BLOCKED),
            SCARD::SCARD_W_EOF => RawError::Kind(SCARD::SCARD_W_EOF),
            SCARD::SCARD_W_CANCELLED_BY_USER => RawError::Kind(SCARD::SCARD_W_CANCELLED_BY_USER),
            SCARD::SCARD_W_CARD_NOT_AUTHENTICATED => RawError::Kind(SCARD::SCARD_W_CARD_NOT_AUTHENTICATED),
            SCARD::SCARD_W_CACHE_ITEM_NOT_FOUND => RawError::Kind(SCARD::SCARD_W_CACHE_ITEM_NOT_FOUND),
            SCARD::SCARD_W_CACHE_ITEM_STALE => RawError::Kind(SCARD::SCARD_W_CACHE_ITEM_STALE),
            SCARD::SCARD_W_CACHE_ITEM_TOO_BIG => RawError::Kind(SCARD::SCARD_W_CACHE_ITEM_TOO_BIG),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            SCARD::SCARD_F_INTERNAL_ERROR => "An internal consistency check failed.",
            SCARD::SCARD_E_CANCELLED => "The action was cancelled by an SCardCancel request.",
            SCARD::SCARD_E_INVALID_HANDLE => "The supplied handle was invalid.",
            SCARD::SCARD_E_INVALID_PARAMETER => "One or more of the supplied parameters could not be properly interpreted.",
            SCARD::SCARD_E_INVALID_TARGET => "Registry startup information is missing or invalid.",
            SCARD::SCARD_E_NO_MEMORY => "Not enough memory available to complete this command.",
            SCARD::SCARD_F_WAITED_TOO_LONG => "An internal consistency timer has expired.",
            SCARD::SCARD_E_INSUFFICIENT_BUFFER => "The data buffer to receive returned data is too small for the returned data.",
            SCARD::SCARD_E_UNKNOWN_READER => "The specified reader name is not recognized.",
            SCARD::SCARD_E_TIMEOUT => "The user-specified timeout value has expired.",
            SCARD::SCARD_E_SHARING_VIOLATION => "The smart card cannot be accessed because of other connections outstanding.",
            SCARD::SCARD_E_NO_SMARTCARD => "The operation requires a smart card, but no smart card is currently in the device.",
            SCARD::SCARD_E_UNKNOWN_CARD => "The specified smart card name is not recognized.",
            SCARD::SCARD_E_CANT_DISPOSE => "The system could not dispose of the media in the requested manner.",
            SCARD::SCARD_E_PROTO_MISMATCH => "The requested protocols are incompatible with the protocol currently in use with the smart card.",
            SCARD::SCARD_E_NOT_READY => "The reader or smart card is not ready to accept commands.",
            SCARD::SCARD_E_INVALID_VALUE => "One or more of the supplied parameters values could not be properly interpreted.",
            SCARD::SCARD_E_SYSTEM_CANCELLED => "The action was cancelled by the system, presumably to log off or shut down.",
            SCARD::SCARD_F_COMM_ERROR => "An internal communications error has been detected.",
            SCARD::SCARD_F_UNKNOWN_ERROR => "An internal error has been detected, but the source is unknown.",
            SCARD::SCARD_E_INVALID_ATR => "An ATR obtained from the registry is not a valid ATR string.",
            SCARD::SCARD_E_NOT_TRANSACTED => "An attempt was made to end a non-existent transaction.",
            SCARD::SCARD_E_READER_UNAVAILABLE => "The specified reader is not currently available for use.",
            SCARD::SCARD_P_SHUTDOWN => "The operation has been aborted to allow the server application to exit.",
            SCARD::SCARD_E_PCI_TOO_SMALL => "The PCI Receive buffer was too small.",
            SCARD::SCARD_E_READER_UNSUPPORTED => "The reader driver does not meet minimal requirements for support.",
            SCARD::SCARD_E_DUPLICATE_READER => "The reader driver did not produce a unique reader name.",
            SCARD::SCARD_E_CARD_UNSUPPORTED => "The smart card does not meet minimal requirements for support.",
            SCARD::SCARD_E_NO_SERVICE => "The Smart Card Resource Manager is not running.",
            SCARD::SCARD_E_SERVICE_STOPPED => "The Smart Card Resource Manager has shut down.",
            SCARD::SCARD_E_UNEXPECTED => "An unexpected card error has occurred.",
            SCARD::SCARD_E_ICC_INSTALLATION => "No Primary Provider can be found for the smart card.",
            SCARD::SCARD_E_ICC_CREATEORDER => "The requested order of object creation is not supported.",
            SCARD::SCARD_E_UNSUPPORTED_FEATURE => "This smart card does not support the requested feature.",
            SCARD::SCARD_E_DIR_NOT_FOUND => "The identified directory does not exist in the smart card.",
            SCARD::SCARD_E_FILE_NOT_FOUND => "The identified file does not exist in the smart card.",
            SCARD::SCARD_E_NO_DIR => "The supplied path does not represent a smart card directory.",
            SCARD::SCARD_E_NO_FILE => "The supplied path does not represent a smart card file.",
            SCARD::SCARD_E_NO_ACCESS => "Access is denied to this file.",
            SCARD::SCARD_E_WRITE_TOO_MANY => "The smart card does not have enough memory to store the information.",
            SCARD::SCARD_E_BAD_SEEK => "There was an error trying to set the smart card file object pointer.",
            SCARD::SCARD_E_INVALID_CHV => "The supplied PIN is incorrect.",
            SCARD::SCARD_E_UNKNOWN_RES_MNG => "An unrecognized error code was returned from a layered component.",
            SCARD::SCARD_E_NO_SUCH_CERTIFICATE => "The requested certificate does not exist.",
            SCARD::SCARD_E_CERTIFICATE_UNAVAILABLE => "The requested certificate could not be obtained.",
            SCARD::SCARD_E_NO_READERS_AVAILABLE => "Cannot find a smart card reader.",
            SCARD::SCARD_E_COMM_DATA_LOST => "A communications error with the smart card has been detected. Retry the operation.",
            SCARD::SCARD_E_NO_KEY_CONTAINER => "The requested key container does not exist on the smart card.",
            SCARD::SCARD_E_SERVER_TOO_BUSY => "The Smart Card Resource Manager is too busy to complete this operation.",
            SCARD::SCARD_E_PIN_CACHE_EXPIRED => "The smart card PIN cache has expired.",
            SCARD::SCARD_E_NO_PIN_CACHE => "The smart card PIN cannot be cached.",
            SCARD::SCARD_E_READ_ONLY_CARD => "The smart card is read only and cannot be written to.",
            SCARD::SCARD_W_UNSUPPORTED_CARD => "The reader cannot communicate with the smart card, due to ATR configuration conflicts.",
            SCARD::SCARD_W_UNRESPONSIVE_CARD => "The smart card is not responding to a reset.",
            SCARD::SCARD_W_UNPOWERED_CARD => "Power has been removed from the smart card, so that further communication is not possible.",
            SCARD::SCARD_W_RESET_CARD => "The smart card has been reset, so any shared state information is invalid.",
            SCARD::SCARD_W_REMOVED_CARD => "The smart card has been removed, so that further communication is not possible.",
            SCARD::SCARD_W_SECURITY_VIOLATION => "Access was denied because of a security violation.",
            SCARD::SCARD_W_WRONG_CHV => "The card cannot be accessed because the wrong PIN was presented.",
            SCARD::SCARD_W_CHV_BLOCKED => "The card cannot be accessed because the maximum number of PIN entry attempts has been reached.",
            SCARD::SCARD_W_EOF => "The end of the smart card file has been reached.",
            SCARD::SCARD_W_CANCELLED_BY_USER => "The action was cancelled by the user.",
            SCARD::SCARD_W_CARD_NOT_AUTHENTICATED => "No PIN was presented to the smart card.",
            SCARD::SCARD_W_CACHE_ITEM_NOT_FOUND => "The requested item could not be found in the cache.",
            SCARD::SCARD_W_CACHE_ITEM_STALE => "The requested cache item is too old and was deleted from the cache.",
            SCARD::SCARD_W_CACHE_ITEM_TOO_BIG => "The new cache item exceeds the maximum per-item size defined for the cache.",
        }
    }

    pub fn from_name(name: &str) -> SCARD {
        return match name {
            "SCARD_F_INTERNAL_ERROR" => SCARD::SCARD_F_INTERNAL_ERROR,
            "SCARD_E_CANCELLED" => SCARD::SCARD_E_CANCELLED,
            "SCARD_E_INVALID_HANDLE" => SCARD::SCARD_E_INVALID_HANDLE,
            "SCARD_E_INVALID_PARAMETER" => SCARD::SCARD_E_INVALID_PARAMETER,
            "SCARD_E_INVALID_TARGET" => SCARD::SCARD_E_INVALID_TARGET,
            "SCARD_E_NO_MEMORY" => SCARD::SCARD_E_NO_MEMORY,
            "SCARD_F_WAITED_TOO_LONG" => SCARD::SCARD_F_WAITED_TOO_LONG,
            "SCARD_E_INSUFFICIENT_BUFFER" => SCARD::SCARD_E_INSUFFICIENT_BUFFER,
            "SCARD_E_UNKNOWN_READER" => SCARD::SCARD_E_UNKNOWN_READER,
            "SCARD_E_TIMEOUT" => SCARD::SCARD_E_TIMEOUT,
            "SCARD_E_SHARING_VIOLATION" => SCARD::SCARD_E_SHARING_VIOLATION,
            "SCARD_E_NO_SMARTCARD" => SCARD::SCARD_E_NO_SMARTCARD,
            "SCARD_E_UNKNOWN_CARD" => SCARD::SCARD_E_UNKNOWN_CARD,
            "SCARD_E_CANT_DISPOSE" => SCARD::SCARD_E_CANT_DISPOSE,
            "SCARD_E_PROTO_MISMATCH" => SCARD::SCARD_E_PROTO_MISMATCH,
            "SCARD_E_NOT_READY" => SCARD::SCARD_E_NOT_READY,
            "SCARD_E_INVALID_VALUE" => SCARD::SCARD_E_INVALID_VALUE,
            "SCARD_E_SYSTEM_CANCELLED" => SCARD::SCARD_E_SYSTEM_CANCELLED,
            "SCARD_F_COMM_ERROR" => SCARD::SCARD_F_COMM_ERROR,
            "SCARD_F_UNKNOWN_ERROR" => SCARD::SCARD_F_UNKNOWN_ERROR,
            "SCARD_E_INVALID_ATR" => SCARD::SCARD_E_INVALID_ATR,
            "SCARD_E_NOT_TRANSACTED" => SCARD::SCARD_E_NOT_TRANSACTED,
            "SCARD_E_READER_UNAVAILABLE" => SCARD::SCARD_E_READER_UNAVAILABLE,
            "SCARD_P_SHUTDOWN" => SCARD::SCARD_P_SHUTDOWN,
            "SCARD_E_PCI_TOO_SMALL" => SCARD::SCARD_E_PCI_TOO_SMALL,
            "SCARD_E_READER_UNSUPPORTED" => SCARD::SCARD_E_READER_UNSUPPORTED,
            "SCARD_E_DUPLICATE_READER" => SCARD::SCARD_E_DUPLICATE_READER,
            "SCARD_E_CARD_UNSUPPORTED" => SCARD::SCARD_E_CARD_UNSUPPORTED,
            "SCARD_E_NO_SERVICE" => SCARD::SCARD_E_NO_SERVICE,
            "SCARD_E_SERVICE_STOPPED" => SCARD::SCARD_E_SERVICE_STOPPED,
            "SCARD_E_UNEXPECTED" => SCARD::SCARD_E_UNEXPECTED,
            "SCARD_E_ICC_INSTALLATION" => SCARD::SCARD_E_ICC_INSTALLATION,
            "SCARD_E_ICC_CREATEORDER" => SCARD::SCARD_E_ICC_CREATEORDER,
            "SCARD_E_UNSUPPORTED_FEATURE" => SCARD::SCARD_E_UNSUPPORTED_FEATURE,
            "SCARD_E_DIR_NOT_FOUND" => SCARD::SCARD_E_DIR_NOT_FOUND,
            "SCARD_E_FILE_NOT_FOUND" => SCARD::SCARD_E_FILE_NOT_FOUND,
            "SCARD_E_NO_DIR" => SCARD::SCARD_E_NO_DIR,
            "SCARD_E_NO_FILE" => SCARD::SCARD_E_NO_FILE,
            "SCARD_E_NO_ACCESS" => SCARD::SCARD_E_NO_ACCESS,
            "SCARD_E_WRITE_TOO_MANY" => SCARD::SCARD_E_WRITE_TOO_MANY,
            "SCARD_E_BAD_SEEK" => SCARD::SCARD_E_BAD_SEEK,
            "SCARD_E_INVALID_CHV" => SCARD::SCARD_E_INVALID_CHV,
            "SCARD_E_UNKNOWN_RES_MNG" => SCARD::SCARD_E_UNKNOWN_RES_MNG,
            "SCARD_E_NO_SUCH_CERTIFICATE" => SCARD::SCARD_E_NO_SUCH_CERTIFICATE,
            "SCARD_E_CERTIFICATE_UNAVAILABLE" => SCARD::SCARD_E_CERTIFICATE_UNAVAILABLE,
            "SCARD_E_NO_READERS_AVAILABLE" => SCARD::SCARD_E_NO_READERS_AVAILABLE,
            "SCARD_E_COMM_DATA_LOST" => SCARD::SCARD_E_COMM_DATA_LOST,
            "SCARD_E_NO_KEY_CONTAINER" => SCARD::SCARD_E_NO_KEY_CONTAINER,
            "SCARD_E_SERVER_TOO_BUSY" => SCARD::SCARD_E_SERVER_TOO_BUSY,
            "SCARD_E_PIN_CACHE_EXPIRED" => SCARD::SCARD_E_PIN_CACHE_EXPIRED,
            "SCARD_E_NO_PIN_CACHE" => SCARD::SCARD_E_NO_PIN_CACHE,
            "SCARD_E_READ_ONLY_CARD" => SCARD::SCARD_E_READ_ONLY_CARD,
            "SCARD_W_UNSUPPORTED_CARD" => SCARD::SCARD_W_UNSUPPORTED_CARD,
            "SCARD_W_UNRESPONSIVE_CARD" => SCARD::SCARD_W_UNRESPONSIVE_CARD,
            "SCARD_W_UNPOWERED_CARD" => SCARD::SCARD_W_UNPOWERED_CARD,
            "SCARD_W_RESET_CARD" => SCARD::SCARD_W_RESET_CARD,
            "SCARD_W_REMOVED_CARD" => SCARD::SCARD_W_REMOVED_CARD,
            "SCARD_W_SECURITY_VIOLATION" => SCARD::SCARD_W_SECURITY_VIOLATION,
            "SCARD_W_WRONG_CHV" => SCARD::SCARD_W_WRONG_CHV,
            "SCARD_W_CHV_BLOCKED" => SCARD::SCARD_W_CHV_BLOCKED,
            "SCARD_W_EOF" => SCARD::SCARD_W_EOF,
            "SCARD_W_CANCELLED_BY_USER" => SCARD::SCARD_W_CANCELLED_BY_USER,
            "SCARD_W_CARD_NOT_AUTHENTICATED" => SCARD::SCARD_W_CARD_NOT_AUTHENTICATED,
            "SCARD_W_CACHE_ITEM_NOT_FOUND" => SCARD::SCARD_W_CACHE_ITEM_NOT_FOUND,
            "SCARD_W_CACHE_ITEM_STALE" => SCARD::SCARD_W_CACHE_ITEM_STALE,
            "SCARD_W_CACHE_ITEM_TOO_BIG" => SCARD::SCARD_W_CACHE_ITEM_TOO_BIG,
        }
    }
    pub fn from_code(code: u32) -> SCARD {
        return match code {
            0x80100001 => SCARD::SCARD_F_INTERNAL_ERROR,
            0x80100002 => SCARD::SCARD_E_CANCELLED,
            0x80100003 => SCARD::SCARD_E_INVALID_HANDLE,
            0x80100004 => SCARD::SCARD_E_INVALID_PARAMETER,
            0x80100005 => SCARD::SCARD_E_INVALID_TARGET,
            0x80100006 => SCARD::SCARD_E_NO_MEMORY,
            0x80100007 => SCARD::SCARD_F_WAITED_TOO_LONG,
            0x80100008 => SCARD::SCARD_E_INSUFFICIENT_BUFFER,
            0x80100009 => SCARD::SCARD_E_UNKNOWN_READER,
            0x8010000A => SCARD::SCARD_E_TIMEOUT,
            0x8010000B => SCARD::SCARD_E_SHARING_VIOLATION,
            0x8010000C => SCARD::SCARD_E_NO_SMARTCARD,
            0x8010000D => SCARD::SCARD_E_UNKNOWN_CARD,
            0x8010000E => SCARD::SCARD_E_CANT_DISPOSE,
            0x8010000F => SCARD::SCARD_E_PROTO_MISMATCH,
            0x80100010 => SCARD::SCARD_E_NOT_READY,
            0x80100011 => SCARD::SCARD_E_INVALID_VALUE,
            0x80100012 => SCARD::SCARD_E_SYSTEM_CANCELLED,
            0x80100013 => SCARD::SCARD_F_COMM_ERROR,
            0x80100014 => SCARD::SCARD_F_UNKNOWN_ERROR,
            0x80100015 => SCARD::SCARD_E_INVALID_ATR,
            0x80100016 => SCARD::SCARD_E_NOT_TRANSACTED,
            0x80100017 => SCARD::SCARD_E_READER_UNAVAILABLE,
            0x80100018 => SCARD::SCARD_P_SHUTDOWN,
            0x80100019 => SCARD::SCARD_E_PCI_TOO_SMALL,
            0x8010001A => SCARD::SCARD_E_READER_UNSUPPORTED,
            0x8010001B => SCARD::SCARD_E_DUPLICATE_READER,
            0x8010001C => SCARD::SCARD_E_CARD_UNSUPPORTED,
            0x8010001D => SCARD::SCARD_E_NO_SERVICE,
            0x8010001E => SCARD::SCARD_E_SERVICE_STOPPED,
            0x8010001F => SCARD::SCARD_E_UNEXPECTED,
            0x80100020 => SCARD::SCARD_E_ICC_INSTALLATION,
            0x80100021 => SCARD::SCARD_E_ICC_CREATEORDER,
            0x80100022 => SCARD::SCARD_E_UNSUPPORTED_FEATURE,
            0x80100023 => SCARD::SCARD_E_DIR_NOT_FOUND,
            0x80100024 => SCARD::SCARD_E_FILE_NOT_FOUND,
            0x80100025 => SCARD::SCARD_E_NO_DIR,
            0x80100026 => SCARD::SCARD_E_NO_FILE,
            0x80100027 => SCARD::SCARD_E_NO_ACCESS,
            0x80100028 => SCARD::SCARD_E_WRITE_TOO_MANY,
            0x80100029 => SCARD::SCARD_E_BAD_SEEK,
            0x8010002A => SCARD::SCARD_E_INVALID_CHV,
            0x8010002B => SCARD::SCARD_E_UNKNOWN_RES_MNG,
            0x8010002C => SCARD::SCARD_E_NO_SUCH_CERTIFICATE,
            0x8010002D => SCARD::SCARD_E_CERTIFICATE_UNAVAILABLE,
            0x8010002E => SCARD::SCARD_E_NO_READERS_AVAILABLE,
            0x8010002F => SCARD::SCARD_E_COMM_DATA_LOST,
            0x80100030 => SCARD::SCARD_E_NO_KEY_CONTAINER,
            0x80100031 => SCARD::SCARD_E_SERVER_TOO_BUSY,
            0x80100032 => SCARD::SCARD_E_PIN_CACHE_EXPIRED,
            0x80100033 => SCARD::SCARD_E_NO_PIN_CACHE,
            0x80100034 => SCARD::SCARD_E_READ_ONLY_CARD,
            0x80100065 => SCARD::SCARD_W_UNSUPPORTED_CARD,
            0x80100066 => SCARD::SCARD_W_UNRESPONSIVE_CARD,
            0x80100067 => SCARD::SCARD_W_UNPOWERED_CARD,
            0x80100068 => SCARD::SCARD_W_RESET_CARD,
            0x80100069 => SCARD::SCARD_W_REMOVED_CARD,
            0x8010006A => SCARD::SCARD_W_SECURITY_VIOLATION,
            0x8010006B => SCARD::SCARD_W_WRONG_CHV,
            0x8010006C => SCARD::SCARD_W_CHV_BLOCKED,
            0x8010006D => SCARD::SCARD_W_EOF,
            0x8010006E => SCARD::SCARD_W_CANCELLED_BY_USER,
            0x8010006F => SCARD::SCARD_W_CARD_NOT_AUTHENTICATED,
            0x80100070 => SCARD::SCARD_W_CACHE_ITEM_NOT_FOUND,
            0x80100071 => SCARD::SCARD_W_CACHE_ITEM_STALE,
            0x80100072 => SCARD::SCARD_W_CACHE_ITEM_TOO_BIG,
        }
    }
}
