/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum SETUPAPI {
    SPAPI_E_EXPECTED_SECTION_NAME,
    SPAPI_E_BAD_SECTION_NAME_LINE,
    SPAPI_E_SECTION_NAME_TOO_LONG,
    SPAPI_E_GENERAL_SYNTAX,
    SPAPI_E_WRONG_INF_STYLE,
    SPAPI_E_SECTION_NOT_FOUND,
    SPAPI_E_LINE_NOT_FOUND,
    SPAPI_E_NO_BACKUP,
    SPAPI_E_NO_ASSOCIATED_CLASS,
    SPAPI_E_CLASS_MISMATCH,
    SPAPI_E_DUPLICATE_FOUND,
    SPAPI_E_NO_DRIVER_SELECTED,
    SPAPI_E_KEY_DOES_NOT_EXIST,
    SPAPI_E_INVALID_DEVINST_NAME,
    SPAPI_E_INVALID_CLASS,
    SPAPI_E_DEVINST_ALREADY_EXISTS,
    SPAPI_E_DEVINFO_NOT_REGISTERED,
    SPAPI_E_INVALID_REG_PROPERTY,
    SPAPI_E_NO_INF,
    SPAPI_E_NO_SUCH_DEVINST,
    SPAPI_E_CANT_LOAD_CLASS_ICON,
    SPAPI_E_INVALID_CLASS_INSTALLER,
    SPAPI_E_DI_DO_DEFAULT,
    SPAPI_E_DI_NOFILECOPY,
    SPAPI_E_INVALID_HWPROFILE,
    SPAPI_E_NO_DEVICE_SELECTED,
    SPAPI_E_DEVINFO_LIST_LOCKED,
    SPAPI_E_DEVINFO_DATA_LOCKED,
    SPAPI_E_DI_BAD_PATH,
    SPAPI_E_NO_CLASSINSTALL_PARAMS,
    SPAPI_E_FILEQUEUE_LOCKED,
    SPAPI_E_BAD_SERVICE_INSTALLSECT,
    SPAPI_E_NO_CLASS_DRIVER_LIST,
    SPAPI_E_NO_ASSOCIATED_SERVICE,
    SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE,
    SPAPI_E_DEVICE_INTERFACE_ACTIVE,
    SPAPI_E_DEVICE_INTERFACE_REMOVED,
    SPAPI_E_BAD_INTERFACE_INSTALLSECT,
    SPAPI_E_NO_SUCH_INTERFACE_CLASS,
    SPAPI_E_INVALID_REFERENCE_STRING,
    SPAPI_E_INVALID_MACHINENAME,
    SPAPI_E_REMOTE_COMM_FAILURE,
    SPAPI_E_MACHINE_UNAVAILABLE,
    SPAPI_E_NO_CONFIGMGR_SERVICES,
    SPAPI_E_INVALID_PROPPAGE_PROVIDER,
    SPAPI_E_NO_SUCH_DEVICE_INTERFACE,
    SPAPI_E_DI_POSTPROCESSING_REQUIRED,
    SPAPI_E_INVALID_COINSTALLER,
    SPAPI_E_NO_COMPAT_DRIVERS,
    SPAPI_E_NO_DEVICE_ICON,
    SPAPI_E_INVALID_INF_LOGCONFIG,
    SPAPI_E_DI_DONT_INSTALL,
    SPAPI_E_INVALID_FILTER_DRIVER,
    SPAPI_E_NON_WINDOWS_NT_DRIVER,
    SPAPI_E_NON_WINDOWS_DRIVER,
    SPAPI_E_NO_CATALOG_FOR_OEM_INF,
    SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE,
    SPAPI_E_NOT_DISABLEABLE,
    SPAPI_E_CANT_REMOVE_DEVINST,
    SPAPI_E_INVALID_TARGET,
    SPAPI_E_DRIVER_NONNATIVE,
    SPAPI_E_IN_WOW64,
    SPAPI_E_SET_SYSTEM_RESTORE_POINT,
    SPAPI_E_INCORRECTLY_COPIED_INF,
    SPAPI_E_SCE_DISABLED,
    SPAPI_E_UNKNOWN_EXCEPTION,
    SPAPI_E_PNP_REGISTRY_ERROR,
    SPAPI_E_REMOTE_REQUEST_UNSUPPORTED,
    SPAPI_E_NOT_AN_INSTALLED_OEM_INF,
    SPAPI_E_INF_IN_USE_BY_DEVICES,
    SPAPI_E_DI_FUNCTION_OBSOLETE,
    SPAPI_E_NO_AUTHENTICODE_CATALOG,
    SPAPI_E_AUTHENTICODE_DISALLOWED,
    SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER,
    SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED,
    SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED,
    SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH,
    SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE,
    SPAPI_E_DEVICE_INSTALLER_NOT_READY,
    SPAPI_E_DRIVER_STORE_ADD_FAILED,
    SPAPI_E_DEVICE_INSTALL_BLOCKED,
    SPAPI_E_DRIVER_INSTALL_BLOCKED,
    SPAPI_E_WRONG_INF_TYPE,
    SPAPI_E_FILE_HASH_NOT_IN_CATALOG,
    SPAPI_E_DRIVER_STORE_DELETE_FAILED,
    SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW,
    SPAPI_E_ERROR_NOT_INSTALLED,
}

impl SETUPAPI {
    pub fn code(&self) -> u32 {
        return match self {
            SETUPAPI::SPAPI_E_EXPECTED_SECTION_NAME => 0x800F0000 as u32,
            SETUPAPI::SPAPI_E_BAD_SECTION_NAME_LINE => 0x800F0001 as u32,
            SETUPAPI::SPAPI_E_SECTION_NAME_TOO_LONG => 0x800F0002 as u32,
            SETUPAPI::SPAPI_E_GENERAL_SYNTAX => 0x800F0003 as u32,
            SETUPAPI::SPAPI_E_WRONG_INF_STYLE => 0x800F0100 as u32,
            SETUPAPI::SPAPI_E_SECTION_NOT_FOUND => 0x800F0101 as u32,
            SETUPAPI::SPAPI_E_LINE_NOT_FOUND => 0x800F0102 as u32,
            SETUPAPI::SPAPI_E_NO_BACKUP => 0x800F0103 as u32,
            SETUPAPI::SPAPI_E_NO_ASSOCIATED_CLASS => 0x800F0200 as u32,
            SETUPAPI::SPAPI_E_CLASS_MISMATCH => 0x800F0201 as u32,
            SETUPAPI::SPAPI_E_DUPLICATE_FOUND => 0x800F0202 as u32,
            SETUPAPI::SPAPI_E_NO_DRIVER_SELECTED => 0x800F0203 as u32,
            SETUPAPI::SPAPI_E_KEY_DOES_NOT_EXIST => 0x800F0204 as u32,
            SETUPAPI::SPAPI_E_INVALID_DEVINST_NAME => 0x800F0205 as u32,
            SETUPAPI::SPAPI_E_INVALID_CLASS => 0x800F0206 as u32,
            SETUPAPI::SPAPI_E_DEVINST_ALREADY_EXISTS => 0x800F0207 as u32,
            SETUPAPI::SPAPI_E_DEVINFO_NOT_REGISTERED => 0x800F0208 as u32,
            SETUPAPI::SPAPI_E_INVALID_REG_PROPERTY => 0x800F0209 as u32,
            SETUPAPI::SPAPI_E_NO_INF => 0x800F020A as u32,
            SETUPAPI::SPAPI_E_NO_SUCH_DEVINST => 0x800F020B as u32,
            SETUPAPI::SPAPI_E_CANT_LOAD_CLASS_ICON => 0x800F020C as u32,
            SETUPAPI::SPAPI_E_INVALID_CLASS_INSTALLER => 0x800F020D as u32,
            SETUPAPI::SPAPI_E_DI_DO_DEFAULT => 0x800F020E as u32,
            SETUPAPI::SPAPI_E_DI_NOFILECOPY => 0x800F020F as u32,
            SETUPAPI::SPAPI_E_INVALID_HWPROFILE => 0x800F0210 as u32,
            SETUPAPI::SPAPI_E_NO_DEVICE_SELECTED => 0x800F0211 as u32,
            SETUPAPI::SPAPI_E_DEVINFO_LIST_LOCKED => 0x800F0212 as u32,
            SETUPAPI::SPAPI_E_DEVINFO_DATA_LOCKED => 0x800F0213 as u32,
            SETUPAPI::SPAPI_E_DI_BAD_PATH => 0x800F0214 as u32,
            SETUPAPI::SPAPI_E_NO_CLASSINSTALL_PARAMS => 0x800F0215 as u32,
            SETUPAPI::SPAPI_E_FILEQUEUE_LOCKED => 0x800F0216 as u32,
            SETUPAPI::SPAPI_E_BAD_SERVICE_INSTALLSECT => 0x800F0217 as u32,
            SETUPAPI::SPAPI_E_NO_CLASS_DRIVER_LIST => 0x800F0218 as u32,
            SETUPAPI::SPAPI_E_NO_ASSOCIATED_SERVICE => 0x800F0219 as u32,
            SETUPAPI::SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE => 0x800F021A as u32,
            SETUPAPI::SPAPI_E_DEVICE_INTERFACE_ACTIVE => 0x800F021B as u32,
            SETUPAPI::SPAPI_E_DEVICE_INTERFACE_REMOVED => 0x800F021C as u32,
            SETUPAPI::SPAPI_E_BAD_INTERFACE_INSTALLSECT => 0x800F021D as u32,
            SETUPAPI::SPAPI_E_NO_SUCH_INTERFACE_CLASS => 0x800F021E as u32,
            SETUPAPI::SPAPI_E_INVALID_REFERENCE_STRING => 0x800F021F as u32,
            SETUPAPI::SPAPI_E_INVALID_MACHINENAME => 0x800F0220 as u32,
            SETUPAPI::SPAPI_E_REMOTE_COMM_FAILURE => 0x800F0221 as u32,
            SETUPAPI::SPAPI_E_MACHINE_UNAVAILABLE => 0x800F0222 as u32,
            SETUPAPI::SPAPI_E_NO_CONFIGMGR_SERVICES => 0x800F0223 as u32,
            SETUPAPI::SPAPI_E_INVALID_PROPPAGE_PROVIDER => 0x800F0224 as u32,
            SETUPAPI::SPAPI_E_NO_SUCH_DEVICE_INTERFACE => 0x800F0225 as u32,
            SETUPAPI::SPAPI_E_DI_POSTPROCESSING_REQUIRED => 0x800F0226 as u32,
            SETUPAPI::SPAPI_E_INVALID_COINSTALLER => 0x800F0227 as u32,
            SETUPAPI::SPAPI_E_NO_COMPAT_DRIVERS => 0x800F0228 as u32,
            SETUPAPI::SPAPI_E_NO_DEVICE_ICON => 0x800F0229 as u32,
            SETUPAPI::SPAPI_E_INVALID_INF_LOGCONFIG => 0x800F022A as u32,
            SETUPAPI::SPAPI_E_DI_DONT_INSTALL => 0x800F022B as u32,
            SETUPAPI::SPAPI_E_INVALID_FILTER_DRIVER => 0x800F022C as u32,
            SETUPAPI::SPAPI_E_NON_WINDOWS_NT_DRIVER => 0x800F022D as u32,
            SETUPAPI::SPAPI_E_NON_WINDOWS_DRIVER => 0x800F022E as u32,
            SETUPAPI::SPAPI_E_NO_CATALOG_FOR_OEM_INF => 0x800F022F as u32,
            SETUPAPI::SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE => 0x800F0230 as u32,
            SETUPAPI::SPAPI_E_NOT_DISABLEABLE => 0x800F0231 as u32,
            SETUPAPI::SPAPI_E_CANT_REMOVE_DEVINST => 0x800F0232 as u32,
            SETUPAPI::SPAPI_E_INVALID_TARGET => 0x800F0233 as u32,
            SETUPAPI::SPAPI_E_DRIVER_NONNATIVE => 0x800F0234 as u32,
            SETUPAPI::SPAPI_E_IN_WOW64 => 0x800F0235 as u32,
            SETUPAPI::SPAPI_E_SET_SYSTEM_RESTORE_POINT => 0x800F0236 as u32,
            SETUPAPI::SPAPI_E_INCORRECTLY_COPIED_INF => 0x800F0237 as u32,
            SETUPAPI::SPAPI_E_SCE_DISABLED => 0x800F0238 as u32,
            SETUPAPI::SPAPI_E_UNKNOWN_EXCEPTION => 0x800F0239 as u32,
            SETUPAPI::SPAPI_E_PNP_REGISTRY_ERROR => 0x800F023A as u32,
            SETUPAPI::SPAPI_E_REMOTE_REQUEST_UNSUPPORTED => 0x800F023B as u32,
            SETUPAPI::SPAPI_E_NOT_AN_INSTALLED_OEM_INF => 0x800F023C as u32,
            SETUPAPI::SPAPI_E_INF_IN_USE_BY_DEVICES => 0x800F023D as u32,
            SETUPAPI::SPAPI_E_DI_FUNCTION_OBSOLETE => 0x800F023E as u32,
            SETUPAPI::SPAPI_E_NO_AUTHENTICODE_CATALOG => 0x800F023F as u32,
            SETUPAPI::SPAPI_E_AUTHENTICODE_DISALLOWED => 0x800F0240 as u32,
            SETUPAPI::SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER => 0x800F0241 as u32,
            SETUPAPI::SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED => 0x800F0242 as u32,
            SETUPAPI::SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED => 0x800F0243 as u32,
            SETUPAPI::SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH => 0x800F0244 as u32,
            SETUPAPI::SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE => 0x800F0245 as u32,
            SETUPAPI::SPAPI_E_DEVICE_INSTALLER_NOT_READY => 0x800F0246 as u32,
            SETUPAPI::SPAPI_E_DRIVER_STORE_ADD_FAILED => 0x800F0247 as u32,
            SETUPAPI::SPAPI_E_DEVICE_INSTALL_BLOCKED => 0x800F0248 as u32,
            SETUPAPI::SPAPI_E_DRIVER_INSTALL_BLOCKED => 0x800F0249 as u32,
            SETUPAPI::SPAPI_E_WRONG_INF_TYPE => 0x800F024A as u32,
            SETUPAPI::SPAPI_E_FILE_HASH_NOT_IN_CATALOG => 0x800F024B as u32,
            SETUPAPI::SPAPI_E_DRIVER_STORE_DELETE_FAILED => 0x800F024C as u32,
            SETUPAPI::SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW => 0x800F0300 as u32,
            SETUPAPI::SPAPI_E_ERROR_NOT_INSTALLED => 0x800F1000 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            SETUPAPI::SPAPI_E_EXPECTED_SECTION_NAME => RawError::Kind(SETUPAPI::SPAPI_E_EXPECTED_SECTION_NAME),
            SETUPAPI::SPAPI_E_BAD_SECTION_NAME_LINE => RawError::Kind(SETUPAPI::SPAPI_E_BAD_SECTION_NAME_LINE),
            SETUPAPI::SPAPI_E_SECTION_NAME_TOO_LONG => RawError::Kind(SETUPAPI::SPAPI_E_SECTION_NAME_TOO_LONG),
            SETUPAPI::SPAPI_E_GENERAL_SYNTAX => RawError::Kind(SETUPAPI::SPAPI_E_GENERAL_SYNTAX),
            SETUPAPI::SPAPI_E_WRONG_INF_STYLE => RawError::Kind(SETUPAPI::SPAPI_E_WRONG_INF_STYLE),
            SETUPAPI::SPAPI_E_SECTION_NOT_FOUND => RawError::Kind(SETUPAPI::SPAPI_E_SECTION_NOT_FOUND),
            SETUPAPI::SPAPI_E_LINE_NOT_FOUND => RawError::Kind(SETUPAPI::SPAPI_E_LINE_NOT_FOUND),
            SETUPAPI::SPAPI_E_NO_BACKUP => RawError::Kind(SETUPAPI::SPAPI_E_NO_BACKUP),
            SETUPAPI::SPAPI_E_NO_ASSOCIATED_CLASS => RawError::Kind(SETUPAPI::SPAPI_E_NO_ASSOCIATED_CLASS),
            SETUPAPI::SPAPI_E_CLASS_MISMATCH => RawError::Kind(SETUPAPI::SPAPI_E_CLASS_MISMATCH),
            SETUPAPI::SPAPI_E_DUPLICATE_FOUND => RawError::Kind(SETUPAPI::SPAPI_E_DUPLICATE_FOUND),
            SETUPAPI::SPAPI_E_NO_DRIVER_SELECTED => RawError::Kind(SETUPAPI::SPAPI_E_NO_DRIVER_SELECTED),
            SETUPAPI::SPAPI_E_KEY_DOES_NOT_EXIST => RawError::Kind(SETUPAPI::SPAPI_E_KEY_DOES_NOT_EXIST),
            SETUPAPI::SPAPI_E_INVALID_DEVINST_NAME => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_DEVINST_NAME),
            SETUPAPI::SPAPI_E_INVALID_CLASS => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_CLASS),
            SETUPAPI::SPAPI_E_DEVINST_ALREADY_EXISTS => RawError::Kind(SETUPAPI::SPAPI_E_DEVINST_ALREADY_EXISTS),
            SETUPAPI::SPAPI_E_DEVINFO_NOT_REGISTERED => RawError::Kind(SETUPAPI::SPAPI_E_DEVINFO_NOT_REGISTERED),
            SETUPAPI::SPAPI_E_INVALID_REG_PROPERTY => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_REG_PROPERTY),
            SETUPAPI::SPAPI_E_NO_INF => RawError::Kind(SETUPAPI::SPAPI_E_NO_INF),
            SETUPAPI::SPAPI_E_NO_SUCH_DEVINST => RawError::Kind(SETUPAPI::SPAPI_E_NO_SUCH_DEVINST),
            SETUPAPI::SPAPI_E_CANT_LOAD_CLASS_ICON => RawError::Kind(SETUPAPI::SPAPI_E_CANT_LOAD_CLASS_ICON),
            SETUPAPI::SPAPI_E_INVALID_CLASS_INSTALLER => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_CLASS_INSTALLER),
            SETUPAPI::SPAPI_E_DI_DO_DEFAULT => RawError::Kind(SETUPAPI::SPAPI_E_DI_DO_DEFAULT),
            SETUPAPI::SPAPI_E_DI_NOFILECOPY => RawError::Kind(SETUPAPI::SPAPI_E_DI_NOFILECOPY),
            SETUPAPI::SPAPI_E_INVALID_HWPROFILE => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_HWPROFILE),
            SETUPAPI::SPAPI_E_NO_DEVICE_SELECTED => RawError::Kind(SETUPAPI::SPAPI_E_NO_DEVICE_SELECTED),
            SETUPAPI::SPAPI_E_DEVINFO_LIST_LOCKED => RawError::Kind(SETUPAPI::SPAPI_E_DEVINFO_LIST_LOCKED),
            SETUPAPI::SPAPI_E_DEVINFO_DATA_LOCKED => RawError::Kind(SETUPAPI::SPAPI_E_DEVINFO_DATA_LOCKED),
            SETUPAPI::SPAPI_E_DI_BAD_PATH => RawError::Kind(SETUPAPI::SPAPI_E_DI_BAD_PATH),
            SETUPAPI::SPAPI_E_NO_CLASSINSTALL_PARAMS => RawError::Kind(SETUPAPI::SPAPI_E_NO_CLASSINSTALL_PARAMS),
            SETUPAPI::SPAPI_E_FILEQUEUE_LOCKED => RawError::Kind(SETUPAPI::SPAPI_E_FILEQUEUE_LOCKED),
            SETUPAPI::SPAPI_E_BAD_SERVICE_INSTALLSECT => RawError::Kind(SETUPAPI::SPAPI_E_BAD_SERVICE_INSTALLSECT),
            SETUPAPI::SPAPI_E_NO_CLASS_DRIVER_LIST => RawError::Kind(SETUPAPI::SPAPI_E_NO_CLASS_DRIVER_LIST),
            SETUPAPI::SPAPI_E_NO_ASSOCIATED_SERVICE => RawError::Kind(SETUPAPI::SPAPI_E_NO_ASSOCIATED_SERVICE),
            SETUPAPI::SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE => RawError::Kind(SETUPAPI::SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE),
            SETUPAPI::SPAPI_E_DEVICE_INTERFACE_ACTIVE => RawError::Kind(SETUPAPI::SPAPI_E_DEVICE_INTERFACE_ACTIVE),
            SETUPAPI::SPAPI_E_DEVICE_INTERFACE_REMOVED => RawError::Kind(SETUPAPI::SPAPI_E_DEVICE_INTERFACE_REMOVED),
            SETUPAPI::SPAPI_E_BAD_INTERFACE_INSTALLSECT => RawError::Kind(SETUPAPI::SPAPI_E_BAD_INTERFACE_INSTALLSECT),
            SETUPAPI::SPAPI_E_NO_SUCH_INTERFACE_CLASS => RawError::Kind(SETUPAPI::SPAPI_E_NO_SUCH_INTERFACE_CLASS),
            SETUPAPI::SPAPI_E_INVALID_REFERENCE_STRING => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_REFERENCE_STRING),
            SETUPAPI::SPAPI_E_INVALID_MACHINENAME => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_MACHINENAME),
            SETUPAPI::SPAPI_E_REMOTE_COMM_FAILURE => RawError::Kind(SETUPAPI::SPAPI_E_REMOTE_COMM_FAILURE),
            SETUPAPI::SPAPI_E_MACHINE_UNAVAILABLE => RawError::Kind(SETUPAPI::SPAPI_E_MACHINE_UNAVAILABLE),
            SETUPAPI::SPAPI_E_NO_CONFIGMGR_SERVICES => RawError::Kind(SETUPAPI::SPAPI_E_NO_CONFIGMGR_SERVICES),
            SETUPAPI::SPAPI_E_INVALID_PROPPAGE_PROVIDER => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_PROPPAGE_PROVIDER),
            SETUPAPI::SPAPI_E_NO_SUCH_DEVICE_INTERFACE => RawError::Kind(SETUPAPI::SPAPI_E_NO_SUCH_DEVICE_INTERFACE),
            SETUPAPI::SPAPI_E_DI_POSTPROCESSING_REQUIRED => RawError::Kind(SETUPAPI::SPAPI_E_DI_POSTPROCESSING_REQUIRED),
            SETUPAPI::SPAPI_E_INVALID_COINSTALLER => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_COINSTALLER),
            SETUPAPI::SPAPI_E_NO_COMPAT_DRIVERS => RawError::Kind(SETUPAPI::SPAPI_E_NO_COMPAT_DRIVERS),
            SETUPAPI::SPAPI_E_NO_DEVICE_ICON => RawError::Kind(SETUPAPI::SPAPI_E_NO_DEVICE_ICON),
            SETUPAPI::SPAPI_E_INVALID_INF_LOGCONFIG => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_INF_LOGCONFIG),
            SETUPAPI::SPAPI_E_DI_DONT_INSTALL => RawError::Kind(SETUPAPI::SPAPI_E_DI_DONT_INSTALL),
            SETUPAPI::SPAPI_E_INVALID_FILTER_DRIVER => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_FILTER_DRIVER),
            SETUPAPI::SPAPI_E_NON_WINDOWS_NT_DRIVER => RawError::Kind(SETUPAPI::SPAPI_E_NON_WINDOWS_NT_DRIVER),
            SETUPAPI::SPAPI_E_NON_WINDOWS_DRIVER => RawError::Kind(SETUPAPI::SPAPI_E_NON_WINDOWS_DRIVER),
            SETUPAPI::SPAPI_E_NO_CATALOG_FOR_OEM_INF => RawError::Kind(SETUPAPI::SPAPI_E_NO_CATALOG_FOR_OEM_INF),
            SETUPAPI::SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE => RawError::Kind(SETUPAPI::SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE),
            SETUPAPI::SPAPI_E_NOT_DISABLEABLE => RawError::Kind(SETUPAPI::SPAPI_E_NOT_DISABLEABLE),
            SETUPAPI::SPAPI_E_CANT_REMOVE_DEVINST => RawError::Kind(SETUPAPI::SPAPI_E_CANT_REMOVE_DEVINST),
            SETUPAPI::SPAPI_E_INVALID_TARGET => RawError::Kind(SETUPAPI::SPAPI_E_INVALID_TARGET),
            SETUPAPI::SPAPI_E_DRIVER_NONNATIVE => RawError::Kind(SETUPAPI::SPAPI_E_DRIVER_NONNATIVE),
            SETUPAPI::SPAPI_E_IN_WOW64 => RawError::Kind(SETUPAPI::SPAPI_E_IN_WOW64),
            SETUPAPI::SPAPI_E_SET_SYSTEM_RESTORE_POINT => RawError::Kind(SETUPAPI::SPAPI_E_SET_SYSTEM_RESTORE_POINT),
            SETUPAPI::SPAPI_E_INCORRECTLY_COPIED_INF => RawError::Kind(SETUPAPI::SPAPI_E_INCORRECTLY_COPIED_INF),
            SETUPAPI::SPAPI_E_SCE_DISABLED => RawError::Kind(SETUPAPI::SPAPI_E_SCE_DISABLED),
            SETUPAPI::SPAPI_E_UNKNOWN_EXCEPTION => RawError::Kind(SETUPAPI::SPAPI_E_UNKNOWN_EXCEPTION),
            SETUPAPI::SPAPI_E_PNP_REGISTRY_ERROR => RawError::Kind(SETUPAPI::SPAPI_E_PNP_REGISTRY_ERROR),
            SETUPAPI::SPAPI_E_REMOTE_REQUEST_UNSUPPORTED => RawError::Kind(SETUPAPI::SPAPI_E_REMOTE_REQUEST_UNSUPPORTED),
            SETUPAPI::SPAPI_E_NOT_AN_INSTALLED_OEM_INF => RawError::Kind(SETUPAPI::SPAPI_E_NOT_AN_INSTALLED_OEM_INF),
            SETUPAPI::SPAPI_E_INF_IN_USE_BY_DEVICES => RawError::Kind(SETUPAPI::SPAPI_E_INF_IN_USE_BY_DEVICES),
            SETUPAPI::SPAPI_E_DI_FUNCTION_OBSOLETE => RawError::Kind(SETUPAPI::SPAPI_E_DI_FUNCTION_OBSOLETE),
            SETUPAPI::SPAPI_E_NO_AUTHENTICODE_CATALOG => RawError::Kind(SETUPAPI::SPAPI_E_NO_AUTHENTICODE_CATALOG),
            SETUPAPI::SPAPI_E_AUTHENTICODE_DISALLOWED => RawError::Kind(SETUPAPI::SPAPI_E_AUTHENTICODE_DISALLOWED),
            SETUPAPI::SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER => RawError::Kind(SETUPAPI::SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER),
            SETUPAPI::SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED => RawError::Kind(SETUPAPI::SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED),
            SETUPAPI::SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED => RawError::Kind(SETUPAPI::SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED),
            SETUPAPI::SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH => RawError::Kind(SETUPAPI::SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH),
            SETUPAPI::SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE => RawError::Kind(SETUPAPI::SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE),
            SETUPAPI::SPAPI_E_DEVICE_INSTALLER_NOT_READY => RawError::Kind(SETUPAPI::SPAPI_E_DEVICE_INSTALLER_NOT_READY),
            SETUPAPI::SPAPI_E_DRIVER_STORE_ADD_FAILED => RawError::Kind(SETUPAPI::SPAPI_E_DRIVER_STORE_ADD_FAILED),
            SETUPAPI::SPAPI_E_DEVICE_INSTALL_BLOCKED => RawError::Kind(SETUPAPI::SPAPI_E_DEVICE_INSTALL_BLOCKED),
            SETUPAPI::SPAPI_E_DRIVER_INSTALL_BLOCKED => RawError::Kind(SETUPAPI::SPAPI_E_DRIVER_INSTALL_BLOCKED),
            SETUPAPI::SPAPI_E_WRONG_INF_TYPE => RawError::Kind(SETUPAPI::SPAPI_E_WRONG_INF_TYPE),
            SETUPAPI::SPAPI_E_FILE_HASH_NOT_IN_CATALOG => RawError::Kind(SETUPAPI::SPAPI_E_FILE_HASH_NOT_IN_CATALOG),
            SETUPAPI::SPAPI_E_DRIVER_STORE_DELETE_FAILED => RawError::Kind(SETUPAPI::SPAPI_E_DRIVER_STORE_DELETE_FAILED),
            SETUPAPI::SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW => RawError::Kind(SETUPAPI::SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW),
            SETUPAPI::SPAPI_E_ERROR_NOT_INSTALLED => RawError::Kind(SETUPAPI::SPAPI_E_ERROR_NOT_INSTALLED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            SETUPAPI::SPAPI_E_EXPECTED_SECTION_NAME => "A non-empty line was encountered in the INF before the start of a section.",
            SETUPAPI::SPAPI_E_BAD_SECTION_NAME_LINE => "A section name marker in the INF is not complete, or does not exist on a line by itself.",
            SETUPAPI::SPAPI_E_SECTION_NAME_TOO_LONG => "An INF section was encountered whose name exceeds the maximum section name length.",
            SETUPAPI::SPAPI_E_GENERAL_SYNTAX => "The syntax of the INF is invalid.",
            SETUPAPI::SPAPI_E_WRONG_INF_STYLE => "The style of the INF is different than what was requested.",
            SETUPAPI::SPAPI_E_SECTION_NOT_FOUND => "The required section was not found in the INF.",
            SETUPAPI::SPAPI_E_LINE_NOT_FOUND => "The required line was not found in the INF.",
            SETUPAPI::SPAPI_E_NO_BACKUP => "The files affected by the installation of this file queue have not been backed up for uninstall.",
            SETUPAPI::SPAPI_E_NO_ASSOCIATED_CLASS => "The INF or the device information set or element does not have an associated install class.",
            SETUPAPI::SPAPI_E_CLASS_MISMATCH => "The INF or the device information set or element does not match the specified install class.",
            SETUPAPI::SPAPI_E_DUPLICATE_FOUND => "An existing device was found that is a duplicate of the device being manually installed.",
            SETUPAPI::SPAPI_E_NO_DRIVER_SELECTED => "There is no driver selected for the device information set or element.",
            SETUPAPI::SPAPI_E_KEY_DOES_NOT_EXIST => "The requested device registry key does not exist.",
            SETUPAPI::SPAPI_E_INVALID_DEVINST_NAME => "The device instance name is invalid.",
            SETUPAPI::SPAPI_E_INVALID_CLASS => "The install class is not present or is invalid.",
            SETUPAPI::SPAPI_E_DEVINST_ALREADY_EXISTS => "The device instance cannot be created because it already exists.",
            SETUPAPI::SPAPI_E_DEVINFO_NOT_REGISTERED => "The operation cannot be performed on a device information element that has not been registered.",
            SETUPAPI::SPAPI_E_INVALID_REG_PROPERTY => "The device property code is invalid.",
            SETUPAPI::SPAPI_E_NO_INF => "The INF from which a driver list is to be built does not exist.",
            SETUPAPI::SPAPI_E_NO_SUCH_DEVINST => "The device instance does not exist in the hardware tree.",
            SETUPAPI::SPAPI_E_CANT_LOAD_CLASS_ICON => "The icon representing this install class cannot be loaded.",
            SETUPAPI::SPAPI_E_INVALID_CLASS_INSTALLER => "The class installer registry entry is invalid.",
            SETUPAPI::SPAPI_E_DI_DO_DEFAULT => "The class installer has indicated that the default action should be performed for this installation request.",
            SETUPAPI::SPAPI_E_DI_NOFILECOPY => "The operation does not require any files to be copied.",
            SETUPAPI::SPAPI_E_INVALID_HWPROFILE => "The specified hardware profile does not exist.",
            SETUPAPI::SPAPI_E_NO_DEVICE_SELECTED => "There is no device information element currently selected for this device information set.",
            SETUPAPI::SPAPI_E_DEVINFO_LIST_LOCKED => "The operation cannot be performed because the device information set is locked.",
            SETUPAPI::SPAPI_E_DEVINFO_DATA_LOCKED => "The operation cannot be performed because the device information element is locked.",
            SETUPAPI::SPAPI_E_DI_BAD_PATH => "The specified path does not contain any applicable device INFs.",
            SETUPAPI::SPAPI_E_NO_CLASSINSTALL_PARAMS => "No class installer parameters have been set for the device information set or element.",
            SETUPAPI::SPAPI_E_FILEQUEUE_LOCKED => "The operation cannot be performed because the file queue is locked.",
            SETUPAPI::SPAPI_E_BAD_SERVICE_INSTALLSECT => "A service installation section in this INF is invalid.",
            SETUPAPI::SPAPI_E_NO_CLASS_DRIVER_LIST => "There is no class driver list for the device information element.",
            SETUPAPI::SPAPI_E_NO_ASSOCIATED_SERVICE => "The installation failed because a function driver was not specified for this device instance.",
            SETUPAPI::SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE => "There is presently no default device interface designated for this interface class.",
            SETUPAPI::SPAPI_E_DEVICE_INTERFACE_ACTIVE => "The operation cannot be performed because the device interface is currently active.",
            SETUPAPI::SPAPI_E_DEVICE_INTERFACE_REMOVED => "The operation cannot be performed because the device interface has been removed from the system.",
            SETUPAPI::SPAPI_E_BAD_INTERFACE_INSTALLSECT => "An interface installation section in this INF is invalid.",
            SETUPAPI::SPAPI_E_NO_SUCH_INTERFACE_CLASS => "This interface class does not exist in the system.",
            SETUPAPI::SPAPI_E_INVALID_REFERENCE_STRING => "The reference string supplied for this interface device is invalid.",
            SETUPAPI::SPAPI_E_INVALID_MACHINENAME => "The specified machine name does not conform to UNC naming conventions.",
            SETUPAPI::SPAPI_E_REMOTE_COMM_FAILURE => "A general remote communication error occurred.",
            SETUPAPI::SPAPI_E_MACHINE_UNAVAILABLE => "The machine selected for remote communication is not available at this time.",
            SETUPAPI::SPAPI_E_NO_CONFIGMGR_SERVICES => "The Plug and Play service is not available on the remote machine.",
            SETUPAPI::SPAPI_E_INVALID_PROPPAGE_PROVIDER => "The property page provider registry entry is invalid.",
            SETUPAPI::SPAPI_E_NO_SUCH_DEVICE_INTERFACE => "The requested device interface is not present in the system.",
            SETUPAPI::SPAPI_E_DI_POSTPROCESSING_REQUIRED => "The device's co-installer has additional work to perform after installation is complete.",
            SETUPAPI::SPAPI_E_INVALID_COINSTALLER => "The device's co-installer is invalid.",
            SETUPAPI::SPAPI_E_NO_COMPAT_DRIVERS => "There are no compatible drivers for this device.",
            SETUPAPI::SPAPI_E_NO_DEVICE_ICON => "There is no icon that represents this device or device type.",
            SETUPAPI::SPAPI_E_INVALID_INF_LOGCONFIG => "A logical configuration specified in this INF is invalid.",
            SETUPAPI::SPAPI_E_DI_DONT_INSTALL => "The class installer has denied the request to install or upgrade this device.",
            SETUPAPI::SPAPI_E_INVALID_FILTER_DRIVER => "One of the filter drivers installed for this device is invalid.",
            SETUPAPI::SPAPI_E_NON_WINDOWS_NT_DRIVER => "The driver selected for this device does not support this version of Windows.",
            SETUPAPI::SPAPI_E_NON_WINDOWS_DRIVER => "The driver selected for this device does not support Windows.",
            SETUPAPI::SPAPI_E_NO_CATALOG_FOR_OEM_INF => "The third-party INF does not contain digital signature information.",
            SETUPAPI::SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE => "An invalid attempt was made to use a device installation file queue for verification of digital signatures relative to other platforms.",
            SETUPAPI::SPAPI_E_NOT_DISABLEABLE => "The device cannot be disabled.",
            SETUPAPI::SPAPI_E_CANT_REMOVE_DEVINST => "The device could not be dynamically removed.",
            SETUPAPI::SPAPI_E_INVALID_TARGET => "Cannot copy to specified target.",
            SETUPAPI::SPAPI_E_DRIVER_NONNATIVE => "Driver is not intended for this platform.",
            SETUPAPI::SPAPI_E_IN_WOW64 => "Operation not allowed in WOW64.",
            SETUPAPI::SPAPI_E_SET_SYSTEM_RESTORE_POINT => "The operation involving unsigned file copying was rolled back, so that a system restore point could be set.",
            SETUPAPI::SPAPI_E_INCORRECTLY_COPIED_INF => "An INF was copied into the Windows INF directory in an improper manner.",
            SETUPAPI::SPAPI_E_SCE_DISABLED => "The Security Configuration Editor (SCE) APIs have been disabled on this Embedded product.",
            SETUPAPI::SPAPI_E_UNKNOWN_EXCEPTION => "An unknown exception was encountered.",
            SETUPAPI::SPAPI_E_PNP_REGISTRY_ERROR => "A problem was encountered when accessing the Plug and Play registry database.",
            SETUPAPI::SPAPI_E_REMOTE_REQUEST_UNSUPPORTED => "The requested operation is not supported for a remote machine.",
            SETUPAPI::SPAPI_E_NOT_AN_INSTALLED_OEM_INF => "The specified file is not an installed OEM INF.",
            SETUPAPI::SPAPI_E_INF_IN_USE_BY_DEVICES => "One or more devices are presently installed using the specified INF.",
            SETUPAPI::SPAPI_E_DI_FUNCTION_OBSOLETE => "The requested device install operation is obsolete.",
            SETUPAPI::SPAPI_E_NO_AUTHENTICODE_CATALOG => "A file could not be verified because it does not have an associated catalog signed via Authenticode(tm).",
            SETUPAPI::SPAPI_E_AUTHENTICODE_DISALLOWED => "Authenticode(tm) signature verification is not supported for the specified INF.",
            SETUPAPI::SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER => "The INF was signed with an Authenticode(tm) catalog from a trusted publisher.",
            SETUPAPI::SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED => "The publisher of an Authenticode(tm) signed catalog has not yet been established as trusted.",
            SETUPAPI::SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED => "The publisher of an Authenticode(tm) signed catalog was not established as trusted.",
            SETUPAPI::SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH => "The software was tested for compliance with Windows Logo requirements on a different version of Windows, and may not be compatible with this version.",
            SETUPAPI::SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE => "The file may only be validated by a catalog signed via Authenticode(tm).",
            SETUPAPI::SPAPI_E_DEVICE_INSTALLER_NOT_READY => "One of the installers for this device cannot perform the installation at this time.",
            SETUPAPI::SPAPI_E_DRIVER_STORE_ADD_FAILED => "A problem was encountered while attempting to add the driver to the store.",
            SETUPAPI::SPAPI_E_DEVICE_INSTALL_BLOCKED => "The installation of this device is forbidden by system policy. Contact your system administrator.",
            SETUPAPI::SPAPI_E_DRIVER_INSTALL_BLOCKED => "The installation of this driver is forbidden by system policy. Contact your system administrator.",
            SETUPAPI::SPAPI_E_WRONG_INF_TYPE => "The specified INF is the wrong type for this operation.",
            SETUPAPI::SPAPI_E_FILE_HASH_NOT_IN_CATALOG => "The hash for the file is not present in the specified catalog file. The file is likely corrupt or the victim of tampering.",
            SETUPAPI::SPAPI_E_DRIVER_STORE_DELETE_FAILED => "A problem was encountered while attempting to delete the driver from the store.",
            SETUPAPI::SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW => "An unrecoverable stack overflow was encountered.",
            SETUPAPI::SPAPI_E_ERROR_NOT_INSTALLED => "No installed components were detected.",
        }
    }

    pub fn from_name(name: &str) -> SETUPAPI {
        return match name {
            "SPAPI_E_EXPECTED_SECTION_NAME" => SETUPAPI::SPAPI_E_EXPECTED_SECTION_NAME,
            "SPAPI_E_BAD_SECTION_NAME_LINE" => SETUPAPI::SPAPI_E_BAD_SECTION_NAME_LINE,
            "SPAPI_E_SECTION_NAME_TOO_LONG" => SETUPAPI::SPAPI_E_SECTION_NAME_TOO_LONG,
            "SPAPI_E_GENERAL_SYNTAX" => SETUPAPI::SPAPI_E_GENERAL_SYNTAX,
            "SPAPI_E_WRONG_INF_STYLE" => SETUPAPI::SPAPI_E_WRONG_INF_STYLE,
            "SPAPI_E_SECTION_NOT_FOUND" => SETUPAPI::SPAPI_E_SECTION_NOT_FOUND,
            "SPAPI_E_LINE_NOT_FOUND" => SETUPAPI::SPAPI_E_LINE_NOT_FOUND,
            "SPAPI_E_NO_BACKUP" => SETUPAPI::SPAPI_E_NO_BACKUP,
            "SPAPI_E_NO_ASSOCIATED_CLASS" => SETUPAPI::SPAPI_E_NO_ASSOCIATED_CLASS,
            "SPAPI_E_CLASS_MISMATCH" => SETUPAPI::SPAPI_E_CLASS_MISMATCH,
            "SPAPI_E_DUPLICATE_FOUND" => SETUPAPI::SPAPI_E_DUPLICATE_FOUND,
            "SPAPI_E_NO_DRIVER_SELECTED" => SETUPAPI::SPAPI_E_NO_DRIVER_SELECTED,
            "SPAPI_E_KEY_DOES_NOT_EXIST" => SETUPAPI::SPAPI_E_KEY_DOES_NOT_EXIST,
            "SPAPI_E_INVALID_DEVINST_NAME" => SETUPAPI::SPAPI_E_INVALID_DEVINST_NAME,
            "SPAPI_E_INVALID_CLASS" => SETUPAPI::SPAPI_E_INVALID_CLASS,
            "SPAPI_E_DEVINST_ALREADY_EXISTS" => SETUPAPI::SPAPI_E_DEVINST_ALREADY_EXISTS,
            "SPAPI_E_DEVINFO_NOT_REGISTERED" => SETUPAPI::SPAPI_E_DEVINFO_NOT_REGISTERED,
            "SPAPI_E_INVALID_REG_PROPERTY" => SETUPAPI::SPAPI_E_INVALID_REG_PROPERTY,
            "SPAPI_E_NO_INF" => SETUPAPI::SPAPI_E_NO_INF,
            "SPAPI_E_NO_SUCH_DEVINST" => SETUPAPI::SPAPI_E_NO_SUCH_DEVINST,
            "SPAPI_E_CANT_LOAD_CLASS_ICON" => SETUPAPI::SPAPI_E_CANT_LOAD_CLASS_ICON,
            "SPAPI_E_INVALID_CLASS_INSTALLER" => SETUPAPI::SPAPI_E_INVALID_CLASS_INSTALLER,
            "SPAPI_E_DI_DO_DEFAULT" => SETUPAPI::SPAPI_E_DI_DO_DEFAULT,
            "SPAPI_E_DI_NOFILECOPY" => SETUPAPI::SPAPI_E_DI_NOFILECOPY,
            "SPAPI_E_INVALID_HWPROFILE" => SETUPAPI::SPAPI_E_INVALID_HWPROFILE,
            "SPAPI_E_NO_DEVICE_SELECTED" => SETUPAPI::SPAPI_E_NO_DEVICE_SELECTED,
            "SPAPI_E_DEVINFO_LIST_LOCKED" => SETUPAPI::SPAPI_E_DEVINFO_LIST_LOCKED,
            "SPAPI_E_DEVINFO_DATA_LOCKED" => SETUPAPI::SPAPI_E_DEVINFO_DATA_LOCKED,
            "SPAPI_E_DI_BAD_PATH" => SETUPAPI::SPAPI_E_DI_BAD_PATH,
            "SPAPI_E_NO_CLASSINSTALL_PARAMS" => SETUPAPI::SPAPI_E_NO_CLASSINSTALL_PARAMS,
            "SPAPI_E_FILEQUEUE_LOCKED" => SETUPAPI::SPAPI_E_FILEQUEUE_LOCKED,
            "SPAPI_E_BAD_SERVICE_INSTALLSECT" => SETUPAPI::SPAPI_E_BAD_SERVICE_INSTALLSECT,
            "SPAPI_E_NO_CLASS_DRIVER_LIST" => SETUPAPI::SPAPI_E_NO_CLASS_DRIVER_LIST,
            "SPAPI_E_NO_ASSOCIATED_SERVICE" => SETUPAPI::SPAPI_E_NO_ASSOCIATED_SERVICE,
            "SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE" => SETUPAPI::SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE,
            "SPAPI_E_DEVICE_INTERFACE_ACTIVE" => SETUPAPI::SPAPI_E_DEVICE_INTERFACE_ACTIVE,
            "SPAPI_E_DEVICE_INTERFACE_REMOVED" => SETUPAPI::SPAPI_E_DEVICE_INTERFACE_REMOVED,
            "SPAPI_E_BAD_INTERFACE_INSTALLSECT" => SETUPAPI::SPAPI_E_BAD_INTERFACE_INSTALLSECT,
            "SPAPI_E_NO_SUCH_INTERFACE_CLASS" => SETUPAPI::SPAPI_E_NO_SUCH_INTERFACE_CLASS,
            "SPAPI_E_INVALID_REFERENCE_STRING" => SETUPAPI::SPAPI_E_INVALID_REFERENCE_STRING,
            "SPAPI_E_INVALID_MACHINENAME" => SETUPAPI::SPAPI_E_INVALID_MACHINENAME,
            "SPAPI_E_REMOTE_COMM_FAILURE" => SETUPAPI::SPAPI_E_REMOTE_COMM_FAILURE,
            "SPAPI_E_MACHINE_UNAVAILABLE" => SETUPAPI::SPAPI_E_MACHINE_UNAVAILABLE,
            "SPAPI_E_NO_CONFIGMGR_SERVICES" => SETUPAPI::SPAPI_E_NO_CONFIGMGR_SERVICES,
            "SPAPI_E_INVALID_PROPPAGE_PROVIDER" => SETUPAPI::SPAPI_E_INVALID_PROPPAGE_PROVIDER,
            "SPAPI_E_NO_SUCH_DEVICE_INTERFACE" => SETUPAPI::SPAPI_E_NO_SUCH_DEVICE_INTERFACE,
            "SPAPI_E_DI_POSTPROCESSING_REQUIRED" => SETUPAPI::SPAPI_E_DI_POSTPROCESSING_REQUIRED,
            "SPAPI_E_INVALID_COINSTALLER" => SETUPAPI::SPAPI_E_INVALID_COINSTALLER,
            "SPAPI_E_NO_COMPAT_DRIVERS" => SETUPAPI::SPAPI_E_NO_COMPAT_DRIVERS,
            "SPAPI_E_NO_DEVICE_ICON" => SETUPAPI::SPAPI_E_NO_DEVICE_ICON,
            "SPAPI_E_INVALID_INF_LOGCONFIG" => SETUPAPI::SPAPI_E_INVALID_INF_LOGCONFIG,
            "SPAPI_E_DI_DONT_INSTALL" => SETUPAPI::SPAPI_E_DI_DONT_INSTALL,
            "SPAPI_E_INVALID_FILTER_DRIVER" => SETUPAPI::SPAPI_E_INVALID_FILTER_DRIVER,
            "SPAPI_E_NON_WINDOWS_NT_DRIVER" => SETUPAPI::SPAPI_E_NON_WINDOWS_NT_DRIVER,
            "SPAPI_E_NON_WINDOWS_DRIVER" => SETUPAPI::SPAPI_E_NON_WINDOWS_DRIVER,
            "SPAPI_E_NO_CATALOG_FOR_OEM_INF" => SETUPAPI::SPAPI_E_NO_CATALOG_FOR_OEM_INF,
            "SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE" => SETUPAPI::SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE,
            "SPAPI_E_NOT_DISABLEABLE" => SETUPAPI::SPAPI_E_NOT_DISABLEABLE,
            "SPAPI_E_CANT_REMOVE_DEVINST" => SETUPAPI::SPAPI_E_CANT_REMOVE_DEVINST,
            "SPAPI_E_INVALID_TARGET" => SETUPAPI::SPAPI_E_INVALID_TARGET,
            "SPAPI_E_DRIVER_NONNATIVE" => SETUPAPI::SPAPI_E_DRIVER_NONNATIVE,
            "SPAPI_E_IN_WOW64" => SETUPAPI::SPAPI_E_IN_WOW64,
            "SPAPI_E_SET_SYSTEM_RESTORE_POINT" => SETUPAPI::SPAPI_E_SET_SYSTEM_RESTORE_POINT,
            "SPAPI_E_INCORRECTLY_COPIED_INF" => SETUPAPI::SPAPI_E_INCORRECTLY_COPIED_INF,
            "SPAPI_E_SCE_DISABLED" => SETUPAPI::SPAPI_E_SCE_DISABLED,
            "SPAPI_E_UNKNOWN_EXCEPTION" => SETUPAPI::SPAPI_E_UNKNOWN_EXCEPTION,
            "SPAPI_E_PNP_REGISTRY_ERROR" => SETUPAPI::SPAPI_E_PNP_REGISTRY_ERROR,
            "SPAPI_E_REMOTE_REQUEST_UNSUPPORTED" => SETUPAPI::SPAPI_E_REMOTE_REQUEST_UNSUPPORTED,
            "SPAPI_E_NOT_AN_INSTALLED_OEM_INF" => SETUPAPI::SPAPI_E_NOT_AN_INSTALLED_OEM_INF,
            "SPAPI_E_INF_IN_USE_BY_DEVICES" => SETUPAPI::SPAPI_E_INF_IN_USE_BY_DEVICES,
            "SPAPI_E_DI_FUNCTION_OBSOLETE" => SETUPAPI::SPAPI_E_DI_FUNCTION_OBSOLETE,
            "SPAPI_E_NO_AUTHENTICODE_CATALOG" => SETUPAPI::SPAPI_E_NO_AUTHENTICODE_CATALOG,
            "SPAPI_E_AUTHENTICODE_DISALLOWED" => SETUPAPI::SPAPI_E_AUTHENTICODE_DISALLOWED,
            "SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER" => SETUPAPI::SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER,
            "SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED" => SETUPAPI::SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED,
            "SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED" => SETUPAPI::SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED,
            "SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH" => SETUPAPI::SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH,
            "SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE" => SETUPAPI::SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE,
            "SPAPI_E_DEVICE_INSTALLER_NOT_READY" => SETUPAPI::SPAPI_E_DEVICE_INSTALLER_NOT_READY,
            "SPAPI_E_DRIVER_STORE_ADD_FAILED" => SETUPAPI::SPAPI_E_DRIVER_STORE_ADD_FAILED,
            "SPAPI_E_DEVICE_INSTALL_BLOCKED" => SETUPAPI::SPAPI_E_DEVICE_INSTALL_BLOCKED,
            "SPAPI_E_DRIVER_INSTALL_BLOCKED" => SETUPAPI::SPAPI_E_DRIVER_INSTALL_BLOCKED,
            "SPAPI_E_WRONG_INF_TYPE" => SETUPAPI::SPAPI_E_WRONG_INF_TYPE,
            "SPAPI_E_FILE_HASH_NOT_IN_CATALOG" => SETUPAPI::SPAPI_E_FILE_HASH_NOT_IN_CATALOG,
            "SPAPI_E_DRIVER_STORE_DELETE_FAILED" => SETUPAPI::SPAPI_E_DRIVER_STORE_DELETE_FAILED,
            "SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW" => SETUPAPI::SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW,
            "SPAPI_E_ERROR_NOT_INSTALLED" => SETUPAPI::SPAPI_E_ERROR_NOT_INSTALLED,
        }
    }
    pub fn from_code(code: u32) -> SETUPAPI {
        return match code {
            0x800F0000 => SETUPAPI::SPAPI_E_EXPECTED_SECTION_NAME,
            0x800F0001 => SETUPAPI::SPAPI_E_BAD_SECTION_NAME_LINE,
            0x800F0002 => SETUPAPI::SPAPI_E_SECTION_NAME_TOO_LONG,
            0x800F0003 => SETUPAPI::SPAPI_E_GENERAL_SYNTAX,
            0x800F0100 => SETUPAPI::SPAPI_E_WRONG_INF_STYLE,
            0x800F0101 => SETUPAPI::SPAPI_E_SECTION_NOT_FOUND,
            0x800F0102 => SETUPAPI::SPAPI_E_LINE_NOT_FOUND,
            0x800F0103 => SETUPAPI::SPAPI_E_NO_BACKUP,
            0x800F0200 => SETUPAPI::SPAPI_E_NO_ASSOCIATED_CLASS,
            0x800F0201 => SETUPAPI::SPAPI_E_CLASS_MISMATCH,
            0x800F0202 => SETUPAPI::SPAPI_E_DUPLICATE_FOUND,
            0x800F0203 => SETUPAPI::SPAPI_E_NO_DRIVER_SELECTED,
            0x800F0204 => SETUPAPI::SPAPI_E_KEY_DOES_NOT_EXIST,
            0x800F0205 => SETUPAPI::SPAPI_E_INVALID_DEVINST_NAME,
            0x800F0206 => SETUPAPI::SPAPI_E_INVALID_CLASS,
            0x800F0207 => SETUPAPI::SPAPI_E_DEVINST_ALREADY_EXISTS,
            0x800F0208 => SETUPAPI::SPAPI_E_DEVINFO_NOT_REGISTERED,
            0x800F0209 => SETUPAPI::SPAPI_E_INVALID_REG_PROPERTY,
            0x800F020A => SETUPAPI::SPAPI_E_NO_INF,
            0x800F020B => SETUPAPI::SPAPI_E_NO_SUCH_DEVINST,
            0x800F020C => SETUPAPI::SPAPI_E_CANT_LOAD_CLASS_ICON,
            0x800F020D => SETUPAPI::SPAPI_E_INVALID_CLASS_INSTALLER,
            0x800F020E => SETUPAPI::SPAPI_E_DI_DO_DEFAULT,
            0x800F020F => SETUPAPI::SPAPI_E_DI_NOFILECOPY,
            0x800F0210 => SETUPAPI::SPAPI_E_INVALID_HWPROFILE,
            0x800F0211 => SETUPAPI::SPAPI_E_NO_DEVICE_SELECTED,
            0x800F0212 => SETUPAPI::SPAPI_E_DEVINFO_LIST_LOCKED,
            0x800F0213 => SETUPAPI::SPAPI_E_DEVINFO_DATA_LOCKED,
            0x800F0214 => SETUPAPI::SPAPI_E_DI_BAD_PATH,
            0x800F0215 => SETUPAPI::SPAPI_E_NO_CLASSINSTALL_PARAMS,
            0x800F0216 => SETUPAPI::SPAPI_E_FILEQUEUE_LOCKED,
            0x800F0217 => SETUPAPI::SPAPI_E_BAD_SERVICE_INSTALLSECT,
            0x800F0218 => SETUPAPI::SPAPI_E_NO_CLASS_DRIVER_LIST,
            0x800F0219 => SETUPAPI::SPAPI_E_NO_ASSOCIATED_SERVICE,
            0x800F021A => SETUPAPI::SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE,
            0x800F021B => SETUPAPI::SPAPI_E_DEVICE_INTERFACE_ACTIVE,
            0x800F021C => SETUPAPI::SPAPI_E_DEVICE_INTERFACE_REMOVED,
            0x800F021D => SETUPAPI::SPAPI_E_BAD_INTERFACE_INSTALLSECT,
            0x800F021E => SETUPAPI::SPAPI_E_NO_SUCH_INTERFACE_CLASS,
            0x800F021F => SETUPAPI::SPAPI_E_INVALID_REFERENCE_STRING,
            0x800F0220 => SETUPAPI::SPAPI_E_INVALID_MACHINENAME,
            0x800F0221 => SETUPAPI::SPAPI_E_REMOTE_COMM_FAILURE,
            0x800F0222 => SETUPAPI::SPAPI_E_MACHINE_UNAVAILABLE,
            0x800F0223 => SETUPAPI::SPAPI_E_NO_CONFIGMGR_SERVICES,
            0x800F0224 => SETUPAPI::SPAPI_E_INVALID_PROPPAGE_PROVIDER,
            0x800F0225 => SETUPAPI::SPAPI_E_NO_SUCH_DEVICE_INTERFACE,
            0x800F0226 => SETUPAPI::SPAPI_E_DI_POSTPROCESSING_REQUIRED,
            0x800F0227 => SETUPAPI::SPAPI_E_INVALID_COINSTALLER,
            0x800F0228 => SETUPAPI::SPAPI_E_NO_COMPAT_DRIVERS,
            0x800F0229 => SETUPAPI::SPAPI_E_NO_DEVICE_ICON,
            0x800F022A => SETUPAPI::SPAPI_E_INVALID_INF_LOGCONFIG,
            0x800F022B => SETUPAPI::SPAPI_E_DI_DONT_INSTALL,
            0x800F022C => SETUPAPI::SPAPI_E_INVALID_FILTER_DRIVER,
            0x800F022D => SETUPAPI::SPAPI_E_NON_WINDOWS_NT_DRIVER,
            0x800F022E => SETUPAPI::SPAPI_E_NON_WINDOWS_DRIVER,
            0x800F022F => SETUPAPI::SPAPI_E_NO_CATALOG_FOR_OEM_INF,
            0x800F0230 => SETUPAPI::SPAPI_E_DEVINSTALL_QUEUE_NONNATIVE,
            0x800F0231 => SETUPAPI::SPAPI_E_NOT_DISABLEABLE,
            0x800F0232 => SETUPAPI::SPAPI_E_CANT_REMOVE_DEVINST,
            0x800F0233 => SETUPAPI::SPAPI_E_INVALID_TARGET,
            0x800F0234 => SETUPAPI::SPAPI_E_DRIVER_NONNATIVE,
            0x800F0235 => SETUPAPI::SPAPI_E_IN_WOW64,
            0x800F0236 => SETUPAPI::SPAPI_E_SET_SYSTEM_RESTORE_POINT,
            0x800F0237 => SETUPAPI::SPAPI_E_INCORRECTLY_COPIED_INF,
            0x800F0238 => SETUPAPI::SPAPI_E_SCE_DISABLED,
            0x800F0239 => SETUPAPI::SPAPI_E_UNKNOWN_EXCEPTION,
            0x800F023A => SETUPAPI::SPAPI_E_PNP_REGISTRY_ERROR,
            0x800F023B => SETUPAPI::SPAPI_E_REMOTE_REQUEST_UNSUPPORTED,
            0x800F023C => SETUPAPI::SPAPI_E_NOT_AN_INSTALLED_OEM_INF,
            0x800F023D => SETUPAPI::SPAPI_E_INF_IN_USE_BY_DEVICES,
            0x800F023E => SETUPAPI::SPAPI_E_DI_FUNCTION_OBSOLETE,
            0x800F023F => SETUPAPI::SPAPI_E_NO_AUTHENTICODE_CATALOG,
            0x800F0240 => SETUPAPI::SPAPI_E_AUTHENTICODE_DISALLOWED,
            0x800F0241 => SETUPAPI::SPAPI_E_AUTHENTICODE_TRUSTED_PUBLISHER,
            0x800F0242 => SETUPAPI::SPAPI_E_AUTHENTICODE_TRUST_NOT_ESTABLISHED,
            0x800F0243 => SETUPAPI::SPAPI_E_AUTHENTICODE_PUBLISHER_NOT_TRUSTED,
            0x800F0244 => SETUPAPI::SPAPI_E_SIGNATURE_OSATTRIBUTE_MISMATCH,
            0x800F0245 => SETUPAPI::SPAPI_E_ONLY_VALIDATE_VIA_AUTHENTICODE,
            0x800F0246 => SETUPAPI::SPAPI_E_DEVICE_INSTALLER_NOT_READY,
            0x800F0247 => SETUPAPI::SPAPI_E_DRIVER_STORE_ADD_FAILED,
            0x800F0248 => SETUPAPI::SPAPI_E_DEVICE_INSTALL_BLOCKED,
            0x800F0249 => SETUPAPI::SPAPI_E_DRIVER_INSTALL_BLOCKED,
            0x800F024A => SETUPAPI::SPAPI_E_WRONG_INF_TYPE,
            0x800F024B => SETUPAPI::SPAPI_E_FILE_HASH_NOT_IN_CATALOG,
            0x800F024C => SETUPAPI::SPAPI_E_DRIVER_STORE_DELETE_FAILED,
            0x800F0300 => SETUPAPI::SPAPI_E_UNRECOVERABLE_STACK_OVERFLOW,
            0x800F1000 => SETUPAPI::SPAPI_E_ERROR_NOT_INSTALLED,
        }
    }
}
