/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum SQLITE {
    SQLITE_E_ERROR,
    SQLITE_E_INTERNAL,
    SQLITE_E_PERM,
    SQLITE_E_ABORT,
    SQLITE_E_BUSY,
    SQLITE_E_LOCKED,
    SQLITE_E_NOMEM,
    SQLITE_E_READONLY,
    SQLITE_E_INTERRUPT,
    SQLITE_E_IOERR,
    SQLITE_E_CORRUPT,
    SQLITE_E_NOTFOUND,
    SQLITE_E_FULL,
    SQLITE_E_CANTOPEN,
    SQLITE_E_PROTOCOL,
    SQLITE_E_EMPTY,
    SQLITE_E_SCHEMA,
    SQLITE_E_TOOBIG,
    SQLITE_E_CONSTRAINT,
    SQLITE_E_MISMATCH,
    SQLITE_E_MISUSE,
    SQLITE_E_NOLFS,
    SQLITE_E_AUTH,
    SQLITE_E_FORMAT,
    SQLITE_E_RANGE,
    SQLITE_E_NOTADB,
    SQLITE_E_NOTICE,
    SQLITE_E_WARNING,
    SQLITE_E_ROW,
    SQLITE_E_DONE,
    SQLITE_E_BUSY_RECOVERY,
    SQLITE_E_LOCKED_SHAREDCACHE,
    SQLITE_E_READONLY_RECOVERY,
    SQLITE_E_IOERR_READ,
    SQLITE_E_CORRUPT_VTAB,
    SQLITE_E_CANTOPEN_NOTEMPDIR,
    SQLITE_E_CONSTRAINT_CHECK,
    SQLITE_E_NOTICE_RECOVER_WAL,
    SQLITE_E_WARNING_AUTOINDEX,
    SQLITE_E_ABORT_ROLLBACK,
    SQLITE_E_BUSY_SNAPSHOT,
    SQLITE_E_READONLY_CANTLOCK,
    SQLITE_E_IOERR_SHORT_READ,
    SQLITE_E_CANTOPEN_ISDIR,
    SQLITE_E_CONSTRAINT_COMMITHOOK,
    SQLITE_E_NOTICE_RECOVER_ROLLBACK,
    SQLITE_E_READONLY_ROLLBACK,
    SQLITE_E_IOERR_WRITE,
    SQLITE_E_CANTOPEN_FULLPATH,
    SQLITE_E_CONSTRAINT_FOREIGNKEY,
    SQLITE_E_READONLY_DBMOVED,
    SQLITE_E_IOERR_FSYNC,
    SQLITE_E_CANTOPEN_CONVPATH,
    SQLITE_E_CONSTRAINT_FUNCTION,
    SQLITE_E_IOERR_DIR_FSYNC,
    SQLITE_E_CONSTRAINT_NOTNULL,
    SQLITE_E_IOERR_TRUNCATE,
    SQLITE_E_CONSTRAINT_PRIMARYKEY,
    SQLITE_E_IOERR_FSTAT,
    SQLITE_E_CONSTRAINT_TRIGGER,
    SQLITE_E_IOERR_UNLOCK,
    SQLITE_E_CONSTRAINT_UNIQUE,
    SQLITE_E_IOERR_RDLOCK,
    SQLITE_E_CONSTRAINT_VTAB,
    SQLITE_E_IOERR_DELETE,
    SQLITE_E_CONSTRAINT_ROWID,
    SQLITE_E_IOERR_BLOCKED,
    SQLITE_E_IOERR_NOMEM,
    SQLITE_E_IOERR_ACCESS,
    SQLITE_E_IOERR_CHECKRESERVEDLOCK,
    SQLITE_E_IOERR_LOCK,
    SQLITE_E_IOERR_CLOSE,
    SQLITE_E_IOERR_DIR_CLOSE,
    SQLITE_E_IOERR_SHMOPEN,
    SQLITE_E_IOERR_SHMSIZE,
    SQLITE_E_IOERR_SHMLOCK,
    SQLITE_E_IOERR_SHMMAP,
    SQLITE_E_IOERR_SEEK,
    SQLITE_E_IOERR_DELETE_NOENT,
    SQLITE_E_IOERR_MMAP,
    SQLITE_E_IOERR_GETTEMPPATH,
    SQLITE_E_IOERR_VNODE,
    SQLITE_E_IOERR_AUTH,
    SQLITE_E_IOERR_CONVPATH,
}

impl SQLITE {
    pub fn code(&self) -> u32 {
        return match self {
            SQLITE::SQLITE_E_ERROR => 0x87AF0001 as u32,
            SQLITE::SQLITE_E_INTERNAL => 0x87AF0002 as u32,
            SQLITE::SQLITE_E_PERM => 0x87AF0003 as u32,
            SQLITE::SQLITE_E_ABORT => 0x87AF0004 as u32,
            SQLITE::SQLITE_E_BUSY => 0x87AF0005 as u32,
            SQLITE::SQLITE_E_LOCKED => 0x87AF0006 as u32,
            SQLITE::SQLITE_E_NOMEM => 0x87AF0007 as u32,
            SQLITE::SQLITE_E_READONLY => 0x87AF0008 as u32,
            SQLITE::SQLITE_E_INTERRUPT => 0x87AF0009 as u32,
            SQLITE::SQLITE_E_IOERR => 0x87AF000A as u32,
            SQLITE::SQLITE_E_CORRUPT => 0x87AF000B as u32,
            SQLITE::SQLITE_E_NOTFOUND => 0x87AF000C as u32,
            SQLITE::SQLITE_E_FULL => 0x87AF000D as u32,
            SQLITE::SQLITE_E_CANTOPEN => 0x87AF000E as u32,
            SQLITE::SQLITE_E_PROTOCOL => 0x87AF000F as u32,
            SQLITE::SQLITE_E_EMPTY => 0x87AF0010 as u32,
            SQLITE::SQLITE_E_SCHEMA => 0x87AF0011 as u32,
            SQLITE::SQLITE_E_TOOBIG => 0x87AF0012 as u32,
            SQLITE::SQLITE_E_CONSTRAINT => 0x87AF0013 as u32,
            SQLITE::SQLITE_E_MISMATCH => 0x87AF0014 as u32,
            SQLITE::SQLITE_E_MISUSE => 0x87AF0015 as u32,
            SQLITE::SQLITE_E_NOLFS => 0x87AF0016 as u32,
            SQLITE::SQLITE_E_AUTH => 0x87AF0017 as u32,
            SQLITE::SQLITE_E_FORMAT => 0x87AF0018 as u32,
            SQLITE::SQLITE_E_RANGE => 0x87AF0019 as u32,
            SQLITE::SQLITE_E_NOTADB => 0x87AF001A as u32,
            SQLITE::SQLITE_E_NOTICE => 0x87AF001B as u32,
            SQLITE::SQLITE_E_WARNING => 0x87AF001C as u32,
            SQLITE::SQLITE_E_ROW => 0x87AF0064 as u32,
            SQLITE::SQLITE_E_DONE => 0x87AF0065 as u32,
            SQLITE::SQLITE_E_BUSY_RECOVERY => 0x87AF0105 as u32,
            SQLITE::SQLITE_E_LOCKED_SHAREDCACHE => 0x87AF0106 as u32,
            SQLITE::SQLITE_E_READONLY_RECOVERY => 0x87AF0108 as u32,
            SQLITE::SQLITE_E_IOERR_READ => 0x87AF010A as u32,
            SQLITE::SQLITE_E_CORRUPT_VTAB => 0x87AF010B as u32,
            SQLITE::SQLITE_E_CANTOPEN_NOTEMPDIR => 0x87AF010E as u32,
            SQLITE::SQLITE_E_CONSTRAINT_CHECK => 0x87AF0113 as u32,
            SQLITE::SQLITE_E_NOTICE_RECOVER_WAL => 0x87AF011B as u32,
            SQLITE::SQLITE_E_WARNING_AUTOINDEX => 0x87AF011C as u32,
            SQLITE::SQLITE_E_ABORT_ROLLBACK => 0x87AF0204 as u32,
            SQLITE::SQLITE_E_BUSY_SNAPSHOT => 0x87AF0205 as u32,
            SQLITE::SQLITE_E_READONLY_CANTLOCK => 0x87AF0208 as u32,
            SQLITE::SQLITE_E_IOERR_SHORT_READ => 0x87AF020A as u32,
            SQLITE::SQLITE_E_CANTOPEN_ISDIR => 0x87AF020E as u32,
            SQLITE::SQLITE_E_CONSTRAINT_COMMITHOOK => 0x87AF0213 as u32,
            SQLITE::SQLITE_E_NOTICE_RECOVER_ROLLBACK => 0x87AF021B as u32,
            SQLITE::SQLITE_E_READONLY_ROLLBACK => 0x87AF0308 as u32,
            SQLITE::SQLITE_E_IOERR_WRITE => 0x87AF030A as u32,
            SQLITE::SQLITE_E_CANTOPEN_FULLPATH => 0x87AF030E as u32,
            SQLITE::SQLITE_E_CONSTRAINT_FOREIGNKEY => 0x87AF0313 as u32,
            SQLITE::SQLITE_E_READONLY_DBMOVED => 0x87AF0408 as u32,
            SQLITE::SQLITE_E_IOERR_FSYNC => 0x87AF040A as u32,
            SQLITE::SQLITE_E_CANTOPEN_CONVPATH => 0x87AF040E as u32,
            SQLITE::SQLITE_E_CONSTRAINT_FUNCTION => 0x87AF0413 as u32,
            SQLITE::SQLITE_E_IOERR_DIR_FSYNC => 0x87AF050A as u32,
            SQLITE::SQLITE_E_CONSTRAINT_NOTNULL => 0x87AF0513 as u32,
            SQLITE::SQLITE_E_IOERR_TRUNCATE => 0x87AF060A as u32,
            SQLITE::SQLITE_E_CONSTRAINT_PRIMARYKEY => 0x87AF0613 as u32,
            SQLITE::SQLITE_E_IOERR_FSTAT => 0x87AF070A as u32,
            SQLITE::SQLITE_E_CONSTRAINT_TRIGGER => 0x87AF0713 as u32,
            SQLITE::SQLITE_E_IOERR_UNLOCK => 0x87AF080A as u32,
            SQLITE::SQLITE_E_CONSTRAINT_UNIQUE => 0x87AF0813 as u32,
            SQLITE::SQLITE_E_IOERR_RDLOCK => 0x87AF090A as u32,
            SQLITE::SQLITE_E_CONSTRAINT_VTAB => 0x87AF0913 as u32,
            SQLITE::SQLITE_E_IOERR_DELETE => 0x87AF0A0A as u32,
            SQLITE::SQLITE_E_CONSTRAINT_ROWID => 0x87AF0A13 as u32,
            SQLITE::SQLITE_E_IOERR_BLOCKED => 0x87AF0B0A as u32,
            SQLITE::SQLITE_E_IOERR_NOMEM => 0x87AF0C0A as u32,
            SQLITE::SQLITE_E_IOERR_ACCESS => 0x87AF0D0A as u32,
            SQLITE::SQLITE_E_IOERR_CHECKRESERVEDLOCK => 0x87AF0E0A as u32,
            SQLITE::SQLITE_E_IOERR_LOCK => 0x87AF0F0A as u32,
            SQLITE::SQLITE_E_IOERR_CLOSE => 0x87AF100A as u32,
            SQLITE::SQLITE_E_IOERR_DIR_CLOSE => 0x87AF110A as u32,
            SQLITE::SQLITE_E_IOERR_SHMOPEN => 0x87AF120A as u32,
            SQLITE::SQLITE_E_IOERR_SHMSIZE => 0x87AF130A as u32,
            SQLITE::SQLITE_E_IOERR_SHMLOCK => 0x87AF140A as u32,
            SQLITE::SQLITE_E_IOERR_SHMMAP => 0x87AF150A as u32,
            SQLITE::SQLITE_E_IOERR_SEEK => 0x87AF160A as u32,
            SQLITE::SQLITE_E_IOERR_DELETE_NOENT => 0x87AF170A as u32,
            SQLITE::SQLITE_E_IOERR_MMAP => 0x87AF180A as u32,
            SQLITE::SQLITE_E_IOERR_GETTEMPPATH => 0x87AF190A as u32,
            SQLITE::SQLITE_E_IOERR_VNODE => 0x87AF1A02 as u32,
            SQLITE::SQLITE_E_IOERR_AUTH => 0x87AF1A03 as u32,
            SQLITE::SQLITE_E_IOERR_CONVPATH => 0x87AF1A0A as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            SQLITE::SQLITE_E_ERROR => RawError::Kind(SQLITE::SQLITE_E_ERROR),
            SQLITE::SQLITE_E_INTERNAL => RawError::Kind(SQLITE::SQLITE_E_INTERNAL),
            SQLITE::SQLITE_E_PERM => RawError::Kind(SQLITE::SQLITE_E_PERM),
            SQLITE::SQLITE_E_ABORT => RawError::Kind(SQLITE::SQLITE_E_ABORT),
            SQLITE::SQLITE_E_BUSY => RawError::Kind(SQLITE::SQLITE_E_BUSY),
            SQLITE::SQLITE_E_LOCKED => RawError::Kind(SQLITE::SQLITE_E_LOCKED),
            SQLITE::SQLITE_E_NOMEM => RawError::Kind(SQLITE::SQLITE_E_NOMEM),
            SQLITE::SQLITE_E_READONLY => RawError::Kind(SQLITE::SQLITE_E_READONLY),
            SQLITE::SQLITE_E_INTERRUPT => RawError::Kind(SQLITE::SQLITE_E_INTERRUPT),
            SQLITE::SQLITE_E_IOERR => RawError::Kind(SQLITE::SQLITE_E_IOERR),
            SQLITE::SQLITE_E_CORRUPT => RawError::Kind(SQLITE::SQLITE_E_CORRUPT),
            SQLITE::SQLITE_E_NOTFOUND => RawError::Kind(SQLITE::SQLITE_E_NOTFOUND),
            SQLITE::SQLITE_E_FULL => RawError::Kind(SQLITE::SQLITE_E_FULL),
            SQLITE::SQLITE_E_CANTOPEN => RawError::Kind(SQLITE::SQLITE_E_CANTOPEN),
            SQLITE::SQLITE_E_PROTOCOL => RawError::Kind(SQLITE::SQLITE_E_PROTOCOL),
            SQLITE::SQLITE_E_EMPTY => RawError::Kind(SQLITE::SQLITE_E_EMPTY),
            SQLITE::SQLITE_E_SCHEMA => RawError::Kind(SQLITE::SQLITE_E_SCHEMA),
            SQLITE::SQLITE_E_TOOBIG => RawError::Kind(SQLITE::SQLITE_E_TOOBIG),
            SQLITE::SQLITE_E_CONSTRAINT => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT),
            SQLITE::SQLITE_E_MISMATCH => RawError::Kind(SQLITE::SQLITE_E_MISMATCH),
            SQLITE::SQLITE_E_MISUSE => RawError::Kind(SQLITE::SQLITE_E_MISUSE),
            SQLITE::SQLITE_E_NOLFS => RawError::Kind(SQLITE::SQLITE_E_NOLFS),
            SQLITE::SQLITE_E_AUTH => RawError::Kind(SQLITE::SQLITE_E_AUTH),
            SQLITE::SQLITE_E_FORMAT => RawError::Kind(SQLITE::SQLITE_E_FORMAT),
            SQLITE::SQLITE_E_RANGE => RawError::Kind(SQLITE::SQLITE_E_RANGE),
            SQLITE::SQLITE_E_NOTADB => RawError::Kind(SQLITE::SQLITE_E_NOTADB),
            SQLITE::SQLITE_E_NOTICE => RawError::Kind(SQLITE::SQLITE_E_NOTICE),
            SQLITE::SQLITE_E_WARNING => RawError::Kind(SQLITE::SQLITE_E_WARNING),
            SQLITE::SQLITE_E_ROW => RawError::Kind(SQLITE::SQLITE_E_ROW),
            SQLITE::SQLITE_E_DONE => RawError::Kind(SQLITE::SQLITE_E_DONE),
            SQLITE::SQLITE_E_BUSY_RECOVERY => RawError::Kind(SQLITE::SQLITE_E_BUSY_RECOVERY),
            SQLITE::SQLITE_E_LOCKED_SHAREDCACHE => RawError::Kind(SQLITE::SQLITE_E_LOCKED_SHAREDCACHE),
            SQLITE::SQLITE_E_READONLY_RECOVERY => RawError::Kind(SQLITE::SQLITE_E_READONLY_RECOVERY),
            SQLITE::SQLITE_E_IOERR_READ => RawError::Kind(SQLITE::SQLITE_E_IOERR_READ),
            SQLITE::SQLITE_E_CORRUPT_VTAB => RawError::Kind(SQLITE::SQLITE_E_CORRUPT_VTAB),
            SQLITE::SQLITE_E_CANTOPEN_NOTEMPDIR => RawError::Kind(SQLITE::SQLITE_E_CANTOPEN_NOTEMPDIR),
            SQLITE::SQLITE_E_CONSTRAINT_CHECK => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_CHECK),
            SQLITE::SQLITE_E_NOTICE_RECOVER_WAL => RawError::Kind(SQLITE::SQLITE_E_NOTICE_RECOVER_WAL),
            SQLITE::SQLITE_E_WARNING_AUTOINDEX => RawError::Kind(SQLITE::SQLITE_E_WARNING_AUTOINDEX),
            SQLITE::SQLITE_E_ABORT_ROLLBACK => RawError::Kind(SQLITE::SQLITE_E_ABORT_ROLLBACK),
            SQLITE::SQLITE_E_BUSY_SNAPSHOT => RawError::Kind(SQLITE::SQLITE_E_BUSY_SNAPSHOT),
            SQLITE::SQLITE_E_READONLY_CANTLOCK => RawError::Kind(SQLITE::SQLITE_E_READONLY_CANTLOCK),
            SQLITE::SQLITE_E_IOERR_SHORT_READ => RawError::Kind(SQLITE::SQLITE_E_IOERR_SHORT_READ),
            SQLITE::SQLITE_E_CANTOPEN_ISDIR => RawError::Kind(SQLITE::SQLITE_E_CANTOPEN_ISDIR),
            SQLITE::SQLITE_E_CONSTRAINT_COMMITHOOK => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_COMMITHOOK),
            SQLITE::SQLITE_E_NOTICE_RECOVER_ROLLBACK => RawError::Kind(SQLITE::SQLITE_E_NOTICE_RECOVER_ROLLBACK),
            SQLITE::SQLITE_E_READONLY_ROLLBACK => RawError::Kind(SQLITE::SQLITE_E_READONLY_ROLLBACK),
            SQLITE::SQLITE_E_IOERR_WRITE => RawError::Kind(SQLITE::SQLITE_E_IOERR_WRITE),
            SQLITE::SQLITE_E_CANTOPEN_FULLPATH => RawError::Kind(SQLITE::SQLITE_E_CANTOPEN_FULLPATH),
            SQLITE::SQLITE_E_CONSTRAINT_FOREIGNKEY => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_FOREIGNKEY),
            SQLITE::SQLITE_E_READONLY_DBMOVED => RawError::Kind(SQLITE::SQLITE_E_READONLY_DBMOVED),
            SQLITE::SQLITE_E_IOERR_FSYNC => RawError::Kind(SQLITE::SQLITE_E_IOERR_FSYNC),
            SQLITE::SQLITE_E_CANTOPEN_CONVPATH => RawError::Kind(SQLITE::SQLITE_E_CANTOPEN_CONVPATH),
            SQLITE::SQLITE_E_CONSTRAINT_FUNCTION => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_FUNCTION),
            SQLITE::SQLITE_E_IOERR_DIR_FSYNC => RawError::Kind(SQLITE::SQLITE_E_IOERR_DIR_FSYNC),
            SQLITE::SQLITE_E_CONSTRAINT_NOTNULL => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_NOTNULL),
            SQLITE::SQLITE_E_IOERR_TRUNCATE => RawError::Kind(SQLITE::SQLITE_E_IOERR_TRUNCATE),
            SQLITE::SQLITE_E_CONSTRAINT_PRIMARYKEY => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_PRIMARYKEY),
            SQLITE::SQLITE_E_IOERR_FSTAT => RawError::Kind(SQLITE::SQLITE_E_IOERR_FSTAT),
            SQLITE::SQLITE_E_CONSTRAINT_TRIGGER => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_TRIGGER),
            SQLITE::SQLITE_E_IOERR_UNLOCK => RawError::Kind(SQLITE::SQLITE_E_IOERR_UNLOCK),
            SQLITE::SQLITE_E_CONSTRAINT_UNIQUE => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_UNIQUE),
            SQLITE::SQLITE_E_IOERR_RDLOCK => RawError::Kind(SQLITE::SQLITE_E_IOERR_RDLOCK),
            SQLITE::SQLITE_E_CONSTRAINT_VTAB => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_VTAB),
            SQLITE::SQLITE_E_IOERR_DELETE => RawError::Kind(SQLITE::SQLITE_E_IOERR_DELETE),
            SQLITE::SQLITE_E_CONSTRAINT_ROWID => RawError::Kind(SQLITE::SQLITE_E_CONSTRAINT_ROWID),
            SQLITE::SQLITE_E_IOERR_BLOCKED => RawError::Kind(SQLITE::SQLITE_E_IOERR_BLOCKED),
            SQLITE::SQLITE_E_IOERR_NOMEM => RawError::Kind(SQLITE::SQLITE_E_IOERR_NOMEM),
            SQLITE::SQLITE_E_IOERR_ACCESS => RawError::Kind(SQLITE::SQLITE_E_IOERR_ACCESS),
            SQLITE::SQLITE_E_IOERR_CHECKRESERVEDLOCK => RawError::Kind(SQLITE::SQLITE_E_IOERR_CHECKRESERVEDLOCK),
            SQLITE::SQLITE_E_IOERR_LOCK => RawError::Kind(SQLITE::SQLITE_E_IOERR_LOCK),
            SQLITE::SQLITE_E_IOERR_CLOSE => RawError::Kind(SQLITE::SQLITE_E_IOERR_CLOSE),
            SQLITE::SQLITE_E_IOERR_DIR_CLOSE => RawError::Kind(SQLITE::SQLITE_E_IOERR_DIR_CLOSE),
            SQLITE::SQLITE_E_IOERR_SHMOPEN => RawError::Kind(SQLITE::SQLITE_E_IOERR_SHMOPEN),
            SQLITE::SQLITE_E_IOERR_SHMSIZE => RawError::Kind(SQLITE::SQLITE_E_IOERR_SHMSIZE),
            SQLITE::SQLITE_E_IOERR_SHMLOCK => RawError::Kind(SQLITE::SQLITE_E_IOERR_SHMLOCK),
            SQLITE::SQLITE_E_IOERR_SHMMAP => RawError::Kind(SQLITE::SQLITE_E_IOERR_SHMMAP),
            SQLITE::SQLITE_E_IOERR_SEEK => RawError::Kind(SQLITE::SQLITE_E_IOERR_SEEK),
            SQLITE::SQLITE_E_IOERR_DELETE_NOENT => RawError::Kind(SQLITE::SQLITE_E_IOERR_DELETE_NOENT),
            SQLITE::SQLITE_E_IOERR_MMAP => RawError::Kind(SQLITE::SQLITE_E_IOERR_MMAP),
            SQLITE::SQLITE_E_IOERR_GETTEMPPATH => RawError::Kind(SQLITE::SQLITE_E_IOERR_GETTEMPPATH),
            SQLITE::SQLITE_E_IOERR_VNODE => RawError::Kind(SQLITE::SQLITE_E_IOERR_VNODE),
            SQLITE::SQLITE_E_IOERR_AUTH => RawError::Kind(SQLITE::SQLITE_E_IOERR_AUTH),
            SQLITE::SQLITE_E_IOERR_CONVPATH => RawError::Kind(SQLITE::SQLITE_E_IOERR_CONVPATH),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            SQLITE::SQLITE_E_ERROR => "SQL error or missing database",
            SQLITE::SQLITE_E_INTERNAL => "Internal logic error in SQLite",
            SQLITE::SQLITE_E_PERM => "Access permission denied",
            SQLITE::SQLITE_E_ABORT => "Callback routine requested an abort",
            SQLITE::SQLITE_E_BUSY => "The database file is locked",
            SQLITE::SQLITE_E_LOCKED => "A table in the database is locked",
            SQLITE::SQLITE_E_NOMEM => "A malloc() failed",
            SQLITE::SQLITE_E_READONLY => "Attempt to write a readonly database",
            SQLITE::SQLITE_E_INTERRUPT => "Operation terminated by sqlite3_interrupt()",
            SQLITE::SQLITE_E_IOERR => "Some kind of disk I/O error occurred",
            SQLITE::SQLITE_E_CORRUPT => "The database disk image is malformed",
            SQLITE::SQLITE_E_NOTFOUND => "Unknown opcode in sqlite3_file_control()",
            SQLITE::SQLITE_E_FULL => "Insertion failed because database is full",
            SQLITE::SQLITE_E_CANTOPEN => "Unable to open the database file",
            SQLITE::SQLITE_E_PROTOCOL => "Database lock protocol error",
            SQLITE::SQLITE_E_EMPTY => "Database is empty",
            SQLITE::SQLITE_E_SCHEMA => "The database schema changed",
            SQLITE::SQLITE_E_TOOBIG => "String or BLOB exceeds size limit",
            SQLITE::SQLITE_E_CONSTRAINT => "Abort due to constraint violation",
            SQLITE::SQLITE_E_MISMATCH => "Data type mismatch",
            SQLITE::SQLITE_E_MISUSE => "Library used incorrectly",
            SQLITE::SQLITE_E_NOLFS => "Uses OS features not supported on host",
            SQLITE::SQLITE_E_AUTH => "Authorization denied",
            SQLITE::SQLITE_E_FORMAT => "Auxiliary database format error",
            SQLITE::SQLITE_E_RANGE => "2nd parameter to sqlite3_bind out of range",
            SQLITE::SQLITE_E_NOTADB => "File opened that is not a database file",
            SQLITE::SQLITE_E_NOTICE => "Notifications from sqlite3_log()",
            SQLITE::SQLITE_E_WARNING => "Warnings from sqlite3_log()",
            SQLITE::SQLITE_E_ROW => "sqlite3_step() has another row ready",
            SQLITE::SQLITE_E_DONE => "sqlite3_step() has finished executing",
            SQLITE::SQLITE_E_BUSY_RECOVERY => "SQLITE_BUSY_RECOVERY",
            SQLITE::SQLITE_E_LOCKED_SHAREDCACHE => "SQLITE_LOCKED_SHAREDCACHE",
            SQLITE::SQLITE_E_READONLY_RECOVERY => "SQLITE_READONLY_RECOVERY",
            SQLITE::SQLITE_E_IOERR_READ => "SQLITE_IOERR_READ",
            SQLITE::SQLITE_E_CORRUPT_VTAB => "SQLITE_CORRUPT_VTAB",
            SQLITE::SQLITE_E_CANTOPEN_NOTEMPDIR => "SQLITE_CANTOPEN_NOTEMPDIR",
            SQLITE::SQLITE_E_CONSTRAINT_CHECK => "SQLITE_CONSTRAINT_CHECK",
            SQLITE::SQLITE_E_NOTICE_RECOVER_WAL => "SQLITE_NOTICE_RECOVER_WAL",
            SQLITE::SQLITE_E_WARNING_AUTOINDEX => "SQLITE_WARNING_AUTOINDEX",
            SQLITE::SQLITE_E_ABORT_ROLLBACK => "SQLITE_ABORT_ROLLBACK",
            SQLITE::SQLITE_E_BUSY_SNAPSHOT => "SQLITE_BUSY_SNAPSHOT",
            SQLITE::SQLITE_E_READONLY_CANTLOCK => "SQLITE_READONLY_CANTLOCK",
            SQLITE::SQLITE_E_IOERR_SHORT_READ => "SQLITE_IOERR_SHORT_READ",
            SQLITE::SQLITE_E_CANTOPEN_ISDIR => "SQLITE_CANTOPEN_ISDIR",
            SQLITE::SQLITE_E_CONSTRAINT_COMMITHOOK => "SQLITE_CONSTRAINT_COMMITHOOK",
            SQLITE::SQLITE_E_NOTICE_RECOVER_ROLLBACK => "SQLITE_NOTICE_RECOVER_ROLLBACK",
            SQLITE::SQLITE_E_READONLY_ROLLBACK => "SQLITE_READONLY_ROLLBACK",
            SQLITE::SQLITE_E_IOERR_WRITE => "SQLITE_IOERR_WRITE",
            SQLITE::SQLITE_E_CANTOPEN_FULLPATH => "SQLITE_CANTOPEN_FULLPATH",
            SQLITE::SQLITE_E_CONSTRAINT_FOREIGNKEY => "SQLITE_CONSTRAINT_FOREIGNKEY",
            SQLITE::SQLITE_E_READONLY_DBMOVED => "SQLITE_READONLY_DBMOVED",
            SQLITE::SQLITE_E_IOERR_FSYNC => "SQLITE_IOERR_FSYNC",
            SQLITE::SQLITE_E_CANTOPEN_CONVPATH => "SQLITE_CANTOPEN_CONVPATH",
            SQLITE::SQLITE_E_CONSTRAINT_FUNCTION => "SQLITE_CONSTRAINT_FUNCTION",
            SQLITE::SQLITE_E_IOERR_DIR_FSYNC => "SQLITE_IOERR_DIR_FSYNC",
            SQLITE::SQLITE_E_CONSTRAINT_NOTNULL => "SQLITE_CONSTRAINT_NOTNULL",
            SQLITE::SQLITE_E_IOERR_TRUNCATE => "SQLITE_IOERR_TRUNCATE",
            SQLITE::SQLITE_E_CONSTRAINT_PRIMARYKEY => "SQLITE_CONSTRAINT_PRIMARYKEY",
            SQLITE::SQLITE_E_IOERR_FSTAT => "SQLITE_IOERR_FSTAT",
            SQLITE::SQLITE_E_CONSTRAINT_TRIGGER => "SQLITE_CONSTRAINT_TRIGGER",
            SQLITE::SQLITE_E_IOERR_UNLOCK => "SQLITE_IOERR_UNLOCK",
            SQLITE::SQLITE_E_CONSTRAINT_UNIQUE => "SQLITE_CONSTRAINT_UNIQUE",
            SQLITE::SQLITE_E_IOERR_RDLOCK => "SQLITE_IOERR_RDLOCK",
            SQLITE::SQLITE_E_CONSTRAINT_VTAB => "SQLITE_CONSTRAINT_VTAB",
            SQLITE::SQLITE_E_IOERR_DELETE => "SQLITE_IOERR_DELETE",
            SQLITE::SQLITE_E_CONSTRAINT_ROWID => "SQLITE_CONSTRAINT_ROWID",
            SQLITE::SQLITE_E_IOERR_BLOCKED => "SQLITE_IOERR_BLOCKED",
            SQLITE::SQLITE_E_IOERR_NOMEM => "SQLITE_IOERR_NOMEM",
            SQLITE::SQLITE_E_IOERR_ACCESS => "SQLITE_IOERR_ACCESS",
            SQLITE::SQLITE_E_IOERR_CHECKRESERVEDLOCK => "SQLITE_IOERR_CHECKRESERVEDLOCK",
            SQLITE::SQLITE_E_IOERR_LOCK => "SQLITE_IOERR_LOCK",
            SQLITE::SQLITE_E_IOERR_CLOSE => "SQLITE_IOERR_CLOSE",
            SQLITE::SQLITE_E_IOERR_DIR_CLOSE => "SQLITE_IOERR_DIR_CLOSE",
            SQLITE::SQLITE_E_IOERR_SHMOPEN => "SQLITE_IOERR_SHMOPEN",
            SQLITE::SQLITE_E_IOERR_SHMSIZE => "SQLITE_IOERR_SHMSIZE",
            SQLITE::SQLITE_E_IOERR_SHMLOCK => "SQLITE_IOERR_SHMLOCK",
            SQLITE::SQLITE_E_IOERR_SHMMAP => "SQLITE_IOERR_SHMMAP",
            SQLITE::SQLITE_E_IOERR_SEEK => "SQLITE_IOERR_SEEK",
            SQLITE::SQLITE_E_IOERR_DELETE_NOENT => "SQLITE_IOERR_DELETE_NOENT",
            SQLITE::SQLITE_E_IOERR_MMAP => "SQLITE_IOERR_MMAP",
            SQLITE::SQLITE_E_IOERR_GETTEMPPATH => "SQLITE_IOERR_GETTEMPPATH",
            SQLITE::SQLITE_E_IOERR_VNODE => "SQLITE_IOERR_VNODE",
            SQLITE::SQLITE_E_IOERR_AUTH => "SQLITE_IOERR_AUTH",
            SQLITE::SQLITE_E_IOERR_CONVPATH => "SQLITE_IOERR_CONVPATH",
        }
    }

    pub fn from_name(name: &str) -> SQLITE {
        return match name {
            "SQLITE_E_ERROR" => SQLITE::SQLITE_E_ERROR,
            "SQLITE_E_INTERNAL" => SQLITE::SQLITE_E_INTERNAL,
            "SQLITE_E_PERM" => SQLITE::SQLITE_E_PERM,
            "SQLITE_E_ABORT" => SQLITE::SQLITE_E_ABORT,
            "SQLITE_E_BUSY" => SQLITE::SQLITE_E_BUSY,
            "SQLITE_E_LOCKED" => SQLITE::SQLITE_E_LOCKED,
            "SQLITE_E_NOMEM" => SQLITE::SQLITE_E_NOMEM,
            "SQLITE_E_READONLY" => SQLITE::SQLITE_E_READONLY,
            "SQLITE_E_INTERRUPT" => SQLITE::SQLITE_E_INTERRUPT,
            "SQLITE_E_IOERR" => SQLITE::SQLITE_E_IOERR,
            "SQLITE_E_CORRUPT" => SQLITE::SQLITE_E_CORRUPT,
            "SQLITE_E_NOTFOUND" => SQLITE::SQLITE_E_NOTFOUND,
            "SQLITE_E_FULL" => SQLITE::SQLITE_E_FULL,
            "SQLITE_E_CANTOPEN" => SQLITE::SQLITE_E_CANTOPEN,
            "SQLITE_E_PROTOCOL" => SQLITE::SQLITE_E_PROTOCOL,
            "SQLITE_E_EMPTY" => SQLITE::SQLITE_E_EMPTY,
            "SQLITE_E_SCHEMA" => SQLITE::SQLITE_E_SCHEMA,
            "SQLITE_E_TOOBIG" => SQLITE::SQLITE_E_TOOBIG,
            "SQLITE_E_CONSTRAINT" => SQLITE::SQLITE_E_CONSTRAINT,
            "SQLITE_E_MISMATCH" => SQLITE::SQLITE_E_MISMATCH,
            "SQLITE_E_MISUSE" => SQLITE::SQLITE_E_MISUSE,
            "SQLITE_E_NOLFS" => SQLITE::SQLITE_E_NOLFS,
            "SQLITE_E_AUTH" => SQLITE::SQLITE_E_AUTH,
            "SQLITE_E_FORMAT" => SQLITE::SQLITE_E_FORMAT,
            "SQLITE_E_RANGE" => SQLITE::SQLITE_E_RANGE,
            "SQLITE_E_NOTADB" => SQLITE::SQLITE_E_NOTADB,
            "SQLITE_E_NOTICE" => SQLITE::SQLITE_E_NOTICE,
            "SQLITE_E_WARNING" => SQLITE::SQLITE_E_WARNING,
            "SQLITE_E_ROW" => SQLITE::SQLITE_E_ROW,
            "SQLITE_E_DONE" => SQLITE::SQLITE_E_DONE,
            "SQLITE_E_BUSY_RECOVERY" => SQLITE::SQLITE_E_BUSY_RECOVERY,
            "SQLITE_E_LOCKED_SHAREDCACHE" => SQLITE::SQLITE_E_LOCKED_SHAREDCACHE,
            "SQLITE_E_READONLY_RECOVERY" => SQLITE::SQLITE_E_READONLY_RECOVERY,
            "SQLITE_E_IOERR_READ" => SQLITE::SQLITE_E_IOERR_READ,
            "SQLITE_E_CORRUPT_VTAB" => SQLITE::SQLITE_E_CORRUPT_VTAB,
            "SQLITE_E_CANTOPEN_NOTEMPDIR" => SQLITE::SQLITE_E_CANTOPEN_NOTEMPDIR,
            "SQLITE_E_CONSTRAINT_CHECK" => SQLITE::SQLITE_E_CONSTRAINT_CHECK,
            "SQLITE_E_NOTICE_RECOVER_WAL" => SQLITE::SQLITE_E_NOTICE_RECOVER_WAL,
            "SQLITE_E_WARNING_AUTOINDEX" => SQLITE::SQLITE_E_WARNING_AUTOINDEX,
            "SQLITE_E_ABORT_ROLLBACK" => SQLITE::SQLITE_E_ABORT_ROLLBACK,
            "SQLITE_E_BUSY_SNAPSHOT" => SQLITE::SQLITE_E_BUSY_SNAPSHOT,
            "SQLITE_E_READONLY_CANTLOCK" => SQLITE::SQLITE_E_READONLY_CANTLOCK,
            "SQLITE_E_IOERR_SHORT_READ" => SQLITE::SQLITE_E_IOERR_SHORT_READ,
            "SQLITE_E_CANTOPEN_ISDIR" => SQLITE::SQLITE_E_CANTOPEN_ISDIR,
            "SQLITE_E_CONSTRAINT_COMMITHOOK" => SQLITE::SQLITE_E_CONSTRAINT_COMMITHOOK,
            "SQLITE_E_NOTICE_RECOVER_ROLLBACK" => SQLITE::SQLITE_E_NOTICE_RECOVER_ROLLBACK,
            "SQLITE_E_READONLY_ROLLBACK" => SQLITE::SQLITE_E_READONLY_ROLLBACK,
            "SQLITE_E_IOERR_WRITE" => SQLITE::SQLITE_E_IOERR_WRITE,
            "SQLITE_E_CANTOPEN_FULLPATH" => SQLITE::SQLITE_E_CANTOPEN_FULLPATH,
            "SQLITE_E_CONSTRAINT_FOREIGNKEY" => SQLITE::SQLITE_E_CONSTRAINT_FOREIGNKEY,
            "SQLITE_E_READONLY_DBMOVED" => SQLITE::SQLITE_E_READONLY_DBMOVED,
            "SQLITE_E_IOERR_FSYNC" => SQLITE::SQLITE_E_IOERR_FSYNC,
            "SQLITE_E_CANTOPEN_CONVPATH" => SQLITE::SQLITE_E_CANTOPEN_CONVPATH,
            "SQLITE_E_CONSTRAINT_FUNCTION" => SQLITE::SQLITE_E_CONSTRAINT_FUNCTION,
            "SQLITE_E_IOERR_DIR_FSYNC" => SQLITE::SQLITE_E_IOERR_DIR_FSYNC,
            "SQLITE_E_CONSTRAINT_NOTNULL" => SQLITE::SQLITE_E_CONSTRAINT_NOTNULL,
            "SQLITE_E_IOERR_TRUNCATE" => SQLITE::SQLITE_E_IOERR_TRUNCATE,
            "SQLITE_E_CONSTRAINT_PRIMARYKEY" => SQLITE::SQLITE_E_CONSTRAINT_PRIMARYKEY,
            "SQLITE_E_IOERR_FSTAT" => SQLITE::SQLITE_E_IOERR_FSTAT,
            "SQLITE_E_CONSTRAINT_TRIGGER" => SQLITE::SQLITE_E_CONSTRAINT_TRIGGER,
            "SQLITE_E_IOERR_UNLOCK" => SQLITE::SQLITE_E_IOERR_UNLOCK,
            "SQLITE_E_CONSTRAINT_UNIQUE" => SQLITE::SQLITE_E_CONSTRAINT_UNIQUE,
            "SQLITE_E_IOERR_RDLOCK" => SQLITE::SQLITE_E_IOERR_RDLOCK,
            "SQLITE_E_CONSTRAINT_VTAB" => SQLITE::SQLITE_E_CONSTRAINT_VTAB,
            "SQLITE_E_IOERR_DELETE" => SQLITE::SQLITE_E_IOERR_DELETE,
            "SQLITE_E_CONSTRAINT_ROWID" => SQLITE::SQLITE_E_CONSTRAINT_ROWID,
            "SQLITE_E_IOERR_BLOCKED" => SQLITE::SQLITE_E_IOERR_BLOCKED,
            "SQLITE_E_IOERR_NOMEM" => SQLITE::SQLITE_E_IOERR_NOMEM,
            "SQLITE_E_IOERR_ACCESS" => SQLITE::SQLITE_E_IOERR_ACCESS,
            "SQLITE_E_IOERR_CHECKRESERVEDLOCK" => SQLITE::SQLITE_E_IOERR_CHECKRESERVEDLOCK,
            "SQLITE_E_IOERR_LOCK" => SQLITE::SQLITE_E_IOERR_LOCK,
            "SQLITE_E_IOERR_CLOSE" => SQLITE::SQLITE_E_IOERR_CLOSE,
            "SQLITE_E_IOERR_DIR_CLOSE" => SQLITE::SQLITE_E_IOERR_DIR_CLOSE,
            "SQLITE_E_IOERR_SHMOPEN" => SQLITE::SQLITE_E_IOERR_SHMOPEN,
            "SQLITE_E_IOERR_SHMSIZE" => SQLITE::SQLITE_E_IOERR_SHMSIZE,
            "SQLITE_E_IOERR_SHMLOCK" => SQLITE::SQLITE_E_IOERR_SHMLOCK,
            "SQLITE_E_IOERR_SHMMAP" => SQLITE::SQLITE_E_IOERR_SHMMAP,
            "SQLITE_E_IOERR_SEEK" => SQLITE::SQLITE_E_IOERR_SEEK,
            "SQLITE_E_IOERR_DELETE_NOENT" => SQLITE::SQLITE_E_IOERR_DELETE_NOENT,
            "SQLITE_E_IOERR_MMAP" => SQLITE::SQLITE_E_IOERR_MMAP,
            "SQLITE_E_IOERR_GETTEMPPATH" => SQLITE::SQLITE_E_IOERR_GETTEMPPATH,
            "SQLITE_E_IOERR_VNODE" => SQLITE::SQLITE_E_IOERR_VNODE,
            "SQLITE_E_IOERR_AUTH" => SQLITE::SQLITE_E_IOERR_AUTH,
            "SQLITE_E_IOERR_CONVPATH" => SQLITE::SQLITE_E_IOERR_CONVPATH,
        }
    }
    pub fn from_code(code: u32) -> SQLITE {
        return match code {
            0x87AF0001 => SQLITE::SQLITE_E_ERROR,
            0x87AF0002 => SQLITE::SQLITE_E_INTERNAL,
            0x87AF0003 => SQLITE::SQLITE_E_PERM,
            0x87AF0004 => SQLITE::SQLITE_E_ABORT,
            0x87AF0005 => SQLITE::SQLITE_E_BUSY,
            0x87AF0006 => SQLITE::SQLITE_E_LOCKED,
            0x87AF0007 => SQLITE::SQLITE_E_NOMEM,
            0x87AF0008 => SQLITE::SQLITE_E_READONLY,
            0x87AF0009 => SQLITE::SQLITE_E_INTERRUPT,
            0x87AF000A => SQLITE::SQLITE_E_IOERR,
            0x87AF000B => SQLITE::SQLITE_E_CORRUPT,
            0x87AF000C => SQLITE::SQLITE_E_NOTFOUND,
            0x87AF000D => SQLITE::SQLITE_E_FULL,
            0x87AF000E => SQLITE::SQLITE_E_CANTOPEN,
            0x87AF000F => SQLITE::SQLITE_E_PROTOCOL,
            0x87AF0010 => SQLITE::SQLITE_E_EMPTY,
            0x87AF0011 => SQLITE::SQLITE_E_SCHEMA,
            0x87AF0012 => SQLITE::SQLITE_E_TOOBIG,
            0x87AF0013 => SQLITE::SQLITE_E_CONSTRAINT,
            0x87AF0014 => SQLITE::SQLITE_E_MISMATCH,
            0x87AF0015 => SQLITE::SQLITE_E_MISUSE,
            0x87AF0016 => SQLITE::SQLITE_E_NOLFS,
            0x87AF0017 => SQLITE::SQLITE_E_AUTH,
            0x87AF0018 => SQLITE::SQLITE_E_FORMAT,
            0x87AF0019 => SQLITE::SQLITE_E_RANGE,
            0x87AF001A => SQLITE::SQLITE_E_NOTADB,
            0x87AF001B => SQLITE::SQLITE_E_NOTICE,
            0x87AF001C => SQLITE::SQLITE_E_WARNING,
            0x87AF0064 => SQLITE::SQLITE_E_ROW,
            0x87AF0065 => SQLITE::SQLITE_E_DONE,
            0x87AF0105 => SQLITE::SQLITE_E_BUSY_RECOVERY,
            0x87AF0106 => SQLITE::SQLITE_E_LOCKED_SHAREDCACHE,
            0x87AF0108 => SQLITE::SQLITE_E_READONLY_RECOVERY,
            0x87AF010A => SQLITE::SQLITE_E_IOERR_READ,
            0x87AF010B => SQLITE::SQLITE_E_CORRUPT_VTAB,
            0x87AF010E => SQLITE::SQLITE_E_CANTOPEN_NOTEMPDIR,
            0x87AF0113 => SQLITE::SQLITE_E_CONSTRAINT_CHECK,
            0x87AF011B => SQLITE::SQLITE_E_NOTICE_RECOVER_WAL,
            0x87AF011C => SQLITE::SQLITE_E_WARNING_AUTOINDEX,
            0x87AF0204 => SQLITE::SQLITE_E_ABORT_ROLLBACK,
            0x87AF0205 => SQLITE::SQLITE_E_BUSY_SNAPSHOT,
            0x87AF0208 => SQLITE::SQLITE_E_READONLY_CANTLOCK,
            0x87AF020A => SQLITE::SQLITE_E_IOERR_SHORT_READ,
            0x87AF020E => SQLITE::SQLITE_E_CANTOPEN_ISDIR,
            0x87AF0213 => SQLITE::SQLITE_E_CONSTRAINT_COMMITHOOK,
            0x87AF021B => SQLITE::SQLITE_E_NOTICE_RECOVER_ROLLBACK,
            0x87AF0308 => SQLITE::SQLITE_E_READONLY_ROLLBACK,
            0x87AF030A => SQLITE::SQLITE_E_IOERR_WRITE,
            0x87AF030E => SQLITE::SQLITE_E_CANTOPEN_FULLPATH,
            0x87AF0313 => SQLITE::SQLITE_E_CONSTRAINT_FOREIGNKEY,
            0x87AF0408 => SQLITE::SQLITE_E_READONLY_DBMOVED,
            0x87AF040A => SQLITE::SQLITE_E_IOERR_FSYNC,
            0x87AF040E => SQLITE::SQLITE_E_CANTOPEN_CONVPATH,
            0x87AF0413 => SQLITE::SQLITE_E_CONSTRAINT_FUNCTION,
            0x87AF050A => SQLITE::SQLITE_E_IOERR_DIR_FSYNC,
            0x87AF0513 => SQLITE::SQLITE_E_CONSTRAINT_NOTNULL,
            0x87AF060A => SQLITE::SQLITE_E_IOERR_TRUNCATE,
            0x87AF0613 => SQLITE::SQLITE_E_CONSTRAINT_PRIMARYKEY,
            0x87AF070A => SQLITE::SQLITE_E_IOERR_FSTAT,
            0x87AF0713 => SQLITE::SQLITE_E_CONSTRAINT_TRIGGER,
            0x87AF080A => SQLITE::SQLITE_E_IOERR_UNLOCK,
            0x87AF0813 => SQLITE::SQLITE_E_CONSTRAINT_UNIQUE,
            0x87AF090A => SQLITE::SQLITE_E_IOERR_RDLOCK,
            0x87AF0913 => SQLITE::SQLITE_E_CONSTRAINT_VTAB,
            0x87AF0A0A => SQLITE::SQLITE_E_IOERR_DELETE,
            0x87AF0A13 => SQLITE::SQLITE_E_CONSTRAINT_ROWID,
            0x87AF0B0A => SQLITE::SQLITE_E_IOERR_BLOCKED,
            0x87AF0C0A => SQLITE::SQLITE_E_IOERR_NOMEM,
            0x87AF0D0A => SQLITE::SQLITE_E_IOERR_ACCESS,
            0x87AF0E0A => SQLITE::SQLITE_E_IOERR_CHECKRESERVEDLOCK,
            0x87AF0F0A => SQLITE::SQLITE_E_IOERR_LOCK,
            0x87AF100A => SQLITE::SQLITE_E_IOERR_CLOSE,
            0x87AF110A => SQLITE::SQLITE_E_IOERR_DIR_CLOSE,
            0x87AF120A => SQLITE::SQLITE_E_IOERR_SHMOPEN,
            0x87AF130A => SQLITE::SQLITE_E_IOERR_SHMSIZE,
            0x87AF140A => SQLITE::SQLITE_E_IOERR_SHMLOCK,
            0x87AF150A => SQLITE::SQLITE_E_IOERR_SHMMAP,
            0x87AF160A => SQLITE::SQLITE_E_IOERR_SEEK,
            0x87AF170A => SQLITE::SQLITE_E_IOERR_DELETE_NOENT,
            0x87AF180A => SQLITE::SQLITE_E_IOERR_MMAP,
            0x87AF190A => SQLITE::SQLITE_E_IOERR_GETTEMPPATH,
            0x87AF1A02 => SQLITE::SQLITE_E_IOERR_VNODE,
            0x87AF1A03 => SQLITE::SQLITE_E_IOERR_AUTH,
            0x87AF1A0A => SQLITE::SQLITE_E_IOERR_CONVPATH,
        }
    }
}
