/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum UI {
    UI_E_CREATE_FAILED,
    E_WPD_DEVICE_ALREADY_OPENED,
    UI_E_SHUTDOWN_CALLED,
    E_WPD_DEVICE_NOT_OPEN,
    UI_E_ILLEGAL_REENTRANCY,
    E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE,
    UI_E_OBJECT_SEALED,
    E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE,
    UI_E_VALUE_NOT_SET,
    E_WPD_OBJECT_NOT_COMMITED,
    UI_E_VALUE_NOT_DETERMINED,
    E_WPD_DEVICE_IS_HUNG,
    UI_E_INVALID_OUTPUT,
    UI_E_BOOLEAN_EXPECTED,
    UI_E_DIFFERENT_OWNER,
    UI_E_AMBIGUOUS_MATCH,
    UI_E_FP_OVERFLOW,
    UI_E_WRONG_THREAD,
    E_WPD_SMS_INVALID_RECIPIENT,
    E_WPD_SMS_INVALID_MESSAGE_BODY,
    E_WPD_SMS_SERVICE_UNAVAILABLE,
    E_WPD_SERVICE_ALREADY_OPENED,
    E_WPD_SERVICE_NOT_OPEN,
    E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE,
    E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE,
    E_WPD_SERVICE_BAD_PARAMETER_ORDER,
    UI_E_STORYBOARD_ACTIVE,
    UI_E_STORYBOARD_NOT_PLAYING,
    UI_E_START_KEYFRAME_AFTER_END,
    UI_E_END_KEYFRAME_NOT_DETERMINED,
    UI_E_LOOPS_OVERLAP,
    UI_E_TRANSITION_ALREADY_USED,
    UI_E_TRANSITION_NOT_IN_STORYBOARD,
    UI_E_TRANSITION_ECLIPSED,
    UI_E_TIME_BEFORE_LAST_UPDATE,
    UI_E_TIMER_CLIENT_ALREADY_CONNECTED,
    UI_E_INVALID_DIMENSION,
    UI_E_PRIMITIVE_OUT_OF_BOUNDS,
    UI_E_WINDOW_CLOSED,
}

impl UI {
    pub fn code(&self) -> u32 {
        return match self {
            UI::UI_E_CREATE_FAILED => 0x802A0001 as u32,
            UI::E_WPD_DEVICE_ALREADY_OPENED => 0x802A0001 as u32,
            UI::UI_E_SHUTDOWN_CALLED => 0x802A0002 as u32,
            UI::E_WPD_DEVICE_NOT_OPEN => 0x802A0002 as u32,
            UI::UI_E_ILLEGAL_REENTRANCY => 0x802A0003 as u32,
            UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE => 0x802A0003 as u32,
            UI::UI_E_OBJECT_SEALED => 0x802A0004 as u32,
            UI::E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE => 0x802A0004 as u32,
            UI::UI_E_VALUE_NOT_SET => 0x802A0005 as u32,
            UI::E_WPD_OBJECT_NOT_COMMITED => 0x802A0005 as u32,
            UI::UI_E_VALUE_NOT_DETERMINED => 0x802A0006 as u32,
            UI::E_WPD_DEVICE_IS_HUNG => 0x802A0006 as u32,
            UI::UI_E_INVALID_OUTPUT => 0x802A0007 as u32,
            UI::UI_E_BOOLEAN_EXPECTED => 0x802A0008 as u32,
            UI::UI_E_DIFFERENT_OWNER => 0x802A0009 as u32,
            UI::UI_E_AMBIGUOUS_MATCH => 0x802A000A as u32,
            UI::UI_E_FP_OVERFLOW => 0x802A000B as u32,
            UI::UI_E_WRONG_THREAD => 0x802A000C as u32,
            UI::E_WPD_SMS_INVALID_RECIPIENT => 0x802A0064 as u32,
            UI::E_WPD_SMS_INVALID_MESSAGE_BODY => 0x802A0065 as u32,
            UI::E_WPD_SMS_SERVICE_UNAVAILABLE => 0x802A0066 as u32,
            UI::E_WPD_SERVICE_ALREADY_OPENED => 0x802A00C8 as u32,
            UI::E_WPD_SERVICE_NOT_OPEN => 0x802A00C9 as u32,
            UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE => 0x802A00CA as u32,
            UI::E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE => 0x802A00CB as u32,
            UI::E_WPD_SERVICE_BAD_PARAMETER_ORDER => 0x802A00CC as u32,
            UI::UI_E_STORYBOARD_ACTIVE => 0x802A0101 as u32,
            UI::UI_E_STORYBOARD_NOT_PLAYING => 0x802A0102 as u32,
            UI::UI_E_START_KEYFRAME_AFTER_END => 0x802A0103 as u32,
            UI::UI_E_END_KEYFRAME_NOT_DETERMINED => 0x802A0104 as u32,
            UI::UI_E_LOOPS_OVERLAP => 0x802A0105 as u32,
            UI::UI_E_TRANSITION_ALREADY_USED => 0x802A0106 as u32,
            UI::UI_E_TRANSITION_NOT_IN_STORYBOARD => 0x802A0107 as u32,
            UI::UI_E_TRANSITION_ECLIPSED => 0x802A0108 as u32,
            UI::UI_E_TIME_BEFORE_LAST_UPDATE => 0x802A0109 as u32,
            UI::UI_E_TIMER_CLIENT_ALREADY_CONNECTED => 0x802A010A as u32,
            UI::UI_E_INVALID_DIMENSION => 0x802A010B as u32,
            UI::UI_E_PRIMITIVE_OUT_OF_BOUNDS => 0x802A010C as u32,
            UI::UI_E_WINDOW_CLOSED => 0x802A0201 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            UI::UI_E_CREATE_FAILED => RawError::Kind(UI::UI_E_CREATE_FAILED),
            UI::E_WPD_DEVICE_ALREADY_OPENED => RawError::Kind(UI::E_WPD_DEVICE_ALREADY_OPENED),
            UI::UI_E_SHUTDOWN_CALLED => RawError::Kind(UI::UI_E_SHUTDOWN_CALLED),
            UI::E_WPD_DEVICE_NOT_OPEN => RawError::Kind(UI::E_WPD_DEVICE_NOT_OPEN),
            UI::UI_E_ILLEGAL_REENTRANCY => RawError::Kind(UI::UI_E_ILLEGAL_REENTRANCY),
            UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE => RawError::Kind(UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE),
            UI::UI_E_OBJECT_SEALED => RawError::Kind(UI::UI_E_OBJECT_SEALED),
            UI::E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE => RawError::Kind(UI::E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE),
            UI::UI_E_VALUE_NOT_SET => RawError::Kind(UI::UI_E_VALUE_NOT_SET),
            UI::E_WPD_OBJECT_NOT_COMMITED => RawError::Kind(UI::E_WPD_OBJECT_NOT_COMMITED),
            UI::UI_E_VALUE_NOT_DETERMINED => RawError::Kind(UI::UI_E_VALUE_NOT_DETERMINED),
            UI::E_WPD_DEVICE_IS_HUNG => RawError::Kind(UI::E_WPD_DEVICE_IS_HUNG),
            UI::UI_E_INVALID_OUTPUT => RawError::Kind(UI::UI_E_INVALID_OUTPUT),
            UI::UI_E_BOOLEAN_EXPECTED => RawError::Kind(UI::UI_E_BOOLEAN_EXPECTED),
            UI::UI_E_DIFFERENT_OWNER => RawError::Kind(UI::UI_E_DIFFERENT_OWNER),
            UI::UI_E_AMBIGUOUS_MATCH => RawError::Kind(UI::UI_E_AMBIGUOUS_MATCH),
            UI::UI_E_FP_OVERFLOW => RawError::Kind(UI::UI_E_FP_OVERFLOW),
            UI::UI_E_WRONG_THREAD => RawError::Kind(UI::UI_E_WRONG_THREAD),
            UI::E_WPD_SMS_INVALID_RECIPIENT => RawError::Kind(UI::E_WPD_SMS_INVALID_RECIPIENT),
            UI::E_WPD_SMS_INVALID_MESSAGE_BODY => RawError::Kind(UI::E_WPD_SMS_INVALID_MESSAGE_BODY),
            UI::E_WPD_SMS_SERVICE_UNAVAILABLE => RawError::Kind(UI::E_WPD_SMS_SERVICE_UNAVAILABLE),
            UI::E_WPD_SERVICE_ALREADY_OPENED => RawError::Kind(UI::E_WPD_SERVICE_ALREADY_OPENED),
            UI::E_WPD_SERVICE_NOT_OPEN => RawError::Kind(UI::E_WPD_SERVICE_NOT_OPEN),
            UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE => RawError::Kind(UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE),
            UI::E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE => RawError::Kind(UI::E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE),
            UI::E_WPD_SERVICE_BAD_PARAMETER_ORDER => RawError::Kind(UI::E_WPD_SERVICE_BAD_PARAMETER_ORDER),
            UI::UI_E_STORYBOARD_ACTIVE => RawError::Kind(UI::UI_E_STORYBOARD_ACTIVE),
            UI::UI_E_STORYBOARD_NOT_PLAYING => RawError::Kind(UI::UI_E_STORYBOARD_NOT_PLAYING),
            UI::UI_E_START_KEYFRAME_AFTER_END => RawError::Kind(UI::UI_E_START_KEYFRAME_AFTER_END),
            UI::UI_E_END_KEYFRAME_NOT_DETERMINED => RawError::Kind(UI::UI_E_END_KEYFRAME_NOT_DETERMINED),
            UI::UI_E_LOOPS_OVERLAP => RawError::Kind(UI::UI_E_LOOPS_OVERLAP),
            UI::UI_E_TRANSITION_ALREADY_USED => RawError::Kind(UI::UI_E_TRANSITION_ALREADY_USED),
            UI::UI_E_TRANSITION_NOT_IN_STORYBOARD => RawError::Kind(UI::UI_E_TRANSITION_NOT_IN_STORYBOARD),
            UI::UI_E_TRANSITION_ECLIPSED => RawError::Kind(UI::UI_E_TRANSITION_ECLIPSED),
            UI::UI_E_TIME_BEFORE_LAST_UPDATE => RawError::Kind(UI::UI_E_TIME_BEFORE_LAST_UPDATE),
            UI::UI_E_TIMER_CLIENT_ALREADY_CONNECTED => RawError::Kind(UI::UI_E_TIMER_CLIENT_ALREADY_CONNECTED),
            UI::UI_E_INVALID_DIMENSION => RawError::Kind(UI::UI_E_INVALID_DIMENSION),
            UI::UI_E_PRIMITIVE_OUT_OF_BOUNDS => RawError::Kind(UI::UI_E_PRIMITIVE_OUT_OF_BOUNDS),
            UI::UI_E_WINDOW_CLOSED => RawError::Kind(UI::UI_E_WINDOW_CLOSED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            UI::UI_E_CREATE_FAILED => "The object could not be created.",
            UI::E_WPD_DEVICE_ALREADY_OPENED => "The device connection has already been opened by a prior call to IPortableDevice::Open. See the WPD SDK for a description of this method.",
            UI::UI_E_SHUTDOWN_CALLED => "Shutdown was already called on this object or the object that owns it.",
            UI::E_WPD_DEVICE_NOT_OPEN => "The device connection has not yet been opened by a call to IPortableDevice::Open.",
            UI::UI_E_ILLEGAL_REENTRANCY => "This method cannot be called during this type of callback.",
            UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE => "The interface object has already been attached to the device interface.",
            UI::UI_E_OBJECT_SEALED => "This object has been sealed, so this change is no longer allowed.",
            UI::E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE => "The interface object has not been attached the device.",
            UI::UI_E_VALUE_NOT_SET => "The requested value was never set.",
            UI::E_WPD_OBJECT_NOT_COMMITED => "IStream::Commit was never called when creating an object with data on a device.",
            UI::UI_E_VALUE_NOT_DETERMINED => "The requested value cannot be determined.",
            UI::E_WPD_DEVICE_IS_HUNG => "The device will no longer respond to input.",
            UI::UI_E_INVALID_OUTPUT => "A callback returned an invalid output parameter.",
            UI::UI_E_BOOLEAN_EXPECTED => "A callback returned a success code other than S_OK or S_FALSE.",
            UI::UI_E_DIFFERENT_OWNER => "A parameter that should be owned by this object is owned by a different object.",
            UI::UI_E_AMBIGUOUS_MATCH => "More than one item matched the search criteria.",
            UI::UI_E_FP_OVERFLOW => "A floating-point overflow occurred.",
            UI::UI_E_WRONG_THREAD => "This method can only be called from the thread that created the object.",
            UI::E_WPD_SMS_INVALID_RECIPIENT => "The recipient specified for a short message service (SMS) message is invalid.",
            UI::E_WPD_SMS_INVALID_MESSAGE_BODY => "The body of a message specified for an SMS message is invalid.",
            UI::E_WPD_SMS_SERVICE_UNAVAILABLE => "The SMS service is not available.",
            UI::E_WPD_SERVICE_ALREADY_OPENED => "The service connection has already been opened by a prior call to IPortableDevice::Open.",
            UI::E_WPD_SERVICE_NOT_OPEN => "The service connection has not yet been opened by a call to IPortableDeviceService::Open.",
            UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE => "The interface object has already been attached to the IPortableDeviceService interface.",
            UI::E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE => "The interface object has not been attached to the IPortableDeviceService interface. Typically, this is returned if the application tries to access methods of an attached interface, such as IPortableDeviceServiceCapabilities, after IPortableDevice::Close is called.",
            UI::E_WPD_SERVICE_BAD_PARAMETER_ORDER => "The method parameters for IPortableDeviceServiceMethods::Invoke or IPortableDeviceServiceMethods::InvokeAsync are not set in the correct order. The parameter must be set in the ordering specified by WPD_PARAMETER_ATTRIBUTE_ORDER.",
            UI::UI_E_STORYBOARD_ACTIVE => "The storyboard is currently in the schedule.",
            UI::UI_E_STORYBOARD_NOT_PLAYING => "The storyboard is not playing.",
            UI::UI_E_START_KEYFRAME_AFTER_END => "The start keyframe might occur after the end keyframe.",
            UI::UI_E_END_KEYFRAME_NOT_DETERMINED => "It might not be possible to determine the end keyframe time when the start keyframe is reached.",
            UI::UI_E_LOOPS_OVERLAP => "Two repeated portions of a storyboard might overlap.",
            UI::UI_E_TRANSITION_ALREADY_USED => "The transition has already been added to a storyboard.",
            UI::UI_E_TRANSITION_NOT_IN_STORYBOARD => "The transition has not been added to a storyboard.",
            UI::UI_E_TRANSITION_ECLIPSED => "The transition might eclipse the beginning of another transition in the storyboard.",
            UI::UI_E_TIME_BEFORE_LAST_UPDATE => "The given time is earlier than the time passed to the last update.",
            UI::UI_E_TIMER_CLIENT_ALREADY_CONNECTED => "This client is already connected to a timer.",
            UI::UI_E_INVALID_DIMENSION => "The passed dimension is invalid or does not match the object's dimension.",
            UI::UI_E_PRIMITIVE_OUT_OF_BOUNDS => "The added primitive begins at or beyond the duration of the interpolator.",
            UI::UI_E_WINDOW_CLOSED => "The operation cannot be completed because the window is being closed.",
        }
    }

    pub fn from_name(name: &str) -> UI {
        return match name {
            "UI_E_CREATE_FAILED" => UI::UI_E_CREATE_FAILED,
            "E_WPD_DEVICE_ALREADY_OPENED" => UI::E_WPD_DEVICE_ALREADY_OPENED,
            "UI_E_SHUTDOWN_CALLED" => UI::UI_E_SHUTDOWN_CALLED,
            "E_WPD_DEVICE_NOT_OPEN" => UI::E_WPD_DEVICE_NOT_OPEN,
            "UI_E_ILLEGAL_REENTRANCY" => UI::UI_E_ILLEGAL_REENTRANCY,
            "E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE" => UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE,
            "UI_E_OBJECT_SEALED" => UI::UI_E_OBJECT_SEALED,
            "E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE" => UI::E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE,
            "UI_E_VALUE_NOT_SET" => UI::UI_E_VALUE_NOT_SET,
            "E_WPD_OBJECT_NOT_COMMITED" => UI::E_WPD_OBJECT_NOT_COMMITED,
            "UI_E_VALUE_NOT_DETERMINED" => UI::UI_E_VALUE_NOT_DETERMINED,
            "E_WPD_DEVICE_IS_HUNG" => UI::E_WPD_DEVICE_IS_HUNG,
            "UI_E_INVALID_OUTPUT" => UI::UI_E_INVALID_OUTPUT,
            "UI_E_BOOLEAN_EXPECTED" => UI::UI_E_BOOLEAN_EXPECTED,
            "UI_E_DIFFERENT_OWNER" => UI::UI_E_DIFFERENT_OWNER,
            "UI_E_AMBIGUOUS_MATCH" => UI::UI_E_AMBIGUOUS_MATCH,
            "UI_E_FP_OVERFLOW" => UI::UI_E_FP_OVERFLOW,
            "UI_E_WRONG_THREAD" => UI::UI_E_WRONG_THREAD,
            "E_WPD_SMS_INVALID_RECIPIENT" => UI::E_WPD_SMS_INVALID_RECIPIENT,
            "E_WPD_SMS_INVALID_MESSAGE_BODY" => UI::E_WPD_SMS_INVALID_MESSAGE_BODY,
            "E_WPD_SMS_SERVICE_UNAVAILABLE" => UI::E_WPD_SMS_SERVICE_UNAVAILABLE,
            "E_WPD_SERVICE_ALREADY_OPENED" => UI::E_WPD_SERVICE_ALREADY_OPENED,
            "E_WPD_SERVICE_NOT_OPEN" => UI::E_WPD_SERVICE_NOT_OPEN,
            "E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE" => UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE,
            "E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE" => UI::E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE,
            "E_WPD_SERVICE_BAD_PARAMETER_ORDER" => UI::E_WPD_SERVICE_BAD_PARAMETER_ORDER,
            "UI_E_STORYBOARD_ACTIVE" => UI::UI_E_STORYBOARD_ACTIVE,
            "UI_E_STORYBOARD_NOT_PLAYING" => UI::UI_E_STORYBOARD_NOT_PLAYING,
            "UI_E_START_KEYFRAME_AFTER_END" => UI::UI_E_START_KEYFRAME_AFTER_END,
            "UI_E_END_KEYFRAME_NOT_DETERMINED" => UI::UI_E_END_KEYFRAME_NOT_DETERMINED,
            "UI_E_LOOPS_OVERLAP" => UI::UI_E_LOOPS_OVERLAP,
            "UI_E_TRANSITION_ALREADY_USED" => UI::UI_E_TRANSITION_ALREADY_USED,
            "UI_E_TRANSITION_NOT_IN_STORYBOARD" => UI::UI_E_TRANSITION_NOT_IN_STORYBOARD,
            "UI_E_TRANSITION_ECLIPSED" => UI::UI_E_TRANSITION_ECLIPSED,
            "UI_E_TIME_BEFORE_LAST_UPDATE" => UI::UI_E_TIME_BEFORE_LAST_UPDATE,
            "UI_E_TIMER_CLIENT_ALREADY_CONNECTED" => UI::UI_E_TIMER_CLIENT_ALREADY_CONNECTED,
            "UI_E_INVALID_DIMENSION" => UI::UI_E_INVALID_DIMENSION,
            "UI_E_PRIMITIVE_OUT_OF_BOUNDS" => UI::UI_E_PRIMITIVE_OUT_OF_BOUNDS,
            "UI_E_WINDOW_CLOSED" => UI::UI_E_WINDOW_CLOSED,
        }
    }
    pub fn from_code(code: u32) -> UI {
        return match code {
            0x802A0001 => UI::UI_E_CREATE_FAILED,
            0x802A0001 => UI::E_WPD_DEVICE_ALREADY_OPENED,
            0x802A0002 => UI::UI_E_SHUTDOWN_CALLED,
            0x802A0002 => UI::E_WPD_DEVICE_NOT_OPEN,
            0x802A0003 => UI::UI_E_ILLEGAL_REENTRANCY,
            0x802A0003 => UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_DEVICE,
            0x802A0004 => UI::UI_E_OBJECT_SEALED,
            0x802A0004 => UI::E_WPD_OBJECT_NOT_ATTACHED_TO_DEVICE,
            0x802A0005 => UI::UI_E_VALUE_NOT_SET,
            0x802A0005 => UI::E_WPD_OBJECT_NOT_COMMITED,
            0x802A0006 => UI::UI_E_VALUE_NOT_DETERMINED,
            0x802A0006 => UI::E_WPD_DEVICE_IS_HUNG,
            0x802A0007 => UI::UI_E_INVALID_OUTPUT,
            0x802A0008 => UI::UI_E_BOOLEAN_EXPECTED,
            0x802A0009 => UI::UI_E_DIFFERENT_OWNER,
            0x802A000A => UI::UI_E_AMBIGUOUS_MATCH,
            0x802A000B => UI::UI_E_FP_OVERFLOW,
            0x802A000C => UI::UI_E_WRONG_THREAD,
            0x802A0064 => UI::E_WPD_SMS_INVALID_RECIPIENT,
            0x802A0065 => UI::E_WPD_SMS_INVALID_MESSAGE_BODY,
            0x802A0066 => UI::E_WPD_SMS_SERVICE_UNAVAILABLE,
            0x802A00C8 => UI::E_WPD_SERVICE_ALREADY_OPENED,
            0x802A00C9 => UI::E_WPD_SERVICE_NOT_OPEN,
            0x802A00CA => UI::E_WPD_OBJECT_ALREADY_ATTACHED_TO_SERVICE,
            0x802A00CB => UI::E_WPD_OBJECT_NOT_ATTACHED_TO_SERVICE,
            0x802A00CC => UI::E_WPD_SERVICE_BAD_PARAMETER_ORDER,
            0x802A0101 => UI::UI_E_STORYBOARD_ACTIVE,
            0x802A0102 => UI::UI_E_STORYBOARD_NOT_PLAYING,
            0x802A0103 => UI::UI_E_START_KEYFRAME_AFTER_END,
            0x802A0104 => UI::UI_E_END_KEYFRAME_NOT_DETERMINED,
            0x802A0105 => UI::UI_E_LOOPS_OVERLAP,
            0x802A0106 => UI::UI_E_TRANSITION_ALREADY_USED,
            0x802A0107 => UI::UI_E_TRANSITION_NOT_IN_STORYBOARD,
            0x802A0108 => UI::UI_E_TRANSITION_ECLIPSED,
            0x802A0109 => UI::UI_E_TIME_BEFORE_LAST_UPDATE,
            0x802A010A => UI::UI_E_TIMER_CLIENT_ALREADY_CONNECTED,
            0x802A010B => UI::UI_E_INVALID_DIMENSION,
            0x802A010C => UI::UI_E_PRIMITIVE_OUT_OF_BOUNDS,
            0x802A0201 => UI::UI_E_WINDOW_CLOSED,
        }
    }
}
