/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum USERMODE_FILTER_MANAGER {
    ERROR_FLT_IO_COMPLETE,
    ERROR_FLT_NO_HANDLER_DEFINED,
    ERROR_FLT_CONTEXT_ALREADY_DEFINED,
    ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST,
    ERROR_FLT_DISALLOW_FAST_IO,
    ERROR_FLT_INVALID_NAME_REQUEST,
    ERROR_FLT_NOT_SAFE_TO_POST_OPERATION,
    ERROR_FLT_NOT_INITIALIZED,
    ERROR_FLT_FILTER_NOT_READY,
    ERROR_FLT_POST_OPERATION_CLEANUP,
    ERROR_FLT_INTERNAL_ERROR,
    ERROR_FLT_DELETING_OBJECT,
    ERROR_FLT_MUST_BE_NONPAGED_POOL,
    ERROR_FLT_DUPLICATE_ENTRY,
    ERROR_FLT_CBDQ_DISABLED,
    ERROR_FLT_DO_NOT_ATTACH,
    ERROR_FLT_DO_NOT_DETACH,
    ERROR_FLT_INSTANCE_ALTITUDE_COLLISION,
    ERROR_FLT_INSTANCE_NAME_COLLISION,
    ERROR_FLT_FILTER_NOT_FOUND,
    ERROR_FLT_VOLUME_NOT_FOUND,
    ERROR_FLT_INSTANCE_NOT_FOUND,
    ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND,
    ERROR_FLT_INVALID_CONTEXT_REGISTRATION,
    ERROR_FLT_NAME_CACHE_MISS,
    ERROR_FLT_NO_DEVICE_OBJECT,
    ERROR_FLT_VOLUME_ALREADY_MOUNTED,
    ERROR_FLT_ALREADY_ENLISTED,
    ERROR_FLT_CONTEXT_ALREADY_LINKED,
    ERROR_FLT_NO_WAITER_FOR_REPLY,
    ERROR_FLT_REGISTRATION_BUSY,
    ERROR_FLT_WCOS_NOT_SUPPORTED,
}

impl USERMODE_FILTER_MANAGER {
    pub fn code(&self) -> u32 {
        return match self {
            USERMODE_FILTER_MANAGER::ERROR_FLT_IO_COMPLETE => 0x001F0001 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_HANDLER_DEFINED => 0x801F0001 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_DEFINED => 0x801F0002 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST => 0x801F0003 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_DISALLOW_FAST_IO => 0x801F0004 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_NAME_REQUEST => 0x801F0005 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_SAFE_TO_POST_OPERATION => 0x801F0006 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_INITIALIZED => 0x801F0007 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_READY => 0x801F0008 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_POST_OPERATION_CLEANUP => 0x801F0009 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INTERNAL_ERROR => 0x801F000A as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_DELETING_OBJECT => 0x801F000B as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_MUST_BE_NONPAGED_POOL => 0x801F000C as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_DUPLICATE_ENTRY => 0x801F000D as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_CBDQ_DISABLED => 0x801F000E as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_ATTACH => 0x801F000F as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_DETACH => 0x801F0010 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_ALTITUDE_COLLISION => 0x801F0011 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NAME_COLLISION => 0x801F0012 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_FOUND => 0x801F0013 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_NOT_FOUND => 0x801F0014 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NOT_FOUND => 0x801F0015 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND => 0x801F0016 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_CONTEXT_REGISTRATION => 0x801F0017 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_NAME_CACHE_MISS => 0x801F0018 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_DEVICE_OBJECT => 0x801F0019 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_ALREADY_MOUNTED => 0x801F001A as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_ALREADY_ENLISTED => 0x801F001B as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_LINKED => 0x801F001C as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_WAITER_FOR_REPLY => 0x801F0020 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_REGISTRATION_BUSY => 0x801F0023 as u32,
            USERMODE_FILTER_MANAGER::ERROR_FLT_WCOS_NOT_SUPPORTED => 0x801F0024 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            USERMODE_FILTER_MANAGER::ERROR_FLT_IO_COMPLETE => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_IO_COMPLETE),
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_HANDLER_DEFINED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_NO_HANDLER_DEFINED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_DEFINED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_DEFINED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST),
            USERMODE_FILTER_MANAGER::ERROR_FLT_DISALLOW_FAST_IO => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_DISALLOW_FAST_IO),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_NAME_REQUEST => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_NAME_REQUEST),
            USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_SAFE_TO_POST_OPERATION => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_SAFE_TO_POST_OPERATION),
            USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_INITIALIZED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_INITIALIZED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_READY => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_READY),
            USERMODE_FILTER_MANAGER::ERROR_FLT_POST_OPERATION_CLEANUP => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_POST_OPERATION_CLEANUP),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INTERNAL_ERROR => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INTERNAL_ERROR),
            USERMODE_FILTER_MANAGER::ERROR_FLT_DELETING_OBJECT => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_DELETING_OBJECT),
            USERMODE_FILTER_MANAGER::ERROR_FLT_MUST_BE_NONPAGED_POOL => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_MUST_BE_NONPAGED_POOL),
            USERMODE_FILTER_MANAGER::ERROR_FLT_DUPLICATE_ENTRY => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_DUPLICATE_ENTRY),
            USERMODE_FILTER_MANAGER::ERROR_FLT_CBDQ_DISABLED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_CBDQ_DISABLED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_ATTACH => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_ATTACH),
            USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_DETACH => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_DETACH),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_ALTITUDE_COLLISION => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_ALTITUDE_COLLISION),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NAME_COLLISION => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NAME_COLLISION),
            USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_FOUND => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_FOUND),
            USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_NOT_FOUND => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_NOT_FOUND),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NOT_FOUND => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NOT_FOUND),
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND),
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_CONTEXT_REGISTRATION => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_CONTEXT_REGISTRATION),
            USERMODE_FILTER_MANAGER::ERROR_FLT_NAME_CACHE_MISS => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_NAME_CACHE_MISS),
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_DEVICE_OBJECT => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_NO_DEVICE_OBJECT),
            USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_ALREADY_MOUNTED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_ALREADY_MOUNTED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_ALREADY_ENLISTED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_ALREADY_ENLISTED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_LINKED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_LINKED),
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_WAITER_FOR_REPLY => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_NO_WAITER_FOR_REPLY),
            USERMODE_FILTER_MANAGER::ERROR_FLT_REGISTRATION_BUSY => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_REGISTRATION_BUSY),
            USERMODE_FILTER_MANAGER::ERROR_FLT_WCOS_NOT_SUPPORTED => RawError::Kind(USERMODE_FILTER_MANAGER::ERROR_FLT_WCOS_NOT_SUPPORTED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            USERMODE_FILTER_MANAGER::ERROR_FLT_IO_COMPLETE => "The IO was completed by a filter.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_HANDLER_DEFINED => "A handler was not defined by the filter for this operation.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_DEFINED => "A context is already defined for this object.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST => "Asynchronous requests are not valid for this operation.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_DISALLOW_FAST_IO => "Disallow the Fast IO path for this operation.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_NAME_REQUEST => "An invalid name request was made. The name requested cannot be retrieved at this time.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_SAFE_TO_POST_OPERATION => "Posting this operation to a worker thread for further processing is not safe at this time because it could lead to a system deadlock.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_INITIALIZED => "The Filter Manager was not initialized when a filter tried to register. Make sure that the Filter Manager is getting loaded as a driver.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_READY => "The filter is not ready for attachment to volumes because it has not finished initializing (FltStartFiltering has not been called).",
            USERMODE_FILTER_MANAGER::ERROR_FLT_POST_OPERATION_CLEANUP => "The filter must cleanup any operation specific context at this time because it is being removed from the system before the operation is completed by the lower drivers.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INTERNAL_ERROR => "The Filter Manager had an internal error from which it cannot recover, therefore the operation has been failed. This is usually the result of a filter returning an invalid value from a pre-operation callback.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_DELETING_OBJECT => "The object specified for this action is in the process of being deleted, therefore the action requested cannot be completed at this time.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_MUST_BE_NONPAGED_POOL => "Non-paged pool must be used for this type of context.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_DUPLICATE_ENTRY => "A duplicate handler definition has been provided for an operation.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_CBDQ_DISABLED => "The callback data queue has been disabled.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_ATTACH => "Do not attach the filter to the volume at this time.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_DETACH => "Do not detach the filter from the volume at this time.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_ALTITUDE_COLLISION => "An instance already exists at this altitude on the volume specified.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NAME_COLLISION => "An instance already exists with this name on the volume specified.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_FOUND => "The system could not find the filter specified.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_NOT_FOUND => "The system could not find the volume specified.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NOT_FOUND => "The system could not find the instance specified.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND => "No registered context allocation definition was found for the given request.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_CONTEXT_REGISTRATION => "An invalid parameter was specified during context registration.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_NAME_CACHE_MISS => "The name requested was not found in Filter Manager's name cache and could not be retrieved from the file system.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_DEVICE_OBJECT => "The requested device object does not exist for the given volume.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_ALREADY_MOUNTED => "The specified volume is already mounted.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_ALREADY_ENLISTED => "The specified Transaction Context is already enlisted in a transaction",
            USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_LINKED => "The specified context is already attached to another object",
            USERMODE_FILTER_MANAGER::ERROR_FLT_NO_WAITER_FOR_REPLY => "No waiter is present for the filter's reply to this message.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_REGISTRATION_BUSY => "The filesystem database resource is in use. Registration cannot complete at this time.",
            USERMODE_FILTER_MANAGER::ERROR_FLT_WCOS_NOT_SUPPORTED => "The filter is not allowed to attach because it has not declared compability with WCOS.",
        }
    }

    pub fn from_name(name: &str) -> USERMODE_FILTER_MANAGER {
        return match name {
            "ERROR_FLT_IO_COMPLETE" => USERMODE_FILTER_MANAGER::ERROR_FLT_IO_COMPLETE,
            "ERROR_FLT_NO_HANDLER_DEFINED" => USERMODE_FILTER_MANAGER::ERROR_FLT_NO_HANDLER_DEFINED,
            "ERROR_FLT_CONTEXT_ALREADY_DEFINED" => USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_DEFINED,
            "ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST" => USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST,
            "ERROR_FLT_DISALLOW_FAST_IO" => USERMODE_FILTER_MANAGER::ERROR_FLT_DISALLOW_FAST_IO,
            "ERROR_FLT_INVALID_NAME_REQUEST" => USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_NAME_REQUEST,
            "ERROR_FLT_NOT_SAFE_TO_POST_OPERATION" => USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_SAFE_TO_POST_OPERATION,
            "ERROR_FLT_NOT_INITIALIZED" => USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_INITIALIZED,
            "ERROR_FLT_FILTER_NOT_READY" => USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_READY,
            "ERROR_FLT_POST_OPERATION_CLEANUP" => USERMODE_FILTER_MANAGER::ERROR_FLT_POST_OPERATION_CLEANUP,
            "ERROR_FLT_INTERNAL_ERROR" => USERMODE_FILTER_MANAGER::ERROR_FLT_INTERNAL_ERROR,
            "ERROR_FLT_DELETING_OBJECT" => USERMODE_FILTER_MANAGER::ERROR_FLT_DELETING_OBJECT,
            "ERROR_FLT_MUST_BE_NONPAGED_POOL" => USERMODE_FILTER_MANAGER::ERROR_FLT_MUST_BE_NONPAGED_POOL,
            "ERROR_FLT_DUPLICATE_ENTRY" => USERMODE_FILTER_MANAGER::ERROR_FLT_DUPLICATE_ENTRY,
            "ERROR_FLT_CBDQ_DISABLED" => USERMODE_FILTER_MANAGER::ERROR_FLT_CBDQ_DISABLED,
            "ERROR_FLT_DO_NOT_ATTACH" => USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_ATTACH,
            "ERROR_FLT_DO_NOT_DETACH" => USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_DETACH,
            "ERROR_FLT_INSTANCE_ALTITUDE_COLLISION" => USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_ALTITUDE_COLLISION,
            "ERROR_FLT_INSTANCE_NAME_COLLISION" => USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NAME_COLLISION,
            "ERROR_FLT_FILTER_NOT_FOUND" => USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_FOUND,
            "ERROR_FLT_VOLUME_NOT_FOUND" => USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_NOT_FOUND,
            "ERROR_FLT_INSTANCE_NOT_FOUND" => USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NOT_FOUND,
            "ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND" => USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND,
            "ERROR_FLT_INVALID_CONTEXT_REGISTRATION" => USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_CONTEXT_REGISTRATION,
            "ERROR_FLT_NAME_CACHE_MISS" => USERMODE_FILTER_MANAGER::ERROR_FLT_NAME_CACHE_MISS,
            "ERROR_FLT_NO_DEVICE_OBJECT" => USERMODE_FILTER_MANAGER::ERROR_FLT_NO_DEVICE_OBJECT,
            "ERROR_FLT_VOLUME_ALREADY_MOUNTED" => USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_ALREADY_MOUNTED,
            "ERROR_FLT_ALREADY_ENLISTED" => USERMODE_FILTER_MANAGER::ERROR_FLT_ALREADY_ENLISTED,
            "ERROR_FLT_CONTEXT_ALREADY_LINKED" => USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_LINKED,
            "ERROR_FLT_NO_WAITER_FOR_REPLY" => USERMODE_FILTER_MANAGER::ERROR_FLT_NO_WAITER_FOR_REPLY,
            "ERROR_FLT_REGISTRATION_BUSY" => USERMODE_FILTER_MANAGER::ERROR_FLT_REGISTRATION_BUSY,
            "ERROR_FLT_WCOS_NOT_SUPPORTED" => USERMODE_FILTER_MANAGER::ERROR_FLT_WCOS_NOT_SUPPORTED,
        }
    }
    pub fn from_code(code: u32) -> USERMODE_FILTER_MANAGER {
        return match code {
            0x001F0001 => USERMODE_FILTER_MANAGER::ERROR_FLT_IO_COMPLETE,
            0x801F0001 => USERMODE_FILTER_MANAGER::ERROR_FLT_NO_HANDLER_DEFINED,
            0x801F0002 => USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_DEFINED,
            0x801F0003 => USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_ASYNCHRONOUS_REQUEST,
            0x801F0004 => USERMODE_FILTER_MANAGER::ERROR_FLT_DISALLOW_FAST_IO,
            0x801F0005 => USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_NAME_REQUEST,
            0x801F0006 => USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_SAFE_TO_POST_OPERATION,
            0x801F0007 => USERMODE_FILTER_MANAGER::ERROR_FLT_NOT_INITIALIZED,
            0x801F0008 => USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_READY,
            0x801F0009 => USERMODE_FILTER_MANAGER::ERROR_FLT_POST_OPERATION_CLEANUP,
            0x801F000A => USERMODE_FILTER_MANAGER::ERROR_FLT_INTERNAL_ERROR,
            0x801F000B => USERMODE_FILTER_MANAGER::ERROR_FLT_DELETING_OBJECT,
            0x801F000C => USERMODE_FILTER_MANAGER::ERROR_FLT_MUST_BE_NONPAGED_POOL,
            0x801F000D => USERMODE_FILTER_MANAGER::ERROR_FLT_DUPLICATE_ENTRY,
            0x801F000E => USERMODE_FILTER_MANAGER::ERROR_FLT_CBDQ_DISABLED,
            0x801F000F => USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_ATTACH,
            0x801F0010 => USERMODE_FILTER_MANAGER::ERROR_FLT_DO_NOT_DETACH,
            0x801F0011 => USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_ALTITUDE_COLLISION,
            0x801F0012 => USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NAME_COLLISION,
            0x801F0013 => USERMODE_FILTER_MANAGER::ERROR_FLT_FILTER_NOT_FOUND,
            0x801F0014 => USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_NOT_FOUND,
            0x801F0015 => USERMODE_FILTER_MANAGER::ERROR_FLT_INSTANCE_NOT_FOUND,
            0x801F0016 => USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALLOCATION_NOT_FOUND,
            0x801F0017 => USERMODE_FILTER_MANAGER::ERROR_FLT_INVALID_CONTEXT_REGISTRATION,
            0x801F0018 => USERMODE_FILTER_MANAGER::ERROR_FLT_NAME_CACHE_MISS,
            0x801F0019 => USERMODE_FILTER_MANAGER::ERROR_FLT_NO_DEVICE_OBJECT,
            0x801F001A => USERMODE_FILTER_MANAGER::ERROR_FLT_VOLUME_ALREADY_MOUNTED,
            0x801F001B => USERMODE_FILTER_MANAGER::ERROR_FLT_ALREADY_ENLISTED,
            0x801F001C => USERMODE_FILTER_MANAGER::ERROR_FLT_CONTEXT_ALREADY_LINKED,
            0x801F0020 => USERMODE_FILTER_MANAGER::ERROR_FLT_NO_WAITER_FOR_REPLY,
            0x801F0023 => USERMODE_FILTER_MANAGER::ERROR_FLT_REGISTRATION_BUSY,
            0x801F0024 => USERMODE_FILTER_MANAGER::ERROR_FLT_WCOS_NOT_SUPPORTED,
        }
    }
}
