/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum USERMODE_SPACES {
    ERROR_SPACES_POOL_WAS_DELETED,
    ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID,
    ERROR_SPACES_INTERNAL_ERROR,
    ERROR_SPACES_RESILIENCY_TYPE_INVALID,
    ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID,
    ERROR_SPACES_DRIVE_REDUNDANCY_INVALID,
    ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID,
    ERROR_SPACES_PARITY_LAYOUT_INVALID,
    ERROR_SPACES_INTERLEAVE_LENGTH_INVALID,
    ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID,
    ERROR_SPACES_NOT_ENOUGH_DRIVES,
    ERROR_SPACES_EXTENDED_ERROR,
    ERROR_SPACES_PROVISIONING_TYPE_INVALID,
    ERROR_SPACES_ALLOCATION_SIZE_INVALID,
    ERROR_SPACES_ENCLOSURE_AWARE_INVALID,
    ERROR_SPACES_WRITE_CACHE_SIZE_INVALID,
    ERROR_SPACES_NUMBER_OF_GROUPS_INVALID,
    ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID,
    ERROR_SPACES_ENTRY_INCOMPLETE,
    ERROR_SPACES_ENTRY_INVALID,
    ERROR_SPACES_UPDATE_COLUMN_STATE,
    ERROR_SPACES_MAP_REQUIRED,
    ERROR_SPACES_UNSUPPORTED_VERSION,
    ERROR_SPACES_CORRUPT_METADATA,
    ERROR_SPACES_DRT_FULL,
    ERROR_SPACES_INCONSISTENCY,
    ERROR_SPACES_LOG_NOT_READY,
    ERROR_SPACES_NO_REDUNDANCY,
    ERROR_SPACES_DRIVE_NOT_READY,
    ERROR_SPACES_DRIVE_SPLIT,
    ERROR_SPACES_DRIVE_LOST_DATA,
    ERROR_SPACES_MARK_DIRTY,
    ERROR_SPACES_FLUSH_METADATA,
    ERROR_SPACES_CACHE_FULL,
    ERROR_SPACES_REPAIR_IN_PROGRESS,
}

impl USERMODE_SPACES {
    pub fn code(&self) -> u32 {
        return match self {
            USERMODE_SPACES::ERROR_SPACES_POOL_WAS_DELETED => 0x00E70001 as u32,
            USERMODE_SPACES::ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID => 0x80E70001 as u32,
            USERMODE_SPACES::ERROR_SPACES_INTERNAL_ERROR => 0x80E70002 as u32,
            USERMODE_SPACES::ERROR_SPACES_RESILIENCY_TYPE_INVALID => 0x80E70003 as u32,
            USERMODE_SPACES::ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID => 0x80E70004 as u32,
            USERMODE_SPACES::ERROR_SPACES_DRIVE_REDUNDANCY_INVALID => 0x80E70006 as u32,
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID => 0x80E70007 as u32,
            USERMODE_SPACES::ERROR_SPACES_PARITY_LAYOUT_INVALID => 0x80E70008 as u32,
            USERMODE_SPACES::ERROR_SPACES_INTERLEAVE_LENGTH_INVALID => 0x80E70009 as u32,
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID => 0x80E7000A as u32,
            USERMODE_SPACES::ERROR_SPACES_NOT_ENOUGH_DRIVES => 0x80E7000B as u32,
            USERMODE_SPACES::ERROR_SPACES_EXTENDED_ERROR => 0x80E7000C as u32,
            USERMODE_SPACES::ERROR_SPACES_PROVISIONING_TYPE_INVALID => 0x80E7000D as u32,
            USERMODE_SPACES::ERROR_SPACES_ALLOCATION_SIZE_INVALID => 0x80E7000E as u32,
            USERMODE_SPACES::ERROR_SPACES_ENCLOSURE_AWARE_INVALID => 0x80E7000F as u32,
            USERMODE_SPACES::ERROR_SPACES_WRITE_CACHE_SIZE_INVALID => 0x80E70010 as u32,
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_GROUPS_INVALID => 0x80E70011 as u32,
            USERMODE_SPACES::ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID => 0x80E70012 as u32,
            USERMODE_SPACES::ERROR_SPACES_ENTRY_INCOMPLETE => 0x80E70013 as u32,
            USERMODE_SPACES::ERROR_SPACES_ENTRY_INVALID => 0x80E70014 as u32,
            USERMODE_SPACES::ERROR_SPACES_UPDATE_COLUMN_STATE => 0x80E70015 as u32,
            USERMODE_SPACES::ERROR_SPACES_MAP_REQUIRED => 0x80E70016 as u32,
            USERMODE_SPACES::ERROR_SPACES_UNSUPPORTED_VERSION => 0x80E70017 as u32,
            USERMODE_SPACES::ERROR_SPACES_CORRUPT_METADATA => 0x80E70018 as u32,
            USERMODE_SPACES::ERROR_SPACES_DRT_FULL => 0x80E70019 as u32,
            USERMODE_SPACES::ERROR_SPACES_INCONSISTENCY => 0x80E7001A as u32,
            USERMODE_SPACES::ERROR_SPACES_LOG_NOT_READY => 0x80E7001B as u32,
            USERMODE_SPACES::ERROR_SPACES_NO_REDUNDANCY => 0x80E7001C as u32,
            USERMODE_SPACES::ERROR_SPACES_DRIVE_NOT_READY => 0x80E7001D as u32,
            USERMODE_SPACES::ERROR_SPACES_DRIVE_SPLIT => 0x80E7001E as u32,
            USERMODE_SPACES::ERROR_SPACES_DRIVE_LOST_DATA => 0x80E7001F as u32,
            USERMODE_SPACES::ERROR_SPACES_MARK_DIRTY => 0x80E70020 as u32,
            USERMODE_SPACES::ERROR_SPACES_FLUSH_METADATA => 0x80E70025 as u32,
            USERMODE_SPACES::ERROR_SPACES_CACHE_FULL => 0x80E70026 as u32,
            USERMODE_SPACES::ERROR_SPACES_REPAIR_IN_PROGRESS => 0x80E70027 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            USERMODE_SPACES::ERROR_SPACES_POOL_WAS_DELETED => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_POOL_WAS_DELETED),
            USERMODE_SPACES::ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_INTERNAL_ERROR => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_INTERNAL_ERROR),
            USERMODE_SPACES::ERROR_SPACES_RESILIENCY_TYPE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_RESILIENCY_TYPE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_DRIVE_REDUNDANCY_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRIVE_REDUNDANCY_INVALID),
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID),
            USERMODE_SPACES::ERROR_SPACES_PARITY_LAYOUT_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_PARITY_LAYOUT_INVALID),
            USERMODE_SPACES::ERROR_SPACES_INTERLEAVE_LENGTH_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_INTERLEAVE_LENGTH_INVALID),
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID),
            USERMODE_SPACES::ERROR_SPACES_NOT_ENOUGH_DRIVES => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_NOT_ENOUGH_DRIVES),
            USERMODE_SPACES::ERROR_SPACES_EXTENDED_ERROR => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_EXTENDED_ERROR),
            USERMODE_SPACES::ERROR_SPACES_PROVISIONING_TYPE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_PROVISIONING_TYPE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_ALLOCATION_SIZE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_ALLOCATION_SIZE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_ENCLOSURE_AWARE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_ENCLOSURE_AWARE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_WRITE_CACHE_SIZE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_WRITE_CACHE_SIZE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_GROUPS_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_GROUPS_INVALID),
            USERMODE_SPACES::ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID),
            USERMODE_SPACES::ERROR_SPACES_ENTRY_INCOMPLETE => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_ENTRY_INCOMPLETE),
            USERMODE_SPACES::ERROR_SPACES_ENTRY_INVALID => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_ENTRY_INVALID),
            USERMODE_SPACES::ERROR_SPACES_UPDATE_COLUMN_STATE => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_UPDATE_COLUMN_STATE),
            USERMODE_SPACES::ERROR_SPACES_MAP_REQUIRED => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_MAP_REQUIRED),
            USERMODE_SPACES::ERROR_SPACES_UNSUPPORTED_VERSION => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_UNSUPPORTED_VERSION),
            USERMODE_SPACES::ERROR_SPACES_CORRUPT_METADATA => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_CORRUPT_METADATA),
            USERMODE_SPACES::ERROR_SPACES_DRT_FULL => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRT_FULL),
            USERMODE_SPACES::ERROR_SPACES_INCONSISTENCY => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_INCONSISTENCY),
            USERMODE_SPACES::ERROR_SPACES_LOG_NOT_READY => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_LOG_NOT_READY),
            USERMODE_SPACES::ERROR_SPACES_NO_REDUNDANCY => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_NO_REDUNDANCY),
            USERMODE_SPACES::ERROR_SPACES_DRIVE_NOT_READY => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRIVE_NOT_READY),
            USERMODE_SPACES::ERROR_SPACES_DRIVE_SPLIT => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRIVE_SPLIT),
            USERMODE_SPACES::ERROR_SPACES_DRIVE_LOST_DATA => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_DRIVE_LOST_DATA),
            USERMODE_SPACES::ERROR_SPACES_MARK_DIRTY => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_MARK_DIRTY),
            USERMODE_SPACES::ERROR_SPACES_FLUSH_METADATA => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_FLUSH_METADATA),
            USERMODE_SPACES::ERROR_SPACES_CACHE_FULL => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_CACHE_FULL),
            USERMODE_SPACES::ERROR_SPACES_REPAIR_IN_PROGRESS => RawError::Kind(USERMODE_SPACES::ERROR_SPACES_REPAIR_IN_PROGRESS),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            USERMODE_SPACES::ERROR_SPACES_POOL_WAS_DELETED => "The storage pool was deleted by the driver. The object cache should be updated.",
            USERMODE_SPACES::ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID => "The specified fault domain type or combination of minimum / maximum fault domain type is not valid.",
            USERMODE_SPACES::ERROR_SPACES_INTERNAL_ERROR => "A Storage Spaces internal error occurred.",
            USERMODE_SPACES::ERROR_SPACES_RESILIENCY_TYPE_INVALID => "The specified resiliency type is not valid.",
            USERMODE_SPACES::ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID => "The physical disk's sector size is not supported by the storage pool.",
            USERMODE_SPACES::ERROR_SPACES_DRIVE_REDUNDANCY_INVALID => "The requested redundancy is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID => "The number of data copies requested is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_PARITY_LAYOUT_INVALID => "The value for ParityLayout is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_INTERLEAVE_LENGTH_INVALID => "The value for interleave length is outside of the supported range of values or is not a power of 2.",
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID => "The number of columns specified is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_NOT_ENOUGH_DRIVES => "There were not enough physical disks to complete the requested operation.",
            USERMODE_SPACES::ERROR_SPACES_EXTENDED_ERROR => "Extended error information is available.",
            USERMODE_SPACES::ERROR_SPACES_PROVISIONING_TYPE_INVALID => "The specified provisioning type is not valid.",
            USERMODE_SPACES::ERROR_SPACES_ALLOCATION_SIZE_INVALID => "The allocation size is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_ENCLOSURE_AWARE_INVALID => "Enclosure awareness is not supported for this virtual disk.",
            USERMODE_SPACES::ERROR_SPACES_WRITE_CACHE_SIZE_INVALID => "The write cache size is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_GROUPS_INVALID => "The value for number of groups is outside of the supported range of values.",
            USERMODE_SPACES::ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID => "The OperationalState of the physical disk is invalid for this operation.",
            USERMODE_SPACES::ERROR_SPACES_ENTRY_INCOMPLETE => "The specified log entry is not complete.",
            USERMODE_SPACES::ERROR_SPACES_ENTRY_INVALID => "The specified log entry is not valid.",
            USERMODE_SPACES::ERROR_SPACES_UPDATE_COLUMN_STATE => "A column's state needs to be updated.",
            USERMODE_SPACES::ERROR_SPACES_MAP_REQUIRED => "An extent needs to be allocated.",
            USERMODE_SPACES::ERROR_SPACES_UNSUPPORTED_VERSION => "The metadata version is unsupported.",
            USERMODE_SPACES::ERROR_SPACES_CORRUPT_METADATA => "The metadata read was corrupt.",
            USERMODE_SPACES::ERROR_SPACES_DRT_FULL => "The DRT is full.",
            USERMODE_SPACES::ERROR_SPACES_INCONSISTENCY => "An inconsistency was found.",
            USERMODE_SPACES::ERROR_SPACES_LOG_NOT_READY => "The log is not ready.",
            USERMODE_SPACES::ERROR_SPACES_NO_REDUNDANCY => "No good copy of data was available.",
            USERMODE_SPACES::ERROR_SPACES_DRIVE_NOT_READY => "The drive is not ready.",
            USERMODE_SPACES::ERROR_SPACES_DRIVE_SPLIT => "The data on this drive is stale.",
            USERMODE_SPACES::ERROR_SPACES_DRIVE_LOST_DATA => "The data on this drive has been lost.",
            USERMODE_SPACES::ERROR_SPACES_MARK_DIRTY => "A slab needs to be marked dirty.",
            USERMODE_SPACES::ERROR_SPACES_FLUSH_METADATA => "The cache metadata needs to be written and flushed.",
            USERMODE_SPACES::ERROR_SPACES_CACHE_FULL => "The cache is full.",
            USERMODE_SPACES::ERROR_SPACES_REPAIR_IN_PROGRESS => "Repair is in progress.",
        }
    }

    pub fn from_name(name: &str) -> USERMODE_SPACES {
        return match name {
            "ERROR_SPACES_POOL_WAS_DELETED" => USERMODE_SPACES::ERROR_SPACES_POOL_WAS_DELETED,
            "ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID" => USERMODE_SPACES::ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID,
            "ERROR_SPACES_INTERNAL_ERROR" => USERMODE_SPACES::ERROR_SPACES_INTERNAL_ERROR,
            "ERROR_SPACES_RESILIENCY_TYPE_INVALID" => USERMODE_SPACES::ERROR_SPACES_RESILIENCY_TYPE_INVALID,
            "ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID" => USERMODE_SPACES::ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID,
            "ERROR_SPACES_DRIVE_REDUNDANCY_INVALID" => USERMODE_SPACES::ERROR_SPACES_DRIVE_REDUNDANCY_INVALID,
            "ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID" => USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID,
            "ERROR_SPACES_PARITY_LAYOUT_INVALID" => USERMODE_SPACES::ERROR_SPACES_PARITY_LAYOUT_INVALID,
            "ERROR_SPACES_INTERLEAVE_LENGTH_INVALID" => USERMODE_SPACES::ERROR_SPACES_INTERLEAVE_LENGTH_INVALID,
            "ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID" => USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID,
            "ERROR_SPACES_NOT_ENOUGH_DRIVES" => USERMODE_SPACES::ERROR_SPACES_NOT_ENOUGH_DRIVES,
            "ERROR_SPACES_EXTENDED_ERROR" => USERMODE_SPACES::ERROR_SPACES_EXTENDED_ERROR,
            "ERROR_SPACES_PROVISIONING_TYPE_INVALID" => USERMODE_SPACES::ERROR_SPACES_PROVISIONING_TYPE_INVALID,
            "ERROR_SPACES_ALLOCATION_SIZE_INVALID" => USERMODE_SPACES::ERROR_SPACES_ALLOCATION_SIZE_INVALID,
            "ERROR_SPACES_ENCLOSURE_AWARE_INVALID" => USERMODE_SPACES::ERROR_SPACES_ENCLOSURE_AWARE_INVALID,
            "ERROR_SPACES_WRITE_CACHE_SIZE_INVALID" => USERMODE_SPACES::ERROR_SPACES_WRITE_CACHE_SIZE_INVALID,
            "ERROR_SPACES_NUMBER_OF_GROUPS_INVALID" => USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_GROUPS_INVALID,
            "ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID" => USERMODE_SPACES::ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID,
            "ERROR_SPACES_ENTRY_INCOMPLETE" => USERMODE_SPACES::ERROR_SPACES_ENTRY_INCOMPLETE,
            "ERROR_SPACES_ENTRY_INVALID" => USERMODE_SPACES::ERROR_SPACES_ENTRY_INVALID,
            "ERROR_SPACES_UPDATE_COLUMN_STATE" => USERMODE_SPACES::ERROR_SPACES_UPDATE_COLUMN_STATE,
            "ERROR_SPACES_MAP_REQUIRED" => USERMODE_SPACES::ERROR_SPACES_MAP_REQUIRED,
            "ERROR_SPACES_UNSUPPORTED_VERSION" => USERMODE_SPACES::ERROR_SPACES_UNSUPPORTED_VERSION,
            "ERROR_SPACES_CORRUPT_METADATA" => USERMODE_SPACES::ERROR_SPACES_CORRUPT_METADATA,
            "ERROR_SPACES_DRT_FULL" => USERMODE_SPACES::ERROR_SPACES_DRT_FULL,
            "ERROR_SPACES_INCONSISTENCY" => USERMODE_SPACES::ERROR_SPACES_INCONSISTENCY,
            "ERROR_SPACES_LOG_NOT_READY" => USERMODE_SPACES::ERROR_SPACES_LOG_NOT_READY,
            "ERROR_SPACES_NO_REDUNDANCY" => USERMODE_SPACES::ERROR_SPACES_NO_REDUNDANCY,
            "ERROR_SPACES_DRIVE_NOT_READY" => USERMODE_SPACES::ERROR_SPACES_DRIVE_NOT_READY,
            "ERROR_SPACES_DRIVE_SPLIT" => USERMODE_SPACES::ERROR_SPACES_DRIVE_SPLIT,
            "ERROR_SPACES_DRIVE_LOST_DATA" => USERMODE_SPACES::ERROR_SPACES_DRIVE_LOST_DATA,
            "ERROR_SPACES_MARK_DIRTY" => USERMODE_SPACES::ERROR_SPACES_MARK_DIRTY,
            "ERROR_SPACES_FLUSH_METADATA" => USERMODE_SPACES::ERROR_SPACES_FLUSH_METADATA,
            "ERROR_SPACES_CACHE_FULL" => USERMODE_SPACES::ERROR_SPACES_CACHE_FULL,
            "ERROR_SPACES_REPAIR_IN_PROGRESS" => USERMODE_SPACES::ERROR_SPACES_REPAIR_IN_PROGRESS,
        }
    }
    pub fn from_code(code: u32) -> USERMODE_SPACES {
        return match code {
            0x00E70001 => USERMODE_SPACES::ERROR_SPACES_POOL_WAS_DELETED,
            0x80E70001 => USERMODE_SPACES::ERROR_SPACES_FAULT_DOMAIN_TYPE_INVALID,
            0x80E70002 => USERMODE_SPACES::ERROR_SPACES_INTERNAL_ERROR,
            0x80E70003 => USERMODE_SPACES::ERROR_SPACES_RESILIENCY_TYPE_INVALID,
            0x80E70004 => USERMODE_SPACES::ERROR_SPACES_DRIVE_SECTOR_SIZE_INVALID,
            0x80E70006 => USERMODE_SPACES::ERROR_SPACES_DRIVE_REDUNDANCY_INVALID,
            0x80E70007 => USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_DATA_COPIES_INVALID,
            0x80E70008 => USERMODE_SPACES::ERROR_SPACES_PARITY_LAYOUT_INVALID,
            0x80E70009 => USERMODE_SPACES::ERROR_SPACES_INTERLEAVE_LENGTH_INVALID,
            0x80E7000A => USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_COLUMNS_INVALID,
            0x80E7000B => USERMODE_SPACES::ERROR_SPACES_NOT_ENOUGH_DRIVES,
            0x80E7000C => USERMODE_SPACES::ERROR_SPACES_EXTENDED_ERROR,
            0x80E7000D => USERMODE_SPACES::ERROR_SPACES_PROVISIONING_TYPE_INVALID,
            0x80E7000E => USERMODE_SPACES::ERROR_SPACES_ALLOCATION_SIZE_INVALID,
            0x80E7000F => USERMODE_SPACES::ERROR_SPACES_ENCLOSURE_AWARE_INVALID,
            0x80E70010 => USERMODE_SPACES::ERROR_SPACES_WRITE_CACHE_SIZE_INVALID,
            0x80E70011 => USERMODE_SPACES::ERROR_SPACES_NUMBER_OF_GROUPS_INVALID,
            0x80E70012 => USERMODE_SPACES::ERROR_SPACES_DRIVE_OPERATIONAL_STATE_INVALID,
            0x80E70013 => USERMODE_SPACES::ERROR_SPACES_ENTRY_INCOMPLETE,
            0x80E70014 => USERMODE_SPACES::ERROR_SPACES_ENTRY_INVALID,
            0x80E70015 => USERMODE_SPACES::ERROR_SPACES_UPDATE_COLUMN_STATE,
            0x80E70016 => USERMODE_SPACES::ERROR_SPACES_MAP_REQUIRED,
            0x80E70017 => USERMODE_SPACES::ERROR_SPACES_UNSUPPORTED_VERSION,
            0x80E70018 => USERMODE_SPACES::ERROR_SPACES_CORRUPT_METADATA,
            0x80E70019 => USERMODE_SPACES::ERROR_SPACES_DRT_FULL,
            0x80E7001A => USERMODE_SPACES::ERROR_SPACES_INCONSISTENCY,
            0x80E7001B => USERMODE_SPACES::ERROR_SPACES_LOG_NOT_READY,
            0x80E7001C => USERMODE_SPACES::ERROR_SPACES_NO_REDUNDANCY,
            0x80E7001D => USERMODE_SPACES::ERROR_SPACES_DRIVE_NOT_READY,
            0x80E7001E => USERMODE_SPACES::ERROR_SPACES_DRIVE_SPLIT,
            0x80E7001F => USERMODE_SPACES::ERROR_SPACES_DRIVE_LOST_DATA,
            0x80E70020 => USERMODE_SPACES::ERROR_SPACES_MARK_DIRTY,
            0x80E70025 => USERMODE_SPACES::ERROR_SPACES_FLUSH_METADATA,
            0x80E70026 => USERMODE_SPACES::ERROR_SPACES_CACHE_FULL,
            0x80E70027 => USERMODE_SPACES::ERROR_SPACES_REPAIR_IN_PROGRESS,
        }
    }
}
