/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum UTC {
    UTC_E_TOGGLE_TRACE_STARTED,
    UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT,
    UTC_E_AOT_NOT_RUNNING,
    UTC_E_SCRIPT_TYPE_INVALID,
    UTC_E_SCENARIODEF_NOT_FOUND,
    UTC_E_TRACEPROFILE_NOT_FOUND,
    UTC_E_FORWARDER_ALREADY_ENABLED,
    UTC_E_FORWARDER_ALREADY_DISABLED,
    UTC_E_EVENTLOG_ENTRY_MALFORMED,
    UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH,
    UTC_E_SCRIPT_TERMINATED,
    UTC_E_INVALID_CUSTOM_FILTER,
    UTC_E_TRACE_NOT_RUNNING,
    UTC_E_REESCALATED_TOO_QUICKLY,
    UTC_E_ESCALATION_ALREADY_RUNNING,
    UTC_E_PERFTRACK_ALREADY_TRACING,
    UTC_E_REACHED_MAX_ESCALATIONS,
    UTC_E_FORWARDER_PRODUCER_MISMATCH,
    UTC_E_INTENTIONAL_SCRIPT_FAILURE,
    UTC_E_SQM_INIT_FAILED,
    UTC_E_NO_WER_LOGGER_SUPPORTED,
    UTC_E_TRACERS_DONT_EXIST,
    UTC_E_WINRT_INIT_FAILED,
    UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH,
    UTC_E_INVALID_FILTER,
    UTC_E_EXE_TERMINATED,
    UTC_E_ESCALATION_NOT_AUTHORIZED,
    UTC_E_SETUP_NOT_AUTHORIZED,
    UTC_E_CHILD_PROCESS_FAILED,
    UTC_E_COMMAND_LINE_NOT_AUTHORIZED,
    UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML,
    UTC_E_ESCALATION_TIMED_OUT,
    UTC_E_SETUP_TIMED_OUT,
    UTC_E_TRIGGER_MISMATCH,
    UTC_E_TRIGGER_NOT_FOUND,
    UTC_E_SIF_NOT_SUPPORTED,
    UTC_E_DELAY_TERMINATED,
    UTC_E_DEVICE_TICKET_ERROR,
    UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED,
    UTC_E_API_RESULT_UNAVAILABLE,
    UTC_E_RPC_TIMEOUT,
    UTC_E_RPC_WAIT_FAILED,
    UTC_E_API_BUSY,
    UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET,
    UTC_E_EXCLUSIVITY_NOT_AVAILABLE,
    UTC_E_GETFILE_FILE_PATH_NOT_APPROVED,
    UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS,
    UTC_E_TIME_TRIGGER_ON_START_INVALID,
    UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION,
    UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE,
    UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE,
    UTC_E_BINARY_MISSING,
    UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID,
    UTC_E_UNABLE_TO_RESOLVE_SESSION,
    UTC_E_THROTTLED,
    UTC_E_UNAPPROVED_SCRIPT,
    UTC_E_SCRIPT_MISSING,
    UTC_E_SCENARIO_THROTTLED,
    UTC_E_API_NOT_SUPPORTED,
    UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED,
    UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED,
    UTC_E_CERT_REV_FAILED,
    UTC_E_FAILED_TO_START_NDISCAP,
    UTC_E_KERNELDUMP_LIMIT_REACHED,
    UTC_E_MISSING_AGGREGATE_EVENT_TAG,
    UTC_E_INVALID_AGGREGATION_STRUCT,
    UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION,
    UTC_E_FILTER_MISSING_ATTRIBUTE,
    UTC_E_FILTER_INVALID_TYPE,
    UTC_E_FILTER_VARIABLE_NOT_FOUND,
    UTC_E_FILTER_FUNCTION_RESTRICTED,
    UTC_E_FILTER_VERSION_MISMATCH,
    UTC_E_FILTER_INVALID_FUNCTION,
    UTC_E_FILTER_INVALID_FUNCTION_PARAMS,
    UTC_E_FILTER_INVALID_COMMAND,
    UTC_E_FILTER_ILLEGAL_EVAL,
    UTC_E_TTTRACER_RETURNED_ERROR,
    UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE,
    UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS,
    UTC_E_SCENARIO_HAS_NO_ACTIONS,
    UTC_E_TTTRACER_STORAGE_FULL,
    UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE,
    UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN,
    UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED,
    UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED,
    UTC_E_TRACE_THROTTLED,
}

impl UTC {
    pub fn code(&self) -> u32 {
        return match self {
            UTC::UTC_E_TOGGLE_TRACE_STARTED => 0x87C51001 as u32,
            UTC::UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT => 0x87C51002 as u32,
            UTC::UTC_E_AOT_NOT_RUNNING => 0x87C51003 as u32,
            UTC::UTC_E_SCRIPT_TYPE_INVALID => 0x87C51004 as u32,
            UTC::UTC_E_SCENARIODEF_NOT_FOUND => 0x87C51005 as u32,
            UTC::UTC_E_TRACEPROFILE_NOT_FOUND => 0x87C51006 as u32,
            UTC::UTC_E_FORWARDER_ALREADY_ENABLED => 0x87C51007 as u32,
            UTC::UTC_E_FORWARDER_ALREADY_DISABLED => 0x87C51008 as u32,
            UTC::UTC_E_EVENTLOG_ENTRY_MALFORMED => 0x87C51009 as u32,
            UTC::UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH => 0x87C5100A as u32,
            UTC::UTC_E_SCRIPT_TERMINATED => 0x87C5100B as u32,
            UTC::UTC_E_INVALID_CUSTOM_FILTER => 0x87C5100C as u32,
            UTC::UTC_E_TRACE_NOT_RUNNING => 0x87C5100D as u32,
            UTC::UTC_E_REESCALATED_TOO_QUICKLY => 0x87C5100E as u32,
            UTC::UTC_E_ESCALATION_ALREADY_RUNNING => 0x87C5100F as u32,
            UTC::UTC_E_PERFTRACK_ALREADY_TRACING => 0x87C51010 as u32,
            UTC::UTC_E_REACHED_MAX_ESCALATIONS => 0x87C51011 as u32,
            UTC::UTC_E_FORWARDER_PRODUCER_MISMATCH => 0x87C51012 as u32,
            UTC::UTC_E_INTENTIONAL_SCRIPT_FAILURE => 0x87C51013 as u32,
            UTC::UTC_E_SQM_INIT_FAILED => 0x87C51014 as u32,
            UTC::UTC_E_NO_WER_LOGGER_SUPPORTED => 0x87C51015 as u32,
            UTC::UTC_E_TRACERS_DONT_EXIST => 0x87C51016 as u32,
            UTC::UTC_E_WINRT_INIT_FAILED => 0x87C51017 as u32,
            UTC::UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH => 0x87C51018 as u32,
            UTC::UTC_E_INVALID_FILTER => 0x87C51019 as u32,
            UTC::UTC_E_EXE_TERMINATED => 0x87C5101A as u32,
            UTC::UTC_E_ESCALATION_NOT_AUTHORIZED => 0x87C5101B as u32,
            UTC::UTC_E_SETUP_NOT_AUTHORIZED => 0x87C5101C as u32,
            UTC::UTC_E_CHILD_PROCESS_FAILED => 0x87C5101D as u32,
            UTC::UTC_E_COMMAND_LINE_NOT_AUTHORIZED => 0x87C5101E as u32,
            UTC::UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML => 0x87C5101F as u32,
            UTC::UTC_E_ESCALATION_TIMED_OUT => 0x87C51020 as u32,
            UTC::UTC_E_SETUP_TIMED_OUT => 0x87C51021 as u32,
            UTC::UTC_E_TRIGGER_MISMATCH => 0x87C51022 as u32,
            UTC::UTC_E_TRIGGER_NOT_FOUND => 0x87C51023 as u32,
            UTC::UTC_E_SIF_NOT_SUPPORTED => 0x87C51024 as u32,
            UTC::UTC_E_DELAY_TERMINATED => 0x87C51025 as u32,
            UTC::UTC_E_DEVICE_TICKET_ERROR => 0x87C51026 as u32,
            UTC::UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED => 0x87C51027 as u32,
            UTC::UTC_E_API_RESULT_UNAVAILABLE => 0x87C51028 as u32,
            UTC::UTC_E_RPC_TIMEOUT => 0x87C51029 as u32,
            UTC::UTC_E_RPC_WAIT_FAILED => 0x87C5102A as u32,
            UTC::UTC_E_API_BUSY => 0x87C5102B as u32,
            UTC::UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET => 0x87C5102C as u32,
            UTC::UTC_E_EXCLUSIVITY_NOT_AVAILABLE => 0x87C5102D as u32,
            UTC::UTC_E_GETFILE_FILE_PATH_NOT_APPROVED => 0x87C5102E as u32,
            UTC::UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS => 0x87C5102F as u32,
            UTC::UTC_E_TIME_TRIGGER_ON_START_INVALID => 0x87C51030 as u32,
            UTC::UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION => 0x87C51031 as u32,
            UTC::UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE => 0x87C51032 as u32,
            UTC::UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE => 0x87C51033 as u32,
            UTC::UTC_E_BINARY_MISSING => 0x87C51034 as u32,
            UTC::UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID => 0x87C51036 as u32,
            UTC::UTC_E_UNABLE_TO_RESOLVE_SESSION => 0x87C51037 as u32,
            UTC::UTC_E_THROTTLED => 0x87C51038 as u32,
            UTC::UTC_E_UNAPPROVED_SCRIPT => 0x87C51039 as u32,
            UTC::UTC_E_SCRIPT_MISSING => 0x87C5103A as u32,
            UTC::UTC_E_SCENARIO_THROTTLED => 0x87C5103B as u32,
            UTC::UTC_E_API_NOT_SUPPORTED => 0x87C5103C as u32,
            UTC::UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED => 0x87C5103D as u32,
            UTC::UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED => 0x87C5103E as u32,
            UTC::UTC_E_CERT_REV_FAILED => 0x87C5103F as u32,
            UTC::UTC_E_FAILED_TO_START_NDISCAP => 0x87C51040 as u32,
            UTC::UTC_E_KERNELDUMP_LIMIT_REACHED => 0x87C51041 as u32,
            UTC::UTC_E_MISSING_AGGREGATE_EVENT_TAG => 0x87C51042 as u32,
            UTC::UTC_E_INVALID_AGGREGATION_STRUCT => 0x87C51043 as u32,
            UTC::UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION => 0x87C51044 as u32,
            UTC::UTC_E_FILTER_MISSING_ATTRIBUTE => 0x87C51045 as u32,
            UTC::UTC_E_FILTER_INVALID_TYPE => 0x87C51046 as u32,
            UTC::UTC_E_FILTER_VARIABLE_NOT_FOUND => 0x87C51047 as u32,
            UTC::UTC_E_FILTER_FUNCTION_RESTRICTED => 0x87C51048 as u32,
            UTC::UTC_E_FILTER_VERSION_MISMATCH => 0x87C51049 as u32,
            UTC::UTC_E_FILTER_INVALID_FUNCTION => 0x87C51050 as u32,
            UTC::UTC_E_FILTER_INVALID_FUNCTION_PARAMS => 0x87C51051 as u32,
            UTC::UTC_E_FILTER_INVALID_COMMAND => 0x87C51052 as u32,
            UTC::UTC_E_FILTER_ILLEGAL_EVAL => 0x87C51053 as u32,
            UTC::UTC_E_TTTRACER_RETURNED_ERROR => 0x87C51054 as u32,
            UTC::UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE => 0x87C51055 as u32,
            UTC::UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS => 0x87C51056 as u32,
            UTC::UTC_E_SCENARIO_HAS_NO_ACTIONS => 0x87C51057 as u32,
            UTC::UTC_E_TTTRACER_STORAGE_FULL => 0x87C51058 as u32,
            UTC::UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE => 0x87C51059 as u32,
            UTC::UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN => 0x87C5105A as u32,
            UTC::UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED => 0x87C5105B as u32,
            UTC::UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED => 0x87C5105C as u32,
            UTC::UTC_E_TRACE_THROTTLED => 0x87C5105D as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            UTC::UTC_E_TOGGLE_TRACE_STARTED => RawError::Kind(UTC::UTC_E_TOGGLE_TRACE_STARTED),
            UTC::UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT => RawError::Kind(UTC::UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT),
            UTC::UTC_E_AOT_NOT_RUNNING => RawError::Kind(UTC::UTC_E_AOT_NOT_RUNNING),
            UTC::UTC_E_SCRIPT_TYPE_INVALID => RawError::Kind(UTC::UTC_E_SCRIPT_TYPE_INVALID),
            UTC::UTC_E_SCENARIODEF_NOT_FOUND => RawError::Kind(UTC::UTC_E_SCENARIODEF_NOT_FOUND),
            UTC::UTC_E_TRACEPROFILE_NOT_FOUND => RawError::Kind(UTC::UTC_E_TRACEPROFILE_NOT_FOUND),
            UTC::UTC_E_FORWARDER_ALREADY_ENABLED => RawError::Kind(UTC::UTC_E_FORWARDER_ALREADY_ENABLED),
            UTC::UTC_E_FORWARDER_ALREADY_DISABLED => RawError::Kind(UTC::UTC_E_FORWARDER_ALREADY_DISABLED),
            UTC::UTC_E_EVENTLOG_ENTRY_MALFORMED => RawError::Kind(UTC::UTC_E_EVENTLOG_ENTRY_MALFORMED),
            UTC::UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH => RawError::Kind(UTC::UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH),
            UTC::UTC_E_SCRIPT_TERMINATED => RawError::Kind(UTC::UTC_E_SCRIPT_TERMINATED),
            UTC::UTC_E_INVALID_CUSTOM_FILTER => RawError::Kind(UTC::UTC_E_INVALID_CUSTOM_FILTER),
            UTC::UTC_E_TRACE_NOT_RUNNING => RawError::Kind(UTC::UTC_E_TRACE_NOT_RUNNING),
            UTC::UTC_E_REESCALATED_TOO_QUICKLY => RawError::Kind(UTC::UTC_E_REESCALATED_TOO_QUICKLY),
            UTC::UTC_E_ESCALATION_ALREADY_RUNNING => RawError::Kind(UTC::UTC_E_ESCALATION_ALREADY_RUNNING),
            UTC::UTC_E_PERFTRACK_ALREADY_TRACING => RawError::Kind(UTC::UTC_E_PERFTRACK_ALREADY_TRACING),
            UTC::UTC_E_REACHED_MAX_ESCALATIONS => RawError::Kind(UTC::UTC_E_REACHED_MAX_ESCALATIONS),
            UTC::UTC_E_FORWARDER_PRODUCER_MISMATCH => RawError::Kind(UTC::UTC_E_FORWARDER_PRODUCER_MISMATCH),
            UTC::UTC_E_INTENTIONAL_SCRIPT_FAILURE => RawError::Kind(UTC::UTC_E_INTENTIONAL_SCRIPT_FAILURE),
            UTC::UTC_E_SQM_INIT_FAILED => RawError::Kind(UTC::UTC_E_SQM_INIT_FAILED),
            UTC::UTC_E_NO_WER_LOGGER_SUPPORTED => RawError::Kind(UTC::UTC_E_NO_WER_LOGGER_SUPPORTED),
            UTC::UTC_E_TRACERS_DONT_EXIST => RawError::Kind(UTC::UTC_E_TRACERS_DONT_EXIST),
            UTC::UTC_E_WINRT_INIT_FAILED => RawError::Kind(UTC::UTC_E_WINRT_INIT_FAILED),
            UTC::UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH => RawError::Kind(UTC::UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH),
            UTC::UTC_E_INVALID_FILTER => RawError::Kind(UTC::UTC_E_INVALID_FILTER),
            UTC::UTC_E_EXE_TERMINATED => RawError::Kind(UTC::UTC_E_EXE_TERMINATED),
            UTC::UTC_E_ESCALATION_NOT_AUTHORIZED => RawError::Kind(UTC::UTC_E_ESCALATION_NOT_AUTHORIZED),
            UTC::UTC_E_SETUP_NOT_AUTHORIZED => RawError::Kind(UTC::UTC_E_SETUP_NOT_AUTHORIZED),
            UTC::UTC_E_CHILD_PROCESS_FAILED => RawError::Kind(UTC::UTC_E_CHILD_PROCESS_FAILED),
            UTC::UTC_E_COMMAND_LINE_NOT_AUTHORIZED => RawError::Kind(UTC::UTC_E_COMMAND_LINE_NOT_AUTHORIZED),
            UTC::UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML => RawError::Kind(UTC::UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML),
            UTC::UTC_E_ESCALATION_TIMED_OUT => RawError::Kind(UTC::UTC_E_ESCALATION_TIMED_OUT),
            UTC::UTC_E_SETUP_TIMED_OUT => RawError::Kind(UTC::UTC_E_SETUP_TIMED_OUT),
            UTC::UTC_E_TRIGGER_MISMATCH => RawError::Kind(UTC::UTC_E_TRIGGER_MISMATCH),
            UTC::UTC_E_TRIGGER_NOT_FOUND => RawError::Kind(UTC::UTC_E_TRIGGER_NOT_FOUND),
            UTC::UTC_E_SIF_NOT_SUPPORTED => RawError::Kind(UTC::UTC_E_SIF_NOT_SUPPORTED),
            UTC::UTC_E_DELAY_TERMINATED => RawError::Kind(UTC::UTC_E_DELAY_TERMINATED),
            UTC::UTC_E_DEVICE_TICKET_ERROR => RawError::Kind(UTC::UTC_E_DEVICE_TICKET_ERROR),
            UTC::UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED => RawError::Kind(UTC::UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED),
            UTC::UTC_E_API_RESULT_UNAVAILABLE => RawError::Kind(UTC::UTC_E_API_RESULT_UNAVAILABLE),
            UTC::UTC_E_RPC_TIMEOUT => RawError::Kind(UTC::UTC_E_RPC_TIMEOUT),
            UTC::UTC_E_RPC_WAIT_FAILED => RawError::Kind(UTC::UTC_E_RPC_WAIT_FAILED),
            UTC::UTC_E_API_BUSY => RawError::Kind(UTC::UTC_E_API_BUSY),
            UTC::UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET => RawError::Kind(UTC::UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET),
            UTC::UTC_E_EXCLUSIVITY_NOT_AVAILABLE => RawError::Kind(UTC::UTC_E_EXCLUSIVITY_NOT_AVAILABLE),
            UTC::UTC_E_GETFILE_FILE_PATH_NOT_APPROVED => RawError::Kind(UTC::UTC_E_GETFILE_FILE_PATH_NOT_APPROVED),
            UTC::UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS => RawError::Kind(UTC::UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS),
            UTC::UTC_E_TIME_TRIGGER_ON_START_INVALID => RawError::Kind(UTC::UTC_E_TIME_TRIGGER_ON_START_INVALID),
            UTC::UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION => RawError::Kind(UTC::UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION),
            UTC::UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE => RawError::Kind(UTC::UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE),
            UTC::UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE => RawError::Kind(UTC::UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE),
            UTC::UTC_E_BINARY_MISSING => RawError::Kind(UTC::UTC_E_BINARY_MISSING),
            UTC::UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID => RawError::Kind(UTC::UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID),
            UTC::UTC_E_UNABLE_TO_RESOLVE_SESSION => RawError::Kind(UTC::UTC_E_UNABLE_TO_RESOLVE_SESSION),
            UTC::UTC_E_THROTTLED => RawError::Kind(UTC::UTC_E_THROTTLED),
            UTC::UTC_E_UNAPPROVED_SCRIPT => RawError::Kind(UTC::UTC_E_UNAPPROVED_SCRIPT),
            UTC::UTC_E_SCRIPT_MISSING => RawError::Kind(UTC::UTC_E_SCRIPT_MISSING),
            UTC::UTC_E_SCENARIO_THROTTLED => RawError::Kind(UTC::UTC_E_SCENARIO_THROTTLED),
            UTC::UTC_E_API_NOT_SUPPORTED => RawError::Kind(UTC::UTC_E_API_NOT_SUPPORTED),
            UTC::UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED => RawError::Kind(UTC::UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED),
            UTC::UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED => RawError::Kind(UTC::UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED),
            UTC::UTC_E_CERT_REV_FAILED => RawError::Kind(UTC::UTC_E_CERT_REV_FAILED),
            UTC::UTC_E_FAILED_TO_START_NDISCAP => RawError::Kind(UTC::UTC_E_FAILED_TO_START_NDISCAP),
            UTC::UTC_E_KERNELDUMP_LIMIT_REACHED => RawError::Kind(UTC::UTC_E_KERNELDUMP_LIMIT_REACHED),
            UTC::UTC_E_MISSING_AGGREGATE_EVENT_TAG => RawError::Kind(UTC::UTC_E_MISSING_AGGREGATE_EVENT_TAG),
            UTC::UTC_E_INVALID_AGGREGATION_STRUCT => RawError::Kind(UTC::UTC_E_INVALID_AGGREGATION_STRUCT),
            UTC::UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION => RawError::Kind(UTC::UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION),
            UTC::UTC_E_FILTER_MISSING_ATTRIBUTE => RawError::Kind(UTC::UTC_E_FILTER_MISSING_ATTRIBUTE),
            UTC::UTC_E_FILTER_INVALID_TYPE => RawError::Kind(UTC::UTC_E_FILTER_INVALID_TYPE),
            UTC::UTC_E_FILTER_VARIABLE_NOT_FOUND => RawError::Kind(UTC::UTC_E_FILTER_VARIABLE_NOT_FOUND),
            UTC::UTC_E_FILTER_FUNCTION_RESTRICTED => RawError::Kind(UTC::UTC_E_FILTER_FUNCTION_RESTRICTED),
            UTC::UTC_E_FILTER_VERSION_MISMATCH => RawError::Kind(UTC::UTC_E_FILTER_VERSION_MISMATCH),
            UTC::UTC_E_FILTER_INVALID_FUNCTION => RawError::Kind(UTC::UTC_E_FILTER_INVALID_FUNCTION),
            UTC::UTC_E_FILTER_INVALID_FUNCTION_PARAMS => RawError::Kind(UTC::UTC_E_FILTER_INVALID_FUNCTION_PARAMS),
            UTC::UTC_E_FILTER_INVALID_COMMAND => RawError::Kind(UTC::UTC_E_FILTER_INVALID_COMMAND),
            UTC::UTC_E_FILTER_ILLEGAL_EVAL => RawError::Kind(UTC::UTC_E_FILTER_ILLEGAL_EVAL),
            UTC::UTC_E_TTTRACER_RETURNED_ERROR => RawError::Kind(UTC::UTC_E_TTTRACER_RETURNED_ERROR),
            UTC::UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE => RawError::Kind(UTC::UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE),
            UTC::UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS => RawError::Kind(UTC::UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS),
            UTC::UTC_E_SCENARIO_HAS_NO_ACTIONS => RawError::Kind(UTC::UTC_E_SCENARIO_HAS_NO_ACTIONS),
            UTC::UTC_E_TTTRACER_STORAGE_FULL => RawError::Kind(UTC::UTC_E_TTTRACER_STORAGE_FULL),
            UTC::UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE => RawError::Kind(UTC::UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE),
            UTC::UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN => RawError::Kind(UTC::UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN),
            UTC::UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED => RawError::Kind(UTC::UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED),
            UTC::UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED => RawError::Kind(UTC::UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED),
            UTC::UTC_E_TRACE_THROTTLED => RawError::Kind(UTC::UTC_E_TRACE_THROTTLED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            UTC::UTC_E_TOGGLE_TRACE_STARTED => "Toggle (alternative) trace started",
            UTC::UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT => "Cannot pre-empt running trace: The current trace has a higher priority",
            UTC::UTC_E_AOT_NOT_RUNNING => "The always-on-trace is not running",
            UTC::UTC_E_SCRIPT_TYPE_INVALID => "RunScriptAction contains an invalid script type",
            UTC::UTC_E_SCENARIODEF_NOT_FOUND => "Requested scenario definition cannot be found",
            UTC::UTC_E_TRACEPROFILE_NOT_FOUND => "Requested trace profile cannot be found",
            UTC::UTC_E_FORWARDER_ALREADY_ENABLED => "Trigger forwarder is already enabled",
            UTC::UTC_E_FORWARDER_ALREADY_DISABLED => "Trigger forwarder is already disabled",
            UTC::UTC_E_EVENTLOG_ENTRY_MALFORMED => "Cannot parse EventLog XML: The entry is malformed",
            UTC::UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH => "<diagrules> node contains a schemaversion which is not compatible with this client",
            UTC::UTC_E_SCRIPT_TERMINATED => "RunScriptAction was forced to terminate a script",
            UTC::UTC_E_INVALID_CUSTOM_FILTER => "ToggleTraceWithCustomFilterAction contains an invalid custom filter",
            UTC::UTC_E_TRACE_NOT_RUNNING => "The trace is not running",
            UTC::UTC_E_REESCALATED_TOO_QUICKLY => "A scenario failed to escalate: This scenario has escalated too recently",
            UTC::UTC_E_ESCALATION_ALREADY_RUNNING => "A scenario failed to escalate: This scenario is already running an escalation",
            UTC::UTC_E_PERFTRACK_ALREADY_TRACING => "Cannot start tracing: PerfTrack component is already tracing",
            UTC::UTC_E_REACHED_MAX_ESCALATIONS => "A scenario failed to escalate: This scenario has reached max escalations for this escalation type",
            UTC::UTC_E_FORWARDER_PRODUCER_MISMATCH => "Cannot update forwarder: The forwarder passed to the function is of a different type",
            UTC::UTC_E_INTENTIONAL_SCRIPT_FAILURE => "RunScriptAction failed intentionally to force this escalation to terminate",
            UTC::UTC_E_SQM_INIT_FAILED => "Failed to initialize SQM logger",
            UTC::UTC_E_NO_WER_LOGGER_SUPPORTED => "Failed to initialize WER logger: This system does not support WER for UTC",
            UTC::UTC_E_TRACERS_DONT_EXIST => "The TraceManager has attempted to take a tracing action without initializing tracers",
            UTC::UTC_E_WINRT_INIT_FAILED => "WinRT initialization failed",
            UTC::UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH => "<scenario> node contains a schemaversion that is not compatible with this client",
            UTC::UTC_E_INVALID_FILTER => "Scenario contains an invalid filter that can never be satisfied",
            UTC::UTC_E_EXE_TERMINATED => "RunExeWithArgsAction was forced to terminate a running executable",
            UTC::UTC_E_ESCALATION_NOT_AUTHORIZED => "Escalation for scenario failed due to insufficient permissions",
            UTC::UTC_E_SETUP_NOT_AUTHORIZED => "Setup for scenario failed due to insufficient permissions",
            UTC::UTC_E_CHILD_PROCESS_FAILED => "A process launched by UTC failed with a non-zero exit code.",
            UTC::UTC_E_COMMAND_LINE_NOT_AUTHORIZED => "A RunExeWithArgs action contains an unauthorized command line.",
            UTC::UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML => "UTC cannot load Scenario Editor XML. Convert the scenario file to a DiagTrack XML using the editor.",
            UTC::UTC_E_ESCALATION_TIMED_OUT => "Escalation for scenario has timed out",
            UTC::UTC_E_SETUP_TIMED_OUT => "Setup for scenario has timed out",
            UTC::UTC_E_TRIGGER_MISMATCH => "The given trigger does not match the expected trigger type",
            UTC::UTC_E_TRIGGER_NOT_FOUND => "Requested trigger cannot be found",
            UTC::UTC_E_SIF_NOT_SUPPORTED => "SIF is not supported on the machine",
            UTC::UTC_E_DELAY_TERMINATED => "The delay action was terminated",
            UTC::UTC_E_DEVICE_TICKET_ERROR => "The device ticket was not obtained",
            UTC::UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED => "The trace profile needs more memory than is available for tracing",
            UTC::UTC_E_API_RESULT_UNAVAILABLE => "The API was not completed successfully so the result is unavailable",
            UTC::UTC_E_RPC_TIMEOUT => "The requested API encountered a timeout in the API manager",
            UTC::UTC_E_RPC_WAIT_FAILED => "The synchronous API encountered a wait failure",
            UTC::UTC_E_API_BUSY => "The UTC API is busy with another request",
            UTC::UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET => "The running trace profile does not have a sufficient runtime to fulfill the escalation request",
            UTC::UTC_E_EXCLUSIVITY_NOT_AVAILABLE => "The trace profile could not be started because it requires exclusivity and another higher priority trace is already running",
            UTC::UTC_E_GETFILE_FILE_PATH_NOT_APPROVED => "The file path is not approved for the GetFile escalation action",
            UTC::UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS => "The escalation working directory for the requested escalation could not be created because it already exists",
            UTC::UTC_E_TIME_TRIGGER_ON_START_INVALID => "Time triggers cannot be used on a transition originating from the '_start' state",
            UTC::UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION => "Time triggers can only be attached to a single transition",
            UTC::UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE => "Time trigger duration must fall within an inclusive range of one second and 15 minutes",
            UTC::UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE => "Only one Time Trigger is allowed per state",
            UTC::UTC_E_BINARY_MISSING => "A RunExeWithArgs action contains a binary which is not present on the targeted device.",
            UTC::UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID => "UTC failed to identify the container id to use for a scenario escalation action.",
            UTC::UTC_E_UNABLE_TO_RESOLVE_SESSION => "Failed to resolve session ID during API invocation.",
            UTC::UTC_E_THROTTLED => "UTC has throttled the event for firing too often.",
            UTC::UTC_E_UNAPPROVED_SCRIPT => "The script is not approved to run as part of DiagTrack scenario.",
            UTC::UTC_E_SCRIPT_MISSING => "The script referenced in DiagTrack scenario is not present on the system.",
            UTC::UTC_E_SCENARIO_THROTTLED => "A trigger in this scenario is throttled, blocking the scenario from being loaded.",
            UTC::UTC_E_API_NOT_SUPPORTED => "The requested UTC API call is not supported on this device.",
            UTC::UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED => "The file path is not approved for collection on external rings for the GetFile escalation action.",
            UTC::UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED => "Querying a scenario definition exceeded the specified maximum timeout.",
            UTC::UTC_E_CERT_REV_FAILED => "Certification revocation checking has been enabled, but the revocation check failed to verify whether a certificate has been revoked. The server used to check for revocation might be unreachable.",
            UTC::UTC_E_FAILED_TO_START_NDISCAP => "Failed to start NDISCAP service for network packet capture trace.",
            UTC::UTC_E_KERNELDUMP_LIMIT_REACHED => "UTC can perform no more than one KernelDump action on a device every 24 hours.",
            UTC::UTC_E_MISSING_AGGREGATE_EVENT_TAG => "The event contained an aggregation or differential privacy structure, but did not specify MICROSOFT_EVENTTAG_AGGREGATE.",
            UTC::UTC_E_INVALID_AGGREGATION_STRUCT => "The event contained an invalid aggregation or differential privacy structure.",
            UTC::UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION => "The action cannot be completed in the specified destination.",
            UTC::UTC_E_FILTER_MISSING_ATTRIBUTE => "Filter command is missing a required attribute.",
            UTC::UTC_E_FILTER_INVALID_TYPE => "Filter command contains an unsupported type.",
            UTC::UTC_E_FILTER_VARIABLE_NOT_FOUND => "Filter variable does not exist at point of evaluation.",
            UTC::UTC_E_FILTER_FUNCTION_RESTRICTED => "Filter command is not allowed in the current context.",
            UTC::UTC_E_FILTER_VERSION_MISMATCH => "Requested filter version is incompatible with available version.",
            UTC::UTC_E_FILTER_INVALID_FUNCTION => "Filter does not support this function.",
            UTC::UTC_E_FILTER_INVALID_FUNCTION_PARAMS => "Filter function does not accept the provided parameter types and/or count.",
            UTC::UTC_E_FILTER_INVALID_COMMAND => "Filter command does not exist or is incorrectly formatted.",
            UTC::UTC_E_FILTER_ILLEGAL_EVAL => "Filter types can not be compared to each other.",
            UTC::UTC_E_TTTRACER_RETURNED_ERROR => "TTTracer executable returned a code other than ERROR_SUCCESS.",
            UTC::UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE => "The total size of the compressed escalation data payload exceeded the allowable limit.",
            UTC::UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS => "Escalation data was not completely transferred from agent to host.",
            UTC::UTC_E_SCENARIO_HAS_NO_ACTIONS => "An escalation was requested for a scenario which has no actions for the passed type.",
            UTC::UTC_E_TTTRACER_STORAGE_FULL => "UTC allocated space for TTTracer escalations is full.",
            UTC::UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE => "Disk needs minimum of 15GB to start TTD recording session.",
            UTC::UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN => "Escalation was cancelled due to component shutdown.",
            UTC::UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED => "The file for the GetFileInfo action must be under the \\Windows, \\Program Files, or \\Program Files (x86) directories.",
            UTC::UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED => "The registry value type for SetRegKey action must be REG_SZ, REG_MULTI_SZ, REG_EXPAND_SZ, REG_BINARY, REG_DWORD, or REG_QWORD.",
            UTC::UTC_E_TRACE_THROTTLED => "An operation which requires a running un-throttled trace failed due to the trace being throttled.",
        }
    }

    pub fn from_name(name: &str) -> UTC {
        return match name {
            "UTC_E_TOGGLE_TRACE_STARTED" => UTC::UTC_E_TOGGLE_TRACE_STARTED,
            "UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT" => UTC::UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT,
            "UTC_E_AOT_NOT_RUNNING" => UTC::UTC_E_AOT_NOT_RUNNING,
            "UTC_E_SCRIPT_TYPE_INVALID" => UTC::UTC_E_SCRIPT_TYPE_INVALID,
            "UTC_E_SCENARIODEF_NOT_FOUND" => UTC::UTC_E_SCENARIODEF_NOT_FOUND,
            "UTC_E_TRACEPROFILE_NOT_FOUND" => UTC::UTC_E_TRACEPROFILE_NOT_FOUND,
            "UTC_E_FORWARDER_ALREADY_ENABLED" => UTC::UTC_E_FORWARDER_ALREADY_ENABLED,
            "UTC_E_FORWARDER_ALREADY_DISABLED" => UTC::UTC_E_FORWARDER_ALREADY_DISABLED,
            "UTC_E_EVENTLOG_ENTRY_MALFORMED" => UTC::UTC_E_EVENTLOG_ENTRY_MALFORMED,
            "UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH" => UTC::UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH,
            "UTC_E_SCRIPT_TERMINATED" => UTC::UTC_E_SCRIPT_TERMINATED,
            "UTC_E_INVALID_CUSTOM_FILTER" => UTC::UTC_E_INVALID_CUSTOM_FILTER,
            "UTC_E_TRACE_NOT_RUNNING" => UTC::UTC_E_TRACE_NOT_RUNNING,
            "UTC_E_REESCALATED_TOO_QUICKLY" => UTC::UTC_E_REESCALATED_TOO_QUICKLY,
            "UTC_E_ESCALATION_ALREADY_RUNNING" => UTC::UTC_E_ESCALATION_ALREADY_RUNNING,
            "UTC_E_PERFTRACK_ALREADY_TRACING" => UTC::UTC_E_PERFTRACK_ALREADY_TRACING,
            "UTC_E_REACHED_MAX_ESCALATIONS" => UTC::UTC_E_REACHED_MAX_ESCALATIONS,
            "UTC_E_FORWARDER_PRODUCER_MISMATCH" => UTC::UTC_E_FORWARDER_PRODUCER_MISMATCH,
            "UTC_E_INTENTIONAL_SCRIPT_FAILURE" => UTC::UTC_E_INTENTIONAL_SCRIPT_FAILURE,
            "UTC_E_SQM_INIT_FAILED" => UTC::UTC_E_SQM_INIT_FAILED,
            "UTC_E_NO_WER_LOGGER_SUPPORTED" => UTC::UTC_E_NO_WER_LOGGER_SUPPORTED,
            "UTC_E_TRACERS_DONT_EXIST" => UTC::UTC_E_TRACERS_DONT_EXIST,
            "UTC_E_WINRT_INIT_FAILED" => UTC::UTC_E_WINRT_INIT_FAILED,
            "UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH" => UTC::UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH,
            "UTC_E_INVALID_FILTER" => UTC::UTC_E_INVALID_FILTER,
            "UTC_E_EXE_TERMINATED" => UTC::UTC_E_EXE_TERMINATED,
            "UTC_E_ESCALATION_NOT_AUTHORIZED" => UTC::UTC_E_ESCALATION_NOT_AUTHORIZED,
            "UTC_E_SETUP_NOT_AUTHORIZED" => UTC::UTC_E_SETUP_NOT_AUTHORIZED,
            "UTC_E_CHILD_PROCESS_FAILED" => UTC::UTC_E_CHILD_PROCESS_FAILED,
            "UTC_E_COMMAND_LINE_NOT_AUTHORIZED" => UTC::UTC_E_COMMAND_LINE_NOT_AUTHORIZED,
            "UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML" => UTC::UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML,
            "UTC_E_ESCALATION_TIMED_OUT" => UTC::UTC_E_ESCALATION_TIMED_OUT,
            "UTC_E_SETUP_TIMED_OUT" => UTC::UTC_E_SETUP_TIMED_OUT,
            "UTC_E_TRIGGER_MISMATCH" => UTC::UTC_E_TRIGGER_MISMATCH,
            "UTC_E_TRIGGER_NOT_FOUND" => UTC::UTC_E_TRIGGER_NOT_FOUND,
            "UTC_E_SIF_NOT_SUPPORTED" => UTC::UTC_E_SIF_NOT_SUPPORTED,
            "UTC_E_DELAY_TERMINATED" => UTC::UTC_E_DELAY_TERMINATED,
            "UTC_E_DEVICE_TICKET_ERROR" => UTC::UTC_E_DEVICE_TICKET_ERROR,
            "UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED" => UTC::UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED,
            "UTC_E_API_RESULT_UNAVAILABLE" => UTC::UTC_E_API_RESULT_UNAVAILABLE,
            "UTC_E_RPC_TIMEOUT" => UTC::UTC_E_RPC_TIMEOUT,
            "UTC_E_RPC_WAIT_FAILED" => UTC::UTC_E_RPC_WAIT_FAILED,
            "UTC_E_API_BUSY" => UTC::UTC_E_API_BUSY,
            "UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET" => UTC::UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET,
            "UTC_E_EXCLUSIVITY_NOT_AVAILABLE" => UTC::UTC_E_EXCLUSIVITY_NOT_AVAILABLE,
            "UTC_E_GETFILE_FILE_PATH_NOT_APPROVED" => UTC::UTC_E_GETFILE_FILE_PATH_NOT_APPROVED,
            "UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS" => UTC::UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS,
            "UTC_E_TIME_TRIGGER_ON_START_INVALID" => UTC::UTC_E_TIME_TRIGGER_ON_START_INVALID,
            "UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION" => UTC::UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION,
            "UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE" => UTC::UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE,
            "UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE" => UTC::UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE,
            "UTC_E_BINARY_MISSING" => UTC::UTC_E_BINARY_MISSING,
            "UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID" => UTC::UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID,
            "UTC_E_UNABLE_TO_RESOLVE_SESSION" => UTC::UTC_E_UNABLE_TO_RESOLVE_SESSION,
            "UTC_E_THROTTLED" => UTC::UTC_E_THROTTLED,
            "UTC_E_UNAPPROVED_SCRIPT" => UTC::UTC_E_UNAPPROVED_SCRIPT,
            "UTC_E_SCRIPT_MISSING" => UTC::UTC_E_SCRIPT_MISSING,
            "UTC_E_SCENARIO_THROTTLED" => UTC::UTC_E_SCENARIO_THROTTLED,
            "UTC_E_API_NOT_SUPPORTED" => UTC::UTC_E_API_NOT_SUPPORTED,
            "UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED" => UTC::UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED,
            "UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED" => UTC::UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED,
            "UTC_E_CERT_REV_FAILED" => UTC::UTC_E_CERT_REV_FAILED,
            "UTC_E_FAILED_TO_START_NDISCAP" => UTC::UTC_E_FAILED_TO_START_NDISCAP,
            "UTC_E_KERNELDUMP_LIMIT_REACHED" => UTC::UTC_E_KERNELDUMP_LIMIT_REACHED,
            "UTC_E_MISSING_AGGREGATE_EVENT_TAG" => UTC::UTC_E_MISSING_AGGREGATE_EVENT_TAG,
            "UTC_E_INVALID_AGGREGATION_STRUCT" => UTC::UTC_E_INVALID_AGGREGATION_STRUCT,
            "UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION" => UTC::UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION,
            "UTC_E_FILTER_MISSING_ATTRIBUTE" => UTC::UTC_E_FILTER_MISSING_ATTRIBUTE,
            "UTC_E_FILTER_INVALID_TYPE" => UTC::UTC_E_FILTER_INVALID_TYPE,
            "UTC_E_FILTER_VARIABLE_NOT_FOUND" => UTC::UTC_E_FILTER_VARIABLE_NOT_FOUND,
            "UTC_E_FILTER_FUNCTION_RESTRICTED" => UTC::UTC_E_FILTER_FUNCTION_RESTRICTED,
            "UTC_E_FILTER_VERSION_MISMATCH" => UTC::UTC_E_FILTER_VERSION_MISMATCH,
            "UTC_E_FILTER_INVALID_FUNCTION" => UTC::UTC_E_FILTER_INVALID_FUNCTION,
            "UTC_E_FILTER_INVALID_FUNCTION_PARAMS" => UTC::UTC_E_FILTER_INVALID_FUNCTION_PARAMS,
            "UTC_E_FILTER_INVALID_COMMAND" => UTC::UTC_E_FILTER_INVALID_COMMAND,
            "UTC_E_FILTER_ILLEGAL_EVAL" => UTC::UTC_E_FILTER_ILLEGAL_EVAL,
            "UTC_E_TTTRACER_RETURNED_ERROR" => UTC::UTC_E_TTTRACER_RETURNED_ERROR,
            "UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE" => UTC::UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE,
            "UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS" => UTC::UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS,
            "UTC_E_SCENARIO_HAS_NO_ACTIONS" => UTC::UTC_E_SCENARIO_HAS_NO_ACTIONS,
            "UTC_E_TTTRACER_STORAGE_FULL" => UTC::UTC_E_TTTRACER_STORAGE_FULL,
            "UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE" => UTC::UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE,
            "UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN" => UTC::UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN,
            "UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED" => UTC::UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED,
            "UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED" => UTC::UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED,
            "UTC_E_TRACE_THROTTLED" => UTC::UTC_E_TRACE_THROTTLED,
        }
    }
    pub fn from_code(code: u32) -> UTC {
        return match code {
            0x87C51001 => UTC::UTC_E_TOGGLE_TRACE_STARTED,
            0x87C51002 => UTC::UTC_E_ALTERNATIVE_TRACE_CANNOT_PREEMPT,
            0x87C51003 => UTC::UTC_E_AOT_NOT_RUNNING,
            0x87C51004 => UTC::UTC_E_SCRIPT_TYPE_INVALID,
            0x87C51005 => UTC::UTC_E_SCENARIODEF_NOT_FOUND,
            0x87C51006 => UTC::UTC_E_TRACEPROFILE_NOT_FOUND,
            0x87C51007 => UTC::UTC_E_FORWARDER_ALREADY_ENABLED,
            0x87C51008 => UTC::UTC_E_FORWARDER_ALREADY_DISABLED,
            0x87C51009 => UTC::UTC_E_EVENTLOG_ENTRY_MALFORMED,
            0x87C5100A => UTC::UTC_E_DIAGRULES_SCHEMAVERSION_MISMATCH,
            0x87C5100B => UTC::UTC_E_SCRIPT_TERMINATED,
            0x87C5100C => UTC::UTC_E_INVALID_CUSTOM_FILTER,
            0x87C5100D => UTC::UTC_E_TRACE_NOT_RUNNING,
            0x87C5100E => UTC::UTC_E_REESCALATED_TOO_QUICKLY,
            0x87C5100F => UTC::UTC_E_ESCALATION_ALREADY_RUNNING,
            0x87C51010 => UTC::UTC_E_PERFTRACK_ALREADY_TRACING,
            0x87C51011 => UTC::UTC_E_REACHED_MAX_ESCALATIONS,
            0x87C51012 => UTC::UTC_E_FORWARDER_PRODUCER_MISMATCH,
            0x87C51013 => UTC::UTC_E_INTENTIONAL_SCRIPT_FAILURE,
            0x87C51014 => UTC::UTC_E_SQM_INIT_FAILED,
            0x87C51015 => UTC::UTC_E_NO_WER_LOGGER_SUPPORTED,
            0x87C51016 => UTC::UTC_E_TRACERS_DONT_EXIST,
            0x87C51017 => UTC::UTC_E_WINRT_INIT_FAILED,
            0x87C51018 => UTC::UTC_E_SCENARIODEF_SCHEMAVERSION_MISMATCH,
            0x87C51019 => UTC::UTC_E_INVALID_FILTER,
            0x87C5101A => UTC::UTC_E_EXE_TERMINATED,
            0x87C5101B => UTC::UTC_E_ESCALATION_NOT_AUTHORIZED,
            0x87C5101C => UTC::UTC_E_SETUP_NOT_AUTHORIZED,
            0x87C5101D => UTC::UTC_E_CHILD_PROCESS_FAILED,
            0x87C5101E => UTC::UTC_E_COMMAND_LINE_NOT_AUTHORIZED,
            0x87C5101F => UTC::UTC_E_CANNOT_LOAD_SCENARIO_EDITOR_XML,
            0x87C51020 => UTC::UTC_E_ESCALATION_TIMED_OUT,
            0x87C51021 => UTC::UTC_E_SETUP_TIMED_OUT,
            0x87C51022 => UTC::UTC_E_TRIGGER_MISMATCH,
            0x87C51023 => UTC::UTC_E_TRIGGER_NOT_FOUND,
            0x87C51024 => UTC::UTC_E_SIF_NOT_SUPPORTED,
            0x87C51025 => UTC::UTC_E_DELAY_TERMINATED,
            0x87C51026 => UTC::UTC_E_DEVICE_TICKET_ERROR,
            0x87C51027 => UTC::UTC_E_TRACE_BUFFER_LIMIT_EXCEEDED,
            0x87C51028 => UTC::UTC_E_API_RESULT_UNAVAILABLE,
            0x87C51029 => UTC::UTC_E_RPC_TIMEOUT,
            0x87C5102A => UTC::UTC_E_RPC_WAIT_FAILED,
            0x87C5102B => UTC::UTC_E_API_BUSY,
            0x87C5102C => UTC::UTC_E_TRACE_MIN_DURATION_REQUIREMENT_NOT_MET,
            0x87C5102D => UTC::UTC_E_EXCLUSIVITY_NOT_AVAILABLE,
            0x87C5102E => UTC::UTC_E_GETFILE_FILE_PATH_NOT_APPROVED,
            0x87C5102F => UTC::UTC_E_ESCALATION_DIRECTORY_ALREADY_EXISTS,
            0x87C51030 => UTC::UTC_E_TIME_TRIGGER_ON_START_INVALID,
            0x87C51031 => UTC::UTC_E_TIME_TRIGGER_ONLY_VALID_ON_SINGLE_TRANSITION,
            0x87C51032 => UTC::UTC_E_TIME_TRIGGER_INVALID_TIME_RANGE,
            0x87C51033 => UTC::UTC_E_MULTIPLE_TIME_TRIGGER_ON_SINGLE_STATE,
            0x87C51034 => UTC::UTC_E_BINARY_MISSING,
            0x87C51036 => UTC::UTC_E_FAILED_TO_RESOLVE_CONTAINER_ID,
            0x87C51037 => UTC::UTC_E_UNABLE_TO_RESOLVE_SESSION,
            0x87C51038 => UTC::UTC_E_THROTTLED,
            0x87C51039 => UTC::UTC_E_UNAPPROVED_SCRIPT,
            0x87C5103A => UTC::UTC_E_SCRIPT_MISSING,
            0x87C5103B => UTC::UTC_E_SCENARIO_THROTTLED,
            0x87C5103C => UTC::UTC_E_API_NOT_SUPPORTED,
            0x87C5103D => UTC::UTC_E_GETFILE_EXTERNAL_PATH_NOT_APPROVED,
            0x87C5103E => UTC::UTC_E_TRY_GET_SCENARIO_TIMEOUT_EXCEEDED,
            0x87C5103F => UTC::UTC_E_CERT_REV_FAILED,
            0x87C51040 => UTC::UTC_E_FAILED_TO_START_NDISCAP,
            0x87C51041 => UTC::UTC_E_KERNELDUMP_LIMIT_REACHED,
            0x87C51042 => UTC::UTC_E_MISSING_AGGREGATE_EVENT_TAG,
            0x87C51043 => UTC::UTC_E_INVALID_AGGREGATION_STRUCT,
            0x87C51044 => UTC::UTC_E_ACTION_NOT_SUPPORTED_IN_DESTINATION,
            0x87C51045 => UTC::UTC_E_FILTER_MISSING_ATTRIBUTE,
            0x87C51046 => UTC::UTC_E_FILTER_INVALID_TYPE,
            0x87C51047 => UTC::UTC_E_FILTER_VARIABLE_NOT_FOUND,
            0x87C51048 => UTC::UTC_E_FILTER_FUNCTION_RESTRICTED,
            0x87C51049 => UTC::UTC_E_FILTER_VERSION_MISMATCH,
            0x87C51050 => UTC::UTC_E_FILTER_INVALID_FUNCTION,
            0x87C51051 => UTC::UTC_E_FILTER_INVALID_FUNCTION_PARAMS,
            0x87C51052 => UTC::UTC_E_FILTER_INVALID_COMMAND,
            0x87C51053 => UTC::UTC_E_FILTER_ILLEGAL_EVAL,
            0x87C51054 => UTC::UTC_E_TTTRACER_RETURNED_ERROR,
            0x87C51055 => UTC::UTC_E_AGENT_DIAGNOSTICS_TOO_LARGE,
            0x87C51056 => UTC::UTC_E_FAILED_TO_RECEIVE_AGENT_DIAGNOSTICS,
            0x87C51057 => UTC::UTC_E_SCENARIO_HAS_NO_ACTIONS,
            0x87C51058 => UTC::UTC_E_TTTRACER_STORAGE_FULL,
            0x87C51059 => UTC::UTC_E_INSUFFICIENT_SPACE_TO_START_TRACE,
            0x87C5105A => UTC::UTC_E_ESCALATION_CANCELLED_AT_SHUTDOWN,
            0x87C5105B => UTC::UTC_E_GETFILEINFOACTION_FILE_NOT_APPROVED,
            0x87C5105C => UTC::UTC_E_SETREGKEYACTION_TYPE_NOT_APPROVED,
            0x87C5105D => UTC::UTC_E_TRACE_THROTTLED,
        }
    }
}
