/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WDS_MC_SERVER {
    EVT_WDSMCS_S_PARAMETERS_READ,
    EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL,
    WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS,
    WDSMCS_E_REQCALLBACKS_NOT_REG,
    WDSMCS_E_INCOMPATIBLE_VERSION,
    WDSMCS_E_CONTENT_NOT_FOUND,
    WDSMCS_E_CLIENT_NOT_FOUND,
    WDSMCS_E_NAMESPACE_NOT_FOUND,
    WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND,
    WDSMCS_E_NAMESPACE_ALREADY_EXISTS,
    WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS,
    WDSMCS_E_NAMESPACE_ALREADY_STARTED,
    WDSMCS_E_NS_START_FAILED_NO_CLIENTS,
    WDSMCS_E_START_TIME_IN_PAST,
    WDSMCS_E_PACKET_NOT_HASHED,
    WDSMCS_E_PACKET_NOT_SIGNED,
    WDSMCS_E_PACKET_HAS_SECURITY,
    WDSMCS_E_PACKET_NOT_CHECKSUMED,
    WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE,
    EVT_WDSMCS_E_PARAMETERS_READ_FAILED,
    EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR,
    EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR,
    EVT_WDSMCS_E_CP_DLL_LOAD_FAILED,
    EVT_WDSMCS_E_CP_INIT_FUNC_MISSING,
    EVT_WDSMCS_E_CP_INIT_FUNC_FAILED,
    EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION,
    EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG,
    EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED,
    EVT_WDSMCS_E_CP_MEMORY_LEAK,
    EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED,
    EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED,
    EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED,
    EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL,
    EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST,
    EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG,
    EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS,
    EVT_WDSMCS_E_NSREG_FAILURE,
}

impl WDS_MC_SERVER {
    pub fn code(&self) -> u32 {
        return match self {
            WDS_MC_SERVER::EVT_WDSMCS_S_PARAMETERS_READ => 0x41210200 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL => 0x8121025A as u32,
            WDS_MC_SERVER::WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS => 0xC1210100 as u32,
            WDS_MC_SERVER::WDSMCS_E_REQCALLBACKS_NOT_REG => 0xC1210101 as u32,
            WDS_MC_SERVER::WDSMCS_E_INCOMPATIBLE_VERSION => 0xC1210102 as u32,
            WDS_MC_SERVER::WDSMCS_E_CONTENT_NOT_FOUND => 0xC1210103 as u32,
            WDS_MC_SERVER::WDSMCS_E_CLIENT_NOT_FOUND => 0xC1210104 as u32,
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_NOT_FOUND => 0xC1210105 as u32,
            WDS_MC_SERVER::WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND => 0xC1210106 as u32,
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_EXISTS => 0xC1210107 as u32,
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS => 0xC1210108 as u32,
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_STARTED => 0xC1210109 as u32,
            WDS_MC_SERVER::WDSMCS_E_NS_START_FAILED_NO_CLIENTS => 0xC121010A as u32,
            WDS_MC_SERVER::WDSMCS_E_START_TIME_IN_PAST => 0xC121010B as u32,
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_HASHED => 0xC121010C as u32,
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_SIGNED => 0xC121010D as u32,
            WDS_MC_SERVER::WDSMCS_E_PACKET_HAS_SECURITY => 0xC121010E as u32,
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_CHECKSUMED => 0xC121010F as u32,
            WDS_MC_SERVER::WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE => 0xC1210110 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_PARAMETERS_READ_FAILED => 0xC1210201 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR => 0xC1210202 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR => 0xC1210203 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED => 0xC1210250 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_MISSING => 0xC1210251 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_FAILED => 0xC1210252 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION => 0xC1210253 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG => 0xC1210254 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED => 0xC1210255 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_MEMORY_LEAK => 0xC1210256 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED => 0xC1210257 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED => 0xC1210258 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED => 0xC1210259 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL => 0xC121025B as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST => 0xC1210300 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG => 0xC1210301 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS => 0xC1210302 as u32,
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_FAILURE => 0xC1210303 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WDS_MC_SERVER::EVT_WDSMCS_S_PARAMETERS_READ => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_S_PARAMETERS_READ),
            WDS_MC_SERVER::EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL),
            WDS_MC_SERVER::WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS),
            WDS_MC_SERVER::WDSMCS_E_REQCALLBACKS_NOT_REG => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_REQCALLBACKS_NOT_REG),
            WDS_MC_SERVER::WDSMCS_E_INCOMPATIBLE_VERSION => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_INCOMPATIBLE_VERSION),
            WDS_MC_SERVER::WDSMCS_E_CONTENT_NOT_FOUND => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_CONTENT_NOT_FOUND),
            WDS_MC_SERVER::WDSMCS_E_CLIENT_NOT_FOUND => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_CLIENT_NOT_FOUND),
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_NOT_FOUND => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_NAMESPACE_NOT_FOUND),
            WDS_MC_SERVER::WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND),
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_EXISTS => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_EXISTS),
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS),
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_STARTED => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_STARTED),
            WDS_MC_SERVER::WDSMCS_E_NS_START_FAILED_NO_CLIENTS => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_NS_START_FAILED_NO_CLIENTS),
            WDS_MC_SERVER::WDSMCS_E_START_TIME_IN_PAST => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_START_TIME_IN_PAST),
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_HASHED => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_HASHED),
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_SIGNED => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_SIGNED),
            WDS_MC_SERVER::WDSMCS_E_PACKET_HAS_SECURITY => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_PACKET_HAS_SECURITY),
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_CHECKSUMED => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_CHECKSUMED),
            WDS_MC_SERVER::WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE => RawError::Kind(WDS_MC_SERVER::WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE),
            WDS_MC_SERVER::EVT_WDSMCS_E_PARAMETERS_READ_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_PARAMETERS_READ_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR),
            WDS_MC_SERVER::EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_MISSING => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_MISSING),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_MEMORY_LEAK => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_MEMORY_LEAK),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED),
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL),
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST),
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG),
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS),
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_FAILURE => RawError::Kind(WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_FAILURE),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WDS_MC_SERVER::EVT_WDSMCS_S_PARAMETERS_READ => "The Windows Deployment Multicast server successfully read its configuration settings. The Windows Deployment Multicast server will now process incoming client requests.",
            WDS_MC_SERVER::EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL => "The Content Provider %1 failed to initialize. The provider is marked as non-critical. WDS Multicast server will continue to start.%n %n Error Information: %2 %n.",
            WDS_MC_SERVER::WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS => "The request for content was rejected because shutdown is in progress for specified session.",
            WDS_MC_SERVER::WDSMCS_E_REQCALLBACKS_NOT_REG => "The Content Provider did not register required callbacks.",
            WDS_MC_SERVER::WDSMCS_E_INCOMPATIBLE_VERSION => "The supported version reported by Content Provider is incompatible.",
            WDS_MC_SERVER::WDSMCS_E_CONTENT_NOT_FOUND => "The specified content was not found.",
            WDS_MC_SERVER::WDSMCS_E_CLIENT_NOT_FOUND => "The specified client was not found.",
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_NOT_FOUND => "The specified namespace was not found.",
            WDS_MC_SERVER::WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND => "The specified content provider was not found.",
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_EXISTS => "The specified namespace already exists.",
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS => "Namespace is in pending close state.",
            WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_STARTED => "The namespace has already started.",
            WDS_MC_SERVER::WDSMCS_E_NS_START_FAILED_NO_CLIENTS => "The namespace cannot be started because there are no clients in the namespace.",
            WDS_MC_SERVER::WDSMCS_E_START_TIME_IN_PAST => "The specified start time is in the past.",
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_HASHED => "A packet was received without a hash.",
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_SIGNED => "A packet was received without a signature.",
            WDS_MC_SERVER::WDSMCS_E_PACKET_HAS_SECURITY => "A signed or hashed packet was received.",
            WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_CHECKSUMED => "A packet was received without checksum.",
            WDS_MC_SERVER::WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE => "The client does not support the required security mode.",
            WDS_MC_SERVER::EVT_WDSMCS_E_PARAMETERS_READ_FAILED => "An error occurred while trying to read the configuration information. The Windows Deployment Multicast server will not process incoming client requests. %n %n Error Information: %1 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR => "The multicast IP address %1 is being used by another Windows Deployment Services server, which has IP %2. Use the Windows Deployment Services management tools to configure your multicast IP address range to avoid this multicast IP address. If you allow this overlap to continue, your network usage will be increased.",
            WDS_MC_SERVER::EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR => "The multicast IP address %1 is being used by another multicast server, which has IP %2. Use the Windows Deployment Services management tools to configure your multicast IP address range to avoid this multicast IP address. If you allow this overlap to continue, your network usage will be increased.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED => "An error occurred while trying to load the module %1 for Content Provider %2. %n %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_MISSING => "The module %1 for Content Provider %2 does not export the initialization function %3. %n %n Error Information: %4 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_FAILED => "The Content Provider %1 loaded from %2 failed to initialize. %n %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION => "The Content Provider %1 is incompatible with this version of Windows Deployment Multicast Server. %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG => "The Content Provider %1 did not register required callbacks during its initialization. %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED => "The shutdown function for Content Provider %1 failed. %n %n Error Information: %2 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_MEMORY_LEAK => "The Content Provider %1 did not release %2 memory allocation(s) after its shutdown function has successfully returned.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED => "The Content Provider %1 returned an error while trying to open a new instance. %n %n Configuration: %2 %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED => "The Content Provider %1 returned an error while trying to close an instance. %n %n Error Information: %2 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED => "The Content Provider %1 returned an error while trying to open content %2. %n %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL => "The Content Provider %1 failed to initialize. The provider is marked as critical. WDS Multicast server will fail to start.%n %n Error Information: %2 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST => "The ScheduledCast namespace %1 using content provider %2 could not be registered as it starts in the past. The namespace has been removed from the namespace store. %n %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG => "The namespace %1 using content provider %2 could not be registered as the content provider is not registered. The namespace has been removed from the namespace store. %n %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS => "The namespace %1 using content provider %2 could not be registered as a namespace by that name already exists. The namespace has been removed from the namespace store. %n %n Error Information: %3 %n.",
            WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_FAILURE => "The namespace %1 using content provider %2 could not be registered due to an unknown error. %n %n Error Information: %3 %n.",
        }
    }

    pub fn from_name(name: &str) -> WDS_MC_SERVER {
        return match name {
            "EVT_WDSMCS_S_PARAMETERS_READ" => WDS_MC_SERVER::EVT_WDSMCS_S_PARAMETERS_READ,
            "EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL" => WDS_MC_SERVER::EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL,
            "WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS" => WDS_MC_SERVER::WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS,
            "WDSMCS_E_REQCALLBACKS_NOT_REG" => WDS_MC_SERVER::WDSMCS_E_REQCALLBACKS_NOT_REG,
            "WDSMCS_E_INCOMPATIBLE_VERSION" => WDS_MC_SERVER::WDSMCS_E_INCOMPATIBLE_VERSION,
            "WDSMCS_E_CONTENT_NOT_FOUND" => WDS_MC_SERVER::WDSMCS_E_CONTENT_NOT_FOUND,
            "WDSMCS_E_CLIENT_NOT_FOUND" => WDS_MC_SERVER::WDSMCS_E_CLIENT_NOT_FOUND,
            "WDSMCS_E_NAMESPACE_NOT_FOUND" => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_NOT_FOUND,
            "WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND" => WDS_MC_SERVER::WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND,
            "WDSMCS_E_NAMESPACE_ALREADY_EXISTS" => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_EXISTS,
            "WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS" => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS,
            "WDSMCS_E_NAMESPACE_ALREADY_STARTED" => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_STARTED,
            "WDSMCS_E_NS_START_FAILED_NO_CLIENTS" => WDS_MC_SERVER::WDSMCS_E_NS_START_FAILED_NO_CLIENTS,
            "WDSMCS_E_START_TIME_IN_PAST" => WDS_MC_SERVER::WDSMCS_E_START_TIME_IN_PAST,
            "WDSMCS_E_PACKET_NOT_HASHED" => WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_HASHED,
            "WDSMCS_E_PACKET_NOT_SIGNED" => WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_SIGNED,
            "WDSMCS_E_PACKET_HAS_SECURITY" => WDS_MC_SERVER::WDSMCS_E_PACKET_HAS_SECURITY,
            "WDSMCS_E_PACKET_NOT_CHECKSUMED" => WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_CHECKSUMED,
            "WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE" => WDS_MC_SERVER::WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE,
            "EVT_WDSMCS_E_PARAMETERS_READ_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_PARAMETERS_READ_FAILED,
            "EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR" => WDS_MC_SERVER::EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR,
            "EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR" => WDS_MC_SERVER::EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR,
            "EVT_WDSMCS_E_CP_DLL_LOAD_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED,
            "EVT_WDSMCS_E_CP_INIT_FUNC_MISSING" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_MISSING,
            "EVT_WDSMCS_E_CP_INIT_FUNC_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_FAILED,
            "EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION,
            "EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG,
            "EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED,
            "EVT_WDSMCS_E_CP_MEMORY_LEAK" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_MEMORY_LEAK,
            "EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED,
            "EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED,
            "EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED,
            "EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL" => WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL,
            "EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST" => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST,
            "EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG" => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG,
            "EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS" => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS,
            "EVT_WDSMCS_E_NSREG_FAILURE" => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_FAILURE,
        }
    }
    pub fn from_code(code: u32) -> WDS_MC_SERVER {
        return match code {
            0x41210200 => WDS_MC_SERVER::EVT_WDSMCS_S_PARAMETERS_READ,
            0x8121025A => WDS_MC_SERVER::EVT_WDSMCS_W_CP_DLL_LOAD_FAILED_NOT_CRITICAL,
            0xC1210100 => WDS_MC_SERVER::WDSMCS_E_SESSION_SHUTDOWN_IN_PROGRESS,
            0xC1210101 => WDS_MC_SERVER::WDSMCS_E_REQCALLBACKS_NOT_REG,
            0xC1210102 => WDS_MC_SERVER::WDSMCS_E_INCOMPATIBLE_VERSION,
            0xC1210103 => WDS_MC_SERVER::WDSMCS_E_CONTENT_NOT_FOUND,
            0xC1210104 => WDS_MC_SERVER::WDSMCS_E_CLIENT_NOT_FOUND,
            0xC1210105 => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_NOT_FOUND,
            0xC1210106 => WDS_MC_SERVER::WDSMCS_E_CONTENT_PROVIDER_NOT_FOUND,
            0xC1210107 => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_EXISTS,
            0xC1210108 => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_SHUTDOWN_IN_PROGRESS,
            0xC1210109 => WDS_MC_SERVER::WDSMCS_E_NAMESPACE_ALREADY_STARTED,
            0xC121010A => WDS_MC_SERVER::WDSMCS_E_NS_START_FAILED_NO_CLIENTS,
            0xC121010B => WDS_MC_SERVER::WDSMCS_E_START_TIME_IN_PAST,
            0xC121010C => WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_HASHED,
            0xC121010D => WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_SIGNED,
            0xC121010E => WDS_MC_SERVER::WDSMCS_E_PACKET_HAS_SECURITY,
            0xC121010F => WDS_MC_SERVER::WDSMCS_E_PACKET_NOT_CHECKSUMED,
            0xC1210110 => WDS_MC_SERVER::WDSMCS_E_CLIENT_DOESNOT_SUPPORT_SECURITY_MODE,
            0xC1210201 => WDS_MC_SERVER::EVT_WDSMCS_E_PARAMETERS_READ_FAILED,
            0xC1210202 => WDS_MC_SERVER::EVT_WDSMCS_E_DUPLICATE_MULTICAST_ADDR,
            0xC1210203 => WDS_MC_SERVER::EVT_WDSMCS_E_NON_WDS_DUPLICATE_MULTICAST_ADDR,
            0xC1210250 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED,
            0xC1210251 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_MISSING,
            0xC1210252 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_INIT_FUNC_FAILED,
            0xC1210253 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_INCOMPATIBLE_SERVER_VERSION,
            0xC1210254 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_CALLBACKS_NOT_REG,
            0xC1210255 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_SHUTDOWN_FUNC_FAILED,
            0xC1210256 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_MEMORY_LEAK,
            0xC1210257 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_INSTANCE_FAILED,
            0xC1210258 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_CLOSE_INSTANCE_FAILED,
            0xC1210259 => WDS_MC_SERVER::EVT_WDSMCS_E_CP_OPEN_CONTENT_FAILED,
            0xC121025B => WDS_MC_SERVER::EVT_WDSMCS_E_CP_DLL_LOAD_FAILED_CRITICAL,
            0xC1210300 => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_START_TIME_IN_PAST,
            0xC1210301 => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_CONTENT_PROVIDER_NOT_REG,
            0xC1210302 => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_NAMESPACE_EXISTS,
            0xC1210303 => WDS_MC_SERVER::EVT_WDSMCS_E_NSREG_FAILURE,
        }
    }
}
