/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WDS_TM {
    WDSTPTMGMT_E_INVALID_PROPERTY,
    WDSTPTMGMT_E_INVALID_OPERATION,
    WDSTPTMGMT_E_INVALID_CLASS,
    WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED,
    WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED,
    WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME,
    WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED,
    WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED,
    WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED,
    WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT,
    WDSTPTMGMT_E_INVALID_NAMESPACE_NAME,
    WDSTPTMGMT_E_INVALID_NAMESPACE_DATA,
    WDSTPTMGMT_E_NAMESPACE_READ_ONLY,
    WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME,
    WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS,
    WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT,
    WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE,
    WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE,
    WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS,
    WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE,
    WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER,
    WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER,
    WDSTPTMGMT_E_INVALID_IP_ADDRESS,
    WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS,
    WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS,
    WDSTPTMGMT_E_IPV6_NOT_SUPPORTED,
    WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE,
    WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT,
    WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD,
    WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED,
    WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE,
    WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED,
    WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED,
    WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED,
    WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED,
    WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE,
}

impl WDS_TM {
    pub fn code(&self) -> u32 {
        return match self {
            WDS_TM::WDSTPTMGMT_E_INVALID_PROPERTY => 0xC1100100 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_OPERATION => 0xC1100101 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_CLASS => 0xC1100102 as u32,
            WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED => 0xC1100103 as u32,
            WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED => 0xC1100104 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME => 0xC1100105 as u32,
            WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED => 0xC1100106 as u32,
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED => 0xC1100107 as u32,
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED => 0xC1100108 as u32,
            WDS_TM::WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT => 0xC1100109 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_NAME => 0xC110010A as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_DATA => 0xC110010B as u32,
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_READ_ONLY => 0xC110010C as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME => 0xC110010D as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS => 0xC110010E as u32,
            WDS_TM::WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT => 0xC110010F as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE => 0xC1100110 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE => 0xC1100111 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS => 0xC1100112 as u32,
            WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE => 0xC1100113 as u32,
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER => 0xC1100114 as u32,
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER => 0xC1100115 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_IP_ADDRESS => 0xC1100116 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS => 0xC1100117 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS => 0xC1100118 as u32,
            WDS_TM::WDSTPTMGMT_E_IPV6_NOT_SUPPORTED => 0xC1100119 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE => 0xC110011A as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT => 0xC110011B as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD => 0xC110011C as u32,
            WDS_TM::WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED => 0xC110011D as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE => 0xC110011E as u32,
            WDS_TM::WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED => 0xC110011F as u32,
            WDS_TM::WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED => 0xC1100120 as u32,
            WDS_TM::WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED => 0xC1100121 as u32,
            WDS_TM::WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED => 0xC1100122 as u32,
            WDS_TM::WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE => 0xC1100123 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WDS_TM::WDSTPTMGMT_E_INVALID_PROPERTY => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_PROPERTY),
            WDS_TM::WDSTPTMGMT_E_INVALID_OPERATION => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_OPERATION),
            WDS_TM::WDSTPTMGMT_E_INVALID_CLASS => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_CLASS),
            WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED),
            WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED),
            WDS_TM::WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME),
            WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED),
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED),
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED),
            WDS_TM::WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT => RawError::Kind(WDS_TM::WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT),
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_NAME => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_NAME),
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_DATA => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_DATA),
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_READ_ONLY => RawError::Kind(WDS_TM::WDSTPTMGMT_E_NAMESPACE_READ_ONLY),
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME),
            WDS_TM::WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS),
            WDS_TM::WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT => RawError::Kind(WDS_TM::WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT),
            WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE),
            WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE),
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS),
            WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE => RawError::Kind(WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE),
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER => RawError::Kind(WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER),
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER => RawError::Kind(WDS_TM::WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER),
            WDS_TM::WDSTPTMGMT_E_INVALID_IP_ADDRESS => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_IP_ADDRESS),
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS),
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS),
            WDS_TM::WDSTPTMGMT_E_IPV6_NOT_SUPPORTED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_IPV6_NOT_SUPPORTED),
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE),
            WDS_TM::WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT),
            WDS_TM::WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD),
            WDS_TM::WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED),
            WDS_TM::WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE),
            WDS_TM::WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED),
            WDS_TM::WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED),
            WDS_TM::WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED),
            WDS_TM::WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED => RawError::Kind(WDS_TM::WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED),
            WDS_TM::WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE => RawError::Kind(WDS_TM::WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WDS_TM::WDSTPTMGMT_E_INVALID_PROPERTY => "The property is invalid.",
            WDS_TM::WDSTPTMGMT_E_INVALID_OPERATION => "The operation is invalid.",
            WDS_TM::WDSTPTMGMT_E_INVALID_CLASS => "The interface pointer passed to the method has an invalid underlying class. Only library classes are supported.",
            WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED => "A content provider with the specified name is already registered on the server.",
            WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED => "The specified content provider is not registered on the server.",
            WDS_TM::WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME => "The specified content provider name is invalid. The name must be 1 to 255 characters long and cannot contain a backslash (\\) character.",
            WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED => "The Windows Deployment Services Transport Server role service has not been configured on the server.",
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED => "The specified namespace is already registered on the server.",
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED => "The specified namespace is not registered on the server.",
            WDS_TM::WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT => "The object has already been initialized and cannot be reinitialized.",
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_NAME => "The specified namespace name is invalid. The name must be 1 to 255 characters long and cannot contain a backslash (\\) character..",
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_DATA => "The namespace contains invalid or unknown data.",
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_READ_ONLY => "The namespace data cannot be modified because it is or has been previously registered on the server.",
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME => "The scheduled start time for the namespace is invalid.",
            WDS_TM::WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS => "The specified diagnostics components mask contains invalid or unknown components.",
            WDS_TM::WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT => "The object contains unsaved changes. The object data cannot be refreshed until you commit or discard the changes.",
            WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE => "The specified IP address range is invalid. The start and end IP addresses must be valid and the start IP address must be less than or equal to the end IP address.",
            WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE => "The specified service port range is invalid. The start port must be less than or equal to the end port, and both values must be between 1025 and 65536, inclusive.",
            WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS => "The start parameters for the namespace are invalid.",
            WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE => "The Windows Deployment Services Transport Server is unavailable.",
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER => "The specified namespace has never been registered on the server.",
            WDS_TM::WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER => "The specified namespace has been unregistered and removed from the server.",
            WDS_TM::WDSTPTMGMT_E_INVALID_IP_ADDRESS => "The specified IP address is invalid. The IP address must be a well formed value of the correct type.",
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS => "The specified IPv4 address is not valid for multicast. IPv4 multicast addresses must be in the range 224.0.1.0 to 239.255.255.255.",
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS => "The specified IPv6 address is not valid for multicast. IPv6 multicast addresses must start with FF (for example, FF15::FF).",
            WDS_TM::WDSTPTMGMT_E_IPV6_NOT_SUPPORTED => "The Windows Deployment Services Transport Server does not support IPv6.",
            WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE => "The specified IPv6 multicast address source is invalid. Transport Server only supports using IPv6 multicast addresses from a range.",
            WDS_TM::WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT => "The specified multistream stream count is invalid. The stream count must be set to either 2 or 3.",
            WDS_TM::WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD => "The specified AutoDisconnect threshold is invalid. The threshold must be set to a value between 1 KBps and 4194303 KBps, inclusive.",
            WDS_TM::WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED => "You cannot configure the multicast session policy on this Transport Server. This policy is only supported on Windows Server 2008 R2 and later.",
            WDS_TM::WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE => "The specified slow-client handling type is not valid.",
            WDS_TM::WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED => "This Windows Deployment Services Transport Server does not support network profiles.",
            WDS_TM::WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED => "The Windows Deployment Services Transport Server does not support UDP port policy.",
            WDS_TM::WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED => "The Windows Deployment Services Transport Server does not support the TFTP maximum block size setting.",
            WDS_TM::WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED => "The Windows Deployment Services Transport Server does not support the TFTP variable window extension.",
            WDS_TM::WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE => "The specified TFTP maximum block size is invalid. It must be either 0 or between 512 and 65531, inclusive.",
        }
    }

    pub fn from_name(name: &str) -> WDS_TM {
        return match name {
            "WDSTPTMGMT_E_INVALID_PROPERTY" => WDS_TM::WDSTPTMGMT_E_INVALID_PROPERTY,
            "WDSTPTMGMT_E_INVALID_OPERATION" => WDS_TM::WDSTPTMGMT_E_INVALID_OPERATION,
            "WDSTPTMGMT_E_INVALID_CLASS" => WDS_TM::WDSTPTMGMT_E_INVALID_CLASS,
            "WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED" => WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED,
            "WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED" => WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED,
            "WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME" => WDS_TM::WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME,
            "WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED" => WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED,
            "WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED" => WDS_TM::WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED,
            "WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED" => WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED,
            "WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT" => WDS_TM::WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT,
            "WDSTPTMGMT_E_INVALID_NAMESPACE_NAME" => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_NAME,
            "WDSTPTMGMT_E_INVALID_NAMESPACE_DATA" => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_DATA,
            "WDSTPTMGMT_E_NAMESPACE_READ_ONLY" => WDS_TM::WDSTPTMGMT_E_NAMESPACE_READ_ONLY,
            "WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME" => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME,
            "WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS" => WDS_TM::WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS,
            "WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT" => WDS_TM::WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT,
            "WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE" => WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE,
            "WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE" => WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE,
            "WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS" => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS,
            "WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE" => WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE,
            "WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER" => WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER,
            "WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER" => WDS_TM::WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER,
            "WDSTPTMGMT_E_INVALID_IP_ADDRESS" => WDS_TM::WDSTPTMGMT_E_INVALID_IP_ADDRESS,
            "WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS" => WDS_TM::WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS,
            "WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS" => WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS,
            "WDSTPTMGMT_E_IPV6_NOT_SUPPORTED" => WDS_TM::WDSTPTMGMT_E_IPV6_NOT_SUPPORTED,
            "WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE" => WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE,
            "WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT" => WDS_TM::WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT,
            "WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD" => WDS_TM::WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD,
            "WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED" => WDS_TM::WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED,
            "WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE" => WDS_TM::WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE,
            "WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED" => WDS_TM::WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED,
            "WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED" => WDS_TM::WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED,
            "WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED" => WDS_TM::WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED,
            "WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED" => WDS_TM::WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED,
            "WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE" => WDS_TM::WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE,
        }
    }
    pub fn from_code(code: u32) -> WDS_TM {
        return match code {
            0xC1100100 => WDS_TM::WDSTPTMGMT_E_INVALID_PROPERTY,
            0xC1100101 => WDS_TM::WDSTPTMGMT_E_INVALID_OPERATION,
            0xC1100102 => WDS_TM::WDSTPTMGMT_E_INVALID_CLASS,
            0xC1100103 => WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_ALREADY_REGISTERED,
            0xC1100104 => WDS_TM::WDSTPTMGMT_E_CONTENT_PROVIDER_NOT_REGISTERED,
            0xC1100105 => WDS_TM::WDSTPTMGMT_E_INVALID_CONTENT_PROVIDER_NAME,
            0xC1100106 => WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_ROLE_NOT_CONFIGURED,
            0xC1100107 => WDS_TM::WDSTPTMGMT_E_NAMESPACE_ALREADY_REGISTERED,
            0xC1100108 => WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_REGISTERED,
            0xC1100109 => WDS_TM::WDSTPTMGMT_E_CANNOT_REINITIALIZE_OBJECT,
            0xC110010A => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_NAME,
            0xC110010B => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_DATA,
            0xC110010C => WDS_TM::WDSTPTMGMT_E_NAMESPACE_READ_ONLY,
            0xC110010D => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_TIME,
            0xC110010E => WDS_TM::WDSTPTMGMT_E_INVALID_DIAGNOSTICS_COMPONENTS,
            0xC110010F => WDS_TM::WDSTPTMGMT_E_CANNOT_REFRESH_DIRTY_OBJECT,
            0xC1100110 => WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_IP_ADDRESS_RANGE,
            0xC1100111 => WDS_TM::WDSTPTMGMT_E_INVALID_SERVICE_PORT_RANGE,
            0xC1100112 => WDS_TM::WDSTPTMGMT_E_INVALID_NAMESPACE_START_PARAMETERS,
            0xC1100113 => WDS_TM::WDSTPTMGMT_E_TRANSPORT_SERVER_UNAVAILABLE,
            0xC1100114 => WDS_TM::WDSTPTMGMT_E_NAMESPACE_NOT_ON_SERVER,
            0xC1100115 => WDS_TM::WDSTPTMGMT_E_NAMESPACE_REMOVED_FROM_SERVER,
            0xC1100116 => WDS_TM::WDSTPTMGMT_E_INVALID_IP_ADDRESS,
            0xC1100117 => WDS_TM::WDSTPTMGMT_E_INVALID_IPV4_MULTICAST_ADDRESS,
            0xC1100118 => WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS,
            0xC1100119 => WDS_TM::WDSTPTMGMT_E_IPV6_NOT_SUPPORTED,
            0xC110011A => WDS_TM::WDSTPTMGMT_E_INVALID_IPV6_MULTICAST_ADDRESS_SOURCE,
            0xC110011B => WDS_TM::WDSTPTMGMT_E_INVALID_MULTISTREAM_STREAM_COUNT,
            0xC110011C => WDS_TM::WDSTPTMGMT_E_INVALID_AUTO_DISCONNECT_THRESHOLD,
            0xC110011D => WDS_TM::WDSTPTMGMT_E_MULTICAST_SESSION_POLICY_NOT_SUPPORTED,
            0xC110011E => WDS_TM::WDSTPTMGMT_E_INVALID_SLOW_CLIENT_HANDLING_TYPE,
            0xC110011F => WDS_TM::WDSTPTMGMT_E_NETWORK_PROFILES_NOT_SUPPORTED,
            0xC1100120 => WDS_TM::WDSTPTMGMT_E_UDP_PORT_POLICY_NOT_SUPPORTED,
            0xC1100121 => WDS_TM::WDSTPTMGMT_E_TFTP_MAX_BLOCKSIZE_NOT_SUPPORTED,
            0xC1100122 => WDS_TM::WDSTPTMGMT_E_TFTP_VAR_WINDOW_NOT_SUPPORTED,
            0xC1100123 => WDS_TM::WDSTPTMGMT_E_INVALID_TFTP_MAX_BLOCKSIZE,
        }
    }
}
