/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WINCODEC_DWRITE_DWM {
    MILERR_OBJECTBUSY,
    MILERR_INSUFFICIENTBUFFER,
    MILERR_WIN32ERROR,
    MILERR_SCANNER_FAILED,
    MILERR_SCREENACCESSDENIED,
    MILERR_DISPLAYSTATEINVALID,
    MILERR_NONINVERTIBLEMATRIX,
    MILERR_ZEROVECTOR,
    MILERR_TERMINATED,
    MILERR_BADNUMBER,
    MILERR_INTERNALERROR,
    MILERR_DISPLAYFORMATNOTSUPPORTED,
    MILERR_INVALIDCALL,
    MILERR_ALREADYLOCKED,
    MILERR_NOTLOCKED,
    MILERR_DEVICECANNOTRENDERTEXT,
    MILERR_GLYPHBITMAPMISSED,
    MILERR_MALFORMEDGLYPHCACHE,
    MILERR_GENERIC_IGNORE,
    MILERR_MALFORMED_GUIDELINE_DATA,
    MILERR_NO_HARDWARE_DEVICE,
    MILERR_NEED_RECREATE_AND_PRESENT,
    MILERR_ALREADY_INITIALIZED,
    MILERR_MISMATCHED_SIZE,
    MILERR_NO_REDIRECTION_SURFACE_AVAILABLE,
    MILERR_REMOTING_NOT_SUPPORTED,
    MILERR_QUEUED_PRESENT_NOT_SUPPORTED,
    MILERR_NOT_QUEUING_PRESENTS,
    MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER,
    MILERR_TOOMANYSHADERELEMNTS,
    MILERR_MROW_READLOCK_FAILED,
    MILERR_MROW_UPDATE_FAILED,
    MILERR_SHADER_COMPILE_FAILED,
    MILERR_MAX_TEXTURE_SIZE_EXCEEDED,
    MILERR_QPC_TIME_WENT_BACKWARD,
    MILERR_DXGI_ENUMERATION_OUT_OF_SYNC,
    MILERR_ADAPTER_NOT_FOUND,
    MILERR_COLORSPACE_NOT_SUPPORTED,
    MILERR_PREFILTER_NOT_SUPPORTED,
    MILERR_DISPLAYID_ACCESS_DENIED,
    UCEERR_INVALIDPACKETHEADER,
    UCEERR_UNKNOWNPACKET,
    UCEERR_ILLEGALPACKET,
    UCEERR_MALFORMEDPACKET,
    UCEERR_ILLEGALHANDLE,
    UCEERR_HANDLELOOKUPFAILED,
    UCEERR_RENDERTHREADFAILURE,
    UCEERR_CTXSTACKFRSTTARGETNULL,
    UCEERR_CONNECTIONIDLOOKUPFAILED,
    UCEERR_BLOCKSFULL,
    UCEERR_MEMORYFAILURE,
    UCEERR_PACKETRECORDOUTOFRANGE,
    UCEERR_ILLEGALRECORDTYPE,
    UCEERR_OUTOFHANDLES,
    UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED,
    UCEERR_NO_MULTIPLE_WORKER_THREADS,
    UCEERR_REMOTINGNOTSUPPORTED,
    UCEERR_MISSINGENDCOMMAND,
    UCEERR_MISSINGBEGINCOMMAND,
    UCEERR_CHANNELSYNCTIMEDOUT,
    UCEERR_CHANNELSYNCABANDONED,
    UCEERR_UNSUPPORTEDTRANSPORTVERSION,
    UCEERR_TRANSPORTUNAVAILABLE,
    UCEERR_FEEDBACK_UNSUPPORTED,
    UCEERR_COMMANDTRANSPORTDENIED,
    UCEERR_GRAPHICSSTREAMUNAVAILABLE,
    UCEERR_GRAPHICSSTREAMALREADYOPEN,
    UCEERR_TRANSPORTDISCONNECTED,
    UCEERR_TRANSPORTOVERLOADED,
    UCEERR_PARTITION_ZOMBIED,
    MILAVERR_NOCLOCK,
    MILAVERR_NOMEDIATYPE,
    MILAVERR_NOVIDEOMIXER,
    MILAVERR_NOVIDEOPRESENTER,
    MILAVERR_NOREADYFRAMES,
    MILAVERR_MODULENOTLOADED,
    MILAVERR_WMPFACTORYNOTREGISTERED,
    MILAVERR_INVALIDWMPVERSION,
    MILAVERR_INSUFFICIENTVIDEORESOURCES,
    MILAVERR_VIDEOACCELERATIONNOTAVAILABLE,
    MILAVERR_REQUESTEDTEXTURETOOBIG,
    MILAVERR_SEEKFAILED,
    MILAVERR_UNEXPECTEDWMPFAILURE,
    MILAVERR_MEDIAPLAYERCLOSED,
    MILAVERR_UNKNOWNHARDWAREERROR,
    MILEFFECTSERR_UNKNOWNPROPERTY,
    MILEFFECTSERR_EFFECTNOTPARTOFGROUP,
    MILEFFECTSERR_NOINPUTSOURCEATTACHED,
    MILEFFECTSERR_CONNECTORNOTCONNECTED,
    MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT,
    MILEFFECTSERR_RESERVED,
    MILEFFECTSERR_CYCLEDETECTED,
    MILEFFECTSERR_EFFECTINMORETHANONEGRAPH,
    MILEFFECTSERR_EFFECTALREADYINAGRAPH,
    MILEFFECTSERR_EFFECTHASNOCHILDREN,
    MILEFFECTSERR_ALREADYATTACHEDTOLISTENER,
    MILEFFECTSERR_NOTAFFINETRANSFORM,
    MILEFFECTSERR_EMPTYBOUNDS,
    MILEFFECTSERR_OUTPUTSIZETOOLARGE,
    DWMERR_STATE_TRANSITION_FAILED,
    DWMERR_THEME_FAILED,
    DWMERR_CATASTROPHIC_FAILURE,
    DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED,
    DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED,
    DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED,
    WINCODEC_ERR_WRONGSTATE,
    WINCODEC_ERR_VALUEOUTOFRANGE,
    WINCODEC_ERR_UNKNOWNIMAGEFORMAT,
    WINCODEC_ERR_UNSUPPORTEDVERSION,
    WINCODEC_ERR_NOTINITIALIZED,
    WINCODEC_ERR_ALREADYLOCKED,
    WINCODEC_ERR_PROPERTYNOTFOUND,
    WINCODEC_ERR_PROPERTYNOTSUPPORTED,
    WINCODEC_ERR_PROPERTYSIZE,
    WINCODEC_ERR_CODECPRESENT,
    WINCODEC_ERR_CODECNOTHUMBNAIL,
    WINCODEC_ERR_PALETTEUNAVAILABLE,
    WINCODEC_ERR_CODECTOOMANYSCANLINES,
    WINCODEC_ERR_INTERNALERROR,
    WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS,
    WINCODEC_ERR_COMPONENTNOTFOUND,
    WINCODEC_ERR_IMAGESIZEOUTOFRANGE,
    WINCODEC_ERR_TOOMUCHMETADATA,
    WINCODEC_ERR_BADIMAGE,
    WINCODEC_ERR_BADHEADER,
    WINCODEC_ERR_FRAMEMISSING,
    WINCODEC_ERR_BADMETADATAHEADER,
    WINCODEC_ERR_BADSTREAMDATA,
    WINCODEC_ERR_STREAMWRITE,
    WINCODEC_ERR_STREAMREAD,
    WINCODEC_ERR_STREAMNOTAVAILABLE,
    WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT,
    WINCODEC_ERR_UNSUPPORTEDOPERATION,
    WINCODEC_ERR_INVALIDREGISTRATION,
    WINCODEC_ERR_COMPONENTINITIALIZEFAILURE,
    WINCODEC_ERR_INSUFFICIENTBUFFER,
    WINCODEC_ERR_DUPLICATEMETADATAPRESENT,
    WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE,
    WINCODEC_ERR_UNEXPECTEDSIZE,
    WINCODEC_ERR_INVALIDQUERYREQUEST,
    WINCODEC_ERR_UNEXPECTEDMETADATATYPE,
    WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT,
    WINCODEC_ERR_INVALIDQUERYCHARACTER,
    WINCODEC_ERR_WIN32ERROR,
    WINCODEC_ERR_INVALIDPROGRESSIVELEVEL,
    WINCODEC_ERR_INVALIDJPEGSCANINDEX,
    DWRITE_E_FILEFORMAT,
    DWRITE_E_UNEXPECTED,
    DWRITE_E_NOFONT,
    DWRITE_E_FILENOTFOUND,
    DWRITE_E_FILEACCESS,
    DWRITE_E_FONTCOLLECTIONOBSOLETE,
    DWRITE_E_ALREADYREGISTERED,
    DWRITE_E_CACHEFORMAT,
    DWRITE_E_CACHEVERSION,
    DWRITE_E_UNSUPPORTEDOPERATION,
    DWRITE_E_TEXTRENDERERINCOMPATIBLE,
    DWRITE_E_FLOWDIRECTIONCONFLICTS,
    DWRITE_E_NOCOLOR,
    DWRITE_E_REMOTEFONT,
    DWRITE_E_DOWNLOADCANCELLED,
    DWRITE_E_DOWNLOADFAILED,
    DWRITE_E_TOOMANYDOWNLOADS,
}

impl WINCODEC_DWRITE_DWM {
    pub fn code(&self) -> u32 {
        return match self {
            WINCODEC_DWRITE_DWM::MILERR_OBJECTBUSY => 0x88980001 as u32,
            WINCODEC_DWRITE_DWM::MILERR_INSUFFICIENTBUFFER => 0x88980002 as u32,
            WINCODEC_DWRITE_DWM::MILERR_WIN32ERROR => 0x88980003 as u32,
            WINCODEC_DWRITE_DWM::MILERR_SCANNER_FAILED => 0x88980004 as u32,
            WINCODEC_DWRITE_DWM::MILERR_SCREENACCESSDENIED => 0x88980005 as u32,
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYSTATEINVALID => 0x88980006 as u32,
            WINCODEC_DWRITE_DWM::MILERR_NONINVERTIBLEMATRIX => 0x88980007 as u32,
            WINCODEC_DWRITE_DWM::MILERR_ZEROVECTOR => 0x88980008 as u32,
            WINCODEC_DWRITE_DWM::MILERR_TERMINATED => 0x88980009 as u32,
            WINCODEC_DWRITE_DWM::MILERR_BADNUMBER => 0x8898000A as u32,
            WINCODEC_DWRITE_DWM::MILERR_INTERNALERROR => 0x88980080 as u32,
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYFORMATNOTSUPPORTED => 0x88980084 as u32,
            WINCODEC_DWRITE_DWM::MILERR_INVALIDCALL => 0x88980085 as u32,
            WINCODEC_DWRITE_DWM::MILERR_ALREADYLOCKED => 0x88980086 as u32,
            WINCODEC_DWRITE_DWM::MILERR_NOTLOCKED => 0x88980087 as u32,
            WINCODEC_DWRITE_DWM::MILERR_DEVICECANNOTRENDERTEXT => 0x88980088 as u32,
            WINCODEC_DWRITE_DWM::MILERR_GLYPHBITMAPMISSED => 0x88980089 as u32,
            WINCODEC_DWRITE_DWM::MILERR_MALFORMEDGLYPHCACHE => 0x8898008A as u32,
            WINCODEC_DWRITE_DWM::MILERR_GENERIC_IGNORE => 0x8898008B as u32,
            WINCODEC_DWRITE_DWM::MILERR_MALFORMED_GUIDELINE_DATA => 0x8898008C as u32,
            WINCODEC_DWRITE_DWM::MILERR_NO_HARDWARE_DEVICE => 0x8898008D as u32,
            WINCODEC_DWRITE_DWM::MILERR_NEED_RECREATE_AND_PRESENT => 0x8898008E as u32,
            WINCODEC_DWRITE_DWM::MILERR_ALREADY_INITIALIZED => 0x8898008F as u32,
            WINCODEC_DWRITE_DWM::MILERR_MISMATCHED_SIZE => 0x88980090 as u32,
            WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_AVAILABLE => 0x88980091 as u32,
            WINCODEC_DWRITE_DWM::MILERR_REMOTING_NOT_SUPPORTED => 0x88980092 as u32,
            WINCODEC_DWRITE_DWM::MILERR_QUEUED_PRESENT_NOT_SUPPORTED => 0x88980093 as u32,
            WINCODEC_DWRITE_DWM::MILERR_NOT_QUEUING_PRESENTS => 0x88980094 as u32,
            WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER => 0x88980095 as u32,
            WINCODEC_DWRITE_DWM::MILERR_TOOMANYSHADERELEMNTS => 0x88980096 as u32,
            WINCODEC_DWRITE_DWM::MILERR_MROW_READLOCK_FAILED => 0x88980097 as u32,
            WINCODEC_DWRITE_DWM::MILERR_MROW_UPDATE_FAILED => 0x88980098 as u32,
            WINCODEC_DWRITE_DWM::MILERR_SHADER_COMPILE_FAILED => 0x88980099 as u32,
            WINCODEC_DWRITE_DWM::MILERR_MAX_TEXTURE_SIZE_EXCEEDED => 0x8898009A as u32,
            WINCODEC_DWRITE_DWM::MILERR_QPC_TIME_WENT_BACKWARD => 0x8898009B as u32,
            WINCODEC_DWRITE_DWM::MILERR_DXGI_ENUMERATION_OUT_OF_SYNC => 0x8898009D as u32,
            WINCODEC_DWRITE_DWM::MILERR_ADAPTER_NOT_FOUND => 0x8898009E as u32,
            WINCODEC_DWRITE_DWM::MILERR_COLORSPACE_NOT_SUPPORTED => 0x8898009F as u32,
            WINCODEC_DWRITE_DWM::MILERR_PREFILTER_NOT_SUPPORTED => 0x889800A0 as u32,
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYID_ACCESS_DENIED => 0x889800A1 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_INVALIDPACKETHEADER => 0x88980400 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_UNKNOWNPACKET => 0x88980401 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALPACKET => 0x88980402 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_MALFORMEDPACKET => 0x88980403 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALHANDLE => 0x88980404 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_HANDLELOOKUPFAILED => 0x88980405 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_RENDERTHREADFAILURE => 0x88980406 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_CTXSTACKFRSTTARGETNULL => 0x88980407 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_CONNECTIONIDLOOKUPFAILED => 0x88980408 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_BLOCKSFULL => 0x88980409 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_MEMORYFAILURE => 0x8898040A as u32,
            WINCODEC_DWRITE_DWM::UCEERR_PACKETRECORDOUTOFRANGE => 0x8898040B as u32,
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALRECORDTYPE => 0x8898040C as u32,
            WINCODEC_DWRITE_DWM::UCEERR_OUTOFHANDLES => 0x8898040D as u32,
            WINCODEC_DWRITE_DWM::UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED => 0x8898040E as u32,
            WINCODEC_DWRITE_DWM::UCEERR_NO_MULTIPLE_WORKER_THREADS => 0x8898040F as u32,
            WINCODEC_DWRITE_DWM::UCEERR_REMOTINGNOTSUPPORTED => 0x88980410 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_MISSINGENDCOMMAND => 0x88980411 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_MISSINGBEGINCOMMAND => 0x88980412 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCTIMEDOUT => 0x88980413 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCABANDONED => 0x88980414 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_UNSUPPORTEDTRANSPORTVERSION => 0x88980415 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTUNAVAILABLE => 0x88980416 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_FEEDBACK_UNSUPPORTED => 0x88980417 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_COMMANDTRANSPORTDENIED => 0x88980418 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMUNAVAILABLE => 0x88980419 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMALREADYOPEN => 0x88980420 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTDISCONNECTED => 0x88980421 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTOVERLOADED => 0x88980422 as u32,
            WINCODEC_DWRITE_DWM::UCEERR_PARTITION_ZOMBIED => 0x88980423 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_NOCLOCK => 0x88980500 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_NOMEDIATYPE => 0x88980501 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOMIXER => 0x88980502 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOPRESENTER => 0x88980503 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_NOREADYFRAMES => 0x88980504 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_MODULENOTLOADED => 0x88980505 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_WMPFACTORYNOTREGISTERED => 0x88980506 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_INVALIDWMPVERSION => 0x88980507 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_INSUFFICIENTVIDEORESOURCES => 0x88980508 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_VIDEOACCELERATIONNOTAVAILABLE => 0x88980509 as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_REQUESTEDTEXTURETOOBIG => 0x8898050A as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_SEEKFAILED => 0x8898050B as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_UNEXPECTEDWMPFAILURE => 0x8898050C as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_MEDIAPLAYERCLOSED => 0x8898050D as u32,
            WINCODEC_DWRITE_DWM::MILAVERR_UNKNOWNHARDWAREERROR => 0x8898050E as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_UNKNOWNPROPERTY => 0x8898060E as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTNOTPARTOFGROUP => 0x8898060F as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOINPUTSOURCEATTACHED => 0x88980610 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTCONNECTED => 0x88980611 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT => 0x88980612 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_RESERVED => 0x88980613 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CYCLEDETECTED => 0x88980614 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTINMORETHANONEGRAPH => 0x88980615 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTALREADYINAGRAPH => 0x88980616 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTHASNOCHILDREN => 0x88980617 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_ALREADYATTACHEDTOLISTENER => 0x88980618 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOTAFFINETRANSFORM => 0x88980619 as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EMPTYBOUNDS => 0x8898061A as u32,
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_OUTPUTSIZETOOLARGE => 0x8898061B as u32,
            WINCODEC_DWRITE_DWM::DWMERR_STATE_TRANSITION_FAILED => 0x88980700 as u32,
            WINCODEC_DWRITE_DWM::DWMERR_THEME_FAILED => 0x88980701 as u32,
            WINCODEC_DWRITE_DWM::DWMERR_CATASTROPHIC_FAILURE => 0x88980702 as u32,
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED => 0x88980800 as u32,
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED => 0x88980801 as u32,
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED => 0x88980802 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_WRONGSTATE => 0x88982F04 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_VALUEOUTOFRANGE => 0x88982F05 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNKNOWNIMAGEFORMAT => 0x88982F07 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDVERSION => 0x88982F0B as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_NOTINITIALIZED => 0x88982F0C as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_ALREADYLOCKED => 0x88982F0D as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTFOUND => 0x88982F40 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTSUPPORTED => 0x88982F41 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYSIZE => 0x88982F42 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECPRESENT => 0x88982F43 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECNOTHUMBNAIL => 0x88982F44 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PALETTEUNAVAILABLE => 0x88982F45 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECTOOMANYSCANLINES => 0x88982F46 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INTERNALERROR => 0x88982F48 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS => 0x88982F49 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTNOTFOUND => 0x88982F50 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_IMAGESIZEOUTOFRANGE => 0x88982F51 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_TOOMUCHMETADATA => 0x88982F52 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADIMAGE => 0x88982F60 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADHEADER => 0x88982F61 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_FRAMEMISSING => 0x88982F62 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADMETADATAHEADER => 0x88982F63 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADSTREAMDATA => 0x88982F70 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMWRITE => 0x88982F71 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMREAD => 0x88982F72 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMNOTAVAILABLE => 0x88982F73 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT => 0x88982F80 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDOPERATION => 0x88982F81 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDREGISTRATION => 0x88982F8A as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTINITIALIZEFAILURE => 0x88982F8B as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INSUFFICIENTBUFFER => 0x88982F8C as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_DUPLICATEMETADATAPRESENT => 0x88982F8D as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE => 0x88982F8E as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDSIZE => 0x88982F8F as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYREQUEST => 0x88982F90 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDMETADATATYPE => 0x88982F91 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT => 0x88982F92 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYCHARACTER => 0x88982F93 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_WIN32ERROR => 0x88982F94 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDPROGRESSIVELEVEL => 0x88982F95 as u32,
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDJPEGSCANINDEX => 0x88982F96 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_FILEFORMAT => 0x88985000 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_UNEXPECTED => 0x88985001 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_NOFONT => 0x88985002 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_FILENOTFOUND => 0x88985003 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_FILEACCESS => 0x88985004 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_FONTCOLLECTIONOBSOLETE => 0x88985005 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_ALREADYREGISTERED => 0x88985006 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_CACHEFORMAT => 0x88985007 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_CACHEVERSION => 0x88985008 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_UNSUPPORTEDOPERATION => 0x88985009 as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_TEXTRENDERERINCOMPATIBLE => 0x8898500A as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_FLOWDIRECTIONCONFLICTS => 0x8898500B as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_NOCOLOR => 0x8898500C as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_REMOTEFONT => 0x8898500D as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADCANCELLED => 0x8898500E as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADFAILED => 0x8898500F as u32,
            WINCODEC_DWRITE_DWM::DWRITE_E_TOOMANYDOWNLOADS => 0x88985010 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WINCODEC_DWRITE_DWM::MILERR_OBJECTBUSY => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_OBJECTBUSY),
            WINCODEC_DWRITE_DWM::MILERR_INSUFFICIENTBUFFER => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_INSUFFICIENTBUFFER),
            WINCODEC_DWRITE_DWM::MILERR_WIN32ERROR => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_WIN32ERROR),
            WINCODEC_DWRITE_DWM::MILERR_SCANNER_FAILED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_SCANNER_FAILED),
            WINCODEC_DWRITE_DWM::MILERR_SCREENACCESSDENIED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_SCREENACCESSDENIED),
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYSTATEINVALID => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_DISPLAYSTATEINVALID),
            WINCODEC_DWRITE_DWM::MILERR_NONINVERTIBLEMATRIX => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NONINVERTIBLEMATRIX),
            WINCODEC_DWRITE_DWM::MILERR_ZEROVECTOR => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_ZEROVECTOR),
            WINCODEC_DWRITE_DWM::MILERR_TERMINATED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_TERMINATED),
            WINCODEC_DWRITE_DWM::MILERR_BADNUMBER => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_BADNUMBER),
            WINCODEC_DWRITE_DWM::MILERR_INTERNALERROR => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_INTERNALERROR),
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYFORMATNOTSUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_DISPLAYFORMATNOTSUPPORTED),
            WINCODEC_DWRITE_DWM::MILERR_INVALIDCALL => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_INVALIDCALL),
            WINCODEC_DWRITE_DWM::MILERR_ALREADYLOCKED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_ALREADYLOCKED),
            WINCODEC_DWRITE_DWM::MILERR_NOTLOCKED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NOTLOCKED),
            WINCODEC_DWRITE_DWM::MILERR_DEVICECANNOTRENDERTEXT => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_DEVICECANNOTRENDERTEXT),
            WINCODEC_DWRITE_DWM::MILERR_GLYPHBITMAPMISSED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_GLYPHBITMAPMISSED),
            WINCODEC_DWRITE_DWM::MILERR_MALFORMEDGLYPHCACHE => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_MALFORMEDGLYPHCACHE),
            WINCODEC_DWRITE_DWM::MILERR_GENERIC_IGNORE => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_GENERIC_IGNORE),
            WINCODEC_DWRITE_DWM::MILERR_MALFORMED_GUIDELINE_DATA => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_MALFORMED_GUIDELINE_DATA),
            WINCODEC_DWRITE_DWM::MILERR_NO_HARDWARE_DEVICE => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NO_HARDWARE_DEVICE),
            WINCODEC_DWRITE_DWM::MILERR_NEED_RECREATE_AND_PRESENT => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NEED_RECREATE_AND_PRESENT),
            WINCODEC_DWRITE_DWM::MILERR_ALREADY_INITIALIZED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_ALREADY_INITIALIZED),
            WINCODEC_DWRITE_DWM::MILERR_MISMATCHED_SIZE => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_MISMATCHED_SIZE),
            WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_AVAILABLE => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_AVAILABLE),
            WINCODEC_DWRITE_DWM::MILERR_REMOTING_NOT_SUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_REMOTING_NOT_SUPPORTED),
            WINCODEC_DWRITE_DWM::MILERR_QUEUED_PRESENT_NOT_SUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_QUEUED_PRESENT_NOT_SUPPORTED),
            WINCODEC_DWRITE_DWM::MILERR_NOT_QUEUING_PRESENTS => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NOT_QUEUING_PRESENTS),
            WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER),
            WINCODEC_DWRITE_DWM::MILERR_TOOMANYSHADERELEMNTS => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_TOOMANYSHADERELEMNTS),
            WINCODEC_DWRITE_DWM::MILERR_MROW_READLOCK_FAILED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_MROW_READLOCK_FAILED),
            WINCODEC_DWRITE_DWM::MILERR_MROW_UPDATE_FAILED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_MROW_UPDATE_FAILED),
            WINCODEC_DWRITE_DWM::MILERR_SHADER_COMPILE_FAILED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_SHADER_COMPILE_FAILED),
            WINCODEC_DWRITE_DWM::MILERR_MAX_TEXTURE_SIZE_EXCEEDED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_MAX_TEXTURE_SIZE_EXCEEDED),
            WINCODEC_DWRITE_DWM::MILERR_QPC_TIME_WENT_BACKWARD => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_QPC_TIME_WENT_BACKWARD),
            WINCODEC_DWRITE_DWM::MILERR_DXGI_ENUMERATION_OUT_OF_SYNC => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_DXGI_ENUMERATION_OUT_OF_SYNC),
            WINCODEC_DWRITE_DWM::MILERR_ADAPTER_NOT_FOUND => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_ADAPTER_NOT_FOUND),
            WINCODEC_DWRITE_DWM::MILERR_COLORSPACE_NOT_SUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_COLORSPACE_NOT_SUPPORTED),
            WINCODEC_DWRITE_DWM::MILERR_PREFILTER_NOT_SUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_PREFILTER_NOT_SUPPORTED),
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYID_ACCESS_DENIED => RawError::Kind(WINCODEC_DWRITE_DWM::MILERR_DISPLAYID_ACCESS_DENIED),
            WINCODEC_DWRITE_DWM::UCEERR_INVALIDPACKETHEADER => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_INVALIDPACKETHEADER),
            WINCODEC_DWRITE_DWM::UCEERR_UNKNOWNPACKET => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_UNKNOWNPACKET),
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALPACKET => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_ILLEGALPACKET),
            WINCODEC_DWRITE_DWM::UCEERR_MALFORMEDPACKET => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_MALFORMEDPACKET),
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALHANDLE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_ILLEGALHANDLE),
            WINCODEC_DWRITE_DWM::UCEERR_HANDLELOOKUPFAILED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_HANDLELOOKUPFAILED),
            WINCODEC_DWRITE_DWM::UCEERR_RENDERTHREADFAILURE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_RENDERTHREADFAILURE),
            WINCODEC_DWRITE_DWM::UCEERR_CTXSTACKFRSTTARGETNULL => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_CTXSTACKFRSTTARGETNULL),
            WINCODEC_DWRITE_DWM::UCEERR_CONNECTIONIDLOOKUPFAILED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_CONNECTIONIDLOOKUPFAILED),
            WINCODEC_DWRITE_DWM::UCEERR_BLOCKSFULL => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_BLOCKSFULL),
            WINCODEC_DWRITE_DWM::UCEERR_MEMORYFAILURE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_MEMORYFAILURE),
            WINCODEC_DWRITE_DWM::UCEERR_PACKETRECORDOUTOFRANGE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_PACKETRECORDOUTOFRANGE),
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALRECORDTYPE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_ILLEGALRECORDTYPE),
            WINCODEC_DWRITE_DWM::UCEERR_OUTOFHANDLES => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_OUTOFHANDLES),
            WINCODEC_DWRITE_DWM::UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED),
            WINCODEC_DWRITE_DWM::UCEERR_NO_MULTIPLE_WORKER_THREADS => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_NO_MULTIPLE_WORKER_THREADS),
            WINCODEC_DWRITE_DWM::UCEERR_REMOTINGNOTSUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_REMOTINGNOTSUPPORTED),
            WINCODEC_DWRITE_DWM::UCEERR_MISSINGENDCOMMAND => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_MISSINGENDCOMMAND),
            WINCODEC_DWRITE_DWM::UCEERR_MISSINGBEGINCOMMAND => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_MISSINGBEGINCOMMAND),
            WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCTIMEDOUT => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCTIMEDOUT),
            WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCABANDONED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCABANDONED),
            WINCODEC_DWRITE_DWM::UCEERR_UNSUPPORTEDTRANSPORTVERSION => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_UNSUPPORTEDTRANSPORTVERSION),
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTUNAVAILABLE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTUNAVAILABLE),
            WINCODEC_DWRITE_DWM::UCEERR_FEEDBACK_UNSUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_FEEDBACK_UNSUPPORTED),
            WINCODEC_DWRITE_DWM::UCEERR_COMMANDTRANSPORTDENIED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_COMMANDTRANSPORTDENIED),
            WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMUNAVAILABLE => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMUNAVAILABLE),
            WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMALREADYOPEN => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMALREADYOPEN),
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTDISCONNECTED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTDISCONNECTED),
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTOVERLOADED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTOVERLOADED),
            WINCODEC_DWRITE_DWM::UCEERR_PARTITION_ZOMBIED => RawError::Kind(WINCODEC_DWRITE_DWM::UCEERR_PARTITION_ZOMBIED),
            WINCODEC_DWRITE_DWM::MILAVERR_NOCLOCK => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_NOCLOCK),
            WINCODEC_DWRITE_DWM::MILAVERR_NOMEDIATYPE => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_NOMEDIATYPE),
            WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOMIXER => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOMIXER),
            WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOPRESENTER => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOPRESENTER),
            WINCODEC_DWRITE_DWM::MILAVERR_NOREADYFRAMES => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_NOREADYFRAMES),
            WINCODEC_DWRITE_DWM::MILAVERR_MODULENOTLOADED => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_MODULENOTLOADED),
            WINCODEC_DWRITE_DWM::MILAVERR_WMPFACTORYNOTREGISTERED => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_WMPFACTORYNOTREGISTERED),
            WINCODEC_DWRITE_DWM::MILAVERR_INVALIDWMPVERSION => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_INVALIDWMPVERSION),
            WINCODEC_DWRITE_DWM::MILAVERR_INSUFFICIENTVIDEORESOURCES => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_INSUFFICIENTVIDEORESOURCES),
            WINCODEC_DWRITE_DWM::MILAVERR_VIDEOACCELERATIONNOTAVAILABLE => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_VIDEOACCELERATIONNOTAVAILABLE),
            WINCODEC_DWRITE_DWM::MILAVERR_REQUESTEDTEXTURETOOBIG => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_REQUESTEDTEXTURETOOBIG),
            WINCODEC_DWRITE_DWM::MILAVERR_SEEKFAILED => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_SEEKFAILED),
            WINCODEC_DWRITE_DWM::MILAVERR_UNEXPECTEDWMPFAILURE => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_UNEXPECTEDWMPFAILURE),
            WINCODEC_DWRITE_DWM::MILAVERR_MEDIAPLAYERCLOSED => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_MEDIAPLAYERCLOSED),
            WINCODEC_DWRITE_DWM::MILAVERR_UNKNOWNHARDWAREERROR => RawError::Kind(WINCODEC_DWRITE_DWM::MILAVERR_UNKNOWNHARDWAREERROR),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_UNKNOWNPROPERTY => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_UNKNOWNPROPERTY),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTNOTPARTOFGROUP => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTNOTPARTOFGROUP),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOINPUTSOURCEATTACHED => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOINPUTSOURCEATTACHED),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTCONNECTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTCONNECTED),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_RESERVED => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_RESERVED),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CYCLEDETECTED => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_CYCLEDETECTED),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTINMORETHANONEGRAPH => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTINMORETHANONEGRAPH),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTALREADYINAGRAPH => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTALREADYINAGRAPH),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTHASNOCHILDREN => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTHASNOCHILDREN),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_ALREADYATTACHEDTOLISTENER => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_ALREADYATTACHEDTOLISTENER),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOTAFFINETRANSFORM => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOTAFFINETRANSFORM),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EMPTYBOUNDS => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_EMPTYBOUNDS),
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_OUTPUTSIZETOOLARGE => RawError::Kind(WINCODEC_DWRITE_DWM::MILEFFECTSERR_OUTPUTSIZETOOLARGE),
            WINCODEC_DWRITE_DWM::DWMERR_STATE_TRANSITION_FAILED => RawError::Kind(WINCODEC_DWRITE_DWM::DWMERR_STATE_TRANSITION_FAILED),
            WINCODEC_DWRITE_DWM::DWMERR_THEME_FAILED => RawError::Kind(WINCODEC_DWRITE_DWM::DWMERR_THEME_FAILED),
            WINCODEC_DWRITE_DWM::DWMERR_CATASTROPHIC_FAILURE => RawError::Kind(WINCODEC_DWRITE_DWM::DWMERR_CATASTROPHIC_FAILURE),
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED => RawError::Kind(WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED),
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED => RawError::Kind(WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED),
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED => RawError::Kind(WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_WRONGSTATE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_WRONGSTATE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_VALUEOUTOFRANGE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_VALUEOUTOFRANGE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNKNOWNIMAGEFORMAT => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNKNOWNIMAGEFORMAT),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDVERSION => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDVERSION),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_NOTINITIALIZED => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_NOTINITIALIZED),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_ALREADYLOCKED => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_ALREADYLOCKED),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTFOUND => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTFOUND),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTSUPPORTED => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTSUPPORTED),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYSIZE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYSIZE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECPRESENT => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECPRESENT),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECNOTHUMBNAIL => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECNOTHUMBNAIL),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PALETTEUNAVAILABLE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_PALETTEUNAVAILABLE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECTOOMANYSCANLINES => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECTOOMANYSCANLINES),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INTERNALERROR => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INTERNALERROR),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTNOTFOUND => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTNOTFOUND),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_IMAGESIZEOUTOFRANGE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_IMAGESIZEOUTOFRANGE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_TOOMUCHMETADATA => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_TOOMUCHMETADATA),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADIMAGE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADIMAGE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADHEADER => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADHEADER),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_FRAMEMISSING => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_FRAMEMISSING),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADMETADATAHEADER => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADMETADATAHEADER),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADSTREAMDATA => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADSTREAMDATA),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMWRITE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMWRITE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMREAD => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMREAD),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMNOTAVAILABLE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMNOTAVAILABLE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDOPERATION => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDOPERATION),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDREGISTRATION => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDREGISTRATION),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTINITIALIZEFAILURE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTINITIALIZEFAILURE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INSUFFICIENTBUFFER => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INSUFFICIENTBUFFER),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_DUPLICATEMETADATAPRESENT => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_DUPLICATEMETADATAPRESENT),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDSIZE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDSIZE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYREQUEST => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYREQUEST),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDMETADATATYPE => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDMETADATATYPE),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYCHARACTER => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYCHARACTER),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_WIN32ERROR => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_WIN32ERROR),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDPROGRESSIVELEVEL => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDPROGRESSIVELEVEL),
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDJPEGSCANINDEX => RawError::Kind(WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDJPEGSCANINDEX),
            WINCODEC_DWRITE_DWM::DWRITE_E_FILEFORMAT => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_FILEFORMAT),
            WINCODEC_DWRITE_DWM::DWRITE_E_UNEXPECTED => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_UNEXPECTED),
            WINCODEC_DWRITE_DWM::DWRITE_E_NOFONT => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_NOFONT),
            WINCODEC_DWRITE_DWM::DWRITE_E_FILENOTFOUND => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_FILENOTFOUND),
            WINCODEC_DWRITE_DWM::DWRITE_E_FILEACCESS => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_FILEACCESS),
            WINCODEC_DWRITE_DWM::DWRITE_E_FONTCOLLECTIONOBSOLETE => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_FONTCOLLECTIONOBSOLETE),
            WINCODEC_DWRITE_DWM::DWRITE_E_ALREADYREGISTERED => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_ALREADYREGISTERED),
            WINCODEC_DWRITE_DWM::DWRITE_E_CACHEFORMAT => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_CACHEFORMAT),
            WINCODEC_DWRITE_DWM::DWRITE_E_CACHEVERSION => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_CACHEVERSION),
            WINCODEC_DWRITE_DWM::DWRITE_E_UNSUPPORTEDOPERATION => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_UNSUPPORTEDOPERATION),
            WINCODEC_DWRITE_DWM::DWRITE_E_TEXTRENDERERINCOMPATIBLE => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_TEXTRENDERERINCOMPATIBLE),
            WINCODEC_DWRITE_DWM::DWRITE_E_FLOWDIRECTIONCONFLICTS => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_FLOWDIRECTIONCONFLICTS),
            WINCODEC_DWRITE_DWM::DWRITE_E_NOCOLOR => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_NOCOLOR),
            WINCODEC_DWRITE_DWM::DWRITE_E_REMOTEFONT => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_REMOTEFONT),
            WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADCANCELLED => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADCANCELLED),
            WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADFAILED => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADFAILED),
            WINCODEC_DWRITE_DWM::DWRITE_E_TOOMANYDOWNLOADS => RawError::Kind(WINCODEC_DWRITE_DWM::DWRITE_E_TOOMANYDOWNLOADS),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WINCODEC_DWRITE_DWM::MILERR_OBJECTBUSY => "MILERR_OBJECTBUSY",
            WINCODEC_DWRITE_DWM::MILERR_INSUFFICIENTBUFFER => "MILERR_INSUFFICIENTBUFFER",
            WINCODEC_DWRITE_DWM::MILERR_WIN32ERROR => "MILERR_WIN32ERROR",
            WINCODEC_DWRITE_DWM::MILERR_SCANNER_FAILED => "MILERR_SCANNER_FAILED",
            WINCODEC_DWRITE_DWM::MILERR_SCREENACCESSDENIED => "MILERR_SCREENACCESSDENIED",
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYSTATEINVALID => "MILERR_DISPLAYSTATEINVALID",
            WINCODEC_DWRITE_DWM::MILERR_NONINVERTIBLEMATRIX => "MILERR_NONINVERTIBLEMATRIX",
            WINCODEC_DWRITE_DWM::MILERR_ZEROVECTOR => "MILERR_ZEROVECTOR",
            WINCODEC_DWRITE_DWM::MILERR_TERMINATED => "MILERR_TERMINATED",
            WINCODEC_DWRITE_DWM::MILERR_BADNUMBER => "MILERR_BADNUMBER",
            WINCODEC_DWRITE_DWM::MILERR_INTERNALERROR => "An internal error (MIL bug) occurred. On checked builds, an assert would be raised.",
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYFORMATNOTSUPPORTED => "The display format we need to render is not supported by the hardware device.",
            WINCODEC_DWRITE_DWM::MILERR_INVALIDCALL => "A call to this method is invalid.",
            WINCODEC_DWRITE_DWM::MILERR_ALREADYLOCKED => "Lock attempted on an already locked object.",
            WINCODEC_DWRITE_DWM::MILERR_NOTLOCKED => "Unlock attempted on an unlocked object.",
            WINCODEC_DWRITE_DWM::MILERR_DEVICECANNOTRENDERTEXT => "No algorithm available to render text with this device",
            WINCODEC_DWRITE_DWM::MILERR_GLYPHBITMAPMISSED => "Some glyph bitmaps, required for glyph run rendering, are not contained in glyph cache.",
            WINCODEC_DWRITE_DWM::MILERR_MALFORMEDGLYPHCACHE => "Some glyph bitmaps in glyph cache are unexpectedly big.",
            WINCODEC_DWRITE_DWM::MILERR_GENERIC_IGNORE => "Marker error for known Win32 errors that are currently being ignored by the compositor. This is to avoid returning S_OK when an error has occurred, but still unwind the stack in the correct location.",
            WINCODEC_DWRITE_DWM::MILERR_MALFORMED_GUIDELINE_DATA => "Guideline coordinates are not sorted properly or contain NaNs.",
            WINCODEC_DWRITE_DWM::MILERR_NO_HARDWARE_DEVICE => "No HW rendering device is available for this operation.",
            WINCODEC_DWRITE_DWM::MILERR_NEED_RECREATE_AND_PRESENT => "There has been a presentation error that may be recoverable. The caller needs to recreate, rerender the entire frame, and reattempt present.",
            WINCODEC_DWRITE_DWM::MILERR_ALREADY_INITIALIZED => "The object has already been initialized.",
            WINCODEC_DWRITE_DWM::MILERR_MISMATCHED_SIZE => "The size of the object does not match the expected size.",
            WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_AVAILABLE => "No Redirection surface available.",
            WINCODEC_DWRITE_DWM::MILERR_REMOTING_NOT_SUPPORTED => "Remoting of this content is not supported.",
            WINCODEC_DWRITE_DWM::MILERR_QUEUED_PRESENT_NOT_SUPPORTED => "Queued Presents are not supported.",
            WINCODEC_DWRITE_DWM::MILERR_NOT_QUEUING_PRESENTS => "Queued Presents are not being used.",
            WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER => "No redirection surface was available. Caller should retry the call.",
            WINCODEC_DWRITE_DWM::MILERR_TOOMANYSHADERELEMNTS => "Shader construction failed because it was too complex.",
            WINCODEC_DWRITE_DWM::MILERR_MROW_READLOCK_FAILED => "MROW attempt to get a read lock failed.",
            WINCODEC_DWRITE_DWM::MILERR_MROW_UPDATE_FAILED => "MROW attempt to update the data failed because another update was outstanding.",
            WINCODEC_DWRITE_DWM::MILERR_SHADER_COMPILE_FAILED => "Shader compilation failed.",
            WINCODEC_DWRITE_DWM::MILERR_MAX_TEXTURE_SIZE_EXCEEDED => "Requested DX redirection surface size exceeded maximum texture size.",
            WINCODEC_DWRITE_DWM::MILERR_QPC_TIME_WENT_BACKWARD => "QueryPerformanceCounter returned a time in the past.",
            WINCODEC_DWRITE_DWM::MILERR_DXGI_ENUMERATION_OUT_OF_SYNC => "Primary Display device returned an invalid refresh rate.",
            WINCODEC_DWRITE_DWM::MILERR_ADAPTER_NOT_FOUND => "DWM can not find the adapter specified by the LUID.",
            WINCODEC_DWRITE_DWM::MILERR_COLORSPACE_NOT_SUPPORTED => "The requested bitmap color space is not supported.",
            WINCODEC_DWRITE_DWM::MILERR_PREFILTER_NOT_SUPPORTED => "The requested bitmap pre-filtering state is not supported.",
            WINCODEC_DWRITE_DWM::MILERR_DISPLAYID_ACCESS_DENIED => "Access is denied to the requested bitmap for the specified display id.",
            WINCODEC_DWRITE_DWM::UCEERR_INVALIDPACKETHEADER => "UCEERR_INVALIDPACKETHEADER",
            WINCODEC_DWRITE_DWM::UCEERR_UNKNOWNPACKET => "UCEERR_UNKNOWNPACKET",
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALPACKET => "UCEERR_ILLEGALPACKET",
            WINCODEC_DWRITE_DWM::UCEERR_MALFORMEDPACKET => "UCEERR_MALFORMEDPACKET",
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALHANDLE => "UCEERR_ILLEGALHANDLE",
            WINCODEC_DWRITE_DWM::UCEERR_HANDLELOOKUPFAILED => "UCEERR_HANDLELOOKUPFAILED",
            WINCODEC_DWRITE_DWM::UCEERR_RENDERTHREADFAILURE => "UCEERR_RENDERTHREADFAILURE",
            WINCODEC_DWRITE_DWM::UCEERR_CTXSTACKFRSTTARGETNULL => "UCEERR_CTXSTACKFRSTTARGETNULL",
            WINCODEC_DWRITE_DWM::UCEERR_CONNECTIONIDLOOKUPFAILED => "UCEERR_CONNECTIONIDLOOKUPFAILED",
            WINCODEC_DWRITE_DWM::UCEERR_BLOCKSFULL => "UCEERR_BLOCKSFULL",
            WINCODEC_DWRITE_DWM::UCEERR_MEMORYFAILURE => "UCEERR_MEMORYFAILURE",
            WINCODEC_DWRITE_DWM::UCEERR_PACKETRECORDOUTOFRANGE => "UCEERR_PACKETRECORDOUTOFRANGE",
            WINCODEC_DWRITE_DWM::UCEERR_ILLEGALRECORDTYPE => "UCEERR_ILLEGALRECORDTYPE",
            WINCODEC_DWRITE_DWM::UCEERR_OUTOFHANDLES => "UCEERR_OUTOFHANDLES",
            WINCODEC_DWRITE_DWM::UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED => "UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED",
            WINCODEC_DWRITE_DWM::UCEERR_NO_MULTIPLE_WORKER_THREADS => "UCEERR_NO_MULTIPLE_WORKER_THREADS",
            WINCODEC_DWRITE_DWM::UCEERR_REMOTINGNOTSUPPORTED => "UCEERR_REMOTINGNOTSUPPORTED",
            WINCODEC_DWRITE_DWM::UCEERR_MISSINGENDCOMMAND => "UCEERR_MISSINGENDCOMMAND",
            WINCODEC_DWRITE_DWM::UCEERR_MISSINGBEGINCOMMAND => "UCEERR_MISSINGBEGINCOMMAND",
            WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCTIMEDOUT => "UCEERR_CHANNELSYNCTIMEDOUT",
            WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCABANDONED => "UCEERR_CHANNELSYNCABANDONED",
            WINCODEC_DWRITE_DWM::UCEERR_UNSUPPORTEDTRANSPORTVERSION => "UCEERR_UNSUPPORTEDTRANSPORTVERSION",
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTUNAVAILABLE => "UCEERR_TRANSPORTUNAVAILABLE",
            WINCODEC_DWRITE_DWM::UCEERR_FEEDBACK_UNSUPPORTED => "UCEERR_FEEDBACK_UNSUPPORTED",
            WINCODEC_DWRITE_DWM::UCEERR_COMMANDTRANSPORTDENIED => "UCEERR_COMMANDTRANSPORTDENIED",
            WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMUNAVAILABLE => "UCEERR_GRAPHICSSTREAMUNAVAILABLE",
            WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMALREADYOPEN => "UCEERR_GRAPHICSSTREAMALREADYOPEN",
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTDISCONNECTED => "UCEERR_TRANSPORTDISCONNECTED",
            WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTOVERLOADED => "UCEERR_TRANSPORTOVERLOADED",
            WINCODEC_DWRITE_DWM::UCEERR_PARTITION_ZOMBIED => "UCEERR_PARTITION_ZOMBIED",
            WINCODEC_DWRITE_DWM::MILAVERR_NOCLOCK => "MILAVERR_NOCLOCK",
            WINCODEC_DWRITE_DWM::MILAVERR_NOMEDIATYPE => "MILAVERR_NOMEDIATYPE",
            WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOMIXER => "MILAVERR_NOVIDEOMIXER",
            WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOPRESENTER => "MILAVERR_NOVIDEOPRESENTER",
            WINCODEC_DWRITE_DWM::MILAVERR_NOREADYFRAMES => "MILAVERR_NOREADYFRAMES",
            WINCODEC_DWRITE_DWM::MILAVERR_MODULENOTLOADED => "MILAVERR_MODULENOTLOADED",
            WINCODEC_DWRITE_DWM::MILAVERR_WMPFACTORYNOTREGISTERED => "MILAVERR_WMPFACTORYNOTREGISTERED",
            WINCODEC_DWRITE_DWM::MILAVERR_INVALIDWMPVERSION => "MILAVERR_INVALIDWMPVERSION",
            WINCODEC_DWRITE_DWM::MILAVERR_INSUFFICIENTVIDEORESOURCES => "MILAVERR_INSUFFICIENTVIDEORESOURCES",
            WINCODEC_DWRITE_DWM::MILAVERR_VIDEOACCELERATIONNOTAVAILABLE => "MILAVERR_VIDEOACCELERATIONNOTAVAILABLE",
            WINCODEC_DWRITE_DWM::MILAVERR_REQUESTEDTEXTURETOOBIG => "MILAVERR_REQUESTEDTEXTURETOOBIG",
            WINCODEC_DWRITE_DWM::MILAVERR_SEEKFAILED => "MILAVERR_SEEKFAILED",
            WINCODEC_DWRITE_DWM::MILAVERR_UNEXPECTEDWMPFAILURE => "MILAVERR_UNEXPECTEDWMPFAILURE",
            WINCODEC_DWRITE_DWM::MILAVERR_MEDIAPLAYERCLOSED => "MILAVERR_MEDIAPLAYERCLOSED",
            WINCODEC_DWRITE_DWM::MILAVERR_UNKNOWNHARDWAREERROR => "MILAVERR_UNKNOWNHARDWAREERROR",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_UNKNOWNPROPERTY => "MILEFFECTSERR_UNKNOWNPROPERTY",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTNOTPARTOFGROUP => "MILEFFECTSERR_EFFECTNOTPARTOFGROUP",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOINPUTSOURCEATTACHED => "MILEFFECTSERR_NOINPUTSOURCEATTACHED",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTCONNECTED => "MILEFFECTSERR_CONNECTORNOTCONNECTED",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT => "MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_RESERVED => "MILEFFECTSERR_RESERVED",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_CYCLEDETECTED => "MILEFFECTSERR_CYCLEDETECTED",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTINMORETHANONEGRAPH => "MILEFFECTSERR_EFFECTINMORETHANONEGRAPH",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTALREADYINAGRAPH => "MILEFFECTSERR_EFFECTALREADYINAGRAPH",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTHASNOCHILDREN => "MILEFFECTSERR_EFFECTHASNOCHILDREN",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_ALREADYATTACHEDTOLISTENER => "MILEFFECTSERR_ALREADYATTACHEDTOLISTENER",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOTAFFINETRANSFORM => "MILEFFECTSERR_NOTAFFINETRANSFORM",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_EMPTYBOUNDS => "MILEFFECTSERR_EMPTYBOUNDS",
            WINCODEC_DWRITE_DWM::MILEFFECTSERR_OUTPUTSIZETOOLARGE => "MILEFFECTSERR_OUTPUTSIZETOOLARGE",
            WINCODEC_DWRITE_DWM::DWMERR_STATE_TRANSITION_FAILED => "DWMERR_STATE_TRANSITION_FAILED",
            WINCODEC_DWRITE_DWM::DWMERR_THEME_FAILED => "DWMERR_THEME_FAILED",
            WINCODEC_DWRITE_DWM::DWMERR_CATASTROPHIC_FAILURE => "DWMERR_CATASTROPHIC_FAILURE",
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED => "DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED",
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED => "DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED",
            WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED => "DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_WRONGSTATE => "The codec is in the wrong state.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_VALUEOUTOFRANGE => "The value is out of range.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNKNOWNIMAGEFORMAT => "The image format is unknown.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDVERSION => "The SDK version is unsupported.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_NOTINITIALIZED => "The component is not initialized.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_ALREADYLOCKED => "There is already an outstanding read or write lock.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTFOUND => "The specified bitmap property cannot be found.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTSUPPORTED => "The bitmap codec does not support the bitmap property.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYSIZE => "The bitmap property size is invalid.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECPRESENT => "An unknown error has occurred.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECNOTHUMBNAIL => "The bitmap codec does not support a thumbnail.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PALETTEUNAVAILABLE => "The bitmap palette is unavailable.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECTOOMANYSCANLINES => "Too many scanlines were requested.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INTERNALERROR => "An internal error occurred.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS => "The bitmap bounds do not match the bitmap dimensions.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTNOTFOUND => "The component cannot be found.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_IMAGESIZEOUTOFRANGE => "The bitmap size is outside the valid range.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_TOOMUCHMETADATA => "There is too much metadata to be written to the bitmap.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADIMAGE => "The image is unrecognized.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADHEADER => "The image header is unrecognized.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_FRAMEMISSING => "The bitmap frame is missing.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADMETADATAHEADER => "The image metadata header is unrecognized.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADSTREAMDATA => "The stream data is unrecognized.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMWRITE => "Failed to write to the stream.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMREAD => "Failed to read from the stream.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMNOTAVAILABLE => "The stream is not available.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT => "The bitmap pixel format is unsupported.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDOPERATION => "The operation is unsupported.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDREGISTRATION => "The component registration is invalid.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTINITIALIZEFAILURE => "The component initialization has failed.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INSUFFICIENTBUFFER => "The buffer allocated is insufficient.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_DUPLICATEMETADATAPRESENT => "Duplicate metadata is present.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE => "The bitmap property type is unexpected.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDSIZE => "The size is unexpected.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYREQUEST => "The property query is invalid.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDMETADATATYPE => "The metadata type is unexpected.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT => "The specified bitmap property is only valid at root level.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYCHARACTER => "The query string contains an invalid character.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_WIN32ERROR => "Windows Codecs received an error from the Win32 system.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDPROGRESSIVELEVEL => "The requested level of detail is not present.",
            WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDJPEGSCANINDEX => "The scan index is invalid.",
            WINCODEC_DWRITE_DWM::DWRITE_E_FILEFORMAT => "Indicates an error in an input file such as a font file.",
            WINCODEC_DWRITE_DWM::DWRITE_E_UNEXPECTED => "Indicates an error originating in DirectWrite code, which is not expected to occur but is safe to recover from.",
            WINCODEC_DWRITE_DWM::DWRITE_E_NOFONT => "Indicates the specified font does not exist.",
            WINCODEC_DWRITE_DWM::DWRITE_E_FILENOTFOUND => "A font file could not be opened because the file, directory, network location, drive, or other storage location does not exist or is unavailable.",
            WINCODEC_DWRITE_DWM::DWRITE_E_FILEACCESS => "A font file exists but could not be opened due to access denied, sharing violation, or similar error.",
            WINCODEC_DWRITE_DWM::DWRITE_E_FONTCOLLECTIONOBSOLETE => "A font collection is obsolete due to changes in the system.",
            WINCODEC_DWRITE_DWM::DWRITE_E_ALREADYREGISTERED => "The given interface is already registered.",
            WINCODEC_DWRITE_DWM::DWRITE_E_CACHEFORMAT => "The font cache contains invalid data.",
            WINCODEC_DWRITE_DWM::DWRITE_E_CACHEVERSION => "A font cache file corresponds to a different version of DirectWrite.",
            WINCODEC_DWRITE_DWM::DWRITE_E_UNSUPPORTEDOPERATION => "The operation is not supported for this type of font.",
            WINCODEC_DWRITE_DWM::DWRITE_E_TEXTRENDERERINCOMPATIBLE => "The version of the text renderer interface is not compatible.",
            WINCODEC_DWRITE_DWM::DWRITE_E_FLOWDIRECTIONCONFLICTS => "The flow direction conflicts with the reading direction. They must be perpendicular to each other.",
            WINCODEC_DWRITE_DWM::DWRITE_E_NOCOLOR => "The font or glyph run does not contain any colored glyphs.",
            WINCODEC_DWRITE_DWM::DWRITE_E_REMOTEFONT => "A font resource could not be accessed because it is remote.",
            WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADCANCELLED => "A font download was canceled.",
            WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADFAILED => "A font download failed.",
            WINCODEC_DWRITE_DWM::DWRITE_E_TOOMANYDOWNLOADS => "A font download request was not added or a download failed because there are too many active downloads.",
        }
    }

    pub fn from_name(name: &str) -> WINCODEC_DWRITE_DWM {
        return match name {
            "MILERR_OBJECTBUSY" => WINCODEC_DWRITE_DWM::MILERR_OBJECTBUSY,
            "MILERR_INSUFFICIENTBUFFER" => WINCODEC_DWRITE_DWM::MILERR_INSUFFICIENTBUFFER,
            "MILERR_WIN32ERROR" => WINCODEC_DWRITE_DWM::MILERR_WIN32ERROR,
            "MILERR_SCANNER_FAILED" => WINCODEC_DWRITE_DWM::MILERR_SCANNER_FAILED,
            "MILERR_SCREENACCESSDENIED" => WINCODEC_DWRITE_DWM::MILERR_SCREENACCESSDENIED,
            "MILERR_DISPLAYSTATEINVALID" => WINCODEC_DWRITE_DWM::MILERR_DISPLAYSTATEINVALID,
            "MILERR_NONINVERTIBLEMATRIX" => WINCODEC_DWRITE_DWM::MILERR_NONINVERTIBLEMATRIX,
            "MILERR_ZEROVECTOR" => WINCODEC_DWRITE_DWM::MILERR_ZEROVECTOR,
            "MILERR_TERMINATED" => WINCODEC_DWRITE_DWM::MILERR_TERMINATED,
            "MILERR_BADNUMBER" => WINCODEC_DWRITE_DWM::MILERR_BADNUMBER,
            "MILERR_INTERNALERROR" => WINCODEC_DWRITE_DWM::MILERR_INTERNALERROR,
            "MILERR_DISPLAYFORMATNOTSUPPORTED" => WINCODEC_DWRITE_DWM::MILERR_DISPLAYFORMATNOTSUPPORTED,
            "MILERR_INVALIDCALL" => WINCODEC_DWRITE_DWM::MILERR_INVALIDCALL,
            "MILERR_ALREADYLOCKED" => WINCODEC_DWRITE_DWM::MILERR_ALREADYLOCKED,
            "MILERR_NOTLOCKED" => WINCODEC_DWRITE_DWM::MILERR_NOTLOCKED,
            "MILERR_DEVICECANNOTRENDERTEXT" => WINCODEC_DWRITE_DWM::MILERR_DEVICECANNOTRENDERTEXT,
            "MILERR_GLYPHBITMAPMISSED" => WINCODEC_DWRITE_DWM::MILERR_GLYPHBITMAPMISSED,
            "MILERR_MALFORMEDGLYPHCACHE" => WINCODEC_DWRITE_DWM::MILERR_MALFORMEDGLYPHCACHE,
            "MILERR_GENERIC_IGNORE" => WINCODEC_DWRITE_DWM::MILERR_GENERIC_IGNORE,
            "MILERR_MALFORMED_GUIDELINE_DATA" => WINCODEC_DWRITE_DWM::MILERR_MALFORMED_GUIDELINE_DATA,
            "MILERR_NO_HARDWARE_DEVICE" => WINCODEC_DWRITE_DWM::MILERR_NO_HARDWARE_DEVICE,
            "MILERR_NEED_RECREATE_AND_PRESENT" => WINCODEC_DWRITE_DWM::MILERR_NEED_RECREATE_AND_PRESENT,
            "MILERR_ALREADY_INITIALIZED" => WINCODEC_DWRITE_DWM::MILERR_ALREADY_INITIALIZED,
            "MILERR_MISMATCHED_SIZE" => WINCODEC_DWRITE_DWM::MILERR_MISMATCHED_SIZE,
            "MILERR_NO_REDIRECTION_SURFACE_AVAILABLE" => WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_AVAILABLE,
            "MILERR_REMOTING_NOT_SUPPORTED" => WINCODEC_DWRITE_DWM::MILERR_REMOTING_NOT_SUPPORTED,
            "MILERR_QUEUED_PRESENT_NOT_SUPPORTED" => WINCODEC_DWRITE_DWM::MILERR_QUEUED_PRESENT_NOT_SUPPORTED,
            "MILERR_NOT_QUEUING_PRESENTS" => WINCODEC_DWRITE_DWM::MILERR_NOT_QUEUING_PRESENTS,
            "MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER" => WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER,
            "MILERR_TOOMANYSHADERELEMNTS" => WINCODEC_DWRITE_DWM::MILERR_TOOMANYSHADERELEMNTS,
            "MILERR_MROW_READLOCK_FAILED" => WINCODEC_DWRITE_DWM::MILERR_MROW_READLOCK_FAILED,
            "MILERR_MROW_UPDATE_FAILED" => WINCODEC_DWRITE_DWM::MILERR_MROW_UPDATE_FAILED,
            "MILERR_SHADER_COMPILE_FAILED" => WINCODEC_DWRITE_DWM::MILERR_SHADER_COMPILE_FAILED,
            "MILERR_MAX_TEXTURE_SIZE_EXCEEDED" => WINCODEC_DWRITE_DWM::MILERR_MAX_TEXTURE_SIZE_EXCEEDED,
            "MILERR_QPC_TIME_WENT_BACKWARD" => WINCODEC_DWRITE_DWM::MILERR_QPC_TIME_WENT_BACKWARD,
            "MILERR_DXGI_ENUMERATION_OUT_OF_SYNC" => WINCODEC_DWRITE_DWM::MILERR_DXGI_ENUMERATION_OUT_OF_SYNC,
            "MILERR_ADAPTER_NOT_FOUND" => WINCODEC_DWRITE_DWM::MILERR_ADAPTER_NOT_FOUND,
            "MILERR_COLORSPACE_NOT_SUPPORTED" => WINCODEC_DWRITE_DWM::MILERR_COLORSPACE_NOT_SUPPORTED,
            "MILERR_PREFILTER_NOT_SUPPORTED" => WINCODEC_DWRITE_DWM::MILERR_PREFILTER_NOT_SUPPORTED,
            "MILERR_DISPLAYID_ACCESS_DENIED" => WINCODEC_DWRITE_DWM::MILERR_DISPLAYID_ACCESS_DENIED,
            "UCEERR_INVALIDPACKETHEADER" => WINCODEC_DWRITE_DWM::UCEERR_INVALIDPACKETHEADER,
            "UCEERR_UNKNOWNPACKET" => WINCODEC_DWRITE_DWM::UCEERR_UNKNOWNPACKET,
            "UCEERR_ILLEGALPACKET" => WINCODEC_DWRITE_DWM::UCEERR_ILLEGALPACKET,
            "UCEERR_MALFORMEDPACKET" => WINCODEC_DWRITE_DWM::UCEERR_MALFORMEDPACKET,
            "UCEERR_ILLEGALHANDLE" => WINCODEC_DWRITE_DWM::UCEERR_ILLEGALHANDLE,
            "UCEERR_HANDLELOOKUPFAILED" => WINCODEC_DWRITE_DWM::UCEERR_HANDLELOOKUPFAILED,
            "UCEERR_RENDERTHREADFAILURE" => WINCODEC_DWRITE_DWM::UCEERR_RENDERTHREADFAILURE,
            "UCEERR_CTXSTACKFRSTTARGETNULL" => WINCODEC_DWRITE_DWM::UCEERR_CTXSTACKFRSTTARGETNULL,
            "UCEERR_CONNECTIONIDLOOKUPFAILED" => WINCODEC_DWRITE_DWM::UCEERR_CONNECTIONIDLOOKUPFAILED,
            "UCEERR_BLOCKSFULL" => WINCODEC_DWRITE_DWM::UCEERR_BLOCKSFULL,
            "UCEERR_MEMORYFAILURE" => WINCODEC_DWRITE_DWM::UCEERR_MEMORYFAILURE,
            "UCEERR_PACKETRECORDOUTOFRANGE" => WINCODEC_DWRITE_DWM::UCEERR_PACKETRECORDOUTOFRANGE,
            "UCEERR_ILLEGALRECORDTYPE" => WINCODEC_DWRITE_DWM::UCEERR_ILLEGALRECORDTYPE,
            "UCEERR_OUTOFHANDLES" => WINCODEC_DWRITE_DWM::UCEERR_OUTOFHANDLES,
            "UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED" => WINCODEC_DWRITE_DWM::UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED,
            "UCEERR_NO_MULTIPLE_WORKER_THREADS" => WINCODEC_DWRITE_DWM::UCEERR_NO_MULTIPLE_WORKER_THREADS,
            "UCEERR_REMOTINGNOTSUPPORTED" => WINCODEC_DWRITE_DWM::UCEERR_REMOTINGNOTSUPPORTED,
            "UCEERR_MISSINGENDCOMMAND" => WINCODEC_DWRITE_DWM::UCEERR_MISSINGENDCOMMAND,
            "UCEERR_MISSINGBEGINCOMMAND" => WINCODEC_DWRITE_DWM::UCEERR_MISSINGBEGINCOMMAND,
            "UCEERR_CHANNELSYNCTIMEDOUT" => WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCTIMEDOUT,
            "UCEERR_CHANNELSYNCABANDONED" => WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCABANDONED,
            "UCEERR_UNSUPPORTEDTRANSPORTVERSION" => WINCODEC_DWRITE_DWM::UCEERR_UNSUPPORTEDTRANSPORTVERSION,
            "UCEERR_TRANSPORTUNAVAILABLE" => WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTUNAVAILABLE,
            "UCEERR_FEEDBACK_UNSUPPORTED" => WINCODEC_DWRITE_DWM::UCEERR_FEEDBACK_UNSUPPORTED,
            "UCEERR_COMMANDTRANSPORTDENIED" => WINCODEC_DWRITE_DWM::UCEERR_COMMANDTRANSPORTDENIED,
            "UCEERR_GRAPHICSSTREAMUNAVAILABLE" => WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMUNAVAILABLE,
            "UCEERR_GRAPHICSSTREAMALREADYOPEN" => WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMALREADYOPEN,
            "UCEERR_TRANSPORTDISCONNECTED" => WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTDISCONNECTED,
            "UCEERR_TRANSPORTOVERLOADED" => WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTOVERLOADED,
            "UCEERR_PARTITION_ZOMBIED" => WINCODEC_DWRITE_DWM::UCEERR_PARTITION_ZOMBIED,
            "MILAVERR_NOCLOCK" => WINCODEC_DWRITE_DWM::MILAVERR_NOCLOCK,
            "MILAVERR_NOMEDIATYPE" => WINCODEC_DWRITE_DWM::MILAVERR_NOMEDIATYPE,
            "MILAVERR_NOVIDEOMIXER" => WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOMIXER,
            "MILAVERR_NOVIDEOPRESENTER" => WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOPRESENTER,
            "MILAVERR_NOREADYFRAMES" => WINCODEC_DWRITE_DWM::MILAVERR_NOREADYFRAMES,
            "MILAVERR_MODULENOTLOADED" => WINCODEC_DWRITE_DWM::MILAVERR_MODULENOTLOADED,
            "MILAVERR_WMPFACTORYNOTREGISTERED" => WINCODEC_DWRITE_DWM::MILAVERR_WMPFACTORYNOTREGISTERED,
            "MILAVERR_INVALIDWMPVERSION" => WINCODEC_DWRITE_DWM::MILAVERR_INVALIDWMPVERSION,
            "MILAVERR_INSUFFICIENTVIDEORESOURCES" => WINCODEC_DWRITE_DWM::MILAVERR_INSUFFICIENTVIDEORESOURCES,
            "MILAVERR_VIDEOACCELERATIONNOTAVAILABLE" => WINCODEC_DWRITE_DWM::MILAVERR_VIDEOACCELERATIONNOTAVAILABLE,
            "MILAVERR_REQUESTEDTEXTURETOOBIG" => WINCODEC_DWRITE_DWM::MILAVERR_REQUESTEDTEXTURETOOBIG,
            "MILAVERR_SEEKFAILED" => WINCODEC_DWRITE_DWM::MILAVERR_SEEKFAILED,
            "MILAVERR_UNEXPECTEDWMPFAILURE" => WINCODEC_DWRITE_DWM::MILAVERR_UNEXPECTEDWMPFAILURE,
            "MILAVERR_MEDIAPLAYERCLOSED" => WINCODEC_DWRITE_DWM::MILAVERR_MEDIAPLAYERCLOSED,
            "MILAVERR_UNKNOWNHARDWAREERROR" => WINCODEC_DWRITE_DWM::MILAVERR_UNKNOWNHARDWAREERROR,
            "MILEFFECTSERR_UNKNOWNPROPERTY" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_UNKNOWNPROPERTY,
            "MILEFFECTSERR_EFFECTNOTPARTOFGROUP" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTNOTPARTOFGROUP,
            "MILEFFECTSERR_NOINPUTSOURCEATTACHED" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOINPUTSOURCEATTACHED,
            "MILEFFECTSERR_CONNECTORNOTCONNECTED" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTCONNECTED,
            "MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT,
            "MILEFFECTSERR_RESERVED" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_RESERVED,
            "MILEFFECTSERR_CYCLEDETECTED" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_CYCLEDETECTED,
            "MILEFFECTSERR_EFFECTINMORETHANONEGRAPH" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTINMORETHANONEGRAPH,
            "MILEFFECTSERR_EFFECTALREADYINAGRAPH" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTALREADYINAGRAPH,
            "MILEFFECTSERR_EFFECTHASNOCHILDREN" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTHASNOCHILDREN,
            "MILEFFECTSERR_ALREADYATTACHEDTOLISTENER" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_ALREADYATTACHEDTOLISTENER,
            "MILEFFECTSERR_NOTAFFINETRANSFORM" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOTAFFINETRANSFORM,
            "MILEFFECTSERR_EMPTYBOUNDS" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EMPTYBOUNDS,
            "MILEFFECTSERR_OUTPUTSIZETOOLARGE" => WINCODEC_DWRITE_DWM::MILEFFECTSERR_OUTPUTSIZETOOLARGE,
            "DWMERR_STATE_TRANSITION_FAILED" => WINCODEC_DWRITE_DWM::DWMERR_STATE_TRANSITION_FAILED,
            "DWMERR_THEME_FAILED" => WINCODEC_DWRITE_DWM::DWMERR_THEME_FAILED,
            "DWMERR_CATASTROPHIC_FAILURE" => WINCODEC_DWRITE_DWM::DWMERR_CATASTROPHIC_FAILURE,
            "DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED" => WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED,
            "DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED" => WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED,
            "DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED" => WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED,
            "WINCODEC_ERR_WRONGSTATE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_WRONGSTATE,
            "WINCODEC_ERR_VALUEOUTOFRANGE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_VALUEOUTOFRANGE,
            "WINCODEC_ERR_UNKNOWNIMAGEFORMAT" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNKNOWNIMAGEFORMAT,
            "WINCODEC_ERR_UNSUPPORTEDVERSION" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDVERSION,
            "WINCODEC_ERR_NOTINITIALIZED" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_NOTINITIALIZED,
            "WINCODEC_ERR_ALREADYLOCKED" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_ALREADYLOCKED,
            "WINCODEC_ERR_PROPERTYNOTFOUND" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTFOUND,
            "WINCODEC_ERR_PROPERTYNOTSUPPORTED" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTSUPPORTED,
            "WINCODEC_ERR_PROPERTYSIZE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYSIZE,
            "WINCODEC_ERR_CODECPRESENT" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECPRESENT,
            "WINCODEC_ERR_CODECNOTHUMBNAIL" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECNOTHUMBNAIL,
            "WINCODEC_ERR_PALETTEUNAVAILABLE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PALETTEUNAVAILABLE,
            "WINCODEC_ERR_CODECTOOMANYSCANLINES" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECTOOMANYSCANLINES,
            "WINCODEC_ERR_INTERNALERROR" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INTERNALERROR,
            "WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS,
            "WINCODEC_ERR_COMPONENTNOTFOUND" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTNOTFOUND,
            "WINCODEC_ERR_IMAGESIZEOUTOFRANGE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_IMAGESIZEOUTOFRANGE,
            "WINCODEC_ERR_TOOMUCHMETADATA" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_TOOMUCHMETADATA,
            "WINCODEC_ERR_BADIMAGE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADIMAGE,
            "WINCODEC_ERR_BADHEADER" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADHEADER,
            "WINCODEC_ERR_FRAMEMISSING" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_FRAMEMISSING,
            "WINCODEC_ERR_BADMETADATAHEADER" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADMETADATAHEADER,
            "WINCODEC_ERR_BADSTREAMDATA" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADSTREAMDATA,
            "WINCODEC_ERR_STREAMWRITE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMWRITE,
            "WINCODEC_ERR_STREAMREAD" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMREAD,
            "WINCODEC_ERR_STREAMNOTAVAILABLE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMNOTAVAILABLE,
            "WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT,
            "WINCODEC_ERR_UNSUPPORTEDOPERATION" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDOPERATION,
            "WINCODEC_ERR_INVALIDREGISTRATION" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDREGISTRATION,
            "WINCODEC_ERR_COMPONENTINITIALIZEFAILURE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTINITIALIZEFAILURE,
            "WINCODEC_ERR_INSUFFICIENTBUFFER" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INSUFFICIENTBUFFER,
            "WINCODEC_ERR_DUPLICATEMETADATAPRESENT" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_DUPLICATEMETADATAPRESENT,
            "WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE,
            "WINCODEC_ERR_UNEXPECTEDSIZE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDSIZE,
            "WINCODEC_ERR_INVALIDQUERYREQUEST" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYREQUEST,
            "WINCODEC_ERR_UNEXPECTEDMETADATATYPE" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDMETADATATYPE,
            "WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT,
            "WINCODEC_ERR_INVALIDQUERYCHARACTER" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYCHARACTER,
            "WINCODEC_ERR_WIN32ERROR" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_WIN32ERROR,
            "WINCODEC_ERR_INVALIDPROGRESSIVELEVEL" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDPROGRESSIVELEVEL,
            "WINCODEC_ERR_INVALIDJPEGSCANINDEX" => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDJPEGSCANINDEX,
            "DWRITE_E_FILEFORMAT" => WINCODEC_DWRITE_DWM::DWRITE_E_FILEFORMAT,
            "DWRITE_E_UNEXPECTED" => WINCODEC_DWRITE_DWM::DWRITE_E_UNEXPECTED,
            "DWRITE_E_NOFONT" => WINCODEC_DWRITE_DWM::DWRITE_E_NOFONT,
            "DWRITE_E_FILENOTFOUND" => WINCODEC_DWRITE_DWM::DWRITE_E_FILENOTFOUND,
            "DWRITE_E_FILEACCESS" => WINCODEC_DWRITE_DWM::DWRITE_E_FILEACCESS,
            "DWRITE_E_FONTCOLLECTIONOBSOLETE" => WINCODEC_DWRITE_DWM::DWRITE_E_FONTCOLLECTIONOBSOLETE,
            "DWRITE_E_ALREADYREGISTERED" => WINCODEC_DWRITE_DWM::DWRITE_E_ALREADYREGISTERED,
            "DWRITE_E_CACHEFORMAT" => WINCODEC_DWRITE_DWM::DWRITE_E_CACHEFORMAT,
            "DWRITE_E_CACHEVERSION" => WINCODEC_DWRITE_DWM::DWRITE_E_CACHEVERSION,
            "DWRITE_E_UNSUPPORTEDOPERATION" => WINCODEC_DWRITE_DWM::DWRITE_E_UNSUPPORTEDOPERATION,
            "DWRITE_E_TEXTRENDERERINCOMPATIBLE" => WINCODEC_DWRITE_DWM::DWRITE_E_TEXTRENDERERINCOMPATIBLE,
            "DWRITE_E_FLOWDIRECTIONCONFLICTS" => WINCODEC_DWRITE_DWM::DWRITE_E_FLOWDIRECTIONCONFLICTS,
            "DWRITE_E_NOCOLOR" => WINCODEC_DWRITE_DWM::DWRITE_E_NOCOLOR,
            "DWRITE_E_REMOTEFONT" => WINCODEC_DWRITE_DWM::DWRITE_E_REMOTEFONT,
            "DWRITE_E_DOWNLOADCANCELLED" => WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADCANCELLED,
            "DWRITE_E_DOWNLOADFAILED" => WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADFAILED,
            "DWRITE_E_TOOMANYDOWNLOADS" => WINCODEC_DWRITE_DWM::DWRITE_E_TOOMANYDOWNLOADS,
        }
    }
    pub fn from_code(code: u32) -> WINCODEC_DWRITE_DWM {
        return match code {
            0x88980001 => WINCODEC_DWRITE_DWM::MILERR_OBJECTBUSY,
            0x88980002 => WINCODEC_DWRITE_DWM::MILERR_INSUFFICIENTBUFFER,
            0x88980003 => WINCODEC_DWRITE_DWM::MILERR_WIN32ERROR,
            0x88980004 => WINCODEC_DWRITE_DWM::MILERR_SCANNER_FAILED,
            0x88980005 => WINCODEC_DWRITE_DWM::MILERR_SCREENACCESSDENIED,
            0x88980006 => WINCODEC_DWRITE_DWM::MILERR_DISPLAYSTATEINVALID,
            0x88980007 => WINCODEC_DWRITE_DWM::MILERR_NONINVERTIBLEMATRIX,
            0x88980008 => WINCODEC_DWRITE_DWM::MILERR_ZEROVECTOR,
            0x88980009 => WINCODEC_DWRITE_DWM::MILERR_TERMINATED,
            0x8898000A => WINCODEC_DWRITE_DWM::MILERR_BADNUMBER,
            0x88980080 => WINCODEC_DWRITE_DWM::MILERR_INTERNALERROR,
            0x88980084 => WINCODEC_DWRITE_DWM::MILERR_DISPLAYFORMATNOTSUPPORTED,
            0x88980085 => WINCODEC_DWRITE_DWM::MILERR_INVALIDCALL,
            0x88980086 => WINCODEC_DWRITE_DWM::MILERR_ALREADYLOCKED,
            0x88980087 => WINCODEC_DWRITE_DWM::MILERR_NOTLOCKED,
            0x88980088 => WINCODEC_DWRITE_DWM::MILERR_DEVICECANNOTRENDERTEXT,
            0x88980089 => WINCODEC_DWRITE_DWM::MILERR_GLYPHBITMAPMISSED,
            0x8898008A => WINCODEC_DWRITE_DWM::MILERR_MALFORMEDGLYPHCACHE,
            0x8898008B => WINCODEC_DWRITE_DWM::MILERR_GENERIC_IGNORE,
            0x8898008C => WINCODEC_DWRITE_DWM::MILERR_MALFORMED_GUIDELINE_DATA,
            0x8898008D => WINCODEC_DWRITE_DWM::MILERR_NO_HARDWARE_DEVICE,
            0x8898008E => WINCODEC_DWRITE_DWM::MILERR_NEED_RECREATE_AND_PRESENT,
            0x8898008F => WINCODEC_DWRITE_DWM::MILERR_ALREADY_INITIALIZED,
            0x88980090 => WINCODEC_DWRITE_DWM::MILERR_MISMATCHED_SIZE,
            0x88980091 => WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_AVAILABLE,
            0x88980092 => WINCODEC_DWRITE_DWM::MILERR_REMOTING_NOT_SUPPORTED,
            0x88980093 => WINCODEC_DWRITE_DWM::MILERR_QUEUED_PRESENT_NOT_SUPPORTED,
            0x88980094 => WINCODEC_DWRITE_DWM::MILERR_NOT_QUEUING_PRESENTS,
            0x88980095 => WINCODEC_DWRITE_DWM::MILERR_NO_REDIRECTION_SURFACE_RETRY_LATER,
            0x88980096 => WINCODEC_DWRITE_DWM::MILERR_TOOMANYSHADERELEMNTS,
            0x88980097 => WINCODEC_DWRITE_DWM::MILERR_MROW_READLOCK_FAILED,
            0x88980098 => WINCODEC_DWRITE_DWM::MILERR_MROW_UPDATE_FAILED,
            0x88980099 => WINCODEC_DWRITE_DWM::MILERR_SHADER_COMPILE_FAILED,
            0x8898009A => WINCODEC_DWRITE_DWM::MILERR_MAX_TEXTURE_SIZE_EXCEEDED,
            0x8898009B => WINCODEC_DWRITE_DWM::MILERR_QPC_TIME_WENT_BACKWARD,
            0x8898009D => WINCODEC_DWRITE_DWM::MILERR_DXGI_ENUMERATION_OUT_OF_SYNC,
            0x8898009E => WINCODEC_DWRITE_DWM::MILERR_ADAPTER_NOT_FOUND,
            0x8898009F => WINCODEC_DWRITE_DWM::MILERR_COLORSPACE_NOT_SUPPORTED,
            0x889800A0 => WINCODEC_DWRITE_DWM::MILERR_PREFILTER_NOT_SUPPORTED,
            0x889800A1 => WINCODEC_DWRITE_DWM::MILERR_DISPLAYID_ACCESS_DENIED,
            0x88980400 => WINCODEC_DWRITE_DWM::UCEERR_INVALIDPACKETHEADER,
            0x88980401 => WINCODEC_DWRITE_DWM::UCEERR_UNKNOWNPACKET,
            0x88980402 => WINCODEC_DWRITE_DWM::UCEERR_ILLEGALPACKET,
            0x88980403 => WINCODEC_DWRITE_DWM::UCEERR_MALFORMEDPACKET,
            0x88980404 => WINCODEC_DWRITE_DWM::UCEERR_ILLEGALHANDLE,
            0x88980405 => WINCODEC_DWRITE_DWM::UCEERR_HANDLELOOKUPFAILED,
            0x88980406 => WINCODEC_DWRITE_DWM::UCEERR_RENDERTHREADFAILURE,
            0x88980407 => WINCODEC_DWRITE_DWM::UCEERR_CTXSTACKFRSTTARGETNULL,
            0x88980408 => WINCODEC_DWRITE_DWM::UCEERR_CONNECTIONIDLOOKUPFAILED,
            0x88980409 => WINCODEC_DWRITE_DWM::UCEERR_BLOCKSFULL,
            0x8898040A => WINCODEC_DWRITE_DWM::UCEERR_MEMORYFAILURE,
            0x8898040B => WINCODEC_DWRITE_DWM::UCEERR_PACKETRECORDOUTOFRANGE,
            0x8898040C => WINCODEC_DWRITE_DWM::UCEERR_ILLEGALRECORDTYPE,
            0x8898040D => WINCODEC_DWRITE_DWM::UCEERR_OUTOFHANDLES,
            0x8898040E => WINCODEC_DWRITE_DWM::UCEERR_UNCHANGABLE_UPDATE_ATTEMPTED,
            0x8898040F => WINCODEC_DWRITE_DWM::UCEERR_NO_MULTIPLE_WORKER_THREADS,
            0x88980410 => WINCODEC_DWRITE_DWM::UCEERR_REMOTINGNOTSUPPORTED,
            0x88980411 => WINCODEC_DWRITE_DWM::UCEERR_MISSINGENDCOMMAND,
            0x88980412 => WINCODEC_DWRITE_DWM::UCEERR_MISSINGBEGINCOMMAND,
            0x88980413 => WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCTIMEDOUT,
            0x88980414 => WINCODEC_DWRITE_DWM::UCEERR_CHANNELSYNCABANDONED,
            0x88980415 => WINCODEC_DWRITE_DWM::UCEERR_UNSUPPORTEDTRANSPORTVERSION,
            0x88980416 => WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTUNAVAILABLE,
            0x88980417 => WINCODEC_DWRITE_DWM::UCEERR_FEEDBACK_UNSUPPORTED,
            0x88980418 => WINCODEC_DWRITE_DWM::UCEERR_COMMANDTRANSPORTDENIED,
            0x88980419 => WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMUNAVAILABLE,
            0x88980420 => WINCODEC_DWRITE_DWM::UCEERR_GRAPHICSSTREAMALREADYOPEN,
            0x88980421 => WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTDISCONNECTED,
            0x88980422 => WINCODEC_DWRITE_DWM::UCEERR_TRANSPORTOVERLOADED,
            0x88980423 => WINCODEC_DWRITE_DWM::UCEERR_PARTITION_ZOMBIED,
            0x88980500 => WINCODEC_DWRITE_DWM::MILAVERR_NOCLOCK,
            0x88980501 => WINCODEC_DWRITE_DWM::MILAVERR_NOMEDIATYPE,
            0x88980502 => WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOMIXER,
            0x88980503 => WINCODEC_DWRITE_DWM::MILAVERR_NOVIDEOPRESENTER,
            0x88980504 => WINCODEC_DWRITE_DWM::MILAVERR_NOREADYFRAMES,
            0x88980505 => WINCODEC_DWRITE_DWM::MILAVERR_MODULENOTLOADED,
            0x88980506 => WINCODEC_DWRITE_DWM::MILAVERR_WMPFACTORYNOTREGISTERED,
            0x88980507 => WINCODEC_DWRITE_DWM::MILAVERR_INVALIDWMPVERSION,
            0x88980508 => WINCODEC_DWRITE_DWM::MILAVERR_INSUFFICIENTVIDEORESOURCES,
            0x88980509 => WINCODEC_DWRITE_DWM::MILAVERR_VIDEOACCELERATIONNOTAVAILABLE,
            0x8898050A => WINCODEC_DWRITE_DWM::MILAVERR_REQUESTEDTEXTURETOOBIG,
            0x8898050B => WINCODEC_DWRITE_DWM::MILAVERR_SEEKFAILED,
            0x8898050C => WINCODEC_DWRITE_DWM::MILAVERR_UNEXPECTEDWMPFAILURE,
            0x8898050D => WINCODEC_DWRITE_DWM::MILAVERR_MEDIAPLAYERCLOSED,
            0x8898050E => WINCODEC_DWRITE_DWM::MILAVERR_UNKNOWNHARDWAREERROR,
            0x8898060E => WINCODEC_DWRITE_DWM::MILEFFECTSERR_UNKNOWNPROPERTY,
            0x8898060F => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTNOTPARTOFGROUP,
            0x88980610 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOINPUTSOURCEATTACHED,
            0x88980611 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTCONNECTED,
            0x88980612 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_CONNECTORNOTASSOCIATEDWITHEFFECT,
            0x88980613 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_RESERVED,
            0x88980614 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_CYCLEDETECTED,
            0x88980615 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTINMORETHANONEGRAPH,
            0x88980616 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTALREADYINAGRAPH,
            0x88980617 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EFFECTHASNOCHILDREN,
            0x88980618 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_ALREADYATTACHEDTOLISTENER,
            0x88980619 => WINCODEC_DWRITE_DWM::MILEFFECTSERR_NOTAFFINETRANSFORM,
            0x8898061A => WINCODEC_DWRITE_DWM::MILEFFECTSERR_EMPTYBOUNDS,
            0x8898061B => WINCODEC_DWRITE_DWM::MILEFFECTSERR_OUTPUTSIZETOOLARGE,
            0x88980700 => WINCODEC_DWRITE_DWM::DWMERR_STATE_TRANSITION_FAILED,
            0x88980701 => WINCODEC_DWRITE_DWM::DWMERR_THEME_FAILED,
            0x88980702 => WINCODEC_DWRITE_DWM::DWMERR_CATASTROPHIC_FAILURE,
            0x88980800 => WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_WINDOW_ALREADY_COMPOSED,
            0x88980801 => WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_BEING_RENDERED,
            0x88980802 => WINCODEC_DWRITE_DWM::DCOMPOSITION_ERROR_SURFACE_NOT_BEING_RENDERED,
            0x88982F04 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_WRONGSTATE,
            0x88982F05 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_VALUEOUTOFRANGE,
            0x88982F07 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNKNOWNIMAGEFORMAT,
            0x88982F0B => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDVERSION,
            0x88982F0C => WINCODEC_DWRITE_DWM::WINCODEC_ERR_NOTINITIALIZED,
            0x88982F0D => WINCODEC_DWRITE_DWM::WINCODEC_ERR_ALREADYLOCKED,
            0x88982F40 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTFOUND,
            0x88982F41 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYNOTSUPPORTED,
            0x88982F42 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYSIZE,
            0x88982F43 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECPRESENT,
            0x88982F44 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECNOTHUMBNAIL,
            0x88982F45 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PALETTEUNAVAILABLE,
            0x88982F46 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_CODECTOOMANYSCANLINES,
            0x88982F48 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INTERNALERROR,
            0x88982F49 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_SOURCERECTDOESNOTMATCHDIMENSIONS,
            0x88982F50 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTNOTFOUND,
            0x88982F51 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_IMAGESIZEOUTOFRANGE,
            0x88982F52 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_TOOMUCHMETADATA,
            0x88982F60 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADIMAGE,
            0x88982F61 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADHEADER,
            0x88982F62 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_FRAMEMISSING,
            0x88982F63 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADMETADATAHEADER,
            0x88982F70 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_BADSTREAMDATA,
            0x88982F71 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMWRITE,
            0x88982F72 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMREAD,
            0x88982F73 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_STREAMNOTAVAILABLE,
            0x88982F80 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDPIXELFORMAT,
            0x88982F81 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNSUPPORTEDOPERATION,
            0x88982F8A => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDREGISTRATION,
            0x88982F8B => WINCODEC_DWRITE_DWM::WINCODEC_ERR_COMPONENTINITIALIZEFAILURE,
            0x88982F8C => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INSUFFICIENTBUFFER,
            0x88982F8D => WINCODEC_DWRITE_DWM::WINCODEC_ERR_DUPLICATEMETADATAPRESENT,
            0x88982F8E => WINCODEC_DWRITE_DWM::WINCODEC_ERR_PROPERTYUNEXPECTEDTYPE,
            0x88982F8F => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDSIZE,
            0x88982F90 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYREQUEST,
            0x88982F91 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_UNEXPECTEDMETADATATYPE,
            0x88982F92 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_REQUESTONLYVALIDATMETADATAROOT,
            0x88982F93 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDQUERYCHARACTER,
            0x88982F94 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_WIN32ERROR,
            0x88982F95 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDPROGRESSIVELEVEL,
            0x88982F96 => WINCODEC_DWRITE_DWM::WINCODEC_ERR_INVALIDJPEGSCANINDEX,
            0x88985000 => WINCODEC_DWRITE_DWM::DWRITE_E_FILEFORMAT,
            0x88985001 => WINCODEC_DWRITE_DWM::DWRITE_E_UNEXPECTED,
            0x88985002 => WINCODEC_DWRITE_DWM::DWRITE_E_NOFONT,
            0x88985003 => WINCODEC_DWRITE_DWM::DWRITE_E_FILENOTFOUND,
            0x88985004 => WINCODEC_DWRITE_DWM::DWRITE_E_FILEACCESS,
            0x88985005 => WINCODEC_DWRITE_DWM::DWRITE_E_FONTCOLLECTIONOBSOLETE,
            0x88985006 => WINCODEC_DWRITE_DWM::DWRITE_E_ALREADYREGISTERED,
            0x88985007 => WINCODEC_DWRITE_DWM::DWRITE_E_CACHEFORMAT,
            0x88985008 => WINCODEC_DWRITE_DWM::DWRITE_E_CACHEVERSION,
            0x88985009 => WINCODEC_DWRITE_DWM::DWRITE_E_UNSUPPORTEDOPERATION,
            0x8898500A => WINCODEC_DWRITE_DWM::DWRITE_E_TEXTRENDERERINCOMPATIBLE,
            0x8898500B => WINCODEC_DWRITE_DWM::DWRITE_E_FLOWDIRECTIONCONFLICTS,
            0x8898500C => WINCODEC_DWRITE_DWM::DWRITE_E_NOCOLOR,
            0x8898500D => WINCODEC_DWRITE_DWM::DWRITE_E_REMOTEFONT,
            0x8898500E => WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADCANCELLED,
            0x8898500F => WINCODEC_DWRITE_DWM::DWRITE_E_DOWNLOADFAILED,
            0x88985010 => WINCODEC_DWRITE_DWM::DWRITE_E_TOOMANYDOWNLOADS,
        }
    }
}
