/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WINDOWS {
    CO_S_NOTALLINTERFACES,
    CO_S_MACHINENAMENOTFOUND,
    CO_E_CLASS_CREATE_FAILED,
    CO_E_SCM_ERROR,
    CO_E_SCM_RPC_FAILURE,
    CO_E_BAD_PATH,
    CO_E_SERVER_EXEC_FAILURE,
    CO_E_OBJSRV_RPC_FAILURE,
    MK_E_NO_NORMALIZED,
    CO_E_SERVER_STOPPING,
    MEM_E_INVALID_ROOT,
    MEM_E_INVALID_LINK,
    MEM_E_INVALID_SIZE,
    CO_E_MISSING_DISPLAYNAME,
    CO_E_RUNAS_VALUE_MUST_BE_AAA,
    CO_E_ELEVATION_DISABLED,
    APPX_E_PACKAGING_INTERNAL,
    APPX_E_INTERLEAVING_NOT_ALLOWED,
    APPX_E_RELATIONSHIPS_NOT_ALLOWED,
    APPX_E_MISSING_REQUIRED_FILE,
    APPX_E_INVALID_MANIFEST,
    APPX_E_INVALID_BLOCKMAP,
    APPX_E_CORRUPT_CONTENT,
    APPX_E_BLOCK_HASH_INVALID,
    APPX_E_REQUESTED_RANGE_TOO_LARGE,
    APPX_E_INVALID_SIP_CLIENT_DATA,
    APPX_E_INVALID_KEY_INFO,
    APPX_E_INVALID_CONTENTGROUPMAP,
    APPX_E_INVALID_APPINSTALLER,
    APPX_E_DELTA_BASELINE_VERSION_MISMATCH,
    APPX_E_DELTA_PACKAGE_MISSING_FILE,
    APPX_E_INVALID_DELTA_PACKAGE,
    APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED,
    APPX_E_INVALID_PACKAGING_LAYOUT,
    APPX_E_INVALID_PACKAGESIGNCONFIG,
    APPX_E_RESOURCESPRI_NOT_ALLOWED,
    APPX_E_FILE_COMPRESSION_MISMATCH,
    APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION,
    APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST,
    APPX_E_INVALID_PACKAGE_FOLDER_ACLS,
    APPX_E_INVALID_PUBLISHER_BRIDGING,
    APPX_E_DIGEST_MISMATCH,
    BT_E_SPURIOUS_ACTIVATION,
}

impl WINDOWS {
    pub fn code(&self) -> u32 {
        return match self {
            WINDOWS::CO_S_NOTALLINTERFACES => 0x00080012 as u32,
            WINDOWS::CO_S_MACHINENAMENOTFOUND => 0x00080013 as u32,
            WINDOWS::CO_E_CLASS_CREATE_FAILED => 0x80080001 as u32,
            WINDOWS::CO_E_SCM_ERROR => 0x80080002 as u32,
            WINDOWS::CO_E_SCM_RPC_FAILURE => 0x80080003 as u32,
            WINDOWS::CO_E_BAD_PATH => 0x80080004 as u32,
            WINDOWS::CO_E_SERVER_EXEC_FAILURE => 0x80080005 as u32,
            WINDOWS::CO_E_OBJSRV_RPC_FAILURE => 0x80080006 as u32,
            WINDOWS::MK_E_NO_NORMALIZED => 0x80080007 as u32,
            WINDOWS::CO_E_SERVER_STOPPING => 0x80080008 as u32,
            WINDOWS::MEM_E_INVALID_ROOT => 0x80080009 as u32,
            WINDOWS::MEM_E_INVALID_LINK => 0x80080010 as u32,
            WINDOWS::MEM_E_INVALID_SIZE => 0x80080011 as u32,
            WINDOWS::CO_E_MISSING_DISPLAYNAME => 0x80080015 as u32,
            WINDOWS::CO_E_RUNAS_VALUE_MUST_BE_AAA => 0x80080016 as u32,
            WINDOWS::CO_E_ELEVATION_DISABLED => 0x80080017 as u32,
            WINDOWS::APPX_E_PACKAGING_INTERNAL => 0x80080200 as u32,
            WINDOWS::APPX_E_INTERLEAVING_NOT_ALLOWED => 0x80080201 as u32,
            WINDOWS::APPX_E_RELATIONSHIPS_NOT_ALLOWED => 0x80080202 as u32,
            WINDOWS::APPX_E_MISSING_REQUIRED_FILE => 0x80080203 as u32,
            WINDOWS::APPX_E_INVALID_MANIFEST => 0x80080204 as u32,
            WINDOWS::APPX_E_INVALID_BLOCKMAP => 0x80080205 as u32,
            WINDOWS::APPX_E_CORRUPT_CONTENT => 0x80080206 as u32,
            WINDOWS::APPX_E_BLOCK_HASH_INVALID => 0x80080207 as u32,
            WINDOWS::APPX_E_REQUESTED_RANGE_TOO_LARGE => 0x80080208 as u32,
            WINDOWS::APPX_E_INVALID_SIP_CLIENT_DATA => 0x80080209 as u32,
            WINDOWS::APPX_E_INVALID_KEY_INFO => 0x8008020A as u32,
            WINDOWS::APPX_E_INVALID_CONTENTGROUPMAP => 0x8008020B as u32,
            WINDOWS::APPX_E_INVALID_APPINSTALLER => 0x8008020C as u32,
            WINDOWS::APPX_E_DELTA_BASELINE_VERSION_MISMATCH => 0x8008020D as u32,
            WINDOWS::APPX_E_DELTA_PACKAGE_MISSING_FILE => 0x8008020E as u32,
            WINDOWS::APPX_E_INVALID_DELTA_PACKAGE => 0x8008020F as u32,
            WINDOWS::APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED => 0x80080210 as u32,
            WINDOWS::APPX_E_INVALID_PACKAGING_LAYOUT => 0x80080211 as u32,
            WINDOWS::APPX_E_INVALID_PACKAGESIGNCONFIG => 0x80080212 as u32,
            WINDOWS::APPX_E_RESOURCESPRI_NOT_ALLOWED => 0x80080213 as u32,
            WINDOWS::APPX_E_FILE_COMPRESSION_MISMATCH => 0x80080214 as u32,
            WINDOWS::APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION => 0x80080215 as u32,
            WINDOWS::APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST => 0x80080216 as u32,
            WINDOWS::APPX_E_INVALID_PACKAGE_FOLDER_ACLS => 0x80080217 as u32,
            WINDOWS::APPX_E_INVALID_PUBLISHER_BRIDGING => 0x80080218 as u32,
            WINDOWS::APPX_E_DIGEST_MISMATCH => 0x80080219 as u32,
            WINDOWS::BT_E_SPURIOUS_ACTIVATION => 0x80080300 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WINDOWS::CO_S_NOTALLINTERFACES => RawError::Kind(WINDOWS::CO_S_NOTALLINTERFACES),
            WINDOWS::CO_S_MACHINENAMENOTFOUND => RawError::Kind(WINDOWS::CO_S_MACHINENAMENOTFOUND),
            WINDOWS::CO_E_CLASS_CREATE_FAILED => RawError::Kind(WINDOWS::CO_E_CLASS_CREATE_FAILED),
            WINDOWS::CO_E_SCM_ERROR => RawError::Kind(WINDOWS::CO_E_SCM_ERROR),
            WINDOWS::CO_E_SCM_RPC_FAILURE => RawError::Kind(WINDOWS::CO_E_SCM_RPC_FAILURE),
            WINDOWS::CO_E_BAD_PATH => RawError::Kind(WINDOWS::CO_E_BAD_PATH),
            WINDOWS::CO_E_SERVER_EXEC_FAILURE => RawError::Kind(WINDOWS::CO_E_SERVER_EXEC_FAILURE),
            WINDOWS::CO_E_OBJSRV_RPC_FAILURE => RawError::Kind(WINDOWS::CO_E_OBJSRV_RPC_FAILURE),
            WINDOWS::MK_E_NO_NORMALIZED => RawError::Kind(WINDOWS::MK_E_NO_NORMALIZED),
            WINDOWS::CO_E_SERVER_STOPPING => RawError::Kind(WINDOWS::CO_E_SERVER_STOPPING),
            WINDOWS::MEM_E_INVALID_ROOT => RawError::Kind(WINDOWS::MEM_E_INVALID_ROOT),
            WINDOWS::MEM_E_INVALID_LINK => RawError::Kind(WINDOWS::MEM_E_INVALID_LINK),
            WINDOWS::MEM_E_INVALID_SIZE => RawError::Kind(WINDOWS::MEM_E_INVALID_SIZE),
            WINDOWS::CO_E_MISSING_DISPLAYNAME => RawError::Kind(WINDOWS::CO_E_MISSING_DISPLAYNAME),
            WINDOWS::CO_E_RUNAS_VALUE_MUST_BE_AAA => RawError::Kind(WINDOWS::CO_E_RUNAS_VALUE_MUST_BE_AAA),
            WINDOWS::CO_E_ELEVATION_DISABLED => RawError::Kind(WINDOWS::CO_E_ELEVATION_DISABLED),
            WINDOWS::APPX_E_PACKAGING_INTERNAL => RawError::Kind(WINDOWS::APPX_E_PACKAGING_INTERNAL),
            WINDOWS::APPX_E_INTERLEAVING_NOT_ALLOWED => RawError::Kind(WINDOWS::APPX_E_INTERLEAVING_NOT_ALLOWED),
            WINDOWS::APPX_E_RELATIONSHIPS_NOT_ALLOWED => RawError::Kind(WINDOWS::APPX_E_RELATIONSHIPS_NOT_ALLOWED),
            WINDOWS::APPX_E_MISSING_REQUIRED_FILE => RawError::Kind(WINDOWS::APPX_E_MISSING_REQUIRED_FILE),
            WINDOWS::APPX_E_INVALID_MANIFEST => RawError::Kind(WINDOWS::APPX_E_INVALID_MANIFEST),
            WINDOWS::APPX_E_INVALID_BLOCKMAP => RawError::Kind(WINDOWS::APPX_E_INVALID_BLOCKMAP),
            WINDOWS::APPX_E_CORRUPT_CONTENT => RawError::Kind(WINDOWS::APPX_E_CORRUPT_CONTENT),
            WINDOWS::APPX_E_BLOCK_HASH_INVALID => RawError::Kind(WINDOWS::APPX_E_BLOCK_HASH_INVALID),
            WINDOWS::APPX_E_REQUESTED_RANGE_TOO_LARGE => RawError::Kind(WINDOWS::APPX_E_REQUESTED_RANGE_TOO_LARGE),
            WINDOWS::APPX_E_INVALID_SIP_CLIENT_DATA => RawError::Kind(WINDOWS::APPX_E_INVALID_SIP_CLIENT_DATA),
            WINDOWS::APPX_E_INVALID_KEY_INFO => RawError::Kind(WINDOWS::APPX_E_INVALID_KEY_INFO),
            WINDOWS::APPX_E_INVALID_CONTENTGROUPMAP => RawError::Kind(WINDOWS::APPX_E_INVALID_CONTENTGROUPMAP),
            WINDOWS::APPX_E_INVALID_APPINSTALLER => RawError::Kind(WINDOWS::APPX_E_INVALID_APPINSTALLER),
            WINDOWS::APPX_E_DELTA_BASELINE_VERSION_MISMATCH => RawError::Kind(WINDOWS::APPX_E_DELTA_BASELINE_VERSION_MISMATCH),
            WINDOWS::APPX_E_DELTA_PACKAGE_MISSING_FILE => RawError::Kind(WINDOWS::APPX_E_DELTA_PACKAGE_MISSING_FILE),
            WINDOWS::APPX_E_INVALID_DELTA_PACKAGE => RawError::Kind(WINDOWS::APPX_E_INVALID_DELTA_PACKAGE),
            WINDOWS::APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED => RawError::Kind(WINDOWS::APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED),
            WINDOWS::APPX_E_INVALID_PACKAGING_LAYOUT => RawError::Kind(WINDOWS::APPX_E_INVALID_PACKAGING_LAYOUT),
            WINDOWS::APPX_E_INVALID_PACKAGESIGNCONFIG => RawError::Kind(WINDOWS::APPX_E_INVALID_PACKAGESIGNCONFIG),
            WINDOWS::APPX_E_RESOURCESPRI_NOT_ALLOWED => RawError::Kind(WINDOWS::APPX_E_RESOURCESPRI_NOT_ALLOWED),
            WINDOWS::APPX_E_FILE_COMPRESSION_MISMATCH => RawError::Kind(WINDOWS::APPX_E_FILE_COMPRESSION_MISMATCH),
            WINDOWS::APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION => RawError::Kind(WINDOWS::APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION),
            WINDOWS::APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST => RawError::Kind(WINDOWS::APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST),
            WINDOWS::APPX_E_INVALID_PACKAGE_FOLDER_ACLS => RawError::Kind(WINDOWS::APPX_E_INVALID_PACKAGE_FOLDER_ACLS),
            WINDOWS::APPX_E_INVALID_PUBLISHER_BRIDGING => RawError::Kind(WINDOWS::APPX_E_INVALID_PUBLISHER_BRIDGING),
            WINDOWS::APPX_E_DIGEST_MISMATCH => RawError::Kind(WINDOWS::APPX_E_DIGEST_MISMATCH),
            WINDOWS::BT_E_SPURIOUS_ACTIVATION => RawError::Kind(WINDOWS::BT_E_SPURIOUS_ACTIVATION),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WINDOWS::CO_S_NOTALLINTERFACES => "Not all the requested interfaces were available",
            WINDOWS::CO_S_MACHINENAMENOTFOUND => "The specified machine name was not found in the cache.",
            WINDOWS::CO_E_CLASS_CREATE_FAILED => "Attempt to create a class object failed",
            WINDOWS::CO_E_SCM_ERROR => "OLE service could not bind object",
            WINDOWS::CO_E_SCM_RPC_FAILURE => "RPC communication failed with OLE service",
            WINDOWS::CO_E_BAD_PATH => "Bad path to object",
            WINDOWS::CO_E_SERVER_EXEC_FAILURE => "Server execution failed",
            WINDOWS::CO_E_OBJSRV_RPC_FAILURE => "OLE service could not communicate with the object server",
            WINDOWS::MK_E_NO_NORMALIZED => "Moniker path could not be normalized",
            WINDOWS::CO_E_SERVER_STOPPING => "Object server is stopping when OLE service contacts it",
            WINDOWS::MEM_E_INVALID_ROOT => "An invalid root block pointer was specified",
            WINDOWS::MEM_E_INVALID_LINK => "An allocation chain contained an invalid link pointer",
            WINDOWS::MEM_E_INVALID_SIZE => "The requested allocation size was too large",
            WINDOWS::CO_E_MISSING_DISPLAYNAME => "The activation requires a display name to be present under the CLSID key.",
            WINDOWS::CO_E_RUNAS_VALUE_MUST_BE_AAA => "The activation requires that the RunAs value for the application is Activate As Activator.",
            WINDOWS::CO_E_ELEVATION_DISABLED => "The class is not configured to support Elevated activation.",
            WINDOWS::APPX_E_PACKAGING_INTERNAL => "Appx packaging API has encountered an internal error.",
            WINDOWS::APPX_E_INTERLEAVING_NOT_ALLOWED => "The file is not a valid Appx package because its contents are interleaved.",
            WINDOWS::APPX_E_RELATIONSHIPS_NOT_ALLOWED => "The file is not a valid Appx package because it contains OPC relationships.",
            WINDOWS::APPX_E_MISSING_REQUIRED_FILE => "The file is not a valid Appx package because it is missing a manifest or block map, or missing a signature file when the code integrity file is present.",
            WINDOWS::APPX_E_INVALID_MANIFEST => "The Appx package's manifest is invalid.",
            WINDOWS::APPX_E_INVALID_BLOCKMAP => "The Appx package's block map is invalid.",
            WINDOWS::APPX_E_CORRUPT_CONTENT => "The Appx package's content cannot be read because it is corrupt.",
            WINDOWS::APPX_E_BLOCK_HASH_INVALID => "The computed hash value of the block does not match the one stored in the block map.",
            WINDOWS::APPX_E_REQUESTED_RANGE_TOO_LARGE => "The requested byte range is over 4GB when translated to byte range of blocks.",
            WINDOWS::APPX_E_INVALID_SIP_CLIENT_DATA => "The SIP_SUBJECTINFO structure used to sign the package didn't contain the required data.",
            WINDOWS::APPX_E_INVALID_KEY_INFO => "The APPX_KEY_INFO structure used to encrypt or decrypt the package contains invalid data.",
            WINDOWS::APPX_E_INVALID_CONTENTGROUPMAP => "The Appx package's content group map is invalid.",
            WINDOWS::APPX_E_INVALID_APPINSTALLER => "The .appinstaller file is invalid.",
            WINDOWS::APPX_E_DELTA_BASELINE_VERSION_MISMATCH => "The baseline package version in delta package does not match the version in the baseline package to be updated.",
            WINDOWS::APPX_E_DELTA_PACKAGE_MISSING_FILE => "The delta package is missing a file from the updated package.",
            WINDOWS::APPX_E_INVALID_DELTA_PACKAGE => "The delta package is invalid.",
            WINDOWS::APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED => "The delta appended package is not allowed for the current operation.",
            WINDOWS::APPX_E_INVALID_PACKAGING_LAYOUT => "The packaging layout file is invalid.",
            WINDOWS::APPX_E_INVALID_PACKAGESIGNCONFIG => "The packageSignConfig file is invalid.",
            WINDOWS::APPX_E_RESOURCESPRI_NOT_ALLOWED => "The resources.pri file is not allowed when there are no resource elements in the package manifest.",
            WINDOWS::APPX_E_FILE_COMPRESSION_MISMATCH => "The compression state of file in baseline and updated package does not match.",
            WINDOWS::APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION => "Non appx extensions are not allowed for payload packages targeting older platforms.",
            WINDOWS::APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST => "The encryptionExclusionFileList file is invalid.",
            WINDOWS::APPX_E_INVALID_PACKAGE_FOLDER_ACLS => "The package folder ACLs are invalid.",
            WINDOWS::APPX_E_INVALID_PUBLISHER_BRIDGING => "The publisher bridging artifact is invalid.",
            WINDOWS::APPX_E_DIGEST_MISMATCH => "The expected digest value did not match the actual digest value of the content.",
            WINDOWS::BT_E_SPURIOUS_ACTIVATION => "The background task activation is spurious.",
        }
    }

    pub fn from_name(name: &str) -> WINDOWS {
        return match name {
            "CO_S_NOTALLINTERFACES" => WINDOWS::CO_S_NOTALLINTERFACES,
            "CO_S_MACHINENAMENOTFOUND" => WINDOWS::CO_S_MACHINENAMENOTFOUND,
            "CO_E_CLASS_CREATE_FAILED" => WINDOWS::CO_E_CLASS_CREATE_FAILED,
            "CO_E_SCM_ERROR" => WINDOWS::CO_E_SCM_ERROR,
            "CO_E_SCM_RPC_FAILURE" => WINDOWS::CO_E_SCM_RPC_FAILURE,
            "CO_E_BAD_PATH" => WINDOWS::CO_E_BAD_PATH,
            "CO_E_SERVER_EXEC_FAILURE" => WINDOWS::CO_E_SERVER_EXEC_FAILURE,
            "CO_E_OBJSRV_RPC_FAILURE" => WINDOWS::CO_E_OBJSRV_RPC_FAILURE,
            "MK_E_NO_NORMALIZED" => WINDOWS::MK_E_NO_NORMALIZED,
            "CO_E_SERVER_STOPPING" => WINDOWS::CO_E_SERVER_STOPPING,
            "MEM_E_INVALID_ROOT" => WINDOWS::MEM_E_INVALID_ROOT,
            "MEM_E_INVALID_LINK" => WINDOWS::MEM_E_INVALID_LINK,
            "MEM_E_INVALID_SIZE" => WINDOWS::MEM_E_INVALID_SIZE,
            "CO_E_MISSING_DISPLAYNAME" => WINDOWS::CO_E_MISSING_DISPLAYNAME,
            "CO_E_RUNAS_VALUE_MUST_BE_AAA" => WINDOWS::CO_E_RUNAS_VALUE_MUST_BE_AAA,
            "CO_E_ELEVATION_DISABLED" => WINDOWS::CO_E_ELEVATION_DISABLED,
            "APPX_E_PACKAGING_INTERNAL" => WINDOWS::APPX_E_PACKAGING_INTERNAL,
            "APPX_E_INTERLEAVING_NOT_ALLOWED" => WINDOWS::APPX_E_INTERLEAVING_NOT_ALLOWED,
            "APPX_E_RELATIONSHIPS_NOT_ALLOWED" => WINDOWS::APPX_E_RELATIONSHIPS_NOT_ALLOWED,
            "APPX_E_MISSING_REQUIRED_FILE" => WINDOWS::APPX_E_MISSING_REQUIRED_FILE,
            "APPX_E_INVALID_MANIFEST" => WINDOWS::APPX_E_INVALID_MANIFEST,
            "APPX_E_INVALID_BLOCKMAP" => WINDOWS::APPX_E_INVALID_BLOCKMAP,
            "APPX_E_CORRUPT_CONTENT" => WINDOWS::APPX_E_CORRUPT_CONTENT,
            "APPX_E_BLOCK_HASH_INVALID" => WINDOWS::APPX_E_BLOCK_HASH_INVALID,
            "APPX_E_REQUESTED_RANGE_TOO_LARGE" => WINDOWS::APPX_E_REQUESTED_RANGE_TOO_LARGE,
            "APPX_E_INVALID_SIP_CLIENT_DATA" => WINDOWS::APPX_E_INVALID_SIP_CLIENT_DATA,
            "APPX_E_INVALID_KEY_INFO" => WINDOWS::APPX_E_INVALID_KEY_INFO,
            "APPX_E_INVALID_CONTENTGROUPMAP" => WINDOWS::APPX_E_INVALID_CONTENTGROUPMAP,
            "APPX_E_INVALID_APPINSTALLER" => WINDOWS::APPX_E_INVALID_APPINSTALLER,
            "APPX_E_DELTA_BASELINE_VERSION_MISMATCH" => WINDOWS::APPX_E_DELTA_BASELINE_VERSION_MISMATCH,
            "APPX_E_DELTA_PACKAGE_MISSING_FILE" => WINDOWS::APPX_E_DELTA_PACKAGE_MISSING_FILE,
            "APPX_E_INVALID_DELTA_PACKAGE" => WINDOWS::APPX_E_INVALID_DELTA_PACKAGE,
            "APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED" => WINDOWS::APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED,
            "APPX_E_INVALID_PACKAGING_LAYOUT" => WINDOWS::APPX_E_INVALID_PACKAGING_LAYOUT,
            "APPX_E_INVALID_PACKAGESIGNCONFIG" => WINDOWS::APPX_E_INVALID_PACKAGESIGNCONFIG,
            "APPX_E_RESOURCESPRI_NOT_ALLOWED" => WINDOWS::APPX_E_RESOURCESPRI_NOT_ALLOWED,
            "APPX_E_FILE_COMPRESSION_MISMATCH" => WINDOWS::APPX_E_FILE_COMPRESSION_MISMATCH,
            "APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION" => WINDOWS::APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION,
            "APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST" => WINDOWS::APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST,
            "APPX_E_INVALID_PACKAGE_FOLDER_ACLS" => WINDOWS::APPX_E_INVALID_PACKAGE_FOLDER_ACLS,
            "APPX_E_INVALID_PUBLISHER_BRIDGING" => WINDOWS::APPX_E_INVALID_PUBLISHER_BRIDGING,
            "APPX_E_DIGEST_MISMATCH" => WINDOWS::APPX_E_DIGEST_MISMATCH,
            "BT_E_SPURIOUS_ACTIVATION" => WINDOWS::BT_E_SPURIOUS_ACTIVATION,
        }
    }
    pub fn from_code(code: u32) -> WINDOWS {
        return match code {
            0x00080012 => WINDOWS::CO_S_NOTALLINTERFACES,
            0x00080013 => WINDOWS::CO_S_MACHINENAMENOTFOUND,
            0x80080001 => WINDOWS::CO_E_CLASS_CREATE_FAILED,
            0x80080002 => WINDOWS::CO_E_SCM_ERROR,
            0x80080003 => WINDOWS::CO_E_SCM_RPC_FAILURE,
            0x80080004 => WINDOWS::CO_E_BAD_PATH,
            0x80080005 => WINDOWS::CO_E_SERVER_EXEC_FAILURE,
            0x80080006 => WINDOWS::CO_E_OBJSRV_RPC_FAILURE,
            0x80080007 => WINDOWS::MK_E_NO_NORMALIZED,
            0x80080008 => WINDOWS::CO_E_SERVER_STOPPING,
            0x80080009 => WINDOWS::MEM_E_INVALID_ROOT,
            0x80080010 => WINDOWS::MEM_E_INVALID_LINK,
            0x80080011 => WINDOWS::MEM_E_INVALID_SIZE,
            0x80080015 => WINDOWS::CO_E_MISSING_DISPLAYNAME,
            0x80080016 => WINDOWS::CO_E_RUNAS_VALUE_MUST_BE_AAA,
            0x80080017 => WINDOWS::CO_E_ELEVATION_DISABLED,
            0x80080200 => WINDOWS::APPX_E_PACKAGING_INTERNAL,
            0x80080201 => WINDOWS::APPX_E_INTERLEAVING_NOT_ALLOWED,
            0x80080202 => WINDOWS::APPX_E_RELATIONSHIPS_NOT_ALLOWED,
            0x80080203 => WINDOWS::APPX_E_MISSING_REQUIRED_FILE,
            0x80080204 => WINDOWS::APPX_E_INVALID_MANIFEST,
            0x80080205 => WINDOWS::APPX_E_INVALID_BLOCKMAP,
            0x80080206 => WINDOWS::APPX_E_CORRUPT_CONTENT,
            0x80080207 => WINDOWS::APPX_E_BLOCK_HASH_INVALID,
            0x80080208 => WINDOWS::APPX_E_REQUESTED_RANGE_TOO_LARGE,
            0x80080209 => WINDOWS::APPX_E_INVALID_SIP_CLIENT_DATA,
            0x8008020A => WINDOWS::APPX_E_INVALID_KEY_INFO,
            0x8008020B => WINDOWS::APPX_E_INVALID_CONTENTGROUPMAP,
            0x8008020C => WINDOWS::APPX_E_INVALID_APPINSTALLER,
            0x8008020D => WINDOWS::APPX_E_DELTA_BASELINE_VERSION_MISMATCH,
            0x8008020E => WINDOWS::APPX_E_DELTA_PACKAGE_MISSING_FILE,
            0x8008020F => WINDOWS::APPX_E_INVALID_DELTA_PACKAGE,
            0x80080210 => WINDOWS::APPX_E_DELTA_APPENDED_PACKAGE_NOT_ALLOWED,
            0x80080211 => WINDOWS::APPX_E_INVALID_PACKAGING_LAYOUT,
            0x80080212 => WINDOWS::APPX_E_INVALID_PACKAGESIGNCONFIG,
            0x80080213 => WINDOWS::APPX_E_RESOURCESPRI_NOT_ALLOWED,
            0x80080214 => WINDOWS::APPX_E_FILE_COMPRESSION_MISMATCH,
            0x80080215 => WINDOWS::APPX_E_INVALID_PAYLOAD_PACKAGE_EXTENSION,
            0x80080216 => WINDOWS::APPX_E_INVALID_ENCRYPTION_EXCLUSION_FILE_LIST,
            0x80080217 => WINDOWS::APPX_E_INVALID_PACKAGE_FOLDER_ACLS,
            0x80080218 => WINDOWS::APPX_E_INVALID_PUBLISHER_BRIDGING,
            0x80080219 => WINDOWS::APPX_E_DIGEST_MISMATCH,
            0x80080300 => WINDOWS::BT_E_SPURIOUS_ACTIVATION,
        }
    }
}
