/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WINDOWS_CE {
    MENROLL_S_ENROLLMENT_SUSPENDED,
    MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR,
    MENROLL_E_DEVICE_AUTHENTICATION_ERROR,
    MENROLL_E_DEVICE_AUTHORIZATION_ERROR,
    MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR,
    MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR,
    MENROLL_E_DEVICE_INTERNALSERVICE_ERROR,
    MENROLL_E_DEVICE_INVALIDSECURITY_ERROR,
    MENROLL_E_DEVICE_UNKNOWN_ERROR,
    MENROLL_E_ENROLLMENT_IN_PROGRESS,
    MENROLL_E_DEVICE_ALREADY_ENROLLED,
    MENROLL_E_DEVICE_NOT_ENROLLED,
    MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID,
    MENROLL_E_PASSWORD_NEEDED,
    MENROLL_E_WAB_ERROR,
    MENROLL_E_CONNECTIVITY,
    MENROLL_E_INVALIDSSLCERT,
    MENROLL_E_DEVICECAPREACHED,
    MENROLL_E_DEVICENOTSUPPORTED,
    MENROLL_E_NOT_SUPPORTED,
    MENROLL_E_NOTELIGIBLETORENEW,
    MENROLL_E_INMAINTENANCE,
    MENROLL_E_USER_LICENSE,
    MENROLL_E_ENROLLMENTDATAINVALID,
    MENROLL_E_INSECUREREDIRECT,
    MENROLL_E_PLATFORM_WRONG_STATE,
    MENROLL_E_PLATFORM_LICENSE_ERROR,
    MENROLL_E_PLATFORM_UNKNOWN_ERROR,
    MENROLL_E_PROV_CSP_CERTSTORE,
    MENROLL_E_PROV_CSP_W7,
    MENROLL_E_PROV_CSP_DMCLIENT,
    MENROLL_E_PROV_CSP_PFW,
    MENROLL_E_PROV_CSP_MISC,
    MENROLL_E_PROV_UNKNOWN,
    MENROLL_E_PROV_SSLCERTNOTFOUND,
    MENROLL_E_PROV_CSP_APPMGMT,
    MENROLL_E_DEVICE_MANAGEMENT_BLOCKED,
    MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED,
    MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT,
    MENROLL_E_EMPTY_MESSAGE,
    MENROLL_E_USER_CANCELLED,
    MENROLL_E_MDM_NOT_CONFIGURED,
    DUA_ERR_BASE,
    DUA_E_NEWER_UPDATE_EXISTS,
    DUA_E_UPDATE_ALREADY_IN_EVALUATION,
    DUA_E_DEPENDENT_UPDATE_MISSING,
    DUA_E_DUPLICATE_ATTRIBUTE,
    DUA_E_MISSING_ATTRIBUTE,
    DUA_E_INVALIDATTRIBUTEVALUE,
    DUA_E_XMLSTRINGTOOLONG,
    DUA_E_ATTRIBUTE_MISMATCH,
    DUA_E_OUT_OF_DISK_SPACE,
    DUA_E_CONNECTION_MANAGER,
    DUA_E_INVALID_HASH,
    DUA_E_INVALID_EULA,
    DUA_E_INVALID_EXTENDED_UPDATE_INFO,
    DUA_E_MAX_SYNCUPDATES_CALLS,
    DUA_E_AUTO_SCAN_OFF,
    DUA_E_XML_CONTENT_TOO_LARGE,
    DUA_E_SDCARD_REMOVED,
    DUA_E_SDCARD_DISABLED,
    DUA_E_SDCARD_HWFAILURE,
    DUA_E_SOAPFAULT_UNKNOWN,
    DUA_E_SOAPFAULT_COOKIEEXPIRED,
    DUA_E_SOAPFAULT_INVALIDCOOKIE,
    DUA_E_SOAPFAULT_CONFIGCHANGED,
    DUA_E_SOAPFAULT_SERVERCHANGED,
    DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE,
    DUA_E_SOAPFAULT_REGISTRATIONREQUIRED,
    DUA_E_SOAPFAULT_INTERNALSERVERERROR,
    DUA_E_SOAPFAULT_INVALIDpMETERS,
    DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED,
    DUA_E_SOAPFAULT_SERVERBUSY,
    DUA_E_SOAPFAULT_FILELOCATIONCHANGED,
    DUA_E_SOAPFAULT_MALFORMED_MESSAGE,
    DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED,
    DUA_ERR_REPORTINGERROR_BASE,
    DUA_E_REPORTINGFAILED,
    DUA_E_INVALIDSAMPLINGRATE,
    DUA_ERR_CLIENTERROR_BASE,
    DUA_E_CLIENT_INVALIDBUTTONID,
    DUA_E_CLIENT_REGKEY_INVALID,
    DUA_E_CLIENT_PLUGINID_NOT_FOUND,
    DUA_ERR_INSTALLATION_BASE,
    DUA_E_BATTERY_LOW,
    DUA_E_UPDATE_NOT_STAGED,
    DUA_E_USS_UPDATE_FOUND,
    DUA_E_INSTALL_INVALIDUPDATESTATE,
    DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN,
    DUA_E_UPDATE_NOT_COMMITTED,
    DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED,
    DUA_ERR_DATA_MIGRATION_BASE,
    DUA_E_COLD_BOOT_REQUIRED,
    DUA_ERR_UPDATE_STORE_BASE,
    DUA_E_UPDATE_NOT_FOUND,
    DUA_E_UPDATE_PROPERTY_NOT_FOUND,
    DUA_E_UPDATE_ALREADY_EXISTS,
    DUA_E_EULA_ALREADY_EXISTS,
    DUA_E_EULA_NOT_FOUND,
    DUA_E_BUNDLE_NOT_FOUND,
    DUA_E_EXTENDED_PROPERTY_NOT_FOUND,
    DUA_E_GETEULA,
    DUA_ERR_SESSION_BASE,
    DUA_E_INVALID_SESSIONID,
    DUA_E_DIFF_SESSION_IN_PROGRESS,
    DUA_E_NO_SESSION_IN_PROGRESS,
    DUA_E_CANNOT_CLOSE_SESSION,
    DUA_E_ALL_RETRY_CONSUMED,
    DUA_E_SERVICE_IS_SHUTTING_DOWN,
    DUA_E_SESSION_TIMEDOUT,
    DUA_E_DOWNLOAD_BASE,
    DUA_E_DOWNLOAD_NOT_CREATED,
    DUA_E_DOWNLOAD_NOT_IDLE,
    DUA_E_DOWNLOAD_USER_CANCELLED,
    DUA_E_DOWNLOAD_NEEDUSERAGREE,
    DUA_E_DOWNLOAD_NEEDOVERCELLULAR,
    DUA_E_DOWNLOAD_USERPOSTPONE,
    DUA_E_DOWNLOAD_ENGINEEXIT,
    DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD,
    DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE,
    DUA_E_CONNECTION_BASE,
    DUA_E_NO_CONNECTIONS,
    DUA_E_CONNECTION_NOT_RELEASED,
    DUA_E_CONNECTION_ACQUIRE_FAILED,
    DUA_E_DUAAPI_BASE,
    DUA_E_DUAAPI_SHELLNOTREADY,
    BTS_ERR_BASE,
    E_CABAPI_NOT_CABINET,
    E_CABAPI_UNKNOWN_FILE,
    BTS_E_HTTP_PROVIDER_ERROR,
    BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED,
    E_CABAPI_FCI_OPEN_SRC,
    E_CABAPI_FCI_READ_SRC,
    E_CABAPI_FCI_ALLOC_FAIL,
    E_CABAPI_FCI_TEMP_FILE,
    E_CABAPI_FCI_BAD_COMPR_TYPE,
    E_CABAPI_FCI_CAB_FILE,
    E_CABAPI_FCI_USER_ABORT,
    E_CABAPI_FCI_MCI_FAIL,
    E_CABAPI_FCI_CAB_FORMAT_LIMIT,
    E_CABAPI_FCI_INVALID_FILE_PATH,
    E_CABAPI_FCI_DUPLICATE_FILE,
    E_CABAPI_FCI_UNKNOWN,
    CABAPI_ERR_FDI_BASE,
    E_CABAPI_FDI_CABINET_NOT_FOUND,
    E_CABAPI_FDI_NOT_A_CABINET,
    E_CABAPI_FDI_UNKNOWN_CABINET_VERSION,
    E_CABAPI_FDI_CORRUPT_CABINET,
    E_CABAPI_FDI_ALLOC_FAIL,
    E_CABAPI_FDI_BAD_COMPR_TYPE,
    E_CABAPI_FDI_MDI_FAIL,
    E_CABAPI_FDI_TARGET_FILE,
    E_CABAPI_FDI_RESERVE_MISMATCH,
    E_CABAPI_FDI_WRONG_CABINET,
    E_CABAPI_FDI_USER_ABORT,
    E_CABAPI_FDI_UNKNOWN,
    IMGUPD_ERROR_BASE,
    E_BASE_PACKAGE_NOT_INSTALLED,
    E_PACKAGE_ALREADY_INSTALLED,
    E_NO_UPDATE_PATH_TO_TARGET,
    E_MULTIPLE_UPDATE_PATHS_FOUND,
    E_DUPLICATE_UPDATE_PACKAGE,
    E_FILE_COLLISION,
    E_INVALID_PACKAGE,
    E_INSUFFICIENT_SPACE_FOR_UPDATE,
    E_REGISTRY_COLLISION,
    E_INVALID_REGISTRY_FILE,
    E_DEPCRECATED1,
    E_TARGET_NOT_APPLICABLE,
    E_PACKAGE_HIGHER_VERSION_INSTALLED,
    E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION,
    E_DIFF_SOURCEVERSION_DOES_NOT_MATCH,
    E_STAGED_FILE_NOT_FOUND,
    E_PACKAGE_TARGETS_WRONG_CPU,
}

impl WINDOWS_CE {
    pub fn code(&self) -> u32 {
        return match self {
            WINDOWS_CE::MENROLL_S_ENROLLMENT_SUSPENDED => 0x00180011 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR => 0x80180001 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_AUTHENTICATION_ERROR => 0x80180002 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_AUTHORIZATION_ERROR => 0x80180003 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR => 0x80180004 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR => 0x80180005 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_INTERNALSERVICE_ERROR => 0x80180006 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_INVALIDSECURITY_ERROR => 0x80180007 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_UNKNOWN_ERROR => 0x80180008 as u32,
            WINDOWS_CE::MENROLL_E_ENROLLMENT_IN_PROGRESS => 0x80180009 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_ALREADY_ENROLLED => 0x8018000A as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_NOT_ENROLLED => 0x8018000B as u32,
            WINDOWS_CE::MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID => 0x8018000D as u32,
            WINDOWS_CE::MENROLL_E_PASSWORD_NEEDED => 0x8018000E as u32,
            WINDOWS_CE::MENROLL_E_WAB_ERROR => 0x8018000F as u32,
            WINDOWS_CE::MENROLL_E_CONNECTIVITY => 0x80180010 as u32,
            WINDOWS_CE::MENROLL_E_INVALIDSSLCERT => 0x80180012 as u32,
            WINDOWS_CE::MENROLL_E_DEVICECAPREACHED => 0x80180013 as u32,
            WINDOWS_CE::MENROLL_E_DEVICENOTSUPPORTED => 0x80180014 as u32,
            WINDOWS_CE::MENROLL_E_NOT_SUPPORTED => 0x80180015 as u32,
            WINDOWS_CE::MENROLL_E_NOTELIGIBLETORENEW => 0x80180016 as u32,
            WINDOWS_CE::MENROLL_E_INMAINTENANCE => 0x80180017 as u32,
            WINDOWS_CE::MENROLL_E_USER_LICENSE => 0x80180018 as u32,
            WINDOWS_CE::MENROLL_E_ENROLLMENTDATAINVALID => 0x80180019 as u32,
            WINDOWS_CE::MENROLL_E_INSECUREREDIRECT => 0x8018001A as u32,
            WINDOWS_CE::MENROLL_E_PLATFORM_WRONG_STATE => 0x8018001B as u32,
            WINDOWS_CE::MENROLL_E_PLATFORM_LICENSE_ERROR => 0x8018001C as u32,
            WINDOWS_CE::MENROLL_E_PLATFORM_UNKNOWN_ERROR => 0x8018001D as u32,
            WINDOWS_CE::MENROLL_E_PROV_CSP_CERTSTORE => 0x8018001E as u32,
            WINDOWS_CE::MENROLL_E_PROV_CSP_W7 => 0x8018001F as u32,
            WINDOWS_CE::MENROLL_E_PROV_CSP_DMCLIENT => 0x80180020 as u32,
            WINDOWS_CE::MENROLL_E_PROV_CSP_PFW => 0x80180021 as u32,
            WINDOWS_CE::MENROLL_E_PROV_CSP_MISC => 0x80180022 as u32,
            WINDOWS_CE::MENROLL_E_PROV_UNKNOWN => 0x80180023 as u32,
            WINDOWS_CE::MENROLL_E_PROV_SSLCERTNOTFOUND => 0x80180024 as u32,
            WINDOWS_CE::MENROLL_E_PROV_CSP_APPMGMT => 0x80180025 as u32,
            WINDOWS_CE::MENROLL_E_DEVICE_MANAGEMENT_BLOCKED => 0x80180026 as u32,
            WINDOWS_CE::MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED => 0x80180027 as u32,
            WINDOWS_CE::MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT => 0x80180028 as u32,
            WINDOWS_CE::MENROLL_E_EMPTY_MESSAGE => 0x80180029 as u32,
            WINDOWS_CE::MENROLL_E_USER_CANCELLED => 0x80180030 as u32,
            WINDOWS_CE::MENROLL_E_MDM_NOT_CONFIGURED => 0x80180031 as u32,
            WINDOWS_CE::DUA_ERR_BASE => 0x801881C0 as u32,
            WINDOWS_CE::DUA_E_NEWER_UPDATE_EXISTS => 0x801881C3 as u32,
            WINDOWS_CE::DUA_E_UPDATE_ALREADY_IN_EVALUATION => 0x801881C4 as u32,
            WINDOWS_CE::DUA_E_DEPENDENT_UPDATE_MISSING => 0x801881C5 as u32,
            WINDOWS_CE::DUA_E_DUPLICATE_ATTRIBUTE => 0x801881C6 as u32,
            WINDOWS_CE::DUA_E_MISSING_ATTRIBUTE => 0x801881C7 as u32,
            WINDOWS_CE::DUA_E_INVALIDATTRIBUTEVALUE => 0x801881C9 as u32,
            WINDOWS_CE::DUA_E_XMLSTRINGTOOLONG => 0x801881CA as u32,
            WINDOWS_CE::DUA_E_ATTRIBUTE_MISMATCH => 0x801881CB as u32,
            WINDOWS_CE::DUA_E_OUT_OF_DISK_SPACE => 0x801881CD as u32,
            WINDOWS_CE::DUA_E_CONNECTION_MANAGER => 0x801881CF as u32,
            WINDOWS_CE::DUA_E_INVALID_HASH => 0x801881D0 as u32,
            WINDOWS_CE::DUA_E_INVALID_EULA => 0x801881D1 as u32,
            WINDOWS_CE::DUA_E_INVALID_EXTENDED_UPDATE_INFO => 0x801881D2 as u32,
            WINDOWS_CE::DUA_E_MAX_SYNCUPDATES_CALLS => 0x801881D3 as u32,
            WINDOWS_CE::DUA_E_AUTO_SCAN_OFF => 0x801881D4 as u32,
            WINDOWS_CE::DUA_E_XML_CONTENT_TOO_LARGE => 0x801881D5 as u32,
            WINDOWS_CE::DUA_E_SDCARD_REMOVED => 0x801881D6 as u32,
            WINDOWS_CE::DUA_E_SDCARD_DISABLED => 0x801881D7 as u32,
            WINDOWS_CE::DUA_E_SDCARD_HWFAILURE => 0x801881D8 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_UNKNOWN => 0x801881E1 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_COOKIEEXPIRED => 0x801881E2 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDCOOKIE => 0x801881E3 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_CONFIGCHANGED => 0x801881E4 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_SERVERCHANGED => 0x801881E5 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE => 0x801881E6 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONREQUIRED => 0x801881E7 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_INTERNALSERVERERROR => 0x801881E8 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDpMETERS => 0x801881E9 as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED => 0x801881EA as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_SERVERBUSY => 0x801881EB as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_FILELOCATIONCHANGED => 0x801881EC as u32,
            WINDOWS_CE::DUA_E_SOAPFAULT_MALFORMED_MESSAGE => 0x801881EE as u32,
            WINDOWS_CE::DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED => 0x801881EF as u32,
            WINDOWS_CE::DUA_ERR_REPORTINGERROR_BASE => 0x80188200 as u32,
            WINDOWS_CE::DUA_E_REPORTINGFAILED => 0x80188201 as u32,
            WINDOWS_CE::DUA_E_INVALIDSAMPLINGRATE => 0x80188203 as u32,
            WINDOWS_CE::DUA_ERR_CLIENTERROR_BASE => 0x80188210 as u32,
            WINDOWS_CE::DUA_E_CLIENT_INVALIDBUTTONID => 0x80188215 as u32,
            WINDOWS_CE::DUA_E_CLIENT_REGKEY_INVALID => 0x80188216 as u32,
            WINDOWS_CE::DUA_E_CLIENT_PLUGINID_NOT_FOUND => 0x80188217 as u32,
            WINDOWS_CE::DUA_ERR_INSTALLATION_BASE => 0x80188220 as u32,
            WINDOWS_CE::DUA_E_BATTERY_LOW => 0x80188226 as u32,
            WINDOWS_CE::DUA_E_UPDATE_NOT_STAGED => 0x80188227 as u32,
            WINDOWS_CE::DUA_E_USS_UPDATE_FOUND => 0x80188228 as u32,
            WINDOWS_CE::DUA_E_INSTALL_INVALIDUPDATESTATE => 0x8018822A as u32,
            WINDOWS_CE::DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN => 0x8018822B as u32,
            WINDOWS_CE::DUA_E_UPDATE_NOT_COMMITTED => 0x8018822C as u32,
            WINDOWS_CE::DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED => 0x8018822D as u32,
            WINDOWS_CE::DUA_ERR_DATA_MIGRATION_BASE => 0x80188230 as u32,
            WINDOWS_CE::DUA_E_COLD_BOOT_REQUIRED => 0x80188231 as u32,
            WINDOWS_CE::DUA_ERR_UPDATE_STORE_BASE => 0x80188240 as u32,
            WINDOWS_CE::DUA_E_UPDATE_NOT_FOUND => 0x80188241 as u32,
            WINDOWS_CE::DUA_E_UPDATE_PROPERTY_NOT_FOUND => 0x80188242 as u32,
            WINDOWS_CE::DUA_E_UPDATE_ALREADY_EXISTS => 0x80188243 as u32,
            WINDOWS_CE::DUA_E_EULA_ALREADY_EXISTS => 0x80188244 as u32,
            WINDOWS_CE::DUA_E_EULA_NOT_FOUND => 0x80188245 as u32,
            WINDOWS_CE::DUA_E_BUNDLE_NOT_FOUND => 0x80188246 as u32,
            WINDOWS_CE::DUA_E_EXTENDED_PROPERTY_NOT_FOUND => 0x80188247 as u32,
            WINDOWS_CE::DUA_E_GETEULA => 0x80188248 as u32,
            WINDOWS_CE::DUA_ERR_SESSION_BASE => 0x80188250 as u32,
            WINDOWS_CE::DUA_E_INVALID_SESSIONID => 0x80188251 as u32,
            WINDOWS_CE::DUA_E_DIFF_SESSION_IN_PROGRESS => 0x80188252 as u32,
            WINDOWS_CE::DUA_E_NO_SESSION_IN_PROGRESS => 0x80188253 as u32,
            WINDOWS_CE::DUA_E_CANNOT_CLOSE_SESSION => 0x80188254 as u32,
            WINDOWS_CE::DUA_E_ALL_RETRY_CONSUMED => 0x80188255 as u32,
            WINDOWS_CE::DUA_E_SERVICE_IS_SHUTTING_DOWN => 0x80188256 as u32,
            WINDOWS_CE::DUA_E_SESSION_TIMEDOUT => 0x80188257 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_BASE => 0x80188260 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_NOT_CREATED => 0x80188261 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_NOT_IDLE => 0x80188262 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_USER_CANCELLED => 0x80188263 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_NEEDUSERAGREE => 0x80188264 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_NEEDOVERCELLULAR => 0x80188265 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_USERPOSTPONE => 0x80188266 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_ENGINEEXIT => 0x80188267 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD => 0x80188269 as u32,
            WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE => 0x8018826A as u32,
            WINDOWS_CE::DUA_E_CONNECTION_BASE => 0x80188270 as u32,
            WINDOWS_CE::DUA_E_NO_CONNECTIONS => 0x80188271 as u32,
            WINDOWS_CE::DUA_E_CONNECTION_NOT_RELEASED => 0x80188272 as u32,
            WINDOWS_CE::DUA_E_CONNECTION_ACQUIRE_FAILED => 0x80188273 as u32,
            WINDOWS_CE::DUA_E_DUAAPI_BASE => 0x80188288 as u32,
            WINDOWS_CE::DUA_E_DUAAPI_SHELLNOTREADY => 0x80188289 as u32,
            WINDOWS_CE::BTS_ERR_BASE => 0x801882C0 as u32,
            WINDOWS_CE::E_CABAPI_NOT_CABINET => 0x801882C1 as u32,
            WINDOWS_CE::E_CABAPI_UNKNOWN_FILE => 0x801882C2 as u32,
            WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR => 0x801882CB as u32,
            WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED => 0x801882CC as u32,
            WINDOWS_CE::E_CABAPI_FCI_OPEN_SRC => 0x801882D1 as u32,
            WINDOWS_CE::E_CABAPI_FCI_READ_SRC => 0x801882D2 as u32,
            WINDOWS_CE::E_CABAPI_FCI_ALLOC_FAIL => 0x801882D3 as u32,
            WINDOWS_CE::E_CABAPI_FCI_TEMP_FILE => 0x801882D4 as u32,
            WINDOWS_CE::E_CABAPI_FCI_BAD_COMPR_TYPE => 0x801882D5 as u32,
            WINDOWS_CE::E_CABAPI_FCI_CAB_FILE => 0x801882D6 as u32,
            WINDOWS_CE::E_CABAPI_FCI_USER_ABORT => 0x801882D7 as u32,
            WINDOWS_CE::E_CABAPI_FCI_MCI_FAIL => 0x801882D8 as u32,
            WINDOWS_CE::E_CABAPI_FCI_CAB_FORMAT_LIMIT => 0x801882D9 as u32,
            WINDOWS_CE::E_CABAPI_FCI_INVALID_FILE_PATH => 0x801882DA as u32,
            WINDOWS_CE::E_CABAPI_FCI_DUPLICATE_FILE => 0x801882DB as u32,
            WINDOWS_CE::E_CABAPI_FCI_UNKNOWN => 0x801882DF as u32,
            WINDOWS_CE::CABAPI_ERR_FDI_BASE => 0x801882E0 as u32,
            WINDOWS_CE::E_CABAPI_FDI_CABINET_NOT_FOUND => 0x801882E1 as u32,
            WINDOWS_CE::E_CABAPI_FDI_NOT_A_CABINET => 0x801882E2 as u32,
            WINDOWS_CE::E_CABAPI_FDI_UNKNOWN_CABINET_VERSION => 0x801882E3 as u32,
            WINDOWS_CE::E_CABAPI_FDI_CORRUPT_CABINET => 0x801882E4 as u32,
            WINDOWS_CE::E_CABAPI_FDI_ALLOC_FAIL => 0x801882E5 as u32,
            WINDOWS_CE::E_CABAPI_FDI_BAD_COMPR_TYPE => 0x801882E6 as u32,
            WINDOWS_CE::E_CABAPI_FDI_MDI_FAIL => 0x801882E7 as u32,
            WINDOWS_CE::E_CABAPI_FDI_TARGET_FILE => 0x801882E8 as u32,
            WINDOWS_CE::E_CABAPI_FDI_RESERVE_MISMATCH => 0x801882E9 as u32,
            WINDOWS_CE::E_CABAPI_FDI_WRONG_CABINET => 0x801882EA as u32,
            WINDOWS_CE::E_CABAPI_FDI_USER_ABORT => 0x801882EB as u32,
            WINDOWS_CE::E_CABAPI_FDI_UNKNOWN => 0x801882EF as u32,
            WINDOWS_CE::IMGUPD_ERROR_BASE => 0x80188300 as u32,
            WINDOWS_CE::E_BASE_PACKAGE_NOT_INSTALLED => 0x80188301 as u32,
            WINDOWS_CE::E_PACKAGE_ALREADY_INSTALLED => 0x80188302 as u32,
            WINDOWS_CE::E_NO_UPDATE_PATH_TO_TARGET => 0x80188303 as u32,
            WINDOWS_CE::E_MULTIPLE_UPDATE_PATHS_FOUND => 0x80188304 as u32,
            WINDOWS_CE::E_DUPLICATE_UPDATE_PACKAGE => 0x80188305 as u32,
            WINDOWS_CE::E_FILE_COLLISION => 0x80188306 as u32,
            WINDOWS_CE::E_INVALID_PACKAGE => 0x80188307 as u32,
            WINDOWS_CE::E_INSUFFICIENT_SPACE_FOR_UPDATE => 0x80188308 as u32,
            WINDOWS_CE::E_REGISTRY_COLLISION => 0x80188309 as u32,
            WINDOWS_CE::E_INVALID_REGISTRY_FILE => 0x8018830A as u32,
            WINDOWS_CE::E_DEPCRECATED1 => 0x8018830B as u32,
            WINDOWS_CE::E_TARGET_NOT_APPLICABLE => 0x8018830C as u32,
            WINDOWS_CE::E_PACKAGE_HIGHER_VERSION_INSTALLED => 0x8018830D as u32,
            WINDOWS_CE::E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION => 0x8018830E as u32,
            WINDOWS_CE::E_DIFF_SOURCEVERSION_DOES_NOT_MATCH => 0x8018830F as u32,
            WINDOWS_CE::E_STAGED_FILE_NOT_FOUND => 0x80188310 as u32,
            WINDOWS_CE::E_PACKAGE_TARGETS_WRONG_CPU => 0x80188311 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WINDOWS_CE::MENROLL_S_ENROLLMENT_SUSPENDED => RawError::Kind(WINDOWS_CE::MENROLL_S_ENROLLMENT_SUSPENDED),
            WINDOWS_CE::MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_AUTHENTICATION_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_AUTHENTICATION_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_AUTHORIZATION_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_AUTHORIZATION_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_INTERNALSERVICE_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_INTERNALSERVICE_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_INVALIDSECURITY_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_INVALIDSECURITY_ERROR),
            WINDOWS_CE::MENROLL_E_DEVICE_UNKNOWN_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_UNKNOWN_ERROR),
            WINDOWS_CE::MENROLL_E_ENROLLMENT_IN_PROGRESS => RawError::Kind(WINDOWS_CE::MENROLL_E_ENROLLMENT_IN_PROGRESS),
            WINDOWS_CE::MENROLL_E_DEVICE_ALREADY_ENROLLED => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_ALREADY_ENROLLED),
            WINDOWS_CE::MENROLL_E_DEVICE_NOT_ENROLLED => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_NOT_ENROLLED),
            WINDOWS_CE::MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID => RawError::Kind(WINDOWS_CE::MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID),
            WINDOWS_CE::MENROLL_E_PASSWORD_NEEDED => RawError::Kind(WINDOWS_CE::MENROLL_E_PASSWORD_NEEDED),
            WINDOWS_CE::MENROLL_E_WAB_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_WAB_ERROR),
            WINDOWS_CE::MENROLL_E_CONNECTIVITY => RawError::Kind(WINDOWS_CE::MENROLL_E_CONNECTIVITY),
            WINDOWS_CE::MENROLL_E_INVALIDSSLCERT => RawError::Kind(WINDOWS_CE::MENROLL_E_INVALIDSSLCERT),
            WINDOWS_CE::MENROLL_E_DEVICECAPREACHED => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICECAPREACHED),
            WINDOWS_CE::MENROLL_E_DEVICENOTSUPPORTED => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICENOTSUPPORTED),
            WINDOWS_CE::MENROLL_E_NOT_SUPPORTED => RawError::Kind(WINDOWS_CE::MENROLL_E_NOT_SUPPORTED),
            WINDOWS_CE::MENROLL_E_NOTELIGIBLETORENEW => RawError::Kind(WINDOWS_CE::MENROLL_E_NOTELIGIBLETORENEW),
            WINDOWS_CE::MENROLL_E_INMAINTENANCE => RawError::Kind(WINDOWS_CE::MENROLL_E_INMAINTENANCE),
            WINDOWS_CE::MENROLL_E_USER_LICENSE => RawError::Kind(WINDOWS_CE::MENROLL_E_USER_LICENSE),
            WINDOWS_CE::MENROLL_E_ENROLLMENTDATAINVALID => RawError::Kind(WINDOWS_CE::MENROLL_E_ENROLLMENTDATAINVALID),
            WINDOWS_CE::MENROLL_E_INSECUREREDIRECT => RawError::Kind(WINDOWS_CE::MENROLL_E_INSECUREREDIRECT),
            WINDOWS_CE::MENROLL_E_PLATFORM_WRONG_STATE => RawError::Kind(WINDOWS_CE::MENROLL_E_PLATFORM_WRONG_STATE),
            WINDOWS_CE::MENROLL_E_PLATFORM_LICENSE_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_PLATFORM_LICENSE_ERROR),
            WINDOWS_CE::MENROLL_E_PLATFORM_UNKNOWN_ERROR => RawError::Kind(WINDOWS_CE::MENROLL_E_PLATFORM_UNKNOWN_ERROR),
            WINDOWS_CE::MENROLL_E_PROV_CSP_CERTSTORE => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_CSP_CERTSTORE),
            WINDOWS_CE::MENROLL_E_PROV_CSP_W7 => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_CSP_W7),
            WINDOWS_CE::MENROLL_E_PROV_CSP_DMCLIENT => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_CSP_DMCLIENT),
            WINDOWS_CE::MENROLL_E_PROV_CSP_PFW => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_CSP_PFW),
            WINDOWS_CE::MENROLL_E_PROV_CSP_MISC => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_CSP_MISC),
            WINDOWS_CE::MENROLL_E_PROV_UNKNOWN => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_UNKNOWN),
            WINDOWS_CE::MENROLL_E_PROV_SSLCERTNOTFOUND => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_SSLCERTNOTFOUND),
            WINDOWS_CE::MENROLL_E_PROV_CSP_APPMGMT => RawError::Kind(WINDOWS_CE::MENROLL_E_PROV_CSP_APPMGMT),
            WINDOWS_CE::MENROLL_E_DEVICE_MANAGEMENT_BLOCKED => RawError::Kind(WINDOWS_CE::MENROLL_E_DEVICE_MANAGEMENT_BLOCKED),
            WINDOWS_CE::MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED => RawError::Kind(WINDOWS_CE::MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED),
            WINDOWS_CE::MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT => RawError::Kind(WINDOWS_CE::MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT),
            WINDOWS_CE::MENROLL_E_EMPTY_MESSAGE => RawError::Kind(WINDOWS_CE::MENROLL_E_EMPTY_MESSAGE),
            WINDOWS_CE::MENROLL_E_USER_CANCELLED => RawError::Kind(WINDOWS_CE::MENROLL_E_USER_CANCELLED),
            WINDOWS_CE::MENROLL_E_MDM_NOT_CONFIGURED => RawError::Kind(WINDOWS_CE::MENROLL_E_MDM_NOT_CONFIGURED),
            WINDOWS_CE::DUA_ERR_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_BASE),
            WINDOWS_CE::DUA_E_NEWER_UPDATE_EXISTS => RawError::Kind(WINDOWS_CE::DUA_E_NEWER_UPDATE_EXISTS),
            WINDOWS_CE::DUA_E_UPDATE_ALREADY_IN_EVALUATION => RawError::Kind(WINDOWS_CE::DUA_E_UPDATE_ALREADY_IN_EVALUATION),
            WINDOWS_CE::DUA_E_DEPENDENT_UPDATE_MISSING => RawError::Kind(WINDOWS_CE::DUA_E_DEPENDENT_UPDATE_MISSING),
            WINDOWS_CE::DUA_E_DUPLICATE_ATTRIBUTE => RawError::Kind(WINDOWS_CE::DUA_E_DUPLICATE_ATTRIBUTE),
            WINDOWS_CE::DUA_E_MISSING_ATTRIBUTE => RawError::Kind(WINDOWS_CE::DUA_E_MISSING_ATTRIBUTE),
            WINDOWS_CE::DUA_E_INVALIDATTRIBUTEVALUE => RawError::Kind(WINDOWS_CE::DUA_E_INVALIDATTRIBUTEVALUE),
            WINDOWS_CE::DUA_E_XMLSTRINGTOOLONG => RawError::Kind(WINDOWS_CE::DUA_E_XMLSTRINGTOOLONG),
            WINDOWS_CE::DUA_E_ATTRIBUTE_MISMATCH => RawError::Kind(WINDOWS_CE::DUA_E_ATTRIBUTE_MISMATCH),
            WINDOWS_CE::DUA_E_OUT_OF_DISK_SPACE => RawError::Kind(WINDOWS_CE::DUA_E_OUT_OF_DISK_SPACE),
            WINDOWS_CE::DUA_E_CONNECTION_MANAGER => RawError::Kind(WINDOWS_CE::DUA_E_CONNECTION_MANAGER),
            WINDOWS_CE::DUA_E_INVALID_HASH => RawError::Kind(WINDOWS_CE::DUA_E_INVALID_HASH),
            WINDOWS_CE::DUA_E_INVALID_EULA => RawError::Kind(WINDOWS_CE::DUA_E_INVALID_EULA),
            WINDOWS_CE::DUA_E_INVALID_EXTENDED_UPDATE_INFO => RawError::Kind(WINDOWS_CE::DUA_E_INVALID_EXTENDED_UPDATE_INFO),
            WINDOWS_CE::DUA_E_MAX_SYNCUPDATES_CALLS => RawError::Kind(WINDOWS_CE::DUA_E_MAX_SYNCUPDATES_CALLS),
            WINDOWS_CE::DUA_E_AUTO_SCAN_OFF => RawError::Kind(WINDOWS_CE::DUA_E_AUTO_SCAN_OFF),
            WINDOWS_CE::DUA_E_XML_CONTENT_TOO_LARGE => RawError::Kind(WINDOWS_CE::DUA_E_XML_CONTENT_TOO_LARGE),
            WINDOWS_CE::DUA_E_SDCARD_REMOVED => RawError::Kind(WINDOWS_CE::DUA_E_SDCARD_REMOVED),
            WINDOWS_CE::DUA_E_SDCARD_DISABLED => RawError::Kind(WINDOWS_CE::DUA_E_SDCARD_DISABLED),
            WINDOWS_CE::DUA_E_SDCARD_HWFAILURE => RawError::Kind(WINDOWS_CE::DUA_E_SDCARD_HWFAILURE),
            WINDOWS_CE::DUA_E_SOAPFAULT_UNKNOWN => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_UNKNOWN),
            WINDOWS_CE::DUA_E_SOAPFAULT_COOKIEEXPIRED => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_COOKIEEXPIRED),
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDCOOKIE => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDCOOKIE),
            WINDOWS_CE::DUA_E_SOAPFAULT_CONFIGCHANGED => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_CONFIGCHANGED),
            WINDOWS_CE::DUA_E_SOAPFAULT_SERVERCHANGED => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_SERVERCHANGED),
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE),
            WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONREQUIRED => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONREQUIRED),
            WINDOWS_CE::DUA_E_SOAPFAULT_INTERNALSERVERERROR => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_INTERNALSERVERERROR),
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDpMETERS => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDpMETERS),
            WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED),
            WINDOWS_CE::DUA_E_SOAPFAULT_SERVERBUSY => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_SERVERBUSY),
            WINDOWS_CE::DUA_E_SOAPFAULT_FILELOCATIONCHANGED => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_FILELOCATIONCHANGED),
            WINDOWS_CE::DUA_E_SOAPFAULT_MALFORMED_MESSAGE => RawError::Kind(WINDOWS_CE::DUA_E_SOAPFAULT_MALFORMED_MESSAGE),
            WINDOWS_CE::DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED => RawError::Kind(WINDOWS_CE::DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED),
            WINDOWS_CE::DUA_ERR_REPORTINGERROR_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_REPORTINGERROR_BASE),
            WINDOWS_CE::DUA_E_REPORTINGFAILED => RawError::Kind(WINDOWS_CE::DUA_E_REPORTINGFAILED),
            WINDOWS_CE::DUA_E_INVALIDSAMPLINGRATE => RawError::Kind(WINDOWS_CE::DUA_E_INVALIDSAMPLINGRATE),
            WINDOWS_CE::DUA_ERR_CLIENTERROR_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_CLIENTERROR_BASE),
            WINDOWS_CE::DUA_E_CLIENT_INVALIDBUTTONID => RawError::Kind(WINDOWS_CE::DUA_E_CLIENT_INVALIDBUTTONID),
            WINDOWS_CE::DUA_E_CLIENT_REGKEY_INVALID => RawError::Kind(WINDOWS_CE::DUA_E_CLIENT_REGKEY_INVALID),
            WINDOWS_CE::DUA_E_CLIENT_PLUGINID_NOT_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_CLIENT_PLUGINID_NOT_FOUND),
            WINDOWS_CE::DUA_ERR_INSTALLATION_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_INSTALLATION_BASE),
            WINDOWS_CE::DUA_E_BATTERY_LOW => RawError::Kind(WINDOWS_CE::DUA_E_BATTERY_LOW),
            WINDOWS_CE::DUA_E_UPDATE_NOT_STAGED => RawError::Kind(WINDOWS_CE::DUA_E_UPDATE_NOT_STAGED),
            WINDOWS_CE::DUA_E_USS_UPDATE_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_USS_UPDATE_FOUND),
            WINDOWS_CE::DUA_E_INSTALL_INVALIDUPDATESTATE => RawError::Kind(WINDOWS_CE::DUA_E_INSTALL_INVALIDUPDATESTATE),
            WINDOWS_CE::DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN => RawError::Kind(WINDOWS_CE::DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN),
            WINDOWS_CE::DUA_E_UPDATE_NOT_COMMITTED => RawError::Kind(WINDOWS_CE::DUA_E_UPDATE_NOT_COMMITTED),
            WINDOWS_CE::DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED => RawError::Kind(WINDOWS_CE::DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED),
            WINDOWS_CE::DUA_ERR_DATA_MIGRATION_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_DATA_MIGRATION_BASE),
            WINDOWS_CE::DUA_E_COLD_BOOT_REQUIRED => RawError::Kind(WINDOWS_CE::DUA_E_COLD_BOOT_REQUIRED),
            WINDOWS_CE::DUA_ERR_UPDATE_STORE_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_UPDATE_STORE_BASE),
            WINDOWS_CE::DUA_E_UPDATE_NOT_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_UPDATE_NOT_FOUND),
            WINDOWS_CE::DUA_E_UPDATE_PROPERTY_NOT_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_UPDATE_PROPERTY_NOT_FOUND),
            WINDOWS_CE::DUA_E_UPDATE_ALREADY_EXISTS => RawError::Kind(WINDOWS_CE::DUA_E_UPDATE_ALREADY_EXISTS),
            WINDOWS_CE::DUA_E_EULA_ALREADY_EXISTS => RawError::Kind(WINDOWS_CE::DUA_E_EULA_ALREADY_EXISTS),
            WINDOWS_CE::DUA_E_EULA_NOT_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_EULA_NOT_FOUND),
            WINDOWS_CE::DUA_E_BUNDLE_NOT_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_BUNDLE_NOT_FOUND),
            WINDOWS_CE::DUA_E_EXTENDED_PROPERTY_NOT_FOUND => RawError::Kind(WINDOWS_CE::DUA_E_EXTENDED_PROPERTY_NOT_FOUND),
            WINDOWS_CE::DUA_E_GETEULA => RawError::Kind(WINDOWS_CE::DUA_E_GETEULA),
            WINDOWS_CE::DUA_ERR_SESSION_BASE => RawError::Kind(WINDOWS_CE::DUA_ERR_SESSION_BASE),
            WINDOWS_CE::DUA_E_INVALID_SESSIONID => RawError::Kind(WINDOWS_CE::DUA_E_INVALID_SESSIONID),
            WINDOWS_CE::DUA_E_DIFF_SESSION_IN_PROGRESS => RawError::Kind(WINDOWS_CE::DUA_E_DIFF_SESSION_IN_PROGRESS),
            WINDOWS_CE::DUA_E_NO_SESSION_IN_PROGRESS => RawError::Kind(WINDOWS_CE::DUA_E_NO_SESSION_IN_PROGRESS),
            WINDOWS_CE::DUA_E_CANNOT_CLOSE_SESSION => RawError::Kind(WINDOWS_CE::DUA_E_CANNOT_CLOSE_SESSION),
            WINDOWS_CE::DUA_E_ALL_RETRY_CONSUMED => RawError::Kind(WINDOWS_CE::DUA_E_ALL_RETRY_CONSUMED),
            WINDOWS_CE::DUA_E_SERVICE_IS_SHUTTING_DOWN => RawError::Kind(WINDOWS_CE::DUA_E_SERVICE_IS_SHUTTING_DOWN),
            WINDOWS_CE::DUA_E_SESSION_TIMEDOUT => RawError::Kind(WINDOWS_CE::DUA_E_SESSION_TIMEDOUT),
            WINDOWS_CE::DUA_E_DOWNLOAD_BASE => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_BASE),
            WINDOWS_CE::DUA_E_DOWNLOAD_NOT_CREATED => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_NOT_CREATED),
            WINDOWS_CE::DUA_E_DOWNLOAD_NOT_IDLE => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_NOT_IDLE),
            WINDOWS_CE::DUA_E_DOWNLOAD_USER_CANCELLED => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_USER_CANCELLED),
            WINDOWS_CE::DUA_E_DOWNLOAD_NEEDUSERAGREE => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_NEEDUSERAGREE),
            WINDOWS_CE::DUA_E_DOWNLOAD_NEEDOVERCELLULAR => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_NEEDOVERCELLULAR),
            WINDOWS_CE::DUA_E_DOWNLOAD_USERPOSTPONE => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_USERPOSTPONE),
            WINDOWS_CE::DUA_E_DOWNLOAD_ENGINEEXIT => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_ENGINEEXIT),
            WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD),
            WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE => RawError::Kind(WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE),
            WINDOWS_CE::DUA_E_CONNECTION_BASE => RawError::Kind(WINDOWS_CE::DUA_E_CONNECTION_BASE),
            WINDOWS_CE::DUA_E_NO_CONNECTIONS => RawError::Kind(WINDOWS_CE::DUA_E_NO_CONNECTIONS),
            WINDOWS_CE::DUA_E_CONNECTION_NOT_RELEASED => RawError::Kind(WINDOWS_CE::DUA_E_CONNECTION_NOT_RELEASED),
            WINDOWS_CE::DUA_E_CONNECTION_ACQUIRE_FAILED => RawError::Kind(WINDOWS_CE::DUA_E_CONNECTION_ACQUIRE_FAILED),
            WINDOWS_CE::DUA_E_DUAAPI_BASE => RawError::Kind(WINDOWS_CE::DUA_E_DUAAPI_BASE),
            WINDOWS_CE::DUA_E_DUAAPI_SHELLNOTREADY => RawError::Kind(WINDOWS_CE::DUA_E_DUAAPI_SHELLNOTREADY),
            WINDOWS_CE::BTS_ERR_BASE => RawError::Kind(WINDOWS_CE::BTS_ERR_BASE),
            WINDOWS_CE::E_CABAPI_NOT_CABINET => RawError::Kind(WINDOWS_CE::E_CABAPI_NOT_CABINET),
            WINDOWS_CE::E_CABAPI_UNKNOWN_FILE => RawError::Kind(WINDOWS_CE::E_CABAPI_UNKNOWN_FILE),
            WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR => RawError::Kind(WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR),
            WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED => RawError::Kind(WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED),
            WINDOWS_CE::E_CABAPI_FCI_OPEN_SRC => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_OPEN_SRC),
            WINDOWS_CE::E_CABAPI_FCI_READ_SRC => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_READ_SRC),
            WINDOWS_CE::E_CABAPI_FCI_ALLOC_FAIL => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_ALLOC_FAIL),
            WINDOWS_CE::E_CABAPI_FCI_TEMP_FILE => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_TEMP_FILE),
            WINDOWS_CE::E_CABAPI_FCI_BAD_COMPR_TYPE => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_BAD_COMPR_TYPE),
            WINDOWS_CE::E_CABAPI_FCI_CAB_FILE => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_CAB_FILE),
            WINDOWS_CE::E_CABAPI_FCI_USER_ABORT => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_USER_ABORT),
            WINDOWS_CE::E_CABAPI_FCI_MCI_FAIL => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_MCI_FAIL),
            WINDOWS_CE::E_CABAPI_FCI_CAB_FORMAT_LIMIT => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_CAB_FORMAT_LIMIT),
            WINDOWS_CE::E_CABAPI_FCI_INVALID_FILE_PATH => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_INVALID_FILE_PATH),
            WINDOWS_CE::E_CABAPI_FCI_DUPLICATE_FILE => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_DUPLICATE_FILE),
            WINDOWS_CE::E_CABAPI_FCI_UNKNOWN => RawError::Kind(WINDOWS_CE::E_CABAPI_FCI_UNKNOWN),
            WINDOWS_CE::CABAPI_ERR_FDI_BASE => RawError::Kind(WINDOWS_CE::CABAPI_ERR_FDI_BASE),
            WINDOWS_CE::E_CABAPI_FDI_CABINET_NOT_FOUND => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_CABINET_NOT_FOUND),
            WINDOWS_CE::E_CABAPI_FDI_NOT_A_CABINET => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_NOT_A_CABINET),
            WINDOWS_CE::E_CABAPI_FDI_UNKNOWN_CABINET_VERSION => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_UNKNOWN_CABINET_VERSION),
            WINDOWS_CE::E_CABAPI_FDI_CORRUPT_CABINET => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_CORRUPT_CABINET),
            WINDOWS_CE::E_CABAPI_FDI_ALLOC_FAIL => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_ALLOC_FAIL),
            WINDOWS_CE::E_CABAPI_FDI_BAD_COMPR_TYPE => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_BAD_COMPR_TYPE),
            WINDOWS_CE::E_CABAPI_FDI_MDI_FAIL => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_MDI_FAIL),
            WINDOWS_CE::E_CABAPI_FDI_TARGET_FILE => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_TARGET_FILE),
            WINDOWS_CE::E_CABAPI_FDI_RESERVE_MISMATCH => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_RESERVE_MISMATCH),
            WINDOWS_CE::E_CABAPI_FDI_WRONG_CABINET => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_WRONG_CABINET),
            WINDOWS_CE::E_CABAPI_FDI_USER_ABORT => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_USER_ABORT),
            WINDOWS_CE::E_CABAPI_FDI_UNKNOWN => RawError::Kind(WINDOWS_CE::E_CABAPI_FDI_UNKNOWN),
            WINDOWS_CE::IMGUPD_ERROR_BASE => RawError::Kind(WINDOWS_CE::IMGUPD_ERROR_BASE),
            WINDOWS_CE::E_BASE_PACKAGE_NOT_INSTALLED => RawError::Kind(WINDOWS_CE::E_BASE_PACKAGE_NOT_INSTALLED),
            WINDOWS_CE::E_PACKAGE_ALREADY_INSTALLED => RawError::Kind(WINDOWS_CE::E_PACKAGE_ALREADY_INSTALLED),
            WINDOWS_CE::E_NO_UPDATE_PATH_TO_TARGET => RawError::Kind(WINDOWS_CE::E_NO_UPDATE_PATH_TO_TARGET),
            WINDOWS_CE::E_MULTIPLE_UPDATE_PATHS_FOUND => RawError::Kind(WINDOWS_CE::E_MULTIPLE_UPDATE_PATHS_FOUND),
            WINDOWS_CE::E_DUPLICATE_UPDATE_PACKAGE => RawError::Kind(WINDOWS_CE::E_DUPLICATE_UPDATE_PACKAGE),
            WINDOWS_CE::E_FILE_COLLISION => RawError::Kind(WINDOWS_CE::E_FILE_COLLISION),
            WINDOWS_CE::E_INVALID_PACKAGE => RawError::Kind(WINDOWS_CE::E_INVALID_PACKAGE),
            WINDOWS_CE::E_INSUFFICIENT_SPACE_FOR_UPDATE => RawError::Kind(WINDOWS_CE::E_INSUFFICIENT_SPACE_FOR_UPDATE),
            WINDOWS_CE::E_REGISTRY_COLLISION => RawError::Kind(WINDOWS_CE::E_REGISTRY_COLLISION),
            WINDOWS_CE::E_INVALID_REGISTRY_FILE => RawError::Kind(WINDOWS_CE::E_INVALID_REGISTRY_FILE),
            WINDOWS_CE::E_DEPCRECATED1 => RawError::Kind(WINDOWS_CE::E_DEPCRECATED1),
            WINDOWS_CE::E_TARGET_NOT_APPLICABLE => RawError::Kind(WINDOWS_CE::E_TARGET_NOT_APPLICABLE),
            WINDOWS_CE::E_PACKAGE_HIGHER_VERSION_INSTALLED => RawError::Kind(WINDOWS_CE::E_PACKAGE_HIGHER_VERSION_INSTALLED),
            WINDOWS_CE::E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION => RawError::Kind(WINDOWS_CE::E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION),
            WINDOWS_CE::E_DIFF_SOURCEVERSION_DOES_NOT_MATCH => RawError::Kind(WINDOWS_CE::E_DIFF_SOURCEVERSION_DOES_NOT_MATCH),
            WINDOWS_CE::E_STAGED_FILE_NOT_FOUND => RawError::Kind(WINDOWS_CE::E_STAGED_FILE_NOT_FOUND),
            WINDOWS_CE::E_PACKAGE_TARGETS_WRONG_CPU => RawError::Kind(WINDOWS_CE::E_PACKAGE_TARGETS_WRONG_CPU),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WINDOWS_CE::MENROLL_S_ENROLLMENT_SUSPENDED => "Enrollment was suspended.",
            WINDOWS_CE::MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR => "Invalid message from the Mobile Device Management (MDM) server.",
            WINDOWS_CE::MENROLL_E_DEVICE_AUTHENTICATION_ERROR => "The Mobile Device Management (MDM) server failed to authenticate the user. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICE_AUTHORIZATION_ERROR => "The user is not authorized to enroll to Mobile Device Management (MDM). Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR => "The user has no permission for the certificate template or the certificate authority is unreachable. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR => "The Mobile Device Management (MDM) server encountered an error. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICE_INTERNALSERVICE_ERROR => "There was an unhandled exception on the Mobile Device Management (MDM) server. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICE_INVALIDSECURITY_ERROR => "The Mobile Device Management (MDM) server was not able to validate your account. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICE_UNKNOWN_ERROR => "Unknown Mobile Device Management (MDM) server error. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_ENROLLMENT_IN_PROGRESS => "Another enrollment operation is currently in progress.",
            WINDOWS_CE::MENROLL_E_DEVICE_ALREADY_ENROLLED => "The device is already enrolled.",
            WINDOWS_CE::MENROLL_E_DEVICE_NOT_ENROLLED => "Windows MDE: Device is not enrolled.",
            WINDOWS_CE::MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID => "There was a Mobile Device Management (MDM) certificate error. The security certificate date is invalid. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_PASSWORD_NEEDED => "A password is required to authenticate your account or device, but was not supplied. Please try again.",
            WINDOWS_CE::MENROLL_E_WAB_ERROR => "There was a problem authenticating your account or device. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_CONNECTIVITY => "There was a network error communicating with the Mobile Device Management (MDM) server. Please try again.",
            WINDOWS_CE::MENROLL_E_INVALIDSSLCERT => "There was a Mobile Device Management (MDM) certificate error. Try again or contact your system administrator.",
            WINDOWS_CE::MENROLL_E_DEVICECAPREACHED => "The account has too many devices enrolled to Mobile Device Management (MDM). Delete or unenroll old devices to fix this error.",
            WINDOWS_CE::MENROLL_E_DEVICENOTSUPPORTED => "The Mobile Device Management (MDM) server doesn't support this platform or version, consider upgrading your device.",
            WINDOWS_CE::MENROLL_E_NOT_SUPPORTED => "Mobile Device Management (MDM) is generally not supported for this device.",
            WINDOWS_CE::MENROLL_E_NOTELIGIBLETORENEW => "The device is attempting to renew the Mobile Device Management (MDM) certificate, but the server rejected the request. Check renew schedule on the device.",
            WINDOWS_CE::MENROLL_E_INMAINTENANCE => "The Mobile Device Management (MDM) server states your account is in maintenance, try again later.",
            WINDOWS_CE::MENROLL_E_USER_LICENSE => "There was an error with your Mobile Device Management (MDM) user license. Contact your system administrator.",
            WINDOWS_CE::MENROLL_E_ENROLLMENTDATAINVALID => "The Mobile Device Management (MDM) server rejected the enrollment data. The server may not be configured correctly.",
            WINDOWS_CE::MENROLL_E_INSECUREREDIRECT => "The server requested HTTP rather than HTTPS but it was not accepted.",
            WINDOWS_CE::MENROLL_E_PLATFORM_WRONG_STATE => "An invalid operation was attempted, such as trying to enroll the same device twice or unenroll an unknown device.",
            WINDOWS_CE::MENROLL_E_PLATFORM_LICENSE_ERROR => "The version of Windows installed on the client does not support this enrollment type.",
            WINDOWS_CE::MENROLL_E_PLATFORM_UNKNOWN_ERROR => "An error occurred on the client.",
            WINDOWS_CE::MENROLL_E_PROV_CSP_CERTSTORE => "Provisioning failed in the certificate store CSP.",
            WINDOWS_CE::MENROLL_E_PROV_CSP_W7 => "Provisioning failed in a W7/DMAcc CSP.",
            WINDOWS_CE::MENROLL_E_PROV_CSP_DMCLIENT => "Provisioning failed in the DM client CSP.",
            WINDOWS_CE::MENROLL_E_PROV_CSP_PFW => "Provisioning failed in the Passport for Work CSP.",
            WINDOWS_CE::MENROLL_E_PROV_CSP_MISC => "Provisioning failed in an unspecified CSP.",
            WINDOWS_CE::MENROLL_E_PROV_UNKNOWN => "Provisioning failed, but a specific CSP is not indicated.",
            WINDOWS_CE::MENROLL_E_PROV_SSLCERTNOTFOUND => "When attempting to bind the public cert/private key, the public cert was not found either: when attempting to bind the public cert/private key, or when looking into provisioning payload.",
            WINDOWS_CE::MENROLL_E_PROV_CSP_APPMGMT => "Provisioning failed in the EnterpriseAppManagement CSP.",
            WINDOWS_CE::MENROLL_E_DEVICE_MANAGEMENT_BLOCKED => "Mobile Device Management (MDM) was blocked, possibly by Group Policy or the local management agent.",
            WINDOWS_CE::MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED => "Failed to create the private key.",
            WINDOWS_CE::MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT => "Certificate Authentication was requested, but failed to find a certificate to use.",
            WINDOWS_CE::MENROLL_E_EMPTY_MESSAGE => "The server responded with HTTP 200, but the message was empty.",
            WINDOWS_CE::MENROLL_E_USER_CANCELLED => "The user canceled the operation.",
            WINDOWS_CE::MENROLL_E_MDM_NOT_CONFIGURED => "Mobile Device Management (MDM) is not configured.",
            WINDOWS_CE::DUA_ERR_BASE => "This is a DUA error base and not a real error code.",
            WINDOWS_CE::DUA_E_NEWER_UPDATE_EXISTS => "An update with a higher revision number exists.",
            WINDOWS_CE::DUA_E_UPDATE_ALREADY_IN_EVALUATION => "An update is being updated while asking for evaluation.",
            WINDOWS_CE::DUA_E_DEPENDENT_UPDATE_MISSING => "A dependent update is missing.",
            WINDOWS_CE::DUA_E_DUPLICATE_ATTRIBUTE => "An attribute is specified more than once.",
            WINDOWS_CE::DUA_E_MISSING_ATTRIBUTE => "A required attribute is not found.",
            WINDOWS_CE::DUA_E_INVALIDATTRIBUTEVALUE => "Attribute value is invalid.",
            WINDOWS_CE::DUA_E_XMLSTRINGTOOLONG => "String/text is too long",
            WINDOWS_CE::DUA_E_ATTRIBUTE_MISMATCH => "Attribute mismatch",
            WINDOWS_CE::DUA_E_OUT_OF_DISK_SPACE => "Not enough disk space for the operation.",
            WINDOWS_CE::DUA_E_CONNECTION_MANAGER => "Call to Connection Manager API failed.",
            WINDOWS_CE::DUA_E_INVALID_HASH => "Given hash is not match to the hash generated from file.",
            WINDOWS_CE::DUA_E_INVALID_EULA => "An invalid or missing EULA was detected.",
            WINDOWS_CE::DUA_E_INVALID_EXTENDED_UPDATE_INFO => "Invalid extended update info was detected.",
            WINDOWS_CE::DUA_E_MAX_SYNCUPDATES_CALLS => "SyncUpdate call reaches the maximum scan limit.",
            WINDOWS_CE::DUA_E_AUTO_SCAN_OFF => "Scan cannot run because auto scan is turned off.",
            WINDOWS_CE::DUA_E_XML_CONTENT_TOO_LARGE => "XML content in string is larger than maximum allowed.",
            WINDOWS_CE::DUA_E_SDCARD_REMOVED => "An SD card was removed during update after the download was started to the SD card.",
            WINDOWS_CE::DUA_E_SDCARD_DISABLED => "The SD card is disabled by policy.",
            WINDOWS_CE::DUA_E_SDCARD_HWFAILURE => "The SD card hardware failed.",
            WINDOWS_CE::DUA_E_SOAPFAULT_UNKNOWN => "Unknown SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_COOKIEEXPIRED => "CookieExpired SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDCOOKIE => "InvalidCookie SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_CONFIGCHANGED => "ConfigChanged SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_SERVERCHANGED => "ServerChanged SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE => "InvalidAuthorizationCookie SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONREQUIRED => "RegistrationRequired SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_INTERNALSERVERERROR => "InternalServerError SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDpMETERS => "Invalidpmeters SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED => "RegistrationNotRequired SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_SERVERBUSY => "ServerBusy SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_FILELOCATIONCHANGED => "FileLocationChanged SOAP fault",
            WINDOWS_CE::DUA_E_SOAPFAULT_MALFORMED_MESSAGE => "Malformed SOAP message",
            WINDOWS_CE::DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED => "Failed to download content from the server.",
            WINDOWS_CE::DUA_ERR_REPORTINGERROR_BASE => "Definition. The error code itself actually not used.",
            WINDOWS_CE::DUA_E_REPORTINGFAILED => "ReportEventBatch web service call returned FALSE",
            WINDOWS_CE::DUA_E_INVALIDSAMPLINGRATE => "Sampling rate in redirect cab is zero.",
            WINDOWS_CE::DUA_ERR_CLIENTERROR_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_CLIENT_INVALIDBUTTONID => "The invalid button ID is used.",
            WINDOWS_CE::DUA_E_CLIENT_REGKEY_INVALID => "Registry key value is not valid.",
            WINDOWS_CE::DUA_E_CLIENT_PLUGINID_NOT_FOUND => "The plugin ID was not found.",
            WINDOWS_CE::DUA_ERR_INSTALLATION_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_BATTERY_LOW => "Cannot stage update because battery is low.",
            WINDOWS_CE::DUA_E_UPDATE_NOT_STAGED => "Update not staged.",
            WINDOWS_CE::DUA_E_USS_UPDATE_FOUND => "A USS update was detected",
            WINDOWS_CE::DUA_E_INSTALL_INVALIDUPDATESTATE => "Update was not committed",
            WINDOWS_CE::DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN => "Image Update Commit API unexpectedly returned S_OK.",
            WINDOWS_CE::DUA_E_UPDATE_NOT_COMMITTED => "Device rebooted before IU Commit was called.",
            WINDOWS_CE::DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED => "A USS update was installed and a reboot is required for it to take effect.",
            WINDOWS_CE::DUA_ERR_DATA_MIGRATION_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_COLD_BOOT_REQUIRED => "A data migrator failed and requested a cold boot.",
            WINDOWS_CE::DUA_ERR_UPDATE_STORE_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_UPDATE_NOT_FOUND => "Update not found.",
            WINDOWS_CE::DUA_E_UPDATE_PROPERTY_NOT_FOUND => "Update property not found.",
            WINDOWS_CE::DUA_E_UPDATE_ALREADY_EXISTS => "Update already exists.",
            WINDOWS_CE::DUA_E_EULA_ALREADY_EXISTS => "EULA already exists",
            WINDOWS_CE::DUA_E_EULA_NOT_FOUND => "EULA not found.",
            WINDOWS_CE::DUA_E_BUNDLE_NOT_FOUND => "Bundle not found.",
            WINDOWS_CE::DUA_E_EXTENDED_PROPERTY_NOT_FOUND => "Extended property not found.",
            WINDOWS_CE::DUA_E_GETEULA => "GetEULAs call failed.",
            WINDOWS_CE::DUA_ERR_SESSION_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_INVALID_SESSIONID => "The specified DuaSessionID is not valid.",
            WINDOWS_CE::DUA_E_DIFF_SESSION_IN_PROGRESS => "There is a DUA session already in progress with a different DuaSessionID.",
            WINDOWS_CE::DUA_E_NO_SESSION_IN_PROGRESS => "There is no DUA session in progress.",
            WINDOWS_CE::DUA_E_CANNOT_CLOSE_SESSION => "We cannot close this session because a client has successfully joined the current session.",
            WINDOWS_CE::DUA_E_ALL_RETRY_CONSUMED => "All retries are consumed.",
            WINDOWS_CE::DUA_E_SERVICE_IS_SHUTTING_DOWN => "Service is shutting down and requested operation can't be performed.",
            WINDOWS_CE::DUA_E_SESSION_TIMEDOUT => "The active session has timed out.",
            WINDOWS_CE::DUA_E_DOWNLOAD_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_DOWNLOAD_NOT_CREATED => "The download request has not been created.",
            WINDOWS_CE::DUA_E_DOWNLOAD_NOT_IDLE => "Update Download Manager is not ready yet.",
            WINDOWS_CE::DUA_E_DOWNLOAD_USER_CANCELLED => "Update Download is cancelled by user.",
            WINDOWS_CE::DUA_E_DOWNLOAD_NEEDUSERAGREE => "Need user to agree to proceed with download.",
            WINDOWS_CE::DUA_E_DOWNLOAD_NEEDOVERCELLULAR => "Need user agreement to download updates via cellular.",
            WINDOWS_CE::DUA_E_DOWNLOAD_USERPOSTPONE => "User postponed download",
            WINDOWS_CE::DUA_E_DOWNLOAD_ENGINEEXIT => "Download handler is stopped to wait for BTS status due to engine exit.",
            WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD => "Not enough internal space for download and the SD slot is empty.",
            WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE => "Not enough space for download on both internal storage and SD slot.",
            WINDOWS_CE::DUA_E_CONNECTION_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_NO_CONNECTIONS => "Connection Manager could not find a candidate connection.",
            WINDOWS_CE::DUA_E_CONNECTION_NOT_RELEASED => "Connection Manager failed because an acquired connection was not released.",
            WINDOWS_CE::DUA_E_CONNECTION_ACQUIRE_FAILED => "Connection Manager failed to acquire a connection.",
            WINDOWS_CE::DUA_E_DUAAPI_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::DUA_E_DUAAPI_SHELLNOTREADY => "WNF_SHL_START_READY is not ready yet.",
            WINDOWS_CE::BTS_ERR_BASE => "Base for CAPAPI; BTS errors.",
            WINDOWS_CE::E_CABAPI_NOT_CABINET => "BTS_E_PER_APP_REQUEST_LIMIT_REACHED",
            WINDOWS_CE::E_CABAPI_UNKNOWN_FILE => "BTS_E_UNABLE_TO_ENQUEUE_REQUEST",
            WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR => "BTS_E_HTTP_PROVIDER_ERROR",
            WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED => "BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED .",
            WINDOWS_CE::E_CABAPI_FCI_OPEN_SRC => "BTS_E_HTTP_PROVIDER_ERROR_NETWORK",
            WINDOWS_CE::E_CABAPI_FCI_READ_SRC => "BTS_E_HTTP_PROVIDER_ERROR_SLOW_TRANSFER",
            WINDOWS_CE::E_CABAPI_FCI_ALLOC_FAIL => "BTS_E_HTTP_PROVIDER_ERROR_INVALID_pMETER.",
            WINDOWS_CE::E_CABAPI_FCI_TEMP_FILE => "BTS_W_TRANSFER_WAITING_BATTERY_SAVER_MODE",
            WINDOWS_CE::E_CABAPI_FCI_BAD_COMPR_TYPE => "BTS_W_SHUTTING_DOWN",
            WINDOWS_CE::E_CABAPI_FCI_CAB_FILE => "BTS_E_API_FAILED_DUE_TO_SHUTDOWN",
            WINDOWS_CE::E_CABAPI_FCI_USER_ABORT => "FCI: aborted",
            WINDOWS_CE::E_CABAPI_FCI_MCI_FAIL => "FCI: Failure compressing data",
            WINDOWS_CE::E_CABAPI_FCI_CAB_FORMAT_LIMIT => "FCI: Data-size or file-count exceeded CAB format limits.",
            WINDOWS_CE::E_CABAPI_FCI_INVALID_FILE_PATH => "FCI: File path is empty or invalid",
            WINDOWS_CE::E_CABAPI_FCI_DUPLICATE_FILE => "FCI: Either a file is being added twice to the CAB; or two source files have the same target path",
            WINDOWS_CE::E_CABAPI_FCI_UNKNOWN => "FCI: An unknown error.",
            WINDOWS_CE::CABAPI_ERR_FDI_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::E_CABAPI_FDI_CABINET_NOT_FOUND => "FDI: the cabinet file was not found.",
            WINDOWS_CE::E_CABAPI_FDI_NOT_A_CABINET => "FDI: The cabinet file does not have the correct format.",
            WINDOWS_CE::E_CABAPI_FDI_UNKNOWN_CABINET_VERSION => "FDI: The cabinet file has an unknown version number.",
            WINDOWS_CE::E_CABAPI_FDI_CORRUPT_CABINET => "FDI: The cabinet file is corrupt.",
            WINDOWS_CE::E_CABAPI_FDI_ALLOC_FAIL => "FDI: Insufficient memory.",
            WINDOWS_CE::E_CABAPI_FDI_BAD_COMPR_TYPE => "FDI: Unknown compression type used in the cabinet folder.",
            WINDOWS_CE::E_CABAPI_FDI_MDI_FAIL => "FDI: Failure decompressing data from the cabinet file.",
            WINDOWS_CE::E_CABAPI_FDI_TARGET_FILE => "Failure writing to the target file. This could be that the device is out of space.",
            WINDOWS_CE::E_CABAPI_FDI_RESERVE_MISMATCH => "FDI: The cabinets within a set do not have the same RESERVE sizes.",
            WINDOWS_CE::E_CABAPI_FDI_WRONG_CABINET => "FDI: The cabinet returned by fdintNEXT_CABINET is incorrect.",
            WINDOWS_CE::E_CABAPI_FDI_USER_ABORT => "FDI: FDI aborted.",
            WINDOWS_CE::E_CABAPI_FDI_UNKNOWN => "FDI: An unknown error.",
            WINDOWS_CE::IMGUPD_ERROR_BASE => "Definition; the error code itself actually not used.",
            WINDOWS_CE::E_BASE_PACKAGE_NOT_INSTALLED => "The base package DSM file was not found in the DSM files store.",
            WINDOWS_CE::E_PACKAGE_ALREADY_INSTALLED => "Package cannot be installed because it is already present on the image",
            WINDOWS_CE::E_NO_UPDATE_PATH_TO_TARGET => "An update path to highest target version could not be found.",
            WINDOWS_CE::E_MULTIPLE_UPDATE_PATHS_FOUND => "Multiple update paths to highest target version exist.",
            WINDOWS_CE::E_DUPLICATE_UPDATE_PACKAGE => "Duplicate packages found in update set.",
            WINDOWS_CE::E_FILE_COLLISION => "More than one package targeted for the same partition contained the same file",
            WINDOWS_CE::E_INVALID_PACKAGE => "Package DSM; or contents are invalid",
            WINDOWS_CE::E_INSUFFICIENT_SPACE_FOR_UPDATE => "Not enough space available in one or more partitions to complete update",
            WINDOWS_CE::E_REGISTRY_COLLISION => "Two or more packages have registry settings that conflict",
            WINDOWS_CE::E_INVALID_REGISTRY_FILE => "A registry file included in the package is invalid",
            WINDOWS_CE::E_DEPCRECATED1 => "Deprecated",
            WINDOWS_CE::E_TARGET_NOT_APPLICABLE => "This package has the target field set but this device is not part of any groups specified in the target.",
            WINDOWS_CE::E_PACKAGE_HIGHER_VERSION_INSTALLED => "This package cannot be installed because a newer version is already installed on the device.",
            WINDOWS_CE::E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION => "This package is a removal package targeted to a binary parition Binary partition packages cannot be deleted.",
            WINDOWS_CE::E_DIFF_SOURCEVERSION_DOES_NOT_MATCH => "This package is a diff that targets a source version that is not the one on the device.",
            WINDOWS_CE::E_STAGED_FILE_NOT_FOUND => "A file that was expected to be staged is missing from the staging area.",
            WINDOWS_CE::E_PACKAGE_TARGETS_WRONG_CPU => "The device's CPU type does not match the package's targeted CPU.",
        }
    }

    pub fn from_name(name: &str) -> WINDOWS_CE {
        return match name {
            "MENROLL_S_ENROLLMENT_SUSPENDED" => WINDOWS_CE::MENROLL_S_ENROLLMENT_SUSPENDED,
            "MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR,
            "MENROLL_E_DEVICE_AUTHENTICATION_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_AUTHENTICATION_ERROR,
            "MENROLL_E_DEVICE_AUTHORIZATION_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_AUTHORIZATION_ERROR,
            "MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR,
            "MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR,
            "MENROLL_E_DEVICE_INTERNALSERVICE_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_INTERNALSERVICE_ERROR,
            "MENROLL_E_DEVICE_INVALIDSECURITY_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_INVALIDSECURITY_ERROR,
            "MENROLL_E_DEVICE_UNKNOWN_ERROR" => WINDOWS_CE::MENROLL_E_DEVICE_UNKNOWN_ERROR,
            "MENROLL_E_ENROLLMENT_IN_PROGRESS" => WINDOWS_CE::MENROLL_E_ENROLLMENT_IN_PROGRESS,
            "MENROLL_E_DEVICE_ALREADY_ENROLLED" => WINDOWS_CE::MENROLL_E_DEVICE_ALREADY_ENROLLED,
            "MENROLL_E_DEVICE_NOT_ENROLLED" => WINDOWS_CE::MENROLL_E_DEVICE_NOT_ENROLLED,
            "MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID" => WINDOWS_CE::MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID,
            "MENROLL_E_PASSWORD_NEEDED" => WINDOWS_CE::MENROLL_E_PASSWORD_NEEDED,
            "MENROLL_E_WAB_ERROR" => WINDOWS_CE::MENROLL_E_WAB_ERROR,
            "MENROLL_E_CONNECTIVITY" => WINDOWS_CE::MENROLL_E_CONNECTIVITY,
            "MENROLL_E_INVALIDSSLCERT" => WINDOWS_CE::MENROLL_E_INVALIDSSLCERT,
            "MENROLL_E_DEVICECAPREACHED" => WINDOWS_CE::MENROLL_E_DEVICECAPREACHED,
            "MENROLL_E_DEVICENOTSUPPORTED" => WINDOWS_CE::MENROLL_E_DEVICENOTSUPPORTED,
            "MENROLL_E_NOT_SUPPORTED" => WINDOWS_CE::MENROLL_E_NOT_SUPPORTED,
            "MENROLL_E_NOTELIGIBLETORENEW" => WINDOWS_CE::MENROLL_E_NOTELIGIBLETORENEW,
            "MENROLL_E_INMAINTENANCE" => WINDOWS_CE::MENROLL_E_INMAINTENANCE,
            "MENROLL_E_USER_LICENSE" => WINDOWS_CE::MENROLL_E_USER_LICENSE,
            "MENROLL_E_ENROLLMENTDATAINVALID" => WINDOWS_CE::MENROLL_E_ENROLLMENTDATAINVALID,
            "MENROLL_E_INSECUREREDIRECT" => WINDOWS_CE::MENROLL_E_INSECUREREDIRECT,
            "MENROLL_E_PLATFORM_WRONG_STATE" => WINDOWS_CE::MENROLL_E_PLATFORM_WRONG_STATE,
            "MENROLL_E_PLATFORM_LICENSE_ERROR" => WINDOWS_CE::MENROLL_E_PLATFORM_LICENSE_ERROR,
            "MENROLL_E_PLATFORM_UNKNOWN_ERROR" => WINDOWS_CE::MENROLL_E_PLATFORM_UNKNOWN_ERROR,
            "MENROLL_E_PROV_CSP_CERTSTORE" => WINDOWS_CE::MENROLL_E_PROV_CSP_CERTSTORE,
            "MENROLL_E_PROV_CSP_W7" => WINDOWS_CE::MENROLL_E_PROV_CSP_W7,
            "MENROLL_E_PROV_CSP_DMCLIENT" => WINDOWS_CE::MENROLL_E_PROV_CSP_DMCLIENT,
            "MENROLL_E_PROV_CSP_PFW" => WINDOWS_CE::MENROLL_E_PROV_CSP_PFW,
            "MENROLL_E_PROV_CSP_MISC" => WINDOWS_CE::MENROLL_E_PROV_CSP_MISC,
            "MENROLL_E_PROV_UNKNOWN" => WINDOWS_CE::MENROLL_E_PROV_UNKNOWN,
            "MENROLL_E_PROV_SSLCERTNOTFOUND" => WINDOWS_CE::MENROLL_E_PROV_SSLCERTNOTFOUND,
            "MENROLL_E_PROV_CSP_APPMGMT" => WINDOWS_CE::MENROLL_E_PROV_CSP_APPMGMT,
            "MENROLL_E_DEVICE_MANAGEMENT_BLOCKED" => WINDOWS_CE::MENROLL_E_DEVICE_MANAGEMENT_BLOCKED,
            "MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED" => WINDOWS_CE::MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED,
            "MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT" => WINDOWS_CE::MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT,
            "MENROLL_E_EMPTY_MESSAGE" => WINDOWS_CE::MENROLL_E_EMPTY_MESSAGE,
            "MENROLL_E_USER_CANCELLED" => WINDOWS_CE::MENROLL_E_USER_CANCELLED,
            "MENROLL_E_MDM_NOT_CONFIGURED" => WINDOWS_CE::MENROLL_E_MDM_NOT_CONFIGURED,
            "DUA_ERR_BASE" => WINDOWS_CE::DUA_ERR_BASE,
            "DUA_E_NEWER_UPDATE_EXISTS" => WINDOWS_CE::DUA_E_NEWER_UPDATE_EXISTS,
            "DUA_E_UPDATE_ALREADY_IN_EVALUATION" => WINDOWS_CE::DUA_E_UPDATE_ALREADY_IN_EVALUATION,
            "DUA_E_DEPENDENT_UPDATE_MISSING" => WINDOWS_CE::DUA_E_DEPENDENT_UPDATE_MISSING,
            "DUA_E_DUPLICATE_ATTRIBUTE" => WINDOWS_CE::DUA_E_DUPLICATE_ATTRIBUTE,
            "DUA_E_MISSING_ATTRIBUTE" => WINDOWS_CE::DUA_E_MISSING_ATTRIBUTE,
            "DUA_E_INVALIDATTRIBUTEVALUE" => WINDOWS_CE::DUA_E_INVALIDATTRIBUTEVALUE,
            "DUA_E_XMLSTRINGTOOLONG" => WINDOWS_CE::DUA_E_XMLSTRINGTOOLONG,
            "DUA_E_ATTRIBUTE_MISMATCH" => WINDOWS_CE::DUA_E_ATTRIBUTE_MISMATCH,
            "DUA_E_OUT_OF_DISK_SPACE" => WINDOWS_CE::DUA_E_OUT_OF_DISK_SPACE,
            "DUA_E_CONNECTION_MANAGER" => WINDOWS_CE::DUA_E_CONNECTION_MANAGER,
            "DUA_E_INVALID_HASH" => WINDOWS_CE::DUA_E_INVALID_HASH,
            "DUA_E_INVALID_EULA" => WINDOWS_CE::DUA_E_INVALID_EULA,
            "DUA_E_INVALID_EXTENDED_UPDATE_INFO" => WINDOWS_CE::DUA_E_INVALID_EXTENDED_UPDATE_INFO,
            "DUA_E_MAX_SYNCUPDATES_CALLS" => WINDOWS_CE::DUA_E_MAX_SYNCUPDATES_CALLS,
            "DUA_E_AUTO_SCAN_OFF" => WINDOWS_CE::DUA_E_AUTO_SCAN_OFF,
            "DUA_E_XML_CONTENT_TOO_LARGE" => WINDOWS_CE::DUA_E_XML_CONTENT_TOO_LARGE,
            "DUA_E_SDCARD_REMOVED" => WINDOWS_CE::DUA_E_SDCARD_REMOVED,
            "DUA_E_SDCARD_DISABLED" => WINDOWS_CE::DUA_E_SDCARD_DISABLED,
            "DUA_E_SDCARD_HWFAILURE" => WINDOWS_CE::DUA_E_SDCARD_HWFAILURE,
            "DUA_E_SOAPFAULT_UNKNOWN" => WINDOWS_CE::DUA_E_SOAPFAULT_UNKNOWN,
            "DUA_E_SOAPFAULT_COOKIEEXPIRED" => WINDOWS_CE::DUA_E_SOAPFAULT_COOKIEEXPIRED,
            "DUA_E_SOAPFAULT_INVALIDCOOKIE" => WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDCOOKIE,
            "DUA_E_SOAPFAULT_CONFIGCHANGED" => WINDOWS_CE::DUA_E_SOAPFAULT_CONFIGCHANGED,
            "DUA_E_SOAPFAULT_SERVERCHANGED" => WINDOWS_CE::DUA_E_SOAPFAULT_SERVERCHANGED,
            "DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE" => WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE,
            "DUA_E_SOAPFAULT_REGISTRATIONREQUIRED" => WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONREQUIRED,
            "DUA_E_SOAPFAULT_INTERNALSERVERERROR" => WINDOWS_CE::DUA_E_SOAPFAULT_INTERNALSERVERERROR,
            "DUA_E_SOAPFAULT_INVALIDpMETERS" => WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDpMETERS,
            "DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED" => WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED,
            "DUA_E_SOAPFAULT_SERVERBUSY" => WINDOWS_CE::DUA_E_SOAPFAULT_SERVERBUSY,
            "DUA_E_SOAPFAULT_FILELOCATIONCHANGED" => WINDOWS_CE::DUA_E_SOAPFAULT_FILELOCATIONCHANGED,
            "DUA_E_SOAPFAULT_MALFORMED_MESSAGE" => WINDOWS_CE::DUA_E_SOAPFAULT_MALFORMED_MESSAGE,
            "DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED" => WINDOWS_CE::DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED,
            "DUA_ERR_REPORTINGERROR_BASE" => WINDOWS_CE::DUA_ERR_REPORTINGERROR_BASE,
            "DUA_E_REPORTINGFAILED" => WINDOWS_CE::DUA_E_REPORTINGFAILED,
            "DUA_E_INVALIDSAMPLINGRATE" => WINDOWS_CE::DUA_E_INVALIDSAMPLINGRATE,
            "DUA_ERR_CLIENTERROR_BASE" => WINDOWS_CE::DUA_ERR_CLIENTERROR_BASE,
            "DUA_E_CLIENT_INVALIDBUTTONID" => WINDOWS_CE::DUA_E_CLIENT_INVALIDBUTTONID,
            "DUA_E_CLIENT_REGKEY_INVALID" => WINDOWS_CE::DUA_E_CLIENT_REGKEY_INVALID,
            "DUA_E_CLIENT_PLUGINID_NOT_FOUND" => WINDOWS_CE::DUA_E_CLIENT_PLUGINID_NOT_FOUND,
            "DUA_ERR_INSTALLATION_BASE" => WINDOWS_CE::DUA_ERR_INSTALLATION_BASE,
            "DUA_E_BATTERY_LOW" => WINDOWS_CE::DUA_E_BATTERY_LOW,
            "DUA_E_UPDATE_NOT_STAGED" => WINDOWS_CE::DUA_E_UPDATE_NOT_STAGED,
            "DUA_E_USS_UPDATE_FOUND" => WINDOWS_CE::DUA_E_USS_UPDATE_FOUND,
            "DUA_E_INSTALL_INVALIDUPDATESTATE" => WINDOWS_CE::DUA_E_INSTALL_INVALIDUPDATESTATE,
            "DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN" => WINDOWS_CE::DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN,
            "DUA_E_UPDATE_NOT_COMMITTED" => WINDOWS_CE::DUA_E_UPDATE_NOT_COMMITTED,
            "DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED" => WINDOWS_CE::DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED,
            "DUA_ERR_DATA_MIGRATION_BASE" => WINDOWS_CE::DUA_ERR_DATA_MIGRATION_BASE,
            "DUA_E_COLD_BOOT_REQUIRED" => WINDOWS_CE::DUA_E_COLD_BOOT_REQUIRED,
            "DUA_ERR_UPDATE_STORE_BASE" => WINDOWS_CE::DUA_ERR_UPDATE_STORE_BASE,
            "DUA_E_UPDATE_NOT_FOUND" => WINDOWS_CE::DUA_E_UPDATE_NOT_FOUND,
            "DUA_E_UPDATE_PROPERTY_NOT_FOUND" => WINDOWS_CE::DUA_E_UPDATE_PROPERTY_NOT_FOUND,
            "DUA_E_UPDATE_ALREADY_EXISTS" => WINDOWS_CE::DUA_E_UPDATE_ALREADY_EXISTS,
            "DUA_E_EULA_ALREADY_EXISTS" => WINDOWS_CE::DUA_E_EULA_ALREADY_EXISTS,
            "DUA_E_EULA_NOT_FOUND" => WINDOWS_CE::DUA_E_EULA_NOT_FOUND,
            "DUA_E_BUNDLE_NOT_FOUND" => WINDOWS_CE::DUA_E_BUNDLE_NOT_FOUND,
            "DUA_E_EXTENDED_PROPERTY_NOT_FOUND" => WINDOWS_CE::DUA_E_EXTENDED_PROPERTY_NOT_FOUND,
            "DUA_E_GETEULA" => WINDOWS_CE::DUA_E_GETEULA,
            "DUA_ERR_SESSION_BASE" => WINDOWS_CE::DUA_ERR_SESSION_BASE,
            "DUA_E_INVALID_SESSIONID" => WINDOWS_CE::DUA_E_INVALID_SESSIONID,
            "DUA_E_DIFF_SESSION_IN_PROGRESS" => WINDOWS_CE::DUA_E_DIFF_SESSION_IN_PROGRESS,
            "DUA_E_NO_SESSION_IN_PROGRESS" => WINDOWS_CE::DUA_E_NO_SESSION_IN_PROGRESS,
            "DUA_E_CANNOT_CLOSE_SESSION" => WINDOWS_CE::DUA_E_CANNOT_CLOSE_SESSION,
            "DUA_E_ALL_RETRY_CONSUMED" => WINDOWS_CE::DUA_E_ALL_RETRY_CONSUMED,
            "DUA_E_SERVICE_IS_SHUTTING_DOWN" => WINDOWS_CE::DUA_E_SERVICE_IS_SHUTTING_DOWN,
            "DUA_E_SESSION_TIMEDOUT" => WINDOWS_CE::DUA_E_SESSION_TIMEDOUT,
            "DUA_E_DOWNLOAD_BASE" => WINDOWS_CE::DUA_E_DOWNLOAD_BASE,
            "DUA_E_DOWNLOAD_NOT_CREATED" => WINDOWS_CE::DUA_E_DOWNLOAD_NOT_CREATED,
            "DUA_E_DOWNLOAD_NOT_IDLE" => WINDOWS_CE::DUA_E_DOWNLOAD_NOT_IDLE,
            "DUA_E_DOWNLOAD_USER_CANCELLED" => WINDOWS_CE::DUA_E_DOWNLOAD_USER_CANCELLED,
            "DUA_E_DOWNLOAD_NEEDUSERAGREE" => WINDOWS_CE::DUA_E_DOWNLOAD_NEEDUSERAGREE,
            "DUA_E_DOWNLOAD_NEEDOVERCELLULAR" => WINDOWS_CE::DUA_E_DOWNLOAD_NEEDOVERCELLULAR,
            "DUA_E_DOWNLOAD_USERPOSTPONE" => WINDOWS_CE::DUA_E_DOWNLOAD_USERPOSTPONE,
            "DUA_E_DOWNLOAD_ENGINEEXIT" => WINDOWS_CE::DUA_E_DOWNLOAD_ENGINEEXIT,
            "DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD" => WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD,
            "DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE" => WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE,
            "DUA_E_CONNECTION_BASE" => WINDOWS_CE::DUA_E_CONNECTION_BASE,
            "DUA_E_NO_CONNECTIONS" => WINDOWS_CE::DUA_E_NO_CONNECTIONS,
            "DUA_E_CONNECTION_NOT_RELEASED" => WINDOWS_CE::DUA_E_CONNECTION_NOT_RELEASED,
            "DUA_E_CONNECTION_ACQUIRE_FAILED" => WINDOWS_CE::DUA_E_CONNECTION_ACQUIRE_FAILED,
            "DUA_E_DUAAPI_BASE" => WINDOWS_CE::DUA_E_DUAAPI_BASE,
            "DUA_E_DUAAPI_SHELLNOTREADY" => WINDOWS_CE::DUA_E_DUAAPI_SHELLNOTREADY,
            "BTS_ERR_BASE" => WINDOWS_CE::BTS_ERR_BASE,
            "E_CABAPI_NOT_CABINET" => WINDOWS_CE::E_CABAPI_NOT_CABINET,
            "E_CABAPI_UNKNOWN_FILE" => WINDOWS_CE::E_CABAPI_UNKNOWN_FILE,
            "BTS_E_HTTP_PROVIDER_ERROR" => WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR,
            "BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED" => WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED,
            "E_CABAPI_FCI_OPEN_SRC" => WINDOWS_CE::E_CABAPI_FCI_OPEN_SRC,
            "E_CABAPI_FCI_READ_SRC" => WINDOWS_CE::E_CABAPI_FCI_READ_SRC,
            "E_CABAPI_FCI_ALLOC_FAIL" => WINDOWS_CE::E_CABAPI_FCI_ALLOC_FAIL,
            "E_CABAPI_FCI_TEMP_FILE" => WINDOWS_CE::E_CABAPI_FCI_TEMP_FILE,
            "E_CABAPI_FCI_BAD_COMPR_TYPE" => WINDOWS_CE::E_CABAPI_FCI_BAD_COMPR_TYPE,
            "E_CABAPI_FCI_CAB_FILE" => WINDOWS_CE::E_CABAPI_FCI_CAB_FILE,
            "E_CABAPI_FCI_USER_ABORT" => WINDOWS_CE::E_CABAPI_FCI_USER_ABORT,
            "E_CABAPI_FCI_MCI_FAIL" => WINDOWS_CE::E_CABAPI_FCI_MCI_FAIL,
            "E_CABAPI_FCI_CAB_FORMAT_LIMIT" => WINDOWS_CE::E_CABAPI_FCI_CAB_FORMAT_LIMIT,
            "E_CABAPI_FCI_INVALID_FILE_PATH" => WINDOWS_CE::E_CABAPI_FCI_INVALID_FILE_PATH,
            "E_CABAPI_FCI_DUPLICATE_FILE" => WINDOWS_CE::E_CABAPI_FCI_DUPLICATE_FILE,
            "E_CABAPI_FCI_UNKNOWN" => WINDOWS_CE::E_CABAPI_FCI_UNKNOWN,
            "CABAPI_ERR_FDI_BASE" => WINDOWS_CE::CABAPI_ERR_FDI_BASE,
            "E_CABAPI_FDI_CABINET_NOT_FOUND" => WINDOWS_CE::E_CABAPI_FDI_CABINET_NOT_FOUND,
            "E_CABAPI_FDI_NOT_A_CABINET" => WINDOWS_CE::E_CABAPI_FDI_NOT_A_CABINET,
            "E_CABAPI_FDI_UNKNOWN_CABINET_VERSION" => WINDOWS_CE::E_CABAPI_FDI_UNKNOWN_CABINET_VERSION,
            "E_CABAPI_FDI_CORRUPT_CABINET" => WINDOWS_CE::E_CABAPI_FDI_CORRUPT_CABINET,
            "E_CABAPI_FDI_ALLOC_FAIL" => WINDOWS_CE::E_CABAPI_FDI_ALLOC_FAIL,
            "E_CABAPI_FDI_BAD_COMPR_TYPE" => WINDOWS_CE::E_CABAPI_FDI_BAD_COMPR_TYPE,
            "E_CABAPI_FDI_MDI_FAIL" => WINDOWS_CE::E_CABAPI_FDI_MDI_FAIL,
            "E_CABAPI_FDI_TARGET_FILE" => WINDOWS_CE::E_CABAPI_FDI_TARGET_FILE,
            "E_CABAPI_FDI_RESERVE_MISMATCH" => WINDOWS_CE::E_CABAPI_FDI_RESERVE_MISMATCH,
            "E_CABAPI_FDI_WRONG_CABINET" => WINDOWS_CE::E_CABAPI_FDI_WRONG_CABINET,
            "E_CABAPI_FDI_USER_ABORT" => WINDOWS_CE::E_CABAPI_FDI_USER_ABORT,
            "E_CABAPI_FDI_UNKNOWN" => WINDOWS_CE::E_CABAPI_FDI_UNKNOWN,
            "IMGUPD_ERROR_BASE" => WINDOWS_CE::IMGUPD_ERROR_BASE,
            "E_BASE_PACKAGE_NOT_INSTALLED" => WINDOWS_CE::E_BASE_PACKAGE_NOT_INSTALLED,
            "E_PACKAGE_ALREADY_INSTALLED" => WINDOWS_CE::E_PACKAGE_ALREADY_INSTALLED,
            "E_NO_UPDATE_PATH_TO_TARGET" => WINDOWS_CE::E_NO_UPDATE_PATH_TO_TARGET,
            "E_MULTIPLE_UPDATE_PATHS_FOUND" => WINDOWS_CE::E_MULTIPLE_UPDATE_PATHS_FOUND,
            "E_DUPLICATE_UPDATE_PACKAGE" => WINDOWS_CE::E_DUPLICATE_UPDATE_PACKAGE,
            "E_FILE_COLLISION" => WINDOWS_CE::E_FILE_COLLISION,
            "E_INVALID_PACKAGE" => WINDOWS_CE::E_INVALID_PACKAGE,
            "E_INSUFFICIENT_SPACE_FOR_UPDATE" => WINDOWS_CE::E_INSUFFICIENT_SPACE_FOR_UPDATE,
            "E_REGISTRY_COLLISION" => WINDOWS_CE::E_REGISTRY_COLLISION,
            "E_INVALID_REGISTRY_FILE" => WINDOWS_CE::E_INVALID_REGISTRY_FILE,
            "E_DEPCRECATED1" => WINDOWS_CE::E_DEPCRECATED1,
            "E_TARGET_NOT_APPLICABLE" => WINDOWS_CE::E_TARGET_NOT_APPLICABLE,
            "E_PACKAGE_HIGHER_VERSION_INSTALLED" => WINDOWS_CE::E_PACKAGE_HIGHER_VERSION_INSTALLED,
            "E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION" => WINDOWS_CE::E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION,
            "E_DIFF_SOURCEVERSION_DOES_NOT_MATCH" => WINDOWS_CE::E_DIFF_SOURCEVERSION_DOES_NOT_MATCH,
            "E_STAGED_FILE_NOT_FOUND" => WINDOWS_CE::E_STAGED_FILE_NOT_FOUND,
            "E_PACKAGE_TARGETS_WRONG_CPU" => WINDOWS_CE::E_PACKAGE_TARGETS_WRONG_CPU,
        }
    }
    pub fn from_code(code: u32) -> WINDOWS_CE {
        return match code {
            0x00180011 => WINDOWS_CE::MENROLL_S_ENROLLMENT_SUSPENDED,
            0x80180001 => WINDOWS_CE::MENROLL_E_DEVICE_MESSAGE_FORMAT_ERROR,
            0x80180002 => WINDOWS_CE::MENROLL_E_DEVICE_AUTHENTICATION_ERROR,
            0x80180003 => WINDOWS_CE::MENROLL_E_DEVICE_AUTHORIZATION_ERROR,
            0x80180004 => WINDOWS_CE::MENROLL_E_DEVICE_CERTIFICATEREQUEST_ERROR,
            0x80180005 => WINDOWS_CE::MENROLL_E_DEVICE_CONFIGMGRSERVER_ERROR,
            0x80180006 => WINDOWS_CE::MENROLL_E_DEVICE_INTERNALSERVICE_ERROR,
            0x80180007 => WINDOWS_CE::MENROLL_E_DEVICE_INVALIDSECURITY_ERROR,
            0x80180008 => WINDOWS_CE::MENROLL_E_DEVICE_UNKNOWN_ERROR,
            0x80180009 => WINDOWS_CE::MENROLL_E_ENROLLMENT_IN_PROGRESS,
            0x8018000A => WINDOWS_CE::MENROLL_E_DEVICE_ALREADY_ENROLLED,
            0x8018000B => WINDOWS_CE::MENROLL_E_DEVICE_NOT_ENROLLED,
            0x8018000D => WINDOWS_CE::MENROLL_E_DISCOVERY_SEC_CERT_DATE_INVALID,
            0x8018000E => WINDOWS_CE::MENROLL_E_PASSWORD_NEEDED,
            0x8018000F => WINDOWS_CE::MENROLL_E_WAB_ERROR,
            0x80180010 => WINDOWS_CE::MENROLL_E_CONNECTIVITY,
            0x80180012 => WINDOWS_CE::MENROLL_E_INVALIDSSLCERT,
            0x80180013 => WINDOWS_CE::MENROLL_E_DEVICECAPREACHED,
            0x80180014 => WINDOWS_CE::MENROLL_E_DEVICENOTSUPPORTED,
            0x80180015 => WINDOWS_CE::MENROLL_E_NOT_SUPPORTED,
            0x80180016 => WINDOWS_CE::MENROLL_E_NOTELIGIBLETORENEW,
            0x80180017 => WINDOWS_CE::MENROLL_E_INMAINTENANCE,
            0x80180018 => WINDOWS_CE::MENROLL_E_USER_LICENSE,
            0x80180019 => WINDOWS_CE::MENROLL_E_ENROLLMENTDATAINVALID,
            0x8018001A => WINDOWS_CE::MENROLL_E_INSECUREREDIRECT,
            0x8018001B => WINDOWS_CE::MENROLL_E_PLATFORM_WRONG_STATE,
            0x8018001C => WINDOWS_CE::MENROLL_E_PLATFORM_LICENSE_ERROR,
            0x8018001D => WINDOWS_CE::MENROLL_E_PLATFORM_UNKNOWN_ERROR,
            0x8018001E => WINDOWS_CE::MENROLL_E_PROV_CSP_CERTSTORE,
            0x8018001F => WINDOWS_CE::MENROLL_E_PROV_CSP_W7,
            0x80180020 => WINDOWS_CE::MENROLL_E_PROV_CSP_DMCLIENT,
            0x80180021 => WINDOWS_CE::MENROLL_E_PROV_CSP_PFW,
            0x80180022 => WINDOWS_CE::MENROLL_E_PROV_CSP_MISC,
            0x80180023 => WINDOWS_CE::MENROLL_E_PROV_UNKNOWN,
            0x80180024 => WINDOWS_CE::MENROLL_E_PROV_SSLCERTNOTFOUND,
            0x80180025 => WINDOWS_CE::MENROLL_E_PROV_CSP_APPMGMT,
            0x80180026 => WINDOWS_CE::MENROLL_E_DEVICE_MANAGEMENT_BLOCKED,
            0x80180027 => WINDOWS_CE::MENROLL_E_CERTPOLICY_PRIVATEKEYCREATION_FAILED,
            0x80180028 => WINDOWS_CE::MENROLL_E_CERTAUTH_FAILED_TO_FIND_CERT,
            0x80180029 => WINDOWS_CE::MENROLL_E_EMPTY_MESSAGE,
            0x80180030 => WINDOWS_CE::MENROLL_E_USER_CANCELLED,
            0x80180031 => WINDOWS_CE::MENROLL_E_MDM_NOT_CONFIGURED,
            0x801881C0 => WINDOWS_CE::DUA_ERR_BASE,
            0x801881C3 => WINDOWS_CE::DUA_E_NEWER_UPDATE_EXISTS,
            0x801881C4 => WINDOWS_CE::DUA_E_UPDATE_ALREADY_IN_EVALUATION,
            0x801881C5 => WINDOWS_CE::DUA_E_DEPENDENT_UPDATE_MISSING,
            0x801881C6 => WINDOWS_CE::DUA_E_DUPLICATE_ATTRIBUTE,
            0x801881C7 => WINDOWS_CE::DUA_E_MISSING_ATTRIBUTE,
            0x801881C9 => WINDOWS_CE::DUA_E_INVALIDATTRIBUTEVALUE,
            0x801881CA => WINDOWS_CE::DUA_E_XMLSTRINGTOOLONG,
            0x801881CB => WINDOWS_CE::DUA_E_ATTRIBUTE_MISMATCH,
            0x801881CD => WINDOWS_CE::DUA_E_OUT_OF_DISK_SPACE,
            0x801881CF => WINDOWS_CE::DUA_E_CONNECTION_MANAGER,
            0x801881D0 => WINDOWS_CE::DUA_E_INVALID_HASH,
            0x801881D1 => WINDOWS_CE::DUA_E_INVALID_EULA,
            0x801881D2 => WINDOWS_CE::DUA_E_INVALID_EXTENDED_UPDATE_INFO,
            0x801881D3 => WINDOWS_CE::DUA_E_MAX_SYNCUPDATES_CALLS,
            0x801881D4 => WINDOWS_CE::DUA_E_AUTO_SCAN_OFF,
            0x801881D5 => WINDOWS_CE::DUA_E_XML_CONTENT_TOO_LARGE,
            0x801881D6 => WINDOWS_CE::DUA_E_SDCARD_REMOVED,
            0x801881D7 => WINDOWS_CE::DUA_E_SDCARD_DISABLED,
            0x801881D8 => WINDOWS_CE::DUA_E_SDCARD_HWFAILURE,
            0x801881E1 => WINDOWS_CE::DUA_E_SOAPFAULT_UNKNOWN,
            0x801881E2 => WINDOWS_CE::DUA_E_SOAPFAULT_COOKIEEXPIRED,
            0x801881E3 => WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDCOOKIE,
            0x801881E4 => WINDOWS_CE::DUA_E_SOAPFAULT_CONFIGCHANGED,
            0x801881E5 => WINDOWS_CE::DUA_E_SOAPFAULT_SERVERCHANGED,
            0x801881E6 => WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDAUTHORIZATIONCOOKIE,
            0x801881E7 => WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONREQUIRED,
            0x801881E8 => WINDOWS_CE::DUA_E_SOAPFAULT_INTERNALSERVERERROR,
            0x801881E9 => WINDOWS_CE::DUA_E_SOAPFAULT_INVALIDpMETERS,
            0x801881EA => WINDOWS_CE::DUA_E_SOAPFAULT_REGISTRATIONNOTREQUIRED,
            0x801881EB => WINDOWS_CE::DUA_E_SOAPFAULT_SERVERBUSY,
            0x801881EC => WINDOWS_CE::DUA_E_SOAPFAULT_FILELOCATIONCHANGED,
            0x801881EE => WINDOWS_CE::DUA_E_SOAPFAULT_MALFORMED_MESSAGE,
            0x801881EF => WINDOWS_CE::DUA_E_CABDOWNLOAD_HTTPSTATUSFAILED,
            0x80188200 => WINDOWS_CE::DUA_ERR_REPORTINGERROR_BASE,
            0x80188201 => WINDOWS_CE::DUA_E_REPORTINGFAILED,
            0x80188203 => WINDOWS_CE::DUA_E_INVALIDSAMPLINGRATE,
            0x80188210 => WINDOWS_CE::DUA_ERR_CLIENTERROR_BASE,
            0x80188215 => WINDOWS_CE::DUA_E_CLIENT_INVALIDBUTTONID,
            0x80188216 => WINDOWS_CE::DUA_E_CLIENT_REGKEY_INVALID,
            0x80188217 => WINDOWS_CE::DUA_E_CLIENT_PLUGINID_NOT_FOUND,
            0x80188220 => WINDOWS_CE::DUA_ERR_INSTALLATION_BASE,
            0x80188226 => WINDOWS_CE::DUA_E_BATTERY_LOW,
            0x80188227 => WINDOWS_CE::DUA_E_UPDATE_NOT_STAGED,
            0x80188228 => WINDOWS_CE::DUA_E_USS_UPDATE_FOUND,
            0x8018822A => WINDOWS_CE::DUA_E_INSTALL_INVALIDUPDATESTATE,
            0x8018822B => WINDOWS_CE::DUA_E_INSTALL_UNEXPECTED_COMMIT_RETURN,
            0x8018822C => WINDOWS_CE::DUA_E_UPDATE_NOT_COMMITTED,
            0x8018822D => WINDOWS_CE::DUA_E_USS_UPDATE_FOUND_REBOOT_REQUIRED,
            0x80188230 => WINDOWS_CE::DUA_ERR_DATA_MIGRATION_BASE,
            0x80188231 => WINDOWS_CE::DUA_E_COLD_BOOT_REQUIRED,
            0x80188240 => WINDOWS_CE::DUA_ERR_UPDATE_STORE_BASE,
            0x80188241 => WINDOWS_CE::DUA_E_UPDATE_NOT_FOUND,
            0x80188242 => WINDOWS_CE::DUA_E_UPDATE_PROPERTY_NOT_FOUND,
            0x80188243 => WINDOWS_CE::DUA_E_UPDATE_ALREADY_EXISTS,
            0x80188244 => WINDOWS_CE::DUA_E_EULA_ALREADY_EXISTS,
            0x80188245 => WINDOWS_CE::DUA_E_EULA_NOT_FOUND,
            0x80188246 => WINDOWS_CE::DUA_E_BUNDLE_NOT_FOUND,
            0x80188247 => WINDOWS_CE::DUA_E_EXTENDED_PROPERTY_NOT_FOUND,
            0x80188248 => WINDOWS_CE::DUA_E_GETEULA,
            0x80188250 => WINDOWS_CE::DUA_ERR_SESSION_BASE,
            0x80188251 => WINDOWS_CE::DUA_E_INVALID_SESSIONID,
            0x80188252 => WINDOWS_CE::DUA_E_DIFF_SESSION_IN_PROGRESS,
            0x80188253 => WINDOWS_CE::DUA_E_NO_SESSION_IN_PROGRESS,
            0x80188254 => WINDOWS_CE::DUA_E_CANNOT_CLOSE_SESSION,
            0x80188255 => WINDOWS_CE::DUA_E_ALL_RETRY_CONSUMED,
            0x80188256 => WINDOWS_CE::DUA_E_SERVICE_IS_SHUTTING_DOWN,
            0x80188257 => WINDOWS_CE::DUA_E_SESSION_TIMEDOUT,
            0x80188260 => WINDOWS_CE::DUA_E_DOWNLOAD_BASE,
            0x80188261 => WINDOWS_CE::DUA_E_DOWNLOAD_NOT_CREATED,
            0x80188262 => WINDOWS_CE::DUA_E_DOWNLOAD_NOT_IDLE,
            0x80188263 => WINDOWS_CE::DUA_E_DOWNLOAD_USER_CANCELLED,
            0x80188264 => WINDOWS_CE::DUA_E_DOWNLOAD_NEEDUSERAGREE,
            0x80188265 => WINDOWS_CE::DUA_E_DOWNLOAD_NEEDOVERCELLULAR,
            0x80188266 => WINDOWS_CE::DUA_E_DOWNLOAD_USERPOSTPONE,
            0x80188267 => WINDOWS_CE::DUA_E_DOWNLOAD_ENGINEEXIT,
            0x80188269 => WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_NEED_SDCARD,
            0x8018826A => WINDOWS_CE::DUA_E_DOWNLOAD_OUT_OF_DISK_SPACE_BOTH_STORAGE,
            0x80188270 => WINDOWS_CE::DUA_E_CONNECTION_BASE,
            0x80188271 => WINDOWS_CE::DUA_E_NO_CONNECTIONS,
            0x80188272 => WINDOWS_CE::DUA_E_CONNECTION_NOT_RELEASED,
            0x80188273 => WINDOWS_CE::DUA_E_CONNECTION_ACQUIRE_FAILED,
            0x80188288 => WINDOWS_CE::DUA_E_DUAAPI_BASE,
            0x80188289 => WINDOWS_CE::DUA_E_DUAAPI_SHELLNOTREADY,
            0x801882C0 => WINDOWS_CE::BTS_ERR_BASE,
            0x801882C1 => WINDOWS_CE::E_CABAPI_NOT_CABINET,
            0x801882C2 => WINDOWS_CE::E_CABAPI_UNKNOWN_FILE,
            0x801882CB => WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR,
            0x801882CC => WINDOWS_CE::BTS_E_HTTP_PROVIDER_ERROR_RANGE_RELATED,
            0x801882D1 => WINDOWS_CE::E_CABAPI_FCI_OPEN_SRC,
            0x801882D2 => WINDOWS_CE::E_CABAPI_FCI_READ_SRC,
            0x801882D3 => WINDOWS_CE::E_CABAPI_FCI_ALLOC_FAIL,
            0x801882D4 => WINDOWS_CE::E_CABAPI_FCI_TEMP_FILE,
            0x801882D5 => WINDOWS_CE::E_CABAPI_FCI_BAD_COMPR_TYPE,
            0x801882D6 => WINDOWS_CE::E_CABAPI_FCI_CAB_FILE,
            0x801882D7 => WINDOWS_CE::E_CABAPI_FCI_USER_ABORT,
            0x801882D8 => WINDOWS_CE::E_CABAPI_FCI_MCI_FAIL,
            0x801882D9 => WINDOWS_CE::E_CABAPI_FCI_CAB_FORMAT_LIMIT,
            0x801882DA => WINDOWS_CE::E_CABAPI_FCI_INVALID_FILE_PATH,
            0x801882DB => WINDOWS_CE::E_CABAPI_FCI_DUPLICATE_FILE,
            0x801882DF => WINDOWS_CE::E_CABAPI_FCI_UNKNOWN,
            0x801882E0 => WINDOWS_CE::CABAPI_ERR_FDI_BASE,
            0x801882E1 => WINDOWS_CE::E_CABAPI_FDI_CABINET_NOT_FOUND,
            0x801882E2 => WINDOWS_CE::E_CABAPI_FDI_NOT_A_CABINET,
            0x801882E3 => WINDOWS_CE::E_CABAPI_FDI_UNKNOWN_CABINET_VERSION,
            0x801882E4 => WINDOWS_CE::E_CABAPI_FDI_CORRUPT_CABINET,
            0x801882E5 => WINDOWS_CE::E_CABAPI_FDI_ALLOC_FAIL,
            0x801882E6 => WINDOWS_CE::E_CABAPI_FDI_BAD_COMPR_TYPE,
            0x801882E7 => WINDOWS_CE::E_CABAPI_FDI_MDI_FAIL,
            0x801882E8 => WINDOWS_CE::E_CABAPI_FDI_TARGET_FILE,
            0x801882E9 => WINDOWS_CE::E_CABAPI_FDI_RESERVE_MISMATCH,
            0x801882EA => WINDOWS_CE::E_CABAPI_FDI_WRONG_CABINET,
            0x801882EB => WINDOWS_CE::E_CABAPI_FDI_USER_ABORT,
            0x801882EF => WINDOWS_CE::E_CABAPI_FDI_UNKNOWN,
            0x80188300 => WINDOWS_CE::IMGUPD_ERROR_BASE,
            0x80188301 => WINDOWS_CE::E_BASE_PACKAGE_NOT_INSTALLED,
            0x80188302 => WINDOWS_CE::E_PACKAGE_ALREADY_INSTALLED,
            0x80188303 => WINDOWS_CE::E_NO_UPDATE_PATH_TO_TARGET,
            0x80188304 => WINDOWS_CE::E_MULTIPLE_UPDATE_PATHS_FOUND,
            0x80188305 => WINDOWS_CE::E_DUPLICATE_UPDATE_PACKAGE,
            0x80188306 => WINDOWS_CE::E_FILE_COLLISION,
            0x80188307 => WINDOWS_CE::E_INVALID_PACKAGE,
            0x80188308 => WINDOWS_CE::E_INSUFFICIENT_SPACE_FOR_UPDATE,
            0x80188309 => WINDOWS_CE::E_REGISTRY_COLLISION,
            0x8018830A => WINDOWS_CE::E_INVALID_REGISTRY_FILE,
            0x8018830B => WINDOWS_CE::E_DEPCRECATED1,
            0x8018830C => WINDOWS_CE::E_TARGET_NOT_APPLICABLE,
            0x8018830D => WINDOWS_CE::E_PACKAGE_HIGHER_VERSION_INSTALLED,
            0x8018830E => WINDOWS_CE::E_REMOVAL_PACKAGE_CANNOT_TARGET_BINARY_PARTITION,
            0x8018830F => WINDOWS_CE::E_DIFF_SOURCEVERSION_DOES_NOT_MATCH,
            0x80188310 => WINDOWS_CE::E_STAGED_FILE_NOT_FOUND,
            0x80188311 => WINDOWS_CE::E_PACKAGE_TARGETS_WRONG_CPU,
        }
    }
}
