/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WINDOWS_STORE {
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7001,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7002,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7003,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7004,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7005,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7006,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7007,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7008,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_7009,
    StoreAgentAcquireLicenseFailure1,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_8002,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_8003,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_8004,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_812C,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_8131,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_8132,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_9008,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_900B,
    WINDOWS_STORE_ERROR_UNDOCUMENTED_900D,
}

impl WINDOWS_STORE {
    pub fn code(&self) -> u32 {
        return match self {
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7001 => 0x803F7001 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7002 => 0x803F7002 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7003 => 0x803F7003 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7004 => 0x803F7004 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7005 => 0x803F7005 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7006 => 0x803F7006 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7007 => 0x803F7007 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7008 => 0x803F7008 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7009 => 0x803F7009 as u32,
            WINDOWS_STORE::StoreAgentAcquireLicenseFailure1 => 0x803F8001 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8002 => 0x803F8002 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8003 => 0x803F8003 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8004 => 0x803F8004 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_812C => 0x803F812C as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8131 => 0x803F8131 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8132 => 0x803F8132 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB => 0x803F81FB as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC => 0x803F81FC as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD => 0x803F81FD as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_9008 => 0x803F9008 as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900B => 0x803F900B as u32,
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900D => 0x803F900D as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7001 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7001),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7002 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7002),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7003 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7003),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7004 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7004),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7005 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7005),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7006 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7006),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7007 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7007),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7008 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7008),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7009 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7009),
            WINDOWS_STORE::StoreAgentAcquireLicenseFailure1 => RawError::Kind(WINDOWS_STORE::StoreAgentAcquireLicenseFailure1),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8002 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8002),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8003 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8003),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8004 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8004),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_812C => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_812C),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8131 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8131),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8132 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8132),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_9008 => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_9008),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900B => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900B),
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900D => RawError::Kind(WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900D),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7001 => "Activation Failed Because This Device Doesn’t Have A Valid Digital Entitlement Or Product Key",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7002 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7003 => "Intermittent network connection error.",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7004 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7005 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7006 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7007 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7008 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7009 => "Description is missing",
            WINDOWS_STORE::StoreAgentAcquireLicenseFailure1 => "The Store Agent can't acquire license for this app",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8002 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8003 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8004 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_812C => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8131 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8132 => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_9008 => "Data has changed.",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900B => "Description is missing",
            WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900D => "Description is missing",
        }
    }

    pub fn from_name(name: &str) -> WINDOWS_STORE {
        return match name {
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7001" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7001,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7002" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7002,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7003" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7003,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7004" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7004,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7005" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7005,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7006" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7006,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7007" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7007,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7008" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7008,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_7009" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7009,
            "StoreAgentAcquireLicenseFailure1" => WINDOWS_STORE::StoreAgentAcquireLicenseFailure1,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_8002" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8002,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_8003" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8003,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_8004" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8004,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_812C" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_812C,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_8131" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8131,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_8132" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8132,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_9008" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_9008,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_900B" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900B,
            "WINDOWS_STORE_ERROR_UNDOCUMENTED_900D" => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900D,
        }
    }
    pub fn from_code(code: u32) -> WINDOWS_STORE {
        return match code {
            0x803F7001 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7001,
            0x803F7002 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7002,
            0x803F7003 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7003,
            0x803F7004 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7004,
            0x803F7005 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7005,
            0x803F7006 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7006,
            0x803F7007 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7007,
            0x803F7008 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7008,
            0x803F7009 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_7009,
            0x803F8001 => WINDOWS_STORE::StoreAgentAcquireLicenseFailure1,
            0x803F8002 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8002,
            0x803F8003 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8003,
            0x803F8004 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8004,
            0x803F812C => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_812C,
            0x803F8131 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8131,
            0x803F8132 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_8132,
            0x803F81FB => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FB,
            0x803F81FC => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FC,
            0x803F81FD => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_81FD,
            0x803F9008 => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_9008,
            0x803F900B => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900B,
            0x803F900D => WINDOWS_STORE::WINDOWS_STORE_ERROR_UNDOCUMENTED_900D,
        }
    }
}
