/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WPN {
    WPN_E_CHANNEL_CLOSED,
    WPN_E_CHANNEL_REQUEST_NOT_COMPLETE,
    WPN_E_INVALID_APP,
    WPN_E_OUTSTANDING_CHANNEL_REQUEST,
    WPN_E_DUPLICATE_CHANNEL,
    WPN_E_PLATFORM_UNAVAILABLE,
    WPN_E_NOTIFICATION_POSTED,
    WPN_E_NOTIFICATION_HIDDEN,
    WPN_E_NOTIFICATION_NOT_POSTED,
    WPN_E_CLOUD_DISABLED,
    WPN_E_CLOUD_INCAPABLE,
    WPN_E_NOTIFICATION_DISABLED,
    WPN_E_NOTIFICATION_INCAPABLE,
    WPN_E_INTERNET_INCAPABLE,
    WPN_E_NOTIFICATION_TYPE_DISABLED,
    WPN_E_NOTIFICATION_SIZE,
    WPN_E_TAG_SIZE,
    WPN_E_ACCESS_DENIED,
    WPN_E_DUPLICATE_REGISTRATION,
    WPN_E_PUSH_NOTIFICATION_INCAPABLE,
    WPN_E_CLOUD_AUTH_UNAVAILABLE,
    WPN_E_CLOUD_SERVICE_UNAVAILABLE,
    WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION,
    WPN_E_DEV_ID_SIZE,
    WPN_E_TAG_ALPHANUMERIC,
    WPN_E_INVALID_HTTP_STATUS_CODE,
    WPN_E_OUT_OF_SESSION,
    WPN_E_POWER_SAVE,
    WPN_E_IMAGE_NOT_FOUND_IN_CACHE,
    WPN_E_ALL_URL_NOT_COMPLETED,
    WPN_E_INVALID_CLOUD_IMAGE,
    WPN_E_NOTIFICATION_ID_MATCHED,
    WPN_E_CALLBACK_ALREADY_REGISTERED,
    WPN_E_TOAST_NOTIFICATION_DROPPED,
    WPN_E_STORAGE_LOCKED,
    WPN_E_GROUP_SIZE,
    WPN_E_GROUP_ALPHANUMERIC,
    WPN_E_CLOUD_DISABLED_FOR_APP,
}

impl WPN {
    pub fn code(&self) -> u32 {
        return match self {
            WPN::WPN_E_CHANNEL_CLOSED => 0x803E0100 as u32,
            WPN::WPN_E_CHANNEL_REQUEST_NOT_COMPLETE => 0x803E0101 as u32,
            WPN::WPN_E_INVALID_APP => 0x803E0102 as u32,
            WPN::WPN_E_OUTSTANDING_CHANNEL_REQUEST => 0x803E0103 as u32,
            WPN::WPN_E_DUPLICATE_CHANNEL => 0x803E0104 as u32,
            WPN::WPN_E_PLATFORM_UNAVAILABLE => 0x803E0105 as u32,
            WPN::WPN_E_NOTIFICATION_POSTED => 0x803E0106 as u32,
            WPN::WPN_E_NOTIFICATION_HIDDEN => 0x803E0107 as u32,
            WPN::WPN_E_NOTIFICATION_NOT_POSTED => 0x803E0108 as u32,
            WPN::WPN_E_CLOUD_DISABLED => 0x803E0109 as u32,
            WPN::WPN_E_CLOUD_INCAPABLE => 0x803E0110 as u32,
            WPN::WPN_E_NOTIFICATION_DISABLED => 0x803E0111 as u32,
            WPN::WPN_E_NOTIFICATION_INCAPABLE => 0x803E0112 as u32,
            WPN::WPN_E_INTERNET_INCAPABLE => 0x803E0113 as u32,
            WPN::WPN_E_NOTIFICATION_TYPE_DISABLED => 0x803E0114 as u32,
            WPN::WPN_E_NOTIFICATION_SIZE => 0x803E0115 as u32,
            WPN::WPN_E_TAG_SIZE => 0x803E0116 as u32,
            WPN::WPN_E_ACCESS_DENIED => 0x803E0117 as u32,
            WPN::WPN_E_DUPLICATE_REGISTRATION => 0x803E0118 as u32,
            WPN::WPN_E_PUSH_NOTIFICATION_INCAPABLE => 0x803E0119 as u32,
            WPN::WPN_E_CLOUD_AUTH_UNAVAILABLE => 0x803E011A as u32,
            WPN::WPN_E_CLOUD_SERVICE_UNAVAILABLE => 0x803E011B as u32,
            WPN::WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION => 0x803E011C as u32,
            WPN::WPN_E_DEV_ID_SIZE => 0x803E0120 as u32,
            WPN::WPN_E_TAG_ALPHANUMERIC => 0x803E012A as u32,
            WPN::WPN_E_INVALID_HTTP_STATUS_CODE => 0x803E012B as u32,
            WPN::WPN_E_OUT_OF_SESSION => 0x803E0200 as u32,
            WPN::WPN_E_POWER_SAVE => 0x803E0201 as u32,
            WPN::WPN_E_IMAGE_NOT_FOUND_IN_CACHE => 0x803E0202 as u32,
            WPN::WPN_E_ALL_URL_NOT_COMPLETED => 0x803E0203 as u32,
            WPN::WPN_E_INVALID_CLOUD_IMAGE => 0x803E0204 as u32,
            WPN::WPN_E_NOTIFICATION_ID_MATCHED => 0x803E0205 as u32,
            WPN::WPN_E_CALLBACK_ALREADY_REGISTERED => 0x803E0206 as u32,
            WPN::WPN_E_TOAST_NOTIFICATION_DROPPED => 0x803E0207 as u32,
            WPN::WPN_E_STORAGE_LOCKED => 0x803E0208 as u32,
            WPN::WPN_E_GROUP_SIZE => 0x803E0209 as u32,
            WPN::WPN_E_GROUP_ALPHANUMERIC => 0x803E020A as u32,
            WPN::WPN_E_CLOUD_DISABLED_FOR_APP => 0x803E020B as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WPN::WPN_E_CHANNEL_CLOSED => RawError::Kind(WPN::WPN_E_CHANNEL_CLOSED),
            WPN::WPN_E_CHANNEL_REQUEST_NOT_COMPLETE => RawError::Kind(WPN::WPN_E_CHANNEL_REQUEST_NOT_COMPLETE),
            WPN::WPN_E_INVALID_APP => RawError::Kind(WPN::WPN_E_INVALID_APP),
            WPN::WPN_E_OUTSTANDING_CHANNEL_REQUEST => RawError::Kind(WPN::WPN_E_OUTSTANDING_CHANNEL_REQUEST),
            WPN::WPN_E_DUPLICATE_CHANNEL => RawError::Kind(WPN::WPN_E_DUPLICATE_CHANNEL),
            WPN::WPN_E_PLATFORM_UNAVAILABLE => RawError::Kind(WPN::WPN_E_PLATFORM_UNAVAILABLE),
            WPN::WPN_E_NOTIFICATION_POSTED => RawError::Kind(WPN::WPN_E_NOTIFICATION_POSTED),
            WPN::WPN_E_NOTIFICATION_HIDDEN => RawError::Kind(WPN::WPN_E_NOTIFICATION_HIDDEN),
            WPN::WPN_E_NOTIFICATION_NOT_POSTED => RawError::Kind(WPN::WPN_E_NOTIFICATION_NOT_POSTED),
            WPN::WPN_E_CLOUD_DISABLED => RawError::Kind(WPN::WPN_E_CLOUD_DISABLED),
            WPN::WPN_E_CLOUD_INCAPABLE => RawError::Kind(WPN::WPN_E_CLOUD_INCAPABLE),
            WPN::WPN_E_NOTIFICATION_DISABLED => RawError::Kind(WPN::WPN_E_NOTIFICATION_DISABLED),
            WPN::WPN_E_NOTIFICATION_INCAPABLE => RawError::Kind(WPN::WPN_E_NOTIFICATION_INCAPABLE),
            WPN::WPN_E_INTERNET_INCAPABLE => RawError::Kind(WPN::WPN_E_INTERNET_INCAPABLE),
            WPN::WPN_E_NOTIFICATION_TYPE_DISABLED => RawError::Kind(WPN::WPN_E_NOTIFICATION_TYPE_DISABLED),
            WPN::WPN_E_NOTIFICATION_SIZE => RawError::Kind(WPN::WPN_E_NOTIFICATION_SIZE),
            WPN::WPN_E_TAG_SIZE => RawError::Kind(WPN::WPN_E_TAG_SIZE),
            WPN::WPN_E_ACCESS_DENIED => RawError::Kind(WPN::WPN_E_ACCESS_DENIED),
            WPN::WPN_E_DUPLICATE_REGISTRATION => RawError::Kind(WPN::WPN_E_DUPLICATE_REGISTRATION),
            WPN::WPN_E_PUSH_NOTIFICATION_INCAPABLE => RawError::Kind(WPN::WPN_E_PUSH_NOTIFICATION_INCAPABLE),
            WPN::WPN_E_CLOUD_AUTH_UNAVAILABLE => RawError::Kind(WPN::WPN_E_CLOUD_AUTH_UNAVAILABLE),
            WPN::WPN_E_CLOUD_SERVICE_UNAVAILABLE => RawError::Kind(WPN::WPN_E_CLOUD_SERVICE_UNAVAILABLE),
            WPN::WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION => RawError::Kind(WPN::WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION),
            WPN::WPN_E_DEV_ID_SIZE => RawError::Kind(WPN::WPN_E_DEV_ID_SIZE),
            WPN::WPN_E_TAG_ALPHANUMERIC => RawError::Kind(WPN::WPN_E_TAG_ALPHANUMERIC),
            WPN::WPN_E_INVALID_HTTP_STATUS_CODE => RawError::Kind(WPN::WPN_E_INVALID_HTTP_STATUS_CODE),
            WPN::WPN_E_OUT_OF_SESSION => RawError::Kind(WPN::WPN_E_OUT_OF_SESSION),
            WPN::WPN_E_POWER_SAVE => RawError::Kind(WPN::WPN_E_POWER_SAVE),
            WPN::WPN_E_IMAGE_NOT_FOUND_IN_CACHE => RawError::Kind(WPN::WPN_E_IMAGE_NOT_FOUND_IN_CACHE),
            WPN::WPN_E_ALL_URL_NOT_COMPLETED => RawError::Kind(WPN::WPN_E_ALL_URL_NOT_COMPLETED),
            WPN::WPN_E_INVALID_CLOUD_IMAGE => RawError::Kind(WPN::WPN_E_INVALID_CLOUD_IMAGE),
            WPN::WPN_E_NOTIFICATION_ID_MATCHED => RawError::Kind(WPN::WPN_E_NOTIFICATION_ID_MATCHED),
            WPN::WPN_E_CALLBACK_ALREADY_REGISTERED => RawError::Kind(WPN::WPN_E_CALLBACK_ALREADY_REGISTERED),
            WPN::WPN_E_TOAST_NOTIFICATION_DROPPED => RawError::Kind(WPN::WPN_E_TOAST_NOTIFICATION_DROPPED),
            WPN::WPN_E_STORAGE_LOCKED => RawError::Kind(WPN::WPN_E_STORAGE_LOCKED),
            WPN::WPN_E_GROUP_SIZE => RawError::Kind(WPN::WPN_E_GROUP_SIZE),
            WPN::WPN_E_GROUP_ALPHANUMERIC => RawError::Kind(WPN::WPN_E_GROUP_ALPHANUMERIC),
            WPN::WPN_E_CLOUD_DISABLED_FOR_APP => RawError::Kind(WPN::WPN_E_CLOUD_DISABLED_FOR_APP),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WPN::WPN_E_CHANNEL_CLOSED => "The notification channel has already been closed.",
            WPN::WPN_E_CHANNEL_REQUEST_NOT_COMPLETE => "The notification channel request did not complete successfully.",
            WPN::WPN_E_INVALID_APP => "The application identifier provided is invalid.",
            WPN::WPN_E_OUTSTANDING_CHANNEL_REQUEST => "A notification channel request for the provided application identifier is in progress.",
            WPN::WPN_E_DUPLICATE_CHANNEL => "The channel identifier is already tied to another application endpoint.",
            WPN::WPN_E_PLATFORM_UNAVAILABLE => "The notification platform is unavailable.",
            WPN::WPN_E_NOTIFICATION_POSTED => "The notification has already been posted.",
            WPN::WPN_E_NOTIFICATION_HIDDEN => "The notification has already been hidden.",
            WPN::WPN_E_NOTIFICATION_NOT_POSTED => "The notification cannot be hidden until it has been shown.",
            WPN::WPN_E_CLOUD_DISABLED => "Cloud notifications have been turned off.",
            WPN::WPN_E_CLOUD_INCAPABLE => "The application does not have the cloud notification capability.",
            WPN::WPN_E_NOTIFICATION_DISABLED => "Settings prevent the notification from being delivered.",
            WPN::WPN_E_NOTIFICATION_INCAPABLE => "Application capabilities prevent the notification from being delivered.",
            WPN::WPN_E_INTERNET_INCAPABLE => "The application does not have the internet access capability.",
            WPN::WPN_E_NOTIFICATION_TYPE_DISABLED => "Settings prevent the notification type from being delivered.",
            WPN::WPN_E_NOTIFICATION_SIZE => "The size of the notification content is too large.",
            WPN::WPN_E_TAG_SIZE => "The size of the notification tag is too large.",
            WPN::WPN_E_ACCESS_DENIED => "The notification platform doesn't have appropriate privilege on resources.",
            WPN::WPN_E_DUPLICATE_REGISTRATION => "The notification platform found application is already registered.",
            WPN::WPN_E_PUSH_NOTIFICATION_INCAPABLE => "The application background task does not have the push notification capability.",
            WPN::WPN_E_CLOUD_AUTH_UNAVAILABLE => "The notification platform is unable to retrieve the authentication credentials required to connect to the cloud notification service.",
            WPN::WPN_E_CLOUD_SERVICE_UNAVAILABLE => "The notification platform is unable to connect to the cloud notification service.",
            WPN::WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION => "The notification platform is unable to initialize a callback for lock screen updates.",
            WPN::WPN_E_DEV_ID_SIZE => "The size of the developer id for scheduled notification is too large.",
            WPN::WPN_E_TAG_ALPHANUMERIC => "The notification tag is not alphanumeric.",
            WPN::WPN_E_INVALID_HTTP_STATUS_CODE => "The notification platform has received invalid HTTP status code other than 2xx for polling.",
            WPN::WPN_E_OUT_OF_SESSION => "The notification platform has run out of presentation layer sessions.",
            WPN::WPN_E_POWER_SAVE => "The notification platform rejects image download request due to system in power save mode.",
            WPN::WPN_E_IMAGE_NOT_FOUND_IN_CACHE => "The notification platform doesn't have the requested image in its cache.",
            WPN::WPN_E_ALL_URL_NOT_COMPLETED => "The notification platform cannot complete all of requested image.",
            WPN::WPN_E_INVALID_CLOUD_IMAGE => "A cloud image downloaded from the notification platform is invalid.",
            WPN::WPN_E_NOTIFICATION_ID_MATCHED => "Notification Id provided as filter is matched with what the notification platform maintains.",
            WPN::WPN_E_CALLBACK_ALREADY_REGISTERED => "Notification callback interface is already registered.",
            WPN::WPN_E_TOAST_NOTIFICATION_DROPPED => "Toast Notification was dropped without being displayed to the user.",
            WPN::WPN_E_STORAGE_LOCKED => "The notification platform does not have the proper privileges to complete the request.",
            WPN::WPN_E_GROUP_SIZE => "The size of the notification group is too large.",
            WPN::WPN_E_GROUP_ALPHANUMERIC => "The notification group is not alphanumeric.",
            WPN::WPN_E_CLOUD_DISABLED_FOR_APP => "Cloud notifications have been disabled for the application due to a policy setting.",
        }
    }

    pub fn from_name(name: &str) -> WPN {
        return match name {
            "WPN_E_CHANNEL_CLOSED" => WPN::WPN_E_CHANNEL_CLOSED,
            "WPN_E_CHANNEL_REQUEST_NOT_COMPLETE" => WPN::WPN_E_CHANNEL_REQUEST_NOT_COMPLETE,
            "WPN_E_INVALID_APP" => WPN::WPN_E_INVALID_APP,
            "WPN_E_OUTSTANDING_CHANNEL_REQUEST" => WPN::WPN_E_OUTSTANDING_CHANNEL_REQUEST,
            "WPN_E_DUPLICATE_CHANNEL" => WPN::WPN_E_DUPLICATE_CHANNEL,
            "WPN_E_PLATFORM_UNAVAILABLE" => WPN::WPN_E_PLATFORM_UNAVAILABLE,
            "WPN_E_NOTIFICATION_POSTED" => WPN::WPN_E_NOTIFICATION_POSTED,
            "WPN_E_NOTIFICATION_HIDDEN" => WPN::WPN_E_NOTIFICATION_HIDDEN,
            "WPN_E_NOTIFICATION_NOT_POSTED" => WPN::WPN_E_NOTIFICATION_NOT_POSTED,
            "WPN_E_CLOUD_DISABLED" => WPN::WPN_E_CLOUD_DISABLED,
            "WPN_E_CLOUD_INCAPABLE" => WPN::WPN_E_CLOUD_INCAPABLE,
            "WPN_E_NOTIFICATION_DISABLED" => WPN::WPN_E_NOTIFICATION_DISABLED,
            "WPN_E_NOTIFICATION_INCAPABLE" => WPN::WPN_E_NOTIFICATION_INCAPABLE,
            "WPN_E_INTERNET_INCAPABLE" => WPN::WPN_E_INTERNET_INCAPABLE,
            "WPN_E_NOTIFICATION_TYPE_DISABLED" => WPN::WPN_E_NOTIFICATION_TYPE_DISABLED,
            "WPN_E_NOTIFICATION_SIZE" => WPN::WPN_E_NOTIFICATION_SIZE,
            "WPN_E_TAG_SIZE" => WPN::WPN_E_TAG_SIZE,
            "WPN_E_ACCESS_DENIED" => WPN::WPN_E_ACCESS_DENIED,
            "WPN_E_DUPLICATE_REGISTRATION" => WPN::WPN_E_DUPLICATE_REGISTRATION,
            "WPN_E_PUSH_NOTIFICATION_INCAPABLE" => WPN::WPN_E_PUSH_NOTIFICATION_INCAPABLE,
            "WPN_E_CLOUD_AUTH_UNAVAILABLE" => WPN::WPN_E_CLOUD_AUTH_UNAVAILABLE,
            "WPN_E_CLOUD_SERVICE_UNAVAILABLE" => WPN::WPN_E_CLOUD_SERVICE_UNAVAILABLE,
            "WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION" => WPN::WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION,
            "WPN_E_DEV_ID_SIZE" => WPN::WPN_E_DEV_ID_SIZE,
            "WPN_E_TAG_ALPHANUMERIC" => WPN::WPN_E_TAG_ALPHANUMERIC,
            "WPN_E_INVALID_HTTP_STATUS_CODE" => WPN::WPN_E_INVALID_HTTP_STATUS_CODE,
            "WPN_E_OUT_OF_SESSION" => WPN::WPN_E_OUT_OF_SESSION,
            "WPN_E_POWER_SAVE" => WPN::WPN_E_POWER_SAVE,
            "WPN_E_IMAGE_NOT_FOUND_IN_CACHE" => WPN::WPN_E_IMAGE_NOT_FOUND_IN_CACHE,
            "WPN_E_ALL_URL_NOT_COMPLETED" => WPN::WPN_E_ALL_URL_NOT_COMPLETED,
            "WPN_E_INVALID_CLOUD_IMAGE" => WPN::WPN_E_INVALID_CLOUD_IMAGE,
            "WPN_E_NOTIFICATION_ID_MATCHED" => WPN::WPN_E_NOTIFICATION_ID_MATCHED,
            "WPN_E_CALLBACK_ALREADY_REGISTERED" => WPN::WPN_E_CALLBACK_ALREADY_REGISTERED,
            "WPN_E_TOAST_NOTIFICATION_DROPPED" => WPN::WPN_E_TOAST_NOTIFICATION_DROPPED,
            "WPN_E_STORAGE_LOCKED" => WPN::WPN_E_STORAGE_LOCKED,
            "WPN_E_GROUP_SIZE" => WPN::WPN_E_GROUP_SIZE,
            "WPN_E_GROUP_ALPHANUMERIC" => WPN::WPN_E_GROUP_ALPHANUMERIC,
            "WPN_E_CLOUD_DISABLED_FOR_APP" => WPN::WPN_E_CLOUD_DISABLED_FOR_APP,
        }
    }
    pub fn from_code(code: u32) -> WPN {
        return match code {
            0x803E0100 => WPN::WPN_E_CHANNEL_CLOSED,
            0x803E0101 => WPN::WPN_E_CHANNEL_REQUEST_NOT_COMPLETE,
            0x803E0102 => WPN::WPN_E_INVALID_APP,
            0x803E0103 => WPN::WPN_E_OUTSTANDING_CHANNEL_REQUEST,
            0x803E0104 => WPN::WPN_E_DUPLICATE_CHANNEL,
            0x803E0105 => WPN::WPN_E_PLATFORM_UNAVAILABLE,
            0x803E0106 => WPN::WPN_E_NOTIFICATION_POSTED,
            0x803E0107 => WPN::WPN_E_NOTIFICATION_HIDDEN,
            0x803E0108 => WPN::WPN_E_NOTIFICATION_NOT_POSTED,
            0x803E0109 => WPN::WPN_E_CLOUD_DISABLED,
            0x803E0110 => WPN::WPN_E_CLOUD_INCAPABLE,
            0x803E0111 => WPN::WPN_E_NOTIFICATION_DISABLED,
            0x803E0112 => WPN::WPN_E_NOTIFICATION_INCAPABLE,
            0x803E0113 => WPN::WPN_E_INTERNET_INCAPABLE,
            0x803E0114 => WPN::WPN_E_NOTIFICATION_TYPE_DISABLED,
            0x803E0115 => WPN::WPN_E_NOTIFICATION_SIZE,
            0x803E0116 => WPN::WPN_E_TAG_SIZE,
            0x803E0117 => WPN::WPN_E_ACCESS_DENIED,
            0x803E0118 => WPN::WPN_E_DUPLICATE_REGISTRATION,
            0x803E0119 => WPN::WPN_E_PUSH_NOTIFICATION_INCAPABLE,
            0x803E011A => WPN::WPN_E_CLOUD_AUTH_UNAVAILABLE,
            0x803E011B => WPN::WPN_E_CLOUD_SERVICE_UNAVAILABLE,
            0x803E011C => WPN::WPN_E_FAILED_LOCK_SCREEN_UPDATE_INTIALIZATION,
            0x803E0120 => WPN::WPN_E_DEV_ID_SIZE,
            0x803E012A => WPN::WPN_E_TAG_ALPHANUMERIC,
            0x803E012B => WPN::WPN_E_INVALID_HTTP_STATUS_CODE,
            0x803E0200 => WPN::WPN_E_OUT_OF_SESSION,
            0x803E0201 => WPN::WPN_E_POWER_SAVE,
            0x803E0202 => WPN::WPN_E_IMAGE_NOT_FOUND_IN_CACHE,
            0x803E0203 => WPN::WPN_E_ALL_URL_NOT_COMPLETED,
            0x803E0204 => WPN::WPN_E_INVALID_CLOUD_IMAGE,
            0x803E0205 => WPN::WPN_E_NOTIFICATION_ID_MATCHED,
            0x803E0206 => WPN::WPN_E_CALLBACK_ALREADY_REGISTERED,
            0x803E0207 => WPN::WPN_E_TOAST_NOTIFICATION_DROPPED,
            0x803E0208 => WPN::WPN_E_STORAGE_LOCKED,
            0x803E0209 => WPN::WPN_E_GROUP_SIZE,
            0x803E020A => WPN::WPN_E_GROUP_ALPHANUMERIC,
            0x803E020B => WPN::WPN_E_CLOUD_DISABLED_FOR_APP,
        }
    }
}
