/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum ITF {
    OLE_S_USEREG,
    OLE_S_STATIC,
    MS_S_PENDING,
    OLE_S_MAC_CLIPFORMAT,
    MS_S_NOUPDATE,
    MS_S_ENDOFSTREAM,
    OLE_S_LAST,
    DRAGDROP_S_DROP,
    DRAGDROP_S_CANCEL,
    DRAGDROP_S_USEDEFAULTCURSORS,
    VFW_S_NO_MORE_ITEMS,
    DATA_S_SAMEFORMATETC,
    VIEW_S_ALREADY_FROZEN,
    CACHE_S_FORMATETC_NOTSUPPORTED,
    CACHE_S_SAMECACHE,
    CACHE_S_SOMECACHES_NOTUPDATED,
    OLEOBJ_S_INVALIDVERB,
    OLEOBJ_S_CANNOT_DOVERB_NOW,
    OLEOBJ_S_INVALIDHWND,
    INPLACE_S_TRUNCATED,
    CONVERT10_S_NO_PRESENTATION,
    MK_S_REDUCED_TO_SELF,
    MK_S_ME,
    MK_S_HIM,
    MK_S_US,
    MK_S_MONIKERALREADYREGISTERED,
    MK_S_ASYNCHRONOUS,
    EVENT_S_SOME_SUBSCRIBERS_FAILED,
    IMAPI_S_PROPERTIESIGNORED,
    MPEG2_S_MORE_DATA_AVAILABLE,
    IMAPI_S_BUFFER_TO_SMALL,
    MPEG2_S_NO_MORE_DATA_AVAILABLE,
    EVENT_S_NOSUBSCRIBERS,
    MPEG2_S_SG_INFO_FOUND,
    _MAPI_W_NO_SERVICE,
    MPEG2_S_SG_INFO_NOT_FOUND,
    MPEG2_S_MPE_INFO_FOUND,
    MPEG2_S_MPE_INFO_NOT_FOUND,
    MPEG2_S_NEW_MODULE_VERSION,
    VFW_S_DUPLICATE_NAME,
    VFW_S_STATE_INTERMEDIATE,
    VFW_S_PARTIAL_RENDER,
    VFW_S_SOME_DATA_IGNORED,
    VFW_S_CONNECTIONS_DEFERRED,
    VFW_S_RESOURCE_NOT_NEEDED,
    TPC_S_TRUNCATED,
    TPC_S_INTERRUPTED,
    TPC_S_NO_DATA_TO_PROCESS,
    VFW_S_MEDIA_TYPE_IGNORED,
    VFW_S_VIDEO_NOT_RENDERED,
    VFW_S_AUDIO_NOT_RENDERED,
    VFW_S_RPZA,
    VFW_S_ESTIMATED,
    VFW_S_RESERVED,
    VFW_S_STREAM_OFF,
    VFW_S_CANT_CUE,
    VFW_S_NOPREVIEWPIN,
    VFW_S_DVD_NON_ONE_SEQUENTIAL,
    VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE,
    VFW_S_DVD_NOT_ACCURATE,
    TF_S_ASYNC,
    TS_S_ASYNC,
    CM_S_NODATASERVERS,
    QRY_S_NOROWSFOUND,
    QRY_S_TERMIGNORED,
    QRY_S_INEXACTRESULTS,
    IDS_MON_DEFAULT_ERROR,
    IDS_MON_ILLEGAL_PASSTHROUGH,
    IDS_MON_PARSE_ERR_1_PARAM,
    IDS_MON_PARSE_ERR_2_PARAM,
    IDS_MON_SEMI_COLON,
    IDS_MON_ORDINAL_OUT_OF_RANGE,
    IDS_MON_VIEW_NOT_DEFINED,
    IDS_MON_COLUMN_NOT_DEFINED,
    IDS_MON_BUILTIN_VIEW,
    IDS_MON_OUT_OF_MEMORY,
    IDS_MON_SELECT_STAR,
    IDS_MON_OR_NOT,
    IDS_MON_CANNOT_CONVERT,
    IDS_MON_OUT_OF_RANGE,
    IDS_MON_RELATIVE_INTERVAL,
    IDS_MON_NOT_COLUMN_OF_VIEW,
    IDS_MON_BUILTIN_PROPERTY,
    IDS_MON_WEIGHT_OUT_OF_RANGE,
    IDS_MON_MATCH_STRING,
    IDS_MON_PROPERTY_NAME_IN_VIEW,
    IDS_MON_VIEW_ALREADY_DEFINED,
    IDS_MON_INVALID_CATALOG,
    IDS_MON_INVALIDSELECT_COALESCE,
    IDS_MON_CANNOT_CAST,
    IDS_MON_DATE_OUT_OF_RANGE,
    IDS_MON_INVALID_IN_GROUP_CLAUSE,
    GTHR_S_STATUS_CHANGE_IGNORED,
    GTHR_S_STATUS_END_CRAWL,
    GTHR_S_STATUS_RESET,
    GTHR_S_STATUS_THROTTLE,
    GTHR_S_STATUS_RESUME,
    GTHR_S_STATUS_PAUSE,
    GTHR_S_END_STD_CHUNKS,
    GTHR_S_NO_CRAWL_SEEDS,
    GTHR_S_CANNOT_FILTER,
    GTHR_S_STATUS_STOP,
    GTHR_S_STATUS_START,
    GTHR_S_CONFIG_HAS_ACCOUNTS,
    GTHR_S_PROB_NOT_MODIFIED,
    GTHR_S_CRAWL_SCHEDULED,
    GTHR_S_TRANSACTION_IGNORED,
    GTHR_S_START_FILTER_FROM_PROTOCOL,
    GTHR_S_BAD_FILE_LINK,
    GTHR_S_NOT_ALL_PARTS,
    GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE,
    GTHR_S_START_FILTER_FROM_BODY,
    GTHR_S_MODIFIED_PARTS,
    GTHR_S_CRAWL_FULL,
    GTHR_S_CRAWL_INCREMENTAL,
    GTHR_S_CRAWL_ADAPTIVE,
    GTHR_S_NO_INDEX,
    GTHR_S_PAUSE_REASON_EXTERNAL,
    GTHR_S_PAUSE_REASON_UPGRADING,
    GTHR_S_PAUSE_REASON_BACKOFF,
    GTHR_S_OFFICE_CHILD,
    GTHR_S_CANNOT_WORDBREAK,
    GTHR_S_USE_MIME_FILTER,
    GTHR_S_PAUSE_REASON_PROFILE_IMPORT,
    DB_S_ROWLIMITEXCEEDED,
    DB_S_COLUMNTYPEMISMATCH,
    DB_S_TYPEINFOOVERRIDDEN,
    DB_S_BOOKMARKSKIPPED,
    DB_S_NONEXTROWSET,
    DB_S_ENDOFROWSET,
    DB_S_COMMANDREEXECUTED,
    DB_S_BUFFERFULL,
    DB_S_NORESULT,
    DB_S_CANTRELEASE,
    DB_S_GOALCHANGED,
    DB_S_UNWANTEDOPERATION,
    DB_S_DIALECTIGNORED,
    DB_S_UNWANTEDPHASE,
    DB_S_UNWANTEDREASON,
    DB_S_ASYNCHRONOUS,
    DB_S_COLUMNSCHANGED,
    DB_S_ERRORSRETURNED,
    DB_S_BADROWHANDLE,
    DB_S_DELETEDROW,
    DB_S_TOOMANYCHANGES,
    DB_S_STOPLIMITREACHED,
    DB_S_NOTSINGLETON,
    DB_S_LOCKUPGRADED,
    DB_S_PROPERTIESCHANGED,
    DB_S_ERRORSOCCURRED,
    DB_S_PARAMUNAVAILABLE,
    DB_S_MULTIPLECHANGES,
    DB_S_NOROWSPECIFICCOLUMNS,
    REC_S_IDIDTHEUPDATES,
    REC_S_NOTCOMPLETE,
    SEO_S_MOREDATA,
    REC_S_NOTCOMPLETEBUTPROPAGATE,
    IDX_S_NO_BUILD_IN_PROGRESS,
    IDX_S_SEARCH_SERVER_ALREADY_EXISTS,
    IDX_S_SEARCH_SERVER_DOES_NOT_EXIST,
    IDX_S_DSS_NOT_AVAILABLE,
    JPS_S_DUPLICATE_DOC_DETECTED,
    PRTH_S_NOT_MODIFIED,
    PRTH_S_MAX_GROWTH,
    PRTH_S_MAX_DOWNLOAD,
    PRTH_S_ACL_IS_READ_EVERYONE,
    PRTH_S_USE_ROSEBUD,
    PRTH_S_NOT_ALL_PARTS,
    PRTH_S_TRY_IMPERSONATING,
    SCHED_S_TASK_READY,
    SCHED_S_TASK_RUNNING,
    SCHED_S_TASK_DISABLED,
    SCHED_S_TASK_HAS_NOT_RUN,
    SCHED_S_TASK_NO_MORE_RUNS,
    SCHED_S_TASK_NOT_SCHEDULED,
    SCHED_S_TASK_TERMINATED,
    SCHED_S_TASK_NO_VALID_TRIGGERS,
    SCHED_S_EVENT_TRIGGER,
    SCHED_S_SOME_TRIGGERS_FAILED,
    SCHED_S_BATCH_LOGON_PROBLEM,
    SCHED_S_TASK_QUEUED,
    QPLIST_S_DUPLICATE,
    FDAEMON_W_WORDLISTFULL,
    FDAEMON_W_EMPTYWORDLIST,
    SEARCH_S_NOMOREHITS,
    FILTER_W_MONIKER_CLIPPED,
    FILTER_S_LAST_TEXT,
    FILTER_S_LAST_VALUES,
    FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE,
    FILTER_S_FULL_CONTENTSCAN_IMMEDIATE,
    FILTER_S_CONTENTSCAN_DELAYED,
    FILTER_S_DISK_FULL,
    FILTER_S_NO_PROPSETS,
    FILTER_S_NO_SECURITY_DESCRIPTOR,
    LANGUAGE_S_LARGE_WORD,
    PSINK_S_LARGE_WORD,
    CI_S_WORKID_DELETED,
    CI_S_END_OF_ENUMERATION,
    CI_S_NO_DOCSTORE,
    CI_S_CAT_STOPPED,
    CI_S_NEW_AUXMETADATA,
    CI_S_CLIENT_REQUESTED_ABORT,
    CI_S_RETRY_DOCUMENT,
    CI_S_CATALOG_RESET,
    NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED,
    VSS_S_ASYNC_PENDING,
    VSS_S_ASYNC_FINISHED,
    VSS_S_ASYNC_CANCELLED,
    VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED,
    VDS_S_DISK_PARTIALLY_CLEANED,
    VDS_S_PROVIDER_ERROR_LOADING_CACHE,
    VDS_S_UPDATE_BOOTFILE_FAILED,
    VDS_S_BOOT_PARTITION_NUMBER_CHANGE,
    VDS_S_VOLUME_COMPRESS_FAILED,
    VDS_S_IN_PROGRESS,
    VDS_S_IA64_BOOT_MIRRORED_TO_MBR,
    VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES,
    VDS_S_EXTEND_FILE_SYSTEM_FAILED,
    VDS_S_MBR_BOOT_MIRRORED_TO_GPT,
    VDS_S_DISK_IS_MISSING,
    VDS_S_NONCONFORMANT_PARTITION_INFO,
    VDS_S_SYSTEM_PARTITION,
    VDS_S_NO_NOTIFICATION,
    VDS_S_DEFAULT_PLEX_MEMBER_IDS,
    VDS_S_DISMOUNT_FAILED,
    VDS_S_REMOUNT_FAILED,
    VDS_S_RESYNC_NOTIFICATION_TASK_FAILED,
    VDS_S_VSS_FLUSH_AND_HOLD_WRITES,
    VDS_S_VSS_RELEASE_WRITES,
    VDS_S_FS_LOCK,
    VDS_S_PLEX_NOT_LOADED_TO_CACHE,
    VDS_S_WINPE_BOOTENTRY,
    NOTESPH_S_IGNORE_ID,
    NOTESPH_S_LISTKNOWNFIELDS,
    VDS_S_NAME_TRUNCATED,
    VDS_S_STATUSES_INCOMPLETELY_SET,
    VDS_S_ALREADY_EXISTS,
    VDS_S_PROPERTIES_INCOMPLETE,
    VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED,
    VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED,
    VDS_S_ISCSI_LOGIN_ALREAD_EXISTS,
    VDS_S_DISK_MOUNT_FAILED,
    VDS_S_DISK_DISMOUNT_FAILED,
    REXSPH_S_REDIRECTED,
    FTE_S_RESOURCES_STARTING_TO_GET_LOW,
    FTE_S_BEYOND_QUOTA,
    FTE_S_REDUNDANT,
    FTE_S_STATUS_CHANGE_REQUEST,
    FTE_S_RESUME,
    FTE_S_PROPERTY_STORE_END_OF_ENUMERATION,
    FTE_S_READONLY_CATALOG,
    FTE_S_TRY_TO_FLUSH,
    FTE_S_CATALOG_BLOB_MISMATCHED,
    FTE_S_PROPERTY_RESET,
    VDS_S_ACCESS_PATH_NOT_DELETED,
    SP_END_OF_STREAM,
    SP_INSUFFICIENTDATA,
    SP_AUDIO_PAUSED,
    SP_AUDIO_CONVERSION_ENABLED,
    SP_NO_HYPOTHESIS_AVAILABLE,
    SP_ALREADY_IN_LEX,
    SP_LEX_NOTHING_TO_SYNC,
    SP_REQUEST_PENDING,
    SP_NO_PARSE_FOUND,
    SP_UNSUPPORTED_ON_STREAM_INPUT,
    SP_WORD_EXISTS_WITHOUT_PRONUNCIATION,
    SP_RECOGNIZER_INACTIVE,
    SP_PARTIAL_PARSE_FOUND,
    SP_NO_RULE_ACTIVE,
    SP_STREAM_UNINITIALIZED,
    SP_AUDIO_STOPPED,
    SP_COMPLETE_BUT_EXTENDABLE,
    SP_NO_RULES_TO_ACTIVATE,
    SP_NO_WORDENTRY_NOTIFICATION,
    S_LIMIT_REACHED,
    S_NOTSUPPORTED,
    FSRM_S_PARTIAL_BATCH,
    FSRM_S_PARTIAL_CLASSIFICATION,
    FSRM_S_CLASSIFICATION_SCAN_FAILURES,
    FSRM_E_AUTO_QUOTA,
    NETCFG_S_REBOOT,
    NETCFG_S_DISABLE_QUERY,
    NETCFG_S_STILL_REFERENCED,
    NETCFG_S_CAUSED_SETUP_CHANGE,
    NETCFG_S_COMMIT_NOW,
    XACT_S_ASYNC,
    XACT_S_DEFECT,
    XACT_S_READONLY,
    XACT_S_SOMENORETAIN,
    XACT_S_OKINFORM,
    XACT_S_MADECHANGESCONTENT,
    XACT_S_MADECHANGESINFORM,
    XACT_S_ALLNORETAIN,
    XACT_S_ABORTING,
    XACT_S_SINGLEPHASE,
    XACT_S_LOCALLY_OK,
    XACT_S_LASTRESOURCEMANAGER,
    S_DEVCAP_OUTPUT_FULL_REPLACEMENT,
    IO_FILE_QUOTA_THRESHOLD,
    IO_FILE_QUOTA_LIMIT,
    IO_FILE_QUOTA_STARTED,
    IO_FILE_QUOTA_SUCCEEDED,
    IO_INFO_THROTTLE_COMPLETE,
    IO_CDROM_EXCLUSIVE_LOCK,
    MSG_TEST_MESSAGE,
    SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK,
    SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL,
    SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED,
    SL_I_OOB_GRACE_PERIOD,
    SL_I_OOT_GRACE_PERIOD,
    SL_E_VL_INFO_PRODUCT_USER_RIGHT,
    SL_I_NONGENUINE_GRACE_PERIOD,
    SL_I_NONGENUINE_GRACE_PERIOD_2,
    SL_I_TIMEBASED_VALIDITY_PERIOD,
    SL_I_PERPETUAL_OOB_GRACE_PERIOD,
    SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD,
    OLE_E_OLEVERB,
    OLE_E_ADVF,
    E_NOTVALIDFORANIMATEDIMAGE,
    OLE_E_ENUM_NOMORE,
    OLE_E_ADVISENOTSUPPORTED,
    TAPI_E_NOTSUPPORTED,
    OLE_E_NOCONNECTION,
    TAPI_E_INVALIDMEDIATYPE,
    OLE_E_NOTRUNNING,
    TAPI_E_OPERATIONFAILED,
    OLE_E_NOCACHE,
    TAPI_E_ALLOCATED,
    OLE_E_BLANK,
    TAPI_E_CALLUNAVAIL,
    OLE_E_CLASSDIFF,
    TAPI_E_COMPLETIONOVERRUN,
    OLE_E_CANT_GETMONIKER,
    TAPI_E_CONFERENCEFULL,
    OLE_E_CANT_BINDTOSOURCE,
    TAPI_E_DIALMODIFIERNOTSUPPORTED,
    OLE_E_STATIC,
    TAPI_E_INUSE,
    OLE_E_PROMPTSAVECANCELLED,
    TAPI_E_INVALADDRESS,
    OLE_E_INVALIDRECT,
    TAPI_E_INVALADDRESSSTATE,
    OLE_E_WRONGCOMPOBJ,
    TAPI_E_INVALCALLPARAMS,
    OLE_E_INVALIDHWND,
    TAPI_E_INVALCALLPRIVILEGE,
    OLE_E_NOT_INPLACEACTIVE,
    TAPI_E_INVALCALLSTATE,
    OLE_E_CANTCONVERT,
    TAPI_E_INVALCARD,
    OLE_E_NOSTORAGE,
    TAPI_E_INVALCOMPLETIONID,
    TAPI_E_INVALCOUNTRYCODE,
    TAPI_E_INVALDEVICECLASS,
    TAPI_E_INVALDIALPARAMS,
    TAPI_E_INVALDIGITS,
    TAPI_E_INVALGROUPID,
    TAPI_E_INVALLOCATION,
    TAPI_E_INVALMESSAGEID,
    TAPI_E_INVALPARKID,
    IO_WRN_BAD_FIRMWARE,
    TAPI_E_INVALRATE,
    TAPI_E_INVALTIMEOUT,
    TAPI_E_INVALTONE,
    TAPI_E_INVALLIST,
    TAPI_E_INVALMODE,
    TAPI_E_NOCONFERENCE,
    IO_WRITE_CACHE_ENABLED,
    TAPI_E_NODEVICE,
    IO_RECOVERED_VIA_ECC,
    TAPI_E_NOREQUEST,
    IO_WRITE_CACHE_DISABLED,
    TAPI_E_NOTOWNER,
    TAPI_E_NOTREGISTERED,
    TAPI_E_REQUESTOVERRUN,
    TAPI_E_TARGETNOTFOUND,
    TAPI_E_TARGETSELF,
    TAPI_E_USERUSERINFOTOOBIG,
    IO_FILE_QUOTA_FAILED,
    TAPI_E_REINIT,
    TAPI_E_ADDRESSBLOCKED,
    TAPI_E_BILLINGREJECTED,
    TAPI_E_INVALFEATURE,
    TAPI_E_INVALBUTTONLAMPID,
    TAPI_E_INVALBUTTONSTATE,
    TAPI_E_INVALDATAID,
    TAPI_E_INVALHOOKSWITCHDEV,
    TAPI_E_DROPPED,
    TAPI_E_NOREQUESTRECIPIENT,
    IO_LOST_DELAYED_WRITE,
    TAPI_E_REQUESTQUEUEFULL,
    IO_WARNING_PAGING_FAILURE,
    TAPI_E_DESTBUSY,
    IO_WRN_FAILURE_PREDICTED,
    TAPI_E_DESTNOANSWER,
    IO_WARNING_INTERRUPT_STILL_PENDING,
    TAPI_E_DESTUNAVAIL,
    IO_DRIVER_CANCEL_TIMEOUT,
    TAPI_E_REQUESTFAILED,
    TAPI_E_REQUESTCANCELLED,
    IO_WARNING_ALLOCATION_FAILED,
    TAPI_E_INVALPRIVILEGE,
    IO_WARNING_LOG_FLUSH_FAILED,
    TAPI_E_INVALIDDIRECTION,
    IO_WARNING_DUPLICATE_SIGNATURE,
    TAPI_E_INVALIDTERMINAL,
    IO_WARNING_DUPLICATE_PATH,
    TAPI_E_INVALIDTERMINALCLASS,
    TAPI_E_NODRIVER,
    TAPI_E_MAXSTREAMS,
    TAPI_E_NOTERMINALSELECTED,
    TAPI_E_TERMINALINUSE,
    TAPI_E_NOTSTOPPED,
    TAPI_E_MAXTERMINALS,
    TAPI_E_INVALIDSTREAM,
    TAPI_E_TIMEOUT,
    TAPI_E_CALLCENTER_GROUP_REMOVED,
    TAPI_E_CALLCENTER_QUEUE_REMOVED,
    TAPI_E_CALLCENTER_NO_AGENT_ID,
    TAPI_E_CALLCENTER_INVALAGENTID,
    TAPI_E_CALLCENTER_INVALAGENTGROUP,
    TAPI_E_CALLCENTER_INVALPASSWORD,
    TAPI_E_CALLCENTER_INVALAGENTSTATE,
    TAPI_E_CALLCENTER_INVALAGENTACTIVITY,
    TAPI_E_REGISTRY_SETTING_CORRUPT,
    TAPI_E_TERMINAL_PEER,
    TAPI_E_PEER_NOT_SET,
    TAPI_E_NOEVENT,
    TAPI_E_INVALADDRESSTYPE,
    TAPI_E_RESOURCEUNAVAIL,
    TAPI_E_PHONENOTOPEN,
    TAPI_E_CALLNOTSELECTED,
    TAPI_E_WRONGEVENT,
    TAPI_E_NOFORMAT,
    TAPI_E_INVALIDSTREAMSTATE,
    TAPI_E_WRONG_STATE,
    TAPI_E_NOT_INITIALIZED,
    TAPI_E_SERVICE_NOT_RUNNING,
    DV_E_FORMATETC,
    DV_E_DVTARGETDEVICE,
    DV_E_STGMEDIUM,
    DV_E_STATDATA,
    DV_E_LINDEX,
    DV_E_TYMED,
    DV_E_CLIPFORMAT,
    DV_E_DVASPECT,
    DV_E_DVTARGETDEVICE_SIZE,
    DV_E_NOIVIEWOBJECT,
    IO_WARNING_BUS_RESET,
    IO_WARNING_RESET,
    IO_WARNING_WRITE_FUA_PROBLEM,
    IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED,
    IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR,
    IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR,
    IO_WARNING_VOLUME_LOST_DISK_EXTENT,
    IO_WARNING_DEVICE_HAS_INTERNAL_DUMP,
    IO_WARNING_SOFT_THRESHOLD_REACHED,
    IO_WARNING_SOFT_THRESHOLD_REACHED_EX,
    IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN,
    IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL,
    IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN,
    IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL,
    IO_WARNING_DISK_CAPACITY_CHANGED,
    IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED,
    IO_WARNING_IO_OPERATION_RETRIED,
    IO_WARNING_COMPLETION_TIME,
    IO_WARNING_DUMP_DISABLED_DEVICE_GONE,
    IO_WARNING_DISK_SURPRISE_REMOVED,
    IO_WARNING_REPEATED_DISK_GUID,
    OLE_E_LAST,
    DRAGDROP_E_NOTREGISTERED,
    DRAGDROP_E_ALREADYREGISTERED,
    DRAGDROP_E_INVALIDHWND,
    _MAPI_E_NO_SUPPORT,
    DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED,
    _MAPI_E_BAD_CHARWIDTH,
    _MAPI_E_STRING_TOO_LONG,
    _MAPI_E_UNKNOWN_FLAGS,
    _MAPI_E_INVALID_ENTRYID,
    _MAPI_E_INVALID_OBJECT,
    _MAPI_E_OBJECT_CHANGED,
    _MAPI_E_OBJECT_DELETED,
    _MAPI_E_BUSY,
    _MAPI_E_NOT_ENOUGH_DISK,
    _MAPI_E_NOT_ENOUGH_RESOURCES,
    _MAPI_E_NOT_FOUND,
    CLASS_E_NOAGGREGATION,
    _MAPI_E_VERSION,
    CLASS_E_CLASSNOTAVAILABLE,
    _MAPI_E_LOGON_FAILED,
    CLASS_E_NOTLICENSED,
    _MAPI_E_SESSION_LIMIT,
    _MAPI_E_USER_CANCEL,
    _MAPI_E_UNABLE_TO_ABORT,
    _MAPI_E_NETWORK_ERROR,
    _MAPI_E_DISK_ERROR,
    _MAPI_E_TOO_COMPLEX,
    _MAPI_E_BAD_COLUMN,
    _MAPI_E_EXTENDED_ERROR,
    _MAPI_E_COMPUTED,
    _MAPI_E_CORRUPT_DATA,
    _MAPI_E_UNCONFIGURED,
    _MAPI_E_FAILONEPROVIDER,
    _MAPI_E_UNKNOWN_CPID,
    _MAPI_E_UNKNOWN_LCID,
    _MAPI_E_PASSWORD_CHANGE_REQUIRED,
    _MAPI_E_PASSWORD_EXPIRED,
    _MAPI_E_INVALID_WORKSTATION_ACCOUNT,
    _MAPI_E_INVALID_ACCESS_TIME,
    _MAPI_E_ACCOUNT_DISABLED,
    VIEW_E_DRAW,
    REGDB_E_READREGDB,
    REGDB_E_WRITEREGDB,
    REGDB_E_KEYMISSING,
    REGDB_E_INVALIDVALUE,
    REGDB_E_CLASSNOTREG,
    E_CLASSNOTREG,
    REGDB_E_IIDNOTREG,
    REGDB_E_BADTHREADINGMODEL,
    REGDB_E_PACKAGEPOLICYVIOLATION,
    CAT_E_CATIDNOEXIST,
    CAT_E_NODESCRIPTION,
    CS_E_PACKAGE_NOTFOUND,
    CS_E_NOT_DELETABLE,
    CS_E_CLASS_NOTFOUND,
    CS_E_INVALID_VERSION,
    CS_E_NO_CLASSSTORE,
    CS_E_OBJECT_NOTFOUND,
    CS_E_OBJECT_ALREADY_EXISTS,
    CS_E_INVALID_PATH,
    CS_E_NETWORK_ERROR,
    CS_E_ADMIN_LIMIT_EXCEEDED,
    CS_E_SCHEMA_MISMATCH,
    CS_E_INTERNAL_ERROR,
    CACHE_E_NOCACHE_UPDATED,
    OLEOBJ_E_NOVERBS,
    OLEOBJ_E_INVALIDVERB,
    INPLACE_E_NOTUNDOABLE,
    INPLACE_E_NOTOOLSPACE,
    CONVERT10_E_OLESTREAM_GET,
    CONVERT10_E_OLESTREAM_PUT,
    CONVERT10_E_OLESTREAM_FMT,
    CONVERT10_E_OLESTREAM_BITMAP_TO_DIB,
    CONVERT10_E_STG_FMT,
    CONVERT10_E_STG_NO_STD_STREAM,
    CONVERT10_E_STG_DIB_TO_BITMAP,
    CLIPBRD_E_CANT_OPEN,
    CLIPBRD_E_CANT_EMPTY,
    CLIPBRD_E_CANT_SET,
    CLIPBRD_E_BAD_DATA,
    CLIPBRD_E_CANT_CLOSE,
    MK_E_CONNECTMANUALLY,
    MK_E_EXCEEDEDDEADLINE,
    MK_E_NEEDGENERIC,
    MK_E_UNAVAILABLE,
    MK_E_SYNTAX,
    MK_E_NOOBJECT,
    MK_E_INVALIDEXTENSION,
    MK_E_INTERMEDIATEINTERFACENOTSUPPORTED,
    MK_E_NOTBINDABLE,
    MK_E_NOTBOUND,
    MK_E_CANTOPENFILE,
    MK_E_MUSTBOTHERUSER,
    MK_E_NOINVERSE,
    MK_E_NOSTORAGE,
    MK_E_NOPREFIX,
    MK_E_ENUMERATION_FAILED,
    CO_E_NOTINITIALIZED,
    DDERR_NOTINITIALIZED,
    CO_E_ALREADYINITIALIZED,
    CO_E_CANTDETERMINECLASS,
    CO_E_CLASSSTRING,
    CO_E_IIDSTRING,
    CO_E_APPNOTFOUND,
    CO_E_APPSINGLEUSE,
    CO_E_ERRORINAPP,
    CO_E_DLLNOTFOUND,
    CO_E_ERRORINDLL,
    CO_E_WRONGOSFORAPP,
    CO_E_OBJNOTREG,
    CO_E_OBJISREG,
    CO_E_OBJNOTCONNECTED,
    CO_E_APPDIDNTREG,
    CO_E_RELEASED,
    VFW_E_INVALIDMEDIATYPE,
    _MAPI_E_END_OF_SESSION,
    MPEG2_E_UNINITIALIZED,
    TF_E_INVALIDPOS,
    TS_E_INVALIDPOS,
    UPNP_E_ROOT_ELEMENT_EXPECTED,
    USP_E_SCRIPT_NOT_IN_FONT,
    EVENT_E_ALL_SUBSCRIBERS_FAILED,
    VFW_E_INVALIDSUBTYPE,
    CDO_E_UNCAUGHT_EXCEPTION,
    _MAPI_E_UNKNOWN_ENTRYID,
    MPEG2_E_ALREADY_INITIALIZED,
    TF_E_NOLOCK,
    TS_E_NOLOCK,
    UPNP_E_DEVICE_ELEMENT_EXPECTED,
    VFW_E_NEED_OWNER,
    CDO_E_NOT_OPENED,
    _MAPI_E_MISSING_REQUIRED_COLUMN,
    MPEG2_E_OUT_OF_BOUNDS,
    TF_E_NOOBJECT,
    TS_E_NOOBJECT,
    UPNP_E_SERVICE_ELEMENT_EXPECTED,
    EVENT_E_QUERYSYNTAX,
    VFW_E_ENUM_OUT_OF_SYNC,
    CDO_E_UNSUPPORTED_DATASOURCE,
    MPEG2_E_MALFORMED_TABLE,
    TF_E_NOSERVICE,
    TS_E_NOSERVICE,
    UPNP_E_SERVICE_NODE_INCOMPLETE,
    EVENT_E_QUERYFIELD,
    VFW_E_ALREADY_CONNECTED,
    CDO_E_INVALID_PROPERTYNAME,
    MPEG2_E_UNDEFINED,
    TF_E_NOINTERFACE,
    TS_E_NOINTERFACE,
    UPNP_E_DEVICE_NODE_INCOMPLETE,
    EVENT_E_INTERNALEXCEPTION,
    VFW_E_FILTER_ACTIVE,
    CDO_E_PROP_UNSUPPORTED,
    MPEG2_E_NOT_PRESENT,
    TF_E_NOSELECTION,
    TS_E_NOSELECTION,
    UPNP_E_ICON_ELEMENT_EXPECTED,
    EVENT_E_INTERNALERROR,
    VFW_E_NO_TYPES,
    CDO_E_INACTIVE,
    MPEG2_E_SECTION_NOT_FOUND,
    TF_E_NOLAYOUT,
    TS_E_NOLAYOUT,
    UPNP_E_ICON_NODE_INCOMPLETE,
    EVENT_E_INVALID_PER_USER_SID,
    VFW_E_NO_ACCEPTABLE_TYPES,
    CDO_E_NO_SUPPORT_FOR_OBJECTS,
    MPEG2_E_TX_STREAM_UNAVAILABLE,
    TF_E_INVALIDPOINT,
    TS_E_INVALIDPOINT,
    UPNP_E_INVALID_ACTION,
    EVENT_E_USER_EXCEPTION,
    VFW_E_INVALID_DIRECTION,
    CDO_E_NOT_AVAILABLE,
    MPEG2_E_SERVICE_ID_NOT_FOUND,
    TF_E_SYNCHRONOUS,
    TS_E_SYNCHRONOUS,
    UPNP_E_INVALID_ARGUMENTS,
    EVENT_E_TOO_MANY_METHODS,
    VFW_E_NOT_CONNECTED,
    CDO_E_NO_DEFAULT_DROP_DIR,
    MPEG2_E_SERVICE_PMT_NOT_FOUND,
    TF_E_READONLY,
    TS_E_READONLY,
    UPNP_E_OUT_OF_SYNC,
    EVENT_E_MISSING_EVENTCLASS,
    VFW_E_NO_ALLOCATOR,
    CDO_E_SMTP_SERVER_REQUIRED,
    MPEG2_E_DSI_NOT_FOUND,
    TF_E_FORMAT,
    TS_E_FORMAT,
    EVENT_E_NOT_ALL_REMOVED,
    VFW_E_RUNTIME_ERROR,
    CDO_E_NNTP_SERVER_REQUIRED,
    IMAPI_E_NOTOPENED,
    MPEG2_E_SERVER_UNAVAILABLE,
    EVENT_E_COMPLUS_NOT_INSTALLED,
    VFW_E_BUFFER_NOTSET,
    CDO_E_RECIPIENT_MISSING,
    IMAPI_E_NOTINITIALIZED,
    MPEG2_E_INVALID_CAROUSEL_ID,
    EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT,
    VFW_E_BUFFER_OVERFLOW,
    CDO_E_FROM_MISSING,
    IMAPI_E_USERABORT,
    MPEG2_E_MALFORMED_DSMCC_MESSAGE,
    EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT,
    VFW_E_BADALIGN,
    CDO_E_SENDER_REJECTED,
    IMAPI_E_GENERIC,
    MPEG2_E_INVALID_SG_OBJECT_KIND,
    EVENT_E_INVALID_EVENT_CLASS_PARTITION,
    VFW_E_ALREADY_COMMITTED,
    CDO_E_RECIPIENTS_REJECTED,
    IMAPI_E_MEDIUM_NOTPRESENT,
    MPEG2_E_OBJECT_NOT_FOUND,
    EVENT_E_PER_USER_SID_NOT_LOGGED_ON,
    VFW_E_BUFFERS_OUTSTANDING,
    CDO_E_NNTP_POST_FAILED,
    IMAPI_E_MEDIUM_INVALIDTYPE,
    MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY,
    UPNP_E_ACTION_REQUEST_FAILED,
    VFW_E_NOT_COMMITTED,
    CDO_E_SMTP_SEND_FAILED,
    IMAPI_E_DEVICE_NOPROPERTIES,
    MPEG2_E_OBJECT_KIND_NOT_A_FILE,
    UPNP_E_TRANSPORT_ERROR,
    TPC_E_NO_DEFAULT_TABLET,
    VFW_E_SIZENOTSET,
    CDO_E_CONNECTION_DROPPED,
    IMAPI_E_DEVICE_NOTACCESSIBLE,
    MPEG2_E_FILE_OFFSET_TOO_BIG,
    UPNP_E_VARIABLE_VALUE_UNKNOWN,
    VFW_E_NO_CLOCK,
    CDO_E_FAILED_TO_CONNECT,
    IMAPI_E_DEVICE_NOTPRESENT,
    MPEG2_E_STREAM_STOPPED,
    UPNP_E_INVALID_VARIABLE,
    VFW_E_NO_SINK,
    CDO_E_INVALID_POST,
    IMAPI_E_DEVICE_INVALIDTYPE,
    MPEG2_E_REGISTRY_ACCESS_FAILED,
    UPNP_E_DEVICE_ERROR,
    VFW_E_NO_INTERFACE,
    CDO_E_AUTHENTICATION_FAILURE,
    IMAPI_E_INITIALIZE_WRITE,
    MPEG2_E_INVALID_UDP_PORT,
    UPNP_E_PROTOCOL_ERROR,
    VFW_E_NOT_FOUND,
    CDO_E_INVALID_CONTENT_TYPE,
    IMAPI_E_INITIALIZE_ENDWRITE,
    MPEG2_E_DATA_SOURCE_FAILED,
    UPNP_E_ERROR_PROCESSING_RESPONSE,
    VFW_E_CANNOT_CONNECT,
    CDO_E_LOGON_FAILURE,
    IMAPI_E_FILESYSTEM,
    MPEG2_E_DII_NOT_FOUND,
    UPNP_E_DEVICE_TIMEOUT,
    VFW_E_CANNOT_RENDER,
    CDO_E_HTTP_NOT_FOUND,
    IMAPI_E_FILEACCESS,
    MPEG2_E_DSHOW_PIN_NOT_FOUND,
    TPC_E_INVALID_INPUT_RECT,
    VFW_E_CHANGING_FORMAT,
    CDO_E_HTTP_FORBIDDEN,
    IMAPI_E_DISCINFO,
    MPEG2_E_BUFFER_TOO_SMALL,
    VFW_E_NO_COLOR_KEY_SET,
    CDO_E_HTTP_FAILED,
    IMAPI_E_TRACKNOTOPEN,
    MPEG2_E_MISSING_SECTIONS,
    TPC_E_UNKNOWN_PROPERTY,
    VFW_E_NOT_OVERLAY_CONNECTION,
    CDO_E_MULTIPART_NO_DATA,
    IMAPI_E_TRACKOPEN,
    MPEG2_E_TOO_MANY_SECTIONS,
    VFW_E_NOT_SAMPLE_CONNECTION,
    CDO_E_INVALID_ENCODING_FOR_MULTIPART,
    IMAPI_E_DISCFULL,
    MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE,
    VFW_E_PALETTE_SET,
    CDO_E_UNSAFE_OPERATION,
    IMAPI_E_BADJOLIETNAME,
    MPEG2_E_INCORRECT_DESCRIPTOR_TAG,
    VFW_E_COLOR_KEY_SET,
    CDO_E_PROP_NOT_FOUND,
    IMAPI_E_INVALIDIMAGE,
    VFW_E_NO_COLOR_KEY_FOUND,
    IMAPI_E_NOACTIVEFORMAT,
    VFW_E_NO_PALETTE_AVAILABLE,
    CDO_E_INVALID_SEND_OPTION,
    IMAPI_E_NOACTIVERECORDER,
    VFW_E_NO_DISPLAY_PALETTE,
    CDO_E_INVALID_POST_OPTION,
    IMAPI_E_WRONGFORMAT,
    TPC_E_INVALID_STROKE,
    VFW_E_TOO_MANY_COLORS,
    CDO_E_NO_PICKUP_DIR,
    IMAPI_E_ALREADYOPEN,
    TPC_E_INITIALIZE_FAIL,
    VFW_E_STATE_CHANGED,
    CDO_E_NOT_ALL_DELETED,
    IMAPI_E_WRONGDISC,
    VFW_E_NOT_STOPPED,
    CDO_E_NO_METHOD,
    IMAPI_E_FILEEXISTS,
    VFW_E_NOT_PAUSED,
    IMAPI_E_STASHINUSE,
    VFW_E_NOT_RUNNING,
    IMAPI_E_DEVICE_STILL_IN_USE,
    VFW_E_WRONG_STATE,
    CDO_E_PROP_READONLY,
    IMAPI_E_LOSS_OF_STREAMING,
    VFW_E_START_TIME_AFTER_END,
    CDO_E_PROP_CANNOT_DELETE,
    IMAPI_E_COMPRESSEDSTASH,
    VFW_E_INVALID_RECT,
    CDO_E_BAD_DATA,
    IMAPI_E_ENCRYPTEDSTASH,
    VFW_E_TYPE_NOT_ACCEPTED,
    CDO_E_PROP_NONHEADER,
    IMAPI_E_NOTENOUGHDISKFORSTASH,
    VFW_E_SAMPLE_REJECTED,
    CDO_E_INVALID_CHARSET,
    IMAPI_E_REMOVABLESTASH,
    VFW_E_SAMPLE_REJECTED_EOS,
    CDO_E_ADOSTREAM_NOT_BOUND,
    IMAPI_E_CANNOT_WRITE_TO_MEDIA,
    VFW_E_DUPLICATE_NAME,
    CDO_E_CONTENTPROPXML_NOT_FOUND,
    IMAPI_E_TRACK_NOT_BIG_ENOUGH,
    VFW_E_TIMEOUT,
    CDO_E_CONTENTPROPXML_WRONG_CHARSET,
    VFW_E_INVALID_FILE_FORMAT,
    CDO_E_CONTENTPROPXML_PARSE_FAILED,
    VFW_E_ENUM_OUT_OF_RANGE,
    CDO_E_CONTENTPROPXML_CONVERT_FAILED,
    VFW_E_CIRCULAR_GRAPH,
    CDO_E_NO_DIRECTORIES_SPECIFIED,
    TPC_E_NOT_RELEVANT,
    VFW_E_NOT_ALLOWED_TO_SAVE,
    CDO_E_DIRECTORIES_UNREACHABLE,
    TPC_E_INVALID_PACKET_DESCRIPTION,
    VFW_E_TIME_ALREADY_PASSED,
    CDO_E_BAD_SENDER,
    VFW_E_ALREADY_CANCELLED,
    CDO_E_SELF_BINDING,
    TPC_E_RECOGNIZER_NOT_REGISTERED,
    VFW_E_CORRUPT_GRAPH_FILE,
    CDO_E_BAD_ATTENDEE_DATA,
    TPC_E_INVALID_RIGHTS,
    VFW_E_ADVISE_ALREADY_SET,
    CDO_E_ROLE_NOMORE_AVAILABLE,
    TPC_E_OUT_OF_ORDER_CALL,
    CDO_E_BAD_TASKTYPE_ONASSIGN,
    TPC_E_QUEUE_FULL,
    VFW_E_NO_MODEX_AVAILABLE,
    CDO_E_NOT_ASSIGNEDTO_USER,
    TPC_E_INVALID_CONFIGURATION,
    VFW_E_NO_ADVISE_SET,
    CDO_E_OUTOFDATE,
    TPC_E_INVALID_DATA_FROM_RECOGNIZER,
    VFW_E_NO_FULLSCREEN,
    VFW_E_IN_FULLSCREEN_MODE,
    VFW_E_UNKNOWN_FILE_TYPE,
    TPC_E_INVALID_PROPERTY,
    VFW_E_CANNOT_LOAD_SOURCE_FILTER,
    VFW_E_FILE_TOO_SHORT,
    VFW_E_INVALID_FILE_VERSION,
    VFW_E_INVALID_CLSID,
    VFW_E_INVALID_MEDIA_TYPE,
    VFW_E_SAMPLE_TIME_NOT_SET,
    VFW_E_MEDIA_TIME_NOT_SET,
    VFW_E_NO_TIME_FORMAT_SET,
    VFW_E_MONO_AUDIO_HW,
    VFW_E_NO_DECOMPRESSOR,
    VFW_E_NO_AUDIO_HARDWARE,
    VFW_E_RPZA,
    VFW_E_PROCESSOR_NOT_SUITABLE,
    VFW_E_UNSUPPORTED_AUDIO,
    VFW_E_UNSUPPORTED_VIDEO,
    VFW_E_MPEG_NOT_CONSTRAINED,
    VFW_E_NOT_IN_GRAPH,
    VFW_E_NO_TIME_FORMAT,
    VFW_E_READ_ONLY,
    VFW_E_BUFFER_UNDERFLOW,
    VFW_E_UNSUPPORTED_STREAM,
    VFW_E_NO_TRANSPORT,
    VFW_E_BAD_VIDEOCD,
    VFW_S_NO_STOP_TIME,
    VFW_E_OUT_OF_VIDEO_MEMORY,
    VFW_E_VP_NEGOTIATION_FAILED,
    VFW_E_DDRAW_CAPS_NOT_SUITABLE,
    VFW_E_NO_VP_HARDWARE,
    VFW_E_NO_CAPTURE_HARDWARE,
    VFW_E_DVD_OPERATION_INHIBITED,
    VFW_E_DVD_INVALIDDOMAIN,
    VFW_E_DVD_NO_BUTTON,
    VFW_E_DVD_GRAPHNOTREADY,
    VFW_E_DVD_RENDERFAIL,
    VFW_E_DVD_DECNOTENOUGH,
    VFW_E_DDRAW_VERSION_NOT_SUITABLE,
    VFW_E_COPYPROT_FAILED,
    VFW_E_TIME_EXPIRED,
    VFW_E_DVD_WRONG_SPEED,
    VFW_E_DVD_MENU_DOES_NOT_EXIST,
    VFW_E_DVD_CMD_CANCELLED,
    VFW_E_DVD_STATE_WRONG_VERSION,
    VFW_E_DVD_STATE_CORRUPT,
    VFW_E_DVD_STATE_WRONG_DISC,
    VFW_E_DVD_INCOMPATIBLE_REGION,
    VFW_E_DVD_NO_ATTRIBUTES,
    VFW_E_DVD_NO_GOUP_PGC,
    VFW_E_DVD_LOW_PARENTAL_LEVEL,
    VFW_E_DVD_NOT_IN_KARAOKE_MODE,
    VFW_E_FRAME_STEP_UNSUPPORTED,
    VFW_E_DVD_STREAM_DISABLED,
    VFW_E_DVD_TITLE_UNKNOWN,
    VFW_E_DVD_INVALID_DISC,
    VFW_E_DVD_NO_RESUME_INFORMATION,
    VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD,
    VFW_E_PIN_ALREADY_BLOCKED,
    VFW_E_CERTIFICATION_FAILURE,
    VFW_E_VMR_NOT_IN_MIXER_MODE,
    VFW_E_VMR_NO_AP_SUPPLIED,
    VFW_E_VMR_NO_DEINTERLACE_HW,
    VFW_E_VMR_NO_PROCAMP_HW,
    VFW_E_DVD_VMR9_INCOMPATIBLEDEC,
    VFW_E_NO_COPP_HW,
    VFW_E_DVD_NONBLOCKING,
    VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH,
    VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH,
    VFW_E_DVD_RESOLUTION_ERROR,
    NET_E_GENERAL,
    FHCFG_E_CORRUPT_CONFIG_FILE,
    UPNP_E_ACTION_SPECIFIC_BASE,
    FHCFG_E_CONFIG_FILE_NOT_FOUND,
    FHCFG_E_CONFIG_ALREADY_EXISTS,
    NET_E_DISCONNECTED,
    FHCFG_E_NO_VALID_CONFIGURATION_LOADED,
    FHCFG_E_TARGET_NOT_CONNECTED,
    FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED,
    FHCFG_E_TARGET_VERIFICATION_FAILED,
    FHCFG_E_TARGET_NOT_CONFIGURED,
    NET_E_INVALIDPARAMS,
    FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE,
    NET_E_OPERATIONINPROGRESS,
    FHCFG_E_TARGET_CANNOT_BE_USED,
    VFW_E_CODECAPI_LINEAR_RANGE,
    FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED,
    VFW_E_CODECAPI_ENUMERATED,
    FHCFG_E_TARGET_REHYDRATED_ELSEWHERE,
    FHCFG_E_LEGACY_TARGET_UNSUPPORTED,
    VFW_E_CODECAPI_NO_DEFAULT,
    FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED,
    VFW_E_CODECAPI_NO_CURRENT_VALUE,
    FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED,
    VFW_E_DVD_CHAPTER_DOES_NOT_EXIST,
    FHCFG_E_LEGACY_BACKUP_NOT_FOUND,
    VFW_E_BAD_KEY,
    DS_E_NOMOREDATA,
    DS_E_INVALIDDATASOURCE,
    MS_E_SAMPLEALLOC,
    DS_E_DATASOURCENOTAVAILABLE,
    MS_E_PURPOSEID,
    DS_E_QUERYCANCELED,
    MS_E_NOSTREAM,
    DS_E_UNKNOWNREQUEST,
    MS_E_NOSEEKING,
    DS_E_BADREQUEST,
    MS_E_INCOMPATIBLE,
    DS_E_SERVERCAPACITY,
    MS_E_BUSY,
    DS_E_BADSEQUENCE,
    MS_E_NOTINIT,
    DS_E_MESSAGETOOLONG,
    MS_E_SOURCEALREADYDEFINED,
    DS_E_SERVERERROR,
    MS_E_INVALIDSTREAMTYPE,
    DS_E_CONFIGBAD,
    MS_E_NOTRUNNING,
    DS_E_DATANOTPRESENT,
    DS_E_SETSTATUSINPROGRESS,
    DS_E_DUPLICATEID,
    DS_E_TOOMANYDATASOURCES,
    DS_E_REGISTRY,
    DS_E_DATASOURCENOTDISABLED,
    DS_E_INVALIDTAGDB,
    DS_E_INVALIDCATALOGNAME,
    DS_E_CONFIGNOTRIGHTTYPE,
    DS_E_PROTOCOLVERSION,
    DS_E_ALREADYENABLED,
    DS_E_INDEXDIRECTORY,
    DS_E_VALUETOOLARGE,
    DS_E_UNKNOWNPARAM,
    DS_E_BUFFERTOOSMALL,
    DS_E_PARAMOUTOFRANGE,
    DS_E_ALREADYDISABLED,
    DS_E_QUERYHUNG,
    DS_E_BADRESULT,
    DS_E_CANNOTWRITEREGISTRY,
    DS_E_CANNOTREMOVECONCURRENT,
    DS_E_SEARCHCATNAMECOLLISION,
    DS_E_PROPVERSIONMISMATCH,
    DS_E_MISSINGCATALOG,
    UPNP_E_ACTION_SPECIFIC_MAX,
    TF_E_LOCKED,
    UPNP_E_INVALID_DOCUMENT,
    COLL_E_BADSEQUENCE,
    TF_E_STACKFULL,
    UPNP_E_EVENT_SUBSCRIPTION_FAILED,
    COLL_E_NOMOREDATA,
    TF_E_NOTOWNEDRANGE,
    COLL_E_INCOMPATIBLECOLUMNS,
    TF_E_NOPROVIDER,
    COLL_E_BUFFERTOOSMALL,
    TF_E_DISCONNECTED,
    TF_E_INVALIDVIEW,
    COLL_E_BADRESULT,
    TF_E_ALREADY_EXISTS,
    COLL_E_NOSORTCOLUMN,
    TF_E_RANGE_NOT_COVERED,
    COLL_E_DUPLICATEDBID,
    TF_E_COMPOSITION_REJECTED,
    COLL_E_TOOMANYMERGECOLUMNS,
    TF_E_EMPTYCONTEXT,
    COLL_E_NODEFAULTCATALOG,
    COLL_E_MAXCONNEXCEEDED,
    FHSVC_E_BACKUP_BLOCKED,
    CM_E_TOOMANYDATASERVERS,
    FHSVC_E_NOT_CONFIGURED,
    CM_E_TOOMANYDATASOURCES,
    FHSVC_E_CONFIG_DISABLED,
    CM_E_NOQUERYCONNECTIONS,
    FHSVC_E_CONFIG_DISABLED_GP,
    CM_E_DATASOURCENOTAVAILABLE,
    FHSVC_E_FATAL_CONFIG_ERROR,
    CM_E_CONNECTIONTIMEOUT,
    FHSVC_E_CONFIG_REHYDRATING,
    CM_E_SERVERNOTFOUND,
    CM_E_REGISTRY,
    CM_E_INVALIDDATASOURCE,
    CM_E_TIMEOUT,
    CM_E_INSUFFICIENTBUFFER,
    QRY_E_QUERYSYNTAX,
    QRY_E_TYPEMISMATCH,
    QRY_E_UNHANDLEDTYPE,
    QRY_E_TOOMANYCOLUMNS,
    QRY_E_TOOMANYDATABASES,
    QRY_E_STARTHITTOBIG,
    QRY_E_TOOMANYQUERYTERMS,
    QRY_E_NODATASOURCES,
    QRY_E_TIMEOUT,
    QRY_E_COLUMNNOTSORTABLE,
    QRY_E_COLUMNNOTSEARCHABLE,
    QRY_E_INVALIDCOLUMN,
    QRY_E_QUERYCORRUPT,
    QRY_E_PREFIXWILDCARD,
    QRY_E_INFIXWILDCARD,
    QRY_E_WILDCARDPREFIXLENGTH,
    QRY_E_ENGINEFAILED,
    QRY_E_SEARCHTOOBIG,
    QRY_E_NULLQUERY,
    QRY_E_NOCOLUMNS,
    QRY_E_INVALIDSCOPES,
    QRY_E_INVALIDCATALOG,
    QRY_E_SCOPECARDINALIDY,
    QRY_E_UNEXPECTED,
    QRY_E_INVALIDPATH,
    QRY_E_LMNOTINITIALIZED,
    QRY_E_INVALIDINTERVAL,
    QRY_E_NOLOGMANAGER,
    SCHEMA_E_LOAD_SPECIAL,
    SCHEMA_E_FILENOTFOUND,
    SCHEMA_E_NESTEDTAG,
    SCHEMA_E_UNEXPECTEDTAG,
    SCHEMA_E_VERSIONMISMATCH,
    SCHEMA_E_CANNOTCREATEFILE,
    SCHEMA_E_CANNOTWRITEFILE,
    SCHEMA_E_EMPTYFILE,
    SCHEMA_E_INVALIDFILETYPE,
    SCHEMA_E_INVALIDDATATYPE,
    SCHEMA_E_CANNOTCREATENOISEWORDFILE,
    SCHEMA_E_ADDSTOPWORDS,
    SCHEMA_E_NAMEEXISTS,
    SCHEMA_E_INVALIDVALUE,
    SCHEMA_E_BADPROPSPEC,
    SCHEMA_E_NOMORECOLUMNS,
    SCHEMA_E_FILECHANGED,
    SCHEMA_E_BADCOLUMNNAME,
    SCHEMA_E_BADPROPPID,
    SCHEMA_E_BADATTRIBUTE,
    SCHEMA_E_BADFILENAME,
    SCHEMA_E_PROPEXISTS,
    SCHEMA_E_DUPLICATENOISE,
    GTHR_E_DUPLICATE_OBJECT,
    GTHR_E_UNABLE_TO_READ_REGISTRY,
    GTHR_E_ERROR_WRITING_REGISTRY,
    GTHR_E_ERROR_INITIALIZING_PERFMON,
    GTHR_E_ERROR_OBJECT_NOT_FOUND,
    GTHR_E_URL_EXCLUDED,
    GTHR_E_CONFIG_DUP_PROJECT,
    GTHR_E_CONFIG_DUP_EXTENSION,
    GTHR_E_DUPLICATE_URL,
    GTHR_E_TOO_MANY_PLUGINS,
    GTHR_E_INVALIDFUNCTION,
    GTHR_E_NOFILTERSINK,
    GTHR_E_FILTER_PROCESS_TERMINATED,
    GTHR_E_FILTER_INVALID_MESSAGE,
    GTHR_E_UNSUPPORTED_PROPERTY_TYPE,
    GTHR_E_NAME_TOO_LONG,
    GTHR_E_NO_IDENTITY,
    GTHR_E_FILTER_NOT_FOUND,
    GTHR_E_FILTER_NO_MORE_THREADS,
    GTHR_E_PRT_HNDLR_PROGID_MISSING,
    GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA,
    GTHR_E_UNKNOWN_PROTOCOL,
    GTHR_E_PROJECT_NOT_INITIALIZED,
    GTHR_E_INVALID_PROJECT_NAME,
    GTHR_E_SHUTTING_DOWN,
    GTHR_E_VALUE_NOT_AVAILABLE,
    GTHR_E_OUT_OF_DOC_ID,
    GTHR_E_NOTIFICATION_START_PAGE,
    GTHR_E_DUP_PROPERTY_MAPPING,
    GTHR_E_INVALID_ACCOUNT,
    GTHR_E_FILTER_INIT,
    GTHR_E_INVALID_ACCOUNT_SYNTAX,
    GTHR_E_PROXY_NAME,
    GTHR_E_SERVER_UNAVAILABLE,
    GTHR_E_INVALID_PATH,
    GTHR_E_FILTER_NO_CODEPAGE,
    GTHR_E_NO_PRTCLHNLR,
    GTHR_E_IE_OFFLINE,
    GTHR_E_BAD_FILTER_DAEMON,
    GTHR_E_INVALID_MAPPING,
    GTHR_E_USER_AGENT_NOT_SPECIFIED,
    GTHR_E_FROM_NOT_SPECIFIED,
    GTHR_E_INVALID_STREAM_LOGS_COUNT,
    GTHR_E_INVALID_EXTENSION,
    GTHR_E_INVALID_GROW_FACTOR,
    GTHR_E_INVALID_TIME_OUT,
    GTHR_E_INVALID_RETRIES,
    GTHR_E_INVALID_LOG_FILE_NAME,
    GTHR_E_INVALID_HOST_NAME,
    GTHR_E_INVALID_START_PAGE,
    GTHR_E_DUPLICATE_PROJECT,
    GTHR_E_INVALID_DIRECTORY,
    GTHR_E_FILTER_INTERRUPTED,
    GTHR_E_INVALID_PROXY_PORT,
    GTHR_E_SECRET_NOT_FOUND,
    GTHR_E_INVALID_PATH_EXPRESSION,
    GTHR_E_INVALID_START_PAGE_HOST,
    GTHR_E_INVALID_START_PAGE_PATH,
    GTHR_E_APPLICATION_NOT_FOUND,
    GTHR_E_CANNOT_REMOVE_PLUGINMGR,
    GTHR_E_INVALID_APPLICATION_NAME,
    GTHR_E_FILTER_FAULT,
    GTHR_E_NON_FIXED_DRIVE,
    GTHR_E_FILTER_SINGLE_THREADED,
    GTHR_E_URL_UNIDENTIFIED,
    GTHR_E_FORCE_NOTIFICATION_RESET,
    GTHR_E_CONTENT_ID_CONFLICT,
    GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE,
    GTHR_E_RECOVERABLE_EXOLEDB_ERROR,
    GTHR_E_INVALID_CALL_FROM_WBREAKER,
    GTHR_E_PROPERTY_LIST_NOT_INITIALIZED,
    GHTR_E_LOCAL_SERVER_UNAVAILABLE,
    GTHR_E_SCHEMA_ERRORS_OCCURRED,
    GTHR_E_TIMEOUT,
    GTHR_E_NOTIFICATION_START_ADDRESS_INVALID,
    GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED,
    GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE,
    GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE,
    GHTR_E_INSUFFICIENT_DISK_SPACE,
    GTHR_E_INVALID_RESOURCE_ID,
    GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES,
    GTHR_E_RETRY,
    GTHR_E_JET_BACKUP_ERROR,
    GTHR_E_JET_RESTORE_ERROR,
    GTHR_E_PLUGIN_NOT_REGISTERED,
    GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED,
    GTHR_E_DIRMON_NOT_INITIALZED,
    GTHR_E_NOTIF_BEING_REMOVED,
    GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT,
    GTHR_E_INVALID_PATH_SPEC,
    GTHR_E_INSUFFICIENT_FEATURE_TERMS,
    GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES,
    GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS,
    GTHR_E_AUTOCAT_UNEXPECTED,
    GTHR_E_SINGLE_THREADED_EMBEDDING,
    GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE,
    GTHR_E_EMPTY_DACL,
    GTHR_E_OBJECT_NOT_VALID,
    GTHR_E_CANNOT_ENABLE_CHECKPOINT,
    GTHR_E_SCOPES_EXCEEDED,
    GTHR_E_PROPERTIES_EXCEEDED,
    GTHR_E_INVALID_START_ADDRESS,
    GTHR_E_PIPE_NOT_CONNECTTED,
    GTHR_E_BACKUP_VALIDATION_FAIL,
    GTHR_E_BAD_FILTER_HOST,
    GTHR_E_FILTERPOOL_NOTFOUND,
    GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT,
    DB_E_BADACCESSORHANDLE,
    DB_E_ROWLIMITEXCEEDED,
    DB_E_READONLYACCESSOR,
    DB_E_SCHEMAVIOLATION,
    DB_E_BADROWHANDLE,
    DB_E_OBJECTOPEN,
    DB_E_BADCHAPTER,
    DB_E_CANTCONVERTVALUE,
    DB_E_BADBINDINFO,
    DB_SEC_E_PERMISSIONDENIED,
    DB_E_NOTAREFERENCECOLUMN,
    DB_E_LIMITREJECTED,
    DB_E_NOCOMMAND,
    DB_E_COSTLIMIT,
    DB_E_BADBOOKMARK,
    DB_E_BADLOCKMODE,
    DB_E_PARAMNOTOPTIONAL,
    DB_E_BADCOLUMNID,
    DB_E_BADRATIO,
    DB_E_BADVALUES,
    DB_E_ERRORSINCOMMAND,
    DB_E_CANTCANCEL,
    DB_E_DIALECTNOTSUPPORTED,
    DB_E_DUPLICATEDATASOURCE,
    DB_E_CANNOTRESTART,
    DB_E_NOTFOUND,
    DB_E_CANNOTFREE,
    DB_E_NEWLYINSERTED,
    DB_E_GOALREJECTED,
    DB_E_UNSUPPORTEDCONVERSION,
    DB_E_BADSTARTPOSITION,
    DB_E_NOQUERY,
    DB_E_NOTREENTRANT,
    DB_E_ERRORSOCCURRED,
    DB_E_NOAGGREGATION,
    DB_E_DELETEDROW,
    DB_E_CANTFETCHBACKWARDS,
    DB_E_ROWSNOTRELEASED,
    DB_E_BADSTORAGEFLAG,
    DB_E_BADCOMPAREOP,
    DB_E_BADSTATUSVALUE,
    DB_E_CANTSCROLLBACKWARDS,
    DB_E_BADREGIONHANDLE,
    DB_E_NONCONTIGUOUSRANGE,
    DB_E_INVALIDTRANSITION,
    DB_E_NOTASUBREGION,
    DB_E_MULTIPLESTATEMENTS,
    DB_E_INTEGRITYVIOLATION,
    DB_E_BADTYPENAME,
    DB_E_ABORTLIMITREACHED,
    DB_E_ROWSETINCOMMAND,
    DB_E_CANTTRANSLATE,
    DB_E_DUPLICATEINDEXID,
    DB_E_NOINDEX,
    DB_E_INDEXINUSE,
    DB_E_NOTABLE,
    DB_E_CONCURRENCYVIOLATION,
    DB_E_BADCOPY,
    DB_E_BADPRECISION,
    DB_E_BADSCALE,
    DB_E_BADTABLEID,
    DB_E_BADTYPE,
    DB_E_DUPLICATECOLUMNID,
    DB_E_DUPLICATETABLEID,
    DB_E_TABLEINUSE,
    DB_E_NOLOCALE,
    DB_E_BADRECORDNUM,
    DB_E_BOOKMARKSKIPPED,
    DB_E_BADPROPERTYVALUE,
    DB_E_INVALID,
    DB_E_BADACCESSORFLAGS,
    DB_E_BADSTORAGEFLAGS,
    DB_E_BYREFACCESSORNOTSUPPORTED,
    DB_E_NULLACCESSORNOTSUPPORTED,
    DB_E_NOTPREPARED,
    DB_E_BADACCESSORTYPE,
    DB_E_WRITEONLYACCESSOR,
    DB_SEC_E_AUTH_FAILED,
    DB_E_CANCELED,
    DB_E_CHAPTERNOTRELEASED,
    DB_E_BADSOURCEHANDLE,
    DB_E_PARAMUNAVAILABLE,
    DB_E_ALREADYINITIALIZED,
    DB_E_NOTSUPPORTED,
    DB_E_MAXPENDCHANGESEXCEEDED,
    DB_E_BADORDINAL,
    DB_E_PENDINGCHANGES,
    DB_E_DATAOVERFLOW,
    DB_E_BADHRESULT,
    DB_E_BADLOOKUPID,
    DB_E_BADDYNAMICERRORID,
    DB_E_PENDINGINSERT,
    DB_E_BADCONVERTFLAG,
    DB_E_BADPARAMETERNAME,
    DB_E_MULTIPLESTORAGE,
    DB_E_CANTFILTER,
    DB_E_CANTORDER,
    MD_E_BADTUPLE,
    MD_E_BADCOORDINATE,
    MD_E_INVALIDAXIS,
    MD_E_INVALIDCELLRANGE,
    DB_E_NOCOLUMN,
    DB_E_COMMANDNOTPERSISTED,
    DB_E_DUPLICATEID,
    DB_E_OBJECTCREATIONLIMITREACHED,
    SEC_E_BADTRUSTEEID,
    SEC_E_NOTRUSTEEID,
    SEC_E_NOMEMBERSHIPSUPPORT,
    SEC_E_INVALIDOBJECT,
    SEC_E_NOOWNER,
    SEC_E_INVALIDACCESSENTRYLIST,
    SEC_E_INVALIDOWNER,
    SEC_E_INVALIDACCESSENTRY,
    DB_E_BADINDEXID,
    DB_E_BADINITSTRING,
    DB_E_NOPROVIDERSREGISTERED,
    DB_E_MISMATCHEDPROVIDER,
    DB_E_BADCOMMANDID,
    DB_E_BADCONSTRAINTTYPE,
    DB_E_BADCONSTRAINTFORM,
    DB_E_BADDEFERRABILITY,
    DB_E_BADMATCHTYPE,
    DB_E_BADUPDATEDELETERULE,
    DB_E_BADCONSTRAINTID,
    DB_E_BADCOMMANDFLAGS,
    DB_E_OBJECTMISMATCH,
    DB_E_RESOURCEOUTOFSCOPE,
    DB_E_DROPRESTRICTED,
    DB_E_NOSOURCEOBJECT,
    DB_E_RESOURCELOCKED,
    DB_E_NOTCOLLECTION,
    DB_E_READONLY,
    DB_E_ASYNCNOTSUPPORTED,
    DB_E_CANNOTCONNECT,
    DB_E_TIMEOUT,
    DB_E_RESOURCEEXISTS,
    DB_E_DUPLICATECONSTRAINTID,
    DB_E_OUTOFSPACE,
    DB_SEC_E_SAFEMODE_DENIED,
    DB_E_NOSTATISTIC,
    DB_E_ALTERRESTRICTED,
    DB_E_RESOURCENOTSUPPORTED,
    DB_E_NOCONSTRAINT,
    DB_E_COLUMNUNAVAILABLE,
    DB_E_BOGUS,
    DXVA2_E_NOT_INITIALIZED,
    MF_E_DXGI_DEVICE_NOT_INITIALIZED,
    SYNC_E_ID_FORMAT_MISMATCH,
    REC_E_ABORTED,
    ROUTER_E_NOTINTERESTED,
    DXVA2_E_NEW_VIDEO_DEVICE,
    MF_E_DXGI_NEW_VIDEO_DEVICE,
    SYNC_E_INVALID_OPERATION,
    REC_E_NOCALLBACK,
    DXVA2_E_VIDEO_DEVICE_LOCKED,
    MF_E_DXGI_VIDEO_DEVICE_LOCKED,
    SYNC_E_REPLICA_NOT_FOUND,
    REC_E_NORESIDUES,
    SEO_E_NOTPRESENT,
    DXVA2_E_NOT_AVAILABLE,
    SYNC_E_CHANGE_COUNT_MISMATCH,
    REC_E_TOODIFFERENT,
    SEO_E_TIMEOUT,
    SYNC_E_CHANGE_UNIT_COUNT_MISMATCH,
    REC_E_INEEDTODOTHEUPDATES,
    SEO_S_DONEPROCESSING,
    SYNC_E_KNOWLEDGE_DECREASED,
    EVENTS_E_BADDATA,
    SYNC_E_CHANGE_NOT_IN_KNOWLEDGE,
    EVENTS_E_TIMEOUT,
    SYNC_E_ITEM_MUST_EXIST,
    EVENTS_E_DISABLED,
    SYNC_E_HAS_NO_DATA,
    SYNC_E_CHANGE_NEEDS_KNOWLEDGE,
    SYNC_E_RANGE_OUT_OF_ORDER,
    SYNC_E_NOT_EXPECTED_CHANGE,
    SYNC_E_DESERIALIZATION,
    SYNC_E_SINGLE_RANGE_ONLY,
    SYNC_E_ITEM_HAS_CHANGE_UNITS,
    SYNC_E_ITEM_HAS_NO_CHANGE_UNITS,
    SYNC_E_ITEM_HAS_NO_VERSION_DATA,
    SYNC_E_OBJECT_NEEDS_STATE,
    SYNC_E_FEEDSYNC_INVALID_FEED,
    SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA,
    SYNC_E_FEEDSYNC_CALLBACK_EXPECTED,
    SYNC_E_INVALID_VERSION,
    SYNC_E_DUPLICATE_ITEM,
    SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS,
    SYNC_E_INVALID_SYNC_TIME,
    SYNC_E_INCOMPLETE_REPLICA_KEY_MAP,
    SYNC_E_INVALID_REPLICA_KEY,
    SYNC_E_NEGATIVE_RANGE_EXCEPTION,
    SYNC_E_BATCH_NEEDS_KNOWLEDGE,
    SYNC_E_INTERNAL_ERROR,
    SYNC_E_CHANGE_BATCH_IS_READ_ONLY,
    SYNC_E_DATA_MODIFIED_CONCURRENTLY,
    SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM,
    SYNC_E_FILTER_NOT_SUPPORTED,
    SYNC_E_LOAD_CONFLICT_DATA_FAILED,
    SYNC_E_INVALID_SERIALIZATION_VERSION,
    SYNC_E_MARKER_MISMATCH,
    SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED,
    SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT,
    SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED,
    SYNC_E_FULL_ENUMERATION_MUST_BE_USED,
    SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE,
    SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED,
    SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER,
    IDX_E_INVALIDTAG,
    IDX_E_METAFILE_CORRUPT,
    IDX_E_TOO_MANY_SEARCH_SERVERS,
    IDX_E_SEARCH_SERVER_ALREADY_EXISTS,
    IDX_E_BUILD_IN_PROGRESS,
    IDX_E_IDXLSTFILE_CORRUPT,
    IDX_E_REGISTRY_ENTRY,
    IDX_E_OBJECT_NOT_FOUND,
    IDX_E_SEARCH_SERVER_NOT_FOUND,
    IDX_E_WB_NOTFOUND,
    IDX_E_NOISELIST_NOTFOUND,
    IDX_E_STEMMER_NOTFOUND,
    IDX_E_PROP_STOPPED,
    IDX_E_DISKFULL,
    IDX_E_INVALID_INDEX,
    IDX_E_CORRUPT_INDEX,
    IDX_E_PROPSTORE_INIT_FAILED,
    IDX_E_PROP_STATE_CORRUPT,
    IDX_E_NOT_LOADED,
    IDX_E_PROP_MAJOR_VERSION_MISMATCH,
    IDX_E_PROP_MINOR_VERSION_MISMATCH,
    IDX_E_DSS_NOT_CONNECTED,
    IDX_E_DOCUMENT_ABORTED,
    IDX_E_CATALOG_DISMOUNTED,
    IDX_E_USE_DEFAULT_CONTENTCLASS,
    IDX_E_USE_APPGLOBAL_PROPTABLE,
    JPS_E_JET_ERR,
    JPS_E_CATALOG_DECSRIPTION_MISSING,
    JPS_E_MISSING_INFORMATION,
    JPS_E_INSUFFICIENT_VERSION_STORAGE,
    JPS_E_INSUFFICIENT_DATABASE_SESSIONS,
    JPS_E_INSUFFICIENT_DATABASE_RESOURCES,
    JPS_E_SCHEMA_ERROR,
    JPS_E_PROPAGATION_FILE,
    JPS_E_PROPAGATION_CORRUPTION,
    JPS_E_PROPAGATION_VERSION_MISMATCH,
    JPS_E_SHARING_VIOLATION,
    EXCI_E_NO_CONFIG,
    EXCI_E_INVALID_SERVER_CONFIG,
    EXCI_E_ACCESS_DENIED,
    EXCI_E_INVALID_EXCHANGE_SERVER,
    EXCI_E_BADCONFIG_OR_ACCESSDENIED,
    EXCI_E_WRONG_SERVER_OR_ACCT,
    EXCI_E_NOT_ADMIN_OR_WRONG_SITE,
    EXCI_E_NO_MAPI,
    EXCI_E_INVALID_ACCOUNT_INFO,
    PRTH_E_COMM_ERROR,
    PRTH_E_OBJ_NOT_FOUND,
    PRTH_E_REQUEST_ERROR,
    PRTH_E_INTERNAL_ERROR,
    PRTH_E_ACCESS_DENIED,
    PRTH_E_SERVER_ERROR,
    PRTH_E_NOT_REDIRECTED,
    PRTH_E_BAD_REQUEST,
    PRTH_E_HTTP_CANNOT_CONNECT,
    PRTH_E_WININET,
    PRTH_E_RETRY,
    PRTH_E_MIME_EXCLUDED,
    PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL,
    PRTH_E_CANT_TRANSFORM_DENIED_ACE,
    PRTH_E_ACL_IS_READ_NONE,
    PRTH_E_ACL_TOO_BIG,
    PRTH_E_NO_PROPERTY,
    PRTH_E_DATABASE_OPEN_ERROR,
    PRTH_E_OPLOCK_BROKEN,
    PRTH_E_LOAD_FAILED,
    PRTH_E_INIT_FAILED,
    PRTH_E_VOLUME_MOUNT_POINT,
    PRTH_E_TRUNCATED,
    GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR,
    PRTH_E_HTTPS_CERTIFICATE_ERROR,
    PRTH_E_HTTPS_REQUIRE_CERTIFICATE,
    SCHED_E_TRIGGER_NOT_FOUND,
    SCHED_E_TASK_NOT_READY,
    SCHED_E_TASK_NOT_RUNNING,
    SCHED_E_SERVICE_NOT_INSTALLED,
    SCHED_E_CANNOT_OPEN_TASK,
    SCHED_E_INVALID_TASK,
    SCHED_E_ACCOUNT_INFORMATION_NOT_SET,
    SCHED_E_ACCOUNT_NAME_NOT_FOUND,
    SCHED_E_ACCOUNT_DBASE_CORRUPT,
    SCHED_E_NO_SECURITY_SERVICES,
    SCHED_E_UNKNOWN_OBJECT_VERSION,
    SCHED_E_UNSUPPORTED_ACCOUNT_OPTION,
    SCHED_E_SERVICE_NOT_RUNNING,
    SCHED_E_UNEXPECTEDNODE,
    SCHED_E_NAMESPACE,
    SCHED_E_INVALIDVALUE,
    SCHED_E_MISSINGNODE,
    SCHED_E_MALFORMEDXML,
    SCHED_E_TOO_MANY_NODES,
    SCHED_E_PAST_END_BOUNDARY,
    SCHED_E_ALREADY_RUNNING,
    SCHED_E_USER_NOT_LOGGED_ON,
    SCHED_E_INVALID_TASK_HASH,
    SCHED_E_SERVICE_NOT_AVAILABLE,
    SCHED_E_SERVICE_TOO_BUSY,
    SCHED_E_TASK_ATTEMPTED,
    SCHED_E_TASK_DISABLED,
    SCHED_E_TASK_NOT_V1_COMPAT,
    SCHED_E_START_ON_DEMAND,
    SCHED_E_TASK_NOT_UBPM_COMPAT,
    SCHED_E_DEPRECATED_FEATURE_USED,
    SEC_E_INITFAILED,
    SEC_E_NOTINITIALIZED,
    SEC_E_INVALIDCONTEXT,
    SEC_E_ACCESSDENIED,
    CMDLINE_E_UNEXPECTED,
    CMDLINE_E_PAREN,
    CMDLINE_E_PARAM_SIZE,
    CMDLINE_E_NOT_INIT,
    CMDLINE_E_ALREADY_INIT,
    CMDLINE_E_NUM_PARAMS,
    QUERY_E_FAILED,
    SYNC_E_REGISTRATION_INTERNAL_ERROR,
    QUERY_E_INVALIDQUERY,
    SYNC_E_REGISTRATION_ALREADY_REGISTERED,
    QUERY_E_INVALIDRESTRICTION,
    SYNC_E_REGISTRATION_NOT_REGISTERED,
    QUERY_E_INVALIDSORT,
    SYNC_E_REGISTRATION_CORRUPT_DATA,
    QUERY_E_INVALIDCATEGORIZE,
    SYNC_E_REGISTRATION_ALREADY_COMMITTED,
    QUERY_E_ALLNOISE,
    QUERY_E_TOOCOMPLEX,
    QUERY_E_TIMEDOUT,
    QUERY_E_DUPLICATE_OUTPUT_COLUMN,
    QUERY_E_INVALID_OUTPUT_COLUMN,
    QUERY_E_INVALID_DIRECTORY,
    QUERY_E_DIR_ON_REMOVABLE_DRIVE,
    QUERY_S_NO_QUERY,
    QUERY_E_ALLNOISE_AND_NO_RELDOC,
    QUERY_E_NO_RELDOC,
    QUERY_E_ALLNOISE_AND_NO_RELPROP,
    QUERY_E_NO_RELPROP,
    QUERY_E_REPEATED_RELDOC,
    QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED,
    QUERY_E_INVALID_DOCUMENT_IDENTIFIER,
    QUERY_E_INCORRECT_VERSION,
    QUERY_E_INVALIDSCOPE_COALESCE,
    QUERY_E_INVALIDSORT_COALESCE,
    QUERY_E_INVALIDCOALESCE,
    QUERY_E_UPGRADEINPROGRESS,
    QUERY_E_AGGREGATE_NOT_SUPPORTED,
    QUERY_E_TOP_LEVEL_IN_GROUP,
    QUERY_E_DUPLICATE_RANGE_NAME,
    QPLIST_E_CANT_OPEN_FILE,
    QPLIST_E_READ_ERROR,
    QPLIST_E_EXPECTING_NAME,
    QPLIST_E_EXPECTING_TYPE,
    QPLIST_E_UNRECOGNIZED_TYPE,
    QPLIST_E_EXPECTING_INTEGER,
    QPLIST_E_EXPECTING_CLOSE_PAREN,
    QPLIST_E_EXPECTING_GUID,
    QPLIST_E_BAD_GUID,
    QPLIST_E_EXPECTING_PROP_SPEC,
    QPLIST_E_CANT_SET_PROPERTY,
    QPLIST_E_DUPLICATE,
    QPLIST_E_VECTORBYREF_USED_ALONE,
    QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE,
    QPARSE_E_UNEXPECTED_NOT,
    QPARSE_E_EXPECTING_INTEGER,
    QPARSE_E_EXPECTING_REAL,
    QPARSE_E_EXPECTING_DATE,
    QPARSE_E_EXPECTING_CURRENCY,
    QPARSE_E_EXPECTING_GUID,
    QPARSE_E_EXPECTING_BRACE,
    QPARSE_E_EXPECTING_PAREN,
    QPARSE_E_EXPECTING_PROPERTY,
    QPARSE_E_NOT_YET_IMPLEMENTED,
    QPARSE_E_EXPECTING_PHRASE,
    QPARSE_E_UNSUPPORTED_PROPERTY_TYPE,
    QPARSE_E_EXPECTING_REGEX,
    QPARSE_E_EXPECTING_REGEX_PROPERTY,
    QPARSE_E_INVALID_LITERAL,
    QPARSE_E_NO_SUCH_PROPERTY,
    QPARSE_E_EXPECTING_EOS,
    QPARSE_E_EXPECTING_COMMA,
    QPARSE_E_UNEXPECTED_EOS,
    QPARSE_E_WEIGHT_OUT_OF_RANGE,
    QPARSE_E_NO_SUCH_SORT_PROPERTY,
    QPARSE_E_INVALID_SORT_ORDER,
    QUTIL_E_CANT_CONVERT_VROOT,
    QPARSE_E_INVALID_GROUPING,
    QPARSE_E_INVALID_QUERY,
    QPARSE_E_INVALID_RANKMETHOD,
    FDAEMON_E_LOWRESOURCE,
    FDAEMON_E_FATALERROR,
    FDAEMON_E_PARTITIONDELETED,
    FDAEMON_E_CHANGEUPDATEFAILED,
    FDAEMON_E_WORDLISTCOMMITFAILED,
    FDAEMON_E_NOWORDLIST,
    FDAEMON_E_TOOMANYFILTEREDBLOCKS,
    SEARCH_E_NOMONIKER,
    SEARCH_E_NOREGION,
    FILTER_E_END_OF_CHUNKS,
    FILTER_E_NO_MORE_TEXT,
    FILTER_E_NO_MORE_VALUES,
    FILTER_E_ACCESS,
    FILTER_E_NO_TEXT,
    FILTER_E_NO_VALUES,
    FILTER_E_EMBEDDING_UNAVAILABLE,
    FILTER_E_LINK_UNAVAILABLE,
    FILTER_E_PASSWORD,
    FILTER_E_UNKNOWNFORMAT,
    FILTER_E_TOO_BIG,
    FILTER_E_ALREADY_OPEN,
    FILTER_E_UNREACHABLE,
    FILTER_E_IN_USE,
    FILTER_E_NOT_OPEN,
    FILTER_E_NO_SUCH_PROPERTY,
    FILTER_E_OFFLINE,
    FILTER_E_PARTIALLY_FILTERED,
    WBREAK_E_END_OF_TEXT,
    WBREAK_E_QUERY_ONLY,
    WBREAK_E_BUFFER_TOO_SMALL,
    LANGUAGE_E_DATABASE_NOT_FOUND,
    WBREAK_E_INIT_FAILED,
    PSINK_E_QUERY_ONLY,
    PSINK_E_INDEX_ONLY,
    PSINK_E_LARGE_ATTACHMENT,
    CI_E_ALREADY_INITIALIZED,
    CI_E_NOT_INITIALIZED,
    CI_E_BUFFERTOOSMALL,
    CI_E_PROPERTY_NOT_CACHED,
    CI_E_INVALID_STATE,
    CI_E_FILTERING_DISABLED,
    CI_E_DISK_FULL,
    CI_E_SHUTDOWN,
    CI_E_WORKID_NOTVALID,
    CI_E_NOT_FOUND,
    CI_E_USE_DEFAULT_PID,
    CI_E_DUPLICATE_NOTIFICATION,
    CI_E_UPDATES_DISABLED,
    CI_E_INVALID_FLAGS_COMBINATION,
    CI_E_OUTOFSEQ_INCREMENT_DATA,
    CI_E_SHARING_VIOLATION,
    CI_E_LOGON_FAILURE,
    CI_E_NO_CATALOG,
    CI_E_STRANGE_PAGEORSECTOR_SIZE,
    CI_E_TIMEOUT,
    CI_E_NOT_RUNNING,
    CI_E_CARDINALITY_MISMATCH,
    CI_E_CONFIG_DISK_FULL,
    CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED,
    CI_E_NO_AUXMETADATA,
    CI_E_INVALID_CATALOG_LIST_VERSION,
    NLADMIN_E_DUPLICATE_CATALOG,
    NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE,
    NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED,
    FAX_E_SRV_OUTOFMEMORY,
    FAX_E_GROUP_NOT_FOUND,
    FAX_E_BAD_GROUP_CONFIGURATION,
    FAX_E_GROUP_IN_USE,
    FAX_E_RULE_NOT_FOUND,
    FAX_E_NOT_NTFS,
    FAX_E_DIRECTORY_IN_USE,
    FAX_E_FILE_ACCESS_DENIED,
    FAX_E_MESSAGE_NOT_FOUND,
    FAX_E_DEVICE_NUM_LIMIT_EXCEEDED,
    FAX_E_NOT_SUPPORTED_ON_THIS_SKU,
    FAX_E_VERSION_MISMATCH,
    FAX_E_RECIPIENTS_LIMIT,
    SCRIPTPI_E_CHUNK_NOT_TEXT,
    SCRIPTPI_E_PID_NOT_NAME,
    SCRIPTPI_E_PID_NOT_NUMERIC,
    SCRIPTPI_E_CHUNK_NOT_VALUE,
    SCRIPTPI_E_CANNOT_ALTER_CHUNK,
    SCRIPTPI_E_ALREADY_COMPLETED,
    MSS_E_INVALIDAPPNAME,
    MSS_E_APPNOTFOUND,
    MSS_E_APPALREADYEXISTS,
    MSS_E_CATALOGNOTFOUND,
    MSS_E_CATALOGSTOPPING,
    MSS_E_UNICODEFILEHEADERMISSING,
    MSS_E_CATALOGALREADYEXISTS,
    XML_E_NODEFAULTNS,
    XML_E_BADSXQL,
    VSS_E_BAD_STATE,
    VSS_E_UNEXPECTED,
    VSS_E_PROVIDER_ALREADY_REGISTERED,
    VSS_E_PROVIDER_NOT_REGISTERED,
    VSS_E_PROVIDER_VETO,
    VSS_E_PROVIDER_IN_USE,
    VSS_E_OBJECT_NOT_FOUND,
    VSS_E_VOLUME_NOT_SUPPORTED,
    VSS_E_OBJECT_ALREADY_EXISTS,
    VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER,
    VSS_E_UNEXPECTED_PROVIDER_ERROR,
    VSS_E_CORRUPT_XML_DOCUMENT,
    VSS_E_INVALID_XML_DOCUMENT,
    VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED,
    VSS_E_FLUSH_WRITES_TIMEOUT,
    VSS_E_HOLD_WRITES_TIMEOUT,
    VSS_E_UNEXPECTED_WRITER_ERROR,
    VSS_E_SNAPSHOT_SET_IN_PROGRESS,
    VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED,
    VSS_E_WRITER_INFRASTRUCTURE,
    VSS_E_WRITER_NOT_RESPONDING,
    VSS_E_WRITER_ALREADY_SUBSCRIBED,
    VSS_E_UNSUPPORTED_CONTEXT,
    VSS_E_VOLUME_IN_USE,
    VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED,
    VSS_E_INSUFFICIENT_STORAGE,
    VSS_E_NO_SNAPSHOTS_IMPORTED,
    VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED,
    VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED,
    VSS_E_REMOTE_SERVER_UNAVAILABLE,
    VSS_E_REMOTE_SERVER_UNSUPPORTED,
    VSS_E_REVERT_IN_PROGRESS,
    VSS_E_REVERT_VOLUME_LOST,
    VSS_E_REBOOT_REQUIRED,
    VSS_E_TRANSACTION_FREEZE_TIMEOUT,
    VSS_E_TRANSACTION_THAW_TIMEOUT,
    VSS_E_UNSELECTED_VOLUME,
    VSS_E_SNAPSHOT_NOT_IN_SET,
    VSS_E_NESTED_VOLUME_LIMIT,
    VSS_E_VOLUME_NOT_LOCAL,
    VSS_E_CLUSTER_TIMEOUT,
    VSS_E_NOT_SUPPORTED,
    VSS_E_WRITERERROR_PARTIAL_FAILURE,
    VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT,
    VSS_E_WRITERERROR_OUTOFRESOURCES,
    VSS_E_WRITERERROR_TIMEOUT,
    VSS_E_WRITERERROR_RETRYABLE,
    VSS_E_WRITERERROR_NONRETRYABLE,
    VSS_E_WRITERERROR_RECOVERY_FAILED,
    VSS_E_BREAK_REVERT_ID_FAILED,
    VSS_E_LEGACY_PROVIDER,
    VSS_E_MISSING_DISK,
    VSS_E_MISSING_HIDDEN_VOLUME,
    VSS_E_MISSING_VOLUME,
    VSS_E_AUTORECOVERY_FAILED,
    VSS_E_DYNAMIC_DISK_ERROR,
    VSS_E_NONTRANSPORTABLE_BCD,
    VSS_E_CANNOT_REVERT_DISKID,
    VSS_E_RESYNC_IN_PROGRESS,
    VDS_E_NOT_SUPPORTED,
    VSS_E_CLUSTER_ERROR,
    FLTRDMN_E_UNEXPECTED,
    VDS_E_INITIALIZED_FAILED,
    VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED,
    FLTRDMN_E_QI_FILTER_FAILED,
    VDS_E_INITIALIZE_NOT_CALLED,
    VSS_E_ASRERROR_DISK_RECREATION_FAILED,
    VDS_E_ALREADY_REGISTERED,
    VSS_E_ASRERROR_NO_ARCPATH,
    FLTRDMN_E_FILTER_INIT_FAILED,
    VDS_E_ANOTHER_CALL_IN_PROGRESS,
    VSS_E_ASRERROR_MISSING_DYNDISK,
    FLTRDMN_E_ENCRYPTED_DOCUMENT,
    VDS_E_OBJECT_NOT_FOUND,
    VSS_E_ASRERROR_SHARED_CRIDISK,
    FLTRDMN_E_CANNOT_DECRYPT_PASSWORD,
    VDS_E_INVALID_SPACE,
    VSS_E_ASRERROR_DATADISK_RDISK0,
    VDS_E_PARTITION_LIMIT_REACHED,
    VSS_E_ASRERROR_RDISK0_TOOSMALL,
    VDS_E_PARTITION_NOT_EMPTY,
    VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL,
    VDS_E_OPERATION_PENDING,
    VSS_E_WRITER_STATUS_NOT_AVAILABLE,
    VDS_E_OPERATION_DENIED,
    VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED,
    VDS_E_OBJECT_DELETED,
    VDS_E_CANCEL_TOO_LATE,
    VDS_E_OPERATION_CANCELED,
    VDS_E_CANNOT_EXTEND,
    VDS_E_NOT_ENOUGH_SPACE,
    VDS_E_NOT_ENOUGH_DRIVE,
    VDS_E_BAD_COOKIE,
    VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK,
    VDS_E_NO_MEDIA,
    VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND,
    VDS_E_DEVICE_IN_USE,
    VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE,
    VDS_E_DISK_NOT_EMPTY,
    VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION,
    VDS_E_INVALID_OPERATION,
    VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED,
    VDS_E_PATH_NOT_FOUND,
    VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN,
    VDS_E_DISK_NOT_INITIALIZED,
    VSS_E_FSS_TIMEOUT,
    VDS_E_NOT_AN_UNALLOCATED_DISK,
    VDS_E_UNRECOVERABLE_ERROR,
    VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED,
    VDS_E_PROVIDER_INITIALIZATION_FAILED,
    VDS_E_OBJECT_EXISTS,
    VDS_E_NO_DISKS_FOUND,
    VDS_E_PROVIDER_CACHE_CORRUPT,
    VDS_E_DMADMIN_METHOD_CALL_FAILED,
    VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND,
    VDS_E_PROVIDER_VOL_OPEN,
    VDS_E_DMADMIN_CORRUPT_NOTIFICATION,
    VDS_E_INCOMPATIBLE_FILE_SYSTEM,
    VDS_E_INCOMPATIBLE_MEDIA,
    VDS_E_ACCESS_DENIED,
    VDS_E_MEDIA_WRITE_PROTECTED,
    VDS_E_BAD_LABEL,
    VDS_E_CANT_QUICK_FORMAT,
    VDS_E_IO_ERROR,
    VDS_E_VOLUME_TOO_SMALL,
    VDS_E_VOLUME_TOO_BIG,
    VDS_E_CLUSTER_SIZE_TOO_SMALL,
    VDS_E_CLUSTER_SIZE_TOO_BIG,
    VDS_E_CLUSTER_COUNT_BEYOND_32BITS,
    VDS_E_OBJECT_STATUS_FAILED,
    VDS_E_VOLUME_INCOMPLETE,
    VDS_E_EXTENT_SIZE_LESS_THAN_MIN,
    VDS_E_BOOT_PARTITION_NUMBER_CHANGE,
    VDS_E_NO_FREE_SPACE,
    VDS_E_ACTIVE_PARTITION,
    VDS_E_PARTITION_OF_UNKNOWN_TYPE,
    VDS_E_LEGACY_VOLUME_FORMAT,
    VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS,
    VDS_E_MIGRATE_OPEN_VOLUME,
    VDS_E_VOLUME_NOT_ONLINE,
    VDS_E_VOLUME_NOT_HEALTHY,
    VDS_E_VOLUME_SPANS_DISKS,
    VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE,
    VDS_E_BAD_PROVIDER_DATA,
    VDS_E_PROVIDER_FAILURE,
    VDS_E_PACK_OFFLINE,
    VDS_E_VOLUME_NOT_A_MIRROR,
    VDS_E_NO_EXTENTS_FOR_VOLUME,
    VDS_E_DISK_NOT_LOADED_TO_CACHE,
    VDS_E_INTERNAL_ERROR,
    VDS_E_PROVIDER_TYPE_NOT_SUPPORTED,
    VDS_E_DISK_NOT_ONLINE,
    VDS_E_DISK_IN_USE_BY_VOLUME,
    VDS_E_ASYNC_OBJECT_FAILURE,
    VDS_E_VOLUME_NOT_MOUNTED,
    VDS_E_PACK_NOT_FOUND,
    VDS_E_IMPORT_SET_INCOMPLETE,
    VDS_E_DISK_NOT_IMPORTED,
    VDS_E_OBJECT_OUT_OF_SYNC,
    VDS_E_MISSING_DISK,
    VDS_E_DISK_PNP_REG_CORRUPT,
    VDS_E_LBN_REMAP_ENABLED_FLAG,
    VDS_E_NO_DRIVELETTER_FLAG,
    VDS_E_REVERT_ON_CLOSE,
    VDS_E_REVERT_ON_CLOSE_SET,
    VDS_E_IA64_BOOT_MIRRORED_TO_MBR,
    VDS_E_VOLUME_TEMPORARILY_DISMOUNTED,
    VDS_E_VOLUME_PERMANENTLY_DISMOUNTED,
    VDS_E_VOLUME_HAS_PATH,
    VDS_E_TIMEOUT,
    VDS_E_REPAIR_VOLUMESTATE,
    VDS_E_LDM_TIMEOUT,
    VDS_E_REVERT_ON_CLOSE_MISMATCH,
    VDS_E_RETRY,
    VDS_E_ONLINE_PACK_EXISTS,
    VDS_E_EXTEND_FILE_SYSTEM_FAILED,
    VDS_E_MAX_USABLE_MBR,
    VDS_S_GPT_BOOT_MIRRORED_TO_MBR,
    OLEDB_BINDER_CUSTOM_ERROR,
    VDS_E_NO_SOFTWARE_PROVIDERS_LOADED,
    VDS_E_DISK_NOT_MISSING,
    VDS_E_NO_VOLUME_LAYOUT,
    VDS_E_CORRUPT_VOLUME_INFO,
    VDS_E_INVALID_ENUMERATOR,
    VDS_E_DRIVER_INTERNAL_ERROR,
    VDS_E_VOLUME_INVALID_NAME,
    VDS_E_CORRUPT_PARTITION_INFO,
    VDS_E_CORRUPT_EXTENT_INFO,
    VDS_E_DUP_EMPTY_PACK_GUID,
    VDS_E_DRIVER_NO_PACK_NAME,
    VDS_E_BAD_PNP_MESSAGE,
    VDS_E_NO_PNP_DISK_ARRIVE,
    VDS_E_NO_PNP_VOLUME_ARRIVE,
    VDS_E_NO_PNP_DISK_REMOVE,
    VDS_E_NO_PNP_VOLUME_REMOVE,
    VDS_E_PROVIDER_EXITING,
    VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE,
    VDS_E_MEMBER_SIZE_INVALID,
    VDS_E_INVALID_DISK,
    VDS_E_INVALID_PACK,
    VDS_E_VOLUME_ON_DISK,
    VDS_E_DRIVER_INVALID_PARAM,
    VDS_E_TARGET_PACK_NOT_EMPTY,
    VDS_E_CANNOT_SHRINK,
    VDS_E_MULTIPLE_PACKS,
    VDS_E_PACK_ONLINE,
    VDS_E_INVALID_PLEX_COUNT,
    VDS_E_INVALID_MEMBER_COUNT,
    VDS_E_INVALID_PLEX_ORDER,
    VDS_E_INVALID_MEMBER_ORDER,
    VDS_E_INVALID_STRIPE_SIZE,
    VDS_E_INVALID_DISK_COUNT,
    VDS_E_INVALID_EXTENT_COUNT,
    VDS_E_SOURCE_IS_TARGET_PACK,
    VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED,
    VDS_E_CORRUPT_NOTIFICATION_INFO,
    VDS_E_INVALID_PLEX_GUID,
    VDS_E_DISK_NOT_FOUND_IN_PACK,
    VDS_E_DUPLICATE_DISK,
    VDS_E_LAST_VALID_DISK,
    VDS_E_INVALID_SECTOR_SIZE,
    VDS_E_ONE_EXTENT_PER_DISK,
    VDS_E_INVALID_BLOCK_SIZE,
    VDS_E_PLEX_SIZE_INVALID,
    VDS_E_NO_EXTENTS_FOR_PLEX,
    VDS_E_INVALID_PLEX_TYPE,
    VDS_E_INVALID_PLEX_BLOCK_SIZE,
    VDS_E_NO_HEALTHY_DISKS,
    VDS_E_CONFIG_LIMIT,
    VDS_E_DISK_CONFIGURATION_CORRUPTED,
    VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC,
    VDS_E_DISK_CONFIGURATION_UPDATE_FAILED,
    VDS_E_DISK_DYNAMIC,
    VDS_E_DRIVER_OBJECT_NOT_FOUND,
    VDS_E_PARTITION_NOT_CYLINDER_ALIGNED,
    VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL,
    VDS_E_DISK_IO_FAILING,
    VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED,
    VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED,
    VDS_E_GPT_ATTRIBUTES_INVALID,
    VDS_E_MEMBER_IS_HEALTHY,
    VDS_E_MEMBER_REGENERATING,
    VDS_E_PACK_NAME_INVALID,
    VDS_E_PLEX_IS_HEALTHY,
    VDS_E_PLEX_LAST_ACTIVE,
    VDS_E_PLEX_MISSING,
    VDS_E_MEMBER_MISSING,
    VDS_E_PLEX_REGENERATING,
    VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE,
    VDS_E_INVALID_VOLUME_LENGTH,
    VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE,
    VDS_E_VOLUME_NOT_RETAINED,
    VDS_E_VOLUME_RETAINED,
    VDS_E_ALIGN_BEYOND_FIRST_CYLINDER,
    VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE,
    VDS_E_ALIGN_NOT_ZERO,
    VDS_E_CACHE_CORRUPT,
    VDS_E_CANNOT_CLEAR_VOLUME_FLAG,
    VDS_E_DISK_BEING_CLEANED,
    VDS_E_DISK_NOT_CONVERTIBLE,
    VDS_E_DISK_REMOVEABLE,
    VDS_E_DISK_REMOVEABLE_NOT_EMPTY,
    VDS_E_DRIVE_LETTER_NOT_FREE,
    VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED,
    VDS_E_INVALID_DRIVE_LETTER,
    VDS_E_INVALID_DRIVE_LETTER_COUNT,
    VDS_E_INVALID_FS_FLAG,
    VDS_E_INVALID_FS_TYPE,
    VDS_E_INVALID_OBJECT_TYPE,
    VDS_E_INVALID_PARTITION_LAYOUT,
    VDS_E_INVALID_PARTITION_STYLE,
    VDS_E_INVALID_PARTITION_TYPE,
    VDS_E_INVALID_PROVIDER_CLSID,
    VDS_E_INVALID_PROVIDER_ID,
    VDS_E_INVALID_PROVIDER_NAME,
    VDS_E_INVALID_PROVIDER_TYPE,
    VDS_E_INVALID_PROVIDER_VERSION_GUID,
    VDS_E_INVALID_PROVIDER_VERSION_STRING,
    VDS_E_INVALID_QUERY_PROVIDER_FLAG,
    VDS_E_INVALID_SERVICE_FLAG,
    VDS_E_INVALID_VOLUME_FLAG,
    VDS_E_PARTITION_NOT_OEM,
    VDS_E_PARTITION_PROTECTED,
    VDS_E_PARTITION_STYLE_MISMATCH,
    VDS_E_PROVIDER_INTERNAL_ERROR,
    VDS_E_SHRINK_SIZE_LESS_THAN_MIN,
    VDS_E_SHRINK_SIZE_TOO_BIG,
    VDS_E_UNRECOVERABLE_PROVIDER_ERROR,
    VDS_E_VOLUME_HIDDEN,
    VDS_E_FLAG_ALREADY_SET,
    VDS_E_DISTINCT_VOLUME,
    VDS_E_VOLUME_NOT_FOUND_IN_PACK,
    VDS_E_PARTITION_NON_DATA,
    VDS_E_CRITICAL_PLEX,
    VDS_E_VOLUME_SYNCHRONIZING,
    VDS_E_VOLUME_REGENERATING,
    VDS_E_READONLY,
    VDS_E_INVALID_VOLUME_TYPE,
    VDS_E_BAD_BOOT_DISK,
    VDS_E_LOG_UPDATE,
    VDS_E_VOLUME_MIRRORED,
    VDS_E_VOLUME_SIMPLE_SPANNED,
    VDS_E_NO_VALID_LOG_COPIES,
    VDS_E_PLEX_NOT_LOADED_TO_CACHE,
    VDS_E_PARTITION_MSR,
    VDS_E_PARTITION_LDM,
    VDS_E_ALIGN_NOT_A_POWER_OF_TWO,
    VDS_E_ALIGN_IS_ZERO,
    VDS_E_SHRINK_IN_PROGRESS,
    VDS_E_CANT_INVALIDATE_FVE,
    VDS_E_FS_NOT_DETERMINED,
    VDS_E_DISK_NOT_OFFLINE,
    VDS_E_FAILED_TO_ONLINE_DISK,
    VDS_E_FAILED_TO_OFFLINE_DISK,
    VDS_E_BAD_REVISION_NUMBER,
    VDS_E_SHRINK_USER_CANCELLED,
    VDS_E_SHRINK_DIRTY_VOLUME,
    NOTESPH_E_UNEXPECTED_STATE,
    NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE,
    NOTESPH_E_ITEM_NOT_FOUND,
    NOTESPH_E_SERVER_CONFIG,
    NOTESPH_E_ATTACHMENTS,
    NOTESPH_E_NO_NTID,
    NOTESPH_E_DB_ACCESS_DENIED,
    NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR,
    NOTESPH_E_FAIL,
    STS_ABORTXMLPARSE,
    STS_WS_ERROR,
    SPS_WS_ERROR,
    EXSTOREPH_E_UNEXPECTED,
    VDS_E_NAME_NOT_UNIQUE,
    VDS_E_ADDRESSES_INCOMPLETELY_SET,
    VDS_E_SECURITY_INCOMPLETELY_SET,
    VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED,
    VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED,
    VDS_E_ISCSI_LOGIN_FAILED,
    VDS_E_ISCSI_LOGOUT_FAILED,
    VDS_E_ISCSI_SESSION_NOT_FOUND,
    VDS_E_ASSOCIATED_LUNS_EXIST,
    VDS_E_ASSOCIATED_PORTALS_EXIST,
    VDS_E_NO_DISCOVERY_DOMAIN,
    VDS_E_MULTIPLE_DISCOVERY_DOMAINS,
    VDS_E_NO_DISK_PATHNAME,
    VDS_E_ISCSI_LOGOUT_INCOMPLETE,
    VDS_E_NO_VOLUME_PATHNAME,
    VDS_E_PROVIDER_CACHE_OUTOFSYNC,
    VDS_E_NO_IMPORT_TARGET,
    CERT_E_NOT_FOUND_OR_NO_PERMISSSION,
    VDS_E_UNABLE_TO_FIND_BOOT_DISK,
    VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO,
    VDS_E_GET_SAN_POLICY,
    VDS_E_SET_SAN_POLICY,
    VDS_E_BOOT_DISK,
    VDS_E_DISK_IS_OFFLINE,
    VDS_E_DISK_IS_READ_ONLY,
    VDS_E_PAGEFILE_DISK,
    VDS_E_HIBERNATION_FILE_DISK,
    VDS_E_CRASHDUMP_DISK,
    VDS_E_UNABLE_TO_FIND_SYSTEM_DISK,
    VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO,
    VDS_E_SYSTEM_DISK,
    VDS_E_VOLUME_SHRINK_FVE_LOCKED,
    VDS_E_VOLUME_SHRINK_FVE_CORRUPT,
    VDS_E_VOLUME_SHRINK_FVE_RECOVERY,
    VDS_E_VOLUME_SHRINK_FVE,
    VDS_E_SHRINK_OVER_DATA,
    VDS_E_INVALID_SHRINK_SIZE,
    VDS_E_LUN_DISK_MISSING,
    VDS_E_LUN_DISK_FAILED,
    VDS_E_LUN_DISK_NOT_READY,
    VDS_E_LUN_DISK_NO_MEDIA,
    VDS_E_LUN_NOT_READY,
    VDS_E_LUN_OFFLINE,
    VDS_E_LUN_FAILED,
    VDS_E_VOLUME_EXTEND_FVE_LOCKED,
    VDS_E_VOLUME_EXTEND_FVE_CORRUPT,
    VDS_E_VOLUME_EXTEND_FVE_RECOVERY,
    VDS_E_VOLUME_EXTEND_FVE,
    VDS_E_SECTOR_SIZE_ERROR,
    VDS_E_INITIATOR_ADAPTER_NOT_FOUND,
    VDS_E_TARGET_PORTAL_NOT_FOUND,
    VDS_E_INVALID_PORT_PATH,
    VDS_E_INVALID_ISCSI_TARGET_NAME,
    VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS,
    VDS_E_ISCSI_GET_IKE_INFO,
    VDS_E_ISCSI_SET_IKE_INFO,
    VDS_E_SUBSYSTEM_ID_IS_NULL,
    VDS_E_ISCSI_INITIATOR_NODE_NAME,
    VDS_E_ISCSI_GROUP_PRESHARE_KEY,
    VDS_E_ISCSI_CHAP_SECRET,
    VDS_E_INVALID_IP_ADDRESS,
    VDS_E_REBOOT_REQUIRED,
    VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED,
    VDS_E_BOOT_PAGEFILE_DRIVE_LETTER,
    VDS_E_DELETE_WITH_CRITICAL,
    VDS_E_CLEAN_WITH_DATA,
    VDS_E_CLEAN_WITH_OEM,
    VDS_E_CLEAN_WITH_CRITICAL,
    VDS_E_FORMAT_CRITICAL,
    VDS_E_NTFS_FORMAT_NOT_SUPPORTED,
    VDS_E_FAT32_FORMAT_NOT_SUPPORTED,
    VDS_E_FAT_FORMAT_NOT_SUPPORTED,
    VDS_E_FORMAT_NOT_SUPPORTED,
    VDS_E_COMPRESSION_NOT_SUPPORTED,
    VDS_E_VDISK_NOT_OPEN,
    VDS_E_VDISK_INVALID_OP_STATE,
    VDS_E_INVALID_PATH,
    VDS_E_INVALID_ISCSI_PATH,
    VDS_E_SHRINK_LUN_NOT_UNMASKED,
    VDS_E_LUN_DISK_READ_ONLY,
    VDS_E_LUN_UPDATE_DISK,
    VDS_E_LUN_DYNAMIC,
    VDS_E_LUN_DYNAMIC_OFFLINE,
    VDS_E_LUN_SHRINK_GPT_HEADER,
    VDS_E_MIRROR_NOT_SUPPORTED,
    VDS_E_RAID5_NOT_SUPPORTED,
    VDS_E_DISK_NOT_CONVERTIBLE_SIZE,
    VDS_E_OFFLINE_NOT_SUPPORTED,
    VDS_E_VDISK_PATHNAME_INVALID,
    VDS_E_EXTEND_TOO_MANY_CLUSTERS,
    VDS_E_EXTEND_UNKNOWN_FILESYSTEM,
    VDS_E_SHRINK_UNKNOWN_FILESYSTEM,
    VDS_E_VD_DISK_NOT_OPEN,
    VDS_E_VD_DISK_IS_EXPANDING,
    VDS_E_VD_DISK_IS_COMPACTING,
    VDS_E_VD_DISK_IS_MERGING,
    VDS_E_VD_IS_ATTACHED,
    VDS_E_VD_DISK_ALREADY_OPEN,
    VDS_E_VD_DISK_ALREADY_EXPANDING,
    VDS_E_VD_ALREADY_COMPACTING,
    VDS_E_VD_ALREADY_MERGING,
    VDS_E_VD_ALREADY_ATTACHED,
    VDS_E_VD_ALREADY_DETACHED,
    VDS_E_VD_NOT_ATTACHED_READONLY,
    VDS_E_VD_IS_BEING_ATTACHED,
    VDS_E_VD_IS_BEING_DETACHED,
    VDS_E_NO_POOL,
    VDS_E_NO_POOL_CREATED,
    VDS_E_NO_MAINTENANCE_MODE,
    VDS_E_BLOCK_CLUSTERED,
    VDS_E_DISK_HAS_BANDS,
    VDS_E_INVALID_STATE,
    VDS_E_REFS_FORMAT_NOT_SUPPORTED,
    VDS_E_DELETE_WITH_BOOTBACKING,
    VDS_E_FORMAT_WITH_BOOTBACKING,
    VDS_E_CLEAN_WITH_BOOTBACKING,
    SRCH_SCHEMA_CACHE_E_UNEXPECTED,
    CONTENT_SOURCE_E_PROPERTY_MAPPING_READ,
    CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER,
    CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE,
    CONTENT_SOURCE_E_CONTENT_CLASS_READ,
    CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION,
    CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR,
    CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE,
    CONTENT_SOURCE_E_OUT_OF_RANGE,
    CONTENT_SOURCE_E_NULL_URI,
    REXSPH_E_INVALID_CALL,
    REXSPH_E_REDIRECT_ON_SECURITY_UPDATE,
    REXSPH_E_MULTIPLE_REDIRECT,
    REXSPH_E_NO_PROPERTY_ON_ROW,
    REXSPH_E_TYPE_MISMATCH_ON_READ,
    REXSPH_E_UNEXPECTED_DATA_STATUS,
    REXSPH_E_UNKNOWN_DATA_TYPE,
    REXSPH_E_UNEXPECTED_FILTER_STATE,
    REXSPH_E_DUPLICATE_PROPERTY,
    FTE_E_SECRET_NOT_FOUND,
    FTE_E_PIPE_NOT_CONNECTED,
    FTE_E_ADMIN_BLOB_CORRUPT,
    FTE_E_FILTER_SINGLE_THREADED,
    FTE_E_ERROR_WRITING_REGISTRY,
    FTE_E_PROJECT_SHUTDOWN,
    FTE_E_PROJECT_NOT_INITALIZED,
    FTE_E_PIPE_DATA_CORRUPTED,
    FTE_E_URB_TOO_BIG,
    FTE_E_INVALID_DOCID,
    FTE_E_PAUSE_EXTERNAL,
    FTE_E_REJECTED_DUE_TO_PROJECT_STATUS,
    FTE_E_FD_DID_NOT_CONNECT,
    FTE_E_PROGID_REQUIRED,
    FTE_E_STATIC_THREAD_INVALID_ARGUMENTS,
    FTE_E_CATALOG_ALREADY_EXISTS,
    FTE_E_PATH_TOO_LONG,
    FTE_INVALID_ADMIN_CLIENT,
    FTE_E_COM_SIGNATURE_VALIDATION,
    FTE_E_AFFINITY_MASK,
    FTE_E_FD_OWNERSHIP_OBSOLETE,
    FTE_E_EXCEEDED_MAX_PLUGINS,
    FTE_E_DUPLICATE_OBJECT,
    FTE_E_REDUNDANT_TRAN_FAILURE,
    FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST,
    FTE_E_FD_SHUTDOWN,
    FTE_E_CATALOG_DOES_NOT_EXIST,
    FTE_E_NO_PLUGINS,
    FTE_E_BATCH_ABORTED,
    FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE,
    FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS,
    FTE_E_FD_TIMEOUT,
    FTE_E_RESOURCE_SHUTDOWN,
    FTE_E_INVALID_PROPERTY,
    FTE_E_NO_MORE_PROPERTIES,
    FTE_E_UNKNOWN_PLUGIN,
    FTE_E_LIBRARY_NOT_LOADED,
    FTE_E_PERFMON_FULL,
    FTE_E_FAILED_TO_CREATE_ACCESSOR,
    FTE_E_INVALID_TYPE,
    FTE_E_OUT_OF_RANGE,
    FTE_E_CORRUPT_PROPERTY_STORE,
    FTE_E_PROPERTY_STORE_WORKID_NOTVALID,
    FTE_E_CORRUPT_GATHERER_HASH_MAP,
    FTE_E_KEY_NOT_CACHED,
    FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN,
    FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED,
    FTE_E_STACK_CORRUPTED,
    FTE_E_INVALID_PROG_ID,
    FTE_E_SERIAL_STREAM_CORRUPT,
    FTE_E_READONLY_CATALOG,
    FTE_E_PERF_NOT_LOADED,
    FTE_E_RETRY_HUGE_DOC,
    FTE_E_UNKNOWN_FD_TYPE,
    FTE_E_DOC_TOO_HUGE,
    FTE_E_DATATYPE_MISALIGNMENT,
    FTE_E_ALREADY_INITIALIZED,
    FTE_E_FD_USED_TOO_MUCH_MEMORY,
    FTE_E_UNEXPECTED_EXIT,
    FTE_E_HIGH_MEMORY_PRESSURE,
    FTE_E_INVALID_ISOLATE_ERROR_BATCH,
    FTE_E_RETRY_SINGLE_DOC_PER_BATCH,
    FTE_E_INVALID_PROJECT_ID,
    FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS,
    FTE_E_INVALID_CODEPAGE,
    FTE_E_FD_IDLE,
    FTE_E_FD_UNRESPONSIVE,
    WCN_E_PEER_NOT_FOUND,
    WCN_E_AUTHENTICATION_FAILED,
    WCN_E_CONNECTION_REJECTED,
    WCN_E_SESSION_TIMEDOUT,
    WCN_E_PROTOCOL_ERROR,
    CDO_E_ARGUMENT1,
    PEOPLE_IMPORT_E_DBCONNFAIL,
    CDO_E_ARGUMENT2,
    PEOPLE_IMPORT_NODSDEFINED,
    CDO_E_ARGUMENT3,
    PEOPLE_IMPORT_E_FAILTOGETDSDEF,
    CDO_E_ARGUMENT4,
    PEOPLE_IMPORT_NOMAPPINGDEFINED,
    CDO_E_ARGUMENT5,
    PEOPLE_IMPORT_E_FAILTOGETDSMAPPING,
    PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED,
    PEOPLE_IMPORT_E_NOCASTINGSUPPORTED,
    PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE,
    PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE,
    PEOPLE_IMPORT_E_LDAPPATH_TOOLONG,
    PEOPLE_IMPORT_E_CANONICALURL_TOOLONG,
    PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED,
    PEOPLE_IMPORT_E_DC_NOT_AVAILABLE,
    PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED,
    PEOPLE_IMPORT_E_FAILTOGETLCID,
    PEOPLE_IMPORT_E_DOMAIN_REMOVED,
    PEOPLE_IMPORT_E_ENUM_ACCESSDENIED,
    PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED,
    SPERR_UNINITIALIZED,
    SPERR_ALREADY_INITIALIZED,
    SPERR_UNSUPPORTED_FORMAT,
    SPERR_INVALID_FLAGS,
    SPERR_DEVICE_BUSY,
    SPERR_DEVICE_NOT_SUPPORTED,
    SPERR_DEVICE_NOT_ENABLED,
    SPERR_NO_DRIVER,
    SPERR_FILEMUSTBEUNICODE,
    SPERR_INVALID_PHRASE_ID,
    SPERR_BUFFER_TOO_SMALL,
    SPERR_FORMAT_NOT_SPECIFIED,
    SPERR_AUDIO_STOPPED,
    SPERR_RULE_NOT_FOUND,
    SPERR_TTS_ENGINE_EXCEPTION,
    SPERR_TTS_NLP_EXCEPTION,
    SPERR_ENGINE_BUSY,
    SPERR_CANT_CREATE,
    SPERR_NOT_IN_LEX,
    SPERR_LEX_VERY_OUT_OF_SYNC,
    SPERR_UNDEFINED_FORWARD_RULE_REF,
    SPERR_EMPTY_RULE,
    SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR,
    SPERR_RULE_NOT_DYNAMIC,
    SPERR_DUPLICATE_RULE_NAME,
    SPERR_DUPLICATE_RESOURCE_NAME,
    SPERR_TOO_MANY_GRAMMARS,
    SPERR_CIRCULAR_REFERENCE,
    SPERR_INVALID_IMPORT,
    SPERR_INVALID_WAV_FILE,
    SPERR_ALL_WORDS_OPTIONAL,
    SPERR_INSTANCE_CHANGE_INVALID,
    SPERR_RULE_NAME_ID_CONFLICT,
    SPERR_NO_RULES,
    SPERR_CIRCULAR_RULE_REF,
    SPERR_NO_PARSE_FOUND,
    SPERR_REMOTE_CALL_TIMED_OUT,
    SPERR_AUDIO_BUFFER_OVERFLOW,
    SPERR_NO_AUDIO_DATA,
    SPERR_DEAD_ALTERNATE,
    SPERR_HIGH_LOW_CONFIDENCE,
    SPERR_INVALID_FORMAT_STRING,
    SPERR_APPLEX_READ_ONLY,
    SPERR_NO_TERMINATING_RULE_PATH,
    SPERR_STREAM_CLOSED,
    SPERR_NO_MORE_ITEMS,
    SPERR_NOT_FOUND,
    SPERR_INVALID_AUDIO_STATE,
    SPERR_GENERIC_MMSYS_ERROR,
    SPERR_MARSHALER_EXCEPTION,
    SPERR_NOT_DYNAMIC_GRAMMAR,
    SPERR_AMBIGUOUS_PROPERTY,
    SPERR_INVALID_REGISTRY_KEY,
    SPERR_INVALID_TOKEN_ID,
    SPERR_XML_BAD_SYNTAX,
    SPERR_XML_RESOURCE_NOT_FOUND,
    SPERR_TOKEN_IN_USE,
    SPERR_TOKEN_DELETED,
    SPERR_MULTI_LINGUAL_NOT_SUPPORTED,
    SPERR_EXPORT_DYNAMIC_RULE,
    SPERR_STGF_ERROR,
    SPERR_WORDFORMAT_ERROR,
    SPERR_STREAM_NOT_ACTIVE,
    SPERR_ENGINE_RESPONSE_INVALID,
    SPERR_SR_ENGINE_EXCEPTION,
    SPERR_STREAM_POS_INVALID,
    SPERR_REMOTE_CALL_ON_WRONG_THREAD,
    SPERR_REMOTE_PROCESS_TERMINATED,
    SPERR_REMOTE_PROCESS_ALREADY_RUNNING,
    SPERR_LANGID_MISMATCH,
    SPERR_NOT_TOPLEVEL_RULE,
    SPERR_LEX_REQUIRES_COOKIE,
    SPERR_UNSUPPORTED_LANG,
    SPERR_VOICE_PAUSED,
    SPERR_AUDIO_BUFFER_UNDERFLOW,
    SPERR_AUDIO_STOPPED_UNEXPECTEDLY,
    SPERR_NO_WORD_PRONUNCIATION,
    SPERR_ALTERNATES_WOULD_BE_INCONSISTENT,
    SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER,
    SPERR_TIMEOUT,
    SPERR_REENTER_SYNCHRONIZE,
    SPERR_STATE_WITH_NO_ARCS,
    SPERR_NOT_ACTIVE_SESSION,
    SPERR_ALREADY_DELETED,
    SPERR_RECOXML_GENERATION_FAIL,
    SPERR_SML_GENERATION_FAIL,
    SPERR_NOT_PROMPT_VOICE,
    SPERR_ROOTRULE_ALREADY_DEFINED,
    SPERR_SCRIPT_DISALLOWED,
    SPERR_REMOTE_CALL_TIMED_OUT_START,
    SPERR_REMOTE_CALL_TIMED_OUT_CONNECT,
    SPERR_SECMGR_CHANGE_NOT_ALLOWED,
    SPERR_FAILED_TO_DELETE_FILE,
    SPERR_SHARED_ENGINE_DISABLED,
    SPERR_RECOGNIZER_NOT_FOUND,
    SPERR_AUDIO_NOT_FOUND,
    SPERR_NO_VOWEL,
    SPERR_UNSUPPORTED_PHONEME,
    SPERR_WORD_NEEDS_NORMALIZATION,
    SPERR_CANNOT_NORMALIZE,
    SPERR_TOPIC_NOT_ADAPTABLE,
    SPERR_PHONEME_CONVERSION,
    SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER,
    SPERR_OVERLOAD,
    SPERR_LEX_INVALID_DATA,
    SPERR_CFG_INVALID_DATA,
    SPERR_LEX_UNEXPECTED_FORMAT,
    SPERR_STRING_TOO_LONG,
    SPERR_STRING_EMPTY,
    SPERR_NON_WORD_TRANSITION,
    SPERR_SISR_ATTRIBUTES_NOT_ALLOWED,
    SPERR_SISR_MIXED_NOT_ALLOWED,
    SPERR_VOICE_NOT_FOUND,
    FSRM_E_NOT_FOUND,
    FSRM_E_INVALID_SCHEDULER_ARGUMENT,
    FSRM_E_ALREADY_EXISTS,
    FSRM_E_PATH_NOT_FOUND,
    FSRM_E_INVALID_USER,
    FSRM_E_INVALID_PATH,
    FSRM_E_INVALID_LIMIT,
    FSRM_E_INVALID_NAME,
    FSRM_E_FAIL_BATCH,
    FSRM_E_INVALID_TEXT,
    FSRM_E_INVALID_IMPORT_VERSION,
    FSRM_E_OUT_OF_RANGE,
    FSRM_E_REQD_PARAM_MISSING,
    FSRM_E_INVALID_COMBINATION,
    FSRM_E_DUPLICATE_NAME,
    FSRM_E_NOT_SUPPORTED,
    FSRM_E_DRIVER_NOT_READY,
    FSRM_E_INSUFFICIENT_DISK,
    FSRM_E_VOLUME_UNSUPPORTED,
    FSRM_E_UNEXPECTED,
    FSRM_E_INSECURE_PATH,
    FSRM_E_INVALID_SMTP_SERVER,
    FSRM_E_EMAIL_NOT_SENT,
    FSRM_E_INVALID_EMAIL_ADDRESS,
    FSRM_E_FILE_SYSTEM_CORRUPT,
    FSRM_E_LONG_CMDLINE,
    FSRM_E_INVALID_FILEGROUP_DEFINITION,
    FSRM_E_INVALID_DATASCREEN_DEFINITION,
    FSRM_E_INVALID_REPORT_FORMAT,
    FSRM_E_INVALID_REPORT_DESC,
    FSRM_E_INVALID_FILENAME,
    FSRM_E_SHADOW_COPY,
    FSRM_E_XML_CORRUPTED,
    FSRM_E_CLUSTER_NOT_RUNNING,
    FSRM_E_STORE_NOT_INSTALLED,
    FSRM_E_NOT_CLUSTER_VOLUME,
    FSRM_E_DIFFERENT_CLUSTER_GROUP,
    FSRM_E_REPORT_TYPE_ALREADY_EXISTS,
    FSRM_E_REPORT_JOB_ALREADY_RUNNING,
    FSRM_E_REPORT_GENERATION_ERR,
    FSRM_E_REPORT_TASK_TRIGGER,
    FSRM_E_LOADING_DISABLED_MODULE,
    FSRM_E_CANNOT_AGGREGATE,
    FSRM_E_MESSAGE_LIMIT_EXCEEDED,
    FSRM_E_OBJECT_IN_USE,
    FSRM_E_CANNOT_RENAME_PROPERTY,
    FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE,
    FSRM_E_MAX_PROPERTY_DEFINITIONS,
    FSRM_E_CLASSIFICATION_ALREADY_RUNNING,
    FSRM_E_CLASSIFICATION_NOT_RUNNING,
    FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING,
    FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION,
    FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM,
    FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION,
    FSRM_E_FILE_OPEN_ERROR,
    FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE,
    FSRM_E_CACHE_INVALID,
    FSRM_E_CACHE_MODULE_ALREADY_EXISTS,
    FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE,
    FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS,
    FSRM_E_PROPERTY_DELETED,
    FSRM_E_LAST_ACCESS_UPDATE_DISABLED,
    FSRM_E_NO_PROPERTY_VALUE,
    FSRM_E_INPROC_MODULE_BLOCKED,
    FSRM_E_ENUM_PROPERTIES_FAILED,
    FSRM_E_SET_PROPERTY_FAILED,
    FSRM_E_CANNOT_STORE_PROPERTIES,
    FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG,
    FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND,
    FSRM_E_TEXTREADER_NOT_INITIALIZED,
    FSRM_E_TEXTREADER_IFILTER_NOT_FOUND,
    FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED,
    FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED,
    FSRM_E_TEXTREADER_STREAM_ERROR,
    FSRM_E_TEXTREADER_FILENAME_TOO_LONG,
    FSRM_E_INCOMPATIBLE_FORMAT,
    FSRM_E_FILE_ENCRYPTED,
    FSRM_E_PERSIST_PROPERTIES_FAILED,
    FSRM_E_VOLUME_OFFLINE,
    FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT,
    FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED,
    FSRM_E_MODULE_INVALID_PARAM,
    FSRM_E_MODULE_INITIALIZATION,
    FSRM_E_MODULE_SESSION_INITIALIZATION,
    FSRM_E_CLASSIFICATION_SCAN_FAIL,
    FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE,
    FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS,
    FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY,
    FSRM_E_SYNC_TASK_TIMEOUT,
    FSRM_E_CANNOT_USE_DELETED_PROPERTY,
    FSRM_E_INVALID_AD_CLAIM,
    FSRM_E_CLASSIFICATION_CANCELED,
    FSRM_E_INVALID_FOLDER_PROPERTY_STORE,
    FSRM_E_REBUILDING_FODLER_TYPE_INDEX,
    FSRM_E_PROPERTY_MUST_APPLY_TO_FILES,
    FSRM_E_CLASSIFICATION_TIMEOUT,
    FSRM_E_CLASSIFICATION_PARTIAL_BATCH,
    FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY,
    FSRM_E_FILE_IN_USE,
    FSRM_E_ERROR_NOT_ENABLED,
    FSRM_E_CANNOT_CREATE_TEMP_COPY,
    FSRM_E_NO_EMAIL_ADDRESS,
    FSRM_E_ADR_MAX_EMAILS_SENT,
    FSRM_E_PATH_NOT_IN_NAMESPACE,
    FSRM_E_RMS_TEMPLATE_NOT_FOUND,
    FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED,
    FSRM_E_RMS_NO_PROTECTORS_INSTALLED,
    FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE,
    FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS,
    FSRM_E_PROPERTY_MUST_BE_SECURE,
    FSRM_E_PROPERTY_MUST_BE_GLOBAL,
    FSRM_E_WMI_FAILURE,
    FSRM_E_FILE_MANAGEMENT_JOB_RMS,
    FSRM_E_SYNC_TASK_HAD_ERRORS,
    FSRM_E_ADR_SRV_NOT_SUPPORTED,
    FSRM_E_ADR_PATH_IS_LOCAL,
    FSRM_E_ADR_NOT_DOMAIN_JOINED,
    FSRM_E_CANNOT_REMOVE_READONLY,
    FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG,
    FSRM_E_LEGACY_SCHEDULE,
    FSRM_E_CSC_PATH_NOT_SUPPORTED,
    FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE,
    FSRM_E_EXPIRATION_PATH_TOO_LONG,
    FSRM_E_EXPIRATION_VOLUME_NOT_NTFS,
    FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED,
    FSRM_E_MODULE_TIMEOUT,
    IFED_S_MORE_ENTRIES,
    IFED_S_EMPTY_DICTIONARY,
    IFED_S_WORD_EXISTS,
    IFED_S_COMMENT_CHANGED,
    IFED_E_NOT_FOUND,
    IFED_E_INVALID_FORMAT,
    IFED_E_OPEN_FAILED,
    IFED_E_WRITE_FAILED,
    IFED_E_NO_ENTRY,
    IFED_E_REGISTER_FAILED,
    IFED_E_NOT_USER_DIC,
    IFED_E_NOT_SUPPORTED,
    IFED_E_USER_COMMENT,
    IFED_E_REGISTER_ILLEGAL_POS,
    IFED_E_REGISTER_IMPROPER_WORD,
    IFED_E_REGISTER_DISCONNECTED,
    NETCFG_E_ALREADY_INITIALIZED,
    UPNP_E_REQUIRED_ELEMENT_ERROR,
    NETCFG_E_NOT_INITIALIZED,
    UPNP_E_DUPLICATE_NOT_ALLOWED,
    NETCFG_E_IN_USE,
    UPNP_E_DUPLICATE_SERVICE_ID,
    UPNP_E_INVALID_DESCRIPTION,
    NETCFG_E_NO_WRITE_LOCK,
    UPNP_E_INVALID_SERVICE,
    NETCFG_E_NEED_REBOOT,
    UPNP_E_INVALID_ICON,
    NETCFG_E_ACTIVE_RAS_CONNECTIONS,
    UPNP_E_INVALID_XML,
    NETCFG_E_ADAPTER_NOT_FOUND,
    UPNP_E_INVALID_ROOT_NAMESPACE,
    NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT,
    UPNP_E_SUFFIX_TOO_LONG,
    NETCFG_E_MAX_FILTER_LIMIT,
    UPNP_E_URLBASE_PRESENT,
    NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER,
    NETCFG_E_DUPLICATE_INSTANCEID,
    UPNP_E_VALUE_TOO_LONG,
    UPNP_E_DEVICE_RUNNING,
    UPNP_E_DEVICE_NOTREGISTERED,
    WTS_E_FAILEDEXTRACTION,
    WTS_E_EXTRACTIONTIMEDOUT,
    WTS_E_SURROGATEUNAVAILABLE,
    WTS_E_FASTEXTRACTIONNOTSUPPORTED,
    WTS_E_DATAFILEUNAVAILABLE,
    FTE_E_CB_OUT_OF_MEMORY,
    FTE_E_CB_CBID_OUT_OF_BOUND,
    FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM,
    FTE_E_CB_NOT_ENOUGH_OCC_BUFFER,
    FTE_E_CORRUPT_WORDLIST,
    XACT_E_ALREADYOTHERSINGLEPHASE,
    XACT_E_CANTRETAIN,
    XACT_E_COMMITFAILED,
    XACT_E_COMMITPREVENTED,
    XACT_E_HEURISTICABORT,
    XACT_E_HEURISTICCOMMIT,
    XACT_E_HEURISTICDAMAGE,
    XACT_E_HEURISTICDANGER,
    XACT_E_ISOLATIONLEVEL,
    XACT_E_NOASYNC,
    XACT_E_NOENLIST,
    XACT_E_NOISORETAIN,
    XACT_E_NORESOURCE,
    XACT_E_NOTCURRENT,
    XACT_E_NOTRANSACTION,
    XACT_E_NOTSUPPORTED,
    XACT_E_UNKNOWNRMGRID,
    XACT_E_WRONGSTATE,
    XACT_E_WRONGUOW,
    XACT_E_XTIONEXISTS,
    XACT_E_NOIMPORTOBJECT,
    XACT_E_INVALIDCOOKIE,
    XACT_E_INDOUBT,
    XACT_E_NOTIMEOUT,
    XACT_E_ALREADYINPROGRESS,
    XACT_E_ABORTED,
    XACT_E_LOGFULL,
    XACT_E_TMNOTAVAILABLE,
    XACT_E_CONNECTION_DOWN,
    XACT_E_CONNECTION_DENIED,
    XACT_E_REENLISTTIMEOUT,
    XACT_E_TIP_CONNECT_FAILED,
    XACT_E_TIP_PROTOCOL_ERROR,
    XACT_E_TIP_PULL_FAILED,
    XACT_E_DEST_TMNOTAVAILABLE,
    XACT_E_TIP_DISABLED,
    XACT_E_NETWORK_TX_DISABLED,
    XACT_E_PARTNER_NETWORK_TX_DISABLED,
    XACT_E_XA_TX_DISABLED,
    XACT_E_UNABLE_TO_READ_DTC_CONFIG,
    XACT_E_UNABLE_TO_LOAD_DTC_PROXY,
    XACT_E_ABORTING,
    XACT_E_PUSH_COMM_FAILURE,
    XACT_E_PULL_COMM_FAILURE,
    XACT_E_LU_TX_DISABLED,
    XACT_E_CLERKNOTFOUND,
    XACT_E_CLERKEXISTS,
    XACT_E_RECOVERYINPROGRESS,
    XACT_E_TRANSACTIONCLOSED,
    XACT_E_INVALIDLSN,
    XACT_E_REPLAYREQUEST,
    XACT_E_CONNECTION_REQUEST_DENIED,
    XACT_E_TOOMANY_ENLISTMENTS,
    XACT_E_DUPLICATE_GUID,
    SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED,
    XACT_E_NOTSINGLEPHASE,
    XACT_E_RECOVERYALREADYDONE,
    XACT_E_PROTOCOL,
    XACT_E_RM_FAILURE,
    XACT_E_RECOVERY_FAILED,
    XACT_E_LU_NOT_FOUND,
    XACT_E_DUPLICATE_LU,
    XACT_E_LU_NOT_CONNECTED,
    XACT_E_DUPLICATE_TRANSID,
    SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED,
    XACT_E_LU_BUSY,
    XACT_E_LU_NO_RECOVERY_PROCESS,
    XACT_E_LU_DOWN,
    XACT_E_LU_RECOVERING,
    XACT_E_LU_RECOVERY_MISMATCH,
    XACT_E_RM_UNAVAILABLE,
    CONTEXT_E_ABORTED,
    CONTEXT_E_ABORTING,
    CONTEXT_E_NOCONTEXT,
    CONTEXT_E_WOULD_DEADLOCK,
    CONTEXT_E_SYNCH_TIMEOUT,
    CONTEXT_E_OLDREF,
    CONTEXT_E_ROLENOTFOUND,
    CONTEXT_E_TMNOTAVAILABLE,
    CO_E_ACTIVATIONFAILED,
    CO_E_ACTIVATIONFAILED_EVENTLOGGED,
    CO_E_ACTIVATIONFAILED_CATALOGERROR,
    CO_E_ACTIVATIONFAILED_TIMEOUT,
    CO_E_INITIALIZATIONFAILED,
    CONTEXT_E_NOJIT,
    SL_E_INVALID_USE_OF_ADD_ON_PKEY,
    CONTEXT_E_NOTRANSACTION,
    CO_E_THREADINGMODEL_CHANGED,
    CO_E_NOIISINTRINSICS,
    CO_E_NOCOOKIES,
    CO_E_DBERROR,
    CO_E_NOTPOOLED,
    CO_E_NOTCONSTRUCTED,
    CO_E_NOSYNCHRONIZATION,
    CO_E_ISOLEVELMISMATCH,
    CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED,
    CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED,
    SL_E_SFS_INVALID_FS_VERSION,
    SL_E_SFS_INVALID_FD_TABLE,
    SL_E_SFS_INVALID_SYNC,
    SL_E_SFS_BAD_TOKEN_NAME,
    SL_E_SFS_BAD_TOKEN_EXT,
    SL_E_SFS_DUPLICATE_TOKEN_NAME,
    SL_E_SFS_TOKEN_SIZE_MISMATCH,
    SL_E_SFS_INVALID_TOKEN_DATA_HASH,
    SL_E_SFS_FILE_READ_ERROR,
    SL_E_SFS_FILE_WRITE_ERROR,
    SL_E_SFS_INVALID_FILE_POSITION,
    SL_E_SFS_NO_ACTIVE_TRANSACTION,
    SL_E_SFS_INVALID_FS_HEADER,
    SL_E_SFS_INVALID_TOKEN_DESCRIPTOR,
    FTE_E_FD_NO_IPERSIST_INTERFACE,
    FTE_E_FD_IFILTER_INIT_FAILED,
    FTE_E_FD_FAILED_TO_LOAD_IFILTER,
    FTE_E_FD_DOC_TIMEOUT,
    FTE_E_FD_UNEXPECTED_EXIT,
    FTE_E_FD_DOC_UNEXPECTED_EXIT,
    FTE_E_FD_NOISE_NO_TEXT_FILTER,
    FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER,
    FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED,
    FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED,
    FTE_E_FD_OCCURRENCE_OVERFLOW,
    FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION,
    IO_ERR_CONFIGURATION_ERROR,
    IO_ERR_DRIVER_ERROR,
    IO_ERR_PARITY,
    IO_ERR_SEEK_ERROR,
    IO_ERR_BAD_BLOCK,
    IO_ERR_OVERRUN_ERROR,
    IO_ERR_TIMEOUT,
    IO_ERR_SEQUENCE,
    IO_ERR_CONTROLLER_ERROR,
    IO_ERR_INTERNAL_ERROR,
    IO_ERR_INCORRECT_IRQL,
    IO_ERR_INVALID_IOBASE,
    IO_ERR_NOT_READY,
    IO_ERR_INVALID_REQUEST,
    IO_ERR_VERSION,
    IO_ERR_LAYERED_FAILURE,
    IO_ERR_RESET,
    IO_ERR_PROTOCOL,
    IO_ERR_MEMORY_CONFLICT_DETECTED,
    IO_ERR_PORT_CONFLICT_DETECTED,
    IO_ERR_DMA_CONFLICT_DETECTED,
    IO_ERR_IRQ_CONFLICT_DETECTED,
    IO_ERR_BAD_FIRMWARE,
    IO_ERR_DMA_RESOURCE_CONFLICT,
    IO_ERR_INTERRUPT_RESOURCE_CONFLICT,
    IO_ERR_MEMORY_RESOURCE_CONFLICT,
    IO_ERR_PORT_RESOURCE_CONFLICT,
    IO_BAD_BLOCK_WITH_NAME,
    IO_FILE_SYSTEM_CORRUPT,
    IO_FILE_QUOTA_CORRUPT,
    IO_SYSTEM_SLEEP_FAILED,
    IO_DUMP_POINTER_FAILURE,
    IO_DUMP_DRIVER_LOAD_FAILURE,
    IO_DUMP_INITIALIZATION_FAILURE,
    IO_DUMP_DUMPFILE_CONFLICT,
    IO_DUMP_DIRECT_CONFIG_FAILED,
    IO_DUMP_PAGE_CONFIG_FAILED,
    IO_FILE_SYSTEM_CORRUPT_WITH_NAME,
    IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER,
    IO_ERR_PORT_TIMEOUT,
    IO_ERROR_DISK_RESOURCES_EXHAUSTED,
    IO_ERROR_IO_HARDWARE_ERROR,
    ES_E_INVALID_RESPONSE,
    ES_E_UNPROVISIONED_HARDWARE,
    ES_E_UNSUPPORTED_HARDWARE,
    ES_E_INCOMPLETE_COMMAND,
    ES_E_BAD_SEQUENCE,
    ES_E_NO_PROBE,
    ES_E_INVALID_SILO,
    ES_E_INVALID_CAPABILITY,
    ES_E_GROUP_POLICY_FORBIDDEN_USE,
    ES_E_GROUP_POLICY_FORBIDDEN_OPERATION,
    ES_E_INVALID_PARAM_COMBINATION,
    ES_E_INVALID_PARAM_LENGTH,
    ES_E_INCONSISTENT_PARAM_LENGTH,
    ES_E_NO_AUTHENTICATION_REQUIRED,
    GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED,
    ES_E_INVALID_FIELD_IDENTIFIER,
    ES_E_CHALLENGE_MISMATCH,
    ES_E_CHALLENGE_SIZE_MISMATCH,
    ES_E_FRIENDLY_NAME_TOO_LONG,
    ES_E_SILO_NAME_TOO_LONG,
    ES_E_PASSWORD_TOO_LONG,
    ES_E_PASSWORD_HINT_TOO_LONG,
    ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE,
    ES_E_DEVICE_DIGEST_MISSING,
    ES_E_NOT_AUTHORIZED_UNEXPECTED,
    ES_E_AUTHORIZED_UNEXPECTED,
    ES_E_PROVISIONED_UNEXPECTED,
    ES_E_UNKNOWN_DIGEST_ALGORITHM,
    QUTIL_E_INVALID_CODEPAGE,
    FILTER_E_CONTENTINDEXCORRUPT,
    CI_CORRUPT_DATABASE,
    CI_CORRUPT_CATALOG,
    CI_INVALID_PARTITION,
    CI_INVALID_PRIORITY,
    CI_NO_STARTING_KEY,
    CI_OUT_OF_INDEX_IDS,
    CI_NO_CATALOG,
    CI_CORRUPT_FILTER_BUFFER,
    CI_INVALID_INDEX,
    CI_PROPSTORE_INCONSISTENCY,
    CI_INCORRECT_VERSION,
    CI_E_ENUMERATION_STARTED,
    CI_E_PROPERTY_TOOLARGE,
    CI_E_CLIENT_FILTER_ABORT,
    CI_E_CORRUPT_FWIDX,
    CI_E_DIACRITIC_SETTINGS_DIFFER,
    CI_E_NO_CATALOG_MANAGER,
    FTE_E_NO_PROPERTY_STORE,
    SL_E_SRV_INVALID_PUBLISH_LICENSE,
    SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE,
    SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE,
    SL_E_SRV_INVALID_LICENSE_STRUCTURE,
    SL_E_SRV_AUTHORIZATION_FAILED,
    SL_E_SRV_INVALID_BINDING,
    SL_E_SRV_SERVER_PONG,
    SL_E_SRV_INVALID_PAYLOAD,
    SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE,
    SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND,
    SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC,
    SL_E_SRV_GENERAL_ERROR,
    SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE,
    SL_E_CHPA_INVALID_BINDING,
    SL_E_CHPA_PRODUCT_KEY_BLOCKED,
    SL_E_CHPA_INVALID_PRODUCT_KEY,
    SL_E_CHPA_BINDING_NOT_FOUND,
    SL_E_CHPA_BINDING_MAPPING_NOT_FOUND,
    SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY,
    SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED,
    SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND,
    SL_E_CHPA_INVALID_PRODUCT_DATA_ID,
    SL_E_CHPA_INVALID_PRODUCT_DATA,
    SL_E_CHPA_SYSTEM_ERROR,
    SL_E_CHPA_INVALID_ACTCONFIG_ID,
    SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH,
    SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT,
    SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR,
    SL_E_CHPA_INVALID_BINDING_URI,
    SL_E_CHPA_NETWORK_ERROR,
    SL_E_CHPA_DATABASE_ERROR,
    SL_E_CHPA_INVALID_ARGUMENT,
    SL_E_CHPA_RESPONSE_NOT_AVAILABLE,
    SL_E_CHPA_OEM_SLP_COA0,
    SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION,
    SL_E_CHPA_DMAK_LIMIT_EXCEEDED,
    SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED,
    SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND,
    SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND,
    SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE,
    SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE,
    SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE,
    SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED,
    SL_E_CHPA_NO_RULES_TO_ACTIVATE,
    SL_E_CHPA_GENERAL_ERROR,
    SL_E_CHPA_DIGITALMARKER_INVALID_BINDING,
    SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED,
    SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY,
    SL_E_INVALID_LICENSE_STATE_BREACH_GRACE,
    SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED,
    SL_E_INVALID_TEMPLATE_ID,
    SL_E_INVALID_XML_BLOB,
    SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND,
    SL_E_INVALID_CLIENT_TOKEN,
    SL_E_INVALID_OFFLINE_BLOB,
    SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND,
    SL_E_INVALID_OSVERSION_TEMPLATEID,
    SL_E_OFFLINE_GENUINE_BLOB_REVOKED,
    SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND,
    SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA,
    SL_E_INVALID_OS_FOR_PRODUCT_KEY,
    SL_E_INVALID_FILE_HASH,
    SL_E_VALIDATION_BLOCKED_PRODUCT_KEY,
    SL_E_MISMATCHED_KEY_TYPES,
    SL_E_VALIDATION_INVALID_PRODUCT_KEY,
    SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA,
    SL_E_INVALID_LICENSE_STATE,
    SL_E_IP_LOCATION_FALIED,
    SL_E_SOFTMOD_EXPLOIT_DETECTED,
    SL_E_INVALID_TOKEN_DATA,
    SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES,
    SL_E_HEALTH_CHECK_FAILED_MUI_FILES,
    SL_E_INVALID_AD_DATA,
    SL_E_INVALID_RSDP_COUNT,
    SL_E_ENGINE_DETECTED_EXPLOIT,
    SL_E_NOTIFICATION_BREACH_DETECTED,
    SL_E_NOTIFICATION_GRACE_EXPIRED,
    SL_E_NOTIFICATION_OTHER_REASONS,
    SL_E_NON_GENUINE_STATUS_LAST,
    SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND,
    SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID,
    SL_E_CHPA_UNKNOWN_PROPERTY_NAME,
    SL_E_CHPA_UNKNOWN_PROPERTY_ID,
    SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING,
    SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING,
    SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING,
    SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML,
    SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY,
    SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY,
    SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY,
    SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE,
    SL_E_CHPA_PRODUCT_KEY_BEING_USED,
    SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD,
    SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD,
    SL_REMAPPING_SP_PUB_API_INVALID_LICENSE,
    SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE,
    SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS,
    SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY,
    SL_REMAPPING_SP_PUB_API_INVALID_HANDLE,
    SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH,
    SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER,
    SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED,
    SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED,
    SL_REMAPPING_SP_STATUS_GENERIC_FAILURE,
    SL_REMAPPING_SP_STATUS_INVALIDARG,
    SL_REMAPPING_SP_STATUS_ALREADY_EXISTS,
    SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER,
    SL_REMAPPING_SP_STATUS_INVALIDDATA,
    SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL,
    SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION,
    SL_REMAPPING_SP_STATUS_NO_MORE_DATA,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE,
    SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID,
    SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID,
    SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID,
    SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID,
    SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED,
    SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE,
    SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND,
    SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT,
    SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING,
    SL_REMAPPING_SP_PUB_TS_TAMPERED,
    SL_REMAPPING_SP_PUB_TS_REARMED,
    SL_REMAPPING_SP_PUB_TS_RECREATED,
    SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND,
    SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS,
    SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG,
    SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED,
    SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG,
    SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING,
    SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS,
    SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND,
    SL_REMAPPING_SP_PUB_TIMER_EXPIRED,
    SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG,
    SL_REMAPPING_SP_PUB_TS_FULL,
    SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY,
    SL_REMAPPING_SP_PUB_TIMER_READ_ONLY,
    SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY,
    SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND,
    SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED,
    SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND,
    SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE,
    SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID,
    SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION,
    SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA,
    SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA,
    SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH,
    SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH,
    SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION,
    SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED,
    SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER,
    SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED,
    SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT,
    SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER,
    SL_E_INVALID_CONTEXT,
    SL_E_TOKEN_STORE_INVALID_STATE,
    SL_E_EVALUATION_FAILED,
    SL_E_NOT_EVALUATED,
    SL_E_NOT_ACTIVATED,
    SL_E_INVALID_GUID,
    SL_E_TOKSTO_TOKEN_NOT_FOUND,
    SL_E_TOKSTO_NO_PROPERTIES,
    SL_E_TOKSTO_NOT_INITIALIZED,
    SL_E_TOKSTO_ALREADY_INITIALIZED,
    SL_E_TOKSTO_NO_ID_SET,
    SL_E_TOKSTO_CANT_CREATE_FILE,
    SL_E_TOKSTO_CANT_WRITE_TO_FILE,
    SL_E_TOKSTO_CANT_READ_FILE,
    SL_E_TOKSTO_CANT_PARSE_PROPERTIES,
    SL_E_TOKSTO_PROPERTY_NOT_FOUND,
    SL_E_TOKSTO_INVALID_FILE,
    SL_E_TOKSTO_CANT_CREATE_MUTEX,
    SL_E_TOKSTO_CANT_ACQUIRE_MUTEX,
    SL_E_TOKSTO_NO_TOKEN_DATA,
    SL_E_EUL_CONSUMPTION_FAILED,
    SL_E_PKEY_INVALID_CONFIG,
    SL_E_PKEY_INVALID_UNIQUEID,
    SL_E_PKEY_INVALID_ALGORITHM,
    SL_E_PKEY_INTERNAL_ERROR,
    SL_E_LICENSE_INVALID_ADDON_INFO,
    SL_E_HWID_ERROR,
    SL_E_PKEY_INVALID_KEYCHANGE1,
    SL_E_PKEY_INVALID_KEYCHANGE2,
    SL_E_PKEY_INVALID_KEYCHANGE3,
    SL_E_POLICY_OTHERINFO_MISMATCH,
    SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID,
    SL_E_SECURE_STORE_ID_MISMATCH,
    SL_E_INVALID_RULESET_RULE,
    SL_E_INVALID_CONTEXT_DATA,
    SL_E_INVALID_HASH,
    SL_E_WINDOWS_VERSION_MISMATCH,
    SL_E_ACTIVATION_IN_PROGRESS,
    SL_E_STORE_UPGRADE_TOKEN_REQUIRED,
    SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION,
    SL_E_STORE_UPGRADE_TOKEN_WRONG_PID,
    SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED,
    SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION,
    SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED,
    SL_E_INTERNAL_ERROR,
    SL_E_RIGHT_NOT_CONSUMED,
    SL_E_USE_LICENSE_NOT_INSTALLED,
    SL_E_MISMATCHED_PKEY_RANGE,
    SL_E_MISMATCHED_PID,
    SL_E_EXTERNAL_SIGNATURE_NOT_FOUND,
    SL_E_RAC_NOT_AVAILABLE,
    SL_E_SPC_NOT_AVAILABLE,
    SL_E_GRACE_TIME_EXPIRED,
    SL_E_MISMATCHED_APPID,
    SL_E_NO_PID_CONFIG_DATA,
    SL_E_MISMATCHED_SECURITY_PROCESSOR,
    SL_E_OUT_OF_TOLERANCE,
    SL_E_INVALID_PKEY,
    SL_E_LICENSE_FILE_NOT_INSTALLED,
    SL_E_VALUE_NOT_FOUND,
    SL_E_RIGHT_NOT_GRANTED,
    SL_E_PKEY_NOT_INSTALLED,
    SL_E_PRODUCT_SKU_NOT_INSTALLED,
    SL_E_NOT_SUPPORTED,
    SL_E_PUBLISHING_LICENSE_NOT_INSTALLED,
    SL_E_LICENSE_SERVER_URL_NOT_FOUND,
    SL_E_INVALID_EVENT_ID,
    SL_E_EVENT_NOT_REGISTERED,
    SL_E_EVENT_ALREADY_REGISTERED,
    SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE,
    SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED,
    SL_E_DATATYPE_MISMATCHED,
    SL_E_INVALID_LICENSE,
    SL_E_INVALID_PACKAGE,
    SL_E_VALIDITY_TIME_EXPIRED,
    SL_E_LICENSE_AUTHORIZATION_FAILED,
    SL_E_LICENSE_DECRYPTION_FAILED,
    SL_E_WINDOWS_INVALID_LICENSE_STATE,
    SL_E_LUA_ACCESSDENIED,
    SL_E_PROXY_KEY_NOT_FOUND,
    SL_E_TAMPER_DETECTED,
    SL_E_POLICY_CACHE_INVALID,
    SL_E_INVALID_RUNNING_MODE,
    SL_E_SLP_NOT_SIGNED,
    SL_E_CIDIID_INVALID_DATA,
    SL_E_CIDIID_INVALID_VERSION,
    SL_E_CIDIID_VERSION_NOT_SUPPORTED,
    SL_E_CIDIID_INVALID_DATA_LENGTH,
    SL_E_CIDIID_NOT_DEPOSITED,
    SL_E_CIDIID_MISMATCHED,
    SL_E_INVALID_BINDING_BLOB,
    SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED,
    SL_E_EUL_NOT_AVAILABLE,
    SL_E_VL_NOT_WINDOWS_SLP,
    SL_E_VL_NOT_ENOUGH_COUNT,
    SL_E_VL_BINDING_SERVICE_NOT_ENABLED,
    SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED,
    SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH,
    SL_E_PROXY_POLICY_NOT_UPDATED,
    SL_E_CIDIID_INVALID_CHECK_DIGITS,
    SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND,
    SL_E_INVALID_PRODUCT_KEY,
    SL_E_BLOCKED_PRODUCT_KEY,
    SL_E_DUPLICATE_POLICY,
    SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE,
    SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED,
    SL_E_BASE_SKU_NOT_AVAILABLE,
    SL_E_VL_MACHINE_NOT_BOUND,
    SL_E_SLP_MISSING_ACPI_SLIC,
    SL_E_SLP_MISSING_SLP_MARKER,
    SL_E_SLP_BAD_FORMAT,
    SL_E_INVALID_PACKAGE_VERSION,
    SL_E_PKEY_INVALID_UPGRADE,
    SL_E_ISSUANCE_LICENSE_NOT_INSTALLED,
    SL_E_SLP_OEM_CERT_MISSING,
    SL_E_NONGENUINE_GRACE_TIME_EXPIRED,
    SL_E_DEPENDENT_PROPERTY_NOT_SET,
    SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2,
    SL_E_MISMATCHED_PRODUCT_SKU,
    SL_E_OPERATION_NOT_ALLOWED,
    SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED,
    SL_E_VL_INVALID_TIMESTAMP,
    SL_E_PLUGIN_INVALID_MANIFEST,
    SL_E_APPLICATION_POLICIES_MISSING,
    SL_E_APPLICATION_POLICIES_NOT_LOADED,
    SL_E_VL_BINDING_SERVICE_UNAVAILABLE,
    SL_E_SERVICE_STOPPING,
    SL_E_PLUGIN_NOT_REGISTERED,
    SL_E_AUTHN_WRONG_VERSION,
    SL_E_AUTHN_MISMATCHED_KEY,
    SL_E_AUTHN_CHALLENGE_NOT_SET,
    SL_E_AUTHN_CANT_VERIFY,
    SL_E_SERVICE_RUNNING,
    SL_E_SLP_INVALID_MARKER_VERSION,
    SL_E_INVALID_PRODUCT_KEY_TYPE,
    SL_E_CIDIID_MISMATCHED_PKEY,
    SL_E_CIDIID_NOT_BOUND,
    SL_E_LICENSE_NOT_BOUND,
    SL_E_VL_AD_AO_NOT_FOUND,
    SL_E_VL_AD_AO_NAME_TOO_LONG,
    SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED,
    SL_E_NOT_GENUINE,
    SL_E_EDITION_MISMATCHED,
    SL_E_TKA_CHALLENGE_EXPIRED,
    SL_E_TKA_SILENT_ACTIVATION_FAILURE,
    SL_E_TKA_INVALID_CERT_CHAIN,
    SL_E_TKA_GRANT_NOT_FOUND,
    SL_E_TKA_CERT_NOT_FOUND,
    SL_E_TKA_INVALID_SKU_ID,
    SL_E_TKA_INVALID_BLOB,
    SL_E_TKA_TAMPERED_CERT_CHAIN,
    SL_E_TKA_CHALLENGE_MISMATCH,
    SL_E_TKA_INVALID_CERTIFICATE,
    SL_E_TKA_INVALID_SMARTCARD,
    SL_E_TKA_FAILED_GRANT_PARSING,
    SL_E_TKA_INVALID_THUMBPRINT,
    SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND,
    SL_E_TKA_CRITERIA_MISMATCH,
    SL_E_TKA_TPID_MISMATCH,
    SL_E_TKA_SOFT_CERT_DISALLOWED,
    SL_E_TKA_SOFT_CERT_INVALID,
    SL_E_TKA_CERT_CNG_NOT_AVAILABLE,
    E_RM_UNKNOWN_ERROR,
    SL_E_VALIDITY_PERIOD_EXPIRED,
    SL_E_IA_THROTTLE_LIMIT_EXCEEDED,
    SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM,
    SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED,
    SL_E_IA_ID_MISMATCH,
    SL_E_IA_MACHINE_NOT_BOUND,
    SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION,
}

impl ITF {
    pub fn code(&self) -> u32 {
        return match self {
            ITF::OLE_S_USEREG => 0x00040000 as u32,
            ITF::OLE_S_STATIC => 0x00040001 as u32,
            ITF::MS_S_PENDING => 0x00040001 as u32,
            ITF::OLE_S_MAC_CLIPFORMAT => 0x00040002 as u32,
            ITF::MS_S_NOUPDATE => 0x00040002 as u32,
            ITF::MS_S_ENDOFSTREAM => 0x00040003 as u32,
            ITF::OLE_S_LAST => 0x000400FF as u32,
            ITF::DRAGDROP_S_DROP => 0x00040100 as u32,
            ITF::DRAGDROP_S_CANCEL => 0x00040101 as u32,
            ITF::DRAGDROP_S_USEDEFAULTCURSORS => 0x00040102 as u32,
            ITF::VFW_S_NO_MORE_ITEMS => 0x00040103 as u32,
            ITF::DATA_S_SAMEFORMATETC => 0x00040130 as u32,
            ITF::VIEW_S_ALREADY_FROZEN => 0x00040140 as u32,
            ITF::CACHE_S_FORMATETC_NOTSUPPORTED => 0x00040170 as u32,
            ITF::CACHE_S_SAMECACHE => 0x00040171 as u32,
            ITF::CACHE_S_SOMECACHES_NOTUPDATED => 0x00040172 as u32,
            ITF::OLEOBJ_S_INVALIDVERB => 0x00040180 as u32,
            ITF::OLEOBJ_S_CANNOT_DOVERB_NOW => 0x00040181 as u32,
            ITF::OLEOBJ_S_INVALIDHWND => 0x00040182 as u32,
            ITF::INPLACE_S_TRUNCATED => 0x000401A0 as u32,
            ITF::CONVERT10_S_NO_PRESENTATION => 0x000401C0 as u32,
            ITF::MK_S_REDUCED_TO_SELF => 0x000401E2 as u32,
            ITF::MK_S_ME => 0x000401E4 as u32,
            ITF::MK_S_HIM => 0x000401E5 as u32,
            ITF::MK_S_US => 0x000401E6 as u32,
            ITF::MK_S_MONIKERALREADYREGISTERED => 0x000401E7 as u32,
            ITF::MK_S_ASYNCHRONOUS => 0x000401E8 as u32,
            ITF::EVENT_S_SOME_SUBSCRIBERS_FAILED => 0x00040200 as u32,
            ITF::IMAPI_S_PROPERTIESIGNORED => 0x00040200 as u32,
            ITF::MPEG2_S_MORE_DATA_AVAILABLE => 0x00040200 as u32,
            ITF::IMAPI_S_BUFFER_TO_SMALL => 0x00040201 as u32,
            ITF::MPEG2_S_NO_MORE_DATA_AVAILABLE => 0x00040201 as u32,
            ITF::EVENT_S_NOSUBSCRIBERS => 0x00040202 as u32,
            ITF::MPEG2_S_SG_INFO_FOUND => 0x00040202 as u32,
            ITF::_MAPI_W_NO_SERVICE => 0x00040203 as u32,
            ITF::MPEG2_S_SG_INFO_NOT_FOUND => 0x00040203 as u32,
            ITF::MPEG2_S_MPE_INFO_FOUND => 0x00040204 as u32,
            ITF::MPEG2_S_MPE_INFO_NOT_FOUND => 0x00040205 as u32,
            ITF::MPEG2_S_NEW_MODULE_VERSION => 0x00040206 as u32,
            ITF::VFW_S_DUPLICATE_NAME => 0x0004022D as u32,
            ITF::VFW_S_STATE_INTERMEDIATE => 0x00040237 as u32,
            ITF::VFW_S_PARTIAL_RENDER => 0x00040242 as u32,
            ITF::VFW_S_SOME_DATA_IGNORED => 0x00040245 as u32,
            ITF::VFW_S_CONNECTIONS_DEFERRED => 0x00040246 as u32,
            ITF::VFW_S_RESOURCE_NOT_NEEDED => 0x00040250 as u32,
            ITF::TPC_S_TRUNCATED => 0x00040252 as u32,
            ITF::TPC_S_INTERRUPTED => 0x00040253 as u32,
            ITF::TPC_S_NO_DATA_TO_PROCESS => 0x00040254 as u32,
            ITF::VFW_S_MEDIA_TYPE_IGNORED => 0x00040254 as u32,
            ITF::VFW_S_VIDEO_NOT_RENDERED => 0x00040257 as u32,
            ITF::VFW_S_AUDIO_NOT_RENDERED => 0x00040258 as u32,
            ITF::VFW_S_RPZA => 0x0004025A as u32,
            ITF::VFW_S_ESTIMATED => 0x00040260 as u32,
            ITF::VFW_S_RESERVED => 0x00040263 as u32,
            ITF::VFW_S_STREAM_OFF => 0x00040267 as u32,
            ITF::VFW_S_CANT_CUE => 0x00040268 as u32,
            ITF::VFW_S_NOPREVIEWPIN => 0x0004027E as u32,
            ITF::VFW_S_DVD_NON_ONE_SEQUENTIAL => 0x00040280 as u32,
            ITF::VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE => 0x0004028C as u32,
            ITF::VFW_S_DVD_NOT_ACCURATE => 0x0004028D as u32,
            ITF::TF_S_ASYNC => 0x00040300 as u32,
            ITF::TS_S_ASYNC => 0x00040300 as u32,
            ITF::CM_S_NODATASERVERS => 0x00040607 as u32,
            ITF::QRY_S_NOROWSFOUND => 0x00040704 as u32,
            ITF::QRY_S_TERMIGNORED => 0x00040712 as u32,
            ITF::QRY_S_INEXACTRESULTS => 0x00040716 as u32,
            ITF::IDS_MON_DEFAULT_ERROR => 0x0004092F as u32,
            ITF::IDS_MON_ILLEGAL_PASSTHROUGH => 0x00040930 as u32,
            ITF::IDS_MON_PARSE_ERR_1_PARAM => 0x00040931 as u32,
            ITF::IDS_MON_PARSE_ERR_2_PARAM => 0x00040932 as u32,
            ITF::IDS_MON_SEMI_COLON => 0x00040933 as u32,
            ITF::IDS_MON_ORDINAL_OUT_OF_RANGE => 0x00040934 as u32,
            ITF::IDS_MON_VIEW_NOT_DEFINED => 0x00040935 as u32,
            ITF::IDS_MON_COLUMN_NOT_DEFINED => 0x00040936 as u32,
            ITF::IDS_MON_BUILTIN_VIEW => 0x00040937 as u32,
            ITF::IDS_MON_OUT_OF_MEMORY => 0x00040938 as u32,
            ITF::IDS_MON_SELECT_STAR => 0x00040939 as u32,
            ITF::IDS_MON_OR_NOT => 0x0004093A as u32,
            ITF::IDS_MON_CANNOT_CONVERT => 0x0004093B as u32,
            ITF::IDS_MON_OUT_OF_RANGE => 0x0004093C as u32,
            ITF::IDS_MON_RELATIVE_INTERVAL => 0x0004093D as u32,
            ITF::IDS_MON_NOT_COLUMN_OF_VIEW => 0x0004093E as u32,
            ITF::IDS_MON_BUILTIN_PROPERTY => 0x0004093F as u32,
            ITF::IDS_MON_WEIGHT_OUT_OF_RANGE => 0x00040940 as u32,
            ITF::IDS_MON_MATCH_STRING => 0x00040941 as u32,
            ITF::IDS_MON_PROPERTY_NAME_IN_VIEW => 0x00040942 as u32,
            ITF::IDS_MON_VIEW_ALREADY_DEFINED => 0x00040943 as u32,
            ITF::IDS_MON_INVALID_CATALOG => 0x00040944 as u32,
            ITF::IDS_MON_INVALIDSELECT_COALESCE => 0x00040945 as u32,
            ITF::IDS_MON_CANNOT_CAST => 0x00040946 as u32,
            ITF::IDS_MON_DATE_OUT_OF_RANGE => 0x00040947 as u32,
            ITF::IDS_MON_INVALID_IN_GROUP_CLAUSE => 0x00040948 as u32,
            ITF::GTHR_S_STATUS_CHANGE_IGNORED => 0x00040D1C as u32,
            ITF::GTHR_S_STATUS_END_CRAWL => 0x00040D1D as u32,
            ITF::GTHR_S_STATUS_RESET => 0x00040D1E as u32,
            ITF::GTHR_S_STATUS_THROTTLE => 0x00040D1F as u32,
            ITF::GTHR_S_STATUS_RESUME => 0x00040D20 as u32,
            ITF::GTHR_S_STATUS_PAUSE => 0x00040D21 as u32,
            ITF::GTHR_S_END_STD_CHUNKS => 0x00040D24 as u32,
            ITF::GTHR_S_NO_CRAWL_SEEDS => 0x00040D2B as u32,
            ITF::GTHR_S_CANNOT_FILTER => 0x00040D30 as u32,
            ITF::GTHR_S_STATUS_STOP => 0x00040D33 as u32,
            ITF::GTHR_S_STATUS_START => 0x00040D36 as u32,
            ITF::GTHR_S_CONFIG_HAS_ACCOUNTS => 0x00040D56 as u32,
            ITF::GTHR_S_PROB_NOT_MODIFIED => 0x00040D67 as u32,
            ITF::GTHR_S_CRAWL_SCHEDULED => 0x00040D68 as u32,
            ITF::GTHR_S_TRANSACTION_IGNORED => 0x00040D69 as u32,
            ITF::GTHR_S_START_FILTER_FROM_PROTOCOL => 0x00040D6A as u32,
            ITF::GTHR_S_BAD_FILE_LINK => 0x00040D6C as u32,
            ITF::GTHR_S_NOT_ALL_PARTS => 0x00040D6E as u32,
            ITF::GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE => 0x00040D70 as u32,
            ITF::GTHR_S_START_FILTER_FROM_BODY => 0x00040D71 as u32,
            ITF::GTHR_S_MODIFIED_PARTS => 0x00040D78 as u32,
            ITF::GTHR_S_CRAWL_FULL => 0x00040D83 as u32,
            ITF::GTHR_S_CRAWL_INCREMENTAL => 0x00040D84 as u32,
            ITF::GTHR_S_CRAWL_ADAPTIVE => 0x00040D85 as u32,
            ITF::GTHR_S_NO_INDEX => 0x00040D90 as u32,
            ITF::GTHR_S_PAUSE_REASON_EXTERNAL => 0x00040D92 as u32,
            ITF::GTHR_S_PAUSE_REASON_UPGRADING => 0x00040D93 as u32,
            ITF::GTHR_S_PAUSE_REASON_BACKOFF => 0x00040D94 as u32,
            ITF::GTHR_S_OFFICE_CHILD => 0x00040D9A as u32,
            ITF::GTHR_S_CANNOT_WORDBREAK => 0x00040DA6 as u32,
            ITF::GTHR_S_USE_MIME_FILTER => 0x00040DA7 as u32,
            ITF::GTHR_S_PAUSE_REASON_PROFILE_IMPORT => 0x00040DB3 as u32,
            ITF::DB_S_ROWLIMITEXCEEDED => 0x00040EC0 as u32,
            ITF::DB_S_COLUMNTYPEMISMATCH => 0x00040EC1 as u32,
            ITF::DB_S_TYPEINFOOVERRIDDEN => 0x00040EC2 as u32,
            ITF::DB_S_BOOKMARKSKIPPED => 0x00040EC3 as u32,
            ITF::DB_S_NONEXTROWSET => 0x00040EC5 as u32,
            ITF::DB_S_ENDOFROWSET => 0x00040EC6 as u32,
            ITF::DB_S_COMMANDREEXECUTED => 0x00040EC7 as u32,
            ITF::DB_S_BUFFERFULL => 0x00040EC8 as u32,
            ITF::DB_S_NORESULT => 0x00040EC9 as u32,
            ITF::DB_S_CANTRELEASE => 0x00040ECA as u32,
            ITF::DB_S_GOALCHANGED => 0x00040ECB as u32,
            ITF::DB_S_UNWANTEDOPERATION => 0x00040ECC as u32,
            ITF::DB_S_DIALECTIGNORED => 0x00040ECD as u32,
            ITF::DB_S_UNWANTEDPHASE => 0x00040ECE as u32,
            ITF::DB_S_UNWANTEDREASON => 0x00040ECF as u32,
            ITF::DB_S_ASYNCHRONOUS => 0x00040ED0 as u32,
            ITF::DB_S_COLUMNSCHANGED => 0x00040ED1 as u32,
            ITF::DB_S_ERRORSRETURNED => 0x00040ED2 as u32,
            ITF::DB_S_BADROWHANDLE => 0x00040ED3 as u32,
            ITF::DB_S_DELETEDROW => 0x00040ED4 as u32,
            ITF::DB_S_TOOMANYCHANGES => 0x00040ED5 as u32,
            ITF::DB_S_STOPLIMITREACHED => 0x00040ED6 as u32,
            ITF::DB_S_NOTSINGLETON => 0x00040ED7 as u32,
            ITF::DB_S_LOCKUPGRADED => 0x00040ED8 as u32,
            ITF::DB_S_PROPERTIESCHANGED => 0x00040ED9 as u32,
            ITF::DB_S_ERRORSOCCURRED => 0x00040EDA as u32,
            ITF::DB_S_PARAMUNAVAILABLE => 0x00040EDB as u32,
            ITF::DB_S_MULTIPLECHANGES => 0x00040EDC as u32,
            ITF::DB_S_NOROWSPECIFICCOLUMNS => 0x00040EDD as u32,
            ITF::REC_S_IDIDTHEUPDATES => 0x00041000 as u32,
            ITF::REC_S_NOTCOMPLETE => 0x00041001 as u32,
            ITF::SEO_S_MOREDATA => 0x00041001 as u32,
            ITF::REC_S_NOTCOMPLETEBUTPROPAGATE => 0x00041002 as u32,
            ITF::IDX_S_NO_BUILD_IN_PROGRESS => 0x00041114 as u32,
            ITF::IDX_S_SEARCH_SERVER_ALREADY_EXISTS => 0x00041115 as u32,
            ITF::IDX_S_SEARCH_SERVER_DOES_NOT_EXIST => 0x00041116 as u32,
            ITF::IDX_S_DSS_NOT_AVAILABLE => 0x0004111D as u32,
            ITF::JPS_S_DUPLICATE_DOC_DETECTED => 0x00041180 as u32,
            ITF::PRTH_S_NOT_MODIFIED => 0x00041203 as u32,
            ITF::PRTH_S_MAX_GROWTH => 0x00041209 as u32,
            ITF::PRTH_S_MAX_DOWNLOAD => 0x0004120C as u32,
            ITF::PRTH_S_ACL_IS_READ_EVERYONE => 0x00041210 as u32,
            ITF::PRTH_S_USE_ROSEBUD => 0x00041214 as u32,
            ITF::PRTH_S_NOT_ALL_PARTS => 0x0004121B as u32,
            ITF::PRTH_S_TRY_IMPERSONATING => 0x00041225 as u32,
            ITF::SCHED_S_TASK_READY => 0x00041300 as u32,
            ITF::SCHED_S_TASK_RUNNING => 0x00041301 as u32,
            ITF::SCHED_S_TASK_DISABLED => 0x00041302 as u32,
            ITF::SCHED_S_TASK_HAS_NOT_RUN => 0x00041303 as u32,
            ITF::SCHED_S_TASK_NO_MORE_RUNS => 0x00041304 as u32,
            ITF::SCHED_S_TASK_NOT_SCHEDULED => 0x00041305 as u32,
            ITF::SCHED_S_TASK_TERMINATED => 0x00041306 as u32,
            ITF::SCHED_S_TASK_NO_VALID_TRIGGERS => 0x00041307 as u32,
            ITF::SCHED_S_EVENT_TRIGGER => 0x00041308 as u32,
            ITF::SCHED_S_SOME_TRIGGERS_FAILED => 0x0004131B as u32,
            ITF::SCHED_S_BATCH_LOGON_PROBLEM => 0x0004131C as u32,
            ITF::SCHED_S_TASK_QUEUED => 0x00041325 as u32,
            ITF::QPLIST_S_DUPLICATE => 0x00041679 as u32,
            ITF::FDAEMON_W_WORDLISTFULL => 0x00041680 as u32,
            ITF::FDAEMON_W_EMPTYWORDLIST => 0x00041685 as u32,
            ITF::SEARCH_S_NOMOREHITS => 0x000416A0 as u32,
            ITF::FILTER_W_MONIKER_CLIPPED => 0x00041704 as u32,
            ITF::FILTER_S_LAST_TEXT => 0x00041709 as u32,
            ITF::FILTER_S_LAST_VALUES => 0x0004170A as u32,
            ITF::FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE => 0x00041731 as u32,
            ITF::FILTER_S_FULL_CONTENTSCAN_IMMEDIATE => 0x00041732 as u32,
            ITF::FILTER_S_CONTENTSCAN_DELAYED => 0x00041733 as u32,
            ITF::FILTER_S_DISK_FULL => 0x00041735 as u32,
            ITF::FILTER_S_NO_PROPSETS => 0x0004173A as u32,
            ITF::FILTER_S_NO_SECURITY_DESCRIPTOR => 0x0004173C as u32,
            ITF::LANGUAGE_S_LARGE_WORD => 0x00041781 as u32,
            ITF::PSINK_S_LARGE_WORD => 0x00041793 as u32,
            ITF::CI_S_WORKID_DELETED => 0x0004180E as u32,
            ITF::CI_S_END_OF_ENUMERATION => 0x00041814 as u32,
            ITF::CI_S_NO_DOCSTORE => 0x00041825 as u32,
            ITF::CI_S_CAT_STOPPED => 0x00041826 as u32,
            ITF::CI_S_NEW_AUXMETADATA => 0x00041829 as u32,
            ITF::CI_S_CLIENT_REQUESTED_ABORT => 0x0004182B as u32,
            ITF::CI_S_RETRY_DOCUMENT => 0x0004182C as u32,
            ITF::CI_S_CATALOG_RESET => 0x00041830 as u32,
            ITF::NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED => 0x00041902 as u32,
            ITF::VSS_S_ASYNC_PENDING => 0x00042309 as u32,
            ITF::VSS_S_ASYNC_FINISHED => 0x0004230A as u32,
            ITF::VSS_S_ASYNC_CANCELLED => 0x0004230B as u32,
            ITF::VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED => 0x00042321 as u32,
            ITF::VDS_S_DISK_PARTIALLY_CLEANED => 0x0004241A as u32,
            ITF::VDS_S_PROVIDER_ERROR_LOADING_CACHE => 0x00042421 as u32,
            ITF::VDS_S_UPDATE_BOOTFILE_FAILED => 0x00042434 as u32,
            ITF::VDS_S_BOOT_PARTITION_NUMBER_CHANGE => 0x00042436 as u32,
            ITF::VDS_S_VOLUME_COMPRESS_FAILED => 0x00042443 as u32,
            ITF::VDS_S_IN_PROGRESS => 0x0004244D as u32,
            ITF::VDS_S_IA64_BOOT_MIRRORED_TO_MBR => 0x0004245A as u32,
            ITF::VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES => 0x0004245B as u32,
            ITF::VDS_S_EXTEND_FILE_SYSTEM_FAILED => 0x00042465 as u32,
            ITF::VDS_S_MBR_BOOT_MIRRORED_TO_GPT => 0x00042467 as u32,
            ITF::VDS_S_DISK_IS_MISSING => 0x00042508 as u32,
            ITF::VDS_S_NONCONFORMANT_PARTITION_INFO => 0x0004250A as u32,
            ITF::VDS_S_SYSTEM_PARTITION => 0x0004250E as u32,
            ITF::VDS_S_NO_NOTIFICATION => 0x00042517 as u32,
            ITF::VDS_S_DEFAULT_PLEX_MEMBER_IDS => 0x00042518 as u32,
            ITF::VDS_S_DISMOUNT_FAILED => 0x00042577 as u32,
            ITF::VDS_S_REMOUNT_FAILED => 0x00042578 as u32,
            ITF::VDS_S_RESYNC_NOTIFICATION_TASK_FAILED => 0x0004257A as u32,
            ITF::VDS_S_VSS_FLUSH_AND_HOLD_WRITES => 0x00042581 as u32,
            ITF::VDS_S_VSS_RELEASE_WRITES => 0x00042582 as u32,
            ITF::VDS_S_FS_LOCK => 0x00042583 as u32,
            ITF::VDS_S_PLEX_NOT_LOADED_TO_CACHE => 0x0004258B as u32,
            ITF::VDS_S_WINPE_BOOTENTRY => 0x0004258E as u32,
            ITF::NOTESPH_S_IGNORE_ID => 0x00042602 as u32,
            ITF::NOTESPH_S_LISTKNOWNFIELDS => 0x00042610 as u32,
            ITF::VDS_S_NAME_TRUNCATED => 0x00042700 as u32,
            ITF::VDS_S_STATUSES_INCOMPLETELY_SET => 0x00042702 as u32,
            ITF::VDS_S_ALREADY_EXISTS => 0x00042714 as u32,
            ITF::VDS_S_PROPERTIES_INCOMPLETE => 0x00042715 as u32,
            ITF::VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED => 0x00042800 as u32,
            ITF::VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED => 0x00042801 as u32,
            ITF::VDS_S_ISCSI_LOGIN_ALREAD_EXISTS => 0x00042802 as u32,
            ITF::VDS_S_DISK_MOUNT_FAILED => 0x00042808 as u32,
            ITF::VDS_S_DISK_DISMOUNT_FAILED => 0x00042809 as u32,
            ITF::REXSPH_S_REDIRECTED => 0x00043501 as u32,
            ITF::FTE_S_RESOURCES_STARTING_TO_GET_LOW => 0x00043619 as u32,
            ITF::FTE_S_BEYOND_QUOTA => 0x00043622 as u32,
            ITF::FTE_S_REDUNDANT => 0x00043625 as u32,
            ITF::FTE_S_STATUS_CHANGE_REQUEST => 0x0004362B as u32,
            ITF::FTE_S_RESUME => 0x0004362E as u32,
            ITF::FTE_S_PROPERTY_STORE_END_OF_ENUMERATION => 0x0004363C as u32,
            ITF::FTE_S_READONLY_CATALOG => 0x00043646 as u32,
            ITF::FTE_S_TRY_TO_FLUSH => 0x00043657 as u32,
            ITF::FTE_S_CATALOG_BLOB_MISMATCHED => 0x00043658 as u32,
            ITF::FTE_S_PROPERTY_RESET => 0x00043659 as u32,
            ITF::VDS_S_ACCESS_PATH_NOT_DELETED => 0x00044244 as u32,
            ITF::SP_END_OF_STREAM => 0x00045005 as u32,
            ITF::SP_INSUFFICIENTDATA => 0x0004500B as u32,
            ITF::SP_AUDIO_PAUSED => 0x00045010 as u32,
            ITF::SP_AUDIO_CONVERSION_ENABLED => 0x00045015 as u32,
            ITF::SP_NO_HYPOTHESIS_AVAILABLE => 0x00045016 as u32,
            ITF::SP_ALREADY_IN_LEX => 0x00045018 as u32,
            ITF::SP_LEX_NOTHING_TO_SYNC => 0x0004501A as u32,
            ITF::SP_REQUEST_PENDING => 0x00045026 as u32,
            ITF::SP_NO_PARSE_FOUND => 0x0004502C as u32,
            ITF::SP_UNSUPPORTED_ON_STREAM_INPUT => 0x00045034 as u32,
            ITF::SP_WORD_EXISTS_WITHOUT_PRONUNCIATION => 0x00045037 as u32,
            ITF::SP_RECOGNIZER_INACTIVE => 0x0004504E as u32,
            ITF::SP_PARTIAL_PARSE_FOUND => 0x00045053 as u32,
            ITF::SP_NO_RULE_ACTIVE => 0x00045055 as u32,
            ITF::SP_STREAM_UNINITIALIZED => 0x00045057 as u32,
            ITF::SP_AUDIO_STOPPED => 0x00045065 as u32,
            ITF::SP_COMPLETE_BUT_EXTENDABLE => 0x00045074 as u32,
            ITF::SP_NO_RULES_TO_ACTIVATE => 0x0004507B as u32,
            ITF::SP_NO_WORDENTRY_NOTIFICATION => 0x0004507C as u32,
            ITF::S_LIMIT_REACHED => 0x0004507F as u32,
            ITF::S_NOTSUPPORTED => 0x00045080 as u32,
            ITF::FSRM_S_PARTIAL_BATCH => 0x00045304 as u32,
            ITF::FSRM_S_PARTIAL_CLASSIFICATION => 0x00045305 as u32,
            ITF::FSRM_S_CLASSIFICATION_SCAN_FAILURES => 0x00045306 as u32,
            ITF::FSRM_E_AUTO_QUOTA => 0x0004531B as u32,
            ITF::NETCFG_S_REBOOT => 0x0004A020 as u32,
            ITF::NETCFG_S_DISABLE_QUERY => 0x0004A022 as u32,
            ITF::NETCFG_S_STILL_REFERENCED => 0x0004A023 as u32,
            ITF::NETCFG_S_CAUSED_SETUP_CHANGE => 0x0004A024 as u32,
            ITF::NETCFG_S_COMMIT_NOW => 0x0004A025 as u32,
            ITF::XACT_S_ASYNC => 0x0004D000 as u32,
            ITF::XACT_S_DEFECT => 0x0004D001 as u32,
            ITF::XACT_S_READONLY => 0x0004D002 as u32,
            ITF::XACT_S_SOMENORETAIN => 0x0004D003 as u32,
            ITF::XACT_S_OKINFORM => 0x0004D004 as u32,
            ITF::XACT_S_MADECHANGESCONTENT => 0x0004D005 as u32,
            ITF::XACT_S_MADECHANGESINFORM => 0x0004D006 as u32,
            ITF::XACT_S_ALLNORETAIN => 0x0004D007 as u32,
            ITF::XACT_S_ABORTING => 0x0004D008 as u32,
            ITF::XACT_S_SINGLEPHASE => 0x0004D009 as u32,
            ITF::XACT_S_LOCALLY_OK => 0x0004D00A as u32,
            ITF::XACT_S_LASTRESOURCEMANAGER => 0x0004D010 as u32,
            ITF::S_DEVCAP_OUTPUT_FULL_REPLACEMENT => 0x0004DC01 as u32,
            ITF::IO_FILE_QUOTA_THRESHOLD => 0x40040024 as u32,
            ITF::IO_FILE_QUOTA_LIMIT => 0x40040025 as u32,
            ITF::IO_FILE_QUOTA_STARTED => 0x40040026 as u32,
            ITF::IO_FILE_QUOTA_SUCCEEDED => 0x40040027 as u32,
            ITF::IO_INFO_THROTTLE_COMPLETE => 0x40040077 as u32,
            ITF::IO_CDROM_EXCLUSIVE_LOCK => 0x40040085 as u32,
            ITF::MSG_TEST_MESSAGE => 0x40041000 as u32,
            ITF::SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK => 0x4004D30F as u32,
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL => 0x4004D601 as u32,
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED => 0x4004D602 as u32,
            ITF::SL_I_OOB_GRACE_PERIOD => 0x4004F00C as u32,
            ITF::SL_I_OOT_GRACE_PERIOD => 0x4004F00D as u32,
            ITF::SL_E_VL_INFO_PRODUCT_USER_RIGHT => 0x4004F040 as u32,
            ITF::SL_I_NONGENUINE_GRACE_PERIOD => 0x4004F065 as u32,
            ITF::SL_I_NONGENUINE_GRACE_PERIOD_2 => 0x4004F068 as u32,
            ITF::SL_I_TIMEBASED_VALIDITY_PERIOD => 0x4004FC04 as u32,
            ITF::SL_I_PERPETUAL_OOB_GRACE_PERIOD => 0x4004FC05 as u32,
            ITF::SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD => 0x4004FC06 as u32,
            ITF::OLE_E_OLEVERB => 0x80040000 as u32,
            ITF::OLE_E_ADVF => 0x80040001 as u32,
            ITF::E_NOTVALIDFORANIMATEDIMAGE => 0x80040001 as u32,
            ITF::OLE_E_ENUM_NOMORE => 0x80040002 as u32,
            ITF::OLE_E_ADVISENOTSUPPORTED => 0x80040003 as u32,
            ITF::TAPI_E_NOTSUPPORTED => 0x80040003 as u32,
            ITF::OLE_E_NOCONNECTION => 0x80040004 as u32,
            ITF::TAPI_E_INVALIDMEDIATYPE => 0x80040004 as u32,
            ITF::OLE_E_NOTRUNNING => 0x80040005 as u32,
            ITF::TAPI_E_OPERATIONFAILED => 0x80040005 as u32,
            ITF::OLE_E_NOCACHE => 0x80040006 as u32,
            ITF::TAPI_E_ALLOCATED => 0x80040006 as u32,
            ITF::OLE_E_BLANK => 0x80040007 as u32,
            ITF::TAPI_E_CALLUNAVAIL => 0x80040007 as u32,
            ITF::OLE_E_CLASSDIFF => 0x80040008 as u32,
            ITF::TAPI_E_COMPLETIONOVERRUN => 0x80040008 as u32,
            ITF::OLE_E_CANT_GETMONIKER => 0x80040009 as u32,
            ITF::TAPI_E_CONFERENCEFULL => 0x80040009 as u32,
            ITF::OLE_E_CANT_BINDTOSOURCE => 0x8004000A as u32,
            ITF::TAPI_E_DIALMODIFIERNOTSUPPORTED => 0x8004000A as u32,
            ITF::OLE_E_STATIC => 0x8004000B as u32,
            ITF::TAPI_E_INUSE => 0x8004000B as u32,
            ITF::OLE_E_PROMPTSAVECANCELLED => 0x8004000C as u32,
            ITF::TAPI_E_INVALADDRESS => 0x8004000C as u32,
            ITF::OLE_E_INVALIDRECT => 0x8004000D as u32,
            ITF::TAPI_E_INVALADDRESSSTATE => 0x8004000D as u32,
            ITF::OLE_E_WRONGCOMPOBJ => 0x8004000E as u32,
            ITF::TAPI_E_INVALCALLPARAMS => 0x8004000E as u32,
            ITF::OLE_E_INVALIDHWND => 0x8004000F as u32,
            ITF::TAPI_E_INVALCALLPRIVILEGE => 0x8004000F as u32,
            ITF::OLE_E_NOT_INPLACEACTIVE => 0x80040010 as u32,
            ITF::TAPI_E_INVALCALLSTATE => 0x80040010 as u32,
            ITF::OLE_E_CANTCONVERT => 0x80040011 as u32,
            ITF::TAPI_E_INVALCARD => 0x80040011 as u32,
            ITF::OLE_E_NOSTORAGE => 0x80040012 as u32,
            ITF::TAPI_E_INVALCOMPLETIONID => 0x80040012 as u32,
            ITF::TAPI_E_INVALCOUNTRYCODE => 0x80040013 as u32,
            ITF::TAPI_E_INVALDEVICECLASS => 0x80040014 as u32,
            ITF::TAPI_E_INVALDIALPARAMS => 0x80040015 as u32,
            ITF::TAPI_E_INVALDIGITS => 0x80040016 as u32,
            ITF::TAPI_E_INVALGROUPID => 0x80040017 as u32,
            ITF::TAPI_E_INVALLOCATION => 0x80040018 as u32,
            ITF::TAPI_E_INVALMESSAGEID => 0x80040019 as u32,
            ITF::TAPI_E_INVALPARKID => 0x8004001A as u32,
            ITF::IO_WRN_BAD_FIRMWARE => 0x8004001A as u32,
            ITF::TAPI_E_INVALRATE => 0x8004001B as u32,
            ITF::TAPI_E_INVALTIMEOUT => 0x8004001C as u32,
            ITF::TAPI_E_INVALTONE => 0x8004001D as u32,
            ITF::TAPI_E_INVALLIST => 0x8004001E as u32,
            ITF::TAPI_E_INVALMODE => 0x8004001F as u32,
            ITF::TAPI_E_NOCONFERENCE => 0x80040020 as u32,
            ITF::IO_WRITE_CACHE_ENABLED => 0x80040020 as u32,
            ITF::TAPI_E_NODEVICE => 0x80040021 as u32,
            ITF::IO_RECOVERED_VIA_ECC => 0x80040021 as u32,
            ITF::TAPI_E_NOREQUEST => 0x80040022 as u32,
            ITF::IO_WRITE_CACHE_DISABLED => 0x80040022 as u32,
            ITF::TAPI_E_NOTOWNER => 0x80040023 as u32,
            ITF::TAPI_E_NOTREGISTERED => 0x80040024 as u32,
            ITF::TAPI_E_REQUESTOVERRUN => 0x80040025 as u32,
            ITF::TAPI_E_TARGETNOTFOUND => 0x80040026 as u32,
            ITF::TAPI_E_TARGETSELF => 0x80040027 as u32,
            ITF::TAPI_E_USERUSERINFOTOOBIG => 0x80040028 as u32,
            ITF::IO_FILE_QUOTA_FAILED => 0x80040028 as u32,
            ITF::TAPI_E_REINIT => 0x80040029 as u32,
            ITF::TAPI_E_ADDRESSBLOCKED => 0x8004002A as u32,
            ITF::TAPI_E_BILLINGREJECTED => 0x8004002B as u32,
            ITF::TAPI_E_INVALFEATURE => 0x8004002C as u32,
            ITF::TAPI_E_INVALBUTTONLAMPID => 0x8004002D as u32,
            ITF::TAPI_E_INVALBUTTONSTATE => 0x8004002E as u32,
            ITF::TAPI_E_INVALDATAID => 0x8004002F as u32,
            ITF::TAPI_E_INVALHOOKSWITCHDEV => 0x80040030 as u32,
            ITF::TAPI_E_DROPPED => 0x80040031 as u32,
            ITF::TAPI_E_NOREQUESTRECIPIENT => 0x80040032 as u32,
            ITF::IO_LOST_DELAYED_WRITE => 0x80040032 as u32,
            ITF::TAPI_E_REQUESTQUEUEFULL => 0x80040033 as u32,
            ITF::IO_WARNING_PAGING_FAILURE => 0x80040033 as u32,
            ITF::TAPI_E_DESTBUSY => 0x80040034 as u32,
            ITF::IO_WRN_FAILURE_PREDICTED => 0x80040034 as u32,
            ITF::TAPI_E_DESTNOANSWER => 0x80040035 as u32,
            ITF::IO_WARNING_INTERRUPT_STILL_PENDING => 0x80040035 as u32,
            ITF::TAPI_E_DESTUNAVAIL => 0x80040036 as u32,
            ITF::IO_DRIVER_CANCEL_TIMEOUT => 0x80040036 as u32,
            ITF::TAPI_E_REQUESTFAILED => 0x80040037 as u32,
            ITF::TAPI_E_REQUESTCANCELLED => 0x80040038 as u32,
            ITF::IO_WARNING_ALLOCATION_FAILED => 0x80040038 as u32,
            ITF::TAPI_E_INVALPRIVILEGE => 0x80040039 as u32,
            ITF::IO_WARNING_LOG_FLUSH_FAILED => 0x80040039 as u32,
            ITF::TAPI_E_INVALIDDIRECTION => 0x8004003A as u32,
            ITF::IO_WARNING_DUPLICATE_SIGNATURE => 0x8004003A as u32,
            ITF::TAPI_E_INVALIDTERMINAL => 0x8004003B as u32,
            ITF::IO_WARNING_DUPLICATE_PATH => 0x8004003B as u32,
            ITF::TAPI_E_INVALIDTERMINALCLASS => 0x8004003C as u32,
            ITF::TAPI_E_NODRIVER => 0x8004003D as u32,
            ITF::TAPI_E_MAXSTREAMS => 0x8004003E as u32,
            ITF::TAPI_E_NOTERMINALSELECTED => 0x8004003F as u32,
            ITF::TAPI_E_TERMINALINUSE => 0x80040040 as u32,
            ITF::TAPI_E_NOTSTOPPED => 0x80040041 as u32,
            ITF::TAPI_E_MAXTERMINALS => 0x80040042 as u32,
            ITF::TAPI_E_INVALIDSTREAM => 0x80040043 as u32,
            ITF::TAPI_E_TIMEOUT => 0x80040044 as u32,
            ITF::TAPI_E_CALLCENTER_GROUP_REMOVED => 0x80040045 as u32,
            ITF::TAPI_E_CALLCENTER_QUEUE_REMOVED => 0x80040046 as u32,
            ITF::TAPI_E_CALLCENTER_NO_AGENT_ID => 0x80040047 as u32,
            ITF::TAPI_E_CALLCENTER_INVALAGENTID => 0x80040048 as u32,
            ITF::TAPI_E_CALLCENTER_INVALAGENTGROUP => 0x80040049 as u32,
            ITF::TAPI_E_CALLCENTER_INVALPASSWORD => 0x8004004A as u32,
            ITF::TAPI_E_CALLCENTER_INVALAGENTSTATE => 0x8004004B as u32,
            ITF::TAPI_E_CALLCENTER_INVALAGENTACTIVITY => 0x8004004C as u32,
            ITF::TAPI_E_REGISTRY_SETTING_CORRUPT => 0x8004004D as u32,
            ITF::TAPI_E_TERMINAL_PEER => 0x8004004E as u32,
            ITF::TAPI_E_PEER_NOT_SET => 0x8004004F as u32,
            ITF::TAPI_E_NOEVENT => 0x80040050 as u32,
            ITF::TAPI_E_INVALADDRESSTYPE => 0x80040051 as u32,
            ITF::TAPI_E_RESOURCEUNAVAIL => 0x80040052 as u32,
            ITF::TAPI_E_PHONENOTOPEN => 0x80040053 as u32,
            ITF::TAPI_E_CALLNOTSELECTED => 0x80040054 as u32,
            ITF::TAPI_E_WRONGEVENT => 0x80040055 as u32,
            ITF::TAPI_E_NOFORMAT => 0x80040056 as u32,
            ITF::TAPI_E_INVALIDSTREAMSTATE => 0x80040057 as u32,
            ITF::TAPI_E_WRONG_STATE => 0x80040058 as u32,
            ITF::TAPI_E_NOT_INITIALIZED => 0x80040059 as u32,
            ITF::TAPI_E_SERVICE_NOT_RUNNING => 0x8004005A as u32,
            ITF::DV_E_FORMATETC => 0x80040064 as u32,
            ITF::DV_E_DVTARGETDEVICE => 0x80040065 as u32,
            ITF::DV_E_STGMEDIUM => 0x80040066 as u32,
            ITF::DV_E_STATDATA => 0x80040067 as u32,
            ITF::DV_E_LINDEX => 0x80040068 as u32,
            ITF::DV_E_TYMED => 0x80040069 as u32,
            ITF::DV_E_CLIPFORMAT => 0x8004006A as u32,
            ITF::DV_E_DVASPECT => 0x8004006B as u32,
            ITF::DV_E_DVTARGETDEVICE_SIZE => 0x8004006C as u32,
            ITF::DV_E_NOIVIEWOBJECT => 0x8004006D as u32,
            ITF::IO_WARNING_BUS_RESET => 0x80040076 as u32,
            ITF::IO_WARNING_RESET => 0x80040081 as u32,
            ITF::IO_WARNING_WRITE_FUA_PROBLEM => 0x80040084 as u32,
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED => 0x8004008B as u32,
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR => 0x8004008C as u32,
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR => 0x8004008D as u32,
            ITF::IO_WARNING_VOLUME_LOST_DISK_EXTENT => 0x8004008E as u32,
            ITF::IO_WARNING_DEVICE_HAS_INTERNAL_DUMP => 0x8004008F as u32,
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED => 0x80040090 as u32,
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX => 0x80040091 as u32,
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN => 0x80040092 as u32,
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL => 0x80040093 as u32,
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN => 0x80040094 as u32,
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL => 0x80040095 as u32,
            ITF::IO_WARNING_DISK_CAPACITY_CHANGED => 0x80040097 as u32,
            ITF::IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED => 0x80040098 as u32,
            ITF::IO_WARNING_IO_OPERATION_RETRIED => 0x80040099 as u32,
            ITF::IO_WARNING_COMPLETION_TIME => 0x8004009B as u32,
            ITF::IO_WARNING_DUMP_DISABLED_DEVICE_GONE => 0x8004009C as u32,
            ITF::IO_WARNING_DISK_SURPRISE_REMOVED => 0x8004009D as u32,
            ITF::IO_WARNING_REPEATED_DISK_GUID => 0x8004009E as u32,
            ITF::OLE_E_LAST => 0x800400FF as u32,
            ITF::DRAGDROP_E_NOTREGISTERED => 0x80040100 as u32,
            ITF::DRAGDROP_E_ALREADYREGISTERED => 0x80040101 as u32,
            ITF::DRAGDROP_E_INVALIDHWND => 0x80040102 as u32,
            ITF::_MAPI_E_NO_SUPPORT => 0x80040102 as u32,
            ITF::DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED => 0x80040103 as u32,
            ITF::_MAPI_E_BAD_CHARWIDTH => 0x80040103 as u32,
            ITF::_MAPI_E_STRING_TOO_LONG => 0x80040105 as u32,
            ITF::_MAPI_E_UNKNOWN_FLAGS => 0x80040106 as u32,
            ITF::_MAPI_E_INVALID_ENTRYID => 0x80040107 as u32,
            ITF::_MAPI_E_INVALID_OBJECT => 0x80040108 as u32,
            ITF::_MAPI_E_OBJECT_CHANGED => 0x80040109 as u32,
            ITF::_MAPI_E_OBJECT_DELETED => 0x8004010A as u32,
            ITF::_MAPI_E_BUSY => 0x8004010B as u32,
            ITF::_MAPI_E_NOT_ENOUGH_DISK => 0x8004010D as u32,
            ITF::_MAPI_E_NOT_ENOUGH_RESOURCES => 0x8004010E as u32,
            ITF::_MAPI_E_NOT_FOUND => 0x8004010F as u32,
            ITF::CLASS_E_NOAGGREGATION => 0x80040110 as u32,
            ITF::_MAPI_E_VERSION => 0x80040110 as u32,
            ITF::CLASS_E_CLASSNOTAVAILABLE => 0x80040111 as u32,
            ITF::_MAPI_E_LOGON_FAILED => 0x80040111 as u32,
            ITF::CLASS_E_NOTLICENSED => 0x80040112 as u32,
            ITF::_MAPI_E_SESSION_LIMIT => 0x80040112 as u32,
            ITF::_MAPI_E_USER_CANCEL => 0x80040113 as u32,
            ITF::_MAPI_E_UNABLE_TO_ABORT => 0x80040114 as u32,
            ITF::_MAPI_E_NETWORK_ERROR => 0x80040115 as u32,
            ITF::_MAPI_E_DISK_ERROR => 0x80040116 as u32,
            ITF::_MAPI_E_TOO_COMPLEX => 0x80040117 as u32,
            ITF::_MAPI_E_BAD_COLUMN => 0x80040118 as u32,
            ITF::_MAPI_E_EXTENDED_ERROR => 0x80040119 as u32,
            ITF::_MAPI_E_COMPUTED => 0x8004011A as u32,
            ITF::_MAPI_E_CORRUPT_DATA => 0x8004011B as u32,
            ITF::_MAPI_E_UNCONFIGURED => 0x8004011C as u32,
            ITF::_MAPI_E_FAILONEPROVIDER => 0x8004011D as u32,
            ITF::_MAPI_E_UNKNOWN_CPID => 0x8004011E as u32,
            ITF::_MAPI_E_UNKNOWN_LCID => 0x8004011F as u32,
            ITF::_MAPI_E_PASSWORD_CHANGE_REQUIRED => 0x80040120 as u32,
            ITF::_MAPI_E_PASSWORD_EXPIRED => 0x80040121 as u32,
            ITF::_MAPI_E_INVALID_WORKSTATION_ACCOUNT => 0x80040122 as u32,
            ITF::_MAPI_E_INVALID_ACCESS_TIME => 0x80040123 as u32,
            ITF::_MAPI_E_ACCOUNT_DISABLED => 0x80040124 as u32,
            ITF::VIEW_E_DRAW => 0x80040140 as u32,
            ITF::REGDB_E_READREGDB => 0x80040150 as u32,
            ITF::REGDB_E_WRITEREGDB => 0x80040151 as u32,
            ITF::REGDB_E_KEYMISSING => 0x80040152 as u32,
            ITF::REGDB_E_INVALIDVALUE => 0x80040153 as u32,
            ITF::REGDB_E_CLASSNOTREG => 0x80040154 as u32,
            ITF::E_CLASSNOTREG => 0x80040154 as u32,
            ITF::REGDB_E_IIDNOTREG => 0x80040155 as u32,
            ITF::REGDB_E_BADTHREADINGMODEL => 0x80040156 as u32,
            ITF::REGDB_E_PACKAGEPOLICYVIOLATION => 0x80040157 as u32,
            ITF::CAT_E_CATIDNOEXIST => 0x80040160 as u32,
            ITF::CAT_E_NODESCRIPTION => 0x80040161 as u32,
            ITF::CS_E_PACKAGE_NOTFOUND => 0x80040164 as u32,
            ITF::CS_E_NOT_DELETABLE => 0x80040165 as u32,
            ITF::CS_E_CLASS_NOTFOUND => 0x80040166 as u32,
            ITF::CS_E_INVALID_VERSION => 0x80040167 as u32,
            ITF::CS_E_NO_CLASSSTORE => 0x80040168 as u32,
            ITF::CS_E_OBJECT_NOTFOUND => 0x80040169 as u32,
            ITF::CS_E_OBJECT_ALREADY_EXISTS => 0x8004016A as u32,
            ITF::CS_E_INVALID_PATH => 0x8004016B as u32,
            ITF::CS_E_NETWORK_ERROR => 0x8004016C as u32,
            ITF::CS_E_ADMIN_LIMIT_EXCEEDED => 0x8004016D as u32,
            ITF::CS_E_SCHEMA_MISMATCH => 0x8004016E as u32,
            ITF::CS_E_INTERNAL_ERROR => 0x8004016F as u32,
            ITF::CACHE_E_NOCACHE_UPDATED => 0x80040170 as u32,
            ITF::OLEOBJ_E_NOVERBS => 0x80040180 as u32,
            ITF::OLEOBJ_E_INVALIDVERB => 0x80040181 as u32,
            ITF::INPLACE_E_NOTUNDOABLE => 0x800401A0 as u32,
            ITF::INPLACE_E_NOTOOLSPACE => 0x800401A1 as u32,
            ITF::CONVERT10_E_OLESTREAM_GET => 0x800401C0 as u32,
            ITF::CONVERT10_E_OLESTREAM_PUT => 0x800401C1 as u32,
            ITF::CONVERT10_E_OLESTREAM_FMT => 0x800401C2 as u32,
            ITF::CONVERT10_E_OLESTREAM_BITMAP_TO_DIB => 0x800401C3 as u32,
            ITF::CONVERT10_E_STG_FMT => 0x800401C4 as u32,
            ITF::CONVERT10_E_STG_NO_STD_STREAM => 0x800401C5 as u32,
            ITF::CONVERT10_E_STG_DIB_TO_BITMAP => 0x800401C6 as u32,
            ITF::CLIPBRD_E_CANT_OPEN => 0x800401D0 as u32,
            ITF::CLIPBRD_E_CANT_EMPTY => 0x800401D1 as u32,
            ITF::CLIPBRD_E_CANT_SET => 0x800401D2 as u32,
            ITF::CLIPBRD_E_BAD_DATA => 0x800401D3 as u32,
            ITF::CLIPBRD_E_CANT_CLOSE => 0x800401D4 as u32,
            ITF::MK_E_CONNECTMANUALLY => 0x800401E0 as u32,
            ITF::MK_E_EXCEEDEDDEADLINE => 0x800401E1 as u32,
            ITF::MK_E_NEEDGENERIC => 0x800401E2 as u32,
            ITF::MK_E_UNAVAILABLE => 0x800401E3 as u32,
            ITF::MK_E_SYNTAX => 0x800401E4 as u32,
            ITF::MK_E_NOOBJECT => 0x800401E5 as u32,
            ITF::MK_E_INVALIDEXTENSION => 0x800401E6 as u32,
            ITF::MK_E_INTERMEDIATEINTERFACENOTSUPPORTED => 0x800401E7 as u32,
            ITF::MK_E_NOTBINDABLE => 0x800401E8 as u32,
            ITF::MK_E_NOTBOUND => 0x800401E9 as u32,
            ITF::MK_E_CANTOPENFILE => 0x800401EA as u32,
            ITF::MK_E_MUSTBOTHERUSER => 0x800401EB as u32,
            ITF::MK_E_NOINVERSE => 0x800401EC as u32,
            ITF::MK_E_NOSTORAGE => 0x800401ED as u32,
            ITF::MK_E_NOPREFIX => 0x800401EE as u32,
            ITF::MK_E_ENUMERATION_FAILED => 0x800401EF as u32,
            ITF::CO_E_NOTINITIALIZED => 0x800401F0 as u32,
            ITF::DDERR_NOTINITIALIZED => 0x800401F0 as u32,
            ITF::CO_E_ALREADYINITIALIZED => 0x800401F1 as u32,
            ITF::CO_E_CANTDETERMINECLASS => 0x800401F2 as u32,
            ITF::CO_E_CLASSSTRING => 0x800401F3 as u32,
            ITF::CO_E_IIDSTRING => 0x800401F4 as u32,
            ITF::CO_E_APPNOTFOUND => 0x800401F5 as u32,
            ITF::CO_E_APPSINGLEUSE => 0x800401F6 as u32,
            ITF::CO_E_ERRORINAPP => 0x800401F7 as u32,
            ITF::CO_E_DLLNOTFOUND => 0x800401F8 as u32,
            ITF::CO_E_ERRORINDLL => 0x800401F9 as u32,
            ITF::CO_E_WRONGOSFORAPP => 0x800401FA as u32,
            ITF::CO_E_OBJNOTREG => 0x800401FB as u32,
            ITF::CO_E_OBJISREG => 0x800401FC as u32,
            ITF::CO_E_OBJNOTCONNECTED => 0x800401FD as u32,
            ITF::CO_E_APPDIDNTREG => 0x800401FE as u32,
            ITF::CO_E_RELEASED => 0x800401FF as u32,
            ITF::VFW_E_INVALIDMEDIATYPE => 0x80040200 as u32,
            ITF::_MAPI_E_END_OF_SESSION => 0x80040200 as u32,
            ITF::MPEG2_E_UNINITIALIZED => 0x80040200 as u32,
            ITF::TF_E_INVALIDPOS => 0x80040200 as u32,
            ITF::TS_E_INVALIDPOS => 0x80040200 as u32,
            ITF::UPNP_E_ROOT_ELEMENT_EXPECTED => 0x80040200 as u32,
            ITF::USP_E_SCRIPT_NOT_IN_FONT => 0x80040200 as u32,
            ITF::EVENT_E_ALL_SUBSCRIBERS_FAILED => 0x80040201 as u32,
            ITF::VFW_E_INVALIDSUBTYPE => 0x80040201 as u32,
            ITF::CDO_E_UNCAUGHT_EXCEPTION => 0x80040201 as u32,
            ITF::_MAPI_E_UNKNOWN_ENTRYID => 0x80040201 as u32,
            ITF::MPEG2_E_ALREADY_INITIALIZED => 0x80040201 as u32,
            ITF::TF_E_NOLOCK => 0x80040201 as u32,
            ITF::TS_E_NOLOCK => 0x80040201 as u32,
            ITF::UPNP_E_DEVICE_ELEMENT_EXPECTED => 0x80040201 as u32,
            ITF::VFW_E_NEED_OWNER => 0x80040202 as u32,
            ITF::CDO_E_NOT_OPENED => 0x80040202 as u32,
            ITF::_MAPI_E_MISSING_REQUIRED_COLUMN => 0x80040202 as u32,
            ITF::MPEG2_E_OUT_OF_BOUNDS => 0x80040202 as u32,
            ITF::TF_E_NOOBJECT => 0x80040202 as u32,
            ITF::TS_E_NOOBJECT => 0x80040202 as u32,
            ITF::UPNP_E_SERVICE_ELEMENT_EXPECTED => 0x80040202 as u32,
            ITF::EVENT_E_QUERYSYNTAX => 0x80040203 as u32,
            ITF::VFW_E_ENUM_OUT_OF_SYNC => 0x80040203 as u32,
            ITF::CDO_E_UNSUPPORTED_DATASOURCE => 0x80040203 as u32,
            ITF::MPEG2_E_MALFORMED_TABLE => 0x80040203 as u32,
            ITF::TF_E_NOSERVICE => 0x80040203 as u32,
            ITF::TS_E_NOSERVICE => 0x80040203 as u32,
            ITF::UPNP_E_SERVICE_NODE_INCOMPLETE => 0x80040203 as u32,
            ITF::EVENT_E_QUERYFIELD => 0x80040204 as u32,
            ITF::VFW_E_ALREADY_CONNECTED => 0x80040204 as u32,
            ITF::CDO_E_INVALID_PROPERTYNAME => 0x80040204 as u32,
            ITF::MPEG2_E_UNDEFINED => 0x80040204 as u32,
            ITF::TF_E_NOINTERFACE => 0x80040204 as u32,
            ITF::TS_E_NOINTERFACE => 0x80040204 as u32,
            ITF::UPNP_E_DEVICE_NODE_INCOMPLETE => 0x80040204 as u32,
            ITF::EVENT_E_INTERNALEXCEPTION => 0x80040205 as u32,
            ITF::VFW_E_FILTER_ACTIVE => 0x80040205 as u32,
            ITF::CDO_E_PROP_UNSUPPORTED => 0x80040205 as u32,
            ITF::MPEG2_E_NOT_PRESENT => 0x80040205 as u32,
            ITF::TF_E_NOSELECTION => 0x80040205 as u32,
            ITF::TS_E_NOSELECTION => 0x80040205 as u32,
            ITF::UPNP_E_ICON_ELEMENT_EXPECTED => 0x80040205 as u32,
            ITF::EVENT_E_INTERNALERROR => 0x80040206 as u32,
            ITF::VFW_E_NO_TYPES => 0x80040206 as u32,
            ITF::CDO_E_INACTIVE => 0x80040206 as u32,
            ITF::MPEG2_E_SECTION_NOT_FOUND => 0x80040206 as u32,
            ITF::TF_E_NOLAYOUT => 0x80040206 as u32,
            ITF::TS_E_NOLAYOUT => 0x80040206 as u32,
            ITF::UPNP_E_ICON_NODE_INCOMPLETE => 0x80040206 as u32,
            ITF::EVENT_E_INVALID_PER_USER_SID => 0x80040207 as u32,
            ITF::VFW_E_NO_ACCEPTABLE_TYPES => 0x80040207 as u32,
            ITF::CDO_E_NO_SUPPORT_FOR_OBJECTS => 0x80040207 as u32,
            ITF::MPEG2_E_TX_STREAM_UNAVAILABLE => 0x80040207 as u32,
            ITF::TF_E_INVALIDPOINT => 0x80040207 as u32,
            ITF::TS_E_INVALIDPOINT => 0x80040207 as u32,
            ITF::UPNP_E_INVALID_ACTION => 0x80040207 as u32,
            ITF::EVENT_E_USER_EXCEPTION => 0x80040208 as u32,
            ITF::VFW_E_INVALID_DIRECTION => 0x80040208 as u32,
            ITF::CDO_E_NOT_AVAILABLE => 0x80040208 as u32,
            ITF::MPEG2_E_SERVICE_ID_NOT_FOUND => 0x80040208 as u32,
            ITF::TF_E_SYNCHRONOUS => 0x80040208 as u32,
            ITF::TS_E_SYNCHRONOUS => 0x80040208 as u32,
            ITF::UPNP_E_INVALID_ARGUMENTS => 0x80040208 as u32,
            ITF::EVENT_E_TOO_MANY_METHODS => 0x80040209 as u32,
            ITF::VFW_E_NOT_CONNECTED => 0x80040209 as u32,
            ITF::CDO_E_NO_DEFAULT_DROP_DIR => 0x80040209 as u32,
            ITF::MPEG2_E_SERVICE_PMT_NOT_FOUND => 0x80040209 as u32,
            ITF::TF_E_READONLY => 0x80040209 as u32,
            ITF::TS_E_READONLY => 0x80040209 as u32,
            ITF::UPNP_E_OUT_OF_SYNC => 0x80040209 as u32,
            ITF::EVENT_E_MISSING_EVENTCLASS => 0x8004020A as u32,
            ITF::VFW_E_NO_ALLOCATOR => 0x8004020A as u32,
            ITF::CDO_E_SMTP_SERVER_REQUIRED => 0x8004020A as u32,
            ITF::MPEG2_E_DSI_NOT_FOUND => 0x8004020A as u32,
            ITF::TF_E_FORMAT => 0x8004020A as u32,
            ITF::TS_E_FORMAT => 0x8004020A as u32,
            ITF::EVENT_E_NOT_ALL_REMOVED => 0x8004020B as u32,
            ITF::VFW_E_RUNTIME_ERROR => 0x8004020B as u32,
            ITF::CDO_E_NNTP_SERVER_REQUIRED => 0x8004020B as u32,
            ITF::IMAPI_E_NOTOPENED => 0x8004020B as u32,
            ITF::MPEG2_E_SERVER_UNAVAILABLE => 0x8004020B as u32,
            ITF::EVENT_E_COMPLUS_NOT_INSTALLED => 0x8004020C as u32,
            ITF::VFW_E_BUFFER_NOTSET => 0x8004020C as u32,
            ITF::CDO_E_RECIPIENT_MISSING => 0x8004020C as u32,
            ITF::IMAPI_E_NOTINITIALIZED => 0x8004020C as u32,
            ITF::MPEG2_E_INVALID_CAROUSEL_ID => 0x8004020C as u32,
            ITF::EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT => 0x8004020D as u32,
            ITF::VFW_E_BUFFER_OVERFLOW => 0x8004020D as u32,
            ITF::CDO_E_FROM_MISSING => 0x8004020D as u32,
            ITF::IMAPI_E_USERABORT => 0x8004020D as u32,
            ITF::MPEG2_E_MALFORMED_DSMCC_MESSAGE => 0x8004020D as u32,
            ITF::EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT => 0x8004020E as u32,
            ITF::VFW_E_BADALIGN => 0x8004020E as u32,
            ITF::CDO_E_SENDER_REJECTED => 0x8004020E as u32,
            ITF::IMAPI_E_GENERIC => 0x8004020E as u32,
            ITF::MPEG2_E_INVALID_SG_OBJECT_KIND => 0x8004020E as u32,
            ITF::EVENT_E_INVALID_EVENT_CLASS_PARTITION => 0x8004020F as u32,
            ITF::VFW_E_ALREADY_COMMITTED => 0x8004020F as u32,
            ITF::CDO_E_RECIPIENTS_REJECTED => 0x8004020F as u32,
            ITF::IMAPI_E_MEDIUM_NOTPRESENT => 0x8004020F as u32,
            ITF::MPEG2_E_OBJECT_NOT_FOUND => 0x8004020F as u32,
            ITF::EVENT_E_PER_USER_SID_NOT_LOGGED_ON => 0x80040210 as u32,
            ITF::VFW_E_BUFFERS_OUTSTANDING => 0x80040210 as u32,
            ITF::CDO_E_NNTP_POST_FAILED => 0x80040210 as u32,
            ITF::IMAPI_E_MEDIUM_INVALIDTYPE => 0x80040210 as u32,
            ITF::MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY => 0x80040210 as u32,
            ITF::UPNP_E_ACTION_REQUEST_FAILED => 0x80040210 as u32,
            ITF::VFW_E_NOT_COMMITTED => 0x80040211 as u32,
            ITF::CDO_E_SMTP_SEND_FAILED => 0x80040211 as u32,
            ITF::IMAPI_E_DEVICE_NOPROPERTIES => 0x80040211 as u32,
            ITF::MPEG2_E_OBJECT_KIND_NOT_A_FILE => 0x80040211 as u32,
            ITF::UPNP_E_TRANSPORT_ERROR => 0x80040211 as u32,
            ITF::TPC_E_NO_DEFAULT_TABLET => 0x80040212 as u32,
            ITF::VFW_E_SIZENOTSET => 0x80040212 as u32,
            ITF::CDO_E_CONNECTION_DROPPED => 0x80040212 as u32,
            ITF::IMAPI_E_DEVICE_NOTACCESSIBLE => 0x80040212 as u32,
            ITF::MPEG2_E_FILE_OFFSET_TOO_BIG => 0x80040212 as u32,
            ITF::UPNP_E_VARIABLE_VALUE_UNKNOWN => 0x80040212 as u32,
            ITF::VFW_E_NO_CLOCK => 0x80040213 as u32,
            ITF::CDO_E_FAILED_TO_CONNECT => 0x80040213 as u32,
            ITF::IMAPI_E_DEVICE_NOTPRESENT => 0x80040213 as u32,
            ITF::MPEG2_E_STREAM_STOPPED => 0x80040213 as u32,
            ITF::UPNP_E_INVALID_VARIABLE => 0x80040213 as u32,
            ITF::VFW_E_NO_SINK => 0x80040214 as u32,
            ITF::CDO_E_INVALID_POST => 0x80040214 as u32,
            ITF::IMAPI_E_DEVICE_INVALIDTYPE => 0x80040214 as u32,
            ITF::MPEG2_E_REGISTRY_ACCESS_FAILED => 0x80040214 as u32,
            ITF::UPNP_E_DEVICE_ERROR => 0x80040214 as u32,
            ITF::VFW_E_NO_INTERFACE => 0x80040215 as u32,
            ITF::CDO_E_AUTHENTICATION_FAILURE => 0x80040215 as u32,
            ITF::IMAPI_E_INITIALIZE_WRITE => 0x80040215 as u32,
            ITF::MPEG2_E_INVALID_UDP_PORT => 0x80040215 as u32,
            ITF::UPNP_E_PROTOCOL_ERROR => 0x80040215 as u32,
            ITF::VFW_E_NOT_FOUND => 0x80040216 as u32,
            ITF::CDO_E_INVALID_CONTENT_TYPE => 0x80040216 as u32,
            ITF::IMAPI_E_INITIALIZE_ENDWRITE => 0x80040216 as u32,
            ITF::MPEG2_E_DATA_SOURCE_FAILED => 0x80040216 as u32,
            ITF::UPNP_E_ERROR_PROCESSING_RESPONSE => 0x80040216 as u32,
            ITF::VFW_E_CANNOT_CONNECT => 0x80040217 as u32,
            ITF::CDO_E_LOGON_FAILURE => 0x80040217 as u32,
            ITF::IMAPI_E_FILESYSTEM => 0x80040217 as u32,
            ITF::MPEG2_E_DII_NOT_FOUND => 0x80040217 as u32,
            ITF::UPNP_E_DEVICE_TIMEOUT => 0x80040217 as u32,
            ITF::VFW_E_CANNOT_RENDER => 0x80040218 as u32,
            ITF::CDO_E_HTTP_NOT_FOUND => 0x80040218 as u32,
            ITF::IMAPI_E_FILEACCESS => 0x80040218 as u32,
            ITF::MPEG2_E_DSHOW_PIN_NOT_FOUND => 0x80040218 as u32,
            ITF::TPC_E_INVALID_INPUT_RECT => 0x80040219 as u32,
            ITF::VFW_E_CHANGING_FORMAT => 0x80040219 as u32,
            ITF::CDO_E_HTTP_FORBIDDEN => 0x80040219 as u32,
            ITF::IMAPI_E_DISCINFO => 0x80040219 as u32,
            ITF::MPEG2_E_BUFFER_TOO_SMALL => 0x80040219 as u32,
            ITF::VFW_E_NO_COLOR_KEY_SET => 0x8004021A as u32,
            ITF::CDO_E_HTTP_FAILED => 0x8004021A as u32,
            ITF::IMAPI_E_TRACKNOTOPEN => 0x8004021A as u32,
            ITF::MPEG2_E_MISSING_SECTIONS => 0x8004021A as u32,
            ITF::TPC_E_UNKNOWN_PROPERTY => 0x8004021B as u32,
            ITF::VFW_E_NOT_OVERLAY_CONNECTION => 0x8004021B as u32,
            ITF::CDO_E_MULTIPART_NO_DATA => 0x8004021B as u32,
            ITF::IMAPI_E_TRACKOPEN => 0x8004021B as u32,
            ITF::MPEG2_E_TOO_MANY_SECTIONS => 0x8004021B as u32,
            ITF::VFW_E_NOT_SAMPLE_CONNECTION => 0x8004021C as u32,
            ITF::CDO_E_INVALID_ENCODING_FOR_MULTIPART => 0x8004021C as u32,
            ITF::IMAPI_E_DISCFULL => 0x8004021C as u32,
            ITF::MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE => 0x8004021C as u32,
            ITF::VFW_E_PALETTE_SET => 0x8004021D as u32,
            ITF::CDO_E_UNSAFE_OPERATION => 0x8004021D as u32,
            ITF::IMAPI_E_BADJOLIETNAME => 0x8004021D as u32,
            ITF::MPEG2_E_INCORRECT_DESCRIPTOR_TAG => 0x8004021D as u32,
            ITF::VFW_E_COLOR_KEY_SET => 0x8004021E as u32,
            ITF::CDO_E_PROP_NOT_FOUND => 0x8004021E as u32,
            ITF::IMAPI_E_INVALIDIMAGE => 0x8004021E as u32,
            ITF::VFW_E_NO_COLOR_KEY_FOUND => 0x8004021F as u32,
            ITF::IMAPI_E_NOACTIVEFORMAT => 0x8004021F as u32,
            ITF::VFW_E_NO_PALETTE_AVAILABLE => 0x80040220 as u32,
            ITF::CDO_E_INVALID_SEND_OPTION => 0x80040220 as u32,
            ITF::IMAPI_E_NOACTIVERECORDER => 0x80040220 as u32,
            ITF::VFW_E_NO_DISPLAY_PALETTE => 0x80040221 as u32,
            ITF::CDO_E_INVALID_POST_OPTION => 0x80040221 as u32,
            ITF::IMAPI_E_WRONGFORMAT => 0x80040221 as u32,
            ITF::TPC_E_INVALID_STROKE => 0x80040222 as u32,
            ITF::VFW_E_TOO_MANY_COLORS => 0x80040222 as u32,
            ITF::CDO_E_NO_PICKUP_DIR => 0x80040222 as u32,
            ITF::IMAPI_E_ALREADYOPEN => 0x80040222 as u32,
            ITF::TPC_E_INITIALIZE_FAIL => 0x80040223 as u32,
            ITF::VFW_E_STATE_CHANGED => 0x80040223 as u32,
            ITF::CDO_E_NOT_ALL_DELETED => 0x80040223 as u32,
            ITF::IMAPI_E_WRONGDISC => 0x80040223 as u32,
            ITF::VFW_E_NOT_STOPPED => 0x80040224 as u32,
            ITF::CDO_E_NO_METHOD => 0x80040224 as u32,
            ITF::IMAPI_E_FILEEXISTS => 0x80040224 as u32,
            ITF::VFW_E_NOT_PAUSED => 0x80040225 as u32,
            ITF::IMAPI_E_STASHINUSE => 0x80040225 as u32,
            ITF::VFW_E_NOT_RUNNING => 0x80040226 as u32,
            ITF::IMAPI_E_DEVICE_STILL_IN_USE => 0x80040226 as u32,
            ITF::VFW_E_WRONG_STATE => 0x80040227 as u32,
            ITF::CDO_E_PROP_READONLY => 0x80040227 as u32,
            ITF::IMAPI_E_LOSS_OF_STREAMING => 0x80040227 as u32,
            ITF::VFW_E_START_TIME_AFTER_END => 0x80040228 as u32,
            ITF::CDO_E_PROP_CANNOT_DELETE => 0x80040228 as u32,
            ITF::IMAPI_E_COMPRESSEDSTASH => 0x80040228 as u32,
            ITF::VFW_E_INVALID_RECT => 0x80040229 as u32,
            ITF::CDO_E_BAD_DATA => 0x80040229 as u32,
            ITF::IMAPI_E_ENCRYPTEDSTASH => 0x80040229 as u32,
            ITF::VFW_E_TYPE_NOT_ACCEPTED => 0x8004022A as u32,
            ITF::CDO_E_PROP_NONHEADER => 0x8004022A as u32,
            ITF::IMAPI_E_NOTENOUGHDISKFORSTASH => 0x8004022A as u32,
            ITF::VFW_E_SAMPLE_REJECTED => 0x8004022B as u32,
            ITF::CDO_E_INVALID_CHARSET => 0x8004022B as u32,
            ITF::IMAPI_E_REMOVABLESTASH => 0x8004022B as u32,
            ITF::VFW_E_SAMPLE_REJECTED_EOS => 0x8004022C as u32,
            ITF::CDO_E_ADOSTREAM_NOT_BOUND => 0x8004022C as u32,
            ITF::IMAPI_E_CANNOT_WRITE_TO_MEDIA => 0x8004022C as u32,
            ITF::VFW_E_DUPLICATE_NAME => 0x8004022D as u32,
            ITF::CDO_E_CONTENTPROPXML_NOT_FOUND => 0x8004022D as u32,
            ITF::IMAPI_E_TRACK_NOT_BIG_ENOUGH => 0x8004022D as u32,
            ITF::VFW_E_TIMEOUT => 0x8004022E as u32,
            ITF::CDO_E_CONTENTPROPXML_WRONG_CHARSET => 0x8004022E as u32,
            ITF::VFW_E_INVALID_FILE_FORMAT => 0x8004022F as u32,
            ITF::CDO_E_CONTENTPROPXML_PARSE_FAILED => 0x8004022F as u32,
            ITF::VFW_E_ENUM_OUT_OF_RANGE => 0x80040230 as u32,
            ITF::CDO_E_CONTENTPROPXML_CONVERT_FAILED => 0x80040230 as u32,
            ITF::VFW_E_CIRCULAR_GRAPH => 0x80040231 as u32,
            ITF::CDO_E_NO_DIRECTORIES_SPECIFIED => 0x80040231 as u32,
            ITF::TPC_E_NOT_RELEVANT => 0x80040232 as u32,
            ITF::VFW_E_NOT_ALLOWED_TO_SAVE => 0x80040232 as u32,
            ITF::CDO_E_DIRECTORIES_UNREACHABLE => 0x80040232 as u32,
            ITF::TPC_E_INVALID_PACKET_DESCRIPTION => 0x80040233 as u32,
            ITF::VFW_E_TIME_ALREADY_PASSED => 0x80040233 as u32,
            ITF::CDO_E_BAD_SENDER => 0x80040233 as u32,
            ITF::VFW_E_ALREADY_CANCELLED => 0x80040234 as u32,
            ITF::CDO_E_SELF_BINDING => 0x80040234 as u32,
            ITF::TPC_E_RECOGNIZER_NOT_REGISTERED => 0x80040235 as u32,
            ITF::VFW_E_CORRUPT_GRAPH_FILE => 0x80040235 as u32,
            ITF::CDO_E_BAD_ATTENDEE_DATA => 0x80040235 as u32,
            ITF::TPC_E_INVALID_RIGHTS => 0x80040236 as u32,
            ITF::VFW_E_ADVISE_ALREADY_SET => 0x80040236 as u32,
            ITF::CDO_E_ROLE_NOMORE_AVAILABLE => 0x80040236 as u32,
            ITF::TPC_E_OUT_OF_ORDER_CALL => 0x80040237 as u32,
            ITF::CDO_E_BAD_TASKTYPE_ONASSIGN => 0x80040237 as u32,
            ITF::TPC_E_QUEUE_FULL => 0x80040238 as u32,
            ITF::VFW_E_NO_MODEX_AVAILABLE => 0x80040238 as u32,
            ITF::CDO_E_NOT_ASSIGNEDTO_USER => 0x80040238 as u32,
            ITF::TPC_E_INVALID_CONFIGURATION => 0x80040239 as u32,
            ITF::VFW_E_NO_ADVISE_SET => 0x80040239 as u32,
            ITF::CDO_E_OUTOFDATE => 0x80040239 as u32,
            ITF::TPC_E_INVALID_DATA_FROM_RECOGNIZER => 0x8004023A as u32,
            ITF::VFW_E_NO_FULLSCREEN => 0x8004023A as u32,
            ITF::VFW_E_IN_FULLSCREEN_MODE => 0x8004023B as u32,
            ITF::VFW_E_UNKNOWN_FILE_TYPE => 0x80040240 as u32,
            ITF::TPC_E_INVALID_PROPERTY => 0x80040241 as u32,
            ITF::VFW_E_CANNOT_LOAD_SOURCE_FILTER => 0x80040241 as u32,
            ITF::VFW_E_FILE_TOO_SHORT => 0x80040243 as u32,
            ITF::VFW_E_INVALID_FILE_VERSION => 0x80040244 as u32,
            ITF::VFW_E_INVALID_CLSID => 0x80040247 as u32,
            ITF::VFW_E_INVALID_MEDIA_TYPE => 0x80040248 as u32,
            ITF::VFW_E_SAMPLE_TIME_NOT_SET => 0x80040249 as u32,
            ITF::VFW_E_MEDIA_TIME_NOT_SET => 0x80040251 as u32,
            ITF::VFW_E_NO_TIME_FORMAT_SET => 0x80040252 as u32,
            ITF::VFW_E_MONO_AUDIO_HW => 0x80040253 as u32,
            ITF::VFW_E_NO_DECOMPRESSOR => 0x80040255 as u32,
            ITF::VFW_E_NO_AUDIO_HARDWARE => 0x80040256 as u32,
            ITF::VFW_E_RPZA => 0x80040259 as u32,
            ITF::VFW_E_PROCESSOR_NOT_SUITABLE => 0x8004025B as u32,
            ITF::VFW_E_UNSUPPORTED_AUDIO => 0x8004025C as u32,
            ITF::VFW_E_UNSUPPORTED_VIDEO => 0x8004025D as u32,
            ITF::VFW_E_MPEG_NOT_CONSTRAINED => 0x8004025E as u32,
            ITF::VFW_E_NOT_IN_GRAPH => 0x8004025F as u32,
            ITF::VFW_E_NO_TIME_FORMAT => 0x80040261 as u32,
            ITF::VFW_E_READ_ONLY => 0x80040262 as u32,
            ITF::VFW_E_BUFFER_UNDERFLOW => 0x80040264 as u32,
            ITF::VFW_E_UNSUPPORTED_STREAM => 0x80040265 as u32,
            ITF::VFW_E_NO_TRANSPORT => 0x80040266 as u32,
            ITF::VFW_E_BAD_VIDEOCD => 0x80040269 as u32,
            ITF::VFW_S_NO_STOP_TIME => 0x80040270 as u32,
            ITF::VFW_E_OUT_OF_VIDEO_MEMORY => 0x80040271 as u32,
            ITF::VFW_E_VP_NEGOTIATION_FAILED => 0x80040272 as u32,
            ITF::VFW_E_DDRAW_CAPS_NOT_SUITABLE => 0x80040273 as u32,
            ITF::VFW_E_NO_VP_HARDWARE => 0x80040274 as u32,
            ITF::VFW_E_NO_CAPTURE_HARDWARE => 0x80040275 as u32,
            ITF::VFW_E_DVD_OPERATION_INHIBITED => 0x80040276 as u32,
            ITF::VFW_E_DVD_INVALIDDOMAIN => 0x80040277 as u32,
            ITF::VFW_E_DVD_NO_BUTTON => 0x80040278 as u32,
            ITF::VFW_E_DVD_GRAPHNOTREADY => 0x80040279 as u32,
            ITF::VFW_E_DVD_RENDERFAIL => 0x8004027A as u32,
            ITF::VFW_E_DVD_DECNOTENOUGH => 0x8004027B as u32,
            ITF::VFW_E_DDRAW_VERSION_NOT_SUITABLE => 0x8004027C as u32,
            ITF::VFW_E_COPYPROT_FAILED => 0x8004027D as u32,
            ITF::VFW_E_TIME_EXPIRED => 0x8004027F as u32,
            ITF::VFW_E_DVD_WRONG_SPEED => 0x80040281 as u32,
            ITF::VFW_E_DVD_MENU_DOES_NOT_EXIST => 0x80040282 as u32,
            ITF::VFW_E_DVD_CMD_CANCELLED => 0x80040283 as u32,
            ITF::VFW_E_DVD_STATE_WRONG_VERSION => 0x80040284 as u32,
            ITF::VFW_E_DVD_STATE_CORRUPT => 0x80040285 as u32,
            ITF::VFW_E_DVD_STATE_WRONG_DISC => 0x80040286 as u32,
            ITF::VFW_E_DVD_INCOMPATIBLE_REGION => 0x80040287 as u32,
            ITF::VFW_E_DVD_NO_ATTRIBUTES => 0x80040288 as u32,
            ITF::VFW_E_DVD_NO_GOUP_PGC => 0x80040289 as u32,
            ITF::VFW_E_DVD_LOW_PARENTAL_LEVEL => 0x8004028A as u32,
            ITF::VFW_E_DVD_NOT_IN_KARAOKE_MODE => 0x8004028B as u32,
            ITF::VFW_E_FRAME_STEP_UNSUPPORTED => 0x8004028E as u32,
            ITF::VFW_E_DVD_STREAM_DISABLED => 0x8004028F as u32,
            ITF::VFW_E_DVD_TITLE_UNKNOWN => 0x80040290 as u32,
            ITF::VFW_E_DVD_INVALID_DISC => 0x80040291 as u32,
            ITF::VFW_E_DVD_NO_RESUME_INFORMATION => 0x80040292 as u32,
            ITF::VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD => 0x80040293 as u32,
            ITF::VFW_E_PIN_ALREADY_BLOCKED => 0x80040294 as u32,
            ITF::VFW_E_CERTIFICATION_FAILURE => 0x80040295 as u32,
            ITF::VFW_E_VMR_NOT_IN_MIXER_MODE => 0x80040296 as u32,
            ITF::VFW_E_VMR_NO_AP_SUPPLIED => 0x80040297 as u32,
            ITF::VFW_E_VMR_NO_DEINTERLACE_HW => 0x80040298 as u32,
            ITF::VFW_E_VMR_NO_PROCAMP_HW => 0x80040299 as u32,
            ITF::VFW_E_DVD_VMR9_INCOMPATIBLEDEC => 0x8004029A as u32,
            ITF::VFW_E_NO_COPP_HW => 0x8004029B as u32,
            ITF::VFW_E_DVD_NONBLOCKING => 0x8004029C as u32,
            ITF::VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH => 0x8004029D as u32,
            ITF::VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH => 0x8004029E as u32,
            ITF::VFW_E_DVD_RESOLUTION_ERROR => 0x8004029F as u32,
            ITF::NET_E_GENERAL => 0x80040300 as u32,
            ITF::FHCFG_E_CORRUPT_CONFIG_FILE => 0x80040300 as u32,
            ITF::UPNP_E_ACTION_SPECIFIC_BASE => 0x80040300 as u32,
            ITF::FHCFG_E_CONFIG_FILE_NOT_FOUND => 0x80040301 as u32,
            ITF::FHCFG_E_CONFIG_ALREADY_EXISTS => 0x80040302 as u32,
            ITF::NET_E_DISCONNECTED => 0x80040303 as u32,
            ITF::FHCFG_E_NO_VALID_CONFIGURATION_LOADED => 0x80040303 as u32,
            ITF::FHCFG_E_TARGET_NOT_CONNECTED => 0x80040304 as u32,
            ITF::FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED => 0x80040305 as u32,
            ITF::FHCFG_E_TARGET_VERIFICATION_FAILED => 0x80040306 as u32,
            ITF::FHCFG_E_TARGET_NOT_CONFIGURED => 0x80040307 as u32,
            ITF::NET_E_INVALIDPARAMS => 0x80040308 as u32,
            ITF::FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE => 0x80040308 as u32,
            ITF::NET_E_OPERATIONINPROGRESS => 0x80040309 as u32,
            ITF::FHCFG_E_TARGET_CANNOT_BE_USED => 0x80040309 as u32,
            ITF::VFW_E_CODECAPI_LINEAR_RANGE => 0x80040310 as u32,
            ITF::FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED => 0x80040310 as u32,
            ITF::VFW_E_CODECAPI_ENUMERATED => 0x80040311 as u32,
            ITF::FHCFG_E_TARGET_REHYDRATED_ELSEWHERE => 0x80040311 as u32,
            ITF::FHCFG_E_LEGACY_TARGET_UNSUPPORTED => 0x80040312 as u32,
            ITF::VFW_E_CODECAPI_NO_DEFAULT => 0x80040313 as u32,
            ITF::FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED => 0x80040313 as u32,
            ITF::VFW_E_CODECAPI_NO_CURRENT_VALUE => 0x80040314 as u32,
            ITF::FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED => 0x80040314 as u32,
            ITF::VFW_E_DVD_CHAPTER_DOES_NOT_EXIST => 0x80040315 as u32,
            ITF::FHCFG_E_LEGACY_BACKUP_NOT_FOUND => 0x80040315 as u32,
            ITF::VFW_E_BAD_KEY => 0x800403F2 as u32,
            ITF::DS_E_NOMOREDATA => 0x80040400 as u32,
            ITF::DS_E_INVALIDDATASOURCE => 0x80040401 as u32,
            ITF::MS_E_SAMPLEALLOC => 0x80040401 as u32,
            ITF::DS_E_DATASOURCENOTAVAILABLE => 0x80040402 as u32,
            ITF::MS_E_PURPOSEID => 0x80040402 as u32,
            ITF::DS_E_QUERYCANCELED => 0x80040403 as u32,
            ITF::MS_E_NOSTREAM => 0x80040403 as u32,
            ITF::DS_E_UNKNOWNREQUEST => 0x80040404 as u32,
            ITF::MS_E_NOSEEKING => 0x80040404 as u32,
            ITF::DS_E_BADREQUEST => 0x80040405 as u32,
            ITF::MS_E_INCOMPATIBLE => 0x80040405 as u32,
            ITF::DS_E_SERVERCAPACITY => 0x80040406 as u32,
            ITF::MS_E_BUSY => 0x80040406 as u32,
            ITF::DS_E_BADSEQUENCE => 0x80040407 as u32,
            ITF::MS_E_NOTINIT => 0x80040407 as u32,
            ITF::DS_E_MESSAGETOOLONG => 0x80040408 as u32,
            ITF::MS_E_SOURCEALREADYDEFINED => 0x80040408 as u32,
            ITF::DS_E_SERVERERROR => 0x80040409 as u32,
            ITF::MS_E_INVALIDSTREAMTYPE => 0x80040409 as u32,
            ITF::DS_E_CONFIGBAD => 0x8004040A as u32,
            ITF::MS_E_NOTRUNNING => 0x8004040A as u32,
            ITF::DS_E_DATANOTPRESENT => 0x80040410 as u32,
            ITF::DS_E_SETSTATUSINPROGRESS => 0x80040411 as u32,
            ITF::DS_E_DUPLICATEID => 0x80040412 as u32,
            ITF::DS_E_TOOMANYDATASOURCES => 0x80040413 as u32,
            ITF::DS_E_REGISTRY => 0x80040414 as u32,
            ITF::DS_E_DATASOURCENOTDISABLED => 0x80040415 as u32,
            ITF::DS_E_INVALIDTAGDB => 0x80040416 as u32,
            ITF::DS_E_INVALIDCATALOGNAME => 0x80040417 as u32,
            ITF::DS_E_CONFIGNOTRIGHTTYPE => 0x80040418 as u32,
            ITF::DS_E_PROTOCOLVERSION => 0x80040419 as u32,
            ITF::DS_E_ALREADYENABLED => 0x8004041A as u32,
            ITF::DS_E_INDEXDIRECTORY => 0x8004041C as u32,
            ITF::DS_E_VALUETOOLARGE => 0x8004041D as u32,
            ITF::DS_E_UNKNOWNPARAM => 0x8004041E as u32,
            ITF::DS_E_BUFFERTOOSMALL => 0x8004041F as u32,
            ITF::DS_E_PARAMOUTOFRANGE => 0x80040420 as u32,
            ITF::DS_E_ALREADYDISABLED => 0x80040421 as u32,
            ITF::DS_E_QUERYHUNG => 0x80040422 as u32,
            ITF::DS_E_BADRESULT => 0x80040423 as u32,
            ITF::DS_E_CANNOTWRITEREGISTRY => 0x80040424 as u32,
            ITF::DS_E_CANNOTREMOVECONCURRENT => 0x80040425 as u32,
            ITF::DS_E_SEARCHCATNAMECOLLISION => 0x80040426 as u32,
            ITF::DS_E_PROPVERSIONMISMATCH => 0x80040427 as u32,
            ITF::DS_E_MISSINGCATALOG => 0x80040428 as u32,
            ITF::UPNP_E_ACTION_SPECIFIC_MAX => 0x8004042B as u32,
            ITF::TF_E_LOCKED => 0x80040500 as u32,
            ITF::UPNP_E_INVALID_DOCUMENT => 0x80040500 as u32,
            ITF::COLL_E_BADSEQUENCE => 0x80040501 as u32,
            ITF::TF_E_STACKFULL => 0x80040501 as u32,
            ITF::UPNP_E_EVENT_SUBSCRIPTION_FAILED => 0x80040501 as u32,
            ITF::COLL_E_NOMOREDATA => 0x80040502 as u32,
            ITF::TF_E_NOTOWNEDRANGE => 0x80040502 as u32,
            ITF::COLL_E_INCOMPATIBLECOLUMNS => 0x80040503 as u32,
            ITF::TF_E_NOPROVIDER => 0x80040503 as u32,
            ITF::COLL_E_BUFFERTOOSMALL => 0x80040504 as u32,
            ITF::TF_E_DISCONNECTED => 0x80040504 as u32,
            ITF::TF_E_INVALIDVIEW => 0x80040505 as u32,
            ITF::COLL_E_BADRESULT => 0x80040506 as u32,
            ITF::TF_E_ALREADY_EXISTS => 0x80040506 as u32,
            ITF::COLL_E_NOSORTCOLUMN => 0x80040507 as u32,
            ITF::TF_E_RANGE_NOT_COVERED => 0x80040507 as u32,
            ITF::COLL_E_DUPLICATEDBID => 0x80040508 as u32,
            ITF::TF_E_COMPOSITION_REJECTED => 0x80040508 as u32,
            ITF::COLL_E_TOOMANYMERGECOLUMNS => 0x80040509 as u32,
            ITF::TF_E_EMPTYCONTEXT => 0x80040509 as u32,
            ITF::COLL_E_NODEFAULTCATALOG => 0x8004050A as u32,
            ITF::COLL_E_MAXCONNEXCEEDED => 0x8004050B as u32,
            ITF::FHSVC_E_BACKUP_BLOCKED => 0x80040600 as u32,
            ITF::CM_E_TOOMANYDATASERVERS => 0x80040601 as u32,
            ITF::FHSVC_E_NOT_CONFIGURED => 0x80040601 as u32,
            ITF::CM_E_TOOMANYDATASOURCES => 0x80040602 as u32,
            ITF::FHSVC_E_CONFIG_DISABLED => 0x80040602 as u32,
            ITF::CM_E_NOQUERYCONNECTIONS => 0x80040603 as u32,
            ITF::FHSVC_E_CONFIG_DISABLED_GP => 0x80040603 as u32,
            ITF::CM_E_DATASOURCENOTAVAILABLE => 0x80040604 as u32,
            ITF::FHSVC_E_FATAL_CONFIG_ERROR => 0x80040604 as u32,
            ITF::CM_E_CONNECTIONTIMEOUT => 0x80040605 as u32,
            ITF::FHSVC_E_CONFIG_REHYDRATING => 0x80040605 as u32,
            ITF::CM_E_SERVERNOTFOUND => 0x80040606 as u32,
            ITF::CM_E_REGISTRY => 0x80040608 as u32,
            ITF::CM_E_INVALIDDATASOURCE => 0x80040609 as u32,
            ITF::CM_E_TIMEOUT => 0x8004060A as u32,
            ITF::CM_E_INSUFFICIENTBUFFER => 0x8004060B as u32,
            ITF::QRY_E_QUERYSYNTAX => 0x80040701 as u32,
            ITF::QRY_E_TYPEMISMATCH => 0x80040702 as u32,
            ITF::QRY_E_UNHANDLEDTYPE => 0x80040703 as u32,
            ITF::QRY_E_TOOMANYCOLUMNS => 0x80040705 as u32,
            ITF::QRY_E_TOOMANYDATABASES => 0x80040706 as u32,
            ITF::QRY_E_STARTHITTOBIG => 0x80040707 as u32,
            ITF::QRY_E_TOOMANYQUERYTERMS => 0x80040708 as u32,
            ITF::QRY_E_NODATASOURCES => 0x80040709 as u32,
            ITF::QRY_E_TIMEOUT => 0x8004070A as u32,
            ITF::QRY_E_COLUMNNOTSORTABLE => 0x8004070B as u32,
            ITF::QRY_E_COLUMNNOTSEARCHABLE => 0x8004070C as u32,
            ITF::QRY_E_INVALIDCOLUMN => 0x8004070D as u32,
            ITF::QRY_E_QUERYCORRUPT => 0x8004070E as u32,
            ITF::QRY_E_PREFIXWILDCARD => 0x8004070F as u32,
            ITF::QRY_E_INFIXWILDCARD => 0x80040710 as u32,
            ITF::QRY_E_WILDCARDPREFIXLENGTH => 0x80040711 as u32,
            ITF::QRY_E_ENGINEFAILED => 0x80040713 as u32,
            ITF::QRY_E_SEARCHTOOBIG => 0x80040714 as u32,
            ITF::QRY_E_NULLQUERY => 0x80040715 as u32,
            ITF::QRY_E_NOCOLUMNS => 0x80040717 as u32,
            ITF::QRY_E_INVALIDSCOPES => 0x80040718 as u32,
            ITF::QRY_E_INVALIDCATALOG => 0x80040719 as u32,
            ITF::QRY_E_SCOPECARDINALIDY => 0x8004071A as u32,
            ITF::QRY_E_UNEXPECTED => 0x8004071B as u32,
            ITF::QRY_E_INVALIDPATH => 0x8004071C as u32,
            ITF::QRY_E_LMNOTINITIALIZED => 0x8004071D as u32,
            ITF::QRY_E_INVALIDINTERVAL => 0x8004071E as u32,
            ITF::QRY_E_NOLOGMANAGER => 0x8004071F as u32,
            ITF::SCHEMA_E_LOAD_SPECIAL => 0x80040C01 as u32,
            ITF::SCHEMA_E_FILENOTFOUND => 0x80040C02 as u32,
            ITF::SCHEMA_E_NESTEDTAG => 0x80040C03 as u32,
            ITF::SCHEMA_E_UNEXPECTEDTAG => 0x80040C04 as u32,
            ITF::SCHEMA_E_VERSIONMISMATCH => 0x80040C05 as u32,
            ITF::SCHEMA_E_CANNOTCREATEFILE => 0x80040C06 as u32,
            ITF::SCHEMA_E_CANNOTWRITEFILE => 0x80040C07 as u32,
            ITF::SCHEMA_E_EMPTYFILE => 0x80040C08 as u32,
            ITF::SCHEMA_E_INVALIDFILETYPE => 0x80040C09 as u32,
            ITF::SCHEMA_E_INVALIDDATATYPE => 0x80040C0A as u32,
            ITF::SCHEMA_E_CANNOTCREATENOISEWORDFILE => 0x80040C0B as u32,
            ITF::SCHEMA_E_ADDSTOPWORDS => 0x80040C0C as u32,
            ITF::SCHEMA_E_NAMEEXISTS => 0x80040C0D as u32,
            ITF::SCHEMA_E_INVALIDVALUE => 0x80040C0E as u32,
            ITF::SCHEMA_E_BADPROPSPEC => 0x80040C0F as u32,
            ITF::SCHEMA_E_NOMORECOLUMNS => 0x80040C10 as u32,
            ITF::SCHEMA_E_FILECHANGED => 0x80040C11 as u32,
            ITF::SCHEMA_E_BADCOLUMNNAME => 0x80040C12 as u32,
            ITF::SCHEMA_E_BADPROPPID => 0x80040C13 as u32,
            ITF::SCHEMA_E_BADATTRIBUTE => 0x80040C14 as u32,
            ITF::SCHEMA_E_BADFILENAME => 0x80040C15 as u32,
            ITF::SCHEMA_E_PROPEXISTS => 0x80040C16 as u32,
            ITF::SCHEMA_E_DUPLICATENOISE => 0x80040C17 as u32,
            ITF::GTHR_E_DUPLICATE_OBJECT => 0x80040D02 as u32,
            ITF::GTHR_E_UNABLE_TO_READ_REGISTRY => 0x80040D03 as u32,
            ITF::GTHR_E_ERROR_WRITING_REGISTRY => 0x80040D04 as u32,
            ITF::GTHR_E_ERROR_INITIALIZING_PERFMON => 0x80040D05 as u32,
            ITF::GTHR_E_ERROR_OBJECT_NOT_FOUND => 0x80040D06 as u32,
            ITF::GTHR_E_URL_EXCLUDED => 0x80040D07 as u32,
            ITF::GTHR_E_CONFIG_DUP_PROJECT => 0x80040D0A as u32,
            ITF::GTHR_E_CONFIG_DUP_EXTENSION => 0x80040D0B as u32,
            ITF::GTHR_E_DUPLICATE_URL => 0x80040D0D as u32,
            ITF::GTHR_E_TOO_MANY_PLUGINS => 0x80040D0E as u32,
            ITF::GTHR_E_INVALIDFUNCTION => 0x80040D0F as u32,
            ITF::GTHR_E_NOFILTERSINK => 0x80040D10 as u32,
            ITF::GTHR_E_FILTER_PROCESS_TERMINATED => 0x80040D11 as u32,
            ITF::GTHR_E_FILTER_INVALID_MESSAGE => 0x80040D12 as u32,
            ITF::GTHR_E_UNSUPPORTED_PROPERTY_TYPE => 0x80040D13 as u32,
            ITF::GTHR_E_NAME_TOO_LONG => 0x80040D14 as u32,
            ITF::GTHR_E_NO_IDENTITY => 0x80040D15 as u32,
            ITF::GTHR_E_FILTER_NOT_FOUND => 0x80040D16 as u32,
            ITF::GTHR_E_FILTER_NO_MORE_THREADS => 0x80040D17 as u32,
            ITF::GTHR_E_PRT_HNDLR_PROGID_MISSING => 0x80040D18 as u32,
            ITF::GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA => 0x80040D19 as u32,
            ITF::GTHR_E_UNKNOWN_PROTOCOL => 0x80040D1A as u32,
            ITF::GTHR_E_PROJECT_NOT_INITIALIZED => 0x80040D1B as u32,
            ITF::GTHR_E_INVALID_PROJECT_NAME => 0x80040D22 as u32,
            ITF::GTHR_E_SHUTTING_DOWN => 0x80040D23 as u32,
            ITF::GTHR_E_VALUE_NOT_AVAILABLE => 0x80040D25 as u32,
            ITF::GTHR_E_OUT_OF_DOC_ID => 0x80040D26 as u32,
            ITF::GTHR_E_NOTIFICATION_START_PAGE => 0x80040D27 as u32,
            ITF::GTHR_E_DUP_PROPERTY_MAPPING => 0x80040D2A as u32,
            ITF::GTHR_E_INVALID_ACCOUNT => 0x80040D2C as u32,
            ITF::GTHR_E_FILTER_INIT => 0x80040D2E as u32,
            ITF::GTHR_E_INVALID_ACCOUNT_SYNTAX => 0x80040D2F as u32,
            ITF::GTHR_E_PROXY_NAME => 0x80040D31 as u32,
            ITF::GTHR_E_SERVER_UNAVAILABLE => 0x80040D32 as u32,
            ITF::GTHR_E_INVALID_PATH => 0x80040D34 as u32,
            ITF::GTHR_E_FILTER_NO_CODEPAGE => 0x80040D35 as u32,
            ITF::GTHR_E_NO_PRTCLHNLR => 0x80040D37 as u32,
            ITF::GTHR_E_IE_OFFLINE => 0x80040D38 as u32,
            ITF::GTHR_E_BAD_FILTER_DAEMON => 0x80040D39 as u32,
            ITF::GTHR_E_INVALID_MAPPING => 0x80040D40 as u32,
            ITF::GTHR_E_USER_AGENT_NOT_SPECIFIED => 0x80040D41 as u32,
            ITF::GTHR_E_FROM_NOT_SPECIFIED => 0x80040D43 as u32,
            ITF::GTHR_E_INVALID_STREAM_LOGS_COUNT => 0x80040D44 as u32,
            ITF::GTHR_E_INVALID_EXTENSION => 0x80040D45 as u32,
            ITF::GTHR_E_INVALID_GROW_FACTOR => 0x80040D46 as u32,
            ITF::GTHR_E_INVALID_TIME_OUT => 0x80040D47 as u32,
            ITF::GTHR_E_INVALID_RETRIES => 0x80040D48 as u32,
            ITF::GTHR_E_INVALID_LOG_FILE_NAME => 0x80040D49 as u32,
            ITF::GTHR_E_INVALID_HOST_NAME => 0x80040D50 as u32,
            ITF::GTHR_E_INVALID_START_PAGE => 0x80040D51 as u32,
            ITF::GTHR_E_DUPLICATE_PROJECT => 0x80040D52 as u32,
            ITF::GTHR_E_INVALID_DIRECTORY => 0x80040D53 as u32,
            ITF::GTHR_E_FILTER_INTERRUPTED => 0x80040D54 as u32,
            ITF::GTHR_E_INVALID_PROXY_PORT => 0x80040D55 as u32,
            ITF::GTHR_E_SECRET_NOT_FOUND => 0x80040D57 as u32,
            ITF::GTHR_E_INVALID_PATH_EXPRESSION => 0x80040D58 as u32,
            ITF::GTHR_E_INVALID_START_PAGE_HOST => 0x80040D59 as u32,
            ITF::GTHR_E_INVALID_START_PAGE_PATH => 0x80040D60 as u32,
            ITF::GTHR_E_APPLICATION_NOT_FOUND => 0x80040D61 as u32,
            ITF::GTHR_E_CANNOT_REMOVE_PLUGINMGR => 0x80040D62 as u32,
            ITF::GTHR_E_INVALID_APPLICATION_NAME => 0x80040D63 as u32,
            ITF::GTHR_E_FILTER_FAULT => 0x80040D65 as u32,
            ITF::GTHR_E_NON_FIXED_DRIVE => 0x80040D66 as u32,
            ITF::GTHR_E_FILTER_SINGLE_THREADED => 0x80040D6B as u32,
            ITF::GTHR_E_URL_UNIDENTIFIED => 0x80040D6D as u32,
            ITF::GTHR_E_FORCE_NOTIFICATION_RESET => 0x80040D6F as u32,
            ITF::GTHR_E_CONTENT_ID_CONFLICT => 0x80040D72 as u32,
            ITF::GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE => 0x80040D73 as u32,
            ITF::GTHR_E_RECOVERABLE_EXOLEDB_ERROR => 0x80040D74 as u32,
            ITF::GTHR_E_INVALID_CALL_FROM_WBREAKER => 0x80040D76 as u32,
            ITF::GTHR_E_PROPERTY_LIST_NOT_INITIALIZED => 0x80040D77 as u32,
            ITF::GHTR_E_LOCAL_SERVER_UNAVAILABLE => 0x80040D79 as u32,
            ITF::GTHR_E_SCHEMA_ERRORS_OCCURRED => 0x80040D7A as u32,
            ITF::GTHR_E_TIMEOUT => 0x80040D7B as u32,
            ITF::GTHR_E_NOTIFICATION_START_ADDRESS_INVALID => 0x80040D86 as u32,
            ITF::GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED => 0x80040D87 as u32,
            ITF::GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE => 0x80040D88 as u32,
            ITF::GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE => 0x80040D89 as u32,
            ITF::GHTR_E_INSUFFICIENT_DISK_SPACE => 0x80040D8B as u32,
            ITF::GTHR_E_INVALID_RESOURCE_ID => 0x80040D8D as u32,
            ITF::GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES => 0x80040D8E as u32,
            ITF::GTHR_E_RETRY => 0x80040D95 as u32,
            ITF::GTHR_E_JET_BACKUP_ERROR => 0x80040D96 as u32,
            ITF::GTHR_E_JET_RESTORE_ERROR => 0x80040D97 as u32,
            ITF::GTHR_E_PLUGIN_NOT_REGISTERED => 0x80040D9B as u32,
            ITF::GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED => 0x80040D9C as u32,
            ITF::GTHR_E_DIRMON_NOT_INITIALZED => 0x80040D9D as u32,
            ITF::GTHR_E_NOTIF_BEING_REMOVED => 0x80040D9E as u32,
            ITF::GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT => 0x80040D9F as u32,
            ITF::GTHR_E_INVALID_PATH_SPEC => 0x80040DA0 as u32,
            ITF::GTHR_E_INSUFFICIENT_FEATURE_TERMS => 0x80040DA1 as u32,
            ITF::GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES => 0x80040DA2 as u32,
            ITF::GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS => 0x80040DA3 as u32,
            ITF::GTHR_E_AUTOCAT_UNEXPECTED => 0x80040DA4 as u32,
            ITF::GTHR_E_SINGLE_THREADED_EMBEDDING => 0x80040DA5 as u32,
            ITF::GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE => 0x80040DA9 as u32,
            ITF::GTHR_E_EMPTY_DACL => 0x80040DAA as u32,
            ITF::GTHR_E_OBJECT_NOT_VALID => 0x80040DAB as u32,
            ITF::GTHR_E_CANNOT_ENABLE_CHECKPOINT => 0x80040DAE as u32,
            ITF::GTHR_E_SCOPES_EXCEEDED => 0x80040DAF as u32,
            ITF::GTHR_E_PROPERTIES_EXCEEDED => 0x80040DB0 as u32,
            ITF::GTHR_E_INVALID_START_ADDRESS => 0x80040DB2 as u32,
            ITF::GTHR_E_PIPE_NOT_CONNECTTED => 0x80040DB4 as u32,
            ITF::GTHR_E_BACKUP_VALIDATION_FAIL => 0x80040DB6 as u32,
            ITF::GTHR_E_BAD_FILTER_HOST => 0x80040DB7 as u32,
            ITF::GTHR_E_FILTERPOOL_NOTFOUND => 0x80040DBA as u32,
            ITF::GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT => 0x80040DBB as u32,
            ITF::DB_E_BADACCESSORHANDLE => 0x80040E00 as u32,
            ITF::DB_E_ROWLIMITEXCEEDED => 0x80040E01 as u32,
            ITF::DB_E_READONLYACCESSOR => 0x80040E02 as u32,
            ITF::DB_E_SCHEMAVIOLATION => 0x80040E03 as u32,
            ITF::DB_E_BADROWHANDLE => 0x80040E04 as u32,
            ITF::DB_E_OBJECTOPEN => 0x80040E05 as u32,
            ITF::DB_E_BADCHAPTER => 0x80040E06 as u32,
            ITF::DB_E_CANTCONVERTVALUE => 0x80040E07 as u32,
            ITF::DB_E_BADBINDINFO => 0x80040E08 as u32,
            ITF::DB_SEC_E_PERMISSIONDENIED => 0x80040E09 as u32,
            ITF::DB_E_NOTAREFERENCECOLUMN => 0x80040E0A as u32,
            ITF::DB_E_LIMITREJECTED => 0x80040E0B as u32,
            ITF::DB_E_NOCOMMAND => 0x80040E0C as u32,
            ITF::DB_E_COSTLIMIT => 0x80040E0D as u32,
            ITF::DB_E_BADBOOKMARK => 0x80040E0E as u32,
            ITF::DB_E_BADLOCKMODE => 0x80040E0F as u32,
            ITF::DB_E_PARAMNOTOPTIONAL => 0x80040E10 as u32,
            ITF::DB_E_BADCOLUMNID => 0x80040E11 as u32,
            ITF::DB_E_BADRATIO => 0x80040E12 as u32,
            ITF::DB_E_BADVALUES => 0x80040E13 as u32,
            ITF::DB_E_ERRORSINCOMMAND => 0x80040E14 as u32,
            ITF::DB_E_CANTCANCEL => 0x80040E15 as u32,
            ITF::DB_E_DIALECTNOTSUPPORTED => 0x80040E16 as u32,
            ITF::DB_E_DUPLICATEDATASOURCE => 0x80040E17 as u32,
            ITF::DB_E_CANNOTRESTART => 0x80040E18 as u32,
            ITF::DB_E_NOTFOUND => 0x80040E19 as u32,
            ITF::DB_E_CANNOTFREE => 0x80040E1A as u32,
            ITF::DB_E_NEWLYINSERTED => 0x80040E1B as u32,
            ITF::DB_E_GOALREJECTED => 0x80040E1C as u32,
            ITF::DB_E_UNSUPPORTEDCONVERSION => 0x80040E1D as u32,
            ITF::DB_E_BADSTARTPOSITION => 0x80040E1E as u32,
            ITF::DB_E_NOQUERY => 0x80040E1F as u32,
            ITF::DB_E_NOTREENTRANT => 0x80040E20 as u32,
            ITF::DB_E_ERRORSOCCURRED => 0x80040E21 as u32,
            ITF::DB_E_NOAGGREGATION => 0x80040E22 as u32,
            ITF::DB_E_DELETEDROW => 0x80040E23 as u32,
            ITF::DB_E_CANTFETCHBACKWARDS => 0x80040E24 as u32,
            ITF::DB_E_ROWSNOTRELEASED => 0x80040E25 as u32,
            ITF::DB_E_BADSTORAGEFLAG => 0x80040E26 as u32,
            ITF::DB_E_BADCOMPAREOP => 0x80040E27 as u32,
            ITF::DB_E_BADSTATUSVALUE => 0x80040E28 as u32,
            ITF::DB_E_CANTSCROLLBACKWARDS => 0x80040E29 as u32,
            ITF::DB_E_BADREGIONHANDLE => 0x80040E2A as u32,
            ITF::DB_E_NONCONTIGUOUSRANGE => 0x80040E2B as u32,
            ITF::DB_E_INVALIDTRANSITION => 0x80040E2C as u32,
            ITF::DB_E_NOTASUBREGION => 0x80040E2D as u32,
            ITF::DB_E_MULTIPLESTATEMENTS => 0x80040E2E as u32,
            ITF::DB_E_INTEGRITYVIOLATION => 0x80040E2F as u32,
            ITF::DB_E_BADTYPENAME => 0x80040E30 as u32,
            ITF::DB_E_ABORTLIMITREACHED => 0x80040E31 as u32,
            ITF::DB_E_ROWSETINCOMMAND => 0x80040E32 as u32,
            ITF::DB_E_CANTTRANSLATE => 0x80040E33 as u32,
            ITF::DB_E_DUPLICATEINDEXID => 0x80040E34 as u32,
            ITF::DB_E_NOINDEX => 0x80040E35 as u32,
            ITF::DB_E_INDEXINUSE => 0x80040E36 as u32,
            ITF::DB_E_NOTABLE => 0x80040E37 as u32,
            ITF::DB_E_CONCURRENCYVIOLATION => 0x80040E38 as u32,
            ITF::DB_E_BADCOPY => 0x80040E39 as u32,
            ITF::DB_E_BADPRECISION => 0x80040E3A as u32,
            ITF::DB_E_BADSCALE => 0x80040E3B as u32,
            ITF::DB_E_BADTABLEID => 0x80040E3C as u32,
            ITF::DB_E_BADTYPE => 0x80040E3D as u32,
            ITF::DB_E_DUPLICATECOLUMNID => 0x80040E3E as u32,
            ITF::DB_E_DUPLICATETABLEID => 0x80040E3F as u32,
            ITF::DB_E_TABLEINUSE => 0x80040E40 as u32,
            ITF::DB_E_NOLOCALE => 0x80040E41 as u32,
            ITF::DB_E_BADRECORDNUM => 0x80040E42 as u32,
            ITF::DB_E_BOOKMARKSKIPPED => 0x80040E43 as u32,
            ITF::DB_E_BADPROPERTYVALUE => 0x80040E44 as u32,
            ITF::DB_E_INVALID => 0x80040E45 as u32,
            ITF::DB_E_BADACCESSORFLAGS => 0x80040E46 as u32,
            ITF::DB_E_BADSTORAGEFLAGS => 0x80040E47 as u32,
            ITF::DB_E_BYREFACCESSORNOTSUPPORTED => 0x80040E48 as u32,
            ITF::DB_E_NULLACCESSORNOTSUPPORTED => 0x80040E49 as u32,
            ITF::DB_E_NOTPREPARED => 0x80040E4A as u32,
            ITF::DB_E_BADACCESSORTYPE => 0x80040E4B as u32,
            ITF::DB_E_WRITEONLYACCESSOR => 0x80040E4C as u32,
            ITF::DB_SEC_E_AUTH_FAILED => 0x80040E4D as u32,
            ITF::DB_E_CANCELED => 0x80040E4E as u32,
            ITF::DB_E_CHAPTERNOTRELEASED => 0x80040E4F as u32,
            ITF::DB_E_BADSOURCEHANDLE => 0x80040E50 as u32,
            ITF::DB_E_PARAMUNAVAILABLE => 0x80040E51 as u32,
            ITF::DB_E_ALREADYINITIALIZED => 0x80040E52 as u32,
            ITF::DB_E_NOTSUPPORTED => 0x80040E53 as u32,
            ITF::DB_E_MAXPENDCHANGESEXCEEDED => 0x80040E54 as u32,
            ITF::DB_E_BADORDINAL => 0x80040E55 as u32,
            ITF::DB_E_PENDINGCHANGES => 0x80040E56 as u32,
            ITF::DB_E_DATAOVERFLOW => 0x80040E57 as u32,
            ITF::DB_E_BADHRESULT => 0x80040E58 as u32,
            ITF::DB_E_BADLOOKUPID => 0x80040E59 as u32,
            ITF::DB_E_BADDYNAMICERRORID => 0x80040E5A as u32,
            ITF::DB_E_PENDINGINSERT => 0x80040E5B as u32,
            ITF::DB_E_BADCONVERTFLAG => 0x80040E5C as u32,
            ITF::DB_E_BADPARAMETERNAME => 0x80040E5D as u32,
            ITF::DB_E_MULTIPLESTORAGE => 0x80040E5E as u32,
            ITF::DB_E_CANTFILTER => 0x80040E5F as u32,
            ITF::DB_E_CANTORDER => 0x80040E60 as u32,
            ITF::MD_E_BADTUPLE => 0x80040E61 as u32,
            ITF::MD_E_BADCOORDINATE => 0x80040E62 as u32,
            ITF::MD_E_INVALIDAXIS => 0x80040E63 as u32,
            ITF::MD_E_INVALIDCELLRANGE => 0x80040E64 as u32,
            ITF::DB_E_NOCOLUMN => 0x80040E65 as u32,
            ITF::DB_E_COMMANDNOTPERSISTED => 0x80040E67 as u32,
            ITF::DB_E_DUPLICATEID => 0x80040E68 as u32,
            ITF::DB_E_OBJECTCREATIONLIMITREACHED => 0x80040E69 as u32,
            ITF::SEC_E_BADTRUSTEEID => 0x80040E6A as u32,
            ITF::SEC_E_NOTRUSTEEID => 0x80040E6B as u32,
            ITF::SEC_E_NOMEMBERSHIPSUPPORT => 0x80040E6C as u32,
            ITF::SEC_E_INVALIDOBJECT => 0x80040E6D as u32,
            ITF::SEC_E_NOOWNER => 0x80040E6E as u32,
            ITF::SEC_E_INVALIDACCESSENTRYLIST => 0x80040E6F as u32,
            ITF::SEC_E_INVALIDOWNER => 0x80040E70 as u32,
            ITF::SEC_E_INVALIDACCESSENTRY => 0x80040E71 as u32,
            ITF::DB_E_BADINDEXID => 0x80040E72 as u32,
            ITF::DB_E_BADINITSTRING => 0x80040E73 as u32,
            ITF::DB_E_NOPROVIDERSREGISTERED => 0x80040E74 as u32,
            ITF::DB_E_MISMATCHEDPROVIDER => 0x80040E75 as u32,
            ITF::DB_E_BADCOMMANDID => 0x80040E76 as u32,
            ITF::DB_E_BADCONSTRAINTTYPE => 0x80040E77 as u32,
            ITF::DB_E_BADCONSTRAINTFORM => 0x80040E78 as u32,
            ITF::DB_E_BADDEFERRABILITY => 0x80040E79 as u32,
            ITF::DB_E_BADMATCHTYPE => 0x80040E80 as u32,
            ITF::DB_E_BADUPDATEDELETERULE => 0x80040E8A as u32,
            ITF::DB_E_BADCONSTRAINTID => 0x80040E8B as u32,
            ITF::DB_E_BADCOMMANDFLAGS => 0x80040E8C as u32,
            ITF::DB_E_OBJECTMISMATCH => 0x80040E8D as u32,
            ITF::DB_E_RESOURCEOUTOFSCOPE => 0x80040E8E as u32,
            ITF::DB_E_DROPRESTRICTED => 0x80040E90 as u32,
            ITF::DB_E_NOSOURCEOBJECT => 0x80040E91 as u32,
            ITF::DB_E_RESOURCELOCKED => 0x80040E92 as u32,
            ITF::DB_E_NOTCOLLECTION => 0x80040E93 as u32,
            ITF::DB_E_READONLY => 0x80040E94 as u32,
            ITF::DB_E_ASYNCNOTSUPPORTED => 0x80040E95 as u32,
            ITF::DB_E_CANNOTCONNECT => 0x80040E96 as u32,
            ITF::DB_E_TIMEOUT => 0x80040E97 as u32,
            ITF::DB_E_RESOURCEEXISTS => 0x80040E98 as u32,
            ITF::DB_E_DUPLICATECONSTRAINTID => 0x80040E99 as u32,
            ITF::DB_E_OUTOFSPACE => 0x80040E9A as u32,
            ITF::DB_SEC_E_SAFEMODE_DENIED => 0x80040E9B as u32,
            ITF::DB_E_NOSTATISTIC => 0x80040E9C as u32,
            ITF::DB_E_ALTERRESTRICTED => 0x80040E9D as u32,
            ITF::DB_E_RESOURCENOTSUPPORTED => 0x80040E9E as u32,
            ITF::DB_E_NOCONSTRAINT => 0x80040E9F as u32,
            ITF::DB_E_COLUMNUNAVAILABLE => 0x80040EA0 as u32,
            ITF::DB_E_BOGUS => 0x80040EFF as u32,
            ITF::DXVA2_E_NOT_INITIALIZED => 0x80041000 as u32,
            ITF::MF_E_DXGI_DEVICE_NOT_INITIALIZED => 0x80041000 as u32,
            ITF::SYNC_E_ID_FORMAT_MISMATCH => 0x80041000 as u32,
            ITF::REC_E_ABORTED => 0x80041000 as u32,
            ITF::ROUTER_E_NOTINTERESTED => 0x80041000 as u32,
            ITF::DXVA2_E_NEW_VIDEO_DEVICE => 0x80041001 as u32,
            ITF::MF_E_DXGI_NEW_VIDEO_DEVICE => 0x80041001 as u32,
            ITF::SYNC_E_INVALID_OPERATION => 0x80041001 as u32,
            ITF::REC_E_NOCALLBACK => 0x80041001 as u32,
            ITF::DXVA2_E_VIDEO_DEVICE_LOCKED => 0x80041002 as u32,
            ITF::MF_E_DXGI_VIDEO_DEVICE_LOCKED => 0x80041002 as u32,
            ITF::SYNC_E_REPLICA_NOT_FOUND => 0x80041002 as u32,
            ITF::REC_E_NORESIDUES => 0x80041002 as u32,
            ITF::SEO_E_NOTPRESENT => 0x80041002 as u32,
            ITF::DXVA2_E_NOT_AVAILABLE => 0x80041003 as u32,
            ITF::SYNC_E_CHANGE_COUNT_MISMATCH => 0x80041003 as u32,
            ITF::REC_E_TOODIFFERENT => 0x80041003 as u32,
            ITF::SEO_E_TIMEOUT => 0x80041003 as u32,
            ITF::SYNC_E_CHANGE_UNIT_COUNT_MISMATCH => 0x80041004 as u32,
            ITF::REC_E_INEEDTODOTHEUPDATES => 0x80041004 as u32,
            ITF::SEO_S_DONEPROCESSING => 0x80041004 as u32,
            ITF::SYNC_E_KNOWLEDGE_DECREASED => 0x80041005 as u32,
            ITF::EVENTS_E_BADDATA => 0x80041005 as u32,
            ITF::SYNC_E_CHANGE_NOT_IN_KNOWLEDGE => 0x80041006 as u32,
            ITF::EVENTS_E_TIMEOUT => 0x80041006 as u32,
            ITF::SYNC_E_ITEM_MUST_EXIST => 0x80041007 as u32,
            ITF::EVENTS_E_DISABLED => 0x80041007 as u32,
            ITF::SYNC_E_HAS_NO_DATA => 0x80041008 as u32,
            ITF::SYNC_E_CHANGE_NEEDS_KNOWLEDGE => 0x80041009 as u32,
            ITF::SYNC_E_RANGE_OUT_OF_ORDER => 0x8004100A as u32,
            ITF::SYNC_E_NOT_EXPECTED_CHANGE => 0x8004100B as u32,
            ITF::SYNC_E_DESERIALIZATION => 0x8004100C as u32,
            ITF::SYNC_E_SINGLE_RANGE_ONLY => 0x8004100D as u32,
            ITF::SYNC_E_ITEM_HAS_CHANGE_UNITS => 0x8004100E as u32,
            ITF::SYNC_E_ITEM_HAS_NO_CHANGE_UNITS => 0x8004100F as u32,
            ITF::SYNC_E_ITEM_HAS_NO_VERSION_DATA => 0x80041010 as u32,
            ITF::SYNC_E_OBJECT_NEEDS_STATE => 0x80041011 as u32,
            ITF::SYNC_E_FEEDSYNC_INVALID_FEED => 0x80041012 as u32,
            ITF::SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA => 0x80041013 as u32,
            ITF::SYNC_E_FEEDSYNC_CALLBACK_EXPECTED => 0x80041014 as u32,
            ITF::SYNC_E_INVALID_VERSION => 0x80041015 as u32,
            ITF::SYNC_E_DUPLICATE_ITEM => 0x80041016 as u32,
            ITF::SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS => 0x80041017 as u32,
            ITF::SYNC_E_INVALID_SYNC_TIME => 0x80041018 as u32,
            ITF::SYNC_E_INCOMPLETE_REPLICA_KEY_MAP => 0x80041019 as u32,
            ITF::SYNC_E_INVALID_REPLICA_KEY => 0x8004101A as u32,
            ITF::SYNC_E_NEGATIVE_RANGE_EXCEPTION => 0x8004101B as u32,
            ITF::SYNC_E_BATCH_NEEDS_KNOWLEDGE => 0x8004101C as u32,
            ITF::SYNC_E_INTERNAL_ERROR => 0x8004101D as u32,
            ITF::SYNC_E_CHANGE_BATCH_IS_READ_ONLY => 0x8004101E as u32,
            ITF::SYNC_E_DATA_MODIFIED_CONCURRENTLY => 0x8004101F as u32,
            ITF::SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM => 0x80041020 as u32,
            ITF::SYNC_E_FILTER_NOT_SUPPORTED => 0x80041021 as u32,
            ITF::SYNC_E_LOAD_CONFLICT_DATA_FAILED => 0x80041022 as u32,
            ITF::SYNC_E_INVALID_SERIALIZATION_VERSION => 0x80041023 as u32,
            ITF::SYNC_E_MARKER_MISMATCH => 0x80041024 as u32,
            ITF::SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED => 0x80041025 as u32,
            ITF::SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT => 0x80041026 as u32,
            ITF::SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED => 0x80041027 as u32,
            ITF::SYNC_E_FULL_ENUMERATION_MUST_BE_USED => 0x80041028 as u32,
            ITF::SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE => 0x80041029 as u32,
            ITF::SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED => 0x8004102A as u32,
            ITF::SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER => 0x8004102B as u32,
            ITF::IDX_E_INVALIDTAG => 0x80041101 as u32,
            ITF::IDX_E_METAFILE_CORRUPT => 0x80041102 as u32,
            ITF::IDX_E_TOO_MANY_SEARCH_SERVERS => 0x80041103 as u32,
            ITF::IDX_E_SEARCH_SERVER_ALREADY_EXISTS => 0x80041104 as u32,
            ITF::IDX_E_BUILD_IN_PROGRESS => 0x80041105 as u32,
            ITF::IDX_E_IDXLSTFILE_CORRUPT => 0x80041106 as u32,
            ITF::IDX_E_REGISTRY_ENTRY => 0x80041107 as u32,
            ITF::IDX_E_OBJECT_NOT_FOUND => 0x80041108 as u32,
            ITF::IDX_E_SEARCH_SERVER_NOT_FOUND => 0x80041109 as u32,
            ITF::IDX_E_WB_NOTFOUND => 0x8004110A as u32,
            ITF::IDX_E_NOISELIST_NOTFOUND => 0x8004110B as u32,
            ITF::IDX_E_STEMMER_NOTFOUND => 0x8004110C as u32,
            ITF::IDX_E_PROP_STOPPED => 0x8004110D as u32,
            ITF::IDX_E_DISKFULL => 0x8004110E as u32,
            ITF::IDX_E_INVALID_INDEX => 0x8004110F as u32,
            ITF::IDX_E_CORRUPT_INDEX => 0x80041110 as u32,
            ITF::IDX_E_PROPSTORE_INIT_FAILED => 0x80041112 as u32,
            ITF::IDX_E_PROP_STATE_CORRUPT => 0x80041113 as u32,
            ITF::IDX_E_NOT_LOADED => 0x80041117 as u32,
            ITF::IDX_E_PROP_MAJOR_VERSION_MISMATCH => 0x80041118 as u32,
            ITF::IDX_E_PROP_MINOR_VERSION_MISMATCH => 0x80041119 as u32,
            ITF::IDX_E_DSS_NOT_CONNECTED => 0x8004111A as u32,
            ITF::IDX_E_DOCUMENT_ABORTED => 0x8004111B as u32,
            ITF::IDX_E_CATALOG_DISMOUNTED => 0x8004111C as u32,
            ITF::IDX_E_USE_DEFAULT_CONTENTCLASS => 0x8004111F as u32,
            ITF::IDX_E_USE_APPGLOBAL_PROPTABLE => 0x80041120 as u32,
            ITF::JPS_E_JET_ERR => 0x8004117F as u32,
            ITF::JPS_E_CATALOG_DECSRIPTION_MISSING => 0x80041181 as u32,
            ITF::JPS_E_MISSING_INFORMATION => 0x80041182 as u32,
            ITF::JPS_E_INSUFFICIENT_VERSION_STORAGE => 0x80041183 as u32,
            ITF::JPS_E_INSUFFICIENT_DATABASE_SESSIONS => 0x80041184 as u32,
            ITF::JPS_E_INSUFFICIENT_DATABASE_RESOURCES => 0x80041185 as u32,
            ITF::JPS_E_SCHEMA_ERROR => 0x80041186 as u32,
            ITF::JPS_E_PROPAGATION_FILE => 0x80041187 as u32,
            ITF::JPS_E_PROPAGATION_CORRUPTION => 0x80041188 as u32,
            ITF::JPS_E_PROPAGATION_VERSION_MISMATCH => 0x80041189 as u32,
            ITF::JPS_E_SHARING_VIOLATION => 0x8004118A as u32,
            ITF::EXCI_E_NO_CONFIG => 0x800411A0 as u32,
            ITF::EXCI_E_INVALID_SERVER_CONFIG => 0x800411A1 as u32,
            ITF::EXCI_E_ACCESS_DENIED => 0x800411A2 as u32,
            ITF::EXCI_E_INVALID_EXCHANGE_SERVER => 0x800411A3 as u32,
            ITF::EXCI_E_BADCONFIG_OR_ACCESSDENIED => 0x800411A4 as u32,
            ITF::EXCI_E_WRONG_SERVER_OR_ACCT => 0x800411A5 as u32,
            ITF::EXCI_E_NOT_ADMIN_OR_WRONG_SITE => 0x800411A6 as u32,
            ITF::EXCI_E_NO_MAPI => 0x800411A7 as u32,
            ITF::EXCI_E_INVALID_ACCOUNT_INFO => 0x800411A8 as u32,
            ITF::PRTH_E_COMM_ERROR => 0x80041200 as u32,
            ITF::PRTH_E_OBJ_NOT_FOUND => 0x80041201 as u32,
            ITF::PRTH_E_REQUEST_ERROR => 0x80041202 as u32,
            ITF::PRTH_E_INTERNAL_ERROR => 0x80041204 as u32,
            ITF::PRTH_E_ACCESS_DENIED => 0x80041205 as u32,
            ITF::PRTH_E_SERVER_ERROR => 0x80041206 as u32,
            ITF::PRTH_E_NOT_REDIRECTED => 0x80041207 as u32,
            ITF::PRTH_E_BAD_REQUEST => 0x80041208 as u32,
            ITF::PRTH_E_HTTP_CANNOT_CONNECT => 0x80041209 as u32,
            ITF::PRTH_E_WININET => 0x8004120A as u32,
            ITF::PRTH_E_RETRY => 0x8004120B as u32,
            ITF::PRTH_E_MIME_EXCLUDED => 0x8004120D as u32,
            ITF::PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL => 0x8004120E as u32,
            ITF::PRTH_E_CANT_TRANSFORM_DENIED_ACE => 0x8004120F as u32,
            ITF::PRTH_E_ACL_IS_READ_NONE => 0x80041211 as u32,
            ITF::PRTH_E_ACL_TOO_BIG => 0x80041212 as u32,
            ITF::PRTH_E_NO_PROPERTY => 0x80041213 as u32,
            ITF::PRTH_E_DATABASE_OPEN_ERROR => 0x80041215 as u32,
            ITF::PRTH_E_OPLOCK_BROKEN => 0x80041216 as u32,
            ITF::PRTH_E_LOAD_FAILED => 0x80041217 as u32,
            ITF::PRTH_E_INIT_FAILED => 0x80041218 as u32,
            ITF::PRTH_E_VOLUME_MOUNT_POINT => 0x80041219 as u32,
            ITF::PRTH_E_TRUNCATED => 0x8004121A as u32,
            ITF::GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR => 0x8004121D as u32,
            ITF::PRTH_E_HTTPS_CERTIFICATE_ERROR => 0x80041223 as u32,
            ITF::PRTH_E_HTTPS_REQUIRE_CERTIFICATE => 0x80041224 as u32,
            ITF::SCHED_E_TRIGGER_NOT_FOUND => 0x80041309 as u32,
            ITF::SCHED_E_TASK_NOT_READY => 0x8004130A as u32,
            ITF::SCHED_E_TASK_NOT_RUNNING => 0x8004130B as u32,
            ITF::SCHED_E_SERVICE_NOT_INSTALLED => 0x8004130C as u32,
            ITF::SCHED_E_CANNOT_OPEN_TASK => 0x8004130D as u32,
            ITF::SCHED_E_INVALID_TASK => 0x8004130E as u32,
            ITF::SCHED_E_ACCOUNT_INFORMATION_NOT_SET => 0x8004130F as u32,
            ITF::SCHED_E_ACCOUNT_NAME_NOT_FOUND => 0x80041310 as u32,
            ITF::SCHED_E_ACCOUNT_DBASE_CORRUPT => 0x80041311 as u32,
            ITF::SCHED_E_NO_SECURITY_SERVICES => 0x80041312 as u32,
            ITF::SCHED_E_UNKNOWN_OBJECT_VERSION => 0x80041313 as u32,
            ITF::SCHED_E_UNSUPPORTED_ACCOUNT_OPTION => 0x80041314 as u32,
            ITF::SCHED_E_SERVICE_NOT_RUNNING => 0x80041315 as u32,
            ITF::SCHED_E_UNEXPECTEDNODE => 0x80041316 as u32,
            ITF::SCHED_E_NAMESPACE => 0x80041317 as u32,
            ITF::SCHED_E_INVALIDVALUE => 0x80041318 as u32,
            ITF::SCHED_E_MISSINGNODE => 0x80041319 as u32,
            ITF::SCHED_E_MALFORMEDXML => 0x8004131A as u32,
            ITF::SCHED_E_TOO_MANY_NODES => 0x8004131D as u32,
            ITF::SCHED_E_PAST_END_BOUNDARY => 0x8004131E as u32,
            ITF::SCHED_E_ALREADY_RUNNING => 0x8004131F as u32,
            ITF::SCHED_E_USER_NOT_LOGGED_ON => 0x80041320 as u32,
            ITF::SCHED_E_INVALID_TASK_HASH => 0x80041321 as u32,
            ITF::SCHED_E_SERVICE_NOT_AVAILABLE => 0x80041322 as u32,
            ITF::SCHED_E_SERVICE_TOO_BUSY => 0x80041323 as u32,
            ITF::SCHED_E_TASK_ATTEMPTED => 0x80041324 as u32,
            ITF::SCHED_E_TASK_DISABLED => 0x80041326 as u32,
            ITF::SCHED_E_TASK_NOT_V1_COMPAT => 0x80041327 as u32,
            ITF::SCHED_E_START_ON_DEMAND => 0x80041328 as u32,
            ITF::SCHED_E_TASK_NOT_UBPM_COMPAT => 0x80041329 as u32,
            ITF::SCHED_E_DEPRECATED_FEATURE_USED => 0x80041330 as u32,
            ITF::SEC_E_INITFAILED => 0x80041401 as u32,
            ITF::SEC_E_NOTINITIALIZED => 0x80041402 as u32,
            ITF::SEC_E_INVALIDCONTEXT => 0x80041403 as u32,
            ITF::SEC_E_ACCESSDENIED => 0x800414FF as u32,
            ITF::CMDLINE_E_UNEXPECTED => 0x80041501 as u32,
            ITF::CMDLINE_E_PAREN => 0x80041502 as u32,
            ITF::CMDLINE_E_PARAM_SIZE => 0x80041503 as u32,
            ITF::CMDLINE_E_NOT_INIT => 0x80041504 as u32,
            ITF::CMDLINE_E_ALREADY_INIT => 0x80041505 as u32,
            ITF::CMDLINE_E_NUM_PARAMS => 0x80041506 as u32,
            ITF::QUERY_E_FAILED => 0x80041600 as u32,
            ITF::SYNC_E_REGISTRATION_INTERNAL_ERROR => 0x80041600 as u32,
            ITF::QUERY_E_INVALIDQUERY => 0x80041601 as u32,
            ITF::SYNC_E_REGISTRATION_ALREADY_REGISTERED => 0x80041601 as u32,
            ITF::QUERY_E_INVALIDRESTRICTION => 0x80041602 as u32,
            ITF::SYNC_E_REGISTRATION_NOT_REGISTERED => 0x80041602 as u32,
            ITF::QUERY_E_INVALIDSORT => 0x80041603 as u32,
            ITF::SYNC_E_REGISTRATION_CORRUPT_DATA => 0x80041603 as u32,
            ITF::QUERY_E_INVALIDCATEGORIZE => 0x80041604 as u32,
            ITF::SYNC_E_REGISTRATION_ALREADY_COMMITTED => 0x80041604 as u32,
            ITF::QUERY_E_ALLNOISE => 0x80041605 as u32,
            ITF::QUERY_E_TOOCOMPLEX => 0x80041606 as u32,
            ITF::QUERY_E_TIMEDOUT => 0x80041607 as u32,
            ITF::QUERY_E_DUPLICATE_OUTPUT_COLUMN => 0x80041608 as u32,
            ITF::QUERY_E_INVALID_OUTPUT_COLUMN => 0x80041609 as u32,
            ITF::QUERY_E_INVALID_DIRECTORY => 0x8004160A as u32,
            ITF::QUERY_E_DIR_ON_REMOVABLE_DRIVE => 0x8004160B as u32,
            ITF::QUERY_S_NO_QUERY => 0x8004160C as u32,
            ITF::QUERY_E_ALLNOISE_AND_NO_RELDOC => 0x8004160D as u32,
            ITF::QUERY_E_NO_RELDOC => 0x8004160E as u32,
            ITF::QUERY_E_ALLNOISE_AND_NO_RELPROP => 0x8004160F as u32,
            ITF::QUERY_E_NO_RELPROP => 0x80041610 as u32,
            ITF::QUERY_E_REPEATED_RELDOC => 0x80041611 as u32,
            ITF::QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED => 0x80041612 as u32,
            ITF::QUERY_E_INVALID_DOCUMENT_IDENTIFIER => 0x80041613 as u32,
            ITF::QUERY_E_INCORRECT_VERSION => 0x80041614 as u32,
            ITF::QUERY_E_INVALIDSCOPE_COALESCE => 0x80041615 as u32,
            ITF::QUERY_E_INVALIDSORT_COALESCE => 0x80041616 as u32,
            ITF::QUERY_E_INVALIDCOALESCE => 0x80041617 as u32,
            ITF::QUERY_E_UPGRADEINPROGRESS => 0x80041618 as u32,
            ITF::QUERY_E_AGGREGATE_NOT_SUPPORTED => 0x80041619 as u32,
            ITF::QUERY_E_TOP_LEVEL_IN_GROUP => 0x8004161A as u32,
            ITF::QUERY_E_DUPLICATE_RANGE_NAME => 0x8004161B as u32,
            ITF::QPLIST_E_CANT_OPEN_FILE => 0x80041651 as u32,
            ITF::QPLIST_E_READ_ERROR => 0x80041652 as u32,
            ITF::QPLIST_E_EXPECTING_NAME => 0x80041653 as u32,
            ITF::QPLIST_E_EXPECTING_TYPE => 0x80041654 as u32,
            ITF::QPLIST_E_UNRECOGNIZED_TYPE => 0x80041655 as u32,
            ITF::QPLIST_E_EXPECTING_INTEGER => 0x80041656 as u32,
            ITF::QPLIST_E_EXPECTING_CLOSE_PAREN => 0x80041657 as u32,
            ITF::QPLIST_E_EXPECTING_GUID => 0x80041658 as u32,
            ITF::QPLIST_E_BAD_GUID => 0x80041659 as u32,
            ITF::QPLIST_E_EXPECTING_PROP_SPEC => 0x8004165A as u32,
            ITF::QPLIST_E_CANT_SET_PROPERTY => 0x8004165B as u32,
            ITF::QPLIST_E_DUPLICATE => 0x8004165C as u32,
            ITF::QPLIST_E_VECTORBYREF_USED_ALONE => 0x8004165D as u32,
            ITF::QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE => 0x8004165E as u32,
            ITF::QPARSE_E_UNEXPECTED_NOT => 0x80041660 as u32,
            ITF::QPARSE_E_EXPECTING_INTEGER => 0x80041661 as u32,
            ITF::QPARSE_E_EXPECTING_REAL => 0x80041662 as u32,
            ITF::QPARSE_E_EXPECTING_DATE => 0x80041663 as u32,
            ITF::QPARSE_E_EXPECTING_CURRENCY => 0x80041664 as u32,
            ITF::QPARSE_E_EXPECTING_GUID => 0x80041665 as u32,
            ITF::QPARSE_E_EXPECTING_BRACE => 0x80041666 as u32,
            ITF::QPARSE_E_EXPECTING_PAREN => 0x80041667 as u32,
            ITF::QPARSE_E_EXPECTING_PROPERTY => 0x80041668 as u32,
            ITF::QPARSE_E_NOT_YET_IMPLEMENTED => 0x80041669 as u32,
            ITF::QPARSE_E_EXPECTING_PHRASE => 0x8004166A as u32,
            ITF::QPARSE_E_UNSUPPORTED_PROPERTY_TYPE => 0x8004166B as u32,
            ITF::QPARSE_E_EXPECTING_REGEX => 0x8004166C as u32,
            ITF::QPARSE_E_EXPECTING_REGEX_PROPERTY => 0x8004166D as u32,
            ITF::QPARSE_E_INVALID_LITERAL => 0x8004166E as u32,
            ITF::QPARSE_E_NO_SUCH_PROPERTY => 0x8004166F as u32,
            ITF::QPARSE_E_EXPECTING_EOS => 0x80041670 as u32,
            ITF::QPARSE_E_EXPECTING_COMMA => 0x80041671 as u32,
            ITF::QPARSE_E_UNEXPECTED_EOS => 0x80041672 as u32,
            ITF::QPARSE_E_WEIGHT_OUT_OF_RANGE => 0x80041673 as u32,
            ITF::QPARSE_E_NO_SUCH_SORT_PROPERTY => 0x80041674 as u32,
            ITF::QPARSE_E_INVALID_SORT_ORDER => 0x80041675 as u32,
            ITF::QUTIL_E_CANT_CONVERT_VROOT => 0x80041676 as u32,
            ITF::QPARSE_E_INVALID_GROUPING => 0x80041677 as u32,
            ITF::QPARSE_E_INVALID_QUERY => 0x8004167A as u32,
            ITF::QPARSE_E_INVALID_RANKMETHOD => 0x8004167B as u32,
            ITF::FDAEMON_E_LOWRESOURCE => 0x80041681 as u32,
            ITF::FDAEMON_E_FATALERROR => 0x80041682 as u32,
            ITF::FDAEMON_E_PARTITIONDELETED => 0x80041683 as u32,
            ITF::FDAEMON_E_CHANGEUPDATEFAILED => 0x80041684 as u32,
            ITF::FDAEMON_E_WORDLISTCOMMITFAILED => 0x80041686 as u32,
            ITF::FDAEMON_E_NOWORDLIST => 0x80041687 as u32,
            ITF::FDAEMON_E_TOOMANYFILTEREDBLOCKS => 0x80041688 as u32,
            ITF::SEARCH_E_NOMONIKER => 0x800416A1 as u32,
            ITF::SEARCH_E_NOREGION => 0x800416A2 as u32,
            ITF::FILTER_E_END_OF_CHUNKS => 0x80041700 as u32,
            ITF::FILTER_E_NO_MORE_TEXT => 0x80041701 as u32,
            ITF::FILTER_E_NO_MORE_VALUES => 0x80041702 as u32,
            ITF::FILTER_E_ACCESS => 0x80041703 as u32,
            ITF::FILTER_E_NO_TEXT => 0x80041705 as u32,
            ITF::FILTER_E_NO_VALUES => 0x80041706 as u32,
            ITF::FILTER_E_EMBEDDING_UNAVAILABLE => 0x80041707 as u32,
            ITF::FILTER_E_LINK_UNAVAILABLE => 0x80041708 as u32,
            ITF::FILTER_E_PASSWORD => 0x8004170B as u32,
            ITF::FILTER_E_UNKNOWNFORMAT => 0x8004170C as u32,
            ITF::FILTER_E_TOO_BIG => 0x80041730 as u32,
            ITF::FILTER_E_ALREADY_OPEN => 0x80041736 as u32,
            ITF::FILTER_E_UNREACHABLE => 0x80041737 as u32,
            ITF::FILTER_E_IN_USE => 0x80041738 as u32,
            ITF::FILTER_E_NOT_OPEN => 0x80041739 as u32,
            ITF::FILTER_E_NO_SUCH_PROPERTY => 0x8004173B as u32,
            ITF::FILTER_E_OFFLINE => 0x8004173D as u32,
            ITF::FILTER_E_PARTIALLY_FILTERED => 0x8004173E as u32,
            ITF::WBREAK_E_END_OF_TEXT => 0x80041780 as u32,
            ITF::WBREAK_E_QUERY_ONLY => 0x80041782 as u32,
            ITF::WBREAK_E_BUFFER_TOO_SMALL => 0x80041783 as u32,
            ITF::LANGUAGE_E_DATABASE_NOT_FOUND => 0x80041784 as u32,
            ITF::WBREAK_E_INIT_FAILED => 0x80041785 as u32,
            ITF::PSINK_E_QUERY_ONLY => 0x80041790 as u32,
            ITF::PSINK_E_INDEX_ONLY => 0x80041791 as u32,
            ITF::PSINK_E_LARGE_ATTACHMENT => 0x80041792 as u32,
            ITF::CI_E_ALREADY_INITIALIZED => 0x8004180A as u32,
            ITF::CI_E_NOT_INITIALIZED => 0x8004180B as u32,
            ITF::CI_E_BUFFERTOOSMALL => 0x8004180C as u32,
            ITF::CI_E_PROPERTY_NOT_CACHED => 0x8004180D as u32,
            ITF::CI_E_INVALID_STATE => 0x8004180F as u32,
            ITF::CI_E_FILTERING_DISABLED => 0x80041810 as u32,
            ITF::CI_E_DISK_FULL => 0x80041811 as u32,
            ITF::CI_E_SHUTDOWN => 0x80041812 as u32,
            ITF::CI_E_WORKID_NOTVALID => 0x80041813 as u32,
            ITF::CI_E_NOT_FOUND => 0x80041815 as u32,
            ITF::CI_E_USE_DEFAULT_PID => 0x80041816 as u32,
            ITF::CI_E_DUPLICATE_NOTIFICATION => 0x80041817 as u32,
            ITF::CI_E_UPDATES_DISABLED => 0x80041818 as u32,
            ITF::CI_E_INVALID_FLAGS_COMBINATION => 0x80041819 as u32,
            ITF::CI_E_OUTOFSEQ_INCREMENT_DATA => 0x8004181A as u32,
            ITF::CI_E_SHARING_VIOLATION => 0x8004181B as u32,
            ITF::CI_E_LOGON_FAILURE => 0x8004181C as u32,
            ITF::CI_E_NO_CATALOG => 0x8004181D as u32,
            ITF::CI_E_STRANGE_PAGEORSECTOR_SIZE => 0x8004181E as u32,
            ITF::CI_E_TIMEOUT => 0x8004181F as u32,
            ITF::CI_E_NOT_RUNNING => 0x80041820 as u32,
            ITF::CI_E_CARDINALITY_MISMATCH => 0x80041827 as u32,
            ITF::CI_E_CONFIG_DISK_FULL => 0x80041828 as u32,
            ITF::CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED => 0x80041829 as u32,
            ITF::CI_E_NO_AUXMETADATA => 0x8004182A as u32,
            ITF::CI_E_INVALID_CATALOG_LIST_VERSION => 0x8004182F as u32,
            ITF::NLADMIN_E_DUPLICATE_CATALOG => 0x80041901 as u32,
            ITF::NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE => 0x80041903 as u32,
            ITF::NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED => 0x80041904 as u32,
            ITF::FAX_E_SRV_OUTOFMEMORY => 0x80041B59 as u32,
            ITF::FAX_E_GROUP_NOT_FOUND => 0x80041B5A as u32,
            ITF::FAX_E_BAD_GROUP_CONFIGURATION => 0x80041B5B as u32,
            ITF::FAX_E_GROUP_IN_USE => 0x80041B5C as u32,
            ITF::FAX_E_RULE_NOT_FOUND => 0x80041B5D as u32,
            ITF::FAX_E_NOT_NTFS => 0x80041B5E as u32,
            ITF::FAX_E_DIRECTORY_IN_USE => 0x80041B5F as u32,
            ITF::FAX_E_FILE_ACCESS_DENIED => 0x80041B60 as u32,
            ITF::FAX_E_MESSAGE_NOT_FOUND => 0x80041B61 as u32,
            ITF::FAX_E_DEVICE_NUM_LIMIT_EXCEEDED => 0x80041B62 as u32,
            ITF::FAX_E_NOT_SUPPORTED_ON_THIS_SKU => 0x80041B63 as u32,
            ITF::FAX_E_VERSION_MISMATCH => 0x80041B64 as u32,
            ITF::FAX_E_RECIPIENTS_LIMIT => 0x80041B65 as u32,
            ITF::SCRIPTPI_E_CHUNK_NOT_TEXT => 0x80042000 as u32,
            ITF::SCRIPTPI_E_PID_NOT_NAME => 0x80042001 as u32,
            ITF::SCRIPTPI_E_PID_NOT_NUMERIC => 0x80042002 as u32,
            ITF::SCRIPTPI_E_CHUNK_NOT_VALUE => 0x80042003 as u32,
            ITF::SCRIPTPI_E_CANNOT_ALTER_CHUNK => 0x80042004 as u32,
            ITF::SCRIPTPI_E_ALREADY_COMPLETED => 0x80042005 as u32,
            ITF::MSS_E_INVALIDAPPNAME => 0x80042100 as u32,
            ITF::MSS_E_APPNOTFOUND => 0x80042101 as u32,
            ITF::MSS_E_APPALREADYEXISTS => 0x80042102 as u32,
            ITF::MSS_E_CATALOGNOTFOUND => 0x80042103 as u32,
            ITF::MSS_E_CATALOGSTOPPING => 0x80042104 as u32,
            ITF::MSS_E_UNICODEFILEHEADERMISSING => 0x80042105 as u32,
            ITF::MSS_E_CATALOGALREADYEXISTS => 0x80042106 as u32,
            ITF::XML_E_NODEFAULTNS => 0x80042200 as u32,
            ITF::XML_E_BADSXQL => 0x80042201 as u32,
            ITF::VSS_E_BAD_STATE => 0x80042301 as u32,
            ITF::VSS_E_UNEXPECTED => 0x80042302 as u32,
            ITF::VSS_E_PROVIDER_ALREADY_REGISTERED => 0x80042303 as u32,
            ITF::VSS_E_PROVIDER_NOT_REGISTERED => 0x80042304 as u32,
            ITF::VSS_E_PROVIDER_VETO => 0x80042306 as u32,
            ITF::VSS_E_PROVIDER_IN_USE => 0x80042307 as u32,
            ITF::VSS_E_OBJECT_NOT_FOUND => 0x80042308 as u32,
            ITF::VSS_E_VOLUME_NOT_SUPPORTED => 0x8004230C as u32,
            ITF::VSS_E_OBJECT_ALREADY_EXISTS => 0x8004230D as u32,
            ITF::VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER => 0x8004230E as u32,
            ITF::VSS_E_UNEXPECTED_PROVIDER_ERROR => 0x8004230F as u32,
            ITF::VSS_E_CORRUPT_XML_DOCUMENT => 0x80042310 as u32,
            ITF::VSS_E_INVALID_XML_DOCUMENT => 0x80042311 as u32,
            ITF::VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED => 0x80042312 as u32,
            ITF::VSS_E_FLUSH_WRITES_TIMEOUT => 0x80042313 as u32,
            ITF::VSS_E_HOLD_WRITES_TIMEOUT => 0x80042314 as u32,
            ITF::VSS_E_UNEXPECTED_WRITER_ERROR => 0x80042315 as u32,
            ITF::VSS_E_SNAPSHOT_SET_IN_PROGRESS => 0x80042316 as u32,
            ITF::VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED => 0x80042317 as u32,
            ITF::VSS_E_WRITER_INFRASTRUCTURE => 0x80042318 as u32,
            ITF::VSS_E_WRITER_NOT_RESPONDING => 0x80042319 as u32,
            ITF::VSS_E_WRITER_ALREADY_SUBSCRIBED => 0x8004231A as u32,
            ITF::VSS_E_UNSUPPORTED_CONTEXT => 0x8004231B as u32,
            ITF::VSS_E_VOLUME_IN_USE => 0x8004231D as u32,
            ITF::VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED => 0x8004231E as u32,
            ITF::VSS_E_INSUFFICIENT_STORAGE => 0x8004231F as u32,
            ITF::VSS_E_NO_SNAPSHOTS_IMPORTED => 0x80042320 as u32,
            ITF::VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED => 0x80042321 as u32,
            ITF::VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED => 0x80042322 as u32,
            ITF::VSS_E_REMOTE_SERVER_UNAVAILABLE => 0x80042323 as u32,
            ITF::VSS_E_REMOTE_SERVER_UNSUPPORTED => 0x80042324 as u32,
            ITF::VSS_E_REVERT_IN_PROGRESS => 0x80042325 as u32,
            ITF::VSS_E_REVERT_VOLUME_LOST => 0x80042326 as u32,
            ITF::VSS_E_REBOOT_REQUIRED => 0x80042327 as u32,
            ITF::VSS_E_TRANSACTION_FREEZE_TIMEOUT => 0x80042328 as u32,
            ITF::VSS_E_TRANSACTION_THAW_TIMEOUT => 0x80042329 as u32,
            ITF::VSS_E_UNSELECTED_VOLUME => 0x8004232A as u32,
            ITF::VSS_E_SNAPSHOT_NOT_IN_SET => 0x8004232B as u32,
            ITF::VSS_E_NESTED_VOLUME_LIMIT => 0x8004232C as u32,
            ITF::VSS_E_VOLUME_NOT_LOCAL => 0x8004232D as u32,
            ITF::VSS_E_CLUSTER_TIMEOUT => 0x8004232E as u32,
            ITF::VSS_E_NOT_SUPPORTED => 0x8004232F as u32,
            ITF::VSS_E_WRITERERROR_PARTIAL_FAILURE => 0x80042336 as u32,
            ITF::VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT => 0x800423F0 as u32,
            ITF::VSS_E_WRITERERROR_OUTOFRESOURCES => 0x800423F1 as u32,
            ITF::VSS_E_WRITERERROR_TIMEOUT => 0x800423F2 as u32,
            ITF::VSS_E_WRITERERROR_RETRYABLE => 0x800423F3 as u32,
            ITF::VSS_E_WRITERERROR_NONRETRYABLE => 0x800423F4 as u32,
            ITF::VSS_E_WRITERERROR_RECOVERY_FAILED => 0x800423F5 as u32,
            ITF::VSS_E_BREAK_REVERT_ID_FAILED => 0x800423F6 as u32,
            ITF::VSS_E_LEGACY_PROVIDER => 0x800423F7 as u32,
            ITF::VSS_E_MISSING_DISK => 0x800423F8 as u32,
            ITF::VSS_E_MISSING_HIDDEN_VOLUME => 0x800423F9 as u32,
            ITF::VSS_E_MISSING_VOLUME => 0x800423FA as u32,
            ITF::VSS_E_AUTORECOVERY_FAILED => 0x800423FB as u32,
            ITF::VSS_E_DYNAMIC_DISK_ERROR => 0x800423FC as u32,
            ITF::VSS_E_NONTRANSPORTABLE_BCD => 0x800423FD as u32,
            ITF::VSS_E_CANNOT_REVERT_DISKID => 0x800423FE as u32,
            ITF::VSS_E_RESYNC_IN_PROGRESS => 0x800423FF as u32,
            ITF::VDS_E_NOT_SUPPORTED => 0x80042400 as u32,
            ITF::VSS_E_CLUSTER_ERROR => 0x80042400 as u32,
            ITF::FLTRDMN_E_UNEXPECTED => 0x80042401 as u32,
            ITF::VDS_E_INITIALIZED_FAILED => 0x80042401 as u32,
            ITF::VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED => 0x80042401 as u32,
            ITF::FLTRDMN_E_QI_FILTER_FAILED => 0x80042402 as u32,
            ITF::VDS_E_INITIALIZE_NOT_CALLED => 0x80042402 as u32,
            ITF::VSS_E_ASRERROR_DISK_RECREATION_FAILED => 0x80042402 as u32,
            ITF::VDS_E_ALREADY_REGISTERED => 0x80042403 as u32,
            ITF::VSS_E_ASRERROR_NO_ARCPATH => 0x80042403 as u32,
            ITF::FLTRDMN_E_FILTER_INIT_FAILED => 0x80042404 as u32,
            ITF::VDS_E_ANOTHER_CALL_IN_PROGRESS => 0x80042404 as u32,
            ITF::VSS_E_ASRERROR_MISSING_DYNDISK => 0x80042404 as u32,
            ITF::FLTRDMN_E_ENCRYPTED_DOCUMENT => 0x80042405 as u32,
            ITF::VDS_E_OBJECT_NOT_FOUND => 0x80042405 as u32,
            ITF::VSS_E_ASRERROR_SHARED_CRIDISK => 0x80042405 as u32,
            ITF::FLTRDMN_E_CANNOT_DECRYPT_PASSWORD => 0x80042406 as u32,
            ITF::VDS_E_INVALID_SPACE => 0x80042406 as u32,
            ITF::VSS_E_ASRERROR_DATADISK_RDISK0 => 0x80042406 as u32,
            ITF::VDS_E_PARTITION_LIMIT_REACHED => 0x80042407 as u32,
            ITF::VSS_E_ASRERROR_RDISK0_TOOSMALL => 0x80042407 as u32,
            ITF::VDS_E_PARTITION_NOT_EMPTY => 0x80042408 as u32,
            ITF::VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL => 0x80042408 as u32,
            ITF::VDS_E_OPERATION_PENDING => 0x80042409 as u32,
            ITF::VSS_E_WRITER_STATUS_NOT_AVAILABLE => 0x80042409 as u32,
            ITF::VDS_E_OPERATION_DENIED => 0x8004240A as u32,
            ITF::VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED => 0x8004240A as u32,
            ITF::VDS_E_OBJECT_DELETED => 0x8004240B as u32,
            ITF::VDS_E_CANCEL_TOO_LATE => 0x8004240C as u32,
            ITF::VDS_E_OPERATION_CANCELED => 0x8004240D as u32,
            ITF::VDS_E_CANNOT_EXTEND => 0x8004240E as u32,
            ITF::VDS_E_NOT_ENOUGH_SPACE => 0x8004240F as u32,
            ITF::VDS_E_NOT_ENOUGH_DRIVE => 0x80042410 as u32,
            ITF::VDS_E_BAD_COOKIE => 0x80042411 as u32,
            ITF::VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK => 0x80042411 as u32,
            ITF::VDS_E_NO_MEDIA => 0x80042412 as u32,
            ITF::VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND => 0x80042412 as u32,
            ITF::VDS_E_DEVICE_IN_USE => 0x80042413 as u32,
            ITF::VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE => 0x80042413 as u32,
            ITF::VDS_E_DISK_NOT_EMPTY => 0x80042414 as u32,
            ITF::VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION => 0x80042414 as u32,
            ITF::VDS_E_INVALID_OPERATION => 0x80042415 as u32,
            ITF::VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED => 0x80042415 as u32,
            ITF::VDS_E_PATH_NOT_FOUND => 0x80042416 as u32,
            ITF::VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN => 0x80042416 as u32,
            ITF::VDS_E_DISK_NOT_INITIALIZED => 0x80042417 as u32,
            ITF::VSS_E_FSS_TIMEOUT => 0x80042417 as u32,
            ITF::VDS_E_NOT_AN_UNALLOCATED_DISK => 0x80042418 as u32,
            ITF::VDS_E_UNRECOVERABLE_ERROR => 0x80042419 as u32,
            ITF::VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED => 0x8004241B as u32,
            ITF::VDS_E_PROVIDER_INITIALIZATION_FAILED => 0x8004241C as u32,
            ITF::VDS_E_OBJECT_EXISTS => 0x8004241D as u32,
            ITF::VDS_E_NO_DISKS_FOUND => 0x8004241E as u32,
            ITF::VDS_E_PROVIDER_CACHE_CORRUPT => 0x8004241F as u32,
            ITF::VDS_E_DMADMIN_METHOD_CALL_FAILED => 0x80042420 as u32,
            ITF::VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND => 0x80042422 as u32,
            ITF::VDS_E_PROVIDER_VOL_OPEN => 0x80042423 as u32,
            ITF::VDS_E_DMADMIN_CORRUPT_NOTIFICATION => 0x80042424 as u32,
            ITF::VDS_E_INCOMPATIBLE_FILE_SYSTEM => 0x80042425 as u32,
            ITF::VDS_E_INCOMPATIBLE_MEDIA => 0x80042426 as u32,
            ITF::VDS_E_ACCESS_DENIED => 0x80042427 as u32,
            ITF::VDS_E_MEDIA_WRITE_PROTECTED => 0x80042428 as u32,
            ITF::VDS_E_BAD_LABEL => 0x80042429 as u32,
            ITF::VDS_E_CANT_QUICK_FORMAT => 0x8004242A as u32,
            ITF::VDS_E_IO_ERROR => 0x8004242B as u32,
            ITF::VDS_E_VOLUME_TOO_SMALL => 0x8004242C as u32,
            ITF::VDS_E_VOLUME_TOO_BIG => 0x8004242D as u32,
            ITF::VDS_E_CLUSTER_SIZE_TOO_SMALL => 0x8004242E as u32,
            ITF::VDS_E_CLUSTER_SIZE_TOO_BIG => 0x8004242F as u32,
            ITF::VDS_E_CLUSTER_COUNT_BEYOND_32BITS => 0x80042430 as u32,
            ITF::VDS_E_OBJECT_STATUS_FAILED => 0x80042431 as u32,
            ITF::VDS_E_VOLUME_INCOMPLETE => 0x80042432 as u32,
            ITF::VDS_E_EXTENT_SIZE_LESS_THAN_MIN => 0x80042433 as u32,
            ITF::VDS_E_BOOT_PARTITION_NUMBER_CHANGE => 0x80042436 as u32,
            ITF::VDS_E_NO_FREE_SPACE => 0x80042437 as u32,
            ITF::VDS_E_ACTIVE_PARTITION => 0x80042438 as u32,
            ITF::VDS_E_PARTITION_OF_UNKNOWN_TYPE => 0x80042439 as u32,
            ITF::VDS_E_LEGACY_VOLUME_FORMAT => 0x8004243A as u32,
            ITF::VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS => 0x8004243B as u32,
            ITF::VDS_E_MIGRATE_OPEN_VOLUME => 0x8004243C as u32,
            ITF::VDS_E_VOLUME_NOT_ONLINE => 0x8004243D as u32,
            ITF::VDS_E_VOLUME_NOT_HEALTHY => 0x8004243E as u32,
            ITF::VDS_E_VOLUME_SPANS_DISKS => 0x8004243F as u32,
            ITF::VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE => 0x80042440 as u32,
            ITF::VDS_E_BAD_PROVIDER_DATA => 0x80042441 as u32,
            ITF::VDS_E_PROVIDER_FAILURE => 0x80042442 as u32,
            ITF::VDS_E_PACK_OFFLINE => 0x80042444 as u32,
            ITF::VDS_E_VOLUME_NOT_A_MIRROR => 0x80042445 as u32,
            ITF::VDS_E_NO_EXTENTS_FOR_VOLUME => 0x80042446 as u32,
            ITF::VDS_E_DISK_NOT_LOADED_TO_CACHE => 0x80042447 as u32,
            ITF::VDS_E_INTERNAL_ERROR => 0x80042448 as u32,
            ITF::VDS_E_PROVIDER_TYPE_NOT_SUPPORTED => 0x8004244A as u32,
            ITF::VDS_E_DISK_NOT_ONLINE => 0x8004244B as u32,
            ITF::VDS_E_DISK_IN_USE_BY_VOLUME => 0x8004244C as u32,
            ITF::VDS_E_ASYNC_OBJECT_FAILURE => 0x8004244E as u32,
            ITF::VDS_E_VOLUME_NOT_MOUNTED => 0x8004244F as u32,
            ITF::VDS_E_PACK_NOT_FOUND => 0x80042450 as u32,
            ITF::VDS_E_IMPORT_SET_INCOMPLETE => 0x80042451 as u32,
            ITF::VDS_E_DISK_NOT_IMPORTED => 0x80042452 as u32,
            ITF::VDS_E_OBJECT_OUT_OF_SYNC => 0x80042453 as u32,
            ITF::VDS_E_MISSING_DISK => 0x80042454 as u32,
            ITF::VDS_E_DISK_PNP_REG_CORRUPT => 0x80042455 as u32,
            ITF::VDS_E_LBN_REMAP_ENABLED_FLAG => 0x80042456 as u32,
            ITF::VDS_E_NO_DRIVELETTER_FLAG => 0x80042457 as u32,
            ITF::VDS_E_REVERT_ON_CLOSE => 0x80042458 as u32,
            ITF::VDS_E_REVERT_ON_CLOSE_SET => 0x80042459 as u32,
            ITF::VDS_E_IA64_BOOT_MIRRORED_TO_MBR => 0x8004245A as u32,
            ITF::VDS_E_VOLUME_TEMPORARILY_DISMOUNTED => 0x8004245C as u32,
            ITF::VDS_E_VOLUME_PERMANENTLY_DISMOUNTED => 0x8004245D as u32,
            ITF::VDS_E_VOLUME_HAS_PATH => 0x8004245E as u32,
            ITF::VDS_E_TIMEOUT => 0x8004245F as u32,
            ITF::VDS_E_REPAIR_VOLUMESTATE => 0x80042460 as u32,
            ITF::VDS_E_LDM_TIMEOUT => 0x80042461 as u32,
            ITF::VDS_E_REVERT_ON_CLOSE_MISMATCH => 0x80042462 as u32,
            ITF::VDS_E_RETRY => 0x80042463 as u32,
            ITF::VDS_E_ONLINE_PACK_EXISTS => 0x80042464 as u32,
            ITF::VDS_E_EXTEND_FILE_SYSTEM_FAILED => 0x80042466 as u32,
            ITF::VDS_E_MAX_USABLE_MBR => 0x80042468 as u32,
            ITF::VDS_S_GPT_BOOT_MIRRORED_TO_MBR => 0x80042469 as u32,
            ITF::OLEDB_BINDER_CUSTOM_ERROR => 0x80042500 as u32,
            ITF::VDS_E_NO_SOFTWARE_PROVIDERS_LOADED => 0x80042500 as u32,
            ITF::VDS_E_DISK_NOT_MISSING => 0x80042501 as u32,
            ITF::VDS_E_NO_VOLUME_LAYOUT => 0x80042502 as u32,
            ITF::VDS_E_CORRUPT_VOLUME_INFO => 0x80042503 as u32,
            ITF::VDS_E_INVALID_ENUMERATOR => 0x80042504 as u32,
            ITF::VDS_E_DRIVER_INTERNAL_ERROR => 0x80042505 as u32,
            ITF::VDS_E_VOLUME_INVALID_NAME => 0x80042507 as u32,
            ITF::VDS_E_CORRUPT_PARTITION_INFO => 0x80042509 as u32,
            ITF::VDS_E_CORRUPT_EXTENT_INFO => 0x8004250B as u32,
            ITF::VDS_E_DUP_EMPTY_PACK_GUID => 0x8004250C as u32,
            ITF::VDS_E_DRIVER_NO_PACK_NAME => 0x8004250D as u32,
            ITF::VDS_E_BAD_PNP_MESSAGE => 0x8004250F as u32,
            ITF::VDS_E_NO_PNP_DISK_ARRIVE => 0x80042510 as u32,
            ITF::VDS_E_NO_PNP_VOLUME_ARRIVE => 0x80042511 as u32,
            ITF::VDS_E_NO_PNP_DISK_REMOVE => 0x80042512 as u32,
            ITF::VDS_E_NO_PNP_VOLUME_REMOVE => 0x80042513 as u32,
            ITF::VDS_E_PROVIDER_EXITING => 0x80042514 as u32,
            ITF::VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE => 0x80042515 as u32,
            ITF::VDS_E_MEMBER_SIZE_INVALID => 0x80042516 as u32,
            ITF::VDS_E_INVALID_DISK => 0x80042519 as u32,
            ITF::VDS_E_INVALID_PACK => 0x8004251A as u32,
            ITF::VDS_E_VOLUME_ON_DISK => 0x8004251B as u32,
            ITF::VDS_E_DRIVER_INVALID_PARAM => 0x8004251C as u32,
            ITF::VDS_E_TARGET_PACK_NOT_EMPTY => 0x8004251D as u32,
            ITF::VDS_E_CANNOT_SHRINK => 0x8004251E as u32,
            ITF::VDS_E_MULTIPLE_PACKS => 0x8004251F as u32,
            ITF::VDS_E_PACK_ONLINE => 0x80042520 as u32,
            ITF::VDS_E_INVALID_PLEX_COUNT => 0x80042521 as u32,
            ITF::VDS_E_INVALID_MEMBER_COUNT => 0x80042522 as u32,
            ITF::VDS_E_INVALID_PLEX_ORDER => 0x80042523 as u32,
            ITF::VDS_E_INVALID_MEMBER_ORDER => 0x80042524 as u32,
            ITF::VDS_E_INVALID_STRIPE_SIZE => 0x80042525 as u32,
            ITF::VDS_E_INVALID_DISK_COUNT => 0x80042526 as u32,
            ITF::VDS_E_INVALID_EXTENT_COUNT => 0x80042527 as u32,
            ITF::VDS_E_SOURCE_IS_TARGET_PACK => 0x80042528 as u32,
            ITF::VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED => 0x80042529 as u32,
            ITF::VDS_E_CORRUPT_NOTIFICATION_INFO => 0x8004252A as u32,
            ITF::VDS_E_INVALID_PLEX_GUID => 0x8004252C as u32,
            ITF::VDS_E_DISK_NOT_FOUND_IN_PACK => 0x8004252D as u32,
            ITF::VDS_E_DUPLICATE_DISK => 0x8004252E as u32,
            ITF::VDS_E_LAST_VALID_DISK => 0x8004252F as u32,
            ITF::VDS_E_INVALID_SECTOR_SIZE => 0x80042530 as u32,
            ITF::VDS_E_ONE_EXTENT_PER_DISK => 0x80042531 as u32,
            ITF::VDS_E_INVALID_BLOCK_SIZE => 0x80042532 as u32,
            ITF::VDS_E_PLEX_SIZE_INVALID => 0x80042533 as u32,
            ITF::VDS_E_NO_EXTENTS_FOR_PLEX => 0x80042534 as u32,
            ITF::VDS_E_INVALID_PLEX_TYPE => 0x80042535 as u32,
            ITF::VDS_E_INVALID_PLEX_BLOCK_SIZE => 0x80042536 as u32,
            ITF::VDS_E_NO_HEALTHY_DISKS => 0x80042537 as u32,
            ITF::VDS_E_CONFIG_LIMIT => 0x80042538 as u32,
            ITF::VDS_E_DISK_CONFIGURATION_CORRUPTED => 0x80042539 as u32,
            ITF::VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC => 0x8004253A as u32,
            ITF::VDS_E_DISK_CONFIGURATION_UPDATE_FAILED => 0x8004253B as u32,
            ITF::VDS_E_DISK_DYNAMIC => 0x8004253C as u32,
            ITF::VDS_E_DRIVER_OBJECT_NOT_FOUND => 0x8004253D as u32,
            ITF::VDS_E_PARTITION_NOT_CYLINDER_ALIGNED => 0x8004253E as u32,
            ITF::VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL => 0x8004253F as u32,
            ITF::VDS_E_DISK_IO_FAILING => 0x80042540 as u32,
            ITF::VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED => 0x80042541 as u32,
            ITF::VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED => 0x80042542 as u32,
            ITF::VDS_E_GPT_ATTRIBUTES_INVALID => 0x80042543 as u32,
            ITF::VDS_E_MEMBER_IS_HEALTHY => 0x80042544 as u32,
            ITF::VDS_E_MEMBER_REGENERATING => 0x80042545 as u32,
            ITF::VDS_E_PACK_NAME_INVALID => 0x80042546 as u32,
            ITF::VDS_E_PLEX_IS_HEALTHY => 0x80042547 as u32,
            ITF::VDS_E_PLEX_LAST_ACTIVE => 0x80042548 as u32,
            ITF::VDS_E_PLEX_MISSING => 0x80042549 as u32,
            ITF::VDS_E_MEMBER_MISSING => 0x8004254A as u32,
            ITF::VDS_E_PLEX_REGENERATING => 0x8004254B as u32,
            ITF::VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE => 0x8004254D as u32,
            ITF::VDS_E_INVALID_VOLUME_LENGTH => 0x8004254E as u32,
            ITF::VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE => 0x8004254F as u32,
            ITF::VDS_E_VOLUME_NOT_RETAINED => 0x80042550 as u32,
            ITF::VDS_E_VOLUME_RETAINED => 0x80042551 as u32,
            ITF::VDS_E_ALIGN_BEYOND_FIRST_CYLINDER => 0x80042553 as u32,
            ITF::VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE => 0x80042554 as u32,
            ITF::VDS_E_ALIGN_NOT_ZERO => 0x80042555 as u32,
            ITF::VDS_E_CACHE_CORRUPT => 0x80042556 as u32,
            ITF::VDS_E_CANNOT_CLEAR_VOLUME_FLAG => 0x80042557 as u32,
            ITF::VDS_E_DISK_BEING_CLEANED => 0x80042558 as u32,
            ITF::VDS_E_DISK_NOT_CONVERTIBLE => 0x80042559 as u32,
            ITF::VDS_E_DISK_REMOVEABLE => 0x8004255A as u32,
            ITF::VDS_E_DISK_REMOVEABLE_NOT_EMPTY => 0x8004255B as u32,
            ITF::VDS_E_DRIVE_LETTER_NOT_FREE => 0x8004255C as u32,
            ITF::VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED => 0x8004255D as u32,
            ITF::VDS_E_INVALID_DRIVE_LETTER => 0x8004255E as u32,
            ITF::VDS_E_INVALID_DRIVE_LETTER_COUNT => 0x8004255F as u32,
            ITF::VDS_E_INVALID_FS_FLAG => 0x80042560 as u32,
            ITF::VDS_E_INVALID_FS_TYPE => 0x80042561 as u32,
            ITF::VDS_E_INVALID_OBJECT_TYPE => 0x80042562 as u32,
            ITF::VDS_E_INVALID_PARTITION_LAYOUT => 0x80042563 as u32,
            ITF::VDS_E_INVALID_PARTITION_STYLE => 0x80042564 as u32,
            ITF::VDS_E_INVALID_PARTITION_TYPE => 0x80042565 as u32,
            ITF::VDS_E_INVALID_PROVIDER_CLSID => 0x80042566 as u32,
            ITF::VDS_E_INVALID_PROVIDER_ID => 0x80042567 as u32,
            ITF::VDS_E_INVALID_PROVIDER_NAME => 0x80042568 as u32,
            ITF::VDS_E_INVALID_PROVIDER_TYPE => 0x80042569 as u32,
            ITF::VDS_E_INVALID_PROVIDER_VERSION_GUID => 0x8004256A as u32,
            ITF::VDS_E_INVALID_PROVIDER_VERSION_STRING => 0x8004256B as u32,
            ITF::VDS_E_INVALID_QUERY_PROVIDER_FLAG => 0x8004256C as u32,
            ITF::VDS_E_INVALID_SERVICE_FLAG => 0x8004256D as u32,
            ITF::VDS_E_INVALID_VOLUME_FLAG => 0x8004256E as u32,
            ITF::VDS_E_PARTITION_NOT_OEM => 0x8004256F as u32,
            ITF::VDS_E_PARTITION_PROTECTED => 0x80042570 as u32,
            ITF::VDS_E_PARTITION_STYLE_MISMATCH => 0x80042571 as u32,
            ITF::VDS_E_PROVIDER_INTERNAL_ERROR => 0x80042572 as u32,
            ITF::VDS_E_SHRINK_SIZE_LESS_THAN_MIN => 0x80042573 as u32,
            ITF::VDS_E_SHRINK_SIZE_TOO_BIG => 0x80042574 as u32,
            ITF::VDS_E_UNRECOVERABLE_PROVIDER_ERROR => 0x80042575 as u32,
            ITF::VDS_E_VOLUME_HIDDEN => 0x80042576 as u32,
            ITF::VDS_E_FLAG_ALREADY_SET => 0x80042579 as u32,
            ITF::VDS_E_DISTINCT_VOLUME => 0x8004257B as u32,
            ITF::VDS_E_VOLUME_NOT_FOUND_IN_PACK => 0x8004257C as u32,
            ITF::VDS_E_PARTITION_NON_DATA => 0x8004257D as u32,
            ITF::VDS_E_CRITICAL_PLEX => 0x8004257E as u32,
            ITF::VDS_E_VOLUME_SYNCHRONIZING => 0x8004257F as u32,
            ITF::VDS_E_VOLUME_REGENERATING => 0x80042580 as u32,
            ITF::VDS_E_READONLY => 0x80042584 as u32,
            ITF::VDS_E_INVALID_VOLUME_TYPE => 0x80042585 as u32,
            ITF::VDS_E_BAD_BOOT_DISK => 0x80042586 as u32,
            ITF::VDS_E_LOG_UPDATE => 0x80042587 as u32,
            ITF::VDS_E_VOLUME_MIRRORED => 0x80042588 as u32,
            ITF::VDS_E_VOLUME_SIMPLE_SPANNED => 0x80042589 as u32,
            ITF::VDS_E_NO_VALID_LOG_COPIES => 0x8004258A as u32,
            ITF::VDS_E_PLEX_NOT_LOADED_TO_CACHE => 0x8004258B as u32,
            ITF::VDS_E_PARTITION_MSR => 0x8004258C as u32,
            ITF::VDS_E_PARTITION_LDM => 0x8004258D as u32,
            ITF::VDS_E_ALIGN_NOT_A_POWER_OF_TWO => 0x8004258F as u32,
            ITF::VDS_E_ALIGN_IS_ZERO => 0x80042590 as u32,
            ITF::VDS_E_SHRINK_IN_PROGRESS => 0x80042591 as u32,
            ITF::VDS_E_CANT_INVALIDATE_FVE => 0x80042592 as u32,
            ITF::VDS_E_FS_NOT_DETERMINED => 0x80042593 as u32,
            ITF::VDS_E_DISK_NOT_OFFLINE => 0x80042595 as u32,
            ITF::VDS_E_FAILED_TO_ONLINE_DISK => 0x80042596 as u32,
            ITF::VDS_E_FAILED_TO_OFFLINE_DISK => 0x80042597 as u32,
            ITF::VDS_E_BAD_REVISION_NUMBER => 0x80042598 as u32,
            ITF::VDS_E_SHRINK_USER_CANCELLED => 0x80042599 as u32,
            ITF::VDS_E_SHRINK_DIRTY_VOLUME => 0x8004259A as u32,
            ITF::NOTESPH_E_UNEXPECTED_STATE => 0x80042601 as u32,
            ITF::NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE => 0x80042603 as u32,
            ITF::NOTESPH_E_ITEM_NOT_FOUND => 0x80042604 as u32,
            ITF::NOTESPH_E_SERVER_CONFIG => 0x80042605 as u32,
            ITF::NOTESPH_E_ATTACHMENTS => 0x80042606 as u32,
            ITF::NOTESPH_E_NO_NTID => 0x80042607 as u32,
            ITF::NOTESPH_E_DB_ACCESS_DENIED => 0x80042608 as u32,
            ITF::NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR => 0x80042609 as u32,
            ITF::NOTESPH_E_FAIL => 0x80042611 as u32,
            ITF::STS_ABORTXMLPARSE => 0x80042614 as u32,
            ITF::STS_WS_ERROR => 0x80042616 as u32,
            ITF::SPS_WS_ERROR => 0x80042617 as u32,
            ITF::EXSTOREPH_E_UNEXPECTED => 0x80042701 as u32,
            ITF::VDS_E_NAME_NOT_UNIQUE => 0x80042701 as u32,
            ITF::VDS_E_ADDRESSES_INCOMPLETELY_SET => 0x80042703 as u32,
            ITF::VDS_E_SECURITY_INCOMPLETELY_SET => 0x80042705 as u32,
            ITF::VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED => 0x80042706 as u32,
            ITF::VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED => 0x80042707 as u32,
            ITF::VDS_E_ISCSI_LOGIN_FAILED => 0x80042708 as u32,
            ITF::VDS_E_ISCSI_LOGOUT_FAILED => 0x80042709 as u32,
            ITF::VDS_E_ISCSI_SESSION_NOT_FOUND => 0x8004270A as u32,
            ITF::VDS_E_ASSOCIATED_LUNS_EXIST => 0x8004270B as u32,
            ITF::VDS_E_ASSOCIATED_PORTALS_EXIST => 0x8004270C as u32,
            ITF::VDS_E_NO_DISCOVERY_DOMAIN => 0x8004270D as u32,
            ITF::VDS_E_MULTIPLE_DISCOVERY_DOMAINS => 0x8004270E as u32,
            ITF::VDS_E_NO_DISK_PATHNAME => 0x8004270F as u32,
            ITF::VDS_E_ISCSI_LOGOUT_INCOMPLETE => 0x80042710 as u32,
            ITF::VDS_E_NO_VOLUME_PATHNAME => 0x80042711 as u32,
            ITF::VDS_E_PROVIDER_CACHE_OUTOFSYNC => 0x80042712 as u32,
            ITF::VDS_E_NO_IMPORT_TARGET => 0x80042713 as u32,
            ITF::CERT_E_NOT_FOUND_OR_NO_PERMISSSION => 0x80042801 as u32,
            ITF::VDS_E_UNABLE_TO_FIND_BOOT_DISK => 0x80042803 as u32,
            ITF::VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO => 0x80042804 as u32,
            ITF::VDS_E_GET_SAN_POLICY => 0x80042805 as u32,
            ITF::VDS_E_SET_SAN_POLICY => 0x80042806 as u32,
            ITF::VDS_E_BOOT_DISK => 0x80042807 as u32,
            ITF::VDS_E_DISK_IS_OFFLINE => 0x8004280A as u32,
            ITF::VDS_E_DISK_IS_READ_ONLY => 0x8004280B as u32,
            ITF::VDS_E_PAGEFILE_DISK => 0x8004280C as u32,
            ITF::VDS_E_HIBERNATION_FILE_DISK => 0x8004280D as u32,
            ITF::VDS_E_CRASHDUMP_DISK => 0x8004280E as u32,
            ITF::VDS_E_UNABLE_TO_FIND_SYSTEM_DISK => 0x8004280F as u32,
            ITF::VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO => 0x80042810 as u32,
            ITF::VDS_E_SYSTEM_DISK => 0x80042811 as u32,
            ITF::VDS_E_VOLUME_SHRINK_FVE_LOCKED => 0x80042812 as u32,
            ITF::VDS_E_VOLUME_SHRINK_FVE_CORRUPT => 0x80042813 as u32,
            ITF::VDS_E_VOLUME_SHRINK_FVE_RECOVERY => 0x80042814 as u32,
            ITF::VDS_E_VOLUME_SHRINK_FVE => 0x80042815 as u32,
            ITF::VDS_E_SHRINK_OVER_DATA => 0x80042816 as u32,
            ITF::VDS_E_INVALID_SHRINK_SIZE => 0x80042817 as u32,
            ITF::VDS_E_LUN_DISK_MISSING => 0x80042818 as u32,
            ITF::VDS_E_LUN_DISK_FAILED => 0x80042819 as u32,
            ITF::VDS_E_LUN_DISK_NOT_READY => 0x8004281A as u32,
            ITF::VDS_E_LUN_DISK_NO_MEDIA => 0x8004281B as u32,
            ITF::VDS_E_LUN_NOT_READY => 0x8004281C as u32,
            ITF::VDS_E_LUN_OFFLINE => 0x8004281D as u32,
            ITF::VDS_E_LUN_FAILED => 0x8004281E as u32,
            ITF::VDS_E_VOLUME_EXTEND_FVE_LOCKED => 0x8004281F as u32,
            ITF::VDS_E_VOLUME_EXTEND_FVE_CORRUPT => 0x80042820 as u32,
            ITF::VDS_E_VOLUME_EXTEND_FVE_RECOVERY => 0x80042821 as u32,
            ITF::VDS_E_VOLUME_EXTEND_FVE => 0x80042822 as u32,
            ITF::VDS_E_SECTOR_SIZE_ERROR => 0x80042823 as u32,
            ITF::VDS_E_INITIATOR_ADAPTER_NOT_FOUND => 0x80042900 as u32,
            ITF::VDS_E_TARGET_PORTAL_NOT_FOUND => 0x80042901 as u32,
            ITF::VDS_E_INVALID_PORT_PATH => 0x80042902 as u32,
            ITF::VDS_E_INVALID_ISCSI_TARGET_NAME => 0x80042903 as u32,
            ITF::VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS => 0x80042904 as u32,
            ITF::VDS_E_ISCSI_GET_IKE_INFO => 0x80042905 as u32,
            ITF::VDS_E_ISCSI_SET_IKE_INFO => 0x80042906 as u32,
            ITF::VDS_E_SUBSYSTEM_ID_IS_NULL => 0x80042907 as u32,
            ITF::VDS_E_ISCSI_INITIATOR_NODE_NAME => 0x80042908 as u32,
            ITF::VDS_E_ISCSI_GROUP_PRESHARE_KEY => 0x80042909 as u32,
            ITF::VDS_E_ISCSI_CHAP_SECRET => 0x8004290A as u32,
            ITF::VDS_E_INVALID_IP_ADDRESS => 0x8004290B as u32,
            ITF::VDS_E_REBOOT_REQUIRED => 0x8004290C as u32,
            ITF::VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED => 0x8004290D as u32,
            ITF::VDS_E_BOOT_PAGEFILE_DRIVE_LETTER => 0x8004290E as u32,
            ITF::VDS_E_DELETE_WITH_CRITICAL => 0x8004290F as u32,
            ITF::VDS_E_CLEAN_WITH_DATA => 0x80042910 as u32,
            ITF::VDS_E_CLEAN_WITH_OEM => 0x80042911 as u32,
            ITF::VDS_E_CLEAN_WITH_CRITICAL => 0x80042912 as u32,
            ITF::VDS_E_FORMAT_CRITICAL => 0x80042913 as u32,
            ITF::VDS_E_NTFS_FORMAT_NOT_SUPPORTED => 0x80042914 as u32,
            ITF::VDS_E_FAT32_FORMAT_NOT_SUPPORTED => 0x80042915 as u32,
            ITF::VDS_E_FAT_FORMAT_NOT_SUPPORTED => 0x80042916 as u32,
            ITF::VDS_E_FORMAT_NOT_SUPPORTED => 0x80042917 as u32,
            ITF::VDS_E_COMPRESSION_NOT_SUPPORTED => 0x80042918 as u32,
            ITF::VDS_E_VDISK_NOT_OPEN => 0x80042919 as u32,
            ITF::VDS_E_VDISK_INVALID_OP_STATE => 0x8004291A as u32,
            ITF::VDS_E_INVALID_PATH => 0x8004291B as u32,
            ITF::VDS_E_INVALID_ISCSI_PATH => 0x8004291C as u32,
            ITF::VDS_E_SHRINK_LUN_NOT_UNMASKED => 0x8004291D as u32,
            ITF::VDS_E_LUN_DISK_READ_ONLY => 0x8004291E as u32,
            ITF::VDS_E_LUN_UPDATE_DISK => 0x8004291F as u32,
            ITF::VDS_E_LUN_DYNAMIC => 0x80042920 as u32,
            ITF::VDS_E_LUN_DYNAMIC_OFFLINE => 0x80042921 as u32,
            ITF::VDS_E_LUN_SHRINK_GPT_HEADER => 0x80042922 as u32,
            ITF::VDS_E_MIRROR_NOT_SUPPORTED => 0x80042923 as u32,
            ITF::VDS_E_RAID5_NOT_SUPPORTED => 0x80042924 as u32,
            ITF::VDS_E_DISK_NOT_CONVERTIBLE_SIZE => 0x80042925 as u32,
            ITF::VDS_E_OFFLINE_NOT_SUPPORTED => 0x80042926 as u32,
            ITF::VDS_E_VDISK_PATHNAME_INVALID => 0x80042927 as u32,
            ITF::VDS_E_EXTEND_TOO_MANY_CLUSTERS => 0x80042928 as u32,
            ITF::VDS_E_EXTEND_UNKNOWN_FILESYSTEM => 0x80042929 as u32,
            ITF::VDS_E_SHRINK_UNKNOWN_FILESYSTEM => 0x8004292A as u32,
            ITF::VDS_E_VD_DISK_NOT_OPEN => 0x8004292B as u32,
            ITF::VDS_E_VD_DISK_IS_EXPANDING => 0x8004292C as u32,
            ITF::VDS_E_VD_DISK_IS_COMPACTING => 0x8004292D as u32,
            ITF::VDS_E_VD_DISK_IS_MERGING => 0x8004292E as u32,
            ITF::VDS_E_VD_IS_ATTACHED => 0x8004292F as u32,
            ITF::VDS_E_VD_DISK_ALREADY_OPEN => 0x80042930 as u32,
            ITF::VDS_E_VD_DISK_ALREADY_EXPANDING => 0x80042931 as u32,
            ITF::VDS_E_VD_ALREADY_COMPACTING => 0x80042932 as u32,
            ITF::VDS_E_VD_ALREADY_MERGING => 0x80042933 as u32,
            ITF::VDS_E_VD_ALREADY_ATTACHED => 0x80042934 as u32,
            ITF::VDS_E_VD_ALREADY_DETACHED => 0x80042935 as u32,
            ITF::VDS_E_VD_NOT_ATTACHED_READONLY => 0x80042936 as u32,
            ITF::VDS_E_VD_IS_BEING_ATTACHED => 0x80042937 as u32,
            ITF::VDS_E_VD_IS_BEING_DETACHED => 0x80042938 as u32,
            ITF::VDS_E_NO_POOL => 0x80042A00 as u32,
            ITF::VDS_E_NO_POOL_CREATED => 0x80042A01 as u32,
            ITF::VDS_E_NO_MAINTENANCE_MODE => 0x80042A02 as u32,
            ITF::VDS_E_BLOCK_CLUSTERED => 0x80042A03 as u32,
            ITF::VDS_E_DISK_HAS_BANDS => 0x80042A04 as u32,
            ITF::VDS_E_INVALID_STATE => 0x80042A05 as u32,
            ITF::VDS_E_REFS_FORMAT_NOT_SUPPORTED => 0x80042A06 as u32,
            ITF::VDS_E_DELETE_WITH_BOOTBACKING => 0x80042A07 as u32,
            ITF::VDS_E_FORMAT_WITH_BOOTBACKING => 0x80042A08 as u32,
            ITF::VDS_E_CLEAN_WITH_BOOTBACKING => 0x80042A09 as u32,
            ITF::SRCH_SCHEMA_CACHE_E_UNEXPECTED => 0x80043301 as u32,
            ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_READ => 0x80043401 as u32,
            ITF::CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER => 0x80043402 as u32,
            ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE => 0x80043403 as u32,
            ITF::CONTENT_SOURCE_E_CONTENT_CLASS_READ => 0x80043404 as u32,
            ITF::CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION => 0x80043405 as u32,
            ITF::CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR => 0x80043406 as u32,
            ITF::CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE => 0x80043407 as u32,
            ITF::CONTENT_SOURCE_E_OUT_OF_RANGE => 0x80043408 as u32,
            ITF::CONTENT_SOURCE_E_NULL_URI => 0x80043409 as u32,
            ITF::REXSPH_E_INVALID_CALL => 0x80043500 as u32,
            ITF::REXSPH_E_REDIRECT_ON_SECURITY_UPDATE => 0x80043502 as u32,
            ITF::REXSPH_E_MULTIPLE_REDIRECT => 0x80043503 as u32,
            ITF::REXSPH_E_NO_PROPERTY_ON_ROW => 0x80043504 as u32,
            ITF::REXSPH_E_TYPE_MISMATCH_ON_READ => 0x80043505 as u32,
            ITF::REXSPH_E_UNEXPECTED_DATA_STATUS => 0x80043506 as u32,
            ITF::REXSPH_E_UNKNOWN_DATA_TYPE => 0x80043507 as u32,
            ITF::REXSPH_E_UNEXPECTED_FILTER_STATE => 0x80043508 as u32,
            ITF::REXSPH_E_DUPLICATE_PROPERTY => 0x80043509 as u32,
            ITF::FTE_E_SECRET_NOT_FOUND => 0x80043602 as u32,
            ITF::FTE_E_PIPE_NOT_CONNECTED => 0x80043603 as u32,
            ITF::FTE_E_ADMIN_BLOB_CORRUPT => 0x80043604 as u32,
            ITF::FTE_E_FILTER_SINGLE_THREADED => 0x80043605 as u32,
            ITF::FTE_E_ERROR_WRITING_REGISTRY => 0x80043606 as u32,
            ITF::FTE_E_PROJECT_SHUTDOWN => 0x80043607 as u32,
            ITF::FTE_E_PROJECT_NOT_INITALIZED => 0x80043608 as u32,
            ITF::FTE_E_PIPE_DATA_CORRUPTED => 0x80043609 as u32,
            ITF::FTE_E_URB_TOO_BIG => 0x80043610 as u32,
            ITF::FTE_E_INVALID_DOCID => 0x80043611 as u32,
            ITF::FTE_E_PAUSE_EXTERNAL => 0x80043612 as u32,
            ITF::FTE_E_REJECTED_DUE_TO_PROJECT_STATUS => 0x80043613 as u32,
            ITF::FTE_E_FD_DID_NOT_CONNECT => 0x80043614 as u32,
            ITF::FTE_E_PROGID_REQUIRED => 0x80043616 as u32,
            ITF::FTE_E_STATIC_THREAD_INVALID_ARGUMENTS => 0x80043617 as u32,
            ITF::FTE_E_CATALOG_ALREADY_EXISTS => 0x80043618 as u32,
            ITF::FTE_E_PATH_TOO_LONG => 0x8004361A as u32,
            ITF::FTE_INVALID_ADMIN_CLIENT => 0x8004361B as u32,
            ITF::FTE_E_COM_SIGNATURE_VALIDATION => 0x8004361C as u32,
            ITF::FTE_E_AFFINITY_MASK => 0x8004361D as u32,
            ITF::FTE_E_FD_OWNERSHIP_OBSOLETE => 0x8004361E as u32,
            ITF::FTE_E_EXCEEDED_MAX_PLUGINS => 0x80043621 as u32,
            ITF::FTE_E_DUPLICATE_OBJECT => 0x80043624 as u32,
            ITF::FTE_E_REDUNDANT_TRAN_FAILURE => 0x80043626 as u32,
            ITF::FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST => 0x80043627 as u32,
            ITF::FTE_E_FD_SHUTDOWN => 0x80043628 as u32,
            ITF::FTE_E_CATALOG_DOES_NOT_EXIST => 0x80043629 as u32,
            ITF::FTE_E_NO_PLUGINS => 0x8004362A as u32,
            ITF::FTE_E_BATCH_ABORTED => 0x8004362C as u32,
            ITF::FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE => 0x8004362D as u32,
            ITF::FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS => 0x8004362F as u32,
            ITF::FTE_E_FD_TIMEOUT => 0x80043630 as u32,
            ITF::FTE_E_RESOURCE_SHUTDOWN => 0x80043631 as u32,
            ITF::FTE_E_INVALID_PROPERTY => 0x80043632 as u32,
            ITF::FTE_E_NO_MORE_PROPERTIES => 0x80043633 as u32,
            ITF::FTE_E_UNKNOWN_PLUGIN => 0x80043634 as u32,
            ITF::FTE_E_LIBRARY_NOT_LOADED => 0x80043635 as u32,
            ITF::FTE_E_PERFMON_FULL => 0x80043636 as u32,
            ITF::FTE_E_FAILED_TO_CREATE_ACCESSOR => 0x80043637 as u32,
            ITF::FTE_E_INVALID_TYPE => 0x80043638 as u32,
            ITF::FTE_E_OUT_OF_RANGE => 0x80043639 as u32,
            ITF::FTE_E_CORRUPT_PROPERTY_STORE => 0x8004363A as u32,
            ITF::FTE_E_PROPERTY_STORE_WORKID_NOTVALID => 0x8004363B as u32,
            ITF::FTE_E_CORRUPT_GATHERER_HASH_MAP => 0x8004363D as u32,
            ITF::FTE_E_KEY_NOT_CACHED => 0x8004363E as u32,
            ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN => 0x8004363F as u32,
            ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED => 0x80043640 as u32,
            ITF::FTE_E_STACK_CORRUPTED => 0x80043641 as u32,
            ITF::FTE_E_INVALID_PROG_ID => 0x80043642 as u32,
            ITF::FTE_E_SERIAL_STREAM_CORRUPT => 0x80043643 as u32,
            ITF::FTE_E_READONLY_CATALOG => 0x80043644 as u32,
            ITF::FTE_E_PERF_NOT_LOADED => 0x80043645 as u32,
            ITF::FTE_E_RETRY_HUGE_DOC => 0x80043648 as u32,
            ITF::FTE_E_UNKNOWN_FD_TYPE => 0x80043649 as u32,
            ITF::FTE_E_DOC_TOO_HUGE => 0x8004364A as u32,
            ITF::FTE_E_DATATYPE_MISALIGNMENT => 0x8004364B as u32,
            ITF::FTE_E_ALREADY_INITIALIZED => 0x8004364C as u32,
            ITF::FTE_E_FD_USED_TOO_MUCH_MEMORY => 0x8004364D as u32,
            ITF::FTE_E_UNEXPECTED_EXIT => 0x8004364E as u32,
            ITF::FTE_E_HIGH_MEMORY_PRESSURE => 0x8004364F as u32,
            ITF::FTE_E_INVALID_ISOLATE_ERROR_BATCH => 0x80043650 as u32,
            ITF::FTE_E_RETRY_SINGLE_DOC_PER_BATCH => 0x80043651 as u32,
            ITF::FTE_E_INVALID_PROJECT_ID => 0x80043652 as u32,
            ITF::FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS => 0x80043653 as u32,
            ITF::FTE_E_INVALID_CODEPAGE => 0x80043654 as u32,
            ITF::FTE_E_FD_IDLE => 0x80043655 as u32,
            ITF::FTE_E_FD_UNRESPONSIVE => 0x80043656 as u32,
            ITF::WCN_E_PEER_NOT_FOUND => 0x80043C01 as u32,
            ITF::WCN_E_AUTHENTICATION_FAILED => 0x80043C02 as u32,
            ITF::WCN_E_CONNECTION_REJECTED => 0x80043C03 as u32,
            ITF::WCN_E_SESSION_TIMEDOUT => 0x80043C04 as u32,
            ITF::WCN_E_PROTOCOL_ERROR => 0x80043C05 as u32,
            ITF::CDO_E_ARGUMENT1 => 0x80044000 as u32,
            ITF::PEOPLE_IMPORT_E_DBCONNFAIL => 0x80044000 as u32,
            ITF::CDO_E_ARGUMENT2 => 0x80044001 as u32,
            ITF::PEOPLE_IMPORT_NODSDEFINED => 0x80044001 as u32,
            ITF::CDO_E_ARGUMENT3 => 0x80044002 as u32,
            ITF::PEOPLE_IMPORT_E_FAILTOGETDSDEF => 0x80044002 as u32,
            ITF::CDO_E_ARGUMENT4 => 0x80044003 as u32,
            ITF::PEOPLE_IMPORT_NOMAPPINGDEFINED => 0x80044003 as u32,
            ITF::CDO_E_ARGUMENT5 => 0x80044004 as u32,
            ITF::PEOPLE_IMPORT_E_FAILTOGETDSMAPPING => 0x80044004 as u32,
            ITF::PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED => 0x80044005 as u32,
            ITF::PEOPLE_IMPORT_E_NOCASTINGSUPPORTED => 0x80044006 as u32,
            ITF::PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE => 0x80044007 as u32,
            ITF::PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE => 0x80044008 as u32,
            ITF::PEOPLE_IMPORT_E_LDAPPATH_TOOLONG => 0x80044009 as u32,
            ITF::PEOPLE_IMPORT_E_CANONICALURL_TOOLONG => 0x8004400A as u32,
            ITF::PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED => 0x8004400B as u32,
            ITF::PEOPLE_IMPORT_E_DC_NOT_AVAILABLE => 0x8004400C as u32,
            ITF::PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED => 0x8004400D as u32,
            ITF::PEOPLE_IMPORT_E_FAILTOGETLCID => 0x8004400E as u32,
            ITF::PEOPLE_IMPORT_E_DOMAIN_REMOVED => 0x8004400F as u32,
            ITF::PEOPLE_IMPORT_E_ENUM_ACCESSDENIED => 0x80044010 as u32,
            ITF::PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED => 0x80044011 as u32,
            ITF::SPERR_UNINITIALIZED => 0x80045001 as u32,
            ITF::SPERR_ALREADY_INITIALIZED => 0x80045002 as u32,
            ITF::SPERR_UNSUPPORTED_FORMAT => 0x80045003 as u32,
            ITF::SPERR_INVALID_FLAGS => 0x80045004 as u32,
            ITF::SPERR_DEVICE_BUSY => 0x80045006 as u32,
            ITF::SPERR_DEVICE_NOT_SUPPORTED => 0x80045007 as u32,
            ITF::SPERR_DEVICE_NOT_ENABLED => 0x80045008 as u32,
            ITF::SPERR_NO_DRIVER => 0x80045009 as u32,
            ITF::SPERR_FILEMUSTBEUNICODE => 0x8004500A as u32,
            ITF::SPERR_INVALID_PHRASE_ID => 0x8004500C as u32,
            ITF::SPERR_BUFFER_TOO_SMALL => 0x8004500D as u32,
            ITF::SPERR_FORMAT_NOT_SPECIFIED => 0x8004500E as u32,
            ITF::SPERR_AUDIO_STOPPED => 0x8004500F as u32,
            ITF::SPERR_RULE_NOT_FOUND => 0x80045011 as u32,
            ITF::SPERR_TTS_ENGINE_EXCEPTION => 0x80045012 as u32,
            ITF::SPERR_TTS_NLP_EXCEPTION => 0x80045013 as u32,
            ITF::SPERR_ENGINE_BUSY => 0x80045014 as u32,
            ITF::SPERR_CANT_CREATE => 0x80045017 as u32,
            ITF::SPERR_NOT_IN_LEX => 0x80045019 as u32,
            ITF::SPERR_LEX_VERY_OUT_OF_SYNC => 0x8004501B as u32,
            ITF::SPERR_UNDEFINED_FORWARD_RULE_REF => 0x8004501C as u32,
            ITF::SPERR_EMPTY_RULE => 0x8004501D as u32,
            ITF::SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR => 0x8004501E as u32,
            ITF::SPERR_RULE_NOT_DYNAMIC => 0x8004501F as u32,
            ITF::SPERR_DUPLICATE_RULE_NAME => 0x80045020 as u32,
            ITF::SPERR_DUPLICATE_RESOURCE_NAME => 0x80045021 as u32,
            ITF::SPERR_TOO_MANY_GRAMMARS => 0x80045022 as u32,
            ITF::SPERR_CIRCULAR_REFERENCE => 0x80045023 as u32,
            ITF::SPERR_INVALID_IMPORT => 0x80045024 as u32,
            ITF::SPERR_INVALID_WAV_FILE => 0x80045025 as u32,
            ITF::SPERR_ALL_WORDS_OPTIONAL => 0x80045027 as u32,
            ITF::SPERR_INSTANCE_CHANGE_INVALID => 0x80045028 as u32,
            ITF::SPERR_RULE_NAME_ID_CONFLICT => 0x80045029 as u32,
            ITF::SPERR_NO_RULES => 0x8004502A as u32,
            ITF::SPERR_CIRCULAR_RULE_REF => 0x8004502B as u32,
            ITF::SPERR_NO_PARSE_FOUND => 0x8004502D as u32,
            ITF::SPERR_REMOTE_CALL_TIMED_OUT => 0x8004502E as u32,
            ITF::SPERR_AUDIO_BUFFER_OVERFLOW => 0x8004502F as u32,
            ITF::SPERR_NO_AUDIO_DATA => 0x80045030 as u32,
            ITF::SPERR_DEAD_ALTERNATE => 0x80045031 as u32,
            ITF::SPERR_HIGH_LOW_CONFIDENCE => 0x80045032 as u32,
            ITF::SPERR_INVALID_FORMAT_STRING => 0x80045033 as u32,
            ITF::SPERR_APPLEX_READ_ONLY => 0x80045035 as u32,
            ITF::SPERR_NO_TERMINATING_RULE_PATH => 0x80045036 as u32,
            ITF::SPERR_STREAM_CLOSED => 0x80045038 as u32,
            ITF::SPERR_NO_MORE_ITEMS => 0x80045039 as u32,
            ITF::SPERR_NOT_FOUND => 0x8004503A as u32,
            ITF::SPERR_INVALID_AUDIO_STATE => 0x8004503B as u32,
            ITF::SPERR_GENERIC_MMSYS_ERROR => 0x8004503C as u32,
            ITF::SPERR_MARSHALER_EXCEPTION => 0x8004503D as u32,
            ITF::SPERR_NOT_DYNAMIC_GRAMMAR => 0x8004503E as u32,
            ITF::SPERR_AMBIGUOUS_PROPERTY => 0x8004503F as u32,
            ITF::SPERR_INVALID_REGISTRY_KEY => 0x80045040 as u32,
            ITF::SPERR_INVALID_TOKEN_ID => 0x80045041 as u32,
            ITF::SPERR_XML_BAD_SYNTAX => 0x80045042 as u32,
            ITF::SPERR_XML_RESOURCE_NOT_FOUND => 0x80045043 as u32,
            ITF::SPERR_TOKEN_IN_USE => 0x80045044 as u32,
            ITF::SPERR_TOKEN_DELETED => 0x80045045 as u32,
            ITF::SPERR_MULTI_LINGUAL_NOT_SUPPORTED => 0x80045046 as u32,
            ITF::SPERR_EXPORT_DYNAMIC_RULE => 0x80045047 as u32,
            ITF::SPERR_STGF_ERROR => 0x80045048 as u32,
            ITF::SPERR_WORDFORMAT_ERROR => 0x80045049 as u32,
            ITF::SPERR_STREAM_NOT_ACTIVE => 0x8004504A as u32,
            ITF::SPERR_ENGINE_RESPONSE_INVALID => 0x8004504B as u32,
            ITF::SPERR_SR_ENGINE_EXCEPTION => 0x8004504C as u32,
            ITF::SPERR_STREAM_POS_INVALID => 0x8004504D as u32,
            ITF::SPERR_REMOTE_CALL_ON_WRONG_THREAD => 0x8004504F as u32,
            ITF::SPERR_REMOTE_PROCESS_TERMINATED => 0x80045050 as u32,
            ITF::SPERR_REMOTE_PROCESS_ALREADY_RUNNING => 0x80045051 as u32,
            ITF::SPERR_LANGID_MISMATCH => 0x80045052 as u32,
            ITF::SPERR_NOT_TOPLEVEL_RULE => 0x80045054 as u32,
            ITF::SPERR_LEX_REQUIRES_COOKIE => 0x80045056 as u32,
            ITF::SPERR_UNSUPPORTED_LANG => 0x80045059 as u32,
            ITF::SPERR_VOICE_PAUSED => 0x8004505A as u32,
            ITF::SPERR_AUDIO_BUFFER_UNDERFLOW => 0x8004505B as u32,
            ITF::SPERR_AUDIO_STOPPED_UNEXPECTEDLY => 0x8004505C as u32,
            ITF::SPERR_NO_WORD_PRONUNCIATION => 0x8004505D as u32,
            ITF::SPERR_ALTERNATES_WOULD_BE_INCONSISTENT => 0x8004505E as u32,
            ITF::SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER => 0x8004505F as u32,
            ITF::SPERR_TIMEOUT => 0x80045060 as u32,
            ITF::SPERR_REENTER_SYNCHRONIZE => 0x80045061 as u32,
            ITF::SPERR_STATE_WITH_NO_ARCS => 0x80045062 as u32,
            ITF::SPERR_NOT_ACTIVE_SESSION => 0x80045063 as u32,
            ITF::SPERR_ALREADY_DELETED => 0x80045064 as u32,
            ITF::SPERR_RECOXML_GENERATION_FAIL => 0x80045066 as u32,
            ITF::SPERR_SML_GENERATION_FAIL => 0x80045067 as u32,
            ITF::SPERR_NOT_PROMPT_VOICE => 0x80045068 as u32,
            ITF::SPERR_ROOTRULE_ALREADY_DEFINED => 0x80045069 as u32,
            ITF::SPERR_SCRIPT_DISALLOWED => 0x80045070 as u32,
            ITF::SPERR_REMOTE_CALL_TIMED_OUT_START => 0x80045071 as u32,
            ITF::SPERR_REMOTE_CALL_TIMED_OUT_CONNECT => 0x80045072 as u32,
            ITF::SPERR_SECMGR_CHANGE_NOT_ALLOWED => 0x80045073 as u32,
            ITF::SPERR_FAILED_TO_DELETE_FILE => 0x80045075 as u32,
            ITF::SPERR_SHARED_ENGINE_DISABLED => 0x80045076 as u32,
            ITF::SPERR_RECOGNIZER_NOT_FOUND => 0x80045077 as u32,
            ITF::SPERR_AUDIO_NOT_FOUND => 0x80045078 as u32,
            ITF::SPERR_NO_VOWEL => 0x80045079 as u32,
            ITF::SPERR_UNSUPPORTED_PHONEME => 0x8004507A as u32,
            ITF::SPERR_WORD_NEEDS_NORMALIZATION => 0x8004507D as u32,
            ITF::SPERR_CANNOT_NORMALIZE => 0x8004507E as u32,
            ITF::SPERR_TOPIC_NOT_ADAPTABLE => 0x80045081 as u32,
            ITF::SPERR_PHONEME_CONVERSION => 0x80045082 as u32,
            ITF::SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER => 0x80045083 as u32,
            ITF::SPERR_OVERLOAD => 0x80045084 as u32,
            ITF::SPERR_LEX_INVALID_DATA => 0x80045085 as u32,
            ITF::SPERR_CFG_INVALID_DATA => 0x80045086 as u32,
            ITF::SPERR_LEX_UNEXPECTED_FORMAT => 0x80045087 as u32,
            ITF::SPERR_STRING_TOO_LONG => 0x80045088 as u32,
            ITF::SPERR_STRING_EMPTY => 0x80045089 as u32,
            ITF::SPERR_NON_WORD_TRANSITION => 0x80045090 as u32,
            ITF::SPERR_SISR_ATTRIBUTES_NOT_ALLOWED => 0x80045091 as u32,
            ITF::SPERR_SISR_MIXED_NOT_ALLOWED => 0x80045092 as u32,
            ITF::SPERR_VOICE_NOT_FOUND => 0x80045093 as u32,
            ITF::FSRM_E_NOT_FOUND => 0x80045301 as u32,
            ITF::FSRM_E_INVALID_SCHEDULER_ARGUMENT => 0x80045302 as u32,
            ITF::FSRM_E_ALREADY_EXISTS => 0x80045303 as u32,
            ITF::FSRM_E_PATH_NOT_FOUND => 0x80045304 as u32,
            ITF::FSRM_E_INVALID_USER => 0x80045305 as u32,
            ITF::FSRM_E_INVALID_PATH => 0x80045306 as u32,
            ITF::FSRM_E_INVALID_LIMIT => 0x80045307 as u32,
            ITF::FSRM_E_INVALID_NAME => 0x80045308 as u32,
            ITF::FSRM_E_FAIL_BATCH => 0x80045309 as u32,
            ITF::FSRM_E_INVALID_TEXT => 0x8004530A as u32,
            ITF::FSRM_E_INVALID_IMPORT_VERSION => 0x8004530B as u32,
            ITF::FSRM_E_OUT_OF_RANGE => 0x8004530D as u32,
            ITF::FSRM_E_REQD_PARAM_MISSING => 0x8004530E as u32,
            ITF::FSRM_E_INVALID_COMBINATION => 0x8004530F as u32,
            ITF::FSRM_E_DUPLICATE_NAME => 0x80045310 as u32,
            ITF::FSRM_E_NOT_SUPPORTED => 0x80045311 as u32,
            ITF::FSRM_E_DRIVER_NOT_READY => 0x80045313 as u32,
            ITF::FSRM_E_INSUFFICIENT_DISK => 0x80045314 as u32,
            ITF::FSRM_E_VOLUME_UNSUPPORTED => 0x80045315 as u32,
            ITF::FSRM_E_UNEXPECTED => 0x80045316 as u32,
            ITF::FSRM_E_INSECURE_PATH => 0x80045317 as u32,
            ITF::FSRM_E_INVALID_SMTP_SERVER => 0x80045318 as u32,
            ITF::FSRM_E_EMAIL_NOT_SENT => 0x8004531C as u32,
            ITF::FSRM_E_INVALID_EMAIL_ADDRESS => 0x8004531E as u32,
            ITF::FSRM_E_FILE_SYSTEM_CORRUPT => 0x8004531F as u32,
            ITF::FSRM_E_LONG_CMDLINE => 0x80045320 as u32,
            ITF::FSRM_E_INVALID_FILEGROUP_DEFINITION => 0x80045321 as u32,
            ITF::FSRM_E_INVALID_DATASCREEN_DEFINITION => 0x80045324 as u32,
            ITF::FSRM_E_INVALID_REPORT_FORMAT => 0x80045328 as u32,
            ITF::FSRM_E_INVALID_REPORT_DESC => 0x80045329 as u32,
            ITF::FSRM_E_INVALID_FILENAME => 0x8004532A as u32,
            ITF::FSRM_E_SHADOW_COPY => 0x8004532C as u32,
            ITF::FSRM_E_XML_CORRUPTED => 0x8004532D as u32,
            ITF::FSRM_E_CLUSTER_NOT_RUNNING => 0x8004532E as u32,
            ITF::FSRM_E_STORE_NOT_INSTALLED => 0x8004532F as u32,
            ITF::FSRM_E_NOT_CLUSTER_VOLUME => 0x80045330 as u32,
            ITF::FSRM_E_DIFFERENT_CLUSTER_GROUP => 0x80045331 as u32,
            ITF::FSRM_E_REPORT_TYPE_ALREADY_EXISTS => 0x80045332 as u32,
            ITF::FSRM_E_REPORT_JOB_ALREADY_RUNNING => 0x80045333 as u32,
            ITF::FSRM_E_REPORT_GENERATION_ERR => 0x80045334 as u32,
            ITF::FSRM_E_REPORT_TASK_TRIGGER => 0x80045335 as u32,
            ITF::FSRM_E_LOADING_DISABLED_MODULE => 0x80045336 as u32,
            ITF::FSRM_E_CANNOT_AGGREGATE => 0x80045337 as u32,
            ITF::FSRM_E_MESSAGE_LIMIT_EXCEEDED => 0x80045338 as u32,
            ITF::FSRM_E_OBJECT_IN_USE => 0x80045339 as u32,
            ITF::FSRM_E_CANNOT_RENAME_PROPERTY => 0x8004533A as u32,
            ITF::FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE => 0x8004533B as u32,
            ITF::FSRM_E_MAX_PROPERTY_DEFINITIONS => 0x8004533C as u32,
            ITF::FSRM_E_CLASSIFICATION_ALREADY_RUNNING => 0x8004533D as u32,
            ITF::FSRM_E_CLASSIFICATION_NOT_RUNNING => 0x8004533E as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING => 0x8004533F as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION => 0x80045340 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM => 0x80045341 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION => 0x80045342 as u32,
            ITF::FSRM_E_FILE_OPEN_ERROR => 0x80045343 as u32,
            ITF::FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE => 0x80045344 as u32,
            ITF::FSRM_E_CACHE_INVALID => 0x80045345 as u32,
            ITF::FSRM_E_CACHE_MODULE_ALREADY_EXISTS => 0x80045346 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE => 0x80045347 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS => 0x80045348 as u32,
            ITF::FSRM_E_PROPERTY_DELETED => 0x80045349 as u32,
            ITF::FSRM_E_LAST_ACCESS_UPDATE_DISABLED => 0x80045350 as u32,
            ITF::FSRM_E_NO_PROPERTY_VALUE => 0x80045351 as u32,
            ITF::FSRM_E_INPROC_MODULE_BLOCKED => 0x80045352 as u32,
            ITF::FSRM_E_ENUM_PROPERTIES_FAILED => 0x80045353 as u32,
            ITF::FSRM_E_SET_PROPERTY_FAILED => 0x80045354 as u32,
            ITF::FSRM_E_CANNOT_STORE_PROPERTIES => 0x80045355 as u32,
            ITF::FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG => 0x80045356 as u32,
            ITF::FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND => 0x80045357 as u32,
            ITF::FSRM_E_TEXTREADER_NOT_INITIALIZED => 0x80045358 as u32,
            ITF::FSRM_E_TEXTREADER_IFILTER_NOT_FOUND => 0x80045359 as u32,
            ITF::FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED => 0x8004535A as u32,
            ITF::FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED => 0x80045360 as u32,
            ITF::FSRM_E_TEXTREADER_STREAM_ERROR => 0x80045361 as u32,
            ITF::FSRM_E_TEXTREADER_FILENAME_TOO_LONG => 0x80045362 as u32,
            ITF::FSRM_E_INCOMPATIBLE_FORMAT => 0x80045363 as u32,
            ITF::FSRM_E_FILE_ENCRYPTED => 0x80045364 as u32,
            ITF::FSRM_E_PERSIST_PROPERTIES_FAILED => 0x80045365 as u32,
            ITF::FSRM_E_VOLUME_OFFLINE => 0x80045366 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT => 0x80045367 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED => 0x80045368 as u32,
            ITF::FSRM_E_MODULE_INVALID_PARAM => 0x80045369 as u32,
            ITF::FSRM_E_MODULE_INITIALIZATION => 0x8004536A as u32,
            ITF::FSRM_E_MODULE_SESSION_INITIALIZATION => 0x8004536B as u32,
            ITF::FSRM_E_CLASSIFICATION_SCAN_FAIL => 0x8004536C as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE => 0x8004536D as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS => 0x8004536E as u32,
            ITF::FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY => 0x8004536F as u32,
            ITF::FSRM_E_SYNC_TASK_TIMEOUT => 0x80045370 as u32,
            ITF::FSRM_E_CANNOT_USE_DELETED_PROPERTY => 0x80045371 as u32,
            ITF::FSRM_E_INVALID_AD_CLAIM => 0x80045372 as u32,
            ITF::FSRM_E_CLASSIFICATION_CANCELED => 0x80045373 as u32,
            ITF::FSRM_E_INVALID_FOLDER_PROPERTY_STORE => 0x80045374 as u32,
            ITF::FSRM_E_REBUILDING_FODLER_TYPE_INDEX => 0x80045375 as u32,
            ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FILES => 0x80045376 as u32,
            ITF::FSRM_E_CLASSIFICATION_TIMEOUT => 0x80045377 as u32,
            ITF::FSRM_E_CLASSIFICATION_PARTIAL_BATCH => 0x80045378 as u32,
            ITF::FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY => 0x80045379 as u32,
            ITF::FSRM_E_FILE_IN_USE => 0x8004537A as u32,
            ITF::FSRM_E_ERROR_NOT_ENABLED => 0x8004537B as u32,
            ITF::FSRM_E_CANNOT_CREATE_TEMP_COPY => 0x8004537C as u32,
            ITF::FSRM_E_NO_EMAIL_ADDRESS => 0x8004537D as u32,
            ITF::FSRM_E_ADR_MAX_EMAILS_SENT => 0x8004537E as u32,
            ITF::FSRM_E_PATH_NOT_IN_NAMESPACE => 0x8004537F as u32,
            ITF::FSRM_E_RMS_TEMPLATE_NOT_FOUND => 0x80045380 as u32,
            ITF::FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED => 0x80045381 as u32,
            ITF::FSRM_E_RMS_NO_PROTECTORS_INSTALLED => 0x80045382 as u32,
            ITF::FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE => 0x80045383 as u32,
            ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS => 0x80045384 as u32,
            ITF::FSRM_E_PROPERTY_MUST_BE_SECURE => 0x80045385 as u32,
            ITF::FSRM_E_PROPERTY_MUST_BE_GLOBAL => 0x80045386 as u32,
            ITF::FSRM_E_WMI_FAILURE => 0x80045387 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_RMS => 0x80045388 as u32,
            ITF::FSRM_E_SYNC_TASK_HAD_ERRORS => 0x80045389 as u32,
            ITF::FSRM_E_ADR_SRV_NOT_SUPPORTED => 0x80045390 as u32,
            ITF::FSRM_E_ADR_PATH_IS_LOCAL => 0x80045391 as u32,
            ITF::FSRM_E_ADR_NOT_DOMAIN_JOINED => 0x80045392 as u32,
            ITF::FSRM_E_CANNOT_REMOVE_READONLY => 0x80045393 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG => 0x80045394 as u32,
            ITF::FSRM_E_LEGACY_SCHEDULE => 0x80045395 as u32,
            ITF::FSRM_E_CSC_PATH_NOT_SUPPORTED => 0x80045396 as u32,
            ITF::FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE => 0x80045397 as u32,
            ITF::FSRM_E_EXPIRATION_PATH_TOO_LONG => 0x80045398 as u32,
            ITF::FSRM_E_EXPIRATION_VOLUME_NOT_NTFS => 0x80045399 as u32,
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED => 0x8004539A as u32,
            ITF::FSRM_E_MODULE_TIMEOUT => 0x8004539B as u32,
            ITF::IFED_S_MORE_ENTRIES => 0x80047200 as u32,
            ITF::IFED_S_EMPTY_DICTIONARY => 0x80047201 as u32,
            ITF::IFED_S_WORD_EXISTS => 0x80047202 as u32,
            ITF::IFED_S_COMMENT_CHANGED => 0x80047203 as u32,
            ITF::IFED_E_NOT_FOUND => 0x80047300 as u32,
            ITF::IFED_E_INVALID_FORMAT => 0x80047301 as u32,
            ITF::IFED_E_OPEN_FAILED => 0x80047302 as u32,
            ITF::IFED_E_WRITE_FAILED => 0x80047303 as u32,
            ITF::IFED_E_NO_ENTRY => 0x80047304 as u32,
            ITF::IFED_E_REGISTER_FAILED => 0x80047305 as u32,
            ITF::IFED_E_NOT_USER_DIC => 0x80047306 as u32,
            ITF::IFED_E_NOT_SUPPORTED => 0x80047307 as u32,
            ITF::IFED_E_USER_COMMENT => 0x80047308 as u32,
            ITF::IFED_E_REGISTER_ILLEGAL_POS => 0x80047309 as u32,
            ITF::IFED_E_REGISTER_IMPROPER_WORD => 0x8004730A as u32,
            ITF::IFED_E_REGISTER_DISCONNECTED => 0x8004730B as u32,
            ITF::NETCFG_E_ALREADY_INITIALIZED => 0x8004A020 as u32,
            ITF::UPNP_E_REQUIRED_ELEMENT_ERROR => 0x8004A020 as u32,
            ITF::NETCFG_E_NOT_INITIALIZED => 0x8004A021 as u32,
            ITF::UPNP_E_DUPLICATE_NOT_ALLOWED => 0x8004A021 as u32,
            ITF::NETCFG_E_IN_USE => 0x8004A022 as u32,
            ITF::UPNP_E_DUPLICATE_SERVICE_ID => 0x8004A022 as u32,
            ITF::UPNP_E_INVALID_DESCRIPTION => 0x8004A023 as u32,
            ITF::NETCFG_E_NO_WRITE_LOCK => 0x8004A024 as u32,
            ITF::UPNP_E_INVALID_SERVICE => 0x8004A024 as u32,
            ITF::NETCFG_E_NEED_REBOOT => 0x8004A025 as u32,
            ITF::UPNP_E_INVALID_ICON => 0x8004A025 as u32,
            ITF::NETCFG_E_ACTIVE_RAS_CONNECTIONS => 0x8004A026 as u32,
            ITF::UPNP_E_INVALID_XML => 0x8004A026 as u32,
            ITF::NETCFG_E_ADAPTER_NOT_FOUND => 0x8004A027 as u32,
            ITF::UPNP_E_INVALID_ROOT_NAMESPACE => 0x8004A027 as u32,
            ITF::NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT => 0x8004A028 as u32,
            ITF::UPNP_E_SUFFIX_TOO_LONG => 0x8004A028 as u32,
            ITF::NETCFG_E_MAX_FILTER_LIMIT => 0x8004A029 as u32,
            ITF::UPNP_E_URLBASE_PRESENT => 0x8004A029 as u32,
            ITF::NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER => 0x8004A02A as u32,
            ITF::NETCFG_E_DUPLICATE_INSTANCEID => 0x8004A02B as u32,
            ITF::UPNP_E_VALUE_TOO_LONG => 0x8004A030 as u32,
            ITF::UPNP_E_DEVICE_RUNNING => 0x8004A031 as u32,
            ITF::UPNP_E_DEVICE_NOTREGISTERED => 0x8004A032 as u32,
            ITF::WTS_E_FAILEDEXTRACTION => 0x8004B200 as u32,
            ITF::WTS_E_EXTRACTIONTIMEDOUT => 0x8004B201 as u32,
            ITF::WTS_E_SURROGATEUNAVAILABLE => 0x8004B202 as u32,
            ITF::WTS_E_FASTEXTRACTIONNOTSUPPORTED => 0x8004B203 as u32,
            ITF::WTS_E_DATAFILEUNAVAILABLE => 0x8004B204 as u32,
            ITF::FTE_E_CB_OUT_OF_MEMORY => 0x8004CB00 as u32,
            ITF::FTE_E_CB_CBID_OUT_OF_BOUND => 0x8004CB01 as u32,
            ITF::FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM => 0x8004CB02 as u32,
            ITF::FTE_E_CB_NOT_ENOUGH_OCC_BUFFER => 0x8004CB03 as u32,
            ITF::FTE_E_CORRUPT_WORDLIST => 0x8004CB04 as u32,
            ITF::XACT_E_ALREADYOTHERSINGLEPHASE => 0x8004D000 as u32,
            ITF::XACT_E_CANTRETAIN => 0x8004D001 as u32,
            ITF::XACT_E_COMMITFAILED => 0x8004D002 as u32,
            ITF::XACT_E_COMMITPREVENTED => 0x8004D003 as u32,
            ITF::XACT_E_HEURISTICABORT => 0x8004D004 as u32,
            ITF::XACT_E_HEURISTICCOMMIT => 0x8004D005 as u32,
            ITF::XACT_E_HEURISTICDAMAGE => 0x8004D006 as u32,
            ITF::XACT_E_HEURISTICDANGER => 0x8004D007 as u32,
            ITF::XACT_E_ISOLATIONLEVEL => 0x8004D008 as u32,
            ITF::XACT_E_NOASYNC => 0x8004D009 as u32,
            ITF::XACT_E_NOENLIST => 0x8004D00A as u32,
            ITF::XACT_E_NOISORETAIN => 0x8004D00B as u32,
            ITF::XACT_E_NORESOURCE => 0x8004D00C as u32,
            ITF::XACT_E_NOTCURRENT => 0x8004D00D as u32,
            ITF::XACT_E_NOTRANSACTION => 0x8004D00E as u32,
            ITF::XACT_E_NOTSUPPORTED => 0x8004D00F as u32,
            ITF::XACT_E_UNKNOWNRMGRID => 0x8004D010 as u32,
            ITF::XACT_E_WRONGSTATE => 0x8004D011 as u32,
            ITF::XACT_E_WRONGUOW => 0x8004D012 as u32,
            ITF::XACT_E_XTIONEXISTS => 0x8004D013 as u32,
            ITF::XACT_E_NOIMPORTOBJECT => 0x8004D014 as u32,
            ITF::XACT_E_INVALIDCOOKIE => 0x8004D015 as u32,
            ITF::XACT_E_INDOUBT => 0x8004D016 as u32,
            ITF::XACT_E_NOTIMEOUT => 0x8004D017 as u32,
            ITF::XACT_E_ALREADYINPROGRESS => 0x8004D018 as u32,
            ITF::XACT_E_ABORTED => 0x8004D019 as u32,
            ITF::XACT_E_LOGFULL => 0x8004D01A as u32,
            ITF::XACT_E_TMNOTAVAILABLE => 0x8004D01B as u32,
            ITF::XACT_E_CONNECTION_DOWN => 0x8004D01C as u32,
            ITF::XACT_E_CONNECTION_DENIED => 0x8004D01D as u32,
            ITF::XACT_E_REENLISTTIMEOUT => 0x8004D01E as u32,
            ITF::XACT_E_TIP_CONNECT_FAILED => 0x8004D01F as u32,
            ITF::XACT_E_TIP_PROTOCOL_ERROR => 0x8004D020 as u32,
            ITF::XACT_E_TIP_PULL_FAILED => 0x8004D021 as u32,
            ITF::XACT_E_DEST_TMNOTAVAILABLE => 0x8004D022 as u32,
            ITF::XACT_E_TIP_DISABLED => 0x8004D023 as u32,
            ITF::XACT_E_NETWORK_TX_DISABLED => 0x8004D024 as u32,
            ITF::XACT_E_PARTNER_NETWORK_TX_DISABLED => 0x8004D025 as u32,
            ITF::XACT_E_XA_TX_DISABLED => 0x8004D026 as u32,
            ITF::XACT_E_UNABLE_TO_READ_DTC_CONFIG => 0x8004D027 as u32,
            ITF::XACT_E_UNABLE_TO_LOAD_DTC_PROXY => 0x8004D028 as u32,
            ITF::XACT_E_ABORTING => 0x8004D029 as u32,
            ITF::XACT_E_PUSH_COMM_FAILURE => 0x8004D02A as u32,
            ITF::XACT_E_PULL_COMM_FAILURE => 0x8004D02B as u32,
            ITF::XACT_E_LU_TX_DISABLED => 0x8004D02C as u32,
            ITF::XACT_E_CLERKNOTFOUND => 0x8004D080 as u32,
            ITF::XACT_E_CLERKEXISTS => 0x8004D081 as u32,
            ITF::XACT_E_RECOVERYINPROGRESS => 0x8004D082 as u32,
            ITF::XACT_E_TRANSACTIONCLOSED => 0x8004D083 as u32,
            ITF::XACT_E_INVALIDLSN => 0x8004D084 as u32,
            ITF::XACT_E_REPLAYREQUEST => 0x8004D085 as u32,
            ITF::XACT_E_CONNECTION_REQUEST_DENIED => 0x8004D100 as u32,
            ITF::XACT_E_TOOMANY_ENLISTMENTS => 0x8004D101 as u32,
            ITF::XACT_E_DUPLICATE_GUID => 0x8004D102 as u32,
            ITF::SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED => 0x8004D102 as u32,
            ITF::XACT_E_NOTSINGLEPHASE => 0x8004D103 as u32,
            ITF::XACT_E_RECOVERYALREADYDONE => 0x8004D104 as u32,
            ITF::XACT_E_PROTOCOL => 0x8004D105 as u32,
            ITF::XACT_E_RM_FAILURE => 0x8004D106 as u32,
            ITF::XACT_E_RECOVERY_FAILED => 0x8004D107 as u32,
            ITF::XACT_E_LU_NOT_FOUND => 0x8004D108 as u32,
            ITF::XACT_E_DUPLICATE_LU => 0x8004D109 as u32,
            ITF::XACT_E_LU_NOT_CONNECTED => 0x8004D10A as u32,
            ITF::XACT_E_DUPLICATE_TRANSID => 0x8004D10B as u32,
            ITF::SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED => 0x8004D10B as u32,
            ITF::XACT_E_LU_BUSY => 0x8004D10C as u32,
            ITF::XACT_E_LU_NO_RECOVERY_PROCESS => 0x8004D10D as u32,
            ITF::XACT_E_LU_DOWN => 0x8004D10E as u32,
            ITF::XACT_E_LU_RECOVERING => 0x8004D10F as u32,
            ITF::XACT_E_LU_RECOVERY_MISMATCH => 0x8004D110 as u32,
            ITF::XACT_E_RM_UNAVAILABLE => 0x8004D111 as u32,
            ITF::CONTEXT_E_ABORTED => 0x8004E002 as u32,
            ITF::CONTEXT_E_ABORTING => 0x8004E003 as u32,
            ITF::CONTEXT_E_NOCONTEXT => 0x8004E004 as u32,
            ITF::CONTEXT_E_WOULD_DEADLOCK => 0x8004E005 as u32,
            ITF::CONTEXT_E_SYNCH_TIMEOUT => 0x8004E006 as u32,
            ITF::CONTEXT_E_OLDREF => 0x8004E007 as u32,
            ITF::CONTEXT_E_ROLENOTFOUND => 0x8004E00C as u32,
            ITF::CONTEXT_E_TMNOTAVAILABLE => 0x8004E00F as u32,
            ITF::CO_E_ACTIVATIONFAILED => 0x8004E021 as u32,
            ITF::CO_E_ACTIVATIONFAILED_EVENTLOGGED => 0x8004E022 as u32,
            ITF::CO_E_ACTIVATIONFAILED_CATALOGERROR => 0x8004E023 as u32,
            ITF::CO_E_ACTIVATIONFAILED_TIMEOUT => 0x8004E024 as u32,
            ITF::CO_E_INITIALIZATIONFAILED => 0x8004E025 as u32,
            ITF::CONTEXT_E_NOJIT => 0x8004E026 as u32,
            ITF::SL_E_INVALID_USE_OF_ADD_ON_PKEY => 0x8004E026 as u32,
            ITF::CONTEXT_E_NOTRANSACTION => 0x8004E027 as u32,
            ITF::CO_E_THREADINGMODEL_CHANGED => 0x8004E028 as u32,
            ITF::CO_E_NOIISINTRINSICS => 0x8004E029 as u32,
            ITF::CO_E_NOCOOKIES => 0x8004E02A as u32,
            ITF::CO_E_DBERROR => 0x8004E02B as u32,
            ITF::CO_E_NOTPOOLED => 0x8004E02C as u32,
            ITF::CO_E_NOTCONSTRUCTED => 0x8004E02D as u32,
            ITF::CO_E_NOSYNCHRONIZATION => 0x8004E02E as u32,
            ITF::CO_E_ISOLEVELMISMATCH => 0x8004E02F as u32,
            ITF::CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED => 0x8004E030 as u32,
            ITF::CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED => 0x8004E031 as u32,
            ITF::SL_E_SFS_INVALID_FS_VERSION => 0x8004E101 as u32,
            ITF::SL_E_SFS_INVALID_FD_TABLE => 0x8004E102 as u32,
            ITF::SL_E_SFS_INVALID_SYNC => 0x8004E103 as u32,
            ITF::SL_E_SFS_BAD_TOKEN_NAME => 0x8004E104 as u32,
            ITF::SL_E_SFS_BAD_TOKEN_EXT => 0x8004E105 as u32,
            ITF::SL_E_SFS_DUPLICATE_TOKEN_NAME => 0x8004E106 as u32,
            ITF::SL_E_SFS_TOKEN_SIZE_MISMATCH => 0x8004E107 as u32,
            ITF::SL_E_SFS_INVALID_TOKEN_DATA_HASH => 0x8004E108 as u32,
            ITF::SL_E_SFS_FILE_READ_ERROR => 0x8004E109 as u32,
            ITF::SL_E_SFS_FILE_WRITE_ERROR => 0x8004E10A as u32,
            ITF::SL_E_SFS_INVALID_FILE_POSITION => 0x8004E10B as u32,
            ITF::SL_E_SFS_NO_ACTIVE_TRANSACTION => 0x8004E10C as u32,
            ITF::SL_E_SFS_INVALID_FS_HEADER => 0x8004E10D as u32,
            ITF::SL_E_SFS_INVALID_TOKEN_DESCRIPTOR => 0x8004E10E as u32,
            ITF::FTE_E_FD_NO_IPERSIST_INTERFACE => 0x8004FD00 as u32,
            ITF::FTE_E_FD_IFILTER_INIT_FAILED => 0x8004FD01 as u32,
            ITF::FTE_E_FD_FAILED_TO_LOAD_IFILTER => 0x8004FD02 as u32,
            ITF::FTE_E_FD_DOC_TIMEOUT => 0x8004FD03 as u32,
            ITF::FTE_E_FD_UNEXPECTED_EXIT => 0x8004FD04 as u32,
            ITF::FTE_E_FD_DOC_UNEXPECTED_EXIT => 0x8004FD05 as u32,
            ITF::FTE_E_FD_NOISE_NO_TEXT_FILTER => 0x8004FD06 as u32,
            ITF::FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER => 0x8004FD07 as u32,
            ITF::FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED => 0x8004FD08 as u32,
            ITF::FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED => 0x8004FD09 as u32,
            ITF::FTE_E_FD_OCCURRENCE_OVERFLOW => 0x8004FD0A as u32,
            ITF::FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION => 0x8004FD0B as u32,
            ITF::IO_ERR_CONFIGURATION_ERROR => 0xC0040003 as u32,
            ITF::IO_ERR_DRIVER_ERROR => 0xC0040004 as u32,
            ITF::IO_ERR_PARITY => 0xC0040005 as u32,
            ITF::IO_ERR_SEEK_ERROR => 0xC0040006 as u32,
            ITF::IO_ERR_BAD_BLOCK => 0xC0040007 as u32,
            ITF::IO_ERR_OVERRUN_ERROR => 0xC0040008 as u32,
            ITF::IO_ERR_TIMEOUT => 0xC0040009 as u32,
            ITF::IO_ERR_SEQUENCE => 0xC004000A as u32,
            ITF::IO_ERR_CONTROLLER_ERROR => 0xC004000B as u32,
            ITF::IO_ERR_INTERNAL_ERROR => 0xC004000C as u32,
            ITF::IO_ERR_INCORRECT_IRQL => 0xC004000D as u32,
            ITF::IO_ERR_INVALID_IOBASE => 0xC004000E as u32,
            ITF::IO_ERR_NOT_READY => 0xC004000F as u32,
            ITF::IO_ERR_INVALID_REQUEST => 0xC0040010 as u32,
            ITF::IO_ERR_VERSION => 0xC0040011 as u32,
            ITF::IO_ERR_LAYERED_FAILURE => 0xC0040012 as u32,
            ITF::IO_ERR_RESET => 0xC0040013 as u32,
            ITF::IO_ERR_PROTOCOL => 0xC0040014 as u32,
            ITF::IO_ERR_MEMORY_CONFLICT_DETECTED => 0xC0040015 as u32,
            ITF::IO_ERR_PORT_CONFLICT_DETECTED => 0xC0040016 as u32,
            ITF::IO_ERR_DMA_CONFLICT_DETECTED => 0xC0040017 as u32,
            ITF::IO_ERR_IRQ_CONFLICT_DETECTED => 0xC0040018 as u32,
            ITF::IO_ERR_BAD_FIRMWARE => 0xC0040019 as u32,
            ITF::IO_ERR_DMA_RESOURCE_CONFLICT => 0xC004001B as u32,
            ITF::IO_ERR_INTERRUPT_RESOURCE_CONFLICT => 0xC004001C as u32,
            ITF::IO_ERR_MEMORY_RESOURCE_CONFLICT => 0xC004001D as u32,
            ITF::IO_ERR_PORT_RESOURCE_CONFLICT => 0xC004001E as u32,
            ITF::IO_BAD_BLOCK_WITH_NAME => 0xC004001F as u32,
            ITF::IO_FILE_SYSTEM_CORRUPT => 0xC0040029 as u32,
            ITF::IO_FILE_QUOTA_CORRUPT => 0xC004002A as u32,
            ITF::IO_SYSTEM_SLEEP_FAILED => 0xC004002B as u32,
            ITF::IO_DUMP_POINTER_FAILURE => 0xC004002C as u32,
            ITF::IO_DUMP_DRIVER_LOAD_FAILURE => 0xC004002D as u32,
            ITF::IO_DUMP_INITIALIZATION_FAILURE => 0xC004002E as u32,
            ITF::IO_DUMP_DUMPFILE_CONFLICT => 0xC004002F as u32,
            ITF::IO_DUMP_DIRECT_CONFIG_FAILED => 0xC0040030 as u32,
            ITF::IO_DUMP_PAGE_CONFIG_FAILED => 0xC0040031 as u32,
            ITF::IO_FILE_SYSTEM_CORRUPT_WITH_NAME => 0xC0040037 as u32,
            ITF::IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER => 0xC004006C as u32,
            ITF::IO_ERR_PORT_TIMEOUT => 0xC0040075 as u32,
            ITF::IO_ERROR_DISK_RESOURCES_EXHAUSTED => 0xC0040096 as u32,
            ITF::IO_ERROR_IO_HARDWARE_ERROR => 0xC004009A as u32,
            ITF::ES_E_INVALID_RESPONSE => 0xC0040200 as u32,
            ITF::ES_E_UNPROVISIONED_HARDWARE => 0xC0040204 as u32,
            ITF::ES_E_UNSUPPORTED_HARDWARE => 0xC0040205 as u32,
            ITF::ES_E_INCOMPLETE_COMMAND => 0xC0040206 as u32,
            ITF::ES_E_BAD_SEQUENCE => 0xC0040207 as u32,
            ITF::ES_E_NO_PROBE => 0xC0040208 as u32,
            ITF::ES_E_INVALID_SILO => 0xC0040209 as u32,
            ITF::ES_E_INVALID_CAPABILITY => 0xC004020A as u32,
            ITF::ES_E_GROUP_POLICY_FORBIDDEN_USE => 0xC004020B as u32,
            ITF::ES_E_GROUP_POLICY_FORBIDDEN_OPERATION => 0xC004020C as u32,
            ITF::ES_E_INVALID_PARAM_COMBINATION => 0xC004020D as u32,
            ITF::ES_E_INVALID_PARAM_LENGTH => 0xC004020E as u32,
            ITF::ES_E_INCONSISTENT_PARAM_LENGTH => 0xC004020F as u32,
            ITF::ES_E_NO_AUTHENTICATION_REQUIRED => 0xC0040400 as u32,
            ITF::GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED => 0xC0040DB9 as u32,
            ITF::ES_E_INVALID_FIELD_IDENTIFIER => 0xC0041100 as u32,
            ITF::ES_E_CHALLENGE_MISMATCH => 0xC0041101 as u32,
            ITF::ES_E_CHALLENGE_SIZE_MISMATCH => 0xC0041102 as u32,
            ITF::ES_E_FRIENDLY_NAME_TOO_LONG => 0xC0041103 as u32,
            ITF::ES_E_SILO_NAME_TOO_LONG => 0xC0041104 as u32,
            ITF::ES_E_PASSWORD_TOO_LONG => 0xC0041105 as u32,
            ITF::ES_E_PASSWORD_HINT_TOO_LONG => 0xC0041106 as u32,
            ITF::ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE => 0xC0041107 as u32,
            ITF::ES_E_DEVICE_DIGEST_MISSING => 0xC0041108 as u32,
            ITF::ES_E_NOT_AUTHORIZED_UNEXPECTED => 0xC0041109 as u32,
            ITF::ES_E_AUTHORIZED_UNEXPECTED => 0xC004110A as u32,
            ITF::ES_E_PROVISIONED_UNEXPECTED => 0xC004110B as u32,
            ITF::ES_E_UNKNOWN_DIGEST_ALGORITHM => 0xC004110C as u32,
            ITF::QUTIL_E_INVALID_CODEPAGE => 0xC0041678 as u32,
            ITF::FILTER_E_CONTENTINDEXCORRUPT => 0xC0041734 as u32,
            ITF::CI_CORRUPT_DATABASE => 0xC0041800 as u32,
            ITF::CI_CORRUPT_CATALOG => 0xC0041801 as u32,
            ITF::CI_INVALID_PARTITION => 0xC0041802 as u32,
            ITF::CI_INVALID_PRIORITY => 0xC0041803 as u32,
            ITF::CI_NO_STARTING_KEY => 0xC0041804 as u32,
            ITF::CI_OUT_OF_INDEX_IDS => 0xC0041805 as u32,
            ITF::CI_NO_CATALOG => 0xC0041806 as u32,
            ITF::CI_CORRUPT_FILTER_BUFFER => 0xC0041807 as u32,
            ITF::CI_INVALID_INDEX => 0xC0041808 as u32,
            ITF::CI_PROPSTORE_INCONSISTENCY => 0xC0041809 as u32,
            ITF::CI_INCORRECT_VERSION => 0xC0041821 as u32,
            ITF::CI_E_ENUMERATION_STARTED => 0xC0041822 as u32,
            ITF::CI_E_PROPERTY_TOOLARGE => 0xC0041823 as u32,
            ITF::CI_E_CLIENT_FILTER_ABORT => 0xC0041824 as u32,
            ITF::CI_E_CORRUPT_FWIDX => 0xC004182D as u32,
            ITF::CI_E_DIACRITIC_SETTINGS_DIFFER => 0xC004182E as u32,
            ITF::CI_E_NO_CATALOG_MANAGER => 0xC0041831 as u32,
            ITF::FTE_E_NO_PROPERTY_STORE => 0xC004365A as u32,
            ITF::SL_E_SRV_INVALID_PUBLISH_LICENSE => 0xC004B001 as u32,
            ITF::SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE => 0xC004B002 as u32,
            ITF::SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE => 0xC004B003 as u32,
            ITF::SL_E_SRV_INVALID_LICENSE_STRUCTURE => 0xC004B004 as u32,
            ITF::SL_E_SRV_AUTHORIZATION_FAILED => 0xC004B005 as u32,
            ITF::SL_E_SRV_INVALID_BINDING => 0xC004B006 as u32,
            ITF::SL_E_SRV_SERVER_PONG => 0xC004B007 as u32,
            ITF::SL_E_SRV_INVALID_PAYLOAD => 0xC004B008 as u32,
            ITF::SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE => 0xC004B009 as u32,
            ITF::SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND => 0xC004B010 as u32,
            ITF::SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC => 0xC004B011 as u32,
            ITF::SL_E_SRV_GENERAL_ERROR => 0xC004B100 as u32,
            ITF::SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE => 0xC004C001 as u32,
            ITF::SL_E_CHPA_INVALID_BINDING => 0xC004C002 as u32,
            ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED => 0xC004C003 as u32,
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY => 0xC004C004 as u32,
            ITF::SL_E_CHPA_BINDING_NOT_FOUND => 0xC004C005 as u32,
            ITF::SL_E_CHPA_BINDING_MAPPING_NOT_FOUND => 0xC004C006 as u32,
            ITF::SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY => 0xC004C007 as u32,
            ITF::SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED => 0xC004C008 as u32,
            ITF::SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND => 0xC004C009 as u32,
            ITF::SL_E_CHPA_INVALID_PRODUCT_DATA_ID => 0xC004C00A as u32,
            ITF::SL_E_CHPA_INVALID_PRODUCT_DATA => 0xC004C00B as u32,
            ITF::SL_E_CHPA_SYSTEM_ERROR => 0xC004C00C as u32,
            ITF::SL_E_CHPA_INVALID_ACTCONFIG_ID => 0xC004C00D as u32,
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH => 0xC004C00E as u32,
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT => 0xC004C00F as u32,
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR => 0xC004C010 as u32,
            ITF::SL_E_CHPA_INVALID_BINDING_URI => 0xC004C011 as u32,
            ITF::SL_E_CHPA_NETWORK_ERROR => 0xC004C012 as u32,
            ITF::SL_E_CHPA_DATABASE_ERROR => 0xC004C013 as u32,
            ITF::SL_E_CHPA_INVALID_ARGUMENT => 0xC004C014 as u32,
            ITF::SL_E_CHPA_RESPONSE_NOT_AVAILABLE => 0xC004C015 as u32,
            ITF::SL_E_CHPA_OEM_SLP_COA0 => 0xC004C016 as u32,
            ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION => 0xC004C017 as u32,
            ITF::SL_E_CHPA_DMAK_LIMIT_EXCEEDED => 0xC004C020 as u32,
            ITF::SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED => 0xC004C021 as u32,
            ITF::SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND => 0xC004C022 as u32,
            ITF::SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND => 0xC004C023 as u32,
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE => 0xC004C030 as u32,
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE => 0xC004C031 as u32,
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE => 0xC004C032 as u32,
            ITF::SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED => 0xC004C033 as u32,
            ITF::SL_E_CHPA_NO_RULES_TO_ACTIVATE => 0xC004C04F as u32,
            ITF::SL_E_CHPA_GENERAL_ERROR => 0xC004C050 as u32,
            ITF::SL_E_CHPA_DIGITALMARKER_INVALID_BINDING => 0xC004C051 as u32,
            ITF::SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED => 0xC004C052 as u32,
            ITF::SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY => 0xC004C060 as u32,
            ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE => 0xC004C291 as u32,
            ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED => 0xC004C292 as u32,
            ITF::SL_E_INVALID_TEMPLATE_ID => 0xC004C2F6 as u32,
            ITF::SL_E_INVALID_XML_BLOB => 0xC004C2FA as u32,
            ITF::SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND => 0xC004C327 as u32,
            ITF::SL_E_INVALID_CLIENT_TOKEN => 0xC004C328 as u32,
            ITF::SL_E_INVALID_OFFLINE_BLOB => 0xC004C329 as u32,
            ITF::SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND => 0xC004C32A as u32,
            ITF::SL_E_INVALID_OSVERSION_TEMPLATEID => 0xC004C32B as u32,
            ITF::SL_E_OFFLINE_GENUINE_BLOB_REVOKED => 0xC004C32C as u32,
            ITF::SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND => 0xC004C32D as u32,
            ITF::SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA => 0xC004C3FF as u32,
            ITF::SL_E_INVALID_OS_FOR_PRODUCT_KEY => 0xC004C401 as u32,
            ITF::SL_E_INVALID_FILE_HASH => 0xC004C4A1 as u32,
            ITF::SL_E_VALIDATION_BLOCKED_PRODUCT_KEY => 0xC004C4A2 as u32,
            ITF::SL_E_MISMATCHED_KEY_TYPES => 0xC004C4A4 as u32,
            ITF::SL_E_VALIDATION_INVALID_PRODUCT_KEY => 0xC004C4A5 as u32,
            ITF::SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA => 0xC004C4A7 as u32,
            ITF::SL_E_INVALID_LICENSE_STATE => 0xC004C4A8 as u32,
            ITF::SL_E_IP_LOCATION_FALIED => 0xC004C4A9 as u32,
            ITF::SL_E_SOFTMOD_EXPLOIT_DETECTED => 0xC004C4AB as u32,
            ITF::SL_E_INVALID_TOKEN_DATA => 0xC004C4AC as u32,
            ITF::SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES => 0xC004C4AD as u32,
            ITF::SL_E_HEALTH_CHECK_FAILED_MUI_FILES => 0xC004C4AE as u32,
            ITF::SL_E_INVALID_AD_DATA => 0xC004C4AF as u32,
            ITF::SL_E_INVALID_RSDP_COUNT => 0xC004C4B0 as u32,
            ITF::SL_E_ENGINE_DETECTED_EXPLOIT => 0xC004C4B1 as u32,
            ITF::SL_E_NOTIFICATION_BREACH_DETECTED => 0xC004C531 as u32,
            ITF::SL_E_NOTIFICATION_GRACE_EXPIRED => 0xC004C532 as u32,
            ITF::SL_E_NOTIFICATION_OTHER_REASONS => 0xC004C533 as u32,
            ITF::SL_E_NON_GENUINE_STATUS_LAST => 0xC004C600 as u32,
            ITF::SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND => 0xC004C700 as u32,
            ITF::SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID => 0xC004C750 as u32,
            ITF::SL_E_CHPA_UNKNOWN_PROPERTY_NAME => 0xC004C751 as u32,
            ITF::SL_E_CHPA_UNKNOWN_PROPERTY_ID => 0xC004C752 as u32,
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING => 0xC004C755 as u32,
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING => 0xC004C756 as u32,
            ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING => 0xC004C757 as u32,
            ITF::SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML => 0xC004C758 as u32,
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY => 0xC004C75A as u32,
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY => 0xC004C75B as u32,
            ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY => 0xC004C75C as u32,
            ITF::SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE => 0xC004C764 as u32,
            ITF::SL_E_CHPA_PRODUCT_KEY_BEING_USED => 0xC004C770 as u32,
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD => 0xC004C780 as u32,
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD => 0xC004C781 as u32,
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_LICENSE => 0xC004D000 as u32,
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE => 0xC004D009 as u32,
            ITF::SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS => 0xC004D00C as u32,
            ITF::SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY => 0xC004D012 as u32,
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_HANDLE => 0xC004D02C as u32,
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH => 0xC004D055 as u32,
            ITF::SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER => 0xC004D073 as u32,
            ITF::SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED => 0xC004D081 as u32,
            ITF::SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED => 0xC004D101 as u32,
            ITF::SL_REMAPPING_SP_STATUS_GENERIC_FAILURE => 0xC004D103 as u32,
            ITF::SL_REMAPPING_SP_STATUS_INVALIDARG => 0xC004D104 as u32,
            ITF::SL_REMAPPING_SP_STATUS_ALREADY_EXISTS => 0xC004D105 as u32,
            ITF::SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER => 0xC004D107 as u32,
            ITF::SL_REMAPPING_SP_STATUS_INVALIDDATA => 0xC004D108 as u32,
            ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL => 0xC004D109 as u32,
            ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION => 0xC004D10A as u32,
            ITF::SL_REMAPPING_SP_STATUS_NO_MORE_DATA => 0xC004D10C as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH => 0xC004D201 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH => 0xC004D202 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER => 0xC004D203 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE => 0xC004D204 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID => 0xC004D205 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID => 0xC004D206 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID => 0xC004D207 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID => 0xC004D208 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED => 0xC004D209 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE => 0xC004D20A as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND => 0xC004D20B as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED => 0xC004D20C as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH => 0xC004D20D as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE => 0xC004D20E as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK => 0xC004D20F as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT => 0xC004D210 as u32,
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING => 0xC004D211 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED => 0xC004D301 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_REARMED => 0xC004D302 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_RECREATED => 0xC004D303 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND => 0xC004D304 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS => 0xC004D305 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG => 0xC004D306 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED => 0xC004D307 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG => 0xC004D308 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING => 0xC004D309 as u32,
            ITF::SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS => 0xC004D30A as u32,
            ITF::SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND => 0xC004D30B as u32,
            ITF::SL_REMAPPING_SP_PUB_TIMER_EXPIRED => 0xC004D30C as u32,
            ITF::SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG => 0xC004D30D as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_FULL => 0xC004D30E as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY => 0xC004D310 as u32,
            ITF::SL_REMAPPING_SP_PUB_TIMER_READ_ONLY => 0xC004D311 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY => 0xC004D312 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND => 0xC004D313 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED => 0xC004D314 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND => 0xC004D315 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE => 0xC004D316 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID => 0xC004D317 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION => 0xC004D318 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA => 0xC004D319 as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA => 0xC004D31A as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH => 0xC004D31B as u32,
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH => 0xC004D31C as u32,
            ITF::SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION => 0xC004D401 as u32,
            ITF::SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED => 0xC004D402 as u32,
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER => 0xC004D501 as u32,
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED => 0xC004D502 as u32,
            ITF::SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT => 0xC004D701 as u32,
            ITF::SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER => 0xC004D702 as u32,
            ITF::SL_E_INVALID_CONTEXT => 0xC004E001 as u32,
            ITF::SL_E_TOKEN_STORE_INVALID_STATE => 0xC004E002 as u32,
            ITF::SL_E_EVALUATION_FAILED => 0xC004E003 as u32,
            ITF::SL_E_NOT_EVALUATED => 0xC004E004 as u32,
            ITF::SL_E_NOT_ACTIVATED => 0xC004E005 as u32,
            ITF::SL_E_INVALID_GUID => 0xC004E006 as u32,
            ITF::SL_E_TOKSTO_TOKEN_NOT_FOUND => 0xC004E007 as u32,
            ITF::SL_E_TOKSTO_NO_PROPERTIES => 0xC004E008 as u32,
            ITF::SL_E_TOKSTO_NOT_INITIALIZED => 0xC004E009 as u32,
            ITF::SL_E_TOKSTO_ALREADY_INITIALIZED => 0xC004E00A as u32,
            ITF::SL_E_TOKSTO_NO_ID_SET => 0xC004E00B as u32,
            ITF::SL_E_TOKSTO_CANT_CREATE_FILE => 0xC004E00C as u32,
            ITF::SL_E_TOKSTO_CANT_WRITE_TO_FILE => 0xC004E00D as u32,
            ITF::SL_E_TOKSTO_CANT_READ_FILE => 0xC004E00E as u32,
            ITF::SL_E_TOKSTO_CANT_PARSE_PROPERTIES => 0xC004E00F as u32,
            ITF::SL_E_TOKSTO_PROPERTY_NOT_FOUND => 0xC004E010 as u32,
            ITF::SL_E_TOKSTO_INVALID_FILE => 0xC004E011 as u32,
            ITF::SL_E_TOKSTO_CANT_CREATE_MUTEX => 0xC004E012 as u32,
            ITF::SL_E_TOKSTO_CANT_ACQUIRE_MUTEX => 0xC004E013 as u32,
            ITF::SL_E_TOKSTO_NO_TOKEN_DATA => 0xC004E014 as u32,
            ITF::SL_E_EUL_CONSUMPTION_FAILED => 0xC004E015 as u32,
            ITF::SL_E_PKEY_INVALID_CONFIG => 0xC004E016 as u32,
            ITF::SL_E_PKEY_INVALID_UNIQUEID => 0xC004E017 as u32,
            ITF::SL_E_PKEY_INVALID_ALGORITHM => 0xC004E018 as u32,
            ITF::SL_E_PKEY_INTERNAL_ERROR => 0xC004E019 as u32,
            ITF::SL_E_LICENSE_INVALID_ADDON_INFO => 0xC004E01A as u32,
            ITF::SL_E_HWID_ERROR => 0xC004E01B as u32,
            ITF::SL_E_PKEY_INVALID_KEYCHANGE1 => 0xC004E01C as u32,
            ITF::SL_E_PKEY_INVALID_KEYCHANGE2 => 0xC004E01D as u32,
            ITF::SL_E_PKEY_INVALID_KEYCHANGE3 => 0xC004E01E as u32,
            ITF::SL_E_POLICY_OTHERINFO_MISMATCH => 0xC004E020 as u32,
            ITF::SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID => 0xC004E021 as u32,
            ITF::SL_E_SECURE_STORE_ID_MISMATCH => 0xC004E022 as u32,
            ITF::SL_E_INVALID_RULESET_RULE => 0xC004E023 as u32,
            ITF::SL_E_INVALID_CONTEXT_DATA => 0xC004E024 as u32,
            ITF::SL_E_INVALID_HASH => 0xC004E025 as u32,
            ITF::SL_E_WINDOWS_VERSION_MISMATCH => 0xC004E027 as u32,
            ITF::SL_E_ACTIVATION_IN_PROGRESS => 0xC004E028 as u32,
            ITF::SL_E_STORE_UPGRADE_TOKEN_REQUIRED => 0xC004E029 as u32,
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION => 0xC004E02A as u32,
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_PID => 0xC004E02B as u32,
            ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED => 0xC004E02C as u32,
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION => 0xC004E02D as u32,
            ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED => 0xC004E02E as u32,
            ITF::SL_E_INTERNAL_ERROR => 0xC004F001 as u32,
            ITF::SL_E_RIGHT_NOT_CONSUMED => 0xC004F002 as u32,
            ITF::SL_E_USE_LICENSE_NOT_INSTALLED => 0xC004F003 as u32,
            ITF::SL_E_MISMATCHED_PKEY_RANGE => 0xC004F004 as u32,
            ITF::SL_E_MISMATCHED_PID => 0xC004F005 as u32,
            ITF::SL_E_EXTERNAL_SIGNATURE_NOT_FOUND => 0xC004F006 as u32,
            ITF::SL_E_RAC_NOT_AVAILABLE => 0xC004F007 as u32,
            ITF::SL_E_SPC_NOT_AVAILABLE => 0xC004F008 as u32,
            ITF::SL_E_GRACE_TIME_EXPIRED => 0xC004F009 as u32,
            ITF::SL_E_MISMATCHED_APPID => 0xC004F00A as u32,
            ITF::SL_E_NO_PID_CONFIG_DATA => 0xC004F00B as u32,
            ITF::SL_E_MISMATCHED_SECURITY_PROCESSOR => 0xC004F00E as u32,
            ITF::SL_E_OUT_OF_TOLERANCE => 0xC004F00F as u32,
            ITF::SL_E_INVALID_PKEY => 0xC004F010 as u32,
            ITF::SL_E_LICENSE_FILE_NOT_INSTALLED => 0xC004F011 as u32,
            ITF::SL_E_VALUE_NOT_FOUND => 0xC004F012 as u32,
            ITF::SL_E_RIGHT_NOT_GRANTED => 0xC004F013 as u32,
            ITF::SL_E_PKEY_NOT_INSTALLED => 0xC004F014 as u32,
            ITF::SL_E_PRODUCT_SKU_NOT_INSTALLED => 0xC004F015 as u32,
            ITF::SL_E_NOT_SUPPORTED => 0xC004F016 as u32,
            ITF::SL_E_PUBLISHING_LICENSE_NOT_INSTALLED => 0xC004F017 as u32,
            ITF::SL_E_LICENSE_SERVER_URL_NOT_FOUND => 0xC004F018 as u32,
            ITF::SL_E_INVALID_EVENT_ID => 0xC004F019 as u32,
            ITF::SL_E_EVENT_NOT_REGISTERED => 0xC004F01A as u32,
            ITF::SL_E_EVENT_ALREADY_REGISTERED => 0xC004F01B as u32,
            ITF::SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE => 0xC004F01C as u32,
            ITF::SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED => 0xC004F01D as u32,
            ITF::SL_E_DATATYPE_MISMATCHED => 0xC004F01E as u32,
            ITF::SL_E_INVALID_LICENSE => 0xC004F01F as u32,
            ITF::SL_E_INVALID_PACKAGE => 0xC004F020 as u32,
            ITF::SL_E_VALIDITY_TIME_EXPIRED => 0xC004F021 as u32,
            ITF::SL_E_LICENSE_AUTHORIZATION_FAILED => 0xC004F022 as u32,
            ITF::SL_E_LICENSE_DECRYPTION_FAILED => 0xC004F023 as u32,
            ITF::SL_E_WINDOWS_INVALID_LICENSE_STATE => 0xC004F024 as u32,
            ITF::SL_E_LUA_ACCESSDENIED => 0xC004F025 as u32,
            ITF::SL_E_PROXY_KEY_NOT_FOUND => 0xC004F026 as u32,
            ITF::SL_E_TAMPER_DETECTED => 0xC004F027 as u32,
            ITF::SL_E_POLICY_CACHE_INVALID => 0xC004F028 as u32,
            ITF::SL_E_INVALID_RUNNING_MODE => 0xC004F029 as u32,
            ITF::SL_E_SLP_NOT_SIGNED => 0xC004F02A as u32,
            ITF::SL_E_CIDIID_INVALID_DATA => 0xC004F02C as u32,
            ITF::SL_E_CIDIID_INVALID_VERSION => 0xC004F02D as u32,
            ITF::SL_E_CIDIID_VERSION_NOT_SUPPORTED => 0xC004F02E as u32,
            ITF::SL_E_CIDIID_INVALID_DATA_LENGTH => 0xC004F02F as u32,
            ITF::SL_E_CIDIID_NOT_DEPOSITED => 0xC004F030 as u32,
            ITF::SL_E_CIDIID_MISMATCHED => 0xC004F031 as u32,
            ITF::SL_E_INVALID_BINDING_BLOB => 0xC004F032 as u32,
            ITF::SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED => 0xC004F033 as u32,
            ITF::SL_E_EUL_NOT_AVAILABLE => 0xC004F034 as u32,
            ITF::SL_E_VL_NOT_WINDOWS_SLP => 0xC004F035 as u32,
            ITF::SL_E_VL_NOT_ENOUGH_COUNT => 0xC004F038 as u32,
            ITF::SL_E_VL_BINDING_SERVICE_NOT_ENABLED => 0xC004F039 as u32,
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED => 0xC004F041 as u32,
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH => 0xC004F042 as u32,
            ITF::SL_E_PROXY_POLICY_NOT_UPDATED => 0xC004F047 as u32,
            ITF::SL_E_CIDIID_INVALID_CHECK_DIGITS => 0xC004F04D as u32,
            ITF::SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND => 0xC004F04F as u32,
            ITF::SL_E_INVALID_PRODUCT_KEY => 0xC004F050 as u32,
            ITF::SL_E_BLOCKED_PRODUCT_KEY => 0xC004F051 as u32,
            ITF::SL_E_DUPLICATE_POLICY => 0xC004F052 as u32,
            ITF::SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE => 0xC004F053 as u32,
            ITF::SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED => 0xC004F054 as u32,
            ITF::SL_E_BASE_SKU_NOT_AVAILABLE => 0xC004F055 as u32,
            ITF::SL_E_VL_MACHINE_NOT_BOUND => 0xC004F056 as u32,
            ITF::SL_E_SLP_MISSING_ACPI_SLIC => 0xC004F057 as u32,
            ITF::SL_E_SLP_MISSING_SLP_MARKER => 0xC004F058 as u32,
            ITF::SL_E_SLP_BAD_FORMAT => 0xC004F059 as u32,
            ITF::SL_E_INVALID_PACKAGE_VERSION => 0xC004F060 as u32,
            ITF::SL_E_PKEY_INVALID_UPGRADE => 0xC004F061 as u32,
            ITF::SL_E_ISSUANCE_LICENSE_NOT_INSTALLED => 0xC004F062 as u32,
            ITF::SL_E_SLP_OEM_CERT_MISSING => 0xC004F063 as u32,
            ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED => 0xC004F064 as u32,
            ITF::SL_E_DEPENDENT_PROPERTY_NOT_SET => 0xC004F066 as u32,
            ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2 => 0xC004F067 as u32,
            ITF::SL_E_MISMATCHED_PRODUCT_SKU => 0xC004F069 as u32,
            ITF::SL_E_OPERATION_NOT_ALLOWED => 0xC004F06A as u32,
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED => 0xC004F06B as u32,
            ITF::SL_E_VL_INVALID_TIMESTAMP => 0xC004F06C as u32,
            ITF::SL_E_PLUGIN_INVALID_MANIFEST => 0xC004F071 as u32,
            ITF::SL_E_APPLICATION_POLICIES_MISSING => 0xC004F072 as u32,
            ITF::SL_E_APPLICATION_POLICIES_NOT_LOADED => 0xC004F073 as u32,
            ITF::SL_E_VL_BINDING_SERVICE_UNAVAILABLE => 0xC004F074 as u32,
            ITF::SL_E_SERVICE_STOPPING => 0xC004F075 as u32,
            ITF::SL_E_PLUGIN_NOT_REGISTERED => 0xC004F076 as u32,
            ITF::SL_E_AUTHN_WRONG_VERSION => 0xC004F077 as u32,
            ITF::SL_E_AUTHN_MISMATCHED_KEY => 0xC004F078 as u32,
            ITF::SL_E_AUTHN_CHALLENGE_NOT_SET => 0xC004F079 as u32,
            ITF::SL_E_AUTHN_CANT_VERIFY => 0xC004F07A as u32,
            ITF::SL_E_SERVICE_RUNNING => 0xC004F07B as u32,
            ITF::SL_E_SLP_INVALID_MARKER_VERSION => 0xC004F07C as u32,
            ITF::SL_E_INVALID_PRODUCT_KEY_TYPE => 0xC004F07D as u32,
            ITF::SL_E_CIDIID_MISMATCHED_PKEY => 0xC004F07E as u32,
            ITF::SL_E_CIDIID_NOT_BOUND => 0xC004F07F as u32,
            ITF::SL_E_LICENSE_NOT_BOUND => 0xC004F080 as u32,
            ITF::SL_E_VL_AD_AO_NOT_FOUND => 0xC004F081 as u32,
            ITF::SL_E_VL_AD_AO_NAME_TOO_LONG => 0xC004F082 as u32,
            ITF::SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED => 0xC004F083 as u32,
            ITF::SL_E_NOT_GENUINE => 0xC004F200 as u32,
            ITF::SL_E_EDITION_MISMATCHED => 0xC004F210 as u32,
            ITF::SL_E_TKA_CHALLENGE_EXPIRED => 0xC004F301 as u32,
            ITF::SL_E_TKA_SILENT_ACTIVATION_FAILURE => 0xC004F302 as u32,
            ITF::SL_E_TKA_INVALID_CERT_CHAIN => 0xC004F303 as u32,
            ITF::SL_E_TKA_GRANT_NOT_FOUND => 0xC004F304 as u32,
            ITF::SL_E_TKA_CERT_NOT_FOUND => 0xC004F305 as u32,
            ITF::SL_E_TKA_INVALID_SKU_ID => 0xC004F306 as u32,
            ITF::SL_E_TKA_INVALID_BLOB => 0xC004F307 as u32,
            ITF::SL_E_TKA_TAMPERED_CERT_CHAIN => 0xC004F308 as u32,
            ITF::SL_E_TKA_CHALLENGE_MISMATCH => 0xC004F309 as u32,
            ITF::SL_E_TKA_INVALID_CERTIFICATE => 0xC004F30A as u32,
            ITF::SL_E_TKA_INVALID_SMARTCARD => 0xC004F30B as u32,
            ITF::SL_E_TKA_FAILED_GRANT_PARSING => 0xC004F30C as u32,
            ITF::SL_E_TKA_INVALID_THUMBPRINT => 0xC004F30D as u32,
            ITF::SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND => 0xC004F30E as u32,
            ITF::SL_E_TKA_CRITERIA_MISMATCH => 0xC004F30F as u32,
            ITF::SL_E_TKA_TPID_MISMATCH => 0xC004F310 as u32,
            ITF::SL_E_TKA_SOFT_CERT_DISALLOWED => 0xC004F311 as u32,
            ITF::SL_E_TKA_SOFT_CERT_INVALID => 0xC004F312 as u32,
            ITF::SL_E_TKA_CERT_CNG_NOT_AVAILABLE => 0xC004F313 as u32,
            ITF::E_RM_UNKNOWN_ERROR => 0xC004FC03 as u32,
            ITF::SL_E_VALIDITY_PERIOD_EXPIRED => 0xC004FC07 as u32,
            ITF::SL_E_IA_THROTTLE_LIMIT_EXCEEDED => 0xC004FD00 as u32,
            ITF::SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM => 0xC004FD01 as u32,
            ITF::SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED => 0xC004FD02 as u32,
            ITF::SL_E_IA_ID_MISMATCH => 0xC004FD03 as u32,
            ITF::SL_E_IA_MACHINE_NOT_BOUND => 0xC004FD04 as u32,
            ITF::SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION => 0xC004FE00 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            ITF::OLE_S_USEREG => RawError::Kind(ITF::OLE_S_USEREG),
            ITF::OLE_S_STATIC => RawError::Kind(ITF::OLE_S_STATIC),
            ITF::MS_S_PENDING => RawError::Kind(ITF::MS_S_PENDING),
            ITF::OLE_S_MAC_CLIPFORMAT => RawError::Kind(ITF::OLE_S_MAC_CLIPFORMAT),
            ITF::MS_S_NOUPDATE => RawError::Kind(ITF::MS_S_NOUPDATE),
            ITF::MS_S_ENDOFSTREAM => RawError::Kind(ITF::MS_S_ENDOFSTREAM),
            ITF::OLE_S_LAST => RawError::Kind(ITF::OLE_S_LAST),
            ITF::DRAGDROP_S_DROP => RawError::Kind(ITF::DRAGDROP_S_DROP),
            ITF::DRAGDROP_S_CANCEL => RawError::Kind(ITF::DRAGDROP_S_CANCEL),
            ITF::DRAGDROP_S_USEDEFAULTCURSORS => RawError::Kind(ITF::DRAGDROP_S_USEDEFAULTCURSORS),
            ITF::VFW_S_NO_MORE_ITEMS => RawError::Kind(ITF::VFW_S_NO_MORE_ITEMS),
            ITF::DATA_S_SAMEFORMATETC => RawError::Kind(ITF::DATA_S_SAMEFORMATETC),
            ITF::VIEW_S_ALREADY_FROZEN => RawError::Kind(ITF::VIEW_S_ALREADY_FROZEN),
            ITF::CACHE_S_FORMATETC_NOTSUPPORTED => RawError::Kind(ITF::CACHE_S_FORMATETC_NOTSUPPORTED),
            ITF::CACHE_S_SAMECACHE => RawError::Kind(ITF::CACHE_S_SAMECACHE),
            ITF::CACHE_S_SOMECACHES_NOTUPDATED => RawError::Kind(ITF::CACHE_S_SOMECACHES_NOTUPDATED),
            ITF::OLEOBJ_S_INVALIDVERB => RawError::Kind(ITF::OLEOBJ_S_INVALIDVERB),
            ITF::OLEOBJ_S_CANNOT_DOVERB_NOW => RawError::Kind(ITF::OLEOBJ_S_CANNOT_DOVERB_NOW),
            ITF::OLEOBJ_S_INVALIDHWND => RawError::Kind(ITF::OLEOBJ_S_INVALIDHWND),
            ITF::INPLACE_S_TRUNCATED => RawError::Kind(ITF::INPLACE_S_TRUNCATED),
            ITF::CONVERT10_S_NO_PRESENTATION => RawError::Kind(ITF::CONVERT10_S_NO_PRESENTATION),
            ITF::MK_S_REDUCED_TO_SELF => RawError::Kind(ITF::MK_S_REDUCED_TO_SELF),
            ITF::MK_S_ME => RawError::Kind(ITF::MK_S_ME),
            ITF::MK_S_HIM => RawError::Kind(ITF::MK_S_HIM),
            ITF::MK_S_US => RawError::Kind(ITF::MK_S_US),
            ITF::MK_S_MONIKERALREADYREGISTERED => RawError::Kind(ITF::MK_S_MONIKERALREADYREGISTERED),
            ITF::MK_S_ASYNCHRONOUS => RawError::Kind(ITF::MK_S_ASYNCHRONOUS),
            ITF::EVENT_S_SOME_SUBSCRIBERS_FAILED => RawError::Kind(ITF::EVENT_S_SOME_SUBSCRIBERS_FAILED),
            ITF::IMAPI_S_PROPERTIESIGNORED => RawError::Kind(ITF::IMAPI_S_PROPERTIESIGNORED),
            ITF::MPEG2_S_MORE_DATA_AVAILABLE => RawError::Kind(ITF::MPEG2_S_MORE_DATA_AVAILABLE),
            ITF::IMAPI_S_BUFFER_TO_SMALL => RawError::Kind(ITF::IMAPI_S_BUFFER_TO_SMALL),
            ITF::MPEG2_S_NO_MORE_DATA_AVAILABLE => RawError::Kind(ITF::MPEG2_S_NO_MORE_DATA_AVAILABLE),
            ITF::EVENT_S_NOSUBSCRIBERS => RawError::Kind(ITF::EVENT_S_NOSUBSCRIBERS),
            ITF::MPEG2_S_SG_INFO_FOUND => RawError::Kind(ITF::MPEG2_S_SG_INFO_FOUND),
            ITF::_MAPI_W_NO_SERVICE => RawError::Kind(ITF::_MAPI_W_NO_SERVICE),
            ITF::MPEG2_S_SG_INFO_NOT_FOUND => RawError::Kind(ITF::MPEG2_S_SG_INFO_NOT_FOUND),
            ITF::MPEG2_S_MPE_INFO_FOUND => RawError::Kind(ITF::MPEG2_S_MPE_INFO_FOUND),
            ITF::MPEG2_S_MPE_INFO_NOT_FOUND => RawError::Kind(ITF::MPEG2_S_MPE_INFO_NOT_FOUND),
            ITF::MPEG2_S_NEW_MODULE_VERSION => RawError::Kind(ITF::MPEG2_S_NEW_MODULE_VERSION),
            ITF::VFW_S_DUPLICATE_NAME => RawError::Kind(ITF::VFW_S_DUPLICATE_NAME),
            ITF::VFW_S_STATE_INTERMEDIATE => RawError::Kind(ITF::VFW_S_STATE_INTERMEDIATE),
            ITF::VFW_S_PARTIAL_RENDER => RawError::Kind(ITF::VFW_S_PARTIAL_RENDER),
            ITF::VFW_S_SOME_DATA_IGNORED => RawError::Kind(ITF::VFW_S_SOME_DATA_IGNORED),
            ITF::VFW_S_CONNECTIONS_DEFERRED => RawError::Kind(ITF::VFW_S_CONNECTIONS_DEFERRED),
            ITF::VFW_S_RESOURCE_NOT_NEEDED => RawError::Kind(ITF::VFW_S_RESOURCE_NOT_NEEDED),
            ITF::TPC_S_TRUNCATED => RawError::Kind(ITF::TPC_S_TRUNCATED),
            ITF::TPC_S_INTERRUPTED => RawError::Kind(ITF::TPC_S_INTERRUPTED),
            ITF::TPC_S_NO_DATA_TO_PROCESS => RawError::Kind(ITF::TPC_S_NO_DATA_TO_PROCESS),
            ITF::VFW_S_MEDIA_TYPE_IGNORED => RawError::Kind(ITF::VFW_S_MEDIA_TYPE_IGNORED),
            ITF::VFW_S_VIDEO_NOT_RENDERED => RawError::Kind(ITF::VFW_S_VIDEO_NOT_RENDERED),
            ITF::VFW_S_AUDIO_NOT_RENDERED => RawError::Kind(ITF::VFW_S_AUDIO_NOT_RENDERED),
            ITF::VFW_S_RPZA => RawError::Kind(ITF::VFW_S_RPZA),
            ITF::VFW_S_ESTIMATED => RawError::Kind(ITF::VFW_S_ESTIMATED),
            ITF::VFW_S_RESERVED => RawError::Kind(ITF::VFW_S_RESERVED),
            ITF::VFW_S_STREAM_OFF => RawError::Kind(ITF::VFW_S_STREAM_OFF),
            ITF::VFW_S_CANT_CUE => RawError::Kind(ITF::VFW_S_CANT_CUE),
            ITF::VFW_S_NOPREVIEWPIN => RawError::Kind(ITF::VFW_S_NOPREVIEWPIN),
            ITF::VFW_S_DVD_NON_ONE_SEQUENTIAL => RawError::Kind(ITF::VFW_S_DVD_NON_ONE_SEQUENTIAL),
            ITF::VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE => RawError::Kind(ITF::VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE),
            ITF::VFW_S_DVD_NOT_ACCURATE => RawError::Kind(ITF::VFW_S_DVD_NOT_ACCURATE),
            ITF::TF_S_ASYNC => RawError::Kind(ITF::TF_S_ASYNC),
            ITF::TS_S_ASYNC => RawError::Kind(ITF::TS_S_ASYNC),
            ITF::CM_S_NODATASERVERS => RawError::Kind(ITF::CM_S_NODATASERVERS),
            ITF::QRY_S_NOROWSFOUND => RawError::Kind(ITF::QRY_S_NOROWSFOUND),
            ITF::QRY_S_TERMIGNORED => RawError::Kind(ITF::QRY_S_TERMIGNORED),
            ITF::QRY_S_INEXACTRESULTS => RawError::Kind(ITF::QRY_S_INEXACTRESULTS),
            ITF::IDS_MON_DEFAULT_ERROR => RawError::Kind(ITF::IDS_MON_DEFAULT_ERROR),
            ITF::IDS_MON_ILLEGAL_PASSTHROUGH => RawError::Kind(ITF::IDS_MON_ILLEGAL_PASSTHROUGH),
            ITF::IDS_MON_PARSE_ERR_1_PARAM => RawError::Kind(ITF::IDS_MON_PARSE_ERR_1_PARAM),
            ITF::IDS_MON_PARSE_ERR_2_PARAM => RawError::Kind(ITF::IDS_MON_PARSE_ERR_2_PARAM),
            ITF::IDS_MON_SEMI_COLON => RawError::Kind(ITF::IDS_MON_SEMI_COLON),
            ITF::IDS_MON_ORDINAL_OUT_OF_RANGE => RawError::Kind(ITF::IDS_MON_ORDINAL_OUT_OF_RANGE),
            ITF::IDS_MON_VIEW_NOT_DEFINED => RawError::Kind(ITF::IDS_MON_VIEW_NOT_DEFINED),
            ITF::IDS_MON_COLUMN_NOT_DEFINED => RawError::Kind(ITF::IDS_MON_COLUMN_NOT_DEFINED),
            ITF::IDS_MON_BUILTIN_VIEW => RawError::Kind(ITF::IDS_MON_BUILTIN_VIEW),
            ITF::IDS_MON_OUT_OF_MEMORY => RawError::Kind(ITF::IDS_MON_OUT_OF_MEMORY),
            ITF::IDS_MON_SELECT_STAR => RawError::Kind(ITF::IDS_MON_SELECT_STAR),
            ITF::IDS_MON_OR_NOT => RawError::Kind(ITF::IDS_MON_OR_NOT),
            ITF::IDS_MON_CANNOT_CONVERT => RawError::Kind(ITF::IDS_MON_CANNOT_CONVERT),
            ITF::IDS_MON_OUT_OF_RANGE => RawError::Kind(ITF::IDS_MON_OUT_OF_RANGE),
            ITF::IDS_MON_RELATIVE_INTERVAL => RawError::Kind(ITF::IDS_MON_RELATIVE_INTERVAL),
            ITF::IDS_MON_NOT_COLUMN_OF_VIEW => RawError::Kind(ITF::IDS_MON_NOT_COLUMN_OF_VIEW),
            ITF::IDS_MON_BUILTIN_PROPERTY => RawError::Kind(ITF::IDS_MON_BUILTIN_PROPERTY),
            ITF::IDS_MON_WEIGHT_OUT_OF_RANGE => RawError::Kind(ITF::IDS_MON_WEIGHT_OUT_OF_RANGE),
            ITF::IDS_MON_MATCH_STRING => RawError::Kind(ITF::IDS_MON_MATCH_STRING),
            ITF::IDS_MON_PROPERTY_NAME_IN_VIEW => RawError::Kind(ITF::IDS_MON_PROPERTY_NAME_IN_VIEW),
            ITF::IDS_MON_VIEW_ALREADY_DEFINED => RawError::Kind(ITF::IDS_MON_VIEW_ALREADY_DEFINED),
            ITF::IDS_MON_INVALID_CATALOG => RawError::Kind(ITF::IDS_MON_INVALID_CATALOG),
            ITF::IDS_MON_INVALIDSELECT_COALESCE => RawError::Kind(ITF::IDS_MON_INVALIDSELECT_COALESCE),
            ITF::IDS_MON_CANNOT_CAST => RawError::Kind(ITF::IDS_MON_CANNOT_CAST),
            ITF::IDS_MON_DATE_OUT_OF_RANGE => RawError::Kind(ITF::IDS_MON_DATE_OUT_OF_RANGE),
            ITF::IDS_MON_INVALID_IN_GROUP_CLAUSE => RawError::Kind(ITF::IDS_MON_INVALID_IN_GROUP_CLAUSE),
            ITF::GTHR_S_STATUS_CHANGE_IGNORED => RawError::Kind(ITF::GTHR_S_STATUS_CHANGE_IGNORED),
            ITF::GTHR_S_STATUS_END_CRAWL => RawError::Kind(ITF::GTHR_S_STATUS_END_CRAWL),
            ITF::GTHR_S_STATUS_RESET => RawError::Kind(ITF::GTHR_S_STATUS_RESET),
            ITF::GTHR_S_STATUS_THROTTLE => RawError::Kind(ITF::GTHR_S_STATUS_THROTTLE),
            ITF::GTHR_S_STATUS_RESUME => RawError::Kind(ITF::GTHR_S_STATUS_RESUME),
            ITF::GTHR_S_STATUS_PAUSE => RawError::Kind(ITF::GTHR_S_STATUS_PAUSE),
            ITF::GTHR_S_END_STD_CHUNKS => RawError::Kind(ITF::GTHR_S_END_STD_CHUNKS),
            ITF::GTHR_S_NO_CRAWL_SEEDS => RawError::Kind(ITF::GTHR_S_NO_CRAWL_SEEDS),
            ITF::GTHR_S_CANNOT_FILTER => RawError::Kind(ITF::GTHR_S_CANNOT_FILTER),
            ITF::GTHR_S_STATUS_STOP => RawError::Kind(ITF::GTHR_S_STATUS_STOP),
            ITF::GTHR_S_STATUS_START => RawError::Kind(ITF::GTHR_S_STATUS_START),
            ITF::GTHR_S_CONFIG_HAS_ACCOUNTS => RawError::Kind(ITF::GTHR_S_CONFIG_HAS_ACCOUNTS),
            ITF::GTHR_S_PROB_NOT_MODIFIED => RawError::Kind(ITF::GTHR_S_PROB_NOT_MODIFIED),
            ITF::GTHR_S_CRAWL_SCHEDULED => RawError::Kind(ITF::GTHR_S_CRAWL_SCHEDULED),
            ITF::GTHR_S_TRANSACTION_IGNORED => RawError::Kind(ITF::GTHR_S_TRANSACTION_IGNORED),
            ITF::GTHR_S_START_FILTER_FROM_PROTOCOL => RawError::Kind(ITF::GTHR_S_START_FILTER_FROM_PROTOCOL),
            ITF::GTHR_S_BAD_FILE_LINK => RawError::Kind(ITF::GTHR_S_BAD_FILE_LINK),
            ITF::GTHR_S_NOT_ALL_PARTS => RawError::Kind(ITF::GTHR_S_NOT_ALL_PARTS),
            ITF::GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE => RawError::Kind(ITF::GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE),
            ITF::GTHR_S_START_FILTER_FROM_BODY => RawError::Kind(ITF::GTHR_S_START_FILTER_FROM_BODY),
            ITF::GTHR_S_MODIFIED_PARTS => RawError::Kind(ITF::GTHR_S_MODIFIED_PARTS),
            ITF::GTHR_S_CRAWL_FULL => RawError::Kind(ITF::GTHR_S_CRAWL_FULL),
            ITF::GTHR_S_CRAWL_INCREMENTAL => RawError::Kind(ITF::GTHR_S_CRAWL_INCREMENTAL),
            ITF::GTHR_S_CRAWL_ADAPTIVE => RawError::Kind(ITF::GTHR_S_CRAWL_ADAPTIVE),
            ITF::GTHR_S_NO_INDEX => RawError::Kind(ITF::GTHR_S_NO_INDEX),
            ITF::GTHR_S_PAUSE_REASON_EXTERNAL => RawError::Kind(ITF::GTHR_S_PAUSE_REASON_EXTERNAL),
            ITF::GTHR_S_PAUSE_REASON_UPGRADING => RawError::Kind(ITF::GTHR_S_PAUSE_REASON_UPGRADING),
            ITF::GTHR_S_PAUSE_REASON_BACKOFF => RawError::Kind(ITF::GTHR_S_PAUSE_REASON_BACKOFF),
            ITF::GTHR_S_OFFICE_CHILD => RawError::Kind(ITF::GTHR_S_OFFICE_CHILD),
            ITF::GTHR_S_CANNOT_WORDBREAK => RawError::Kind(ITF::GTHR_S_CANNOT_WORDBREAK),
            ITF::GTHR_S_USE_MIME_FILTER => RawError::Kind(ITF::GTHR_S_USE_MIME_FILTER),
            ITF::GTHR_S_PAUSE_REASON_PROFILE_IMPORT => RawError::Kind(ITF::GTHR_S_PAUSE_REASON_PROFILE_IMPORT),
            ITF::DB_S_ROWLIMITEXCEEDED => RawError::Kind(ITF::DB_S_ROWLIMITEXCEEDED),
            ITF::DB_S_COLUMNTYPEMISMATCH => RawError::Kind(ITF::DB_S_COLUMNTYPEMISMATCH),
            ITF::DB_S_TYPEINFOOVERRIDDEN => RawError::Kind(ITF::DB_S_TYPEINFOOVERRIDDEN),
            ITF::DB_S_BOOKMARKSKIPPED => RawError::Kind(ITF::DB_S_BOOKMARKSKIPPED),
            ITF::DB_S_NONEXTROWSET => RawError::Kind(ITF::DB_S_NONEXTROWSET),
            ITF::DB_S_ENDOFROWSET => RawError::Kind(ITF::DB_S_ENDOFROWSET),
            ITF::DB_S_COMMANDREEXECUTED => RawError::Kind(ITF::DB_S_COMMANDREEXECUTED),
            ITF::DB_S_BUFFERFULL => RawError::Kind(ITF::DB_S_BUFFERFULL),
            ITF::DB_S_NORESULT => RawError::Kind(ITF::DB_S_NORESULT),
            ITF::DB_S_CANTRELEASE => RawError::Kind(ITF::DB_S_CANTRELEASE),
            ITF::DB_S_GOALCHANGED => RawError::Kind(ITF::DB_S_GOALCHANGED),
            ITF::DB_S_UNWANTEDOPERATION => RawError::Kind(ITF::DB_S_UNWANTEDOPERATION),
            ITF::DB_S_DIALECTIGNORED => RawError::Kind(ITF::DB_S_DIALECTIGNORED),
            ITF::DB_S_UNWANTEDPHASE => RawError::Kind(ITF::DB_S_UNWANTEDPHASE),
            ITF::DB_S_UNWANTEDREASON => RawError::Kind(ITF::DB_S_UNWANTEDREASON),
            ITF::DB_S_ASYNCHRONOUS => RawError::Kind(ITF::DB_S_ASYNCHRONOUS),
            ITF::DB_S_COLUMNSCHANGED => RawError::Kind(ITF::DB_S_COLUMNSCHANGED),
            ITF::DB_S_ERRORSRETURNED => RawError::Kind(ITF::DB_S_ERRORSRETURNED),
            ITF::DB_S_BADROWHANDLE => RawError::Kind(ITF::DB_S_BADROWHANDLE),
            ITF::DB_S_DELETEDROW => RawError::Kind(ITF::DB_S_DELETEDROW),
            ITF::DB_S_TOOMANYCHANGES => RawError::Kind(ITF::DB_S_TOOMANYCHANGES),
            ITF::DB_S_STOPLIMITREACHED => RawError::Kind(ITF::DB_S_STOPLIMITREACHED),
            ITF::DB_S_NOTSINGLETON => RawError::Kind(ITF::DB_S_NOTSINGLETON),
            ITF::DB_S_LOCKUPGRADED => RawError::Kind(ITF::DB_S_LOCKUPGRADED),
            ITF::DB_S_PROPERTIESCHANGED => RawError::Kind(ITF::DB_S_PROPERTIESCHANGED),
            ITF::DB_S_ERRORSOCCURRED => RawError::Kind(ITF::DB_S_ERRORSOCCURRED),
            ITF::DB_S_PARAMUNAVAILABLE => RawError::Kind(ITF::DB_S_PARAMUNAVAILABLE),
            ITF::DB_S_MULTIPLECHANGES => RawError::Kind(ITF::DB_S_MULTIPLECHANGES),
            ITF::DB_S_NOROWSPECIFICCOLUMNS => RawError::Kind(ITF::DB_S_NOROWSPECIFICCOLUMNS),
            ITF::REC_S_IDIDTHEUPDATES => RawError::Kind(ITF::REC_S_IDIDTHEUPDATES),
            ITF::REC_S_NOTCOMPLETE => RawError::Kind(ITF::REC_S_NOTCOMPLETE),
            ITF::SEO_S_MOREDATA => RawError::Kind(ITF::SEO_S_MOREDATA),
            ITF::REC_S_NOTCOMPLETEBUTPROPAGATE => RawError::Kind(ITF::REC_S_NOTCOMPLETEBUTPROPAGATE),
            ITF::IDX_S_NO_BUILD_IN_PROGRESS => RawError::Kind(ITF::IDX_S_NO_BUILD_IN_PROGRESS),
            ITF::IDX_S_SEARCH_SERVER_ALREADY_EXISTS => RawError::Kind(ITF::IDX_S_SEARCH_SERVER_ALREADY_EXISTS),
            ITF::IDX_S_SEARCH_SERVER_DOES_NOT_EXIST => RawError::Kind(ITF::IDX_S_SEARCH_SERVER_DOES_NOT_EXIST),
            ITF::IDX_S_DSS_NOT_AVAILABLE => RawError::Kind(ITF::IDX_S_DSS_NOT_AVAILABLE),
            ITF::JPS_S_DUPLICATE_DOC_DETECTED => RawError::Kind(ITF::JPS_S_DUPLICATE_DOC_DETECTED),
            ITF::PRTH_S_NOT_MODIFIED => RawError::Kind(ITF::PRTH_S_NOT_MODIFIED),
            ITF::PRTH_S_MAX_GROWTH => RawError::Kind(ITF::PRTH_S_MAX_GROWTH),
            ITF::PRTH_S_MAX_DOWNLOAD => RawError::Kind(ITF::PRTH_S_MAX_DOWNLOAD),
            ITF::PRTH_S_ACL_IS_READ_EVERYONE => RawError::Kind(ITF::PRTH_S_ACL_IS_READ_EVERYONE),
            ITF::PRTH_S_USE_ROSEBUD => RawError::Kind(ITF::PRTH_S_USE_ROSEBUD),
            ITF::PRTH_S_NOT_ALL_PARTS => RawError::Kind(ITF::PRTH_S_NOT_ALL_PARTS),
            ITF::PRTH_S_TRY_IMPERSONATING => RawError::Kind(ITF::PRTH_S_TRY_IMPERSONATING),
            ITF::SCHED_S_TASK_READY => RawError::Kind(ITF::SCHED_S_TASK_READY),
            ITF::SCHED_S_TASK_RUNNING => RawError::Kind(ITF::SCHED_S_TASK_RUNNING),
            ITF::SCHED_S_TASK_DISABLED => RawError::Kind(ITF::SCHED_S_TASK_DISABLED),
            ITF::SCHED_S_TASK_HAS_NOT_RUN => RawError::Kind(ITF::SCHED_S_TASK_HAS_NOT_RUN),
            ITF::SCHED_S_TASK_NO_MORE_RUNS => RawError::Kind(ITF::SCHED_S_TASK_NO_MORE_RUNS),
            ITF::SCHED_S_TASK_NOT_SCHEDULED => RawError::Kind(ITF::SCHED_S_TASK_NOT_SCHEDULED),
            ITF::SCHED_S_TASK_TERMINATED => RawError::Kind(ITF::SCHED_S_TASK_TERMINATED),
            ITF::SCHED_S_TASK_NO_VALID_TRIGGERS => RawError::Kind(ITF::SCHED_S_TASK_NO_VALID_TRIGGERS),
            ITF::SCHED_S_EVENT_TRIGGER => RawError::Kind(ITF::SCHED_S_EVENT_TRIGGER),
            ITF::SCHED_S_SOME_TRIGGERS_FAILED => RawError::Kind(ITF::SCHED_S_SOME_TRIGGERS_FAILED),
            ITF::SCHED_S_BATCH_LOGON_PROBLEM => RawError::Kind(ITF::SCHED_S_BATCH_LOGON_PROBLEM),
            ITF::SCHED_S_TASK_QUEUED => RawError::Kind(ITF::SCHED_S_TASK_QUEUED),
            ITF::QPLIST_S_DUPLICATE => RawError::Kind(ITF::QPLIST_S_DUPLICATE),
            ITF::FDAEMON_W_WORDLISTFULL => RawError::Kind(ITF::FDAEMON_W_WORDLISTFULL),
            ITF::FDAEMON_W_EMPTYWORDLIST => RawError::Kind(ITF::FDAEMON_W_EMPTYWORDLIST),
            ITF::SEARCH_S_NOMOREHITS => RawError::Kind(ITF::SEARCH_S_NOMOREHITS),
            ITF::FILTER_W_MONIKER_CLIPPED => RawError::Kind(ITF::FILTER_W_MONIKER_CLIPPED),
            ITF::FILTER_S_LAST_TEXT => RawError::Kind(ITF::FILTER_S_LAST_TEXT),
            ITF::FILTER_S_LAST_VALUES => RawError::Kind(ITF::FILTER_S_LAST_VALUES),
            ITF::FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE => RawError::Kind(ITF::FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE),
            ITF::FILTER_S_FULL_CONTENTSCAN_IMMEDIATE => RawError::Kind(ITF::FILTER_S_FULL_CONTENTSCAN_IMMEDIATE),
            ITF::FILTER_S_CONTENTSCAN_DELAYED => RawError::Kind(ITF::FILTER_S_CONTENTSCAN_DELAYED),
            ITF::FILTER_S_DISK_FULL => RawError::Kind(ITF::FILTER_S_DISK_FULL),
            ITF::FILTER_S_NO_PROPSETS => RawError::Kind(ITF::FILTER_S_NO_PROPSETS),
            ITF::FILTER_S_NO_SECURITY_DESCRIPTOR => RawError::Kind(ITF::FILTER_S_NO_SECURITY_DESCRIPTOR),
            ITF::LANGUAGE_S_LARGE_WORD => RawError::Kind(ITF::LANGUAGE_S_LARGE_WORD),
            ITF::PSINK_S_LARGE_WORD => RawError::Kind(ITF::PSINK_S_LARGE_WORD),
            ITF::CI_S_WORKID_DELETED => RawError::Kind(ITF::CI_S_WORKID_DELETED),
            ITF::CI_S_END_OF_ENUMERATION => RawError::Kind(ITF::CI_S_END_OF_ENUMERATION),
            ITF::CI_S_NO_DOCSTORE => RawError::Kind(ITF::CI_S_NO_DOCSTORE),
            ITF::CI_S_CAT_STOPPED => RawError::Kind(ITF::CI_S_CAT_STOPPED),
            ITF::CI_S_NEW_AUXMETADATA => RawError::Kind(ITF::CI_S_NEW_AUXMETADATA),
            ITF::CI_S_CLIENT_REQUESTED_ABORT => RawError::Kind(ITF::CI_S_CLIENT_REQUESTED_ABORT),
            ITF::CI_S_RETRY_DOCUMENT => RawError::Kind(ITF::CI_S_RETRY_DOCUMENT),
            ITF::CI_S_CATALOG_RESET => RawError::Kind(ITF::CI_S_CATALOG_RESET),
            ITF::NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED => RawError::Kind(ITF::NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED),
            ITF::VSS_S_ASYNC_PENDING => RawError::Kind(ITF::VSS_S_ASYNC_PENDING),
            ITF::VSS_S_ASYNC_FINISHED => RawError::Kind(ITF::VSS_S_ASYNC_FINISHED),
            ITF::VSS_S_ASYNC_CANCELLED => RawError::Kind(ITF::VSS_S_ASYNC_CANCELLED),
            ITF::VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED => RawError::Kind(ITF::VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED),
            ITF::VDS_S_DISK_PARTIALLY_CLEANED => RawError::Kind(ITF::VDS_S_DISK_PARTIALLY_CLEANED),
            ITF::VDS_S_PROVIDER_ERROR_LOADING_CACHE => RawError::Kind(ITF::VDS_S_PROVIDER_ERROR_LOADING_CACHE),
            ITF::VDS_S_UPDATE_BOOTFILE_FAILED => RawError::Kind(ITF::VDS_S_UPDATE_BOOTFILE_FAILED),
            ITF::VDS_S_BOOT_PARTITION_NUMBER_CHANGE => RawError::Kind(ITF::VDS_S_BOOT_PARTITION_NUMBER_CHANGE),
            ITF::VDS_S_VOLUME_COMPRESS_FAILED => RawError::Kind(ITF::VDS_S_VOLUME_COMPRESS_FAILED),
            ITF::VDS_S_IN_PROGRESS => RawError::Kind(ITF::VDS_S_IN_PROGRESS),
            ITF::VDS_S_IA64_BOOT_MIRRORED_TO_MBR => RawError::Kind(ITF::VDS_S_IA64_BOOT_MIRRORED_TO_MBR),
            ITF::VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES => RawError::Kind(ITF::VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES),
            ITF::VDS_S_EXTEND_FILE_SYSTEM_FAILED => RawError::Kind(ITF::VDS_S_EXTEND_FILE_SYSTEM_FAILED),
            ITF::VDS_S_MBR_BOOT_MIRRORED_TO_GPT => RawError::Kind(ITF::VDS_S_MBR_BOOT_MIRRORED_TO_GPT),
            ITF::VDS_S_DISK_IS_MISSING => RawError::Kind(ITF::VDS_S_DISK_IS_MISSING),
            ITF::VDS_S_NONCONFORMANT_PARTITION_INFO => RawError::Kind(ITF::VDS_S_NONCONFORMANT_PARTITION_INFO),
            ITF::VDS_S_SYSTEM_PARTITION => RawError::Kind(ITF::VDS_S_SYSTEM_PARTITION),
            ITF::VDS_S_NO_NOTIFICATION => RawError::Kind(ITF::VDS_S_NO_NOTIFICATION),
            ITF::VDS_S_DEFAULT_PLEX_MEMBER_IDS => RawError::Kind(ITF::VDS_S_DEFAULT_PLEX_MEMBER_IDS),
            ITF::VDS_S_DISMOUNT_FAILED => RawError::Kind(ITF::VDS_S_DISMOUNT_FAILED),
            ITF::VDS_S_REMOUNT_FAILED => RawError::Kind(ITF::VDS_S_REMOUNT_FAILED),
            ITF::VDS_S_RESYNC_NOTIFICATION_TASK_FAILED => RawError::Kind(ITF::VDS_S_RESYNC_NOTIFICATION_TASK_FAILED),
            ITF::VDS_S_VSS_FLUSH_AND_HOLD_WRITES => RawError::Kind(ITF::VDS_S_VSS_FLUSH_AND_HOLD_WRITES),
            ITF::VDS_S_VSS_RELEASE_WRITES => RawError::Kind(ITF::VDS_S_VSS_RELEASE_WRITES),
            ITF::VDS_S_FS_LOCK => RawError::Kind(ITF::VDS_S_FS_LOCK),
            ITF::VDS_S_PLEX_NOT_LOADED_TO_CACHE => RawError::Kind(ITF::VDS_S_PLEX_NOT_LOADED_TO_CACHE),
            ITF::VDS_S_WINPE_BOOTENTRY => RawError::Kind(ITF::VDS_S_WINPE_BOOTENTRY),
            ITF::NOTESPH_S_IGNORE_ID => RawError::Kind(ITF::NOTESPH_S_IGNORE_ID),
            ITF::NOTESPH_S_LISTKNOWNFIELDS => RawError::Kind(ITF::NOTESPH_S_LISTKNOWNFIELDS),
            ITF::VDS_S_NAME_TRUNCATED => RawError::Kind(ITF::VDS_S_NAME_TRUNCATED),
            ITF::VDS_S_STATUSES_INCOMPLETELY_SET => RawError::Kind(ITF::VDS_S_STATUSES_INCOMPLETELY_SET),
            ITF::VDS_S_ALREADY_EXISTS => RawError::Kind(ITF::VDS_S_ALREADY_EXISTS),
            ITF::VDS_S_PROPERTIES_INCOMPLETE => RawError::Kind(ITF::VDS_S_PROPERTIES_INCOMPLETE),
            ITF::VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED => RawError::Kind(ITF::VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED),
            ITF::VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED => RawError::Kind(ITF::VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED),
            ITF::VDS_S_ISCSI_LOGIN_ALREAD_EXISTS => RawError::Kind(ITF::VDS_S_ISCSI_LOGIN_ALREAD_EXISTS),
            ITF::VDS_S_DISK_MOUNT_FAILED => RawError::Kind(ITF::VDS_S_DISK_MOUNT_FAILED),
            ITF::VDS_S_DISK_DISMOUNT_FAILED => RawError::Kind(ITF::VDS_S_DISK_DISMOUNT_FAILED),
            ITF::REXSPH_S_REDIRECTED => RawError::Kind(ITF::REXSPH_S_REDIRECTED),
            ITF::FTE_S_RESOURCES_STARTING_TO_GET_LOW => RawError::Kind(ITF::FTE_S_RESOURCES_STARTING_TO_GET_LOW),
            ITF::FTE_S_BEYOND_QUOTA => RawError::Kind(ITF::FTE_S_BEYOND_QUOTA),
            ITF::FTE_S_REDUNDANT => RawError::Kind(ITF::FTE_S_REDUNDANT),
            ITF::FTE_S_STATUS_CHANGE_REQUEST => RawError::Kind(ITF::FTE_S_STATUS_CHANGE_REQUEST),
            ITF::FTE_S_RESUME => RawError::Kind(ITF::FTE_S_RESUME),
            ITF::FTE_S_PROPERTY_STORE_END_OF_ENUMERATION => RawError::Kind(ITF::FTE_S_PROPERTY_STORE_END_OF_ENUMERATION),
            ITF::FTE_S_READONLY_CATALOG => RawError::Kind(ITF::FTE_S_READONLY_CATALOG),
            ITF::FTE_S_TRY_TO_FLUSH => RawError::Kind(ITF::FTE_S_TRY_TO_FLUSH),
            ITF::FTE_S_CATALOG_BLOB_MISMATCHED => RawError::Kind(ITF::FTE_S_CATALOG_BLOB_MISMATCHED),
            ITF::FTE_S_PROPERTY_RESET => RawError::Kind(ITF::FTE_S_PROPERTY_RESET),
            ITF::VDS_S_ACCESS_PATH_NOT_DELETED => RawError::Kind(ITF::VDS_S_ACCESS_PATH_NOT_DELETED),
            ITF::SP_END_OF_STREAM => RawError::Kind(ITF::SP_END_OF_STREAM),
            ITF::SP_INSUFFICIENTDATA => RawError::Kind(ITF::SP_INSUFFICIENTDATA),
            ITF::SP_AUDIO_PAUSED => RawError::Kind(ITF::SP_AUDIO_PAUSED),
            ITF::SP_AUDIO_CONVERSION_ENABLED => RawError::Kind(ITF::SP_AUDIO_CONVERSION_ENABLED),
            ITF::SP_NO_HYPOTHESIS_AVAILABLE => RawError::Kind(ITF::SP_NO_HYPOTHESIS_AVAILABLE),
            ITF::SP_ALREADY_IN_LEX => RawError::Kind(ITF::SP_ALREADY_IN_LEX),
            ITF::SP_LEX_NOTHING_TO_SYNC => RawError::Kind(ITF::SP_LEX_NOTHING_TO_SYNC),
            ITF::SP_REQUEST_PENDING => RawError::Kind(ITF::SP_REQUEST_PENDING),
            ITF::SP_NO_PARSE_FOUND => RawError::Kind(ITF::SP_NO_PARSE_FOUND),
            ITF::SP_UNSUPPORTED_ON_STREAM_INPUT => RawError::Kind(ITF::SP_UNSUPPORTED_ON_STREAM_INPUT),
            ITF::SP_WORD_EXISTS_WITHOUT_PRONUNCIATION => RawError::Kind(ITF::SP_WORD_EXISTS_WITHOUT_PRONUNCIATION),
            ITF::SP_RECOGNIZER_INACTIVE => RawError::Kind(ITF::SP_RECOGNIZER_INACTIVE),
            ITF::SP_PARTIAL_PARSE_FOUND => RawError::Kind(ITF::SP_PARTIAL_PARSE_FOUND),
            ITF::SP_NO_RULE_ACTIVE => RawError::Kind(ITF::SP_NO_RULE_ACTIVE),
            ITF::SP_STREAM_UNINITIALIZED => RawError::Kind(ITF::SP_STREAM_UNINITIALIZED),
            ITF::SP_AUDIO_STOPPED => RawError::Kind(ITF::SP_AUDIO_STOPPED),
            ITF::SP_COMPLETE_BUT_EXTENDABLE => RawError::Kind(ITF::SP_COMPLETE_BUT_EXTENDABLE),
            ITF::SP_NO_RULES_TO_ACTIVATE => RawError::Kind(ITF::SP_NO_RULES_TO_ACTIVATE),
            ITF::SP_NO_WORDENTRY_NOTIFICATION => RawError::Kind(ITF::SP_NO_WORDENTRY_NOTIFICATION),
            ITF::S_LIMIT_REACHED => RawError::Kind(ITF::S_LIMIT_REACHED),
            ITF::S_NOTSUPPORTED => RawError::Kind(ITF::S_NOTSUPPORTED),
            ITF::FSRM_S_PARTIAL_BATCH => RawError::Kind(ITF::FSRM_S_PARTIAL_BATCH),
            ITF::FSRM_S_PARTIAL_CLASSIFICATION => RawError::Kind(ITF::FSRM_S_PARTIAL_CLASSIFICATION),
            ITF::FSRM_S_CLASSIFICATION_SCAN_FAILURES => RawError::Kind(ITF::FSRM_S_CLASSIFICATION_SCAN_FAILURES),
            ITF::FSRM_E_AUTO_QUOTA => RawError::Kind(ITF::FSRM_E_AUTO_QUOTA),
            ITF::NETCFG_S_REBOOT => RawError::Kind(ITF::NETCFG_S_REBOOT),
            ITF::NETCFG_S_DISABLE_QUERY => RawError::Kind(ITF::NETCFG_S_DISABLE_QUERY),
            ITF::NETCFG_S_STILL_REFERENCED => RawError::Kind(ITF::NETCFG_S_STILL_REFERENCED),
            ITF::NETCFG_S_CAUSED_SETUP_CHANGE => RawError::Kind(ITF::NETCFG_S_CAUSED_SETUP_CHANGE),
            ITF::NETCFG_S_COMMIT_NOW => RawError::Kind(ITF::NETCFG_S_COMMIT_NOW),
            ITF::XACT_S_ASYNC => RawError::Kind(ITF::XACT_S_ASYNC),
            ITF::XACT_S_DEFECT => RawError::Kind(ITF::XACT_S_DEFECT),
            ITF::XACT_S_READONLY => RawError::Kind(ITF::XACT_S_READONLY),
            ITF::XACT_S_SOMENORETAIN => RawError::Kind(ITF::XACT_S_SOMENORETAIN),
            ITF::XACT_S_OKINFORM => RawError::Kind(ITF::XACT_S_OKINFORM),
            ITF::XACT_S_MADECHANGESCONTENT => RawError::Kind(ITF::XACT_S_MADECHANGESCONTENT),
            ITF::XACT_S_MADECHANGESINFORM => RawError::Kind(ITF::XACT_S_MADECHANGESINFORM),
            ITF::XACT_S_ALLNORETAIN => RawError::Kind(ITF::XACT_S_ALLNORETAIN),
            ITF::XACT_S_ABORTING => RawError::Kind(ITF::XACT_S_ABORTING),
            ITF::XACT_S_SINGLEPHASE => RawError::Kind(ITF::XACT_S_SINGLEPHASE),
            ITF::XACT_S_LOCALLY_OK => RawError::Kind(ITF::XACT_S_LOCALLY_OK),
            ITF::XACT_S_LASTRESOURCEMANAGER => RawError::Kind(ITF::XACT_S_LASTRESOURCEMANAGER),
            ITF::S_DEVCAP_OUTPUT_FULL_REPLACEMENT => RawError::Kind(ITF::S_DEVCAP_OUTPUT_FULL_REPLACEMENT),
            ITF::IO_FILE_QUOTA_THRESHOLD => RawError::Kind(ITF::IO_FILE_QUOTA_THRESHOLD),
            ITF::IO_FILE_QUOTA_LIMIT => RawError::Kind(ITF::IO_FILE_QUOTA_LIMIT),
            ITF::IO_FILE_QUOTA_STARTED => RawError::Kind(ITF::IO_FILE_QUOTA_STARTED),
            ITF::IO_FILE_QUOTA_SUCCEEDED => RawError::Kind(ITF::IO_FILE_QUOTA_SUCCEEDED),
            ITF::IO_INFO_THROTTLE_COMPLETE => RawError::Kind(ITF::IO_INFO_THROTTLE_COMPLETE),
            ITF::IO_CDROM_EXCLUSIVE_LOCK => RawError::Kind(ITF::IO_CDROM_EXCLUSIVE_LOCK),
            ITF::MSG_TEST_MESSAGE => RawError::Kind(ITF::MSG_TEST_MESSAGE),
            ITF::SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK),
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL),
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED),
            ITF::SL_I_OOB_GRACE_PERIOD => RawError::Kind(ITF::SL_I_OOB_GRACE_PERIOD),
            ITF::SL_I_OOT_GRACE_PERIOD => RawError::Kind(ITF::SL_I_OOT_GRACE_PERIOD),
            ITF::SL_E_VL_INFO_PRODUCT_USER_RIGHT => RawError::Kind(ITF::SL_E_VL_INFO_PRODUCT_USER_RIGHT),
            ITF::SL_I_NONGENUINE_GRACE_PERIOD => RawError::Kind(ITF::SL_I_NONGENUINE_GRACE_PERIOD),
            ITF::SL_I_NONGENUINE_GRACE_PERIOD_2 => RawError::Kind(ITF::SL_I_NONGENUINE_GRACE_PERIOD_2),
            ITF::SL_I_TIMEBASED_VALIDITY_PERIOD => RawError::Kind(ITF::SL_I_TIMEBASED_VALIDITY_PERIOD),
            ITF::SL_I_PERPETUAL_OOB_GRACE_PERIOD => RawError::Kind(ITF::SL_I_PERPETUAL_OOB_GRACE_PERIOD),
            ITF::SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD => RawError::Kind(ITF::SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD),
            ITF::OLE_E_OLEVERB => RawError::Kind(ITF::OLE_E_OLEVERB),
            ITF::OLE_E_ADVF => RawError::Kind(ITF::OLE_E_ADVF),
            ITF::E_NOTVALIDFORANIMATEDIMAGE => RawError::Kind(ITF::E_NOTVALIDFORANIMATEDIMAGE),
            ITF::OLE_E_ENUM_NOMORE => RawError::Kind(ITF::OLE_E_ENUM_NOMORE),
            ITF::OLE_E_ADVISENOTSUPPORTED => RawError::Kind(ITF::OLE_E_ADVISENOTSUPPORTED),
            ITF::TAPI_E_NOTSUPPORTED => RawError::Kind(ITF::TAPI_E_NOTSUPPORTED),
            ITF::OLE_E_NOCONNECTION => RawError::Kind(ITF::OLE_E_NOCONNECTION),
            ITF::TAPI_E_INVALIDMEDIATYPE => RawError::Kind(ITF::TAPI_E_INVALIDMEDIATYPE),
            ITF::OLE_E_NOTRUNNING => RawError::Kind(ITF::OLE_E_NOTRUNNING),
            ITF::TAPI_E_OPERATIONFAILED => RawError::Kind(ITF::TAPI_E_OPERATIONFAILED),
            ITF::OLE_E_NOCACHE => RawError::Kind(ITF::OLE_E_NOCACHE),
            ITF::TAPI_E_ALLOCATED => RawError::Kind(ITF::TAPI_E_ALLOCATED),
            ITF::OLE_E_BLANK => RawError::Kind(ITF::OLE_E_BLANK),
            ITF::TAPI_E_CALLUNAVAIL => RawError::Kind(ITF::TAPI_E_CALLUNAVAIL),
            ITF::OLE_E_CLASSDIFF => RawError::Kind(ITF::OLE_E_CLASSDIFF),
            ITF::TAPI_E_COMPLETIONOVERRUN => RawError::Kind(ITF::TAPI_E_COMPLETIONOVERRUN),
            ITF::OLE_E_CANT_GETMONIKER => RawError::Kind(ITF::OLE_E_CANT_GETMONIKER),
            ITF::TAPI_E_CONFERENCEFULL => RawError::Kind(ITF::TAPI_E_CONFERENCEFULL),
            ITF::OLE_E_CANT_BINDTOSOURCE => RawError::Kind(ITF::OLE_E_CANT_BINDTOSOURCE),
            ITF::TAPI_E_DIALMODIFIERNOTSUPPORTED => RawError::Kind(ITF::TAPI_E_DIALMODIFIERNOTSUPPORTED),
            ITF::OLE_E_STATIC => RawError::Kind(ITF::OLE_E_STATIC),
            ITF::TAPI_E_INUSE => RawError::Kind(ITF::TAPI_E_INUSE),
            ITF::OLE_E_PROMPTSAVECANCELLED => RawError::Kind(ITF::OLE_E_PROMPTSAVECANCELLED),
            ITF::TAPI_E_INVALADDRESS => RawError::Kind(ITF::TAPI_E_INVALADDRESS),
            ITF::OLE_E_INVALIDRECT => RawError::Kind(ITF::OLE_E_INVALIDRECT),
            ITF::TAPI_E_INVALADDRESSSTATE => RawError::Kind(ITF::TAPI_E_INVALADDRESSSTATE),
            ITF::OLE_E_WRONGCOMPOBJ => RawError::Kind(ITF::OLE_E_WRONGCOMPOBJ),
            ITF::TAPI_E_INVALCALLPARAMS => RawError::Kind(ITF::TAPI_E_INVALCALLPARAMS),
            ITF::OLE_E_INVALIDHWND => RawError::Kind(ITF::OLE_E_INVALIDHWND),
            ITF::TAPI_E_INVALCALLPRIVILEGE => RawError::Kind(ITF::TAPI_E_INVALCALLPRIVILEGE),
            ITF::OLE_E_NOT_INPLACEACTIVE => RawError::Kind(ITF::OLE_E_NOT_INPLACEACTIVE),
            ITF::TAPI_E_INVALCALLSTATE => RawError::Kind(ITF::TAPI_E_INVALCALLSTATE),
            ITF::OLE_E_CANTCONVERT => RawError::Kind(ITF::OLE_E_CANTCONVERT),
            ITF::TAPI_E_INVALCARD => RawError::Kind(ITF::TAPI_E_INVALCARD),
            ITF::OLE_E_NOSTORAGE => RawError::Kind(ITF::OLE_E_NOSTORAGE),
            ITF::TAPI_E_INVALCOMPLETIONID => RawError::Kind(ITF::TAPI_E_INVALCOMPLETIONID),
            ITF::TAPI_E_INVALCOUNTRYCODE => RawError::Kind(ITF::TAPI_E_INVALCOUNTRYCODE),
            ITF::TAPI_E_INVALDEVICECLASS => RawError::Kind(ITF::TAPI_E_INVALDEVICECLASS),
            ITF::TAPI_E_INVALDIALPARAMS => RawError::Kind(ITF::TAPI_E_INVALDIALPARAMS),
            ITF::TAPI_E_INVALDIGITS => RawError::Kind(ITF::TAPI_E_INVALDIGITS),
            ITF::TAPI_E_INVALGROUPID => RawError::Kind(ITF::TAPI_E_INVALGROUPID),
            ITF::TAPI_E_INVALLOCATION => RawError::Kind(ITF::TAPI_E_INVALLOCATION),
            ITF::TAPI_E_INVALMESSAGEID => RawError::Kind(ITF::TAPI_E_INVALMESSAGEID),
            ITF::TAPI_E_INVALPARKID => RawError::Kind(ITF::TAPI_E_INVALPARKID),
            ITF::IO_WRN_BAD_FIRMWARE => RawError::Kind(ITF::IO_WRN_BAD_FIRMWARE),
            ITF::TAPI_E_INVALRATE => RawError::Kind(ITF::TAPI_E_INVALRATE),
            ITF::TAPI_E_INVALTIMEOUT => RawError::Kind(ITF::TAPI_E_INVALTIMEOUT),
            ITF::TAPI_E_INVALTONE => RawError::Kind(ITF::TAPI_E_INVALTONE),
            ITF::TAPI_E_INVALLIST => RawError::Kind(ITF::TAPI_E_INVALLIST),
            ITF::TAPI_E_INVALMODE => RawError::Kind(ITF::TAPI_E_INVALMODE),
            ITF::TAPI_E_NOCONFERENCE => RawError::Kind(ITF::TAPI_E_NOCONFERENCE),
            ITF::IO_WRITE_CACHE_ENABLED => RawError::Kind(ITF::IO_WRITE_CACHE_ENABLED),
            ITF::TAPI_E_NODEVICE => RawError::Kind(ITF::TAPI_E_NODEVICE),
            ITF::IO_RECOVERED_VIA_ECC => RawError::Kind(ITF::IO_RECOVERED_VIA_ECC),
            ITF::TAPI_E_NOREQUEST => RawError::Kind(ITF::TAPI_E_NOREQUEST),
            ITF::IO_WRITE_CACHE_DISABLED => RawError::Kind(ITF::IO_WRITE_CACHE_DISABLED),
            ITF::TAPI_E_NOTOWNER => RawError::Kind(ITF::TAPI_E_NOTOWNER),
            ITF::TAPI_E_NOTREGISTERED => RawError::Kind(ITF::TAPI_E_NOTREGISTERED),
            ITF::TAPI_E_REQUESTOVERRUN => RawError::Kind(ITF::TAPI_E_REQUESTOVERRUN),
            ITF::TAPI_E_TARGETNOTFOUND => RawError::Kind(ITF::TAPI_E_TARGETNOTFOUND),
            ITF::TAPI_E_TARGETSELF => RawError::Kind(ITF::TAPI_E_TARGETSELF),
            ITF::TAPI_E_USERUSERINFOTOOBIG => RawError::Kind(ITF::TAPI_E_USERUSERINFOTOOBIG),
            ITF::IO_FILE_QUOTA_FAILED => RawError::Kind(ITF::IO_FILE_QUOTA_FAILED),
            ITF::TAPI_E_REINIT => RawError::Kind(ITF::TAPI_E_REINIT),
            ITF::TAPI_E_ADDRESSBLOCKED => RawError::Kind(ITF::TAPI_E_ADDRESSBLOCKED),
            ITF::TAPI_E_BILLINGREJECTED => RawError::Kind(ITF::TAPI_E_BILLINGREJECTED),
            ITF::TAPI_E_INVALFEATURE => RawError::Kind(ITF::TAPI_E_INVALFEATURE),
            ITF::TAPI_E_INVALBUTTONLAMPID => RawError::Kind(ITF::TAPI_E_INVALBUTTONLAMPID),
            ITF::TAPI_E_INVALBUTTONSTATE => RawError::Kind(ITF::TAPI_E_INVALBUTTONSTATE),
            ITF::TAPI_E_INVALDATAID => RawError::Kind(ITF::TAPI_E_INVALDATAID),
            ITF::TAPI_E_INVALHOOKSWITCHDEV => RawError::Kind(ITF::TAPI_E_INVALHOOKSWITCHDEV),
            ITF::TAPI_E_DROPPED => RawError::Kind(ITF::TAPI_E_DROPPED),
            ITF::TAPI_E_NOREQUESTRECIPIENT => RawError::Kind(ITF::TAPI_E_NOREQUESTRECIPIENT),
            ITF::IO_LOST_DELAYED_WRITE => RawError::Kind(ITF::IO_LOST_DELAYED_WRITE),
            ITF::TAPI_E_REQUESTQUEUEFULL => RawError::Kind(ITF::TAPI_E_REQUESTQUEUEFULL),
            ITF::IO_WARNING_PAGING_FAILURE => RawError::Kind(ITF::IO_WARNING_PAGING_FAILURE),
            ITF::TAPI_E_DESTBUSY => RawError::Kind(ITF::TAPI_E_DESTBUSY),
            ITF::IO_WRN_FAILURE_PREDICTED => RawError::Kind(ITF::IO_WRN_FAILURE_PREDICTED),
            ITF::TAPI_E_DESTNOANSWER => RawError::Kind(ITF::TAPI_E_DESTNOANSWER),
            ITF::IO_WARNING_INTERRUPT_STILL_PENDING => RawError::Kind(ITF::IO_WARNING_INTERRUPT_STILL_PENDING),
            ITF::TAPI_E_DESTUNAVAIL => RawError::Kind(ITF::TAPI_E_DESTUNAVAIL),
            ITF::IO_DRIVER_CANCEL_TIMEOUT => RawError::Kind(ITF::IO_DRIVER_CANCEL_TIMEOUT),
            ITF::TAPI_E_REQUESTFAILED => RawError::Kind(ITF::TAPI_E_REQUESTFAILED),
            ITF::TAPI_E_REQUESTCANCELLED => RawError::Kind(ITF::TAPI_E_REQUESTCANCELLED),
            ITF::IO_WARNING_ALLOCATION_FAILED => RawError::Kind(ITF::IO_WARNING_ALLOCATION_FAILED),
            ITF::TAPI_E_INVALPRIVILEGE => RawError::Kind(ITF::TAPI_E_INVALPRIVILEGE),
            ITF::IO_WARNING_LOG_FLUSH_FAILED => RawError::Kind(ITF::IO_WARNING_LOG_FLUSH_FAILED),
            ITF::TAPI_E_INVALIDDIRECTION => RawError::Kind(ITF::TAPI_E_INVALIDDIRECTION),
            ITF::IO_WARNING_DUPLICATE_SIGNATURE => RawError::Kind(ITF::IO_WARNING_DUPLICATE_SIGNATURE),
            ITF::TAPI_E_INVALIDTERMINAL => RawError::Kind(ITF::TAPI_E_INVALIDTERMINAL),
            ITF::IO_WARNING_DUPLICATE_PATH => RawError::Kind(ITF::IO_WARNING_DUPLICATE_PATH),
            ITF::TAPI_E_INVALIDTERMINALCLASS => RawError::Kind(ITF::TAPI_E_INVALIDTERMINALCLASS),
            ITF::TAPI_E_NODRIVER => RawError::Kind(ITF::TAPI_E_NODRIVER),
            ITF::TAPI_E_MAXSTREAMS => RawError::Kind(ITF::TAPI_E_MAXSTREAMS),
            ITF::TAPI_E_NOTERMINALSELECTED => RawError::Kind(ITF::TAPI_E_NOTERMINALSELECTED),
            ITF::TAPI_E_TERMINALINUSE => RawError::Kind(ITF::TAPI_E_TERMINALINUSE),
            ITF::TAPI_E_NOTSTOPPED => RawError::Kind(ITF::TAPI_E_NOTSTOPPED),
            ITF::TAPI_E_MAXTERMINALS => RawError::Kind(ITF::TAPI_E_MAXTERMINALS),
            ITF::TAPI_E_INVALIDSTREAM => RawError::Kind(ITF::TAPI_E_INVALIDSTREAM),
            ITF::TAPI_E_TIMEOUT => RawError::Kind(ITF::TAPI_E_TIMEOUT),
            ITF::TAPI_E_CALLCENTER_GROUP_REMOVED => RawError::Kind(ITF::TAPI_E_CALLCENTER_GROUP_REMOVED),
            ITF::TAPI_E_CALLCENTER_QUEUE_REMOVED => RawError::Kind(ITF::TAPI_E_CALLCENTER_QUEUE_REMOVED),
            ITF::TAPI_E_CALLCENTER_NO_AGENT_ID => RawError::Kind(ITF::TAPI_E_CALLCENTER_NO_AGENT_ID),
            ITF::TAPI_E_CALLCENTER_INVALAGENTID => RawError::Kind(ITF::TAPI_E_CALLCENTER_INVALAGENTID),
            ITF::TAPI_E_CALLCENTER_INVALAGENTGROUP => RawError::Kind(ITF::TAPI_E_CALLCENTER_INVALAGENTGROUP),
            ITF::TAPI_E_CALLCENTER_INVALPASSWORD => RawError::Kind(ITF::TAPI_E_CALLCENTER_INVALPASSWORD),
            ITF::TAPI_E_CALLCENTER_INVALAGENTSTATE => RawError::Kind(ITF::TAPI_E_CALLCENTER_INVALAGENTSTATE),
            ITF::TAPI_E_CALLCENTER_INVALAGENTACTIVITY => RawError::Kind(ITF::TAPI_E_CALLCENTER_INVALAGENTACTIVITY),
            ITF::TAPI_E_REGISTRY_SETTING_CORRUPT => RawError::Kind(ITF::TAPI_E_REGISTRY_SETTING_CORRUPT),
            ITF::TAPI_E_TERMINAL_PEER => RawError::Kind(ITF::TAPI_E_TERMINAL_PEER),
            ITF::TAPI_E_PEER_NOT_SET => RawError::Kind(ITF::TAPI_E_PEER_NOT_SET),
            ITF::TAPI_E_NOEVENT => RawError::Kind(ITF::TAPI_E_NOEVENT),
            ITF::TAPI_E_INVALADDRESSTYPE => RawError::Kind(ITF::TAPI_E_INVALADDRESSTYPE),
            ITF::TAPI_E_RESOURCEUNAVAIL => RawError::Kind(ITF::TAPI_E_RESOURCEUNAVAIL),
            ITF::TAPI_E_PHONENOTOPEN => RawError::Kind(ITF::TAPI_E_PHONENOTOPEN),
            ITF::TAPI_E_CALLNOTSELECTED => RawError::Kind(ITF::TAPI_E_CALLNOTSELECTED),
            ITF::TAPI_E_WRONGEVENT => RawError::Kind(ITF::TAPI_E_WRONGEVENT),
            ITF::TAPI_E_NOFORMAT => RawError::Kind(ITF::TAPI_E_NOFORMAT),
            ITF::TAPI_E_INVALIDSTREAMSTATE => RawError::Kind(ITF::TAPI_E_INVALIDSTREAMSTATE),
            ITF::TAPI_E_WRONG_STATE => RawError::Kind(ITF::TAPI_E_WRONG_STATE),
            ITF::TAPI_E_NOT_INITIALIZED => RawError::Kind(ITF::TAPI_E_NOT_INITIALIZED),
            ITF::TAPI_E_SERVICE_NOT_RUNNING => RawError::Kind(ITF::TAPI_E_SERVICE_NOT_RUNNING),
            ITF::DV_E_FORMATETC => RawError::Kind(ITF::DV_E_FORMATETC),
            ITF::DV_E_DVTARGETDEVICE => RawError::Kind(ITF::DV_E_DVTARGETDEVICE),
            ITF::DV_E_STGMEDIUM => RawError::Kind(ITF::DV_E_STGMEDIUM),
            ITF::DV_E_STATDATA => RawError::Kind(ITF::DV_E_STATDATA),
            ITF::DV_E_LINDEX => RawError::Kind(ITF::DV_E_LINDEX),
            ITF::DV_E_TYMED => RawError::Kind(ITF::DV_E_TYMED),
            ITF::DV_E_CLIPFORMAT => RawError::Kind(ITF::DV_E_CLIPFORMAT),
            ITF::DV_E_DVASPECT => RawError::Kind(ITF::DV_E_DVASPECT),
            ITF::DV_E_DVTARGETDEVICE_SIZE => RawError::Kind(ITF::DV_E_DVTARGETDEVICE_SIZE),
            ITF::DV_E_NOIVIEWOBJECT => RawError::Kind(ITF::DV_E_NOIVIEWOBJECT),
            ITF::IO_WARNING_BUS_RESET => RawError::Kind(ITF::IO_WARNING_BUS_RESET),
            ITF::IO_WARNING_RESET => RawError::Kind(ITF::IO_WARNING_RESET),
            ITF::IO_WARNING_WRITE_FUA_PROBLEM => RawError::Kind(ITF::IO_WARNING_WRITE_FUA_PROBLEM),
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED => RawError::Kind(ITF::IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED),
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR => RawError::Kind(ITF::IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR),
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR => RawError::Kind(ITF::IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR),
            ITF::IO_WARNING_VOLUME_LOST_DISK_EXTENT => RawError::Kind(ITF::IO_WARNING_VOLUME_LOST_DISK_EXTENT),
            ITF::IO_WARNING_DEVICE_HAS_INTERNAL_DUMP => RawError::Kind(ITF::IO_WARNING_DEVICE_HAS_INTERNAL_DUMP),
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED => RawError::Kind(ITF::IO_WARNING_SOFT_THRESHOLD_REACHED),
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX => RawError::Kind(ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX),
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN => RawError::Kind(ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN),
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL => RawError::Kind(ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL),
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN => RawError::Kind(ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN),
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL => RawError::Kind(ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL),
            ITF::IO_WARNING_DISK_CAPACITY_CHANGED => RawError::Kind(ITF::IO_WARNING_DISK_CAPACITY_CHANGED),
            ITF::IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED => RawError::Kind(ITF::IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED),
            ITF::IO_WARNING_IO_OPERATION_RETRIED => RawError::Kind(ITF::IO_WARNING_IO_OPERATION_RETRIED),
            ITF::IO_WARNING_COMPLETION_TIME => RawError::Kind(ITF::IO_WARNING_COMPLETION_TIME),
            ITF::IO_WARNING_DUMP_DISABLED_DEVICE_GONE => RawError::Kind(ITF::IO_WARNING_DUMP_DISABLED_DEVICE_GONE),
            ITF::IO_WARNING_DISK_SURPRISE_REMOVED => RawError::Kind(ITF::IO_WARNING_DISK_SURPRISE_REMOVED),
            ITF::IO_WARNING_REPEATED_DISK_GUID => RawError::Kind(ITF::IO_WARNING_REPEATED_DISK_GUID),
            ITF::OLE_E_LAST => RawError::Kind(ITF::OLE_E_LAST),
            ITF::DRAGDROP_E_NOTREGISTERED => RawError::Kind(ITF::DRAGDROP_E_NOTREGISTERED),
            ITF::DRAGDROP_E_ALREADYREGISTERED => RawError::Kind(ITF::DRAGDROP_E_ALREADYREGISTERED),
            ITF::DRAGDROP_E_INVALIDHWND => RawError::Kind(ITF::DRAGDROP_E_INVALIDHWND),
            ITF::_MAPI_E_NO_SUPPORT => RawError::Kind(ITF::_MAPI_E_NO_SUPPORT),
            ITF::DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED => RawError::Kind(ITF::DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED),
            ITF::_MAPI_E_BAD_CHARWIDTH => RawError::Kind(ITF::_MAPI_E_BAD_CHARWIDTH),
            ITF::_MAPI_E_STRING_TOO_LONG => RawError::Kind(ITF::_MAPI_E_STRING_TOO_LONG),
            ITF::_MAPI_E_UNKNOWN_FLAGS => RawError::Kind(ITF::_MAPI_E_UNKNOWN_FLAGS),
            ITF::_MAPI_E_INVALID_ENTRYID => RawError::Kind(ITF::_MAPI_E_INVALID_ENTRYID),
            ITF::_MAPI_E_INVALID_OBJECT => RawError::Kind(ITF::_MAPI_E_INVALID_OBJECT),
            ITF::_MAPI_E_OBJECT_CHANGED => RawError::Kind(ITF::_MAPI_E_OBJECT_CHANGED),
            ITF::_MAPI_E_OBJECT_DELETED => RawError::Kind(ITF::_MAPI_E_OBJECT_DELETED),
            ITF::_MAPI_E_BUSY => RawError::Kind(ITF::_MAPI_E_BUSY),
            ITF::_MAPI_E_NOT_ENOUGH_DISK => RawError::Kind(ITF::_MAPI_E_NOT_ENOUGH_DISK),
            ITF::_MAPI_E_NOT_ENOUGH_RESOURCES => RawError::Kind(ITF::_MAPI_E_NOT_ENOUGH_RESOURCES),
            ITF::_MAPI_E_NOT_FOUND => RawError::Kind(ITF::_MAPI_E_NOT_FOUND),
            ITF::CLASS_E_NOAGGREGATION => RawError::Kind(ITF::CLASS_E_NOAGGREGATION),
            ITF::_MAPI_E_VERSION => RawError::Kind(ITF::_MAPI_E_VERSION),
            ITF::CLASS_E_CLASSNOTAVAILABLE => RawError::Kind(ITF::CLASS_E_CLASSNOTAVAILABLE),
            ITF::_MAPI_E_LOGON_FAILED => RawError::Kind(ITF::_MAPI_E_LOGON_FAILED),
            ITF::CLASS_E_NOTLICENSED => RawError::Kind(ITF::CLASS_E_NOTLICENSED),
            ITF::_MAPI_E_SESSION_LIMIT => RawError::Kind(ITF::_MAPI_E_SESSION_LIMIT),
            ITF::_MAPI_E_USER_CANCEL => RawError::Kind(ITF::_MAPI_E_USER_CANCEL),
            ITF::_MAPI_E_UNABLE_TO_ABORT => RawError::Kind(ITF::_MAPI_E_UNABLE_TO_ABORT),
            ITF::_MAPI_E_NETWORK_ERROR => RawError::Kind(ITF::_MAPI_E_NETWORK_ERROR),
            ITF::_MAPI_E_DISK_ERROR => RawError::Kind(ITF::_MAPI_E_DISK_ERROR),
            ITF::_MAPI_E_TOO_COMPLEX => RawError::Kind(ITF::_MAPI_E_TOO_COMPLEX),
            ITF::_MAPI_E_BAD_COLUMN => RawError::Kind(ITF::_MAPI_E_BAD_COLUMN),
            ITF::_MAPI_E_EXTENDED_ERROR => RawError::Kind(ITF::_MAPI_E_EXTENDED_ERROR),
            ITF::_MAPI_E_COMPUTED => RawError::Kind(ITF::_MAPI_E_COMPUTED),
            ITF::_MAPI_E_CORRUPT_DATA => RawError::Kind(ITF::_MAPI_E_CORRUPT_DATA),
            ITF::_MAPI_E_UNCONFIGURED => RawError::Kind(ITF::_MAPI_E_UNCONFIGURED),
            ITF::_MAPI_E_FAILONEPROVIDER => RawError::Kind(ITF::_MAPI_E_FAILONEPROVIDER),
            ITF::_MAPI_E_UNKNOWN_CPID => RawError::Kind(ITF::_MAPI_E_UNKNOWN_CPID),
            ITF::_MAPI_E_UNKNOWN_LCID => RawError::Kind(ITF::_MAPI_E_UNKNOWN_LCID),
            ITF::_MAPI_E_PASSWORD_CHANGE_REQUIRED => RawError::Kind(ITF::_MAPI_E_PASSWORD_CHANGE_REQUIRED),
            ITF::_MAPI_E_PASSWORD_EXPIRED => RawError::Kind(ITF::_MAPI_E_PASSWORD_EXPIRED),
            ITF::_MAPI_E_INVALID_WORKSTATION_ACCOUNT => RawError::Kind(ITF::_MAPI_E_INVALID_WORKSTATION_ACCOUNT),
            ITF::_MAPI_E_INVALID_ACCESS_TIME => RawError::Kind(ITF::_MAPI_E_INVALID_ACCESS_TIME),
            ITF::_MAPI_E_ACCOUNT_DISABLED => RawError::Kind(ITF::_MAPI_E_ACCOUNT_DISABLED),
            ITF::VIEW_E_DRAW => RawError::Kind(ITF::VIEW_E_DRAW),
            ITF::REGDB_E_READREGDB => RawError::Kind(ITF::REGDB_E_READREGDB),
            ITF::REGDB_E_WRITEREGDB => RawError::Kind(ITF::REGDB_E_WRITEREGDB),
            ITF::REGDB_E_KEYMISSING => RawError::Kind(ITF::REGDB_E_KEYMISSING),
            ITF::REGDB_E_INVALIDVALUE => RawError::Kind(ITF::REGDB_E_INVALIDVALUE),
            ITF::REGDB_E_CLASSNOTREG => RawError::Kind(ITF::REGDB_E_CLASSNOTREG),
            ITF::E_CLASSNOTREG => RawError::Kind(ITF::E_CLASSNOTREG),
            ITF::REGDB_E_IIDNOTREG => RawError::Kind(ITF::REGDB_E_IIDNOTREG),
            ITF::REGDB_E_BADTHREADINGMODEL => RawError::Kind(ITF::REGDB_E_BADTHREADINGMODEL),
            ITF::REGDB_E_PACKAGEPOLICYVIOLATION => RawError::Kind(ITF::REGDB_E_PACKAGEPOLICYVIOLATION),
            ITF::CAT_E_CATIDNOEXIST => RawError::Kind(ITF::CAT_E_CATIDNOEXIST),
            ITF::CAT_E_NODESCRIPTION => RawError::Kind(ITF::CAT_E_NODESCRIPTION),
            ITF::CS_E_PACKAGE_NOTFOUND => RawError::Kind(ITF::CS_E_PACKAGE_NOTFOUND),
            ITF::CS_E_NOT_DELETABLE => RawError::Kind(ITF::CS_E_NOT_DELETABLE),
            ITF::CS_E_CLASS_NOTFOUND => RawError::Kind(ITF::CS_E_CLASS_NOTFOUND),
            ITF::CS_E_INVALID_VERSION => RawError::Kind(ITF::CS_E_INVALID_VERSION),
            ITF::CS_E_NO_CLASSSTORE => RawError::Kind(ITF::CS_E_NO_CLASSSTORE),
            ITF::CS_E_OBJECT_NOTFOUND => RawError::Kind(ITF::CS_E_OBJECT_NOTFOUND),
            ITF::CS_E_OBJECT_ALREADY_EXISTS => RawError::Kind(ITF::CS_E_OBJECT_ALREADY_EXISTS),
            ITF::CS_E_INVALID_PATH => RawError::Kind(ITF::CS_E_INVALID_PATH),
            ITF::CS_E_NETWORK_ERROR => RawError::Kind(ITF::CS_E_NETWORK_ERROR),
            ITF::CS_E_ADMIN_LIMIT_EXCEEDED => RawError::Kind(ITF::CS_E_ADMIN_LIMIT_EXCEEDED),
            ITF::CS_E_SCHEMA_MISMATCH => RawError::Kind(ITF::CS_E_SCHEMA_MISMATCH),
            ITF::CS_E_INTERNAL_ERROR => RawError::Kind(ITF::CS_E_INTERNAL_ERROR),
            ITF::CACHE_E_NOCACHE_UPDATED => RawError::Kind(ITF::CACHE_E_NOCACHE_UPDATED),
            ITF::OLEOBJ_E_NOVERBS => RawError::Kind(ITF::OLEOBJ_E_NOVERBS),
            ITF::OLEOBJ_E_INVALIDVERB => RawError::Kind(ITF::OLEOBJ_E_INVALIDVERB),
            ITF::INPLACE_E_NOTUNDOABLE => RawError::Kind(ITF::INPLACE_E_NOTUNDOABLE),
            ITF::INPLACE_E_NOTOOLSPACE => RawError::Kind(ITF::INPLACE_E_NOTOOLSPACE),
            ITF::CONVERT10_E_OLESTREAM_GET => RawError::Kind(ITF::CONVERT10_E_OLESTREAM_GET),
            ITF::CONVERT10_E_OLESTREAM_PUT => RawError::Kind(ITF::CONVERT10_E_OLESTREAM_PUT),
            ITF::CONVERT10_E_OLESTREAM_FMT => RawError::Kind(ITF::CONVERT10_E_OLESTREAM_FMT),
            ITF::CONVERT10_E_OLESTREAM_BITMAP_TO_DIB => RawError::Kind(ITF::CONVERT10_E_OLESTREAM_BITMAP_TO_DIB),
            ITF::CONVERT10_E_STG_FMT => RawError::Kind(ITF::CONVERT10_E_STG_FMT),
            ITF::CONVERT10_E_STG_NO_STD_STREAM => RawError::Kind(ITF::CONVERT10_E_STG_NO_STD_STREAM),
            ITF::CONVERT10_E_STG_DIB_TO_BITMAP => RawError::Kind(ITF::CONVERT10_E_STG_DIB_TO_BITMAP),
            ITF::CLIPBRD_E_CANT_OPEN => RawError::Kind(ITF::CLIPBRD_E_CANT_OPEN),
            ITF::CLIPBRD_E_CANT_EMPTY => RawError::Kind(ITF::CLIPBRD_E_CANT_EMPTY),
            ITF::CLIPBRD_E_CANT_SET => RawError::Kind(ITF::CLIPBRD_E_CANT_SET),
            ITF::CLIPBRD_E_BAD_DATA => RawError::Kind(ITF::CLIPBRD_E_BAD_DATA),
            ITF::CLIPBRD_E_CANT_CLOSE => RawError::Kind(ITF::CLIPBRD_E_CANT_CLOSE),
            ITF::MK_E_CONNECTMANUALLY => RawError::Kind(ITF::MK_E_CONNECTMANUALLY),
            ITF::MK_E_EXCEEDEDDEADLINE => RawError::Kind(ITF::MK_E_EXCEEDEDDEADLINE),
            ITF::MK_E_NEEDGENERIC => RawError::Kind(ITF::MK_E_NEEDGENERIC),
            ITF::MK_E_UNAVAILABLE => RawError::Kind(ITF::MK_E_UNAVAILABLE),
            ITF::MK_E_SYNTAX => RawError::Kind(ITF::MK_E_SYNTAX),
            ITF::MK_E_NOOBJECT => RawError::Kind(ITF::MK_E_NOOBJECT),
            ITF::MK_E_INVALIDEXTENSION => RawError::Kind(ITF::MK_E_INVALIDEXTENSION),
            ITF::MK_E_INTERMEDIATEINTERFACENOTSUPPORTED => RawError::Kind(ITF::MK_E_INTERMEDIATEINTERFACENOTSUPPORTED),
            ITF::MK_E_NOTBINDABLE => RawError::Kind(ITF::MK_E_NOTBINDABLE),
            ITF::MK_E_NOTBOUND => RawError::Kind(ITF::MK_E_NOTBOUND),
            ITF::MK_E_CANTOPENFILE => RawError::Kind(ITF::MK_E_CANTOPENFILE),
            ITF::MK_E_MUSTBOTHERUSER => RawError::Kind(ITF::MK_E_MUSTBOTHERUSER),
            ITF::MK_E_NOINVERSE => RawError::Kind(ITF::MK_E_NOINVERSE),
            ITF::MK_E_NOSTORAGE => RawError::Kind(ITF::MK_E_NOSTORAGE),
            ITF::MK_E_NOPREFIX => RawError::Kind(ITF::MK_E_NOPREFIX),
            ITF::MK_E_ENUMERATION_FAILED => RawError::Kind(ITF::MK_E_ENUMERATION_FAILED),
            ITF::CO_E_NOTINITIALIZED => RawError::Kind(ITF::CO_E_NOTINITIALIZED),
            ITF::DDERR_NOTINITIALIZED => RawError::Kind(ITF::DDERR_NOTINITIALIZED),
            ITF::CO_E_ALREADYINITIALIZED => RawError::Kind(ITF::CO_E_ALREADYINITIALIZED),
            ITF::CO_E_CANTDETERMINECLASS => RawError::Kind(ITF::CO_E_CANTDETERMINECLASS),
            ITF::CO_E_CLASSSTRING => RawError::Kind(ITF::CO_E_CLASSSTRING),
            ITF::CO_E_IIDSTRING => RawError::Kind(ITF::CO_E_IIDSTRING),
            ITF::CO_E_APPNOTFOUND => RawError::Kind(ITF::CO_E_APPNOTFOUND),
            ITF::CO_E_APPSINGLEUSE => RawError::Kind(ITF::CO_E_APPSINGLEUSE),
            ITF::CO_E_ERRORINAPP => RawError::Kind(ITF::CO_E_ERRORINAPP),
            ITF::CO_E_DLLNOTFOUND => RawError::Kind(ITF::CO_E_DLLNOTFOUND),
            ITF::CO_E_ERRORINDLL => RawError::Kind(ITF::CO_E_ERRORINDLL),
            ITF::CO_E_WRONGOSFORAPP => RawError::Kind(ITF::CO_E_WRONGOSFORAPP),
            ITF::CO_E_OBJNOTREG => RawError::Kind(ITF::CO_E_OBJNOTREG),
            ITF::CO_E_OBJISREG => RawError::Kind(ITF::CO_E_OBJISREG),
            ITF::CO_E_OBJNOTCONNECTED => RawError::Kind(ITF::CO_E_OBJNOTCONNECTED),
            ITF::CO_E_APPDIDNTREG => RawError::Kind(ITF::CO_E_APPDIDNTREG),
            ITF::CO_E_RELEASED => RawError::Kind(ITF::CO_E_RELEASED),
            ITF::VFW_E_INVALIDMEDIATYPE => RawError::Kind(ITF::VFW_E_INVALIDMEDIATYPE),
            ITF::_MAPI_E_END_OF_SESSION => RawError::Kind(ITF::_MAPI_E_END_OF_SESSION),
            ITF::MPEG2_E_UNINITIALIZED => RawError::Kind(ITF::MPEG2_E_UNINITIALIZED),
            ITF::TF_E_INVALIDPOS => RawError::Kind(ITF::TF_E_INVALIDPOS),
            ITF::TS_E_INVALIDPOS => RawError::Kind(ITF::TS_E_INVALIDPOS),
            ITF::UPNP_E_ROOT_ELEMENT_EXPECTED => RawError::Kind(ITF::UPNP_E_ROOT_ELEMENT_EXPECTED),
            ITF::USP_E_SCRIPT_NOT_IN_FONT => RawError::Kind(ITF::USP_E_SCRIPT_NOT_IN_FONT),
            ITF::EVENT_E_ALL_SUBSCRIBERS_FAILED => RawError::Kind(ITF::EVENT_E_ALL_SUBSCRIBERS_FAILED),
            ITF::VFW_E_INVALIDSUBTYPE => RawError::Kind(ITF::VFW_E_INVALIDSUBTYPE),
            ITF::CDO_E_UNCAUGHT_EXCEPTION => RawError::Kind(ITF::CDO_E_UNCAUGHT_EXCEPTION),
            ITF::_MAPI_E_UNKNOWN_ENTRYID => RawError::Kind(ITF::_MAPI_E_UNKNOWN_ENTRYID),
            ITF::MPEG2_E_ALREADY_INITIALIZED => RawError::Kind(ITF::MPEG2_E_ALREADY_INITIALIZED),
            ITF::TF_E_NOLOCK => RawError::Kind(ITF::TF_E_NOLOCK),
            ITF::TS_E_NOLOCK => RawError::Kind(ITF::TS_E_NOLOCK),
            ITF::UPNP_E_DEVICE_ELEMENT_EXPECTED => RawError::Kind(ITF::UPNP_E_DEVICE_ELEMENT_EXPECTED),
            ITF::VFW_E_NEED_OWNER => RawError::Kind(ITF::VFW_E_NEED_OWNER),
            ITF::CDO_E_NOT_OPENED => RawError::Kind(ITF::CDO_E_NOT_OPENED),
            ITF::_MAPI_E_MISSING_REQUIRED_COLUMN => RawError::Kind(ITF::_MAPI_E_MISSING_REQUIRED_COLUMN),
            ITF::MPEG2_E_OUT_OF_BOUNDS => RawError::Kind(ITF::MPEG2_E_OUT_OF_BOUNDS),
            ITF::TF_E_NOOBJECT => RawError::Kind(ITF::TF_E_NOOBJECT),
            ITF::TS_E_NOOBJECT => RawError::Kind(ITF::TS_E_NOOBJECT),
            ITF::UPNP_E_SERVICE_ELEMENT_EXPECTED => RawError::Kind(ITF::UPNP_E_SERVICE_ELEMENT_EXPECTED),
            ITF::EVENT_E_QUERYSYNTAX => RawError::Kind(ITF::EVENT_E_QUERYSYNTAX),
            ITF::VFW_E_ENUM_OUT_OF_SYNC => RawError::Kind(ITF::VFW_E_ENUM_OUT_OF_SYNC),
            ITF::CDO_E_UNSUPPORTED_DATASOURCE => RawError::Kind(ITF::CDO_E_UNSUPPORTED_DATASOURCE),
            ITF::MPEG2_E_MALFORMED_TABLE => RawError::Kind(ITF::MPEG2_E_MALFORMED_TABLE),
            ITF::TF_E_NOSERVICE => RawError::Kind(ITF::TF_E_NOSERVICE),
            ITF::TS_E_NOSERVICE => RawError::Kind(ITF::TS_E_NOSERVICE),
            ITF::UPNP_E_SERVICE_NODE_INCOMPLETE => RawError::Kind(ITF::UPNP_E_SERVICE_NODE_INCOMPLETE),
            ITF::EVENT_E_QUERYFIELD => RawError::Kind(ITF::EVENT_E_QUERYFIELD),
            ITF::VFW_E_ALREADY_CONNECTED => RawError::Kind(ITF::VFW_E_ALREADY_CONNECTED),
            ITF::CDO_E_INVALID_PROPERTYNAME => RawError::Kind(ITF::CDO_E_INVALID_PROPERTYNAME),
            ITF::MPEG2_E_UNDEFINED => RawError::Kind(ITF::MPEG2_E_UNDEFINED),
            ITF::TF_E_NOINTERFACE => RawError::Kind(ITF::TF_E_NOINTERFACE),
            ITF::TS_E_NOINTERFACE => RawError::Kind(ITF::TS_E_NOINTERFACE),
            ITF::UPNP_E_DEVICE_NODE_INCOMPLETE => RawError::Kind(ITF::UPNP_E_DEVICE_NODE_INCOMPLETE),
            ITF::EVENT_E_INTERNALEXCEPTION => RawError::Kind(ITF::EVENT_E_INTERNALEXCEPTION),
            ITF::VFW_E_FILTER_ACTIVE => RawError::Kind(ITF::VFW_E_FILTER_ACTIVE),
            ITF::CDO_E_PROP_UNSUPPORTED => RawError::Kind(ITF::CDO_E_PROP_UNSUPPORTED),
            ITF::MPEG2_E_NOT_PRESENT => RawError::Kind(ITF::MPEG2_E_NOT_PRESENT),
            ITF::TF_E_NOSELECTION => RawError::Kind(ITF::TF_E_NOSELECTION),
            ITF::TS_E_NOSELECTION => RawError::Kind(ITF::TS_E_NOSELECTION),
            ITF::UPNP_E_ICON_ELEMENT_EXPECTED => RawError::Kind(ITF::UPNP_E_ICON_ELEMENT_EXPECTED),
            ITF::EVENT_E_INTERNALERROR => RawError::Kind(ITF::EVENT_E_INTERNALERROR),
            ITF::VFW_E_NO_TYPES => RawError::Kind(ITF::VFW_E_NO_TYPES),
            ITF::CDO_E_INACTIVE => RawError::Kind(ITF::CDO_E_INACTIVE),
            ITF::MPEG2_E_SECTION_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_SECTION_NOT_FOUND),
            ITF::TF_E_NOLAYOUT => RawError::Kind(ITF::TF_E_NOLAYOUT),
            ITF::TS_E_NOLAYOUT => RawError::Kind(ITF::TS_E_NOLAYOUT),
            ITF::UPNP_E_ICON_NODE_INCOMPLETE => RawError::Kind(ITF::UPNP_E_ICON_NODE_INCOMPLETE),
            ITF::EVENT_E_INVALID_PER_USER_SID => RawError::Kind(ITF::EVENT_E_INVALID_PER_USER_SID),
            ITF::VFW_E_NO_ACCEPTABLE_TYPES => RawError::Kind(ITF::VFW_E_NO_ACCEPTABLE_TYPES),
            ITF::CDO_E_NO_SUPPORT_FOR_OBJECTS => RawError::Kind(ITF::CDO_E_NO_SUPPORT_FOR_OBJECTS),
            ITF::MPEG2_E_TX_STREAM_UNAVAILABLE => RawError::Kind(ITF::MPEG2_E_TX_STREAM_UNAVAILABLE),
            ITF::TF_E_INVALIDPOINT => RawError::Kind(ITF::TF_E_INVALIDPOINT),
            ITF::TS_E_INVALIDPOINT => RawError::Kind(ITF::TS_E_INVALIDPOINT),
            ITF::UPNP_E_INVALID_ACTION => RawError::Kind(ITF::UPNP_E_INVALID_ACTION),
            ITF::EVENT_E_USER_EXCEPTION => RawError::Kind(ITF::EVENT_E_USER_EXCEPTION),
            ITF::VFW_E_INVALID_DIRECTION => RawError::Kind(ITF::VFW_E_INVALID_DIRECTION),
            ITF::CDO_E_NOT_AVAILABLE => RawError::Kind(ITF::CDO_E_NOT_AVAILABLE),
            ITF::MPEG2_E_SERVICE_ID_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_SERVICE_ID_NOT_FOUND),
            ITF::TF_E_SYNCHRONOUS => RawError::Kind(ITF::TF_E_SYNCHRONOUS),
            ITF::TS_E_SYNCHRONOUS => RawError::Kind(ITF::TS_E_SYNCHRONOUS),
            ITF::UPNP_E_INVALID_ARGUMENTS => RawError::Kind(ITF::UPNP_E_INVALID_ARGUMENTS),
            ITF::EVENT_E_TOO_MANY_METHODS => RawError::Kind(ITF::EVENT_E_TOO_MANY_METHODS),
            ITF::VFW_E_NOT_CONNECTED => RawError::Kind(ITF::VFW_E_NOT_CONNECTED),
            ITF::CDO_E_NO_DEFAULT_DROP_DIR => RawError::Kind(ITF::CDO_E_NO_DEFAULT_DROP_DIR),
            ITF::MPEG2_E_SERVICE_PMT_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_SERVICE_PMT_NOT_FOUND),
            ITF::TF_E_READONLY => RawError::Kind(ITF::TF_E_READONLY),
            ITF::TS_E_READONLY => RawError::Kind(ITF::TS_E_READONLY),
            ITF::UPNP_E_OUT_OF_SYNC => RawError::Kind(ITF::UPNP_E_OUT_OF_SYNC),
            ITF::EVENT_E_MISSING_EVENTCLASS => RawError::Kind(ITF::EVENT_E_MISSING_EVENTCLASS),
            ITF::VFW_E_NO_ALLOCATOR => RawError::Kind(ITF::VFW_E_NO_ALLOCATOR),
            ITF::CDO_E_SMTP_SERVER_REQUIRED => RawError::Kind(ITF::CDO_E_SMTP_SERVER_REQUIRED),
            ITF::MPEG2_E_DSI_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_DSI_NOT_FOUND),
            ITF::TF_E_FORMAT => RawError::Kind(ITF::TF_E_FORMAT),
            ITF::TS_E_FORMAT => RawError::Kind(ITF::TS_E_FORMAT),
            ITF::EVENT_E_NOT_ALL_REMOVED => RawError::Kind(ITF::EVENT_E_NOT_ALL_REMOVED),
            ITF::VFW_E_RUNTIME_ERROR => RawError::Kind(ITF::VFW_E_RUNTIME_ERROR),
            ITF::CDO_E_NNTP_SERVER_REQUIRED => RawError::Kind(ITF::CDO_E_NNTP_SERVER_REQUIRED),
            ITF::IMAPI_E_NOTOPENED => RawError::Kind(ITF::IMAPI_E_NOTOPENED),
            ITF::MPEG2_E_SERVER_UNAVAILABLE => RawError::Kind(ITF::MPEG2_E_SERVER_UNAVAILABLE),
            ITF::EVENT_E_COMPLUS_NOT_INSTALLED => RawError::Kind(ITF::EVENT_E_COMPLUS_NOT_INSTALLED),
            ITF::VFW_E_BUFFER_NOTSET => RawError::Kind(ITF::VFW_E_BUFFER_NOTSET),
            ITF::CDO_E_RECIPIENT_MISSING => RawError::Kind(ITF::CDO_E_RECIPIENT_MISSING),
            ITF::IMAPI_E_NOTINITIALIZED => RawError::Kind(ITF::IMAPI_E_NOTINITIALIZED),
            ITF::MPEG2_E_INVALID_CAROUSEL_ID => RawError::Kind(ITF::MPEG2_E_INVALID_CAROUSEL_ID),
            ITF::EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT => RawError::Kind(ITF::EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT),
            ITF::VFW_E_BUFFER_OVERFLOW => RawError::Kind(ITF::VFW_E_BUFFER_OVERFLOW),
            ITF::CDO_E_FROM_MISSING => RawError::Kind(ITF::CDO_E_FROM_MISSING),
            ITF::IMAPI_E_USERABORT => RawError::Kind(ITF::IMAPI_E_USERABORT),
            ITF::MPEG2_E_MALFORMED_DSMCC_MESSAGE => RawError::Kind(ITF::MPEG2_E_MALFORMED_DSMCC_MESSAGE),
            ITF::EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT => RawError::Kind(ITF::EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT),
            ITF::VFW_E_BADALIGN => RawError::Kind(ITF::VFW_E_BADALIGN),
            ITF::CDO_E_SENDER_REJECTED => RawError::Kind(ITF::CDO_E_SENDER_REJECTED),
            ITF::IMAPI_E_GENERIC => RawError::Kind(ITF::IMAPI_E_GENERIC),
            ITF::MPEG2_E_INVALID_SG_OBJECT_KIND => RawError::Kind(ITF::MPEG2_E_INVALID_SG_OBJECT_KIND),
            ITF::EVENT_E_INVALID_EVENT_CLASS_PARTITION => RawError::Kind(ITF::EVENT_E_INVALID_EVENT_CLASS_PARTITION),
            ITF::VFW_E_ALREADY_COMMITTED => RawError::Kind(ITF::VFW_E_ALREADY_COMMITTED),
            ITF::CDO_E_RECIPIENTS_REJECTED => RawError::Kind(ITF::CDO_E_RECIPIENTS_REJECTED),
            ITF::IMAPI_E_MEDIUM_NOTPRESENT => RawError::Kind(ITF::IMAPI_E_MEDIUM_NOTPRESENT),
            ITF::MPEG2_E_OBJECT_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_OBJECT_NOT_FOUND),
            ITF::EVENT_E_PER_USER_SID_NOT_LOGGED_ON => RawError::Kind(ITF::EVENT_E_PER_USER_SID_NOT_LOGGED_ON),
            ITF::VFW_E_BUFFERS_OUTSTANDING => RawError::Kind(ITF::VFW_E_BUFFERS_OUTSTANDING),
            ITF::CDO_E_NNTP_POST_FAILED => RawError::Kind(ITF::CDO_E_NNTP_POST_FAILED),
            ITF::IMAPI_E_MEDIUM_INVALIDTYPE => RawError::Kind(ITF::IMAPI_E_MEDIUM_INVALIDTYPE),
            ITF::MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY => RawError::Kind(ITF::MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY),
            ITF::UPNP_E_ACTION_REQUEST_FAILED => RawError::Kind(ITF::UPNP_E_ACTION_REQUEST_FAILED),
            ITF::VFW_E_NOT_COMMITTED => RawError::Kind(ITF::VFW_E_NOT_COMMITTED),
            ITF::CDO_E_SMTP_SEND_FAILED => RawError::Kind(ITF::CDO_E_SMTP_SEND_FAILED),
            ITF::IMAPI_E_DEVICE_NOPROPERTIES => RawError::Kind(ITF::IMAPI_E_DEVICE_NOPROPERTIES),
            ITF::MPEG2_E_OBJECT_KIND_NOT_A_FILE => RawError::Kind(ITF::MPEG2_E_OBJECT_KIND_NOT_A_FILE),
            ITF::UPNP_E_TRANSPORT_ERROR => RawError::Kind(ITF::UPNP_E_TRANSPORT_ERROR),
            ITF::TPC_E_NO_DEFAULT_TABLET => RawError::Kind(ITF::TPC_E_NO_DEFAULT_TABLET),
            ITF::VFW_E_SIZENOTSET => RawError::Kind(ITF::VFW_E_SIZENOTSET),
            ITF::CDO_E_CONNECTION_DROPPED => RawError::Kind(ITF::CDO_E_CONNECTION_DROPPED),
            ITF::IMAPI_E_DEVICE_NOTACCESSIBLE => RawError::Kind(ITF::IMAPI_E_DEVICE_NOTACCESSIBLE),
            ITF::MPEG2_E_FILE_OFFSET_TOO_BIG => RawError::Kind(ITF::MPEG2_E_FILE_OFFSET_TOO_BIG),
            ITF::UPNP_E_VARIABLE_VALUE_UNKNOWN => RawError::Kind(ITF::UPNP_E_VARIABLE_VALUE_UNKNOWN),
            ITF::VFW_E_NO_CLOCK => RawError::Kind(ITF::VFW_E_NO_CLOCK),
            ITF::CDO_E_FAILED_TO_CONNECT => RawError::Kind(ITF::CDO_E_FAILED_TO_CONNECT),
            ITF::IMAPI_E_DEVICE_NOTPRESENT => RawError::Kind(ITF::IMAPI_E_DEVICE_NOTPRESENT),
            ITF::MPEG2_E_STREAM_STOPPED => RawError::Kind(ITF::MPEG2_E_STREAM_STOPPED),
            ITF::UPNP_E_INVALID_VARIABLE => RawError::Kind(ITF::UPNP_E_INVALID_VARIABLE),
            ITF::VFW_E_NO_SINK => RawError::Kind(ITF::VFW_E_NO_SINK),
            ITF::CDO_E_INVALID_POST => RawError::Kind(ITF::CDO_E_INVALID_POST),
            ITF::IMAPI_E_DEVICE_INVALIDTYPE => RawError::Kind(ITF::IMAPI_E_DEVICE_INVALIDTYPE),
            ITF::MPEG2_E_REGISTRY_ACCESS_FAILED => RawError::Kind(ITF::MPEG2_E_REGISTRY_ACCESS_FAILED),
            ITF::UPNP_E_DEVICE_ERROR => RawError::Kind(ITF::UPNP_E_DEVICE_ERROR),
            ITF::VFW_E_NO_INTERFACE => RawError::Kind(ITF::VFW_E_NO_INTERFACE),
            ITF::CDO_E_AUTHENTICATION_FAILURE => RawError::Kind(ITF::CDO_E_AUTHENTICATION_FAILURE),
            ITF::IMAPI_E_INITIALIZE_WRITE => RawError::Kind(ITF::IMAPI_E_INITIALIZE_WRITE),
            ITF::MPEG2_E_INVALID_UDP_PORT => RawError::Kind(ITF::MPEG2_E_INVALID_UDP_PORT),
            ITF::UPNP_E_PROTOCOL_ERROR => RawError::Kind(ITF::UPNP_E_PROTOCOL_ERROR),
            ITF::VFW_E_NOT_FOUND => RawError::Kind(ITF::VFW_E_NOT_FOUND),
            ITF::CDO_E_INVALID_CONTENT_TYPE => RawError::Kind(ITF::CDO_E_INVALID_CONTENT_TYPE),
            ITF::IMAPI_E_INITIALIZE_ENDWRITE => RawError::Kind(ITF::IMAPI_E_INITIALIZE_ENDWRITE),
            ITF::MPEG2_E_DATA_SOURCE_FAILED => RawError::Kind(ITF::MPEG2_E_DATA_SOURCE_FAILED),
            ITF::UPNP_E_ERROR_PROCESSING_RESPONSE => RawError::Kind(ITF::UPNP_E_ERROR_PROCESSING_RESPONSE),
            ITF::VFW_E_CANNOT_CONNECT => RawError::Kind(ITF::VFW_E_CANNOT_CONNECT),
            ITF::CDO_E_LOGON_FAILURE => RawError::Kind(ITF::CDO_E_LOGON_FAILURE),
            ITF::IMAPI_E_FILESYSTEM => RawError::Kind(ITF::IMAPI_E_FILESYSTEM),
            ITF::MPEG2_E_DII_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_DII_NOT_FOUND),
            ITF::UPNP_E_DEVICE_TIMEOUT => RawError::Kind(ITF::UPNP_E_DEVICE_TIMEOUT),
            ITF::VFW_E_CANNOT_RENDER => RawError::Kind(ITF::VFW_E_CANNOT_RENDER),
            ITF::CDO_E_HTTP_NOT_FOUND => RawError::Kind(ITF::CDO_E_HTTP_NOT_FOUND),
            ITF::IMAPI_E_FILEACCESS => RawError::Kind(ITF::IMAPI_E_FILEACCESS),
            ITF::MPEG2_E_DSHOW_PIN_NOT_FOUND => RawError::Kind(ITF::MPEG2_E_DSHOW_PIN_NOT_FOUND),
            ITF::TPC_E_INVALID_INPUT_RECT => RawError::Kind(ITF::TPC_E_INVALID_INPUT_RECT),
            ITF::VFW_E_CHANGING_FORMAT => RawError::Kind(ITF::VFW_E_CHANGING_FORMAT),
            ITF::CDO_E_HTTP_FORBIDDEN => RawError::Kind(ITF::CDO_E_HTTP_FORBIDDEN),
            ITF::IMAPI_E_DISCINFO => RawError::Kind(ITF::IMAPI_E_DISCINFO),
            ITF::MPEG2_E_BUFFER_TOO_SMALL => RawError::Kind(ITF::MPEG2_E_BUFFER_TOO_SMALL),
            ITF::VFW_E_NO_COLOR_KEY_SET => RawError::Kind(ITF::VFW_E_NO_COLOR_KEY_SET),
            ITF::CDO_E_HTTP_FAILED => RawError::Kind(ITF::CDO_E_HTTP_FAILED),
            ITF::IMAPI_E_TRACKNOTOPEN => RawError::Kind(ITF::IMAPI_E_TRACKNOTOPEN),
            ITF::MPEG2_E_MISSING_SECTIONS => RawError::Kind(ITF::MPEG2_E_MISSING_SECTIONS),
            ITF::TPC_E_UNKNOWN_PROPERTY => RawError::Kind(ITF::TPC_E_UNKNOWN_PROPERTY),
            ITF::VFW_E_NOT_OVERLAY_CONNECTION => RawError::Kind(ITF::VFW_E_NOT_OVERLAY_CONNECTION),
            ITF::CDO_E_MULTIPART_NO_DATA => RawError::Kind(ITF::CDO_E_MULTIPART_NO_DATA),
            ITF::IMAPI_E_TRACKOPEN => RawError::Kind(ITF::IMAPI_E_TRACKOPEN),
            ITF::MPEG2_E_TOO_MANY_SECTIONS => RawError::Kind(ITF::MPEG2_E_TOO_MANY_SECTIONS),
            ITF::VFW_E_NOT_SAMPLE_CONNECTION => RawError::Kind(ITF::VFW_E_NOT_SAMPLE_CONNECTION),
            ITF::CDO_E_INVALID_ENCODING_FOR_MULTIPART => RawError::Kind(ITF::CDO_E_INVALID_ENCODING_FOR_MULTIPART),
            ITF::IMAPI_E_DISCFULL => RawError::Kind(ITF::IMAPI_E_DISCFULL),
            ITF::MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE => RawError::Kind(ITF::MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE),
            ITF::VFW_E_PALETTE_SET => RawError::Kind(ITF::VFW_E_PALETTE_SET),
            ITF::CDO_E_UNSAFE_OPERATION => RawError::Kind(ITF::CDO_E_UNSAFE_OPERATION),
            ITF::IMAPI_E_BADJOLIETNAME => RawError::Kind(ITF::IMAPI_E_BADJOLIETNAME),
            ITF::MPEG2_E_INCORRECT_DESCRIPTOR_TAG => RawError::Kind(ITF::MPEG2_E_INCORRECT_DESCRIPTOR_TAG),
            ITF::VFW_E_COLOR_KEY_SET => RawError::Kind(ITF::VFW_E_COLOR_KEY_SET),
            ITF::CDO_E_PROP_NOT_FOUND => RawError::Kind(ITF::CDO_E_PROP_NOT_FOUND),
            ITF::IMAPI_E_INVALIDIMAGE => RawError::Kind(ITF::IMAPI_E_INVALIDIMAGE),
            ITF::VFW_E_NO_COLOR_KEY_FOUND => RawError::Kind(ITF::VFW_E_NO_COLOR_KEY_FOUND),
            ITF::IMAPI_E_NOACTIVEFORMAT => RawError::Kind(ITF::IMAPI_E_NOACTIVEFORMAT),
            ITF::VFW_E_NO_PALETTE_AVAILABLE => RawError::Kind(ITF::VFW_E_NO_PALETTE_AVAILABLE),
            ITF::CDO_E_INVALID_SEND_OPTION => RawError::Kind(ITF::CDO_E_INVALID_SEND_OPTION),
            ITF::IMAPI_E_NOACTIVERECORDER => RawError::Kind(ITF::IMAPI_E_NOACTIVERECORDER),
            ITF::VFW_E_NO_DISPLAY_PALETTE => RawError::Kind(ITF::VFW_E_NO_DISPLAY_PALETTE),
            ITF::CDO_E_INVALID_POST_OPTION => RawError::Kind(ITF::CDO_E_INVALID_POST_OPTION),
            ITF::IMAPI_E_WRONGFORMAT => RawError::Kind(ITF::IMAPI_E_WRONGFORMAT),
            ITF::TPC_E_INVALID_STROKE => RawError::Kind(ITF::TPC_E_INVALID_STROKE),
            ITF::VFW_E_TOO_MANY_COLORS => RawError::Kind(ITF::VFW_E_TOO_MANY_COLORS),
            ITF::CDO_E_NO_PICKUP_DIR => RawError::Kind(ITF::CDO_E_NO_PICKUP_DIR),
            ITF::IMAPI_E_ALREADYOPEN => RawError::Kind(ITF::IMAPI_E_ALREADYOPEN),
            ITF::TPC_E_INITIALIZE_FAIL => RawError::Kind(ITF::TPC_E_INITIALIZE_FAIL),
            ITF::VFW_E_STATE_CHANGED => RawError::Kind(ITF::VFW_E_STATE_CHANGED),
            ITF::CDO_E_NOT_ALL_DELETED => RawError::Kind(ITF::CDO_E_NOT_ALL_DELETED),
            ITF::IMAPI_E_WRONGDISC => RawError::Kind(ITF::IMAPI_E_WRONGDISC),
            ITF::VFW_E_NOT_STOPPED => RawError::Kind(ITF::VFW_E_NOT_STOPPED),
            ITF::CDO_E_NO_METHOD => RawError::Kind(ITF::CDO_E_NO_METHOD),
            ITF::IMAPI_E_FILEEXISTS => RawError::Kind(ITF::IMAPI_E_FILEEXISTS),
            ITF::VFW_E_NOT_PAUSED => RawError::Kind(ITF::VFW_E_NOT_PAUSED),
            ITF::IMAPI_E_STASHINUSE => RawError::Kind(ITF::IMAPI_E_STASHINUSE),
            ITF::VFW_E_NOT_RUNNING => RawError::Kind(ITF::VFW_E_NOT_RUNNING),
            ITF::IMAPI_E_DEVICE_STILL_IN_USE => RawError::Kind(ITF::IMAPI_E_DEVICE_STILL_IN_USE),
            ITF::VFW_E_WRONG_STATE => RawError::Kind(ITF::VFW_E_WRONG_STATE),
            ITF::CDO_E_PROP_READONLY => RawError::Kind(ITF::CDO_E_PROP_READONLY),
            ITF::IMAPI_E_LOSS_OF_STREAMING => RawError::Kind(ITF::IMAPI_E_LOSS_OF_STREAMING),
            ITF::VFW_E_START_TIME_AFTER_END => RawError::Kind(ITF::VFW_E_START_TIME_AFTER_END),
            ITF::CDO_E_PROP_CANNOT_DELETE => RawError::Kind(ITF::CDO_E_PROP_CANNOT_DELETE),
            ITF::IMAPI_E_COMPRESSEDSTASH => RawError::Kind(ITF::IMAPI_E_COMPRESSEDSTASH),
            ITF::VFW_E_INVALID_RECT => RawError::Kind(ITF::VFW_E_INVALID_RECT),
            ITF::CDO_E_BAD_DATA => RawError::Kind(ITF::CDO_E_BAD_DATA),
            ITF::IMAPI_E_ENCRYPTEDSTASH => RawError::Kind(ITF::IMAPI_E_ENCRYPTEDSTASH),
            ITF::VFW_E_TYPE_NOT_ACCEPTED => RawError::Kind(ITF::VFW_E_TYPE_NOT_ACCEPTED),
            ITF::CDO_E_PROP_NONHEADER => RawError::Kind(ITF::CDO_E_PROP_NONHEADER),
            ITF::IMAPI_E_NOTENOUGHDISKFORSTASH => RawError::Kind(ITF::IMAPI_E_NOTENOUGHDISKFORSTASH),
            ITF::VFW_E_SAMPLE_REJECTED => RawError::Kind(ITF::VFW_E_SAMPLE_REJECTED),
            ITF::CDO_E_INVALID_CHARSET => RawError::Kind(ITF::CDO_E_INVALID_CHARSET),
            ITF::IMAPI_E_REMOVABLESTASH => RawError::Kind(ITF::IMAPI_E_REMOVABLESTASH),
            ITF::VFW_E_SAMPLE_REJECTED_EOS => RawError::Kind(ITF::VFW_E_SAMPLE_REJECTED_EOS),
            ITF::CDO_E_ADOSTREAM_NOT_BOUND => RawError::Kind(ITF::CDO_E_ADOSTREAM_NOT_BOUND),
            ITF::IMAPI_E_CANNOT_WRITE_TO_MEDIA => RawError::Kind(ITF::IMAPI_E_CANNOT_WRITE_TO_MEDIA),
            ITF::VFW_E_DUPLICATE_NAME => RawError::Kind(ITF::VFW_E_DUPLICATE_NAME),
            ITF::CDO_E_CONTENTPROPXML_NOT_FOUND => RawError::Kind(ITF::CDO_E_CONTENTPROPXML_NOT_FOUND),
            ITF::IMAPI_E_TRACK_NOT_BIG_ENOUGH => RawError::Kind(ITF::IMAPI_E_TRACK_NOT_BIG_ENOUGH),
            ITF::VFW_E_TIMEOUT => RawError::Kind(ITF::VFW_E_TIMEOUT),
            ITF::CDO_E_CONTENTPROPXML_WRONG_CHARSET => RawError::Kind(ITF::CDO_E_CONTENTPROPXML_WRONG_CHARSET),
            ITF::VFW_E_INVALID_FILE_FORMAT => RawError::Kind(ITF::VFW_E_INVALID_FILE_FORMAT),
            ITF::CDO_E_CONTENTPROPXML_PARSE_FAILED => RawError::Kind(ITF::CDO_E_CONTENTPROPXML_PARSE_FAILED),
            ITF::VFW_E_ENUM_OUT_OF_RANGE => RawError::Kind(ITF::VFW_E_ENUM_OUT_OF_RANGE),
            ITF::CDO_E_CONTENTPROPXML_CONVERT_FAILED => RawError::Kind(ITF::CDO_E_CONTENTPROPXML_CONVERT_FAILED),
            ITF::VFW_E_CIRCULAR_GRAPH => RawError::Kind(ITF::VFW_E_CIRCULAR_GRAPH),
            ITF::CDO_E_NO_DIRECTORIES_SPECIFIED => RawError::Kind(ITF::CDO_E_NO_DIRECTORIES_SPECIFIED),
            ITF::TPC_E_NOT_RELEVANT => RawError::Kind(ITF::TPC_E_NOT_RELEVANT),
            ITF::VFW_E_NOT_ALLOWED_TO_SAVE => RawError::Kind(ITF::VFW_E_NOT_ALLOWED_TO_SAVE),
            ITF::CDO_E_DIRECTORIES_UNREACHABLE => RawError::Kind(ITF::CDO_E_DIRECTORIES_UNREACHABLE),
            ITF::TPC_E_INVALID_PACKET_DESCRIPTION => RawError::Kind(ITF::TPC_E_INVALID_PACKET_DESCRIPTION),
            ITF::VFW_E_TIME_ALREADY_PASSED => RawError::Kind(ITF::VFW_E_TIME_ALREADY_PASSED),
            ITF::CDO_E_BAD_SENDER => RawError::Kind(ITF::CDO_E_BAD_SENDER),
            ITF::VFW_E_ALREADY_CANCELLED => RawError::Kind(ITF::VFW_E_ALREADY_CANCELLED),
            ITF::CDO_E_SELF_BINDING => RawError::Kind(ITF::CDO_E_SELF_BINDING),
            ITF::TPC_E_RECOGNIZER_NOT_REGISTERED => RawError::Kind(ITF::TPC_E_RECOGNIZER_NOT_REGISTERED),
            ITF::VFW_E_CORRUPT_GRAPH_FILE => RawError::Kind(ITF::VFW_E_CORRUPT_GRAPH_FILE),
            ITF::CDO_E_BAD_ATTENDEE_DATA => RawError::Kind(ITF::CDO_E_BAD_ATTENDEE_DATA),
            ITF::TPC_E_INVALID_RIGHTS => RawError::Kind(ITF::TPC_E_INVALID_RIGHTS),
            ITF::VFW_E_ADVISE_ALREADY_SET => RawError::Kind(ITF::VFW_E_ADVISE_ALREADY_SET),
            ITF::CDO_E_ROLE_NOMORE_AVAILABLE => RawError::Kind(ITF::CDO_E_ROLE_NOMORE_AVAILABLE),
            ITF::TPC_E_OUT_OF_ORDER_CALL => RawError::Kind(ITF::TPC_E_OUT_OF_ORDER_CALL),
            ITF::CDO_E_BAD_TASKTYPE_ONASSIGN => RawError::Kind(ITF::CDO_E_BAD_TASKTYPE_ONASSIGN),
            ITF::TPC_E_QUEUE_FULL => RawError::Kind(ITF::TPC_E_QUEUE_FULL),
            ITF::VFW_E_NO_MODEX_AVAILABLE => RawError::Kind(ITF::VFW_E_NO_MODEX_AVAILABLE),
            ITF::CDO_E_NOT_ASSIGNEDTO_USER => RawError::Kind(ITF::CDO_E_NOT_ASSIGNEDTO_USER),
            ITF::TPC_E_INVALID_CONFIGURATION => RawError::Kind(ITF::TPC_E_INVALID_CONFIGURATION),
            ITF::VFW_E_NO_ADVISE_SET => RawError::Kind(ITF::VFW_E_NO_ADVISE_SET),
            ITF::CDO_E_OUTOFDATE => RawError::Kind(ITF::CDO_E_OUTOFDATE),
            ITF::TPC_E_INVALID_DATA_FROM_RECOGNIZER => RawError::Kind(ITF::TPC_E_INVALID_DATA_FROM_RECOGNIZER),
            ITF::VFW_E_NO_FULLSCREEN => RawError::Kind(ITF::VFW_E_NO_FULLSCREEN),
            ITF::VFW_E_IN_FULLSCREEN_MODE => RawError::Kind(ITF::VFW_E_IN_FULLSCREEN_MODE),
            ITF::VFW_E_UNKNOWN_FILE_TYPE => RawError::Kind(ITF::VFW_E_UNKNOWN_FILE_TYPE),
            ITF::TPC_E_INVALID_PROPERTY => RawError::Kind(ITF::TPC_E_INVALID_PROPERTY),
            ITF::VFW_E_CANNOT_LOAD_SOURCE_FILTER => RawError::Kind(ITF::VFW_E_CANNOT_LOAD_SOURCE_FILTER),
            ITF::VFW_E_FILE_TOO_SHORT => RawError::Kind(ITF::VFW_E_FILE_TOO_SHORT),
            ITF::VFW_E_INVALID_FILE_VERSION => RawError::Kind(ITF::VFW_E_INVALID_FILE_VERSION),
            ITF::VFW_E_INVALID_CLSID => RawError::Kind(ITF::VFW_E_INVALID_CLSID),
            ITF::VFW_E_INVALID_MEDIA_TYPE => RawError::Kind(ITF::VFW_E_INVALID_MEDIA_TYPE),
            ITF::VFW_E_SAMPLE_TIME_NOT_SET => RawError::Kind(ITF::VFW_E_SAMPLE_TIME_NOT_SET),
            ITF::VFW_E_MEDIA_TIME_NOT_SET => RawError::Kind(ITF::VFW_E_MEDIA_TIME_NOT_SET),
            ITF::VFW_E_NO_TIME_FORMAT_SET => RawError::Kind(ITF::VFW_E_NO_TIME_FORMAT_SET),
            ITF::VFW_E_MONO_AUDIO_HW => RawError::Kind(ITF::VFW_E_MONO_AUDIO_HW),
            ITF::VFW_E_NO_DECOMPRESSOR => RawError::Kind(ITF::VFW_E_NO_DECOMPRESSOR),
            ITF::VFW_E_NO_AUDIO_HARDWARE => RawError::Kind(ITF::VFW_E_NO_AUDIO_HARDWARE),
            ITF::VFW_E_RPZA => RawError::Kind(ITF::VFW_E_RPZA),
            ITF::VFW_E_PROCESSOR_NOT_SUITABLE => RawError::Kind(ITF::VFW_E_PROCESSOR_NOT_SUITABLE),
            ITF::VFW_E_UNSUPPORTED_AUDIO => RawError::Kind(ITF::VFW_E_UNSUPPORTED_AUDIO),
            ITF::VFW_E_UNSUPPORTED_VIDEO => RawError::Kind(ITF::VFW_E_UNSUPPORTED_VIDEO),
            ITF::VFW_E_MPEG_NOT_CONSTRAINED => RawError::Kind(ITF::VFW_E_MPEG_NOT_CONSTRAINED),
            ITF::VFW_E_NOT_IN_GRAPH => RawError::Kind(ITF::VFW_E_NOT_IN_GRAPH),
            ITF::VFW_E_NO_TIME_FORMAT => RawError::Kind(ITF::VFW_E_NO_TIME_FORMAT),
            ITF::VFW_E_READ_ONLY => RawError::Kind(ITF::VFW_E_READ_ONLY),
            ITF::VFW_E_BUFFER_UNDERFLOW => RawError::Kind(ITF::VFW_E_BUFFER_UNDERFLOW),
            ITF::VFW_E_UNSUPPORTED_STREAM => RawError::Kind(ITF::VFW_E_UNSUPPORTED_STREAM),
            ITF::VFW_E_NO_TRANSPORT => RawError::Kind(ITF::VFW_E_NO_TRANSPORT),
            ITF::VFW_E_BAD_VIDEOCD => RawError::Kind(ITF::VFW_E_BAD_VIDEOCD),
            ITF::VFW_S_NO_STOP_TIME => RawError::Kind(ITF::VFW_S_NO_STOP_TIME),
            ITF::VFW_E_OUT_OF_VIDEO_MEMORY => RawError::Kind(ITF::VFW_E_OUT_OF_VIDEO_MEMORY),
            ITF::VFW_E_VP_NEGOTIATION_FAILED => RawError::Kind(ITF::VFW_E_VP_NEGOTIATION_FAILED),
            ITF::VFW_E_DDRAW_CAPS_NOT_SUITABLE => RawError::Kind(ITF::VFW_E_DDRAW_CAPS_NOT_SUITABLE),
            ITF::VFW_E_NO_VP_HARDWARE => RawError::Kind(ITF::VFW_E_NO_VP_HARDWARE),
            ITF::VFW_E_NO_CAPTURE_HARDWARE => RawError::Kind(ITF::VFW_E_NO_CAPTURE_HARDWARE),
            ITF::VFW_E_DVD_OPERATION_INHIBITED => RawError::Kind(ITF::VFW_E_DVD_OPERATION_INHIBITED),
            ITF::VFW_E_DVD_INVALIDDOMAIN => RawError::Kind(ITF::VFW_E_DVD_INVALIDDOMAIN),
            ITF::VFW_E_DVD_NO_BUTTON => RawError::Kind(ITF::VFW_E_DVD_NO_BUTTON),
            ITF::VFW_E_DVD_GRAPHNOTREADY => RawError::Kind(ITF::VFW_E_DVD_GRAPHNOTREADY),
            ITF::VFW_E_DVD_RENDERFAIL => RawError::Kind(ITF::VFW_E_DVD_RENDERFAIL),
            ITF::VFW_E_DVD_DECNOTENOUGH => RawError::Kind(ITF::VFW_E_DVD_DECNOTENOUGH),
            ITF::VFW_E_DDRAW_VERSION_NOT_SUITABLE => RawError::Kind(ITF::VFW_E_DDRAW_VERSION_NOT_SUITABLE),
            ITF::VFW_E_COPYPROT_FAILED => RawError::Kind(ITF::VFW_E_COPYPROT_FAILED),
            ITF::VFW_E_TIME_EXPIRED => RawError::Kind(ITF::VFW_E_TIME_EXPIRED),
            ITF::VFW_E_DVD_WRONG_SPEED => RawError::Kind(ITF::VFW_E_DVD_WRONG_SPEED),
            ITF::VFW_E_DVD_MENU_DOES_NOT_EXIST => RawError::Kind(ITF::VFW_E_DVD_MENU_DOES_NOT_EXIST),
            ITF::VFW_E_DVD_CMD_CANCELLED => RawError::Kind(ITF::VFW_E_DVD_CMD_CANCELLED),
            ITF::VFW_E_DVD_STATE_WRONG_VERSION => RawError::Kind(ITF::VFW_E_DVD_STATE_WRONG_VERSION),
            ITF::VFW_E_DVD_STATE_CORRUPT => RawError::Kind(ITF::VFW_E_DVD_STATE_CORRUPT),
            ITF::VFW_E_DVD_STATE_WRONG_DISC => RawError::Kind(ITF::VFW_E_DVD_STATE_WRONG_DISC),
            ITF::VFW_E_DVD_INCOMPATIBLE_REGION => RawError::Kind(ITF::VFW_E_DVD_INCOMPATIBLE_REGION),
            ITF::VFW_E_DVD_NO_ATTRIBUTES => RawError::Kind(ITF::VFW_E_DVD_NO_ATTRIBUTES),
            ITF::VFW_E_DVD_NO_GOUP_PGC => RawError::Kind(ITF::VFW_E_DVD_NO_GOUP_PGC),
            ITF::VFW_E_DVD_LOW_PARENTAL_LEVEL => RawError::Kind(ITF::VFW_E_DVD_LOW_PARENTAL_LEVEL),
            ITF::VFW_E_DVD_NOT_IN_KARAOKE_MODE => RawError::Kind(ITF::VFW_E_DVD_NOT_IN_KARAOKE_MODE),
            ITF::VFW_E_FRAME_STEP_UNSUPPORTED => RawError::Kind(ITF::VFW_E_FRAME_STEP_UNSUPPORTED),
            ITF::VFW_E_DVD_STREAM_DISABLED => RawError::Kind(ITF::VFW_E_DVD_STREAM_DISABLED),
            ITF::VFW_E_DVD_TITLE_UNKNOWN => RawError::Kind(ITF::VFW_E_DVD_TITLE_UNKNOWN),
            ITF::VFW_E_DVD_INVALID_DISC => RawError::Kind(ITF::VFW_E_DVD_INVALID_DISC),
            ITF::VFW_E_DVD_NO_RESUME_INFORMATION => RawError::Kind(ITF::VFW_E_DVD_NO_RESUME_INFORMATION),
            ITF::VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD => RawError::Kind(ITF::VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD),
            ITF::VFW_E_PIN_ALREADY_BLOCKED => RawError::Kind(ITF::VFW_E_PIN_ALREADY_BLOCKED),
            ITF::VFW_E_CERTIFICATION_FAILURE => RawError::Kind(ITF::VFW_E_CERTIFICATION_FAILURE),
            ITF::VFW_E_VMR_NOT_IN_MIXER_MODE => RawError::Kind(ITF::VFW_E_VMR_NOT_IN_MIXER_MODE),
            ITF::VFW_E_VMR_NO_AP_SUPPLIED => RawError::Kind(ITF::VFW_E_VMR_NO_AP_SUPPLIED),
            ITF::VFW_E_VMR_NO_DEINTERLACE_HW => RawError::Kind(ITF::VFW_E_VMR_NO_DEINTERLACE_HW),
            ITF::VFW_E_VMR_NO_PROCAMP_HW => RawError::Kind(ITF::VFW_E_VMR_NO_PROCAMP_HW),
            ITF::VFW_E_DVD_VMR9_INCOMPATIBLEDEC => RawError::Kind(ITF::VFW_E_DVD_VMR9_INCOMPATIBLEDEC),
            ITF::VFW_E_NO_COPP_HW => RawError::Kind(ITF::VFW_E_NO_COPP_HW),
            ITF::VFW_E_DVD_NONBLOCKING => RawError::Kind(ITF::VFW_E_DVD_NONBLOCKING),
            ITF::VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH => RawError::Kind(ITF::VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH),
            ITF::VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH => RawError::Kind(ITF::VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH),
            ITF::VFW_E_DVD_RESOLUTION_ERROR => RawError::Kind(ITF::VFW_E_DVD_RESOLUTION_ERROR),
            ITF::NET_E_GENERAL => RawError::Kind(ITF::NET_E_GENERAL),
            ITF::FHCFG_E_CORRUPT_CONFIG_FILE => RawError::Kind(ITF::FHCFG_E_CORRUPT_CONFIG_FILE),
            ITF::UPNP_E_ACTION_SPECIFIC_BASE => RawError::Kind(ITF::UPNP_E_ACTION_SPECIFIC_BASE),
            ITF::FHCFG_E_CONFIG_FILE_NOT_FOUND => RawError::Kind(ITF::FHCFG_E_CONFIG_FILE_NOT_FOUND),
            ITF::FHCFG_E_CONFIG_ALREADY_EXISTS => RawError::Kind(ITF::FHCFG_E_CONFIG_ALREADY_EXISTS),
            ITF::NET_E_DISCONNECTED => RawError::Kind(ITF::NET_E_DISCONNECTED),
            ITF::FHCFG_E_NO_VALID_CONFIGURATION_LOADED => RawError::Kind(ITF::FHCFG_E_NO_VALID_CONFIGURATION_LOADED),
            ITF::FHCFG_E_TARGET_NOT_CONNECTED => RawError::Kind(ITF::FHCFG_E_TARGET_NOT_CONNECTED),
            ITF::FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED => RawError::Kind(ITF::FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED),
            ITF::FHCFG_E_TARGET_VERIFICATION_FAILED => RawError::Kind(ITF::FHCFG_E_TARGET_VERIFICATION_FAILED),
            ITF::FHCFG_E_TARGET_NOT_CONFIGURED => RawError::Kind(ITF::FHCFG_E_TARGET_NOT_CONFIGURED),
            ITF::NET_E_INVALIDPARAMS => RawError::Kind(ITF::NET_E_INVALIDPARAMS),
            ITF::FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE => RawError::Kind(ITF::FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE),
            ITF::NET_E_OPERATIONINPROGRESS => RawError::Kind(ITF::NET_E_OPERATIONINPROGRESS),
            ITF::FHCFG_E_TARGET_CANNOT_BE_USED => RawError::Kind(ITF::FHCFG_E_TARGET_CANNOT_BE_USED),
            ITF::VFW_E_CODECAPI_LINEAR_RANGE => RawError::Kind(ITF::VFW_E_CODECAPI_LINEAR_RANGE),
            ITF::FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED => RawError::Kind(ITF::FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED),
            ITF::VFW_E_CODECAPI_ENUMERATED => RawError::Kind(ITF::VFW_E_CODECAPI_ENUMERATED),
            ITF::FHCFG_E_TARGET_REHYDRATED_ELSEWHERE => RawError::Kind(ITF::FHCFG_E_TARGET_REHYDRATED_ELSEWHERE),
            ITF::FHCFG_E_LEGACY_TARGET_UNSUPPORTED => RawError::Kind(ITF::FHCFG_E_LEGACY_TARGET_UNSUPPORTED),
            ITF::VFW_E_CODECAPI_NO_DEFAULT => RawError::Kind(ITF::VFW_E_CODECAPI_NO_DEFAULT),
            ITF::FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED => RawError::Kind(ITF::FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED),
            ITF::VFW_E_CODECAPI_NO_CURRENT_VALUE => RawError::Kind(ITF::VFW_E_CODECAPI_NO_CURRENT_VALUE),
            ITF::FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED => RawError::Kind(ITF::FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED),
            ITF::VFW_E_DVD_CHAPTER_DOES_NOT_EXIST => RawError::Kind(ITF::VFW_E_DVD_CHAPTER_DOES_NOT_EXIST),
            ITF::FHCFG_E_LEGACY_BACKUP_NOT_FOUND => RawError::Kind(ITF::FHCFG_E_LEGACY_BACKUP_NOT_FOUND),
            ITF::VFW_E_BAD_KEY => RawError::Kind(ITF::VFW_E_BAD_KEY),
            ITF::DS_E_NOMOREDATA => RawError::Kind(ITF::DS_E_NOMOREDATA),
            ITF::DS_E_INVALIDDATASOURCE => RawError::Kind(ITF::DS_E_INVALIDDATASOURCE),
            ITF::MS_E_SAMPLEALLOC => RawError::Kind(ITF::MS_E_SAMPLEALLOC),
            ITF::DS_E_DATASOURCENOTAVAILABLE => RawError::Kind(ITF::DS_E_DATASOURCENOTAVAILABLE),
            ITF::MS_E_PURPOSEID => RawError::Kind(ITF::MS_E_PURPOSEID),
            ITF::DS_E_QUERYCANCELED => RawError::Kind(ITF::DS_E_QUERYCANCELED),
            ITF::MS_E_NOSTREAM => RawError::Kind(ITF::MS_E_NOSTREAM),
            ITF::DS_E_UNKNOWNREQUEST => RawError::Kind(ITF::DS_E_UNKNOWNREQUEST),
            ITF::MS_E_NOSEEKING => RawError::Kind(ITF::MS_E_NOSEEKING),
            ITF::DS_E_BADREQUEST => RawError::Kind(ITF::DS_E_BADREQUEST),
            ITF::MS_E_INCOMPATIBLE => RawError::Kind(ITF::MS_E_INCOMPATIBLE),
            ITF::DS_E_SERVERCAPACITY => RawError::Kind(ITF::DS_E_SERVERCAPACITY),
            ITF::MS_E_BUSY => RawError::Kind(ITF::MS_E_BUSY),
            ITF::DS_E_BADSEQUENCE => RawError::Kind(ITF::DS_E_BADSEQUENCE),
            ITF::MS_E_NOTINIT => RawError::Kind(ITF::MS_E_NOTINIT),
            ITF::DS_E_MESSAGETOOLONG => RawError::Kind(ITF::DS_E_MESSAGETOOLONG),
            ITF::MS_E_SOURCEALREADYDEFINED => RawError::Kind(ITF::MS_E_SOURCEALREADYDEFINED),
            ITF::DS_E_SERVERERROR => RawError::Kind(ITF::DS_E_SERVERERROR),
            ITF::MS_E_INVALIDSTREAMTYPE => RawError::Kind(ITF::MS_E_INVALIDSTREAMTYPE),
            ITF::DS_E_CONFIGBAD => RawError::Kind(ITF::DS_E_CONFIGBAD),
            ITF::MS_E_NOTRUNNING => RawError::Kind(ITF::MS_E_NOTRUNNING),
            ITF::DS_E_DATANOTPRESENT => RawError::Kind(ITF::DS_E_DATANOTPRESENT),
            ITF::DS_E_SETSTATUSINPROGRESS => RawError::Kind(ITF::DS_E_SETSTATUSINPROGRESS),
            ITF::DS_E_DUPLICATEID => RawError::Kind(ITF::DS_E_DUPLICATEID),
            ITF::DS_E_TOOMANYDATASOURCES => RawError::Kind(ITF::DS_E_TOOMANYDATASOURCES),
            ITF::DS_E_REGISTRY => RawError::Kind(ITF::DS_E_REGISTRY),
            ITF::DS_E_DATASOURCENOTDISABLED => RawError::Kind(ITF::DS_E_DATASOURCENOTDISABLED),
            ITF::DS_E_INVALIDTAGDB => RawError::Kind(ITF::DS_E_INVALIDTAGDB),
            ITF::DS_E_INVALIDCATALOGNAME => RawError::Kind(ITF::DS_E_INVALIDCATALOGNAME),
            ITF::DS_E_CONFIGNOTRIGHTTYPE => RawError::Kind(ITF::DS_E_CONFIGNOTRIGHTTYPE),
            ITF::DS_E_PROTOCOLVERSION => RawError::Kind(ITF::DS_E_PROTOCOLVERSION),
            ITF::DS_E_ALREADYENABLED => RawError::Kind(ITF::DS_E_ALREADYENABLED),
            ITF::DS_E_INDEXDIRECTORY => RawError::Kind(ITF::DS_E_INDEXDIRECTORY),
            ITF::DS_E_VALUETOOLARGE => RawError::Kind(ITF::DS_E_VALUETOOLARGE),
            ITF::DS_E_UNKNOWNPARAM => RawError::Kind(ITF::DS_E_UNKNOWNPARAM),
            ITF::DS_E_BUFFERTOOSMALL => RawError::Kind(ITF::DS_E_BUFFERTOOSMALL),
            ITF::DS_E_PARAMOUTOFRANGE => RawError::Kind(ITF::DS_E_PARAMOUTOFRANGE),
            ITF::DS_E_ALREADYDISABLED => RawError::Kind(ITF::DS_E_ALREADYDISABLED),
            ITF::DS_E_QUERYHUNG => RawError::Kind(ITF::DS_E_QUERYHUNG),
            ITF::DS_E_BADRESULT => RawError::Kind(ITF::DS_E_BADRESULT),
            ITF::DS_E_CANNOTWRITEREGISTRY => RawError::Kind(ITF::DS_E_CANNOTWRITEREGISTRY),
            ITF::DS_E_CANNOTREMOVECONCURRENT => RawError::Kind(ITF::DS_E_CANNOTREMOVECONCURRENT),
            ITF::DS_E_SEARCHCATNAMECOLLISION => RawError::Kind(ITF::DS_E_SEARCHCATNAMECOLLISION),
            ITF::DS_E_PROPVERSIONMISMATCH => RawError::Kind(ITF::DS_E_PROPVERSIONMISMATCH),
            ITF::DS_E_MISSINGCATALOG => RawError::Kind(ITF::DS_E_MISSINGCATALOG),
            ITF::UPNP_E_ACTION_SPECIFIC_MAX => RawError::Kind(ITF::UPNP_E_ACTION_SPECIFIC_MAX),
            ITF::TF_E_LOCKED => RawError::Kind(ITF::TF_E_LOCKED),
            ITF::UPNP_E_INVALID_DOCUMENT => RawError::Kind(ITF::UPNP_E_INVALID_DOCUMENT),
            ITF::COLL_E_BADSEQUENCE => RawError::Kind(ITF::COLL_E_BADSEQUENCE),
            ITF::TF_E_STACKFULL => RawError::Kind(ITF::TF_E_STACKFULL),
            ITF::UPNP_E_EVENT_SUBSCRIPTION_FAILED => RawError::Kind(ITF::UPNP_E_EVENT_SUBSCRIPTION_FAILED),
            ITF::COLL_E_NOMOREDATA => RawError::Kind(ITF::COLL_E_NOMOREDATA),
            ITF::TF_E_NOTOWNEDRANGE => RawError::Kind(ITF::TF_E_NOTOWNEDRANGE),
            ITF::COLL_E_INCOMPATIBLECOLUMNS => RawError::Kind(ITF::COLL_E_INCOMPATIBLECOLUMNS),
            ITF::TF_E_NOPROVIDER => RawError::Kind(ITF::TF_E_NOPROVIDER),
            ITF::COLL_E_BUFFERTOOSMALL => RawError::Kind(ITF::COLL_E_BUFFERTOOSMALL),
            ITF::TF_E_DISCONNECTED => RawError::Kind(ITF::TF_E_DISCONNECTED),
            ITF::TF_E_INVALIDVIEW => RawError::Kind(ITF::TF_E_INVALIDVIEW),
            ITF::COLL_E_BADRESULT => RawError::Kind(ITF::COLL_E_BADRESULT),
            ITF::TF_E_ALREADY_EXISTS => RawError::Kind(ITF::TF_E_ALREADY_EXISTS),
            ITF::COLL_E_NOSORTCOLUMN => RawError::Kind(ITF::COLL_E_NOSORTCOLUMN),
            ITF::TF_E_RANGE_NOT_COVERED => RawError::Kind(ITF::TF_E_RANGE_NOT_COVERED),
            ITF::COLL_E_DUPLICATEDBID => RawError::Kind(ITF::COLL_E_DUPLICATEDBID),
            ITF::TF_E_COMPOSITION_REJECTED => RawError::Kind(ITF::TF_E_COMPOSITION_REJECTED),
            ITF::COLL_E_TOOMANYMERGECOLUMNS => RawError::Kind(ITF::COLL_E_TOOMANYMERGECOLUMNS),
            ITF::TF_E_EMPTYCONTEXT => RawError::Kind(ITF::TF_E_EMPTYCONTEXT),
            ITF::COLL_E_NODEFAULTCATALOG => RawError::Kind(ITF::COLL_E_NODEFAULTCATALOG),
            ITF::COLL_E_MAXCONNEXCEEDED => RawError::Kind(ITF::COLL_E_MAXCONNEXCEEDED),
            ITF::FHSVC_E_BACKUP_BLOCKED => RawError::Kind(ITF::FHSVC_E_BACKUP_BLOCKED),
            ITF::CM_E_TOOMANYDATASERVERS => RawError::Kind(ITF::CM_E_TOOMANYDATASERVERS),
            ITF::FHSVC_E_NOT_CONFIGURED => RawError::Kind(ITF::FHSVC_E_NOT_CONFIGURED),
            ITF::CM_E_TOOMANYDATASOURCES => RawError::Kind(ITF::CM_E_TOOMANYDATASOURCES),
            ITF::FHSVC_E_CONFIG_DISABLED => RawError::Kind(ITF::FHSVC_E_CONFIG_DISABLED),
            ITF::CM_E_NOQUERYCONNECTIONS => RawError::Kind(ITF::CM_E_NOQUERYCONNECTIONS),
            ITF::FHSVC_E_CONFIG_DISABLED_GP => RawError::Kind(ITF::FHSVC_E_CONFIG_DISABLED_GP),
            ITF::CM_E_DATASOURCENOTAVAILABLE => RawError::Kind(ITF::CM_E_DATASOURCENOTAVAILABLE),
            ITF::FHSVC_E_FATAL_CONFIG_ERROR => RawError::Kind(ITF::FHSVC_E_FATAL_CONFIG_ERROR),
            ITF::CM_E_CONNECTIONTIMEOUT => RawError::Kind(ITF::CM_E_CONNECTIONTIMEOUT),
            ITF::FHSVC_E_CONFIG_REHYDRATING => RawError::Kind(ITF::FHSVC_E_CONFIG_REHYDRATING),
            ITF::CM_E_SERVERNOTFOUND => RawError::Kind(ITF::CM_E_SERVERNOTFOUND),
            ITF::CM_E_REGISTRY => RawError::Kind(ITF::CM_E_REGISTRY),
            ITF::CM_E_INVALIDDATASOURCE => RawError::Kind(ITF::CM_E_INVALIDDATASOURCE),
            ITF::CM_E_TIMEOUT => RawError::Kind(ITF::CM_E_TIMEOUT),
            ITF::CM_E_INSUFFICIENTBUFFER => RawError::Kind(ITF::CM_E_INSUFFICIENTBUFFER),
            ITF::QRY_E_QUERYSYNTAX => RawError::Kind(ITF::QRY_E_QUERYSYNTAX),
            ITF::QRY_E_TYPEMISMATCH => RawError::Kind(ITF::QRY_E_TYPEMISMATCH),
            ITF::QRY_E_UNHANDLEDTYPE => RawError::Kind(ITF::QRY_E_UNHANDLEDTYPE),
            ITF::QRY_E_TOOMANYCOLUMNS => RawError::Kind(ITF::QRY_E_TOOMANYCOLUMNS),
            ITF::QRY_E_TOOMANYDATABASES => RawError::Kind(ITF::QRY_E_TOOMANYDATABASES),
            ITF::QRY_E_STARTHITTOBIG => RawError::Kind(ITF::QRY_E_STARTHITTOBIG),
            ITF::QRY_E_TOOMANYQUERYTERMS => RawError::Kind(ITF::QRY_E_TOOMANYQUERYTERMS),
            ITF::QRY_E_NODATASOURCES => RawError::Kind(ITF::QRY_E_NODATASOURCES),
            ITF::QRY_E_TIMEOUT => RawError::Kind(ITF::QRY_E_TIMEOUT),
            ITF::QRY_E_COLUMNNOTSORTABLE => RawError::Kind(ITF::QRY_E_COLUMNNOTSORTABLE),
            ITF::QRY_E_COLUMNNOTSEARCHABLE => RawError::Kind(ITF::QRY_E_COLUMNNOTSEARCHABLE),
            ITF::QRY_E_INVALIDCOLUMN => RawError::Kind(ITF::QRY_E_INVALIDCOLUMN),
            ITF::QRY_E_QUERYCORRUPT => RawError::Kind(ITF::QRY_E_QUERYCORRUPT),
            ITF::QRY_E_PREFIXWILDCARD => RawError::Kind(ITF::QRY_E_PREFIXWILDCARD),
            ITF::QRY_E_INFIXWILDCARD => RawError::Kind(ITF::QRY_E_INFIXWILDCARD),
            ITF::QRY_E_WILDCARDPREFIXLENGTH => RawError::Kind(ITF::QRY_E_WILDCARDPREFIXLENGTH),
            ITF::QRY_E_ENGINEFAILED => RawError::Kind(ITF::QRY_E_ENGINEFAILED),
            ITF::QRY_E_SEARCHTOOBIG => RawError::Kind(ITF::QRY_E_SEARCHTOOBIG),
            ITF::QRY_E_NULLQUERY => RawError::Kind(ITF::QRY_E_NULLQUERY),
            ITF::QRY_E_NOCOLUMNS => RawError::Kind(ITF::QRY_E_NOCOLUMNS),
            ITF::QRY_E_INVALIDSCOPES => RawError::Kind(ITF::QRY_E_INVALIDSCOPES),
            ITF::QRY_E_INVALIDCATALOG => RawError::Kind(ITF::QRY_E_INVALIDCATALOG),
            ITF::QRY_E_SCOPECARDINALIDY => RawError::Kind(ITF::QRY_E_SCOPECARDINALIDY),
            ITF::QRY_E_UNEXPECTED => RawError::Kind(ITF::QRY_E_UNEXPECTED),
            ITF::QRY_E_INVALIDPATH => RawError::Kind(ITF::QRY_E_INVALIDPATH),
            ITF::QRY_E_LMNOTINITIALIZED => RawError::Kind(ITF::QRY_E_LMNOTINITIALIZED),
            ITF::QRY_E_INVALIDINTERVAL => RawError::Kind(ITF::QRY_E_INVALIDINTERVAL),
            ITF::QRY_E_NOLOGMANAGER => RawError::Kind(ITF::QRY_E_NOLOGMANAGER),
            ITF::SCHEMA_E_LOAD_SPECIAL => RawError::Kind(ITF::SCHEMA_E_LOAD_SPECIAL),
            ITF::SCHEMA_E_FILENOTFOUND => RawError::Kind(ITF::SCHEMA_E_FILENOTFOUND),
            ITF::SCHEMA_E_NESTEDTAG => RawError::Kind(ITF::SCHEMA_E_NESTEDTAG),
            ITF::SCHEMA_E_UNEXPECTEDTAG => RawError::Kind(ITF::SCHEMA_E_UNEXPECTEDTAG),
            ITF::SCHEMA_E_VERSIONMISMATCH => RawError::Kind(ITF::SCHEMA_E_VERSIONMISMATCH),
            ITF::SCHEMA_E_CANNOTCREATEFILE => RawError::Kind(ITF::SCHEMA_E_CANNOTCREATEFILE),
            ITF::SCHEMA_E_CANNOTWRITEFILE => RawError::Kind(ITF::SCHEMA_E_CANNOTWRITEFILE),
            ITF::SCHEMA_E_EMPTYFILE => RawError::Kind(ITF::SCHEMA_E_EMPTYFILE),
            ITF::SCHEMA_E_INVALIDFILETYPE => RawError::Kind(ITF::SCHEMA_E_INVALIDFILETYPE),
            ITF::SCHEMA_E_INVALIDDATATYPE => RawError::Kind(ITF::SCHEMA_E_INVALIDDATATYPE),
            ITF::SCHEMA_E_CANNOTCREATENOISEWORDFILE => RawError::Kind(ITF::SCHEMA_E_CANNOTCREATENOISEWORDFILE),
            ITF::SCHEMA_E_ADDSTOPWORDS => RawError::Kind(ITF::SCHEMA_E_ADDSTOPWORDS),
            ITF::SCHEMA_E_NAMEEXISTS => RawError::Kind(ITF::SCHEMA_E_NAMEEXISTS),
            ITF::SCHEMA_E_INVALIDVALUE => RawError::Kind(ITF::SCHEMA_E_INVALIDVALUE),
            ITF::SCHEMA_E_BADPROPSPEC => RawError::Kind(ITF::SCHEMA_E_BADPROPSPEC),
            ITF::SCHEMA_E_NOMORECOLUMNS => RawError::Kind(ITF::SCHEMA_E_NOMORECOLUMNS),
            ITF::SCHEMA_E_FILECHANGED => RawError::Kind(ITF::SCHEMA_E_FILECHANGED),
            ITF::SCHEMA_E_BADCOLUMNNAME => RawError::Kind(ITF::SCHEMA_E_BADCOLUMNNAME),
            ITF::SCHEMA_E_BADPROPPID => RawError::Kind(ITF::SCHEMA_E_BADPROPPID),
            ITF::SCHEMA_E_BADATTRIBUTE => RawError::Kind(ITF::SCHEMA_E_BADATTRIBUTE),
            ITF::SCHEMA_E_BADFILENAME => RawError::Kind(ITF::SCHEMA_E_BADFILENAME),
            ITF::SCHEMA_E_PROPEXISTS => RawError::Kind(ITF::SCHEMA_E_PROPEXISTS),
            ITF::SCHEMA_E_DUPLICATENOISE => RawError::Kind(ITF::SCHEMA_E_DUPLICATENOISE),
            ITF::GTHR_E_DUPLICATE_OBJECT => RawError::Kind(ITF::GTHR_E_DUPLICATE_OBJECT),
            ITF::GTHR_E_UNABLE_TO_READ_REGISTRY => RawError::Kind(ITF::GTHR_E_UNABLE_TO_READ_REGISTRY),
            ITF::GTHR_E_ERROR_WRITING_REGISTRY => RawError::Kind(ITF::GTHR_E_ERROR_WRITING_REGISTRY),
            ITF::GTHR_E_ERROR_INITIALIZING_PERFMON => RawError::Kind(ITF::GTHR_E_ERROR_INITIALIZING_PERFMON),
            ITF::GTHR_E_ERROR_OBJECT_NOT_FOUND => RawError::Kind(ITF::GTHR_E_ERROR_OBJECT_NOT_FOUND),
            ITF::GTHR_E_URL_EXCLUDED => RawError::Kind(ITF::GTHR_E_URL_EXCLUDED),
            ITF::GTHR_E_CONFIG_DUP_PROJECT => RawError::Kind(ITF::GTHR_E_CONFIG_DUP_PROJECT),
            ITF::GTHR_E_CONFIG_DUP_EXTENSION => RawError::Kind(ITF::GTHR_E_CONFIG_DUP_EXTENSION),
            ITF::GTHR_E_DUPLICATE_URL => RawError::Kind(ITF::GTHR_E_DUPLICATE_URL),
            ITF::GTHR_E_TOO_MANY_PLUGINS => RawError::Kind(ITF::GTHR_E_TOO_MANY_PLUGINS),
            ITF::GTHR_E_INVALIDFUNCTION => RawError::Kind(ITF::GTHR_E_INVALIDFUNCTION),
            ITF::GTHR_E_NOFILTERSINK => RawError::Kind(ITF::GTHR_E_NOFILTERSINK),
            ITF::GTHR_E_FILTER_PROCESS_TERMINATED => RawError::Kind(ITF::GTHR_E_FILTER_PROCESS_TERMINATED),
            ITF::GTHR_E_FILTER_INVALID_MESSAGE => RawError::Kind(ITF::GTHR_E_FILTER_INVALID_MESSAGE),
            ITF::GTHR_E_UNSUPPORTED_PROPERTY_TYPE => RawError::Kind(ITF::GTHR_E_UNSUPPORTED_PROPERTY_TYPE),
            ITF::GTHR_E_NAME_TOO_LONG => RawError::Kind(ITF::GTHR_E_NAME_TOO_LONG),
            ITF::GTHR_E_NO_IDENTITY => RawError::Kind(ITF::GTHR_E_NO_IDENTITY),
            ITF::GTHR_E_FILTER_NOT_FOUND => RawError::Kind(ITF::GTHR_E_FILTER_NOT_FOUND),
            ITF::GTHR_E_FILTER_NO_MORE_THREADS => RawError::Kind(ITF::GTHR_E_FILTER_NO_MORE_THREADS),
            ITF::GTHR_E_PRT_HNDLR_PROGID_MISSING => RawError::Kind(ITF::GTHR_E_PRT_HNDLR_PROGID_MISSING),
            ITF::GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA => RawError::Kind(ITF::GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA),
            ITF::GTHR_E_UNKNOWN_PROTOCOL => RawError::Kind(ITF::GTHR_E_UNKNOWN_PROTOCOL),
            ITF::GTHR_E_PROJECT_NOT_INITIALIZED => RawError::Kind(ITF::GTHR_E_PROJECT_NOT_INITIALIZED),
            ITF::GTHR_E_INVALID_PROJECT_NAME => RawError::Kind(ITF::GTHR_E_INVALID_PROJECT_NAME),
            ITF::GTHR_E_SHUTTING_DOWN => RawError::Kind(ITF::GTHR_E_SHUTTING_DOWN),
            ITF::GTHR_E_VALUE_NOT_AVAILABLE => RawError::Kind(ITF::GTHR_E_VALUE_NOT_AVAILABLE),
            ITF::GTHR_E_OUT_OF_DOC_ID => RawError::Kind(ITF::GTHR_E_OUT_OF_DOC_ID),
            ITF::GTHR_E_NOTIFICATION_START_PAGE => RawError::Kind(ITF::GTHR_E_NOTIFICATION_START_PAGE),
            ITF::GTHR_E_DUP_PROPERTY_MAPPING => RawError::Kind(ITF::GTHR_E_DUP_PROPERTY_MAPPING),
            ITF::GTHR_E_INVALID_ACCOUNT => RawError::Kind(ITF::GTHR_E_INVALID_ACCOUNT),
            ITF::GTHR_E_FILTER_INIT => RawError::Kind(ITF::GTHR_E_FILTER_INIT),
            ITF::GTHR_E_INVALID_ACCOUNT_SYNTAX => RawError::Kind(ITF::GTHR_E_INVALID_ACCOUNT_SYNTAX),
            ITF::GTHR_E_PROXY_NAME => RawError::Kind(ITF::GTHR_E_PROXY_NAME),
            ITF::GTHR_E_SERVER_UNAVAILABLE => RawError::Kind(ITF::GTHR_E_SERVER_UNAVAILABLE),
            ITF::GTHR_E_INVALID_PATH => RawError::Kind(ITF::GTHR_E_INVALID_PATH),
            ITF::GTHR_E_FILTER_NO_CODEPAGE => RawError::Kind(ITF::GTHR_E_FILTER_NO_CODEPAGE),
            ITF::GTHR_E_NO_PRTCLHNLR => RawError::Kind(ITF::GTHR_E_NO_PRTCLHNLR),
            ITF::GTHR_E_IE_OFFLINE => RawError::Kind(ITF::GTHR_E_IE_OFFLINE),
            ITF::GTHR_E_BAD_FILTER_DAEMON => RawError::Kind(ITF::GTHR_E_BAD_FILTER_DAEMON),
            ITF::GTHR_E_INVALID_MAPPING => RawError::Kind(ITF::GTHR_E_INVALID_MAPPING),
            ITF::GTHR_E_USER_AGENT_NOT_SPECIFIED => RawError::Kind(ITF::GTHR_E_USER_AGENT_NOT_SPECIFIED),
            ITF::GTHR_E_FROM_NOT_SPECIFIED => RawError::Kind(ITF::GTHR_E_FROM_NOT_SPECIFIED),
            ITF::GTHR_E_INVALID_STREAM_LOGS_COUNT => RawError::Kind(ITF::GTHR_E_INVALID_STREAM_LOGS_COUNT),
            ITF::GTHR_E_INVALID_EXTENSION => RawError::Kind(ITF::GTHR_E_INVALID_EXTENSION),
            ITF::GTHR_E_INVALID_GROW_FACTOR => RawError::Kind(ITF::GTHR_E_INVALID_GROW_FACTOR),
            ITF::GTHR_E_INVALID_TIME_OUT => RawError::Kind(ITF::GTHR_E_INVALID_TIME_OUT),
            ITF::GTHR_E_INVALID_RETRIES => RawError::Kind(ITF::GTHR_E_INVALID_RETRIES),
            ITF::GTHR_E_INVALID_LOG_FILE_NAME => RawError::Kind(ITF::GTHR_E_INVALID_LOG_FILE_NAME),
            ITF::GTHR_E_INVALID_HOST_NAME => RawError::Kind(ITF::GTHR_E_INVALID_HOST_NAME),
            ITF::GTHR_E_INVALID_START_PAGE => RawError::Kind(ITF::GTHR_E_INVALID_START_PAGE),
            ITF::GTHR_E_DUPLICATE_PROJECT => RawError::Kind(ITF::GTHR_E_DUPLICATE_PROJECT),
            ITF::GTHR_E_INVALID_DIRECTORY => RawError::Kind(ITF::GTHR_E_INVALID_DIRECTORY),
            ITF::GTHR_E_FILTER_INTERRUPTED => RawError::Kind(ITF::GTHR_E_FILTER_INTERRUPTED),
            ITF::GTHR_E_INVALID_PROXY_PORT => RawError::Kind(ITF::GTHR_E_INVALID_PROXY_PORT),
            ITF::GTHR_E_SECRET_NOT_FOUND => RawError::Kind(ITF::GTHR_E_SECRET_NOT_FOUND),
            ITF::GTHR_E_INVALID_PATH_EXPRESSION => RawError::Kind(ITF::GTHR_E_INVALID_PATH_EXPRESSION),
            ITF::GTHR_E_INVALID_START_PAGE_HOST => RawError::Kind(ITF::GTHR_E_INVALID_START_PAGE_HOST),
            ITF::GTHR_E_INVALID_START_PAGE_PATH => RawError::Kind(ITF::GTHR_E_INVALID_START_PAGE_PATH),
            ITF::GTHR_E_APPLICATION_NOT_FOUND => RawError::Kind(ITF::GTHR_E_APPLICATION_NOT_FOUND),
            ITF::GTHR_E_CANNOT_REMOVE_PLUGINMGR => RawError::Kind(ITF::GTHR_E_CANNOT_REMOVE_PLUGINMGR),
            ITF::GTHR_E_INVALID_APPLICATION_NAME => RawError::Kind(ITF::GTHR_E_INVALID_APPLICATION_NAME),
            ITF::GTHR_E_FILTER_FAULT => RawError::Kind(ITF::GTHR_E_FILTER_FAULT),
            ITF::GTHR_E_NON_FIXED_DRIVE => RawError::Kind(ITF::GTHR_E_NON_FIXED_DRIVE),
            ITF::GTHR_E_FILTER_SINGLE_THREADED => RawError::Kind(ITF::GTHR_E_FILTER_SINGLE_THREADED),
            ITF::GTHR_E_URL_UNIDENTIFIED => RawError::Kind(ITF::GTHR_E_URL_UNIDENTIFIED),
            ITF::GTHR_E_FORCE_NOTIFICATION_RESET => RawError::Kind(ITF::GTHR_E_FORCE_NOTIFICATION_RESET),
            ITF::GTHR_E_CONTENT_ID_CONFLICT => RawError::Kind(ITF::GTHR_E_CONTENT_ID_CONFLICT),
            ITF::GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE => RawError::Kind(ITF::GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE),
            ITF::GTHR_E_RECOVERABLE_EXOLEDB_ERROR => RawError::Kind(ITF::GTHR_E_RECOVERABLE_EXOLEDB_ERROR),
            ITF::GTHR_E_INVALID_CALL_FROM_WBREAKER => RawError::Kind(ITF::GTHR_E_INVALID_CALL_FROM_WBREAKER),
            ITF::GTHR_E_PROPERTY_LIST_NOT_INITIALIZED => RawError::Kind(ITF::GTHR_E_PROPERTY_LIST_NOT_INITIALIZED),
            ITF::GHTR_E_LOCAL_SERVER_UNAVAILABLE => RawError::Kind(ITF::GHTR_E_LOCAL_SERVER_UNAVAILABLE),
            ITF::GTHR_E_SCHEMA_ERRORS_OCCURRED => RawError::Kind(ITF::GTHR_E_SCHEMA_ERRORS_OCCURRED),
            ITF::GTHR_E_TIMEOUT => RawError::Kind(ITF::GTHR_E_TIMEOUT),
            ITF::GTHR_E_NOTIFICATION_START_ADDRESS_INVALID => RawError::Kind(ITF::GTHR_E_NOTIFICATION_START_ADDRESS_INVALID),
            ITF::GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED => RawError::Kind(ITF::GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED),
            ITF::GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE => RawError::Kind(ITF::GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE),
            ITF::GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE => RawError::Kind(ITF::GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE),
            ITF::GHTR_E_INSUFFICIENT_DISK_SPACE => RawError::Kind(ITF::GHTR_E_INSUFFICIENT_DISK_SPACE),
            ITF::GTHR_E_INVALID_RESOURCE_ID => RawError::Kind(ITF::GTHR_E_INVALID_RESOURCE_ID),
            ITF::GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES => RawError::Kind(ITF::GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES),
            ITF::GTHR_E_RETRY => RawError::Kind(ITF::GTHR_E_RETRY),
            ITF::GTHR_E_JET_BACKUP_ERROR => RawError::Kind(ITF::GTHR_E_JET_BACKUP_ERROR),
            ITF::GTHR_E_JET_RESTORE_ERROR => RawError::Kind(ITF::GTHR_E_JET_RESTORE_ERROR),
            ITF::GTHR_E_PLUGIN_NOT_REGISTERED => RawError::Kind(ITF::GTHR_E_PLUGIN_NOT_REGISTERED),
            ITF::GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED => RawError::Kind(ITF::GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED),
            ITF::GTHR_E_DIRMON_NOT_INITIALZED => RawError::Kind(ITF::GTHR_E_DIRMON_NOT_INITIALZED),
            ITF::GTHR_E_NOTIF_BEING_REMOVED => RawError::Kind(ITF::GTHR_E_NOTIF_BEING_REMOVED),
            ITF::GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT => RawError::Kind(ITF::GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT),
            ITF::GTHR_E_INVALID_PATH_SPEC => RawError::Kind(ITF::GTHR_E_INVALID_PATH_SPEC),
            ITF::GTHR_E_INSUFFICIENT_FEATURE_TERMS => RawError::Kind(ITF::GTHR_E_INSUFFICIENT_FEATURE_TERMS),
            ITF::GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES => RawError::Kind(ITF::GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES),
            ITF::GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS => RawError::Kind(ITF::GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS),
            ITF::GTHR_E_AUTOCAT_UNEXPECTED => RawError::Kind(ITF::GTHR_E_AUTOCAT_UNEXPECTED),
            ITF::GTHR_E_SINGLE_THREADED_EMBEDDING => RawError::Kind(ITF::GTHR_E_SINGLE_THREADED_EMBEDDING),
            ITF::GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE => RawError::Kind(ITF::GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE),
            ITF::GTHR_E_EMPTY_DACL => RawError::Kind(ITF::GTHR_E_EMPTY_DACL),
            ITF::GTHR_E_OBJECT_NOT_VALID => RawError::Kind(ITF::GTHR_E_OBJECT_NOT_VALID),
            ITF::GTHR_E_CANNOT_ENABLE_CHECKPOINT => RawError::Kind(ITF::GTHR_E_CANNOT_ENABLE_CHECKPOINT),
            ITF::GTHR_E_SCOPES_EXCEEDED => RawError::Kind(ITF::GTHR_E_SCOPES_EXCEEDED),
            ITF::GTHR_E_PROPERTIES_EXCEEDED => RawError::Kind(ITF::GTHR_E_PROPERTIES_EXCEEDED),
            ITF::GTHR_E_INVALID_START_ADDRESS => RawError::Kind(ITF::GTHR_E_INVALID_START_ADDRESS),
            ITF::GTHR_E_PIPE_NOT_CONNECTTED => RawError::Kind(ITF::GTHR_E_PIPE_NOT_CONNECTTED),
            ITF::GTHR_E_BACKUP_VALIDATION_FAIL => RawError::Kind(ITF::GTHR_E_BACKUP_VALIDATION_FAIL),
            ITF::GTHR_E_BAD_FILTER_HOST => RawError::Kind(ITF::GTHR_E_BAD_FILTER_HOST),
            ITF::GTHR_E_FILTERPOOL_NOTFOUND => RawError::Kind(ITF::GTHR_E_FILTERPOOL_NOTFOUND),
            ITF::GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT => RawError::Kind(ITF::GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT),
            ITF::DB_E_BADACCESSORHANDLE => RawError::Kind(ITF::DB_E_BADACCESSORHANDLE),
            ITF::DB_E_ROWLIMITEXCEEDED => RawError::Kind(ITF::DB_E_ROWLIMITEXCEEDED),
            ITF::DB_E_READONLYACCESSOR => RawError::Kind(ITF::DB_E_READONLYACCESSOR),
            ITF::DB_E_SCHEMAVIOLATION => RawError::Kind(ITF::DB_E_SCHEMAVIOLATION),
            ITF::DB_E_BADROWHANDLE => RawError::Kind(ITF::DB_E_BADROWHANDLE),
            ITF::DB_E_OBJECTOPEN => RawError::Kind(ITF::DB_E_OBJECTOPEN),
            ITF::DB_E_BADCHAPTER => RawError::Kind(ITF::DB_E_BADCHAPTER),
            ITF::DB_E_CANTCONVERTVALUE => RawError::Kind(ITF::DB_E_CANTCONVERTVALUE),
            ITF::DB_E_BADBINDINFO => RawError::Kind(ITF::DB_E_BADBINDINFO),
            ITF::DB_SEC_E_PERMISSIONDENIED => RawError::Kind(ITF::DB_SEC_E_PERMISSIONDENIED),
            ITF::DB_E_NOTAREFERENCECOLUMN => RawError::Kind(ITF::DB_E_NOTAREFERENCECOLUMN),
            ITF::DB_E_LIMITREJECTED => RawError::Kind(ITF::DB_E_LIMITREJECTED),
            ITF::DB_E_NOCOMMAND => RawError::Kind(ITF::DB_E_NOCOMMAND),
            ITF::DB_E_COSTLIMIT => RawError::Kind(ITF::DB_E_COSTLIMIT),
            ITF::DB_E_BADBOOKMARK => RawError::Kind(ITF::DB_E_BADBOOKMARK),
            ITF::DB_E_BADLOCKMODE => RawError::Kind(ITF::DB_E_BADLOCKMODE),
            ITF::DB_E_PARAMNOTOPTIONAL => RawError::Kind(ITF::DB_E_PARAMNOTOPTIONAL),
            ITF::DB_E_BADCOLUMNID => RawError::Kind(ITF::DB_E_BADCOLUMNID),
            ITF::DB_E_BADRATIO => RawError::Kind(ITF::DB_E_BADRATIO),
            ITF::DB_E_BADVALUES => RawError::Kind(ITF::DB_E_BADVALUES),
            ITF::DB_E_ERRORSINCOMMAND => RawError::Kind(ITF::DB_E_ERRORSINCOMMAND),
            ITF::DB_E_CANTCANCEL => RawError::Kind(ITF::DB_E_CANTCANCEL),
            ITF::DB_E_DIALECTNOTSUPPORTED => RawError::Kind(ITF::DB_E_DIALECTNOTSUPPORTED),
            ITF::DB_E_DUPLICATEDATASOURCE => RawError::Kind(ITF::DB_E_DUPLICATEDATASOURCE),
            ITF::DB_E_CANNOTRESTART => RawError::Kind(ITF::DB_E_CANNOTRESTART),
            ITF::DB_E_NOTFOUND => RawError::Kind(ITF::DB_E_NOTFOUND),
            ITF::DB_E_CANNOTFREE => RawError::Kind(ITF::DB_E_CANNOTFREE),
            ITF::DB_E_NEWLYINSERTED => RawError::Kind(ITF::DB_E_NEWLYINSERTED),
            ITF::DB_E_GOALREJECTED => RawError::Kind(ITF::DB_E_GOALREJECTED),
            ITF::DB_E_UNSUPPORTEDCONVERSION => RawError::Kind(ITF::DB_E_UNSUPPORTEDCONVERSION),
            ITF::DB_E_BADSTARTPOSITION => RawError::Kind(ITF::DB_E_BADSTARTPOSITION),
            ITF::DB_E_NOQUERY => RawError::Kind(ITF::DB_E_NOQUERY),
            ITF::DB_E_NOTREENTRANT => RawError::Kind(ITF::DB_E_NOTREENTRANT),
            ITF::DB_E_ERRORSOCCURRED => RawError::Kind(ITF::DB_E_ERRORSOCCURRED),
            ITF::DB_E_NOAGGREGATION => RawError::Kind(ITF::DB_E_NOAGGREGATION),
            ITF::DB_E_DELETEDROW => RawError::Kind(ITF::DB_E_DELETEDROW),
            ITF::DB_E_CANTFETCHBACKWARDS => RawError::Kind(ITF::DB_E_CANTFETCHBACKWARDS),
            ITF::DB_E_ROWSNOTRELEASED => RawError::Kind(ITF::DB_E_ROWSNOTRELEASED),
            ITF::DB_E_BADSTORAGEFLAG => RawError::Kind(ITF::DB_E_BADSTORAGEFLAG),
            ITF::DB_E_BADCOMPAREOP => RawError::Kind(ITF::DB_E_BADCOMPAREOP),
            ITF::DB_E_BADSTATUSVALUE => RawError::Kind(ITF::DB_E_BADSTATUSVALUE),
            ITF::DB_E_CANTSCROLLBACKWARDS => RawError::Kind(ITF::DB_E_CANTSCROLLBACKWARDS),
            ITF::DB_E_BADREGIONHANDLE => RawError::Kind(ITF::DB_E_BADREGIONHANDLE),
            ITF::DB_E_NONCONTIGUOUSRANGE => RawError::Kind(ITF::DB_E_NONCONTIGUOUSRANGE),
            ITF::DB_E_INVALIDTRANSITION => RawError::Kind(ITF::DB_E_INVALIDTRANSITION),
            ITF::DB_E_NOTASUBREGION => RawError::Kind(ITF::DB_E_NOTASUBREGION),
            ITF::DB_E_MULTIPLESTATEMENTS => RawError::Kind(ITF::DB_E_MULTIPLESTATEMENTS),
            ITF::DB_E_INTEGRITYVIOLATION => RawError::Kind(ITF::DB_E_INTEGRITYVIOLATION),
            ITF::DB_E_BADTYPENAME => RawError::Kind(ITF::DB_E_BADTYPENAME),
            ITF::DB_E_ABORTLIMITREACHED => RawError::Kind(ITF::DB_E_ABORTLIMITREACHED),
            ITF::DB_E_ROWSETINCOMMAND => RawError::Kind(ITF::DB_E_ROWSETINCOMMAND),
            ITF::DB_E_CANTTRANSLATE => RawError::Kind(ITF::DB_E_CANTTRANSLATE),
            ITF::DB_E_DUPLICATEINDEXID => RawError::Kind(ITF::DB_E_DUPLICATEINDEXID),
            ITF::DB_E_NOINDEX => RawError::Kind(ITF::DB_E_NOINDEX),
            ITF::DB_E_INDEXINUSE => RawError::Kind(ITF::DB_E_INDEXINUSE),
            ITF::DB_E_NOTABLE => RawError::Kind(ITF::DB_E_NOTABLE),
            ITF::DB_E_CONCURRENCYVIOLATION => RawError::Kind(ITF::DB_E_CONCURRENCYVIOLATION),
            ITF::DB_E_BADCOPY => RawError::Kind(ITF::DB_E_BADCOPY),
            ITF::DB_E_BADPRECISION => RawError::Kind(ITF::DB_E_BADPRECISION),
            ITF::DB_E_BADSCALE => RawError::Kind(ITF::DB_E_BADSCALE),
            ITF::DB_E_BADTABLEID => RawError::Kind(ITF::DB_E_BADTABLEID),
            ITF::DB_E_BADTYPE => RawError::Kind(ITF::DB_E_BADTYPE),
            ITF::DB_E_DUPLICATECOLUMNID => RawError::Kind(ITF::DB_E_DUPLICATECOLUMNID),
            ITF::DB_E_DUPLICATETABLEID => RawError::Kind(ITF::DB_E_DUPLICATETABLEID),
            ITF::DB_E_TABLEINUSE => RawError::Kind(ITF::DB_E_TABLEINUSE),
            ITF::DB_E_NOLOCALE => RawError::Kind(ITF::DB_E_NOLOCALE),
            ITF::DB_E_BADRECORDNUM => RawError::Kind(ITF::DB_E_BADRECORDNUM),
            ITF::DB_E_BOOKMARKSKIPPED => RawError::Kind(ITF::DB_E_BOOKMARKSKIPPED),
            ITF::DB_E_BADPROPERTYVALUE => RawError::Kind(ITF::DB_E_BADPROPERTYVALUE),
            ITF::DB_E_INVALID => RawError::Kind(ITF::DB_E_INVALID),
            ITF::DB_E_BADACCESSORFLAGS => RawError::Kind(ITF::DB_E_BADACCESSORFLAGS),
            ITF::DB_E_BADSTORAGEFLAGS => RawError::Kind(ITF::DB_E_BADSTORAGEFLAGS),
            ITF::DB_E_BYREFACCESSORNOTSUPPORTED => RawError::Kind(ITF::DB_E_BYREFACCESSORNOTSUPPORTED),
            ITF::DB_E_NULLACCESSORNOTSUPPORTED => RawError::Kind(ITF::DB_E_NULLACCESSORNOTSUPPORTED),
            ITF::DB_E_NOTPREPARED => RawError::Kind(ITF::DB_E_NOTPREPARED),
            ITF::DB_E_BADACCESSORTYPE => RawError::Kind(ITF::DB_E_BADACCESSORTYPE),
            ITF::DB_E_WRITEONLYACCESSOR => RawError::Kind(ITF::DB_E_WRITEONLYACCESSOR),
            ITF::DB_SEC_E_AUTH_FAILED => RawError::Kind(ITF::DB_SEC_E_AUTH_FAILED),
            ITF::DB_E_CANCELED => RawError::Kind(ITF::DB_E_CANCELED),
            ITF::DB_E_CHAPTERNOTRELEASED => RawError::Kind(ITF::DB_E_CHAPTERNOTRELEASED),
            ITF::DB_E_BADSOURCEHANDLE => RawError::Kind(ITF::DB_E_BADSOURCEHANDLE),
            ITF::DB_E_PARAMUNAVAILABLE => RawError::Kind(ITF::DB_E_PARAMUNAVAILABLE),
            ITF::DB_E_ALREADYINITIALIZED => RawError::Kind(ITF::DB_E_ALREADYINITIALIZED),
            ITF::DB_E_NOTSUPPORTED => RawError::Kind(ITF::DB_E_NOTSUPPORTED),
            ITF::DB_E_MAXPENDCHANGESEXCEEDED => RawError::Kind(ITF::DB_E_MAXPENDCHANGESEXCEEDED),
            ITF::DB_E_BADORDINAL => RawError::Kind(ITF::DB_E_BADORDINAL),
            ITF::DB_E_PENDINGCHANGES => RawError::Kind(ITF::DB_E_PENDINGCHANGES),
            ITF::DB_E_DATAOVERFLOW => RawError::Kind(ITF::DB_E_DATAOVERFLOW),
            ITF::DB_E_BADHRESULT => RawError::Kind(ITF::DB_E_BADHRESULT),
            ITF::DB_E_BADLOOKUPID => RawError::Kind(ITF::DB_E_BADLOOKUPID),
            ITF::DB_E_BADDYNAMICERRORID => RawError::Kind(ITF::DB_E_BADDYNAMICERRORID),
            ITF::DB_E_PENDINGINSERT => RawError::Kind(ITF::DB_E_PENDINGINSERT),
            ITF::DB_E_BADCONVERTFLAG => RawError::Kind(ITF::DB_E_BADCONVERTFLAG),
            ITF::DB_E_BADPARAMETERNAME => RawError::Kind(ITF::DB_E_BADPARAMETERNAME),
            ITF::DB_E_MULTIPLESTORAGE => RawError::Kind(ITF::DB_E_MULTIPLESTORAGE),
            ITF::DB_E_CANTFILTER => RawError::Kind(ITF::DB_E_CANTFILTER),
            ITF::DB_E_CANTORDER => RawError::Kind(ITF::DB_E_CANTORDER),
            ITF::MD_E_BADTUPLE => RawError::Kind(ITF::MD_E_BADTUPLE),
            ITF::MD_E_BADCOORDINATE => RawError::Kind(ITF::MD_E_BADCOORDINATE),
            ITF::MD_E_INVALIDAXIS => RawError::Kind(ITF::MD_E_INVALIDAXIS),
            ITF::MD_E_INVALIDCELLRANGE => RawError::Kind(ITF::MD_E_INVALIDCELLRANGE),
            ITF::DB_E_NOCOLUMN => RawError::Kind(ITF::DB_E_NOCOLUMN),
            ITF::DB_E_COMMANDNOTPERSISTED => RawError::Kind(ITF::DB_E_COMMANDNOTPERSISTED),
            ITF::DB_E_DUPLICATEID => RawError::Kind(ITF::DB_E_DUPLICATEID),
            ITF::DB_E_OBJECTCREATIONLIMITREACHED => RawError::Kind(ITF::DB_E_OBJECTCREATIONLIMITREACHED),
            ITF::SEC_E_BADTRUSTEEID => RawError::Kind(ITF::SEC_E_BADTRUSTEEID),
            ITF::SEC_E_NOTRUSTEEID => RawError::Kind(ITF::SEC_E_NOTRUSTEEID),
            ITF::SEC_E_NOMEMBERSHIPSUPPORT => RawError::Kind(ITF::SEC_E_NOMEMBERSHIPSUPPORT),
            ITF::SEC_E_INVALIDOBJECT => RawError::Kind(ITF::SEC_E_INVALIDOBJECT),
            ITF::SEC_E_NOOWNER => RawError::Kind(ITF::SEC_E_NOOWNER),
            ITF::SEC_E_INVALIDACCESSENTRYLIST => RawError::Kind(ITF::SEC_E_INVALIDACCESSENTRYLIST),
            ITF::SEC_E_INVALIDOWNER => RawError::Kind(ITF::SEC_E_INVALIDOWNER),
            ITF::SEC_E_INVALIDACCESSENTRY => RawError::Kind(ITF::SEC_E_INVALIDACCESSENTRY),
            ITF::DB_E_BADINDEXID => RawError::Kind(ITF::DB_E_BADINDEXID),
            ITF::DB_E_BADINITSTRING => RawError::Kind(ITF::DB_E_BADINITSTRING),
            ITF::DB_E_NOPROVIDERSREGISTERED => RawError::Kind(ITF::DB_E_NOPROVIDERSREGISTERED),
            ITF::DB_E_MISMATCHEDPROVIDER => RawError::Kind(ITF::DB_E_MISMATCHEDPROVIDER),
            ITF::DB_E_BADCOMMANDID => RawError::Kind(ITF::DB_E_BADCOMMANDID),
            ITF::DB_E_BADCONSTRAINTTYPE => RawError::Kind(ITF::DB_E_BADCONSTRAINTTYPE),
            ITF::DB_E_BADCONSTRAINTFORM => RawError::Kind(ITF::DB_E_BADCONSTRAINTFORM),
            ITF::DB_E_BADDEFERRABILITY => RawError::Kind(ITF::DB_E_BADDEFERRABILITY),
            ITF::DB_E_BADMATCHTYPE => RawError::Kind(ITF::DB_E_BADMATCHTYPE),
            ITF::DB_E_BADUPDATEDELETERULE => RawError::Kind(ITF::DB_E_BADUPDATEDELETERULE),
            ITF::DB_E_BADCONSTRAINTID => RawError::Kind(ITF::DB_E_BADCONSTRAINTID),
            ITF::DB_E_BADCOMMANDFLAGS => RawError::Kind(ITF::DB_E_BADCOMMANDFLAGS),
            ITF::DB_E_OBJECTMISMATCH => RawError::Kind(ITF::DB_E_OBJECTMISMATCH),
            ITF::DB_E_RESOURCEOUTOFSCOPE => RawError::Kind(ITF::DB_E_RESOURCEOUTOFSCOPE),
            ITF::DB_E_DROPRESTRICTED => RawError::Kind(ITF::DB_E_DROPRESTRICTED),
            ITF::DB_E_NOSOURCEOBJECT => RawError::Kind(ITF::DB_E_NOSOURCEOBJECT),
            ITF::DB_E_RESOURCELOCKED => RawError::Kind(ITF::DB_E_RESOURCELOCKED),
            ITF::DB_E_NOTCOLLECTION => RawError::Kind(ITF::DB_E_NOTCOLLECTION),
            ITF::DB_E_READONLY => RawError::Kind(ITF::DB_E_READONLY),
            ITF::DB_E_ASYNCNOTSUPPORTED => RawError::Kind(ITF::DB_E_ASYNCNOTSUPPORTED),
            ITF::DB_E_CANNOTCONNECT => RawError::Kind(ITF::DB_E_CANNOTCONNECT),
            ITF::DB_E_TIMEOUT => RawError::Kind(ITF::DB_E_TIMEOUT),
            ITF::DB_E_RESOURCEEXISTS => RawError::Kind(ITF::DB_E_RESOURCEEXISTS),
            ITF::DB_E_DUPLICATECONSTRAINTID => RawError::Kind(ITF::DB_E_DUPLICATECONSTRAINTID),
            ITF::DB_E_OUTOFSPACE => RawError::Kind(ITF::DB_E_OUTOFSPACE),
            ITF::DB_SEC_E_SAFEMODE_DENIED => RawError::Kind(ITF::DB_SEC_E_SAFEMODE_DENIED),
            ITF::DB_E_NOSTATISTIC => RawError::Kind(ITF::DB_E_NOSTATISTIC),
            ITF::DB_E_ALTERRESTRICTED => RawError::Kind(ITF::DB_E_ALTERRESTRICTED),
            ITF::DB_E_RESOURCENOTSUPPORTED => RawError::Kind(ITF::DB_E_RESOURCENOTSUPPORTED),
            ITF::DB_E_NOCONSTRAINT => RawError::Kind(ITF::DB_E_NOCONSTRAINT),
            ITF::DB_E_COLUMNUNAVAILABLE => RawError::Kind(ITF::DB_E_COLUMNUNAVAILABLE),
            ITF::DB_E_BOGUS => RawError::Kind(ITF::DB_E_BOGUS),
            ITF::DXVA2_E_NOT_INITIALIZED => RawError::Kind(ITF::DXVA2_E_NOT_INITIALIZED),
            ITF::MF_E_DXGI_DEVICE_NOT_INITIALIZED => RawError::Kind(ITF::MF_E_DXGI_DEVICE_NOT_INITIALIZED),
            ITF::SYNC_E_ID_FORMAT_MISMATCH => RawError::Kind(ITF::SYNC_E_ID_FORMAT_MISMATCH),
            ITF::REC_E_ABORTED => RawError::Kind(ITF::REC_E_ABORTED),
            ITF::ROUTER_E_NOTINTERESTED => RawError::Kind(ITF::ROUTER_E_NOTINTERESTED),
            ITF::DXVA2_E_NEW_VIDEO_DEVICE => RawError::Kind(ITF::DXVA2_E_NEW_VIDEO_DEVICE),
            ITF::MF_E_DXGI_NEW_VIDEO_DEVICE => RawError::Kind(ITF::MF_E_DXGI_NEW_VIDEO_DEVICE),
            ITF::SYNC_E_INVALID_OPERATION => RawError::Kind(ITF::SYNC_E_INVALID_OPERATION),
            ITF::REC_E_NOCALLBACK => RawError::Kind(ITF::REC_E_NOCALLBACK),
            ITF::DXVA2_E_VIDEO_DEVICE_LOCKED => RawError::Kind(ITF::DXVA2_E_VIDEO_DEVICE_LOCKED),
            ITF::MF_E_DXGI_VIDEO_DEVICE_LOCKED => RawError::Kind(ITF::MF_E_DXGI_VIDEO_DEVICE_LOCKED),
            ITF::SYNC_E_REPLICA_NOT_FOUND => RawError::Kind(ITF::SYNC_E_REPLICA_NOT_FOUND),
            ITF::REC_E_NORESIDUES => RawError::Kind(ITF::REC_E_NORESIDUES),
            ITF::SEO_E_NOTPRESENT => RawError::Kind(ITF::SEO_E_NOTPRESENT),
            ITF::DXVA2_E_NOT_AVAILABLE => RawError::Kind(ITF::DXVA2_E_NOT_AVAILABLE),
            ITF::SYNC_E_CHANGE_COUNT_MISMATCH => RawError::Kind(ITF::SYNC_E_CHANGE_COUNT_MISMATCH),
            ITF::REC_E_TOODIFFERENT => RawError::Kind(ITF::REC_E_TOODIFFERENT),
            ITF::SEO_E_TIMEOUT => RawError::Kind(ITF::SEO_E_TIMEOUT),
            ITF::SYNC_E_CHANGE_UNIT_COUNT_MISMATCH => RawError::Kind(ITF::SYNC_E_CHANGE_UNIT_COUNT_MISMATCH),
            ITF::REC_E_INEEDTODOTHEUPDATES => RawError::Kind(ITF::REC_E_INEEDTODOTHEUPDATES),
            ITF::SEO_S_DONEPROCESSING => RawError::Kind(ITF::SEO_S_DONEPROCESSING),
            ITF::SYNC_E_KNOWLEDGE_DECREASED => RawError::Kind(ITF::SYNC_E_KNOWLEDGE_DECREASED),
            ITF::EVENTS_E_BADDATA => RawError::Kind(ITF::EVENTS_E_BADDATA),
            ITF::SYNC_E_CHANGE_NOT_IN_KNOWLEDGE => RawError::Kind(ITF::SYNC_E_CHANGE_NOT_IN_KNOWLEDGE),
            ITF::EVENTS_E_TIMEOUT => RawError::Kind(ITF::EVENTS_E_TIMEOUT),
            ITF::SYNC_E_ITEM_MUST_EXIST => RawError::Kind(ITF::SYNC_E_ITEM_MUST_EXIST),
            ITF::EVENTS_E_DISABLED => RawError::Kind(ITF::EVENTS_E_DISABLED),
            ITF::SYNC_E_HAS_NO_DATA => RawError::Kind(ITF::SYNC_E_HAS_NO_DATA),
            ITF::SYNC_E_CHANGE_NEEDS_KNOWLEDGE => RawError::Kind(ITF::SYNC_E_CHANGE_NEEDS_KNOWLEDGE),
            ITF::SYNC_E_RANGE_OUT_OF_ORDER => RawError::Kind(ITF::SYNC_E_RANGE_OUT_OF_ORDER),
            ITF::SYNC_E_NOT_EXPECTED_CHANGE => RawError::Kind(ITF::SYNC_E_NOT_EXPECTED_CHANGE),
            ITF::SYNC_E_DESERIALIZATION => RawError::Kind(ITF::SYNC_E_DESERIALIZATION),
            ITF::SYNC_E_SINGLE_RANGE_ONLY => RawError::Kind(ITF::SYNC_E_SINGLE_RANGE_ONLY),
            ITF::SYNC_E_ITEM_HAS_CHANGE_UNITS => RawError::Kind(ITF::SYNC_E_ITEM_HAS_CHANGE_UNITS),
            ITF::SYNC_E_ITEM_HAS_NO_CHANGE_UNITS => RawError::Kind(ITF::SYNC_E_ITEM_HAS_NO_CHANGE_UNITS),
            ITF::SYNC_E_ITEM_HAS_NO_VERSION_DATA => RawError::Kind(ITF::SYNC_E_ITEM_HAS_NO_VERSION_DATA),
            ITF::SYNC_E_OBJECT_NEEDS_STATE => RawError::Kind(ITF::SYNC_E_OBJECT_NEEDS_STATE),
            ITF::SYNC_E_FEEDSYNC_INVALID_FEED => RawError::Kind(ITF::SYNC_E_FEEDSYNC_INVALID_FEED),
            ITF::SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA => RawError::Kind(ITF::SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA),
            ITF::SYNC_E_FEEDSYNC_CALLBACK_EXPECTED => RawError::Kind(ITF::SYNC_E_FEEDSYNC_CALLBACK_EXPECTED),
            ITF::SYNC_E_INVALID_VERSION => RawError::Kind(ITF::SYNC_E_INVALID_VERSION),
            ITF::SYNC_E_DUPLICATE_ITEM => RawError::Kind(ITF::SYNC_E_DUPLICATE_ITEM),
            ITF::SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS => RawError::Kind(ITF::SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS),
            ITF::SYNC_E_INVALID_SYNC_TIME => RawError::Kind(ITF::SYNC_E_INVALID_SYNC_TIME),
            ITF::SYNC_E_INCOMPLETE_REPLICA_KEY_MAP => RawError::Kind(ITF::SYNC_E_INCOMPLETE_REPLICA_KEY_MAP),
            ITF::SYNC_E_INVALID_REPLICA_KEY => RawError::Kind(ITF::SYNC_E_INVALID_REPLICA_KEY),
            ITF::SYNC_E_NEGATIVE_RANGE_EXCEPTION => RawError::Kind(ITF::SYNC_E_NEGATIVE_RANGE_EXCEPTION),
            ITF::SYNC_E_BATCH_NEEDS_KNOWLEDGE => RawError::Kind(ITF::SYNC_E_BATCH_NEEDS_KNOWLEDGE),
            ITF::SYNC_E_INTERNAL_ERROR => RawError::Kind(ITF::SYNC_E_INTERNAL_ERROR),
            ITF::SYNC_E_CHANGE_BATCH_IS_READ_ONLY => RawError::Kind(ITF::SYNC_E_CHANGE_BATCH_IS_READ_ONLY),
            ITF::SYNC_E_DATA_MODIFIED_CONCURRENTLY => RawError::Kind(ITF::SYNC_E_DATA_MODIFIED_CONCURRENTLY),
            ITF::SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM => RawError::Kind(ITF::SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM),
            ITF::SYNC_E_FILTER_NOT_SUPPORTED => RawError::Kind(ITF::SYNC_E_FILTER_NOT_SUPPORTED),
            ITF::SYNC_E_LOAD_CONFLICT_DATA_FAILED => RawError::Kind(ITF::SYNC_E_LOAD_CONFLICT_DATA_FAILED),
            ITF::SYNC_E_INVALID_SERIALIZATION_VERSION => RawError::Kind(ITF::SYNC_E_INVALID_SERIALIZATION_VERSION),
            ITF::SYNC_E_MARKER_MISMATCH => RawError::Kind(ITF::SYNC_E_MARKER_MISMATCH),
            ITF::SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED => RawError::Kind(ITF::SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED),
            ITF::SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT => RawError::Kind(ITF::SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT),
            ITF::SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED => RawError::Kind(ITF::SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED),
            ITF::SYNC_E_FULL_ENUMERATION_MUST_BE_USED => RawError::Kind(ITF::SYNC_E_FULL_ENUMERATION_MUST_BE_USED),
            ITF::SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE => RawError::Kind(ITF::SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE),
            ITF::SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED => RawError::Kind(ITF::SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED),
            ITF::SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER => RawError::Kind(ITF::SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER),
            ITF::IDX_E_INVALIDTAG => RawError::Kind(ITF::IDX_E_INVALIDTAG),
            ITF::IDX_E_METAFILE_CORRUPT => RawError::Kind(ITF::IDX_E_METAFILE_CORRUPT),
            ITF::IDX_E_TOO_MANY_SEARCH_SERVERS => RawError::Kind(ITF::IDX_E_TOO_MANY_SEARCH_SERVERS),
            ITF::IDX_E_SEARCH_SERVER_ALREADY_EXISTS => RawError::Kind(ITF::IDX_E_SEARCH_SERVER_ALREADY_EXISTS),
            ITF::IDX_E_BUILD_IN_PROGRESS => RawError::Kind(ITF::IDX_E_BUILD_IN_PROGRESS),
            ITF::IDX_E_IDXLSTFILE_CORRUPT => RawError::Kind(ITF::IDX_E_IDXLSTFILE_CORRUPT),
            ITF::IDX_E_REGISTRY_ENTRY => RawError::Kind(ITF::IDX_E_REGISTRY_ENTRY),
            ITF::IDX_E_OBJECT_NOT_FOUND => RawError::Kind(ITF::IDX_E_OBJECT_NOT_FOUND),
            ITF::IDX_E_SEARCH_SERVER_NOT_FOUND => RawError::Kind(ITF::IDX_E_SEARCH_SERVER_NOT_FOUND),
            ITF::IDX_E_WB_NOTFOUND => RawError::Kind(ITF::IDX_E_WB_NOTFOUND),
            ITF::IDX_E_NOISELIST_NOTFOUND => RawError::Kind(ITF::IDX_E_NOISELIST_NOTFOUND),
            ITF::IDX_E_STEMMER_NOTFOUND => RawError::Kind(ITF::IDX_E_STEMMER_NOTFOUND),
            ITF::IDX_E_PROP_STOPPED => RawError::Kind(ITF::IDX_E_PROP_STOPPED),
            ITF::IDX_E_DISKFULL => RawError::Kind(ITF::IDX_E_DISKFULL),
            ITF::IDX_E_INVALID_INDEX => RawError::Kind(ITF::IDX_E_INVALID_INDEX),
            ITF::IDX_E_CORRUPT_INDEX => RawError::Kind(ITF::IDX_E_CORRUPT_INDEX),
            ITF::IDX_E_PROPSTORE_INIT_FAILED => RawError::Kind(ITF::IDX_E_PROPSTORE_INIT_FAILED),
            ITF::IDX_E_PROP_STATE_CORRUPT => RawError::Kind(ITF::IDX_E_PROP_STATE_CORRUPT),
            ITF::IDX_E_NOT_LOADED => RawError::Kind(ITF::IDX_E_NOT_LOADED),
            ITF::IDX_E_PROP_MAJOR_VERSION_MISMATCH => RawError::Kind(ITF::IDX_E_PROP_MAJOR_VERSION_MISMATCH),
            ITF::IDX_E_PROP_MINOR_VERSION_MISMATCH => RawError::Kind(ITF::IDX_E_PROP_MINOR_VERSION_MISMATCH),
            ITF::IDX_E_DSS_NOT_CONNECTED => RawError::Kind(ITF::IDX_E_DSS_NOT_CONNECTED),
            ITF::IDX_E_DOCUMENT_ABORTED => RawError::Kind(ITF::IDX_E_DOCUMENT_ABORTED),
            ITF::IDX_E_CATALOG_DISMOUNTED => RawError::Kind(ITF::IDX_E_CATALOG_DISMOUNTED),
            ITF::IDX_E_USE_DEFAULT_CONTENTCLASS => RawError::Kind(ITF::IDX_E_USE_DEFAULT_CONTENTCLASS),
            ITF::IDX_E_USE_APPGLOBAL_PROPTABLE => RawError::Kind(ITF::IDX_E_USE_APPGLOBAL_PROPTABLE),
            ITF::JPS_E_JET_ERR => RawError::Kind(ITF::JPS_E_JET_ERR),
            ITF::JPS_E_CATALOG_DECSRIPTION_MISSING => RawError::Kind(ITF::JPS_E_CATALOG_DECSRIPTION_MISSING),
            ITF::JPS_E_MISSING_INFORMATION => RawError::Kind(ITF::JPS_E_MISSING_INFORMATION),
            ITF::JPS_E_INSUFFICIENT_VERSION_STORAGE => RawError::Kind(ITF::JPS_E_INSUFFICIENT_VERSION_STORAGE),
            ITF::JPS_E_INSUFFICIENT_DATABASE_SESSIONS => RawError::Kind(ITF::JPS_E_INSUFFICIENT_DATABASE_SESSIONS),
            ITF::JPS_E_INSUFFICIENT_DATABASE_RESOURCES => RawError::Kind(ITF::JPS_E_INSUFFICIENT_DATABASE_RESOURCES),
            ITF::JPS_E_SCHEMA_ERROR => RawError::Kind(ITF::JPS_E_SCHEMA_ERROR),
            ITF::JPS_E_PROPAGATION_FILE => RawError::Kind(ITF::JPS_E_PROPAGATION_FILE),
            ITF::JPS_E_PROPAGATION_CORRUPTION => RawError::Kind(ITF::JPS_E_PROPAGATION_CORRUPTION),
            ITF::JPS_E_PROPAGATION_VERSION_MISMATCH => RawError::Kind(ITF::JPS_E_PROPAGATION_VERSION_MISMATCH),
            ITF::JPS_E_SHARING_VIOLATION => RawError::Kind(ITF::JPS_E_SHARING_VIOLATION),
            ITF::EXCI_E_NO_CONFIG => RawError::Kind(ITF::EXCI_E_NO_CONFIG),
            ITF::EXCI_E_INVALID_SERVER_CONFIG => RawError::Kind(ITF::EXCI_E_INVALID_SERVER_CONFIG),
            ITF::EXCI_E_ACCESS_DENIED => RawError::Kind(ITF::EXCI_E_ACCESS_DENIED),
            ITF::EXCI_E_INVALID_EXCHANGE_SERVER => RawError::Kind(ITF::EXCI_E_INVALID_EXCHANGE_SERVER),
            ITF::EXCI_E_BADCONFIG_OR_ACCESSDENIED => RawError::Kind(ITF::EXCI_E_BADCONFIG_OR_ACCESSDENIED),
            ITF::EXCI_E_WRONG_SERVER_OR_ACCT => RawError::Kind(ITF::EXCI_E_WRONG_SERVER_OR_ACCT),
            ITF::EXCI_E_NOT_ADMIN_OR_WRONG_SITE => RawError::Kind(ITF::EXCI_E_NOT_ADMIN_OR_WRONG_SITE),
            ITF::EXCI_E_NO_MAPI => RawError::Kind(ITF::EXCI_E_NO_MAPI),
            ITF::EXCI_E_INVALID_ACCOUNT_INFO => RawError::Kind(ITF::EXCI_E_INVALID_ACCOUNT_INFO),
            ITF::PRTH_E_COMM_ERROR => RawError::Kind(ITF::PRTH_E_COMM_ERROR),
            ITF::PRTH_E_OBJ_NOT_FOUND => RawError::Kind(ITF::PRTH_E_OBJ_NOT_FOUND),
            ITF::PRTH_E_REQUEST_ERROR => RawError::Kind(ITF::PRTH_E_REQUEST_ERROR),
            ITF::PRTH_E_INTERNAL_ERROR => RawError::Kind(ITF::PRTH_E_INTERNAL_ERROR),
            ITF::PRTH_E_ACCESS_DENIED => RawError::Kind(ITF::PRTH_E_ACCESS_DENIED),
            ITF::PRTH_E_SERVER_ERROR => RawError::Kind(ITF::PRTH_E_SERVER_ERROR),
            ITF::PRTH_E_NOT_REDIRECTED => RawError::Kind(ITF::PRTH_E_NOT_REDIRECTED),
            ITF::PRTH_E_BAD_REQUEST => RawError::Kind(ITF::PRTH_E_BAD_REQUEST),
            ITF::PRTH_E_HTTP_CANNOT_CONNECT => RawError::Kind(ITF::PRTH_E_HTTP_CANNOT_CONNECT),
            ITF::PRTH_E_WININET => RawError::Kind(ITF::PRTH_E_WININET),
            ITF::PRTH_E_RETRY => RawError::Kind(ITF::PRTH_E_RETRY),
            ITF::PRTH_E_MIME_EXCLUDED => RawError::Kind(ITF::PRTH_E_MIME_EXCLUDED),
            ITF::PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL => RawError::Kind(ITF::PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL),
            ITF::PRTH_E_CANT_TRANSFORM_DENIED_ACE => RawError::Kind(ITF::PRTH_E_CANT_TRANSFORM_DENIED_ACE),
            ITF::PRTH_E_ACL_IS_READ_NONE => RawError::Kind(ITF::PRTH_E_ACL_IS_READ_NONE),
            ITF::PRTH_E_ACL_TOO_BIG => RawError::Kind(ITF::PRTH_E_ACL_TOO_BIG),
            ITF::PRTH_E_NO_PROPERTY => RawError::Kind(ITF::PRTH_E_NO_PROPERTY),
            ITF::PRTH_E_DATABASE_OPEN_ERROR => RawError::Kind(ITF::PRTH_E_DATABASE_OPEN_ERROR),
            ITF::PRTH_E_OPLOCK_BROKEN => RawError::Kind(ITF::PRTH_E_OPLOCK_BROKEN),
            ITF::PRTH_E_LOAD_FAILED => RawError::Kind(ITF::PRTH_E_LOAD_FAILED),
            ITF::PRTH_E_INIT_FAILED => RawError::Kind(ITF::PRTH_E_INIT_FAILED),
            ITF::PRTH_E_VOLUME_MOUNT_POINT => RawError::Kind(ITF::PRTH_E_VOLUME_MOUNT_POINT),
            ITF::PRTH_E_TRUNCATED => RawError::Kind(ITF::PRTH_E_TRUNCATED),
            ITF::GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR => RawError::Kind(ITF::GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR),
            ITF::PRTH_E_HTTPS_CERTIFICATE_ERROR => RawError::Kind(ITF::PRTH_E_HTTPS_CERTIFICATE_ERROR),
            ITF::PRTH_E_HTTPS_REQUIRE_CERTIFICATE => RawError::Kind(ITF::PRTH_E_HTTPS_REQUIRE_CERTIFICATE),
            ITF::SCHED_E_TRIGGER_NOT_FOUND => RawError::Kind(ITF::SCHED_E_TRIGGER_NOT_FOUND),
            ITF::SCHED_E_TASK_NOT_READY => RawError::Kind(ITF::SCHED_E_TASK_NOT_READY),
            ITF::SCHED_E_TASK_NOT_RUNNING => RawError::Kind(ITF::SCHED_E_TASK_NOT_RUNNING),
            ITF::SCHED_E_SERVICE_NOT_INSTALLED => RawError::Kind(ITF::SCHED_E_SERVICE_NOT_INSTALLED),
            ITF::SCHED_E_CANNOT_OPEN_TASK => RawError::Kind(ITF::SCHED_E_CANNOT_OPEN_TASK),
            ITF::SCHED_E_INVALID_TASK => RawError::Kind(ITF::SCHED_E_INVALID_TASK),
            ITF::SCHED_E_ACCOUNT_INFORMATION_NOT_SET => RawError::Kind(ITF::SCHED_E_ACCOUNT_INFORMATION_NOT_SET),
            ITF::SCHED_E_ACCOUNT_NAME_NOT_FOUND => RawError::Kind(ITF::SCHED_E_ACCOUNT_NAME_NOT_FOUND),
            ITF::SCHED_E_ACCOUNT_DBASE_CORRUPT => RawError::Kind(ITF::SCHED_E_ACCOUNT_DBASE_CORRUPT),
            ITF::SCHED_E_NO_SECURITY_SERVICES => RawError::Kind(ITF::SCHED_E_NO_SECURITY_SERVICES),
            ITF::SCHED_E_UNKNOWN_OBJECT_VERSION => RawError::Kind(ITF::SCHED_E_UNKNOWN_OBJECT_VERSION),
            ITF::SCHED_E_UNSUPPORTED_ACCOUNT_OPTION => RawError::Kind(ITF::SCHED_E_UNSUPPORTED_ACCOUNT_OPTION),
            ITF::SCHED_E_SERVICE_NOT_RUNNING => RawError::Kind(ITF::SCHED_E_SERVICE_NOT_RUNNING),
            ITF::SCHED_E_UNEXPECTEDNODE => RawError::Kind(ITF::SCHED_E_UNEXPECTEDNODE),
            ITF::SCHED_E_NAMESPACE => RawError::Kind(ITF::SCHED_E_NAMESPACE),
            ITF::SCHED_E_INVALIDVALUE => RawError::Kind(ITF::SCHED_E_INVALIDVALUE),
            ITF::SCHED_E_MISSINGNODE => RawError::Kind(ITF::SCHED_E_MISSINGNODE),
            ITF::SCHED_E_MALFORMEDXML => RawError::Kind(ITF::SCHED_E_MALFORMEDXML),
            ITF::SCHED_E_TOO_MANY_NODES => RawError::Kind(ITF::SCHED_E_TOO_MANY_NODES),
            ITF::SCHED_E_PAST_END_BOUNDARY => RawError::Kind(ITF::SCHED_E_PAST_END_BOUNDARY),
            ITF::SCHED_E_ALREADY_RUNNING => RawError::Kind(ITF::SCHED_E_ALREADY_RUNNING),
            ITF::SCHED_E_USER_NOT_LOGGED_ON => RawError::Kind(ITF::SCHED_E_USER_NOT_LOGGED_ON),
            ITF::SCHED_E_INVALID_TASK_HASH => RawError::Kind(ITF::SCHED_E_INVALID_TASK_HASH),
            ITF::SCHED_E_SERVICE_NOT_AVAILABLE => RawError::Kind(ITF::SCHED_E_SERVICE_NOT_AVAILABLE),
            ITF::SCHED_E_SERVICE_TOO_BUSY => RawError::Kind(ITF::SCHED_E_SERVICE_TOO_BUSY),
            ITF::SCHED_E_TASK_ATTEMPTED => RawError::Kind(ITF::SCHED_E_TASK_ATTEMPTED),
            ITF::SCHED_E_TASK_DISABLED => RawError::Kind(ITF::SCHED_E_TASK_DISABLED),
            ITF::SCHED_E_TASK_NOT_V1_COMPAT => RawError::Kind(ITF::SCHED_E_TASK_NOT_V1_COMPAT),
            ITF::SCHED_E_START_ON_DEMAND => RawError::Kind(ITF::SCHED_E_START_ON_DEMAND),
            ITF::SCHED_E_TASK_NOT_UBPM_COMPAT => RawError::Kind(ITF::SCHED_E_TASK_NOT_UBPM_COMPAT),
            ITF::SCHED_E_DEPRECATED_FEATURE_USED => RawError::Kind(ITF::SCHED_E_DEPRECATED_FEATURE_USED),
            ITF::SEC_E_INITFAILED => RawError::Kind(ITF::SEC_E_INITFAILED),
            ITF::SEC_E_NOTINITIALIZED => RawError::Kind(ITF::SEC_E_NOTINITIALIZED),
            ITF::SEC_E_INVALIDCONTEXT => RawError::Kind(ITF::SEC_E_INVALIDCONTEXT),
            ITF::SEC_E_ACCESSDENIED => RawError::Kind(ITF::SEC_E_ACCESSDENIED),
            ITF::CMDLINE_E_UNEXPECTED => RawError::Kind(ITF::CMDLINE_E_UNEXPECTED),
            ITF::CMDLINE_E_PAREN => RawError::Kind(ITF::CMDLINE_E_PAREN),
            ITF::CMDLINE_E_PARAM_SIZE => RawError::Kind(ITF::CMDLINE_E_PARAM_SIZE),
            ITF::CMDLINE_E_NOT_INIT => RawError::Kind(ITF::CMDLINE_E_NOT_INIT),
            ITF::CMDLINE_E_ALREADY_INIT => RawError::Kind(ITF::CMDLINE_E_ALREADY_INIT),
            ITF::CMDLINE_E_NUM_PARAMS => RawError::Kind(ITF::CMDLINE_E_NUM_PARAMS),
            ITF::QUERY_E_FAILED => RawError::Kind(ITF::QUERY_E_FAILED),
            ITF::SYNC_E_REGISTRATION_INTERNAL_ERROR => RawError::Kind(ITF::SYNC_E_REGISTRATION_INTERNAL_ERROR),
            ITF::QUERY_E_INVALIDQUERY => RawError::Kind(ITF::QUERY_E_INVALIDQUERY),
            ITF::SYNC_E_REGISTRATION_ALREADY_REGISTERED => RawError::Kind(ITF::SYNC_E_REGISTRATION_ALREADY_REGISTERED),
            ITF::QUERY_E_INVALIDRESTRICTION => RawError::Kind(ITF::QUERY_E_INVALIDRESTRICTION),
            ITF::SYNC_E_REGISTRATION_NOT_REGISTERED => RawError::Kind(ITF::SYNC_E_REGISTRATION_NOT_REGISTERED),
            ITF::QUERY_E_INVALIDSORT => RawError::Kind(ITF::QUERY_E_INVALIDSORT),
            ITF::SYNC_E_REGISTRATION_CORRUPT_DATA => RawError::Kind(ITF::SYNC_E_REGISTRATION_CORRUPT_DATA),
            ITF::QUERY_E_INVALIDCATEGORIZE => RawError::Kind(ITF::QUERY_E_INVALIDCATEGORIZE),
            ITF::SYNC_E_REGISTRATION_ALREADY_COMMITTED => RawError::Kind(ITF::SYNC_E_REGISTRATION_ALREADY_COMMITTED),
            ITF::QUERY_E_ALLNOISE => RawError::Kind(ITF::QUERY_E_ALLNOISE),
            ITF::QUERY_E_TOOCOMPLEX => RawError::Kind(ITF::QUERY_E_TOOCOMPLEX),
            ITF::QUERY_E_TIMEDOUT => RawError::Kind(ITF::QUERY_E_TIMEDOUT),
            ITF::QUERY_E_DUPLICATE_OUTPUT_COLUMN => RawError::Kind(ITF::QUERY_E_DUPLICATE_OUTPUT_COLUMN),
            ITF::QUERY_E_INVALID_OUTPUT_COLUMN => RawError::Kind(ITF::QUERY_E_INVALID_OUTPUT_COLUMN),
            ITF::QUERY_E_INVALID_DIRECTORY => RawError::Kind(ITF::QUERY_E_INVALID_DIRECTORY),
            ITF::QUERY_E_DIR_ON_REMOVABLE_DRIVE => RawError::Kind(ITF::QUERY_E_DIR_ON_REMOVABLE_DRIVE),
            ITF::QUERY_S_NO_QUERY => RawError::Kind(ITF::QUERY_S_NO_QUERY),
            ITF::QUERY_E_ALLNOISE_AND_NO_RELDOC => RawError::Kind(ITF::QUERY_E_ALLNOISE_AND_NO_RELDOC),
            ITF::QUERY_E_NO_RELDOC => RawError::Kind(ITF::QUERY_E_NO_RELDOC),
            ITF::QUERY_E_ALLNOISE_AND_NO_RELPROP => RawError::Kind(ITF::QUERY_E_ALLNOISE_AND_NO_RELPROP),
            ITF::QUERY_E_NO_RELPROP => RawError::Kind(ITF::QUERY_E_NO_RELPROP),
            ITF::QUERY_E_REPEATED_RELDOC => RawError::Kind(ITF::QUERY_E_REPEATED_RELDOC),
            ITF::QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED => RawError::Kind(ITF::QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED),
            ITF::QUERY_E_INVALID_DOCUMENT_IDENTIFIER => RawError::Kind(ITF::QUERY_E_INVALID_DOCUMENT_IDENTIFIER),
            ITF::QUERY_E_INCORRECT_VERSION => RawError::Kind(ITF::QUERY_E_INCORRECT_VERSION),
            ITF::QUERY_E_INVALIDSCOPE_COALESCE => RawError::Kind(ITF::QUERY_E_INVALIDSCOPE_COALESCE),
            ITF::QUERY_E_INVALIDSORT_COALESCE => RawError::Kind(ITF::QUERY_E_INVALIDSORT_COALESCE),
            ITF::QUERY_E_INVALIDCOALESCE => RawError::Kind(ITF::QUERY_E_INVALIDCOALESCE),
            ITF::QUERY_E_UPGRADEINPROGRESS => RawError::Kind(ITF::QUERY_E_UPGRADEINPROGRESS),
            ITF::QUERY_E_AGGREGATE_NOT_SUPPORTED => RawError::Kind(ITF::QUERY_E_AGGREGATE_NOT_SUPPORTED),
            ITF::QUERY_E_TOP_LEVEL_IN_GROUP => RawError::Kind(ITF::QUERY_E_TOP_LEVEL_IN_GROUP),
            ITF::QUERY_E_DUPLICATE_RANGE_NAME => RawError::Kind(ITF::QUERY_E_DUPLICATE_RANGE_NAME),
            ITF::QPLIST_E_CANT_OPEN_FILE => RawError::Kind(ITF::QPLIST_E_CANT_OPEN_FILE),
            ITF::QPLIST_E_READ_ERROR => RawError::Kind(ITF::QPLIST_E_READ_ERROR),
            ITF::QPLIST_E_EXPECTING_NAME => RawError::Kind(ITF::QPLIST_E_EXPECTING_NAME),
            ITF::QPLIST_E_EXPECTING_TYPE => RawError::Kind(ITF::QPLIST_E_EXPECTING_TYPE),
            ITF::QPLIST_E_UNRECOGNIZED_TYPE => RawError::Kind(ITF::QPLIST_E_UNRECOGNIZED_TYPE),
            ITF::QPLIST_E_EXPECTING_INTEGER => RawError::Kind(ITF::QPLIST_E_EXPECTING_INTEGER),
            ITF::QPLIST_E_EXPECTING_CLOSE_PAREN => RawError::Kind(ITF::QPLIST_E_EXPECTING_CLOSE_PAREN),
            ITF::QPLIST_E_EXPECTING_GUID => RawError::Kind(ITF::QPLIST_E_EXPECTING_GUID),
            ITF::QPLIST_E_BAD_GUID => RawError::Kind(ITF::QPLIST_E_BAD_GUID),
            ITF::QPLIST_E_EXPECTING_PROP_SPEC => RawError::Kind(ITF::QPLIST_E_EXPECTING_PROP_SPEC),
            ITF::QPLIST_E_CANT_SET_PROPERTY => RawError::Kind(ITF::QPLIST_E_CANT_SET_PROPERTY),
            ITF::QPLIST_E_DUPLICATE => RawError::Kind(ITF::QPLIST_E_DUPLICATE),
            ITF::QPLIST_E_VECTORBYREF_USED_ALONE => RawError::Kind(ITF::QPLIST_E_VECTORBYREF_USED_ALONE),
            ITF::QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE => RawError::Kind(ITF::QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE),
            ITF::QPARSE_E_UNEXPECTED_NOT => RawError::Kind(ITF::QPARSE_E_UNEXPECTED_NOT),
            ITF::QPARSE_E_EXPECTING_INTEGER => RawError::Kind(ITF::QPARSE_E_EXPECTING_INTEGER),
            ITF::QPARSE_E_EXPECTING_REAL => RawError::Kind(ITF::QPARSE_E_EXPECTING_REAL),
            ITF::QPARSE_E_EXPECTING_DATE => RawError::Kind(ITF::QPARSE_E_EXPECTING_DATE),
            ITF::QPARSE_E_EXPECTING_CURRENCY => RawError::Kind(ITF::QPARSE_E_EXPECTING_CURRENCY),
            ITF::QPARSE_E_EXPECTING_GUID => RawError::Kind(ITF::QPARSE_E_EXPECTING_GUID),
            ITF::QPARSE_E_EXPECTING_BRACE => RawError::Kind(ITF::QPARSE_E_EXPECTING_BRACE),
            ITF::QPARSE_E_EXPECTING_PAREN => RawError::Kind(ITF::QPARSE_E_EXPECTING_PAREN),
            ITF::QPARSE_E_EXPECTING_PROPERTY => RawError::Kind(ITF::QPARSE_E_EXPECTING_PROPERTY),
            ITF::QPARSE_E_NOT_YET_IMPLEMENTED => RawError::Kind(ITF::QPARSE_E_NOT_YET_IMPLEMENTED),
            ITF::QPARSE_E_EXPECTING_PHRASE => RawError::Kind(ITF::QPARSE_E_EXPECTING_PHRASE),
            ITF::QPARSE_E_UNSUPPORTED_PROPERTY_TYPE => RawError::Kind(ITF::QPARSE_E_UNSUPPORTED_PROPERTY_TYPE),
            ITF::QPARSE_E_EXPECTING_REGEX => RawError::Kind(ITF::QPARSE_E_EXPECTING_REGEX),
            ITF::QPARSE_E_EXPECTING_REGEX_PROPERTY => RawError::Kind(ITF::QPARSE_E_EXPECTING_REGEX_PROPERTY),
            ITF::QPARSE_E_INVALID_LITERAL => RawError::Kind(ITF::QPARSE_E_INVALID_LITERAL),
            ITF::QPARSE_E_NO_SUCH_PROPERTY => RawError::Kind(ITF::QPARSE_E_NO_SUCH_PROPERTY),
            ITF::QPARSE_E_EXPECTING_EOS => RawError::Kind(ITF::QPARSE_E_EXPECTING_EOS),
            ITF::QPARSE_E_EXPECTING_COMMA => RawError::Kind(ITF::QPARSE_E_EXPECTING_COMMA),
            ITF::QPARSE_E_UNEXPECTED_EOS => RawError::Kind(ITF::QPARSE_E_UNEXPECTED_EOS),
            ITF::QPARSE_E_WEIGHT_OUT_OF_RANGE => RawError::Kind(ITF::QPARSE_E_WEIGHT_OUT_OF_RANGE),
            ITF::QPARSE_E_NO_SUCH_SORT_PROPERTY => RawError::Kind(ITF::QPARSE_E_NO_SUCH_SORT_PROPERTY),
            ITF::QPARSE_E_INVALID_SORT_ORDER => RawError::Kind(ITF::QPARSE_E_INVALID_SORT_ORDER),
            ITF::QUTIL_E_CANT_CONVERT_VROOT => RawError::Kind(ITF::QUTIL_E_CANT_CONVERT_VROOT),
            ITF::QPARSE_E_INVALID_GROUPING => RawError::Kind(ITF::QPARSE_E_INVALID_GROUPING),
            ITF::QPARSE_E_INVALID_QUERY => RawError::Kind(ITF::QPARSE_E_INVALID_QUERY),
            ITF::QPARSE_E_INVALID_RANKMETHOD => RawError::Kind(ITF::QPARSE_E_INVALID_RANKMETHOD),
            ITF::FDAEMON_E_LOWRESOURCE => RawError::Kind(ITF::FDAEMON_E_LOWRESOURCE),
            ITF::FDAEMON_E_FATALERROR => RawError::Kind(ITF::FDAEMON_E_FATALERROR),
            ITF::FDAEMON_E_PARTITIONDELETED => RawError::Kind(ITF::FDAEMON_E_PARTITIONDELETED),
            ITF::FDAEMON_E_CHANGEUPDATEFAILED => RawError::Kind(ITF::FDAEMON_E_CHANGEUPDATEFAILED),
            ITF::FDAEMON_E_WORDLISTCOMMITFAILED => RawError::Kind(ITF::FDAEMON_E_WORDLISTCOMMITFAILED),
            ITF::FDAEMON_E_NOWORDLIST => RawError::Kind(ITF::FDAEMON_E_NOWORDLIST),
            ITF::FDAEMON_E_TOOMANYFILTEREDBLOCKS => RawError::Kind(ITF::FDAEMON_E_TOOMANYFILTEREDBLOCKS),
            ITF::SEARCH_E_NOMONIKER => RawError::Kind(ITF::SEARCH_E_NOMONIKER),
            ITF::SEARCH_E_NOREGION => RawError::Kind(ITF::SEARCH_E_NOREGION),
            ITF::FILTER_E_END_OF_CHUNKS => RawError::Kind(ITF::FILTER_E_END_OF_CHUNKS),
            ITF::FILTER_E_NO_MORE_TEXT => RawError::Kind(ITF::FILTER_E_NO_MORE_TEXT),
            ITF::FILTER_E_NO_MORE_VALUES => RawError::Kind(ITF::FILTER_E_NO_MORE_VALUES),
            ITF::FILTER_E_ACCESS => RawError::Kind(ITF::FILTER_E_ACCESS),
            ITF::FILTER_E_NO_TEXT => RawError::Kind(ITF::FILTER_E_NO_TEXT),
            ITF::FILTER_E_NO_VALUES => RawError::Kind(ITF::FILTER_E_NO_VALUES),
            ITF::FILTER_E_EMBEDDING_UNAVAILABLE => RawError::Kind(ITF::FILTER_E_EMBEDDING_UNAVAILABLE),
            ITF::FILTER_E_LINK_UNAVAILABLE => RawError::Kind(ITF::FILTER_E_LINK_UNAVAILABLE),
            ITF::FILTER_E_PASSWORD => RawError::Kind(ITF::FILTER_E_PASSWORD),
            ITF::FILTER_E_UNKNOWNFORMAT => RawError::Kind(ITF::FILTER_E_UNKNOWNFORMAT),
            ITF::FILTER_E_TOO_BIG => RawError::Kind(ITF::FILTER_E_TOO_BIG),
            ITF::FILTER_E_ALREADY_OPEN => RawError::Kind(ITF::FILTER_E_ALREADY_OPEN),
            ITF::FILTER_E_UNREACHABLE => RawError::Kind(ITF::FILTER_E_UNREACHABLE),
            ITF::FILTER_E_IN_USE => RawError::Kind(ITF::FILTER_E_IN_USE),
            ITF::FILTER_E_NOT_OPEN => RawError::Kind(ITF::FILTER_E_NOT_OPEN),
            ITF::FILTER_E_NO_SUCH_PROPERTY => RawError::Kind(ITF::FILTER_E_NO_SUCH_PROPERTY),
            ITF::FILTER_E_OFFLINE => RawError::Kind(ITF::FILTER_E_OFFLINE),
            ITF::FILTER_E_PARTIALLY_FILTERED => RawError::Kind(ITF::FILTER_E_PARTIALLY_FILTERED),
            ITF::WBREAK_E_END_OF_TEXT => RawError::Kind(ITF::WBREAK_E_END_OF_TEXT),
            ITF::WBREAK_E_QUERY_ONLY => RawError::Kind(ITF::WBREAK_E_QUERY_ONLY),
            ITF::WBREAK_E_BUFFER_TOO_SMALL => RawError::Kind(ITF::WBREAK_E_BUFFER_TOO_SMALL),
            ITF::LANGUAGE_E_DATABASE_NOT_FOUND => RawError::Kind(ITF::LANGUAGE_E_DATABASE_NOT_FOUND),
            ITF::WBREAK_E_INIT_FAILED => RawError::Kind(ITF::WBREAK_E_INIT_FAILED),
            ITF::PSINK_E_QUERY_ONLY => RawError::Kind(ITF::PSINK_E_QUERY_ONLY),
            ITF::PSINK_E_INDEX_ONLY => RawError::Kind(ITF::PSINK_E_INDEX_ONLY),
            ITF::PSINK_E_LARGE_ATTACHMENT => RawError::Kind(ITF::PSINK_E_LARGE_ATTACHMENT),
            ITF::CI_E_ALREADY_INITIALIZED => RawError::Kind(ITF::CI_E_ALREADY_INITIALIZED),
            ITF::CI_E_NOT_INITIALIZED => RawError::Kind(ITF::CI_E_NOT_INITIALIZED),
            ITF::CI_E_BUFFERTOOSMALL => RawError::Kind(ITF::CI_E_BUFFERTOOSMALL),
            ITF::CI_E_PROPERTY_NOT_CACHED => RawError::Kind(ITF::CI_E_PROPERTY_NOT_CACHED),
            ITF::CI_E_INVALID_STATE => RawError::Kind(ITF::CI_E_INVALID_STATE),
            ITF::CI_E_FILTERING_DISABLED => RawError::Kind(ITF::CI_E_FILTERING_DISABLED),
            ITF::CI_E_DISK_FULL => RawError::Kind(ITF::CI_E_DISK_FULL),
            ITF::CI_E_SHUTDOWN => RawError::Kind(ITF::CI_E_SHUTDOWN),
            ITF::CI_E_WORKID_NOTVALID => RawError::Kind(ITF::CI_E_WORKID_NOTVALID),
            ITF::CI_E_NOT_FOUND => RawError::Kind(ITF::CI_E_NOT_FOUND),
            ITF::CI_E_USE_DEFAULT_PID => RawError::Kind(ITF::CI_E_USE_DEFAULT_PID),
            ITF::CI_E_DUPLICATE_NOTIFICATION => RawError::Kind(ITF::CI_E_DUPLICATE_NOTIFICATION),
            ITF::CI_E_UPDATES_DISABLED => RawError::Kind(ITF::CI_E_UPDATES_DISABLED),
            ITF::CI_E_INVALID_FLAGS_COMBINATION => RawError::Kind(ITF::CI_E_INVALID_FLAGS_COMBINATION),
            ITF::CI_E_OUTOFSEQ_INCREMENT_DATA => RawError::Kind(ITF::CI_E_OUTOFSEQ_INCREMENT_DATA),
            ITF::CI_E_SHARING_VIOLATION => RawError::Kind(ITF::CI_E_SHARING_VIOLATION),
            ITF::CI_E_LOGON_FAILURE => RawError::Kind(ITF::CI_E_LOGON_FAILURE),
            ITF::CI_E_NO_CATALOG => RawError::Kind(ITF::CI_E_NO_CATALOG),
            ITF::CI_E_STRANGE_PAGEORSECTOR_SIZE => RawError::Kind(ITF::CI_E_STRANGE_PAGEORSECTOR_SIZE),
            ITF::CI_E_TIMEOUT => RawError::Kind(ITF::CI_E_TIMEOUT),
            ITF::CI_E_NOT_RUNNING => RawError::Kind(ITF::CI_E_NOT_RUNNING),
            ITF::CI_E_CARDINALITY_MISMATCH => RawError::Kind(ITF::CI_E_CARDINALITY_MISMATCH),
            ITF::CI_E_CONFIG_DISK_FULL => RawError::Kind(ITF::CI_E_CONFIG_DISK_FULL),
            ITF::CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED => RawError::Kind(ITF::CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED),
            ITF::CI_E_NO_AUXMETADATA => RawError::Kind(ITF::CI_E_NO_AUXMETADATA),
            ITF::CI_E_INVALID_CATALOG_LIST_VERSION => RawError::Kind(ITF::CI_E_INVALID_CATALOG_LIST_VERSION),
            ITF::NLADMIN_E_DUPLICATE_CATALOG => RawError::Kind(ITF::NLADMIN_E_DUPLICATE_CATALOG),
            ITF::NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE => RawError::Kind(ITF::NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE),
            ITF::NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED => RawError::Kind(ITF::NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED),
            ITF::FAX_E_SRV_OUTOFMEMORY => RawError::Kind(ITF::FAX_E_SRV_OUTOFMEMORY),
            ITF::FAX_E_GROUP_NOT_FOUND => RawError::Kind(ITF::FAX_E_GROUP_NOT_FOUND),
            ITF::FAX_E_BAD_GROUP_CONFIGURATION => RawError::Kind(ITF::FAX_E_BAD_GROUP_CONFIGURATION),
            ITF::FAX_E_GROUP_IN_USE => RawError::Kind(ITF::FAX_E_GROUP_IN_USE),
            ITF::FAX_E_RULE_NOT_FOUND => RawError::Kind(ITF::FAX_E_RULE_NOT_FOUND),
            ITF::FAX_E_NOT_NTFS => RawError::Kind(ITF::FAX_E_NOT_NTFS),
            ITF::FAX_E_DIRECTORY_IN_USE => RawError::Kind(ITF::FAX_E_DIRECTORY_IN_USE),
            ITF::FAX_E_FILE_ACCESS_DENIED => RawError::Kind(ITF::FAX_E_FILE_ACCESS_DENIED),
            ITF::FAX_E_MESSAGE_NOT_FOUND => RawError::Kind(ITF::FAX_E_MESSAGE_NOT_FOUND),
            ITF::FAX_E_DEVICE_NUM_LIMIT_EXCEEDED => RawError::Kind(ITF::FAX_E_DEVICE_NUM_LIMIT_EXCEEDED),
            ITF::FAX_E_NOT_SUPPORTED_ON_THIS_SKU => RawError::Kind(ITF::FAX_E_NOT_SUPPORTED_ON_THIS_SKU),
            ITF::FAX_E_VERSION_MISMATCH => RawError::Kind(ITF::FAX_E_VERSION_MISMATCH),
            ITF::FAX_E_RECIPIENTS_LIMIT => RawError::Kind(ITF::FAX_E_RECIPIENTS_LIMIT),
            ITF::SCRIPTPI_E_CHUNK_NOT_TEXT => RawError::Kind(ITF::SCRIPTPI_E_CHUNK_NOT_TEXT),
            ITF::SCRIPTPI_E_PID_NOT_NAME => RawError::Kind(ITF::SCRIPTPI_E_PID_NOT_NAME),
            ITF::SCRIPTPI_E_PID_NOT_NUMERIC => RawError::Kind(ITF::SCRIPTPI_E_PID_NOT_NUMERIC),
            ITF::SCRIPTPI_E_CHUNK_NOT_VALUE => RawError::Kind(ITF::SCRIPTPI_E_CHUNK_NOT_VALUE),
            ITF::SCRIPTPI_E_CANNOT_ALTER_CHUNK => RawError::Kind(ITF::SCRIPTPI_E_CANNOT_ALTER_CHUNK),
            ITF::SCRIPTPI_E_ALREADY_COMPLETED => RawError::Kind(ITF::SCRIPTPI_E_ALREADY_COMPLETED),
            ITF::MSS_E_INVALIDAPPNAME => RawError::Kind(ITF::MSS_E_INVALIDAPPNAME),
            ITF::MSS_E_APPNOTFOUND => RawError::Kind(ITF::MSS_E_APPNOTFOUND),
            ITF::MSS_E_APPALREADYEXISTS => RawError::Kind(ITF::MSS_E_APPALREADYEXISTS),
            ITF::MSS_E_CATALOGNOTFOUND => RawError::Kind(ITF::MSS_E_CATALOGNOTFOUND),
            ITF::MSS_E_CATALOGSTOPPING => RawError::Kind(ITF::MSS_E_CATALOGSTOPPING),
            ITF::MSS_E_UNICODEFILEHEADERMISSING => RawError::Kind(ITF::MSS_E_UNICODEFILEHEADERMISSING),
            ITF::MSS_E_CATALOGALREADYEXISTS => RawError::Kind(ITF::MSS_E_CATALOGALREADYEXISTS),
            ITF::XML_E_NODEFAULTNS => RawError::Kind(ITF::XML_E_NODEFAULTNS),
            ITF::XML_E_BADSXQL => RawError::Kind(ITF::XML_E_BADSXQL),
            ITF::VSS_E_BAD_STATE => RawError::Kind(ITF::VSS_E_BAD_STATE),
            ITF::VSS_E_UNEXPECTED => RawError::Kind(ITF::VSS_E_UNEXPECTED),
            ITF::VSS_E_PROVIDER_ALREADY_REGISTERED => RawError::Kind(ITF::VSS_E_PROVIDER_ALREADY_REGISTERED),
            ITF::VSS_E_PROVIDER_NOT_REGISTERED => RawError::Kind(ITF::VSS_E_PROVIDER_NOT_REGISTERED),
            ITF::VSS_E_PROVIDER_VETO => RawError::Kind(ITF::VSS_E_PROVIDER_VETO),
            ITF::VSS_E_PROVIDER_IN_USE => RawError::Kind(ITF::VSS_E_PROVIDER_IN_USE),
            ITF::VSS_E_OBJECT_NOT_FOUND => RawError::Kind(ITF::VSS_E_OBJECT_NOT_FOUND),
            ITF::VSS_E_VOLUME_NOT_SUPPORTED => RawError::Kind(ITF::VSS_E_VOLUME_NOT_SUPPORTED),
            ITF::VSS_E_OBJECT_ALREADY_EXISTS => RawError::Kind(ITF::VSS_E_OBJECT_ALREADY_EXISTS),
            ITF::VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER => RawError::Kind(ITF::VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER),
            ITF::VSS_E_UNEXPECTED_PROVIDER_ERROR => RawError::Kind(ITF::VSS_E_UNEXPECTED_PROVIDER_ERROR),
            ITF::VSS_E_CORRUPT_XML_DOCUMENT => RawError::Kind(ITF::VSS_E_CORRUPT_XML_DOCUMENT),
            ITF::VSS_E_INVALID_XML_DOCUMENT => RawError::Kind(ITF::VSS_E_INVALID_XML_DOCUMENT),
            ITF::VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED => RawError::Kind(ITF::VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED),
            ITF::VSS_E_FLUSH_WRITES_TIMEOUT => RawError::Kind(ITF::VSS_E_FLUSH_WRITES_TIMEOUT),
            ITF::VSS_E_HOLD_WRITES_TIMEOUT => RawError::Kind(ITF::VSS_E_HOLD_WRITES_TIMEOUT),
            ITF::VSS_E_UNEXPECTED_WRITER_ERROR => RawError::Kind(ITF::VSS_E_UNEXPECTED_WRITER_ERROR),
            ITF::VSS_E_SNAPSHOT_SET_IN_PROGRESS => RawError::Kind(ITF::VSS_E_SNAPSHOT_SET_IN_PROGRESS),
            ITF::VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED => RawError::Kind(ITF::VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED),
            ITF::VSS_E_WRITER_INFRASTRUCTURE => RawError::Kind(ITF::VSS_E_WRITER_INFRASTRUCTURE),
            ITF::VSS_E_WRITER_NOT_RESPONDING => RawError::Kind(ITF::VSS_E_WRITER_NOT_RESPONDING),
            ITF::VSS_E_WRITER_ALREADY_SUBSCRIBED => RawError::Kind(ITF::VSS_E_WRITER_ALREADY_SUBSCRIBED),
            ITF::VSS_E_UNSUPPORTED_CONTEXT => RawError::Kind(ITF::VSS_E_UNSUPPORTED_CONTEXT),
            ITF::VSS_E_VOLUME_IN_USE => RawError::Kind(ITF::VSS_E_VOLUME_IN_USE),
            ITF::VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED => RawError::Kind(ITF::VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED),
            ITF::VSS_E_INSUFFICIENT_STORAGE => RawError::Kind(ITF::VSS_E_INSUFFICIENT_STORAGE),
            ITF::VSS_E_NO_SNAPSHOTS_IMPORTED => RawError::Kind(ITF::VSS_E_NO_SNAPSHOTS_IMPORTED),
            ITF::VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED => RawError::Kind(ITF::VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED),
            ITF::VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED => RawError::Kind(ITF::VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED),
            ITF::VSS_E_REMOTE_SERVER_UNAVAILABLE => RawError::Kind(ITF::VSS_E_REMOTE_SERVER_UNAVAILABLE),
            ITF::VSS_E_REMOTE_SERVER_UNSUPPORTED => RawError::Kind(ITF::VSS_E_REMOTE_SERVER_UNSUPPORTED),
            ITF::VSS_E_REVERT_IN_PROGRESS => RawError::Kind(ITF::VSS_E_REVERT_IN_PROGRESS),
            ITF::VSS_E_REVERT_VOLUME_LOST => RawError::Kind(ITF::VSS_E_REVERT_VOLUME_LOST),
            ITF::VSS_E_REBOOT_REQUIRED => RawError::Kind(ITF::VSS_E_REBOOT_REQUIRED),
            ITF::VSS_E_TRANSACTION_FREEZE_TIMEOUT => RawError::Kind(ITF::VSS_E_TRANSACTION_FREEZE_TIMEOUT),
            ITF::VSS_E_TRANSACTION_THAW_TIMEOUT => RawError::Kind(ITF::VSS_E_TRANSACTION_THAW_TIMEOUT),
            ITF::VSS_E_UNSELECTED_VOLUME => RawError::Kind(ITF::VSS_E_UNSELECTED_VOLUME),
            ITF::VSS_E_SNAPSHOT_NOT_IN_SET => RawError::Kind(ITF::VSS_E_SNAPSHOT_NOT_IN_SET),
            ITF::VSS_E_NESTED_VOLUME_LIMIT => RawError::Kind(ITF::VSS_E_NESTED_VOLUME_LIMIT),
            ITF::VSS_E_VOLUME_NOT_LOCAL => RawError::Kind(ITF::VSS_E_VOLUME_NOT_LOCAL),
            ITF::VSS_E_CLUSTER_TIMEOUT => RawError::Kind(ITF::VSS_E_CLUSTER_TIMEOUT),
            ITF::VSS_E_NOT_SUPPORTED => RawError::Kind(ITF::VSS_E_NOT_SUPPORTED),
            ITF::VSS_E_WRITERERROR_PARTIAL_FAILURE => RawError::Kind(ITF::VSS_E_WRITERERROR_PARTIAL_FAILURE),
            ITF::VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT => RawError::Kind(ITF::VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT),
            ITF::VSS_E_WRITERERROR_OUTOFRESOURCES => RawError::Kind(ITF::VSS_E_WRITERERROR_OUTOFRESOURCES),
            ITF::VSS_E_WRITERERROR_TIMEOUT => RawError::Kind(ITF::VSS_E_WRITERERROR_TIMEOUT),
            ITF::VSS_E_WRITERERROR_RETRYABLE => RawError::Kind(ITF::VSS_E_WRITERERROR_RETRYABLE),
            ITF::VSS_E_WRITERERROR_NONRETRYABLE => RawError::Kind(ITF::VSS_E_WRITERERROR_NONRETRYABLE),
            ITF::VSS_E_WRITERERROR_RECOVERY_FAILED => RawError::Kind(ITF::VSS_E_WRITERERROR_RECOVERY_FAILED),
            ITF::VSS_E_BREAK_REVERT_ID_FAILED => RawError::Kind(ITF::VSS_E_BREAK_REVERT_ID_FAILED),
            ITF::VSS_E_LEGACY_PROVIDER => RawError::Kind(ITF::VSS_E_LEGACY_PROVIDER),
            ITF::VSS_E_MISSING_DISK => RawError::Kind(ITF::VSS_E_MISSING_DISK),
            ITF::VSS_E_MISSING_HIDDEN_VOLUME => RawError::Kind(ITF::VSS_E_MISSING_HIDDEN_VOLUME),
            ITF::VSS_E_MISSING_VOLUME => RawError::Kind(ITF::VSS_E_MISSING_VOLUME),
            ITF::VSS_E_AUTORECOVERY_FAILED => RawError::Kind(ITF::VSS_E_AUTORECOVERY_FAILED),
            ITF::VSS_E_DYNAMIC_DISK_ERROR => RawError::Kind(ITF::VSS_E_DYNAMIC_DISK_ERROR),
            ITF::VSS_E_NONTRANSPORTABLE_BCD => RawError::Kind(ITF::VSS_E_NONTRANSPORTABLE_BCD),
            ITF::VSS_E_CANNOT_REVERT_DISKID => RawError::Kind(ITF::VSS_E_CANNOT_REVERT_DISKID),
            ITF::VSS_E_RESYNC_IN_PROGRESS => RawError::Kind(ITF::VSS_E_RESYNC_IN_PROGRESS),
            ITF::VDS_E_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_NOT_SUPPORTED),
            ITF::VSS_E_CLUSTER_ERROR => RawError::Kind(ITF::VSS_E_CLUSTER_ERROR),
            ITF::FLTRDMN_E_UNEXPECTED => RawError::Kind(ITF::FLTRDMN_E_UNEXPECTED),
            ITF::VDS_E_INITIALIZED_FAILED => RawError::Kind(ITF::VDS_E_INITIALIZED_FAILED),
            ITF::VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED => RawError::Kind(ITF::VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED),
            ITF::FLTRDMN_E_QI_FILTER_FAILED => RawError::Kind(ITF::FLTRDMN_E_QI_FILTER_FAILED),
            ITF::VDS_E_INITIALIZE_NOT_CALLED => RawError::Kind(ITF::VDS_E_INITIALIZE_NOT_CALLED),
            ITF::VSS_E_ASRERROR_DISK_RECREATION_FAILED => RawError::Kind(ITF::VSS_E_ASRERROR_DISK_RECREATION_FAILED),
            ITF::VDS_E_ALREADY_REGISTERED => RawError::Kind(ITF::VDS_E_ALREADY_REGISTERED),
            ITF::VSS_E_ASRERROR_NO_ARCPATH => RawError::Kind(ITF::VSS_E_ASRERROR_NO_ARCPATH),
            ITF::FLTRDMN_E_FILTER_INIT_FAILED => RawError::Kind(ITF::FLTRDMN_E_FILTER_INIT_FAILED),
            ITF::VDS_E_ANOTHER_CALL_IN_PROGRESS => RawError::Kind(ITF::VDS_E_ANOTHER_CALL_IN_PROGRESS),
            ITF::VSS_E_ASRERROR_MISSING_DYNDISK => RawError::Kind(ITF::VSS_E_ASRERROR_MISSING_DYNDISK),
            ITF::FLTRDMN_E_ENCRYPTED_DOCUMENT => RawError::Kind(ITF::FLTRDMN_E_ENCRYPTED_DOCUMENT),
            ITF::VDS_E_OBJECT_NOT_FOUND => RawError::Kind(ITF::VDS_E_OBJECT_NOT_FOUND),
            ITF::VSS_E_ASRERROR_SHARED_CRIDISK => RawError::Kind(ITF::VSS_E_ASRERROR_SHARED_CRIDISK),
            ITF::FLTRDMN_E_CANNOT_DECRYPT_PASSWORD => RawError::Kind(ITF::FLTRDMN_E_CANNOT_DECRYPT_PASSWORD),
            ITF::VDS_E_INVALID_SPACE => RawError::Kind(ITF::VDS_E_INVALID_SPACE),
            ITF::VSS_E_ASRERROR_DATADISK_RDISK0 => RawError::Kind(ITF::VSS_E_ASRERROR_DATADISK_RDISK0),
            ITF::VDS_E_PARTITION_LIMIT_REACHED => RawError::Kind(ITF::VDS_E_PARTITION_LIMIT_REACHED),
            ITF::VSS_E_ASRERROR_RDISK0_TOOSMALL => RawError::Kind(ITF::VSS_E_ASRERROR_RDISK0_TOOSMALL),
            ITF::VDS_E_PARTITION_NOT_EMPTY => RawError::Kind(ITF::VDS_E_PARTITION_NOT_EMPTY),
            ITF::VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL => RawError::Kind(ITF::VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL),
            ITF::VDS_E_OPERATION_PENDING => RawError::Kind(ITF::VDS_E_OPERATION_PENDING),
            ITF::VSS_E_WRITER_STATUS_NOT_AVAILABLE => RawError::Kind(ITF::VSS_E_WRITER_STATUS_NOT_AVAILABLE),
            ITF::VDS_E_OPERATION_DENIED => RawError::Kind(ITF::VDS_E_OPERATION_DENIED),
            ITF::VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED => RawError::Kind(ITF::VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED),
            ITF::VDS_E_OBJECT_DELETED => RawError::Kind(ITF::VDS_E_OBJECT_DELETED),
            ITF::VDS_E_CANCEL_TOO_LATE => RawError::Kind(ITF::VDS_E_CANCEL_TOO_LATE),
            ITF::VDS_E_OPERATION_CANCELED => RawError::Kind(ITF::VDS_E_OPERATION_CANCELED),
            ITF::VDS_E_CANNOT_EXTEND => RawError::Kind(ITF::VDS_E_CANNOT_EXTEND),
            ITF::VDS_E_NOT_ENOUGH_SPACE => RawError::Kind(ITF::VDS_E_NOT_ENOUGH_SPACE),
            ITF::VDS_E_NOT_ENOUGH_DRIVE => RawError::Kind(ITF::VDS_E_NOT_ENOUGH_DRIVE),
            ITF::VDS_E_BAD_COOKIE => RawError::Kind(ITF::VDS_E_BAD_COOKIE),
            ITF::VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK => RawError::Kind(ITF::VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK),
            ITF::VDS_E_NO_MEDIA => RawError::Kind(ITF::VDS_E_NO_MEDIA),
            ITF::VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND => RawError::Kind(ITF::VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND),
            ITF::VDS_E_DEVICE_IN_USE => RawError::Kind(ITF::VDS_E_DEVICE_IN_USE),
            ITF::VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE => RawError::Kind(ITF::VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE),
            ITF::VDS_E_DISK_NOT_EMPTY => RawError::Kind(ITF::VDS_E_DISK_NOT_EMPTY),
            ITF::VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION => RawError::Kind(ITF::VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION),
            ITF::VDS_E_INVALID_OPERATION => RawError::Kind(ITF::VDS_E_INVALID_OPERATION),
            ITF::VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED => RawError::Kind(ITF::VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED),
            ITF::VDS_E_PATH_NOT_FOUND => RawError::Kind(ITF::VDS_E_PATH_NOT_FOUND),
            ITF::VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN => RawError::Kind(ITF::VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN),
            ITF::VDS_E_DISK_NOT_INITIALIZED => RawError::Kind(ITF::VDS_E_DISK_NOT_INITIALIZED),
            ITF::VSS_E_FSS_TIMEOUT => RawError::Kind(ITF::VSS_E_FSS_TIMEOUT),
            ITF::VDS_E_NOT_AN_UNALLOCATED_DISK => RawError::Kind(ITF::VDS_E_NOT_AN_UNALLOCATED_DISK),
            ITF::VDS_E_UNRECOVERABLE_ERROR => RawError::Kind(ITF::VDS_E_UNRECOVERABLE_ERROR),
            ITF::VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED => RawError::Kind(ITF::VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED),
            ITF::VDS_E_PROVIDER_INITIALIZATION_FAILED => RawError::Kind(ITF::VDS_E_PROVIDER_INITIALIZATION_FAILED),
            ITF::VDS_E_OBJECT_EXISTS => RawError::Kind(ITF::VDS_E_OBJECT_EXISTS),
            ITF::VDS_E_NO_DISKS_FOUND => RawError::Kind(ITF::VDS_E_NO_DISKS_FOUND),
            ITF::VDS_E_PROVIDER_CACHE_CORRUPT => RawError::Kind(ITF::VDS_E_PROVIDER_CACHE_CORRUPT),
            ITF::VDS_E_DMADMIN_METHOD_CALL_FAILED => RawError::Kind(ITF::VDS_E_DMADMIN_METHOD_CALL_FAILED),
            ITF::VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND => RawError::Kind(ITF::VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND),
            ITF::VDS_E_PROVIDER_VOL_OPEN => RawError::Kind(ITF::VDS_E_PROVIDER_VOL_OPEN),
            ITF::VDS_E_DMADMIN_CORRUPT_NOTIFICATION => RawError::Kind(ITF::VDS_E_DMADMIN_CORRUPT_NOTIFICATION),
            ITF::VDS_E_INCOMPATIBLE_FILE_SYSTEM => RawError::Kind(ITF::VDS_E_INCOMPATIBLE_FILE_SYSTEM),
            ITF::VDS_E_INCOMPATIBLE_MEDIA => RawError::Kind(ITF::VDS_E_INCOMPATIBLE_MEDIA),
            ITF::VDS_E_ACCESS_DENIED => RawError::Kind(ITF::VDS_E_ACCESS_DENIED),
            ITF::VDS_E_MEDIA_WRITE_PROTECTED => RawError::Kind(ITF::VDS_E_MEDIA_WRITE_PROTECTED),
            ITF::VDS_E_BAD_LABEL => RawError::Kind(ITF::VDS_E_BAD_LABEL),
            ITF::VDS_E_CANT_QUICK_FORMAT => RawError::Kind(ITF::VDS_E_CANT_QUICK_FORMAT),
            ITF::VDS_E_IO_ERROR => RawError::Kind(ITF::VDS_E_IO_ERROR),
            ITF::VDS_E_VOLUME_TOO_SMALL => RawError::Kind(ITF::VDS_E_VOLUME_TOO_SMALL),
            ITF::VDS_E_VOLUME_TOO_BIG => RawError::Kind(ITF::VDS_E_VOLUME_TOO_BIG),
            ITF::VDS_E_CLUSTER_SIZE_TOO_SMALL => RawError::Kind(ITF::VDS_E_CLUSTER_SIZE_TOO_SMALL),
            ITF::VDS_E_CLUSTER_SIZE_TOO_BIG => RawError::Kind(ITF::VDS_E_CLUSTER_SIZE_TOO_BIG),
            ITF::VDS_E_CLUSTER_COUNT_BEYOND_32BITS => RawError::Kind(ITF::VDS_E_CLUSTER_COUNT_BEYOND_32BITS),
            ITF::VDS_E_OBJECT_STATUS_FAILED => RawError::Kind(ITF::VDS_E_OBJECT_STATUS_FAILED),
            ITF::VDS_E_VOLUME_INCOMPLETE => RawError::Kind(ITF::VDS_E_VOLUME_INCOMPLETE),
            ITF::VDS_E_EXTENT_SIZE_LESS_THAN_MIN => RawError::Kind(ITF::VDS_E_EXTENT_SIZE_LESS_THAN_MIN),
            ITF::VDS_E_BOOT_PARTITION_NUMBER_CHANGE => RawError::Kind(ITF::VDS_E_BOOT_PARTITION_NUMBER_CHANGE),
            ITF::VDS_E_NO_FREE_SPACE => RawError::Kind(ITF::VDS_E_NO_FREE_SPACE),
            ITF::VDS_E_ACTIVE_PARTITION => RawError::Kind(ITF::VDS_E_ACTIVE_PARTITION),
            ITF::VDS_E_PARTITION_OF_UNKNOWN_TYPE => RawError::Kind(ITF::VDS_E_PARTITION_OF_UNKNOWN_TYPE),
            ITF::VDS_E_LEGACY_VOLUME_FORMAT => RawError::Kind(ITF::VDS_E_LEGACY_VOLUME_FORMAT),
            ITF::VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS => RawError::Kind(ITF::VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS),
            ITF::VDS_E_MIGRATE_OPEN_VOLUME => RawError::Kind(ITF::VDS_E_MIGRATE_OPEN_VOLUME),
            ITF::VDS_E_VOLUME_NOT_ONLINE => RawError::Kind(ITF::VDS_E_VOLUME_NOT_ONLINE),
            ITF::VDS_E_VOLUME_NOT_HEALTHY => RawError::Kind(ITF::VDS_E_VOLUME_NOT_HEALTHY),
            ITF::VDS_E_VOLUME_SPANS_DISKS => RawError::Kind(ITF::VDS_E_VOLUME_SPANS_DISKS),
            ITF::VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE => RawError::Kind(ITF::VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE),
            ITF::VDS_E_BAD_PROVIDER_DATA => RawError::Kind(ITF::VDS_E_BAD_PROVIDER_DATA),
            ITF::VDS_E_PROVIDER_FAILURE => RawError::Kind(ITF::VDS_E_PROVIDER_FAILURE),
            ITF::VDS_E_PACK_OFFLINE => RawError::Kind(ITF::VDS_E_PACK_OFFLINE),
            ITF::VDS_E_VOLUME_NOT_A_MIRROR => RawError::Kind(ITF::VDS_E_VOLUME_NOT_A_MIRROR),
            ITF::VDS_E_NO_EXTENTS_FOR_VOLUME => RawError::Kind(ITF::VDS_E_NO_EXTENTS_FOR_VOLUME),
            ITF::VDS_E_DISK_NOT_LOADED_TO_CACHE => RawError::Kind(ITF::VDS_E_DISK_NOT_LOADED_TO_CACHE),
            ITF::VDS_E_INTERNAL_ERROR => RawError::Kind(ITF::VDS_E_INTERNAL_ERROR),
            ITF::VDS_E_PROVIDER_TYPE_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_PROVIDER_TYPE_NOT_SUPPORTED),
            ITF::VDS_E_DISK_NOT_ONLINE => RawError::Kind(ITF::VDS_E_DISK_NOT_ONLINE),
            ITF::VDS_E_DISK_IN_USE_BY_VOLUME => RawError::Kind(ITF::VDS_E_DISK_IN_USE_BY_VOLUME),
            ITF::VDS_E_ASYNC_OBJECT_FAILURE => RawError::Kind(ITF::VDS_E_ASYNC_OBJECT_FAILURE),
            ITF::VDS_E_VOLUME_NOT_MOUNTED => RawError::Kind(ITF::VDS_E_VOLUME_NOT_MOUNTED),
            ITF::VDS_E_PACK_NOT_FOUND => RawError::Kind(ITF::VDS_E_PACK_NOT_FOUND),
            ITF::VDS_E_IMPORT_SET_INCOMPLETE => RawError::Kind(ITF::VDS_E_IMPORT_SET_INCOMPLETE),
            ITF::VDS_E_DISK_NOT_IMPORTED => RawError::Kind(ITF::VDS_E_DISK_NOT_IMPORTED),
            ITF::VDS_E_OBJECT_OUT_OF_SYNC => RawError::Kind(ITF::VDS_E_OBJECT_OUT_OF_SYNC),
            ITF::VDS_E_MISSING_DISK => RawError::Kind(ITF::VDS_E_MISSING_DISK),
            ITF::VDS_E_DISK_PNP_REG_CORRUPT => RawError::Kind(ITF::VDS_E_DISK_PNP_REG_CORRUPT),
            ITF::VDS_E_LBN_REMAP_ENABLED_FLAG => RawError::Kind(ITF::VDS_E_LBN_REMAP_ENABLED_FLAG),
            ITF::VDS_E_NO_DRIVELETTER_FLAG => RawError::Kind(ITF::VDS_E_NO_DRIVELETTER_FLAG),
            ITF::VDS_E_REVERT_ON_CLOSE => RawError::Kind(ITF::VDS_E_REVERT_ON_CLOSE),
            ITF::VDS_E_REVERT_ON_CLOSE_SET => RawError::Kind(ITF::VDS_E_REVERT_ON_CLOSE_SET),
            ITF::VDS_E_IA64_BOOT_MIRRORED_TO_MBR => RawError::Kind(ITF::VDS_E_IA64_BOOT_MIRRORED_TO_MBR),
            ITF::VDS_E_VOLUME_TEMPORARILY_DISMOUNTED => RawError::Kind(ITF::VDS_E_VOLUME_TEMPORARILY_DISMOUNTED),
            ITF::VDS_E_VOLUME_PERMANENTLY_DISMOUNTED => RawError::Kind(ITF::VDS_E_VOLUME_PERMANENTLY_DISMOUNTED),
            ITF::VDS_E_VOLUME_HAS_PATH => RawError::Kind(ITF::VDS_E_VOLUME_HAS_PATH),
            ITF::VDS_E_TIMEOUT => RawError::Kind(ITF::VDS_E_TIMEOUT),
            ITF::VDS_E_REPAIR_VOLUMESTATE => RawError::Kind(ITF::VDS_E_REPAIR_VOLUMESTATE),
            ITF::VDS_E_LDM_TIMEOUT => RawError::Kind(ITF::VDS_E_LDM_TIMEOUT),
            ITF::VDS_E_REVERT_ON_CLOSE_MISMATCH => RawError::Kind(ITF::VDS_E_REVERT_ON_CLOSE_MISMATCH),
            ITF::VDS_E_RETRY => RawError::Kind(ITF::VDS_E_RETRY),
            ITF::VDS_E_ONLINE_PACK_EXISTS => RawError::Kind(ITF::VDS_E_ONLINE_PACK_EXISTS),
            ITF::VDS_E_EXTEND_FILE_SYSTEM_FAILED => RawError::Kind(ITF::VDS_E_EXTEND_FILE_SYSTEM_FAILED),
            ITF::VDS_E_MAX_USABLE_MBR => RawError::Kind(ITF::VDS_E_MAX_USABLE_MBR),
            ITF::VDS_S_GPT_BOOT_MIRRORED_TO_MBR => RawError::Kind(ITF::VDS_S_GPT_BOOT_MIRRORED_TO_MBR),
            ITF::OLEDB_BINDER_CUSTOM_ERROR => RawError::Kind(ITF::OLEDB_BINDER_CUSTOM_ERROR),
            ITF::VDS_E_NO_SOFTWARE_PROVIDERS_LOADED => RawError::Kind(ITF::VDS_E_NO_SOFTWARE_PROVIDERS_LOADED),
            ITF::VDS_E_DISK_NOT_MISSING => RawError::Kind(ITF::VDS_E_DISK_NOT_MISSING),
            ITF::VDS_E_NO_VOLUME_LAYOUT => RawError::Kind(ITF::VDS_E_NO_VOLUME_LAYOUT),
            ITF::VDS_E_CORRUPT_VOLUME_INFO => RawError::Kind(ITF::VDS_E_CORRUPT_VOLUME_INFO),
            ITF::VDS_E_INVALID_ENUMERATOR => RawError::Kind(ITF::VDS_E_INVALID_ENUMERATOR),
            ITF::VDS_E_DRIVER_INTERNAL_ERROR => RawError::Kind(ITF::VDS_E_DRIVER_INTERNAL_ERROR),
            ITF::VDS_E_VOLUME_INVALID_NAME => RawError::Kind(ITF::VDS_E_VOLUME_INVALID_NAME),
            ITF::VDS_E_CORRUPT_PARTITION_INFO => RawError::Kind(ITF::VDS_E_CORRUPT_PARTITION_INFO),
            ITF::VDS_E_CORRUPT_EXTENT_INFO => RawError::Kind(ITF::VDS_E_CORRUPT_EXTENT_INFO),
            ITF::VDS_E_DUP_EMPTY_PACK_GUID => RawError::Kind(ITF::VDS_E_DUP_EMPTY_PACK_GUID),
            ITF::VDS_E_DRIVER_NO_PACK_NAME => RawError::Kind(ITF::VDS_E_DRIVER_NO_PACK_NAME),
            ITF::VDS_E_BAD_PNP_MESSAGE => RawError::Kind(ITF::VDS_E_BAD_PNP_MESSAGE),
            ITF::VDS_E_NO_PNP_DISK_ARRIVE => RawError::Kind(ITF::VDS_E_NO_PNP_DISK_ARRIVE),
            ITF::VDS_E_NO_PNP_VOLUME_ARRIVE => RawError::Kind(ITF::VDS_E_NO_PNP_VOLUME_ARRIVE),
            ITF::VDS_E_NO_PNP_DISK_REMOVE => RawError::Kind(ITF::VDS_E_NO_PNP_DISK_REMOVE),
            ITF::VDS_E_NO_PNP_VOLUME_REMOVE => RawError::Kind(ITF::VDS_E_NO_PNP_VOLUME_REMOVE),
            ITF::VDS_E_PROVIDER_EXITING => RawError::Kind(ITF::VDS_E_PROVIDER_EXITING),
            ITF::VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE => RawError::Kind(ITF::VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE),
            ITF::VDS_E_MEMBER_SIZE_INVALID => RawError::Kind(ITF::VDS_E_MEMBER_SIZE_INVALID),
            ITF::VDS_E_INVALID_DISK => RawError::Kind(ITF::VDS_E_INVALID_DISK),
            ITF::VDS_E_INVALID_PACK => RawError::Kind(ITF::VDS_E_INVALID_PACK),
            ITF::VDS_E_VOLUME_ON_DISK => RawError::Kind(ITF::VDS_E_VOLUME_ON_DISK),
            ITF::VDS_E_DRIVER_INVALID_PARAM => RawError::Kind(ITF::VDS_E_DRIVER_INVALID_PARAM),
            ITF::VDS_E_TARGET_PACK_NOT_EMPTY => RawError::Kind(ITF::VDS_E_TARGET_PACK_NOT_EMPTY),
            ITF::VDS_E_CANNOT_SHRINK => RawError::Kind(ITF::VDS_E_CANNOT_SHRINK),
            ITF::VDS_E_MULTIPLE_PACKS => RawError::Kind(ITF::VDS_E_MULTIPLE_PACKS),
            ITF::VDS_E_PACK_ONLINE => RawError::Kind(ITF::VDS_E_PACK_ONLINE),
            ITF::VDS_E_INVALID_PLEX_COUNT => RawError::Kind(ITF::VDS_E_INVALID_PLEX_COUNT),
            ITF::VDS_E_INVALID_MEMBER_COUNT => RawError::Kind(ITF::VDS_E_INVALID_MEMBER_COUNT),
            ITF::VDS_E_INVALID_PLEX_ORDER => RawError::Kind(ITF::VDS_E_INVALID_PLEX_ORDER),
            ITF::VDS_E_INVALID_MEMBER_ORDER => RawError::Kind(ITF::VDS_E_INVALID_MEMBER_ORDER),
            ITF::VDS_E_INVALID_STRIPE_SIZE => RawError::Kind(ITF::VDS_E_INVALID_STRIPE_SIZE),
            ITF::VDS_E_INVALID_DISK_COUNT => RawError::Kind(ITF::VDS_E_INVALID_DISK_COUNT),
            ITF::VDS_E_INVALID_EXTENT_COUNT => RawError::Kind(ITF::VDS_E_INVALID_EXTENT_COUNT),
            ITF::VDS_E_SOURCE_IS_TARGET_PACK => RawError::Kind(ITF::VDS_E_SOURCE_IS_TARGET_PACK),
            ITF::VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED => RawError::Kind(ITF::VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED),
            ITF::VDS_E_CORRUPT_NOTIFICATION_INFO => RawError::Kind(ITF::VDS_E_CORRUPT_NOTIFICATION_INFO),
            ITF::VDS_E_INVALID_PLEX_GUID => RawError::Kind(ITF::VDS_E_INVALID_PLEX_GUID),
            ITF::VDS_E_DISK_NOT_FOUND_IN_PACK => RawError::Kind(ITF::VDS_E_DISK_NOT_FOUND_IN_PACK),
            ITF::VDS_E_DUPLICATE_DISK => RawError::Kind(ITF::VDS_E_DUPLICATE_DISK),
            ITF::VDS_E_LAST_VALID_DISK => RawError::Kind(ITF::VDS_E_LAST_VALID_DISK),
            ITF::VDS_E_INVALID_SECTOR_SIZE => RawError::Kind(ITF::VDS_E_INVALID_SECTOR_SIZE),
            ITF::VDS_E_ONE_EXTENT_PER_DISK => RawError::Kind(ITF::VDS_E_ONE_EXTENT_PER_DISK),
            ITF::VDS_E_INVALID_BLOCK_SIZE => RawError::Kind(ITF::VDS_E_INVALID_BLOCK_SIZE),
            ITF::VDS_E_PLEX_SIZE_INVALID => RawError::Kind(ITF::VDS_E_PLEX_SIZE_INVALID),
            ITF::VDS_E_NO_EXTENTS_FOR_PLEX => RawError::Kind(ITF::VDS_E_NO_EXTENTS_FOR_PLEX),
            ITF::VDS_E_INVALID_PLEX_TYPE => RawError::Kind(ITF::VDS_E_INVALID_PLEX_TYPE),
            ITF::VDS_E_INVALID_PLEX_BLOCK_SIZE => RawError::Kind(ITF::VDS_E_INVALID_PLEX_BLOCK_SIZE),
            ITF::VDS_E_NO_HEALTHY_DISKS => RawError::Kind(ITF::VDS_E_NO_HEALTHY_DISKS),
            ITF::VDS_E_CONFIG_LIMIT => RawError::Kind(ITF::VDS_E_CONFIG_LIMIT),
            ITF::VDS_E_DISK_CONFIGURATION_CORRUPTED => RawError::Kind(ITF::VDS_E_DISK_CONFIGURATION_CORRUPTED),
            ITF::VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC => RawError::Kind(ITF::VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC),
            ITF::VDS_E_DISK_CONFIGURATION_UPDATE_FAILED => RawError::Kind(ITF::VDS_E_DISK_CONFIGURATION_UPDATE_FAILED),
            ITF::VDS_E_DISK_DYNAMIC => RawError::Kind(ITF::VDS_E_DISK_DYNAMIC),
            ITF::VDS_E_DRIVER_OBJECT_NOT_FOUND => RawError::Kind(ITF::VDS_E_DRIVER_OBJECT_NOT_FOUND),
            ITF::VDS_E_PARTITION_NOT_CYLINDER_ALIGNED => RawError::Kind(ITF::VDS_E_PARTITION_NOT_CYLINDER_ALIGNED),
            ITF::VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL => RawError::Kind(ITF::VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL),
            ITF::VDS_E_DISK_IO_FAILING => RawError::Kind(ITF::VDS_E_DISK_IO_FAILING),
            ITF::VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED),
            ITF::VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED),
            ITF::VDS_E_GPT_ATTRIBUTES_INVALID => RawError::Kind(ITF::VDS_E_GPT_ATTRIBUTES_INVALID),
            ITF::VDS_E_MEMBER_IS_HEALTHY => RawError::Kind(ITF::VDS_E_MEMBER_IS_HEALTHY),
            ITF::VDS_E_MEMBER_REGENERATING => RawError::Kind(ITF::VDS_E_MEMBER_REGENERATING),
            ITF::VDS_E_PACK_NAME_INVALID => RawError::Kind(ITF::VDS_E_PACK_NAME_INVALID),
            ITF::VDS_E_PLEX_IS_HEALTHY => RawError::Kind(ITF::VDS_E_PLEX_IS_HEALTHY),
            ITF::VDS_E_PLEX_LAST_ACTIVE => RawError::Kind(ITF::VDS_E_PLEX_LAST_ACTIVE),
            ITF::VDS_E_PLEX_MISSING => RawError::Kind(ITF::VDS_E_PLEX_MISSING),
            ITF::VDS_E_MEMBER_MISSING => RawError::Kind(ITF::VDS_E_MEMBER_MISSING),
            ITF::VDS_E_PLEX_REGENERATING => RawError::Kind(ITF::VDS_E_PLEX_REGENERATING),
            ITF::VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE => RawError::Kind(ITF::VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE),
            ITF::VDS_E_INVALID_VOLUME_LENGTH => RawError::Kind(ITF::VDS_E_INVALID_VOLUME_LENGTH),
            ITF::VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE => RawError::Kind(ITF::VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE),
            ITF::VDS_E_VOLUME_NOT_RETAINED => RawError::Kind(ITF::VDS_E_VOLUME_NOT_RETAINED),
            ITF::VDS_E_VOLUME_RETAINED => RawError::Kind(ITF::VDS_E_VOLUME_RETAINED),
            ITF::VDS_E_ALIGN_BEYOND_FIRST_CYLINDER => RawError::Kind(ITF::VDS_E_ALIGN_BEYOND_FIRST_CYLINDER),
            ITF::VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE => RawError::Kind(ITF::VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE),
            ITF::VDS_E_ALIGN_NOT_ZERO => RawError::Kind(ITF::VDS_E_ALIGN_NOT_ZERO),
            ITF::VDS_E_CACHE_CORRUPT => RawError::Kind(ITF::VDS_E_CACHE_CORRUPT),
            ITF::VDS_E_CANNOT_CLEAR_VOLUME_FLAG => RawError::Kind(ITF::VDS_E_CANNOT_CLEAR_VOLUME_FLAG),
            ITF::VDS_E_DISK_BEING_CLEANED => RawError::Kind(ITF::VDS_E_DISK_BEING_CLEANED),
            ITF::VDS_E_DISK_NOT_CONVERTIBLE => RawError::Kind(ITF::VDS_E_DISK_NOT_CONVERTIBLE),
            ITF::VDS_E_DISK_REMOVEABLE => RawError::Kind(ITF::VDS_E_DISK_REMOVEABLE),
            ITF::VDS_E_DISK_REMOVEABLE_NOT_EMPTY => RawError::Kind(ITF::VDS_E_DISK_REMOVEABLE_NOT_EMPTY),
            ITF::VDS_E_DRIVE_LETTER_NOT_FREE => RawError::Kind(ITF::VDS_E_DRIVE_LETTER_NOT_FREE),
            ITF::VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED),
            ITF::VDS_E_INVALID_DRIVE_LETTER => RawError::Kind(ITF::VDS_E_INVALID_DRIVE_LETTER),
            ITF::VDS_E_INVALID_DRIVE_LETTER_COUNT => RawError::Kind(ITF::VDS_E_INVALID_DRIVE_LETTER_COUNT),
            ITF::VDS_E_INVALID_FS_FLAG => RawError::Kind(ITF::VDS_E_INVALID_FS_FLAG),
            ITF::VDS_E_INVALID_FS_TYPE => RawError::Kind(ITF::VDS_E_INVALID_FS_TYPE),
            ITF::VDS_E_INVALID_OBJECT_TYPE => RawError::Kind(ITF::VDS_E_INVALID_OBJECT_TYPE),
            ITF::VDS_E_INVALID_PARTITION_LAYOUT => RawError::Kind(ITF::VDS_E_INVALID_PARTITION_LAYOUT),
            ITF::VDS_E_INVALID_PARTITION_STYLE => RawError::Kind(ITF::VDS_E_INVALID_PARTITION_STYLE),
            ITF::VDS_E_INVALID_PARTITION_TYPE => RawError::Kind(ITF::VDS_E_INVALID_PARTITION_TYPE),
            ITF::VDS_E_INVALID_PROVIDER_CLSID => RawError::Kind(ITF::VDS_E_INVALID_PROVIDER_CLSID),
            ITF::VDS_E_INVALID_PROVIDER_ID => RawError::Kind(ITF::VDS_E_INVALID_PROVIDER_ID),
            ITF::VDS_E_INVALID_PROVIDER_NAME => RawError::Kind(ITF::VDS_E_INVALID_PROVIDER_NAME),
            ITF::VDS_E_INVALID_PROVIDER_TYPE => RawError::Kind(ITF::VDS_E_INVALID_PROVIDER_TYPE),
            ITF::VDS_E_INVALID_PROVIDER_VERSION_GUID => RawError::Kind(ITF::VDS_E_INVALID_PROVIDER_VERSION_GUID),
            ITF::VDS_E_INVALID_PROVIDER_VERSION_STRING => RawError::Kind(ITF::VDS_E_INVALID_PROVIDER_VERSION_STRING),
            ITF::VDS_E_INVALID_QUERY_PROVIDER_FLAG => RawError::Kind(ITF::VDS_E_INVALID_QUERY_PROVIDER_FLAG),
            ITF::VDS_E_INVALID_SERVICE_FLAG => RawError::Kind(ITF::VDS_E_INVALID_SERVICE_FLAG),
            ITF::VDS_E_INVALID_VOLUME_FLAG => RawError::Kind(ITF::VDS_E_INVALID_VOLUME_FLAG),
            ITF::VDS_E_PARTITION_NOT_OEM => RawError::Kind(ITF::VDS_E_PARTITION_NOT_OEM),
            ITF::VDS_E_PARTITION_PROTECTED => RawError::Kind(ITF::VDS_E_PARTITION_PROTECTED),
            ITF::VDS_E_PARTITION_STYLE_MISMATCH => RawError::Kind(ITF::VDS_E_PARTITION_STYLE_MISMATCH),
            ITF::VDS_E_PROVIDER_INTERNAL_ERROR => RawError::Kind(ITF::VDS_E_PROVIDER_INTERNAL_ERROR),
            ITF::VDS_E_SHRINK_SIZE_LESS_THAN_MIN => RawError::Kind(ITF::VDS_E_SHRINK_SIZE_LESS_THAN_MIN),
            ITF::VDS_E_SHRINK_SIZE_TOO_BIG => RawError::Kind(ITF::VDS_E_SHRINK_SIZE_TOO_BIG),
            ITF::VDS_E_UNRECOVERABLE_PROVIDER_ERROR => RawError::Kind(ITF::VDS_E_UNRECOVERABLE_PROVIDER_ERROR),
            ITF::VDS_E_VOLUME_HIDDEN => RawError::Kind(ITF::VDS_E_VOLUME_HIDDEN),
            ITF::VDS_E_FLAG_ALREADY_SET => RawError::Kind(ITF::VDS_E_FLAG_ALREADY_SET),
            ITF::VDS_E_DISTINCT_VOLUME => RawError::Kind(ITF::VDS_E_DISTINCT_VOLUME),
            ITF::VDS_E_VOLUME_NOT_FOUND_IN_PACK => RawError::Kind(ITF::VDS_E_VOLUME_NOT_FOUND_IN_PACK),
            ITF::VDS_E_PARTITION_NON_DATA => RawError::Kind(ITF::VDS_E_PARTITION_NON_DATA),
            ITF::VDS_E_CRITICAL_PLEX => RawError::Kind(ITF::VDS_E_CRITICAL_PLEX),
            ITF::VDS_E_VOLUME_SYNCHRONIZING => RawError::Kind(ITF::VDS_E_VOLUME_SYNCHRONIZING),
            ITF::VDS_E_VOLUME_REGENERATING => RawError::Kind(ITF::VDS_E_VOLUME_REGENERATING),
            ITF::VDS_E_READONLY => RawError::Kind(ITF::VDS_E_READONLY),
            ITF::VDS_E_INVALID_VOLUME_TYPE => RawError::Kind(ITF::VDS_E_INVALID_VOLUME_TYPE),
            ITF::VDS_E_BAD_BOOT_DISK => RawError::Kind(ITF::VDS_E_BAD_BOOT_DISK),
            ITF::VDS_E_LOG_UPDATE => RawError::Kind(ITF::VDS_E_LOG_UPDATE),
            ITF::VDS_E_VOLUME_MIRRORED => RawError::Kind(ITF::VDS_E_VOLUME_MIRRORED),
            ITF::VDS_E_VOLUME_SIMPLE_SPANNED => RawError::Kind(ITF::VDS_E_VOLUME_SIMPLE_SPANNED),
            ITF::VDS_E_NO_VALID_LOG_COPIES => RawError::Kind(ITF::VDS_E_NO_VALID_LOG_COPIES),
            ITF::VDS_E_PLEX_NOT_LOADED_TO_CACHE => RawError::Kind(ITF::VDS_E_PLEX_NOT_LOADED_TO_CACHE),
            ITF::VDS_E_PARTITION_MSR => RawError::Kind(ITF::VDS_E_PARTITION_MSR),
            ITF::VDS_E_PARTITION_LDM => RawError::Kind(ITF::VDS_E_PARTITION_LDM),
            ITF::VDS_E_ALIGN_NOT_A_POWER_OF_TWO => RawError::Kind(ITF::VDS_E_ALIGN_NOT_A_POWER_OF_TWO),
            ITF::VDS_E_ALIGN_IS_ZERO => RawError::Kind(ITF::VDS_E_ALIGN_IS_ZERO),
            ITF::VDS_E_SHRINK_IN_PROGRESS => RawError::Kind(ITF::VDS_E_SHRINK_IN_PROGRESS),
            ITF::VDS_E_CANT_INVALIDATE_FVE => RawError::Kind(ITF::VDS_E_CANT_INVALIDATE_FVE),
            ITF::VDS_E_FS_NOT_DETERMINED => RawError::Kind(ITF::VDS_E_FS_NOT_DETERMINED),
            ITF::VDS_E_DISK_NOT_OFFLINE => RawError::Kind(ITF::VDS_E_DISK_NOT_OFFLINE),
            ITF::VDS_E_FAILED_TO_ONLINE_DISK => RawError::Kind(ITF::VDS_E_FAILED_TO_ONLINE_DISK),
            ITF::VDS_E_FAILED_TO_OFFLINE_DISK => RawError::Kind(ITF::VDS_E_FAILED_TO_OFFLINE_DISK),
            ITF::VDS_E_BAD_REVISION_NUMBER => RawError::Kind(ITF::VDS_E_BAD_REVISION_NUMBER),
            ITF::VDS_E_SHRINK_USER_CANCELLED => RawError::Kind(ITF::VDS_E_SHRINK_USER_CANCELLED),
            ITF::VDS_E_SHRINK_DIRTY_VOLUME => RawError::Kind(ITF::VDS_E_SHRINK_DIRTY_VOLUME),
            ITF::NOTESPH_E_UNEXPECTED_STATE => RawError::Kind(ITF::NOTESPH_E_UNEXPECTED_STATE),
            ITF::NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE => RawError::Kind(ITF::NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE),
            ITF::NOTESPH_E_ITEM_NOT_FOUND => RawError::Kind(ITF::NOTESPH_E_ITEM_NOT_FOUND),
            ITF::NOTESPH_E_SERVER_CONFIG => RawError::Kind(ITF::NOTESPH_E_SERVER_CONFIG),
            ITF::NOTESPH_E_ATTACHMENTS => RawError::Kind(ITF::NOTESPH_E_ATTACHMENTS),
            ITF::NOTESPH_E_NO_NTID => RawError::Kind(ITF::NOTESPH_E_NO_NTID),
            ITF::NOTESPH_E_DB_ACCESS_DENIED => RawError::Kind(ITF::NOTESPH_E_DB_ACCESS_DENIED),
            ITF::NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR => RawError::Kind(ITF::NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR),
            ITF::NOTESPH_E_FAIL => RawError::Kind(ITF::NOTESPH_E_FAIL),
            ITF::STS_ABORTXMLPARSE => RawError::Kind(ITF::STS_ABORTXMLPARSE),
            ITF::STS_WS_ERROR => RawError::Kind(ITF::STS_WS_ERROR),
            ITF::SPS_WS_ERROR => RawError::Kind(ITF::SPS_WS_ERROR),
            ITF::EXSTOREPH_E_UNEXPECTED => RawError::Kind(ITF::EXSTOREPH_E_UNEXPECTED),
            ITF::VDS_E_NAME_NOT_UNIQUE => RawError::Kind(ITF::VDS_E_NAME_NOT_UNIQUE),
            ITF::VDS_E_ADDRESSES_INCOMPLETELY_SET => RawError::Kind(ITF::VDS_E_ADDRESSES_INCOMPLETELY_SET),
            ITF::VDS_E_SECURITY_INCOMPLETELY_SET => RawError::Kind(ITF::VDS_E_SECURITY_INCOMPLETELY_SET),
            ITF::VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED),
            ITF::VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED),
            ITF::VDS_E_ISCSI_LOGIN_FAILED => RawError::Kind(ITF::VDS_E_ISCSI_LOGIN_FAILED),
            ITF::VDS_E_ISCSI_LOGOUT_FAILED => RawError::Kind(ITF::VDS_E_ISCSI_LOGOUT_FAILED),
            ITF::VDS_E_ISCSI_SESSION_NOT_FOUND => RawError::Kind(ITF::VDS_E_ISCSI_SESSION_NOT_FOUND),
            ITF::VDS_E_ASSOCIATED_LUNS_EXIST => RawError::Kind(ITF::VDS_E_ASSOCIATED_LUNS_EXIST),
            ITF::VDS_E_ASSOCIATED_PORTALS_EXIST => RawError::Kind(ITF::VDS_E_ASSOCIATED_PORTALS_EXIST),
            ITF::VDS_E_NO_DISCOVERY_DOMAIN => RawError::Kind(ITF::VDS_E_NO_DISCOVERY_DOMAIN),
            ITF::VDS_E_MULTIPLE_DISCOVERY_DOMAINS => RawError::Kind(ITF::VDS_E_MULTIPLE_DISCOVERY_DOMAINS),
            ITF::VDS_E_NO_DISK_PATHNAME => RawError::Kind(ITF::VDS_E_NO_DISK_PATHNAME),
            ITF::VDS_E_ISCSI_LOGOUT_INCOMPLETE => RawError::Kind(ITF::VDS_E_ISCSI_LOGOUT_INCOMPLETE),
            ITF::VDS_E_NO_VOLUME_PATHNAME => RawError::Kind(ITF::VDS_E_NO_VOLUME_PATHNAME),
            ITF::VDS_E_PROVIDER_CACHE_OUTOFSYNC => RawError::Kind(ITF::VDS_E_PROVIDER_CACHE_OUTOFSYNC),
            ITF::VDS_E_NO_IMPORT_TARGET => RawError::Kind(ITF::VDS_E_NO_IMPORT_TARGET),
            ITF::CERT_E_NOT_FOUND_OR_NO_PERMISSSION => RawError::Kind(ITF::CERT_E_NOT_FOUND_OR_NO_PERMISSSION),
            ITF::VDS_E_UNABLE_TO_FIND_BOOT_DISK => RawError::Kind(ITF::VDS_E_UNABLE_TO_FIND_BOOT_DISK),
            ITF::VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO => RawError::Kind(ITF::VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO),
            ITF::VDS_E_GET_SAN_POLICY => RawError::Kind(ITF::VDS_E_GET_SAN_POLICY),
            ITF::VDS_E_SET_SAN_POLICY => RawError::Kind(ITF::VDS_E_SET_SAN_POLICY),
            ITF::VDS_E_BOOT_DISK => RawError::Kind(ITF::VDS_E_BOOT_DISK),
            ITF::VDS_E_DISK_IS_OFFLINE => RawError::Kind(ITF::VDS_E_DISK_IS_OFFLINE),
            ITF::VDS_E_DISK_IS_READ_ONLY => RawError::Kind(ITF::VDS_E_DISK_IS_READ_ONLY),
            ITF::VDS_E_PAGEFILE_DISK => RawError::Kind(ITF::VDS_E_PAGEFILE_DISK),
            ITF::VDS_E_HIBERNATION_FILE_DISK => RawError::Kind(ITF::VDS_E_HIBERNATION_FILE_DISK),
            ITF::VDS_E_CRASHDUMP_DISK => RawError::Kind(ITF::VDS_E_CRASHDUMP_DISK),
            ITF::VDS_E_UNABLE_TO_FIND_SYSTEM_DISK => RawError::Kind(ITF::VDS_E_UNABLE_TO_FIND_SYSTEM_DISK),
            ITF::VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO => RawError::Kind(ITF::VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO),
            ITF::VDS_E_SYSTEM_DISK => RawError::Kind(ITF::VDS_E_SYSTEM_DISK),
            ITF::VDS_E_VOLUME_SHRINK_FVE_LOCKED => RawError::Kind(ITF::VDS_E_VOLUME_SHRINK_FVE_LOCKED),
            ITF::VDS_E_VOLUME_SHRINK_FVE_CORRUPT => RawError::Kind(ITF::VDS_E_VOLUME_SHRINK_FVE_CORRUPT),
            ITF::VDS_E_VOLUME_SHRINK_FVE_RECOVERY => RawError::Kind(ITF::VDS_E_VOLUME_SHRINK_FVE_RECOVERY),
            ITF::VDS_E_VOLUME_SHRINK_FVE => RawError::Kind(ITF::VDS_E_VOLUME_SHRINK_FVE),
            ITF::VDS_E_SHRINK_OVER_DATA => RawError::Kind(ITF::VDS_E_SHRINK_OVER_DATA),
            ITF::VDS_E_INVALID_SHRINK_SIZE => RawError::Kind(ITF::VDS_E_INVALID_SHRINK_SIZE),
            ITF::VDS_E_LUN_DISK_MISSING => RawError::Kind(ITF::VDS_E_LUN_DISK_MISSING),
            ITF::VDS_E_LUN_DISK_FAILED => RawError::Kind(ITF::VDS_E_LUN_DISK_FAILED),
            ITF::VDS_E_LUN_DISK_NOT_READY => RawError::Kind(ITF::VDS_E_LUN_DISK_NOT_READY),
            ITF::VDS_E_LUN_DISK_NO_MEDIA => RawError::Kind(ITF::VDS_E_LUN_DISK_NO_MEDIA),
            ITF::VDS_E_LUN_NOT_READY => RawError::Kind(ITF::VDS_E_LUN_NOT_READY),
            ITF::VDS_E_LUN_OFFLINE => RawError::Kind(ITF::VDS_E_LUN_OFFLINE),
            ITF::VDS_E_LUN_FAILED => RawError::Kind(ITF::VDS_E_LUN_FAILED),
            ITF::VDS_E_VOLUME_EXTEND_FVE_LOCKED => RawError::Kind(ITF::VDS_E_VOLUME_EXTEND_FVE_LOCKED),
            ITF::VDS_E_VOLUME_EXTEND_FVE_CORRUPT => RawError::Kind(ITF::VDS_E_VOLUME_EXTEND_FVE_CORRUPT),
            ITF::VDS_E_VOLUME_EXTEND_FVE_RECOVERY => RawError::Kind(ITF::VDS_E_VOLUME_EXTEND_FVE_RECOVERY),
            ITF::VDS_E_VOLUME_EXTEND_FVE => RawError::Kind(ITF::VDS_E_VOLUME_EXTEND_FVE),
            ITF::VDS_E_SECTOR_SIZE_ERROR => RawError::Kind(ITF::VDS_E_SECTOR_SIZE_ERROR),
            ITF::VDS_E_INITIATOR_ADAPTER_NOT_FOUND => RawError::Kind(ITF::VDS_E_INITIATOR_ADAPTER_NOT_FOUND),
            ITF::VDS_E_TARGET_PORTAL_NOT_FOUND => RawError::Kind(ITF::VDS_E_TARGET_PORTAL_NOT_FOUND),
            ITF::VDS_E_INVALID_PORT_PATH => RawError::Kind(ITF::VDS_E_INVALID_PORT_PATH),
            ITF::VDS_E_INVALID_ISCSI_TARGET_NAME => RawError::Kind(ITF::VDS_E_INVALID_ISCSI_TARGET_NAME),
            ITF::VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS => RawError::Kind(ITF::VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS),
            ITF::VDS_E_ISCSI_GET_IKE_INFO => RawError::Kind(ITF::VDS_E_ISCSI_GET_IKE_INFO),
            ITF::VDS_E_ISCSI_SET_IKE_INFO => RawError::Kind(ITF::VDS_E_ISCSI_SET_IKE_INFO),
            ITF::VDS_E_SUBSYSTEM_ID_IS_NULL => RawError::Kind(ITF::VDS_E_SUBSYSTEM_ID_IS_NULL),
            ITF::VDS_E_ISCSI_INITIATOR_NODE_NAME => RawError::Kind(ITF::VDS_E_ISCSI_INITIATOR_NODE_NAME),
            ITF::VDS_E_ISCSI_GROUP_PRESHARE_KEY => RawError::Kind(ITF::VDS_E_ISCSI_GROUP_PRESHARE_KEY),
            ITF::VDS_E_ISCSI_CHAP_SECRET => RawError::Kind(ITF::VDS_E_ISCSI_CHAP_SECRET),
            ITF::VDS_E_INVALID_IP_ADDRESS => RawError::Kind(ITF::VDS_E_INVALID_IP_ADDRESS),
            ITF::VDS_E_REBOOT_REQUIRED => RawError::Kind(ITF::VDS_E_REBOOT_REQUIRED),
            ITF::VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED => RawError::Kind(ITF::VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED),
            ITF::VDS_E_BOOT_PAGEFILE_DRIVE_LETTER => RawError::Kind(ITF::VDS_E_BOOT_PAGEFILE_DRIVE_LETTER),
            ITF::VDS_E_DELETE_WITH_CRITICAL => RawError::Kind(ITF::VDS_E_DELETE_WITH_CRITICAL),
            ITF::VDS_E_CLEAN_WITH_DATA => RawError::Kind(ITF::VDS_E_CLEAN_WITH_DATA),
            ITF::VDS_E_CLEAN_WITH_OEM => RawError::Kind(ITF::VDS_E_CLEAN_WITH_OEM),
            ITF::VDS_E_CLEAN_WITH_CRITICAL => RawError::Kind(ITF::VDS_E_CLEAN_WITH_CRITICAL),
            ITF::VDS_E_FORMAT_CRITICAL => RawError::Kind(ITF::VDS_E_FORMAT_CRITICAL),
            ITF::VDS_E_NTFS_FORMAT_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_NTFS_FORMAT_NOT_SUPPORTED),
            ITF::VDS_E_FAT32_FORMAT_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_FAT32_FORMAT_NOT_SUPPORTED),
            ITF::VDS_E_FAT_FORMAT_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_FAT_FORMAT_NOT_SUPPORTED),
            ITF::VDS_E_FORMAT_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_FORMAT_NOT_SUPPORTED),
            ITF::VDS_E_COMPRESSION_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_COMPRESSION_NOT_SUPPORTED),
            ITF::VDS_E_VDISK_NOT_OPEN => RawError::Kind(ITF::VDS_E_VDISK_NOT_OPEN),
            ITF::VDS_E_VDISK_INVALID_OP_STATE => RawError::Kind(ITF::VDS_E_VDISK_INVALID_OP_STATE),
            ITF::VDS_E_INVALID_PATH => RawError::Kind(ITF::VDS_E_INVALID_PATH),
            ITF::VDS_E_INVALID_ISCSI_PATH => RawError::Kind(ITF::VDS_E_INVALID_ISCSI_PATH),
            ITF::VDS_E_SHRINK_LUN_NOT_UNMASKED => RawError::Kind(ITF::VDS_E_SHRINK_LUN_NOT_UNMASKED),
            ITF::VDS_E_LUN_DISK_READ_ONLY => RawError::Kind(ITF::VDS_E_LUN_DISK_READ_ONLY),
            ITF::VDS_E_LUN_UPDATE_DISK => RawError::Kind(ITF::VDS_E_LUN_UPDATE_DISK),
            ITF::VDS_E_LUN_DYNAMIC => RawError::Kind(ITF::VDS_E_LUN_DYNAMIC),
            ITF::VDS_E_LUN_DYNAMIC_OFFLINE => RawError::Kind(ITF::VDS_E_LUN_DYNAMIC_OFFLINE),
            ITF::VDS_E_LUN_SHRINK_GPT_HEADER => RawError::Kind(ITF::VDS_E_LUN_SHRINK_GPT_HEADER),
            ITF::VDS_E_MIRROR_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_MIRROR_NOT_SUPPORTED),
            ITF::VDS_E_RAID5_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_RAID5_NOT_SUPPORTED),
            ITF::VDS_E_DISK_NOT_CONVERTIBLE_SIZE => RawError::Kind(ITF::VDS_E_DISK_NOT_CONVERTIBLE_SIZE),
            ITF::VDS_E_OFFLINE_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_OFFLINE_NOT_SUPPORTED),
            ITF::VDS_E_VDISK_PATHNAME_INVALID => RawError::Kind(ITF::VDS_E_VDISK_PATHNAME_INVALID),
            ITF::VDS_E_EXTEND_TOO_MANY_CLUSTERS => RawError::Kind(ITF::VDS_E_EXTEND_TOO_MANY_CLUSTERS),
            ITF::VDS_E_EXTEND_UNKNOWN_FILESYSTEM => RawError::Kind(ITF::VDS_E_EXTEND_UNKNOWN_FILESYSTEM),
            ITF::VDS_E_SHRINK_UNKNOWN_FILESYSTEM => RawError::Kind(ITF::VDS_E_SHRINK_UNKNOWN_FILESYSTEM),
            ITF::VDS_E_VD_DISK_NOT_OPEN => RawError::Kind(ITF::VDS_E_VD_DISK_NOT_OPEN),
            ITF::VDS_E_VD_DISK_IS_EXPANDING => RawError::Kind(ITF::VDS_E_VD_DISK_IS_EXPANDING),
            ITF::VDS_E_VD_DISK_IS_COMPACTING => RawError::Kind(ITF::VDS_E_VD_DISK_IS_COMPACTING),
            ITF::VDS_E_VD_DISK_IS_MERGING => RawError::Kind(ITF::VDS_E_VD_DISK_IS_MERGING),
            ITF::VDS_E_VD_IS_ATTACHED => RawError::Kind(ITF::VDS_E_VD_IS_ATTACHED),
            ITF::VDS_E_VD_DISK_ALREADY_OPEN => RawError::Kind(ITF::VDS_E_VD_DISK_ALREADY_OPEN),
            ITF::VDS_E_VD_DISK_ALREADY_EXPANDING => RawError::Kind(ITF::VDS_E_VD_DISK_ALREADY_EXPANDING),
            ITF::VDS_E_VD_ALREADY_COMPACTING => RawError::Kind(ITF::VDS_E_VD_ALREADY_COMPACTING),
            ITF::VDS_E_VD_ALREADY_MERGING => RawError::Kind(ITF::VDS_E_VD_ALREADY_MERGING),
            ITF::VDS_E_VD_ALREADY_ATTACHED => RawError::Kind(ITF::VDS_E_VD_ALREADY_ATTACHED),
            ITF::VDS_E_VD_ALREADY_DETACHED => RawError::Kind(ITF::VDS_E_VD_ALREADY_DETACHED),
            ITF::VDS_E_VD_NOT_ATTACHED_READONLY => RawError::Kind(ITF::VDS_E_VD_NOT_ATTACHED_READONLY),
            ITF::VDS_E_VD_IS_BEING_ATTACHED => RawError::Kind(ITF::VDS_E_VD_IS_BEING_ATTACHED),
            ITF::VDS_E_VD_IS_BEING_DETACHED => RawError::Kind(ITF::VDS_E_VD_IS_BEING_DETACHED),
            ITF::VDS_E_NO_POOL => RawError::Kind(ITF::VDS_E_NO_POOL),
            ITF::VDS_E_NO_POOL_CREATED => RawError::Kind(ITF::VDS_E_NO_POOL_CREATED),
            ITF::VDS_E_NO_MAINTENANCE_MODE => RawError::Kind(ITF::VDS_E_NO_MAINTENANCE_MODE),
            ITF::VDS_E_BLOCK_CLUSTERED => RawError::Kind(ITF::VDS_E_BLOCK_CLUSTERED),
            ITF::VDS_E_DISK_HAS_BANDS => RawError::Kind(ITF::VDS_E_DISK_HAS_BANDS),
            ITF::VDS_E_INVALID_STATE => RawError::Kind(ITF::VDS_E_INVALID_STATE),
            ITF::VDS_E_REFS_FORMAT_NOT_SUPPORTED => RawError::Kind(ITF::VDS_E_REFS_FORMAT_NOT_SUPPORTED),
            ITF::VDS_E_DELETE_WITH_BOOTBACKING => RawError::Kind(ITF::VDS_E_DELETE_WITH_BOOTBACKING),
            ITF::VDS_E_FORMAT_WITH_BOOTBACKING => RawError::Kind(ITF::VDS_E_FORMAT_WITH_BOOTBACKING),
            ITF::VDS_E_CLEAN_WITH_BOOTBACKING => RawError::Kind(ITF::VDS_E_CLEAN_WITH_BOOTBACKING),
            ITF::SRCH_SCHEMA_CACHE_E_UNEXPECTED => RawError::Kind(ITF::SRCH_SCHEMA_CACHE_E_UNEXPECTED),
            ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_READ => RawError::Kind(ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_READ),
            ITF::CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER => RawError::Kind(ITF::CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER),
            ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE => RawError::Kind(ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE),
            ITF::CONTENT_SOURCE_E_CONTENT_CLASS_READ => RawError::Kind(ITF::CONTENT_SOURCE_E_CONTENT_CLASS_READ),
            ITF::CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION => RawError::Kind(ITF::CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION),
            ITF::CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR => RawError::Kind(ITF::CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR),
            ITF::CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE => RawError::Kind(ITF::CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE),
            ITF::CONTENT_SOURCE_E_OUT_OF_RANGE => RawError::Kind(ITF::CONTENT_SOURCE_E_OUT_OF_RANGE),
            ITF::CONTENT_SOURCE_E_NULL_URI => RawError::Kind(ITF::CONTENT_SOURCE_E_NULL_URI),
            ITF::REXSPH_E_INVALID_CALL => RawError::Kind(ITF::REXSPH_E_INVALID_CALL),
            ITF::REXSPH_E_REDIRECT_ON_SECURITY_UPDATE => RawError::Kind(ITF::REXSPH_E_REDIRECT_ON_SECURITY_UPDATE),
            ITF::REXSPH_E_MULTIPLE_REDIRECT => RawError::Kind(ITF::REXSPH_E_MULTIPLE_REDIRECT),
            ITF::REXSPH_E_NO_PROPERTY_ON_ROW => RawError::Kind(ITF::REXSPH_E_NO_PROPERTY_ON_ROW),
            ITF::REXSPH_E_TYPE_MISMATCH_ON_READ => RawError::Kind(ITF::REXSPH_E_TYPE_MISMATCH_ON_READ),
            ITF::REXSPH_E_UNEXPECTED_DATA_STATUS => RawError::Kind(ITF::REXSPH_E_UNEXPECTED_DATA_STATUS),
            ITF::REXSPH_E_UNKNOWN_DATA_TYPE => RawError::Kind(ITF::REXSPH_E_UNKNOWN_DATA_TYPE),
            ITF::REXSPH_E_UNEXPECTED_FILTER_STATE => RawError::Kind(ITF::REXSPH_E_UNEXPECTED_FILTER_STATE),
            ITF::REXSPH_E_DUPLICATE_PROPERTY => RawError::Kind(ITF::REXSPH_E_DUPLICATE_PROPERTY),
            ITF::FTE_E_SECRET_NOT_FOUND => RawError::Kind(ITF::FTE_E_SECRET_NOT_FOUND),
            ITF::FTE_E_PIPE_NOT_CONNECTED => RawError::Kind(ITF::FTE_E_PIPE_NOT_CONNECTED),
            ITF::FTE_E_ADMIN_BLOB_CORRUPT => RawError::Kind(ITF::FTE_E_ADMIN_BLOB_CORRUPT),
            ITF::FTE_E_FILTER_SINGLE_THREADED => RawError::Kind(ITF::FTE_E_FILTER_SINGLE_THREADED),
            ITF::FTE_E_ERROR_WRITING_REGISTRY => RawError::Kind(ITF::FTE_E_ERROR_WRITING_REGISTRY),
            ITF::FTE_E_PROJECT_SHUTDOWN => RawError::Kind(ITF::FTE_E_PROJECT_SHUTDOWN),
            ITF::FTE_E_PROJECT_NOT_INITALIZED => RawError::Kind(ITF::FTE_E_PROJECT_NOT_INITALIZED),
            ITF::FTE_E_PIPE_DATA_CORRUPTED => RawError::Kind(ITF::FTE_E_PIPE_DATA_CORRUPTED),
            ITF::FTE_E_URB_TOO_BIG => RawError::Kind(ITF::FTE_E_URB_TOO_BIG),
            ITF::FTE_E_INVALID_DOCID => RawError::Kind(ITF::FTE_E_INVALID_DOCID),
            ITF::FTE_E_PAUSE_EXTERNAL => RawError::Kind(ITF::FTE_E_PAUSE_EXTERNAL),
            ITF::FTE_E_REJECTED_DUE_TO_PROJECT_STATUS => RawError::Kind(ITF::FTE_E_REJECTED_DUE_TO_PROJECT_STATUS),
            ITF::FTE_E_FD_DID_NOT_CONNECT => RawError::Kind(ITF::FTE_E_FD_DID_NOT_CONNECT),
            ITF::FTE_E_PROGID_REQUIRED => RawError::Kind(ITF::FTE_E_PROGID_REQUIRED),
            ITF::FTE_E_STATIC_THREAD_INVALID_ARGUMENTS => RawError::Kind(ITF::FTE_E_STATIC_THREAD_INVALID_ARGUMENTS),
            ITF::FTE_E_CATALOG_ALREADY_EXISTS => RawError::Kind(ITF::FTE_E_CATALOG_ALREADY_EXISTS),
            ITF::FTE_E_PATH_TOO_LONG => RawError::Kind(ITF::FTE_E_PATH_TOO_LONG),
            ITF::FTE_INVALID_ADMIN_CLIENT => RawError::Kind(ITF::FTE_INVALID_ADMIN_CLIENT),
            ITF::FTE_E_COM_SIGNATURE_VALIDATION => RawError::Kind(ITF::FTE_E_COM_SIGNATURE_VALIDATION),
            ITF::FTE_E_AFFINITY_MASK => RawError::Kind(ITF::FTE_E_AFFINITY_MASK),
            ITF::FTE_E_FD_OWNERSHIP_OBSOLETE => RawError::Kind(ITF::FTE_E_FD_OWNERSHIP_OBSOLETE),
            ITF::FTE_E_EXCEEDED_MAX_PLUGINS => RawError::Kind(ITF::FTE_E_EXCEEDED_MAX_PLUGINS),
            ITF::FTE_E_DUPLICATE_OBJECT => RawError::Kind(ITF::FTE_E_DUPLICATE_OBJECT),
            ITF::FTE_E_REDUNDANT_TRAN_FAILURE => RawError::Kind(ITF::FTE_E_REDUNDANT_TRAN_FAILURE),
            ITF::FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST => RawError::Kind(ITF::FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST),
            ITF::FTE_E_FD_SHUTDOWN => RawError::Kind(ITF::FTE_E_FD_SHUTDOWN),
            ITF::FTE_E_CATALOG_DOES_NOT_EXIST => RawError::Kind(ITF::FTE_E_CATALOG_DOES_NOT_EXIST),
            ITF::FTE_E_NO_PLUGINS => RawError::Kind(ITF::FTE_E_NO_PLUGINS),
            ITF::FTE_E_BATCH_ABORTED => RawError::Kind(ITF::FTE_E_BATCH_ABORTED),
            ITF::FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE => RawError::Kind(ITF::FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE),
            ITF::FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS => RawError::Kind(ITF::FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS),
            ITF::FTE_E_FD_TIMEOUT => RawError::Kind(ITF::FTE_E_FD_TIMEOUT),
            ITF::FTE_E_RESOURCE_SHUTDOWN => RawError::Kind(ITF::FTE_E_RESOURCE_SHUTDOWN),
            ITF::FTE_E_INVALID_PROPERTY => RawError::Kind(ITF::FTE_E_INVALID_PROPERTY),
            ITF::FTE_E_NO_MORE_PROPERTIES => RawError::Kind(ITF::FTE_E_NO_MORE_PROPERTIES),
            ITF::FTE_E_UNKNOWN_PLUGIN => RawError::Kind(ITF::FTE_E_UNKNOWN_PLUGIN),
            ITF::FTE_E_LIBRARY_NOT_LOADED => RawError::Kind(ITF::FTE_E_LIBRARY_NOT_LOADED),
            ITF::FTE_E_PERFMON_FULL => RawError::Kind(ITF::FTE_E_PERFMON_FULL),
            ITF::FTE_E_FAILED_TO_CREATE_ACCESSOR => RawError::Kind(ITF::FTE_E_FAILED_TO_CREATE_ACCESSOR),
            ITF::FTE_E_INVALID_TYPE => RawError::Kind(ITF::FTE_E_INVALID_TYPE),
            ITF::FTE_E_OUT_OF_RANGE => RawError::Kind(ITF::FTE_E_OUT_OF_RANGE),
            ITF::FTE_E_CORRUPT_PROPERTY_STORE => RawError::Kind(ITF::FTE_E_CORRUPT_PROPERTY_STORE),
            ITF::FTE_E_PROPERTY_STORE_WORKID_NOTVALID => RawError::Kind(ITF::FTE_E_PROPERTY_STORE_WORKID_NOTVALID),
            ITF::FTE_E_CORRUPT_GATHERER_HASH_MAP => RawError::Kind(ITF::FTE_E_CORRUPT_GATHERER_HASH_MAP),
            ITF::FTE_E_KEY_NOT_CACHED => RawError::Kind(ITF::FTE_E_KEY_NOT_CACHED),
            ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN => RawError::Kind(ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN),
            ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED => RawError::Kind(ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED),
            ITF::FTE_E_STACK_CORRUPTED => RawError::Kind(ITF::FTE_E_STACK_CORRUPTED),
            ITF::FTE_E_INVALID_PROG_ID => RawError::Kind(ITF::FTE_E_INVALID_PROG_ID),
            ITF::FTE_E_SERIAL_STREAM_CORRUPT => RawError::Kind(ITF::FTE_E_SERIAL_STREAM_CORRUPT),
            ITF::FTE_E_READONLY_CATALOG => RawError::Kind(ITF::FTE_E_READONLY_CATALOG),
            ITF::FTE_E_PERF_NOT_LOADED => RawError::Kind(ITF::FTE_E_PERF_NOT_LOADED),
            ITF::FTE_E_RETRY_HUGE_DOC => RawError::Kind(ITF::FTE_E_RETRY_HUGE_DOC),
            ITF::FTE_E_UNKNOWN_FD_TYPE => RawError::Kind(ITF::FTE_E_UNKNOWN_FD_TYPE),
            ITF::FTE_E_DOC_TOO_HUGE => RawError::Kind(ITF::FTE_E_DOC_TOO_HUGE),
            ITF::FTE_E_DATATYPE_MISALIGNMENT => RawError::Kind(ITF::FTE_E_DATATYPE_MISALIGNMENT),
            ITF::FTE_E_ALREADY_INITIALIZED => RawError::Kind(ITF::FTE_E_ALREADY_INITIALIZED),
            ITF::FTE_E_FD_USED_TOO_MUCH_MEMORY => RawError::Kind(ITF::FTE_E_FD_USED_TOO_MUCH_MEMORY),
            ITF::FTE_E_UNEXPECTED_EXIT => RawError::Kind(ITF::FTE_E_UNEXPECTED_EXIT),
            ITF::FTE_E_HIGH_MEMORY_PRESSURE => RawError::Kind(ITF::FTE_E_HIGH_MEMORY_PRESSURE),
            ITF::FTE_E_INVALID_ISOLATE_ERROR_BATCH => RawError::Kind(ITF::FTE_E_INVALID_ISOLATE_ERROR_BATCH),
            ITF::FTE_E_RETRY_SINGLE_DOC_PER_BATCH => RawError::Kind(ITF::FTE_E_RETRY_SINGLE_DOC_PER_BATCH),
            ITF::FTE_E_INVALID_PROJECT_ID => RawError::Kind(ITF::FTE_E_INVALID_PROJECT_ID),
            ITF::FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS => RawError::Kind(ITF::FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS),
            ITF::FTE_E_INVALID_CODEPAGE => RawError::Kind(ITF::FTE_E_INVALID_CODEPAGE),
            ITF::FTE_E_FD_IDLE => RawError::Kind(ITF::FTE_E_FD_IDLE),
            ITF::FTE_E_FD_UNRESPONSIVE => RawError::Kind(ITF::FTE_E_FD_UNRESPONSIVE),
            ITF::WCN_E_PEER_NOT_FOUND => RawError::Kind(ITF::WCN_E_PEER_NOT_FOUND),
            ITF::WCN_E_AUTHENTICATION_FAILED => RawError::Kind(ITF::WCN_E_AUTHENTICATION_FAILED),
            ITF::WCN_E_CONNECTION_REJECTED => RawError::Kind(ITF::WCN_E_CONNECTION_REJECTED),
            ITF::WCN_E_SESSION_TIMEDOUT => RawError::Kind(ITF::WCN_E_SESSION_TIMEDOUT),
            ITF::WCN_E_PROTOCOL_ERROR => RawError::Kind(ITF::WCN_E_PROTOCOL_ERROR),
            ITF::CDO_E_ARGUMENT1 => RawError::Kind(ITF::CDO_E_ARGUMENT1),
            ITF::PEOPLE_IMPORT_E_DBCONNFAIL => RawError::Kind(ITF::PEOPLE_IMPORT_E_DBCONNFAIL),
            ITF::CDO_E_ARGUMENT2 => RawError::Kind(ITF::CDO_E_ARGUMENT2),
            ITF::PEOPLE_IMPORT_NODSDEFINED => RawError::Kind(ITF::PEOPLE_IMPORT_NODSDEFINED),
            ITF::CDO_E_ARGUMENT3 => RawError::Kind(ITF::CDO_E_ARGUMENT3),
            ITF::PEOPLE_IMPORT_E_FAILTOGETDSDEF => RawError::Kind(ITF::PEOPLE_IMPORT_E_FAILTOGETDSDEF),
            ITF::CDO_E_ARGUMENT4 => RawError::Kind(ITF::CDO_E_ARGUMENT4),
            ITF::PEOPLE_IMPORT_NOMAPPINGDEFINED => RawError::Kind(ITF::PEOPLE_IMPORT_NOMAPPINGDEFINED),
            ITF::CDO_E_ARGUMENT5 => RawError::Kind(ITF::CDO_E_ARGUMENT5),
            ITF::PEOPLE_IMPORT_E_FAILTOGETDSMAPPING => RawError::Kind(ITF::PEOPLE_IMPORT_E_FAILTOGETDSMAPPING),
            ITF::PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED => RawError::Kind(ITF::PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED),
            ITF::PEOPLE_IMPORT_E_NOCASTINGSUPPORTED => RawError::Kind(ITF::PEOPLE_IMPORT_E_NOCASTINGSUPPORTED),
            ITF::PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE => RawError::Kind(ITF::PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE),
            ITF::PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE => RawError::Kind(ITF::PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE),
            ITF::PEOPLE_IMPORT_E_LDAPPATH_TOOLONG => RawError::Kind(ITF::PEOPLE_IMPORT_E_LDAPPATH_TOOLONG),
            ITF::PEOPLE_IMPORT_E_CANONICALURL_TOOLONG => RawError::Kind(ITF::PEOPLE_IMPORT_E_CANONICALURL_TOOLONG),
            ITF::PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED => RawError::Kind(ITF::PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED),
            ITF::PEOPLE_IMPORT_E_DC_NOT_AVAILABLE => RawError::Kind(ITF::PEOPLE_IMPORT_E_DC_NOT_AVAILABLE),
            ITF::PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED => RawError::Kind(ITF::PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED),
            ITF::PEOPLE_IMPORT_E_FAILTOGETLCID => RawError::Kind(ITF::PEOPLE_IMPORT_E_FAILTOGETLCID),
            ITF::PEOPLE_IMPORT_E_DOMAIN_REMOVED => RawError::Kind(ITF::PEOPLE_IMPORT_E_DOMAIN_REMOVED),
            ITF::PEOPLE_IMPORT_E_ENUM_ACCESSDENIED => RawError::Kind(ITF::PEOPLE_IMPORT_E_ENUM_ACCESSDENIED),
            ITF::PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED => RawError::Kind(ITF::PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED),
            ITF::SPERR_UNINITIALIZED => RawError::Kind(ITF::SPERR_UNINITIALIZED),
            ITF::SPERR_ALREADY_INITIALIZED => RawError::Kind(ITF::SPERR_ALREADY_INITIALIZED),
            ITF::SPERR_UNSUPPORTED_FORMAT => RawError::Kind(ITF::SPERR_UNSUPPORTED_FORMAT),
            ITF::SPERR_INVALID_FLAGS => RawError::Kind(ITF::SPERR_INVALID_FLAGS),
            ITF::SPERR_DEVICE_BUSY => RawError::Kind(ITF::SPERR_DEVICE_BUSY),
            ITF::SPERR_DEVICE_NOT_SUPPORTED => RawError::Kind(ITF::SPERR_DEVICE_NOT_SUPPORTED),
            ITF::SPERR_DEVICE_NOT_ENABLED => RawError::Kind(ITF::SPERR_DEVICE_NOT_ENABLED),
            ITF::SPERR_NO_DRIVER => RawError::Kind(ITF::SPERR_NO_DRIVER),
            ITF::SPERR_FILEMUSTBEUNICODE => RawError::Kind(ITF::SPERR_FILEMUSTBEUNICODE),
            ITF::SPERR_INVALID_PHRASE_ID => RawError::Kind(ITF::SPERR_INVALID_PHRASE_ID),
            ITF::SPERR_BUFFER_TOO_SMALL => RawError::Kind(ITF::SPERR_BUFFER_TOO_SMALL),
            ITF::SPERR_FORMAT_NOT_SPECIFIED => RawError::Kind(ITF::SPERR_FORMAT_NOT_SPECIFIED),
            ITF::SPERR_AUDIO_STOPPED => RawError::Kind(ITF::SPERR_AUDIO_STOPPED),
            ITF::SPERR_RULE_NOT_FOUND => RawError::Kind(ITF::SPERR_RULE_NOT_FOUND),
            ITF::SPERR_TTS_ENGINE_EXCEPTION => RawError::Kind(ITF::SPERR_TTS_ENGINE_EXCEPTION),
            ITF::SPERR_TTS_NLP_EXCEPTION => RawError::Kind(ITF::SPERR_TTS_NLP_EXCEPTION),
            ITF::SPERR_ENGINE_BUSY => RawError::Kind(ITF::SPERR_ENGINE_BUSY),
            ITF::SPERR_CANT_CREATE => RawError::Kind(ITF::SPERR_CANT_CREATE),
            ITF::SPERR_NOT_IN_LEX => RawError::Kind(ITF::SPERR_NOT_IN_LEX),
            ITF::SPERR_LEX_VERY_OUT_OF_SYNC => RawError::Kind(ITF::SPERR_LEX_VERY_OUT_OF_SYNC),
            ITF::SPERR_UNDEFINED_FORWARD_RULE_REF => RawError::Kind(ITF::SPERR_UNDEFINED_FORWARD_RULE_REF),
            ITF::SPERR_EMPTY_RULE => RawError::Kind(ITF::SPERR_EMPTY_RULE),
            ITF::SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR => RawError::Kind(ITF::SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR),
            ITF::SPERR_RULE_NOT_DYNAMIC => RawError::Kind(ITF::SPERR_RULE_NOT_DYNAMIC),
            ITF::SPERR_DUPLICATE_RULE_NAME => RawError::Kind(ITF::SPERR_DUPLICATE_RULE_NAME),
            ITF::SPERR_DUPLICATE_RESOURCE_NAME => RawError::Kind(ITF::SPERR_DUPLICATE_RESOURCE_NAME),
            ITF::SPERR_TOO_MANY_GRAMMARS => RawError::Kind(ITF::SPERR_TOO_MANY_GRAMMARS),
            ITF::SPERR_CIRCULAR_REFERENCE => RawError::Kind(ITF::SPERR_CIRCULAR_REFERENCE),
            ITF::SPERR_INVALID_IMPORT => RawError::Kind(ITF::SPERR_INVALID_IMPORT),
            ITF::SPERR_INVALID_WAV_FILE => RawError::Kind(ITF::SPERR_INVALID_WAV_FILE),
            ITF::SPERR_ALL_WORDS_OPTIONAL => RawError::Kind(ITF::SPERR_ALL_WORDS_OPTIONAL),
            ITF::SPERR_INSTANCE_CHANGE_INVALID => RawError::Kind(ITF::SPERR_INSTANCE_CHANGE_INVALID),
            ITF::SPERR_RULE_NAME_ID_CONFLICT => RawError::Kind(ITF::SPERR_RULE_NAME_ID_CONFLICT),
            ITF::SPERR_NO_RULES => RawError::Kind(ITF::SPERR_NO_RULES),
            ITF::SPERR_CIRCULAR_RULE_REF => RawError::Kind(ITF::SPERR_CIRCULAR_RULE_REF),
            ITF::SPERR_NO_PARSE_FOUND => RawError::Kind(ITF::SPERR_NO_PARSE_FOUND),
            ITF::SPERR_REMOTE_CALL_TIMED_OUT => RawError::Kind(ITF::SPERR_REMOTE_CALL_TIMED_OUT),
            ITF::SPERR_AUDIO_BUFFER_OVERFLOW => RawError::Kind(ITF::SPERR_AUDIO_BUFFER_OVERFLOW),
            ITF::SPERR_NO_AUDIO_DATA => RawError::Kind(ITF::SPERR_NO_AUDIO_DATA),
            ITF::SPERR_DEAD_ALTERNATE => RawError::Kind(ITF::SPERR_DEAD_ALTERNATE),
            ITF::SPERR_HIGH_LOW_CONFIDENCE => RawError::Kind(ITF::SPERR_HIGH_LOW_CONFIDENCE),
            ITF::SPERR_INVALID_FORMAT_STRING => RawError::Kind(ITF::SPERR_INVALID_FORMAT_STRING),
            ITF::SPERR_APPLEX_READ_ONLY => RawError::Kind(ITF::SPERR_APPLEX_READ_ONLY),
            ITF::SPERR_NO_TERMINATING_RULE_PATH => RawError::Kind(ITF::SPERR_NO_TERMINATING_RULE_PATH),
            ITF::SPERR_STREAM_CLOSED => RawError::Kind(ITF::SPERR_STREAM_CLOSED),
            ITF::SPERR_NO_MORE_ITEMS => RawError::Kind(ITF::SPERR_NO_MORE_ITEMS),
            ITF::SPERR_NOT_FOUND => RawError::Kind(ITF::SPERR_NOT_FOUND),
            ITF::SPERR_INVALID_AUDIO_STATE => RawError::Kind(ITF::SPERR_INVALID_AUDIO_STATE),
            ITF::SPERR_GENERIC_MMSYS_ERROR => RawError::Kind(ITF::SPERR_GENERIC_MMSYS_ERROR),
            ITF::SPERR_MARSHALER_EXCEPTION => RawError::Kind(ITF::SPERR_MARSHALER_EXCEPTION),
            ITF::SPERR_NOT_DYNAMIC_GRAMMAR => RawError::Kind(ITF::SPERR_NOT_DYNAMIC_GRAMMAR),
            ITF::SPERR_AMBIGUOUS_PROPERTY => RawError::Kind(ITF::SPERR_AMBIGUOUS_PROPERTY),
            ITF::SPERR_INVALID_REGISTRY_KEY => RawError::Kind(ITF::SPERR_INVALID_REGISTRY_KEY),
            ITF::SPERR_INVALID_TOKEN_ID => RawError::Kind(ITF::SPERR_INVALID_TOKEN_ID),
            ITF::SPERR_XML_BAD_SYNTAX => RawError::Kind(ITF::SPERR_XML_BAD_SYNTAX),
            ITF::SPERR_XML_RESOURCE_NOT_FOUND => RawError::Kind(ITF::SPERR_XML_RESOURCE_NOT_FOUND),
            ITF::SPERR_TOKEN_IN_USE => RawError::Kind(ITF::SPERR_TOKEN_IN_USE),
            ITF::SPERR_TOKEN_DELETED => RawError::Kind(ITF::SPERR_TOKEN_DELETED),
            ITF::SPERR_MULTI_LINGUAL_NOT_SUPPORTED => RawError::Kind(ITF::SPERR_MULTI_LINGUAL_NOT_SUPPORTED),
            ITF::SPERR_EXPORT_DYNAMIC_RULE => RawError::Kind(ITF::SPERR_EXPORT_DYNAMIC_RULE),
            ITF::SPERR_STGF_ERROR => RawError::Kind(ITF::SPERR_STGF_ERROR),
            ITF::SPERR_WORDFORMAT_ERROR => RawError::Kind(ITF::SPERR_WORDFORMAT_ERROR),
            ITF::SPERR_STREAM_NOT_ACTIVE => RawError::Kind(ITF::SPERR_STREAM_NOT_ACTIVE),
            ITF::SPERR_ENGINE_RESPONSE_INVALID => RawError::Kind(ITF::SPERR_ENGINE_RESPONSE_INVALID),
            ITF::SPERR_SR_ENGINE_EXCEPTION => RawError::Kind(ITF::SPERR_SR_ENGINE_EXCEPTION),
            ITF::SPERR_STREAM_POS_INVALID => RawError::Kind(ITF::SPERR_STREAM_POS_INVALID),
            ITF::SPERR_REMOTE_CALL_ON_WRONG_THREAD => RawError::Kind(ITF::SPERR_REMOTE_CALL_ON_WRONG_THREAD),
            ITF::SPERR_REMOTE_PROCESS_TERMINATED => RawError::Kind(ITF::SPERR_REMOTE_PROCESS_TERMINATED),
            ITF::SPERR_REMOTE_PROCESS_ALREADY_RUNNING => RawError::Kind(ITF::SPERR_REMOTE_PROCESS_ALREADY_RUNNING),
            ITF::SPERR_LANGID_MISMATCH => RawError::Kind(ITF::SPERR_LANGID_MISMATCH),
            ITF::SPERR_NOT_TOPLEVEL_RULE => RawError::Kind(ITF::SPERR_NOT_TOPLEVEL_RULE),
            ITF::SPERR_LEX_REQUIRES_COOKIE => RawError::Kind(ITF::SPERR_LEX_REQUIRES_COOKIE),
            ITF::SPERR_UNSUPPORTED_LANG => RawError::Kind(ITF::SPERR_UNSUPPORTED_LANG),
            ITF::SPERR_VOICE_PAUSED => RawError::Kind(ITF::SPERR_VOICE_PAUSED),
            ITF::SPERR_AUDIO_BUFFER_UNDERFLOW => RawError::Kind(ITF::SPERR_AUDIO_BUFFER_UNDERFLOW),
            ITF::SPERR_AUDIO_STOPPED_UNEXPECTEDLY => RawError::Kind(ITF::SPERR_AUDIO_STOPPED_UNEXPECTEDLY),
            ITF::SPERR_NO_WORD_PRONUNCIATION => RawError::Kind(ITF::SPERR_NO_WORD_PRONUNCIATION),
            ITF::SPERR_ALTERNATES_WOULD_BE_INCONSISTENT => RawError::Kind(ITF::SPERR_ALTERNATES_WOULD_BE_INCONSISTENT),
            ITF::SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER => RawError::Kind(ITF::SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER),
            ITF::SPERR_TIMEOUT => RawError::Kind(ITF::SPERR_TIMEOUT),
            ITF::SPERR_REENTER_SYNCHRONIZE => RawError::Kind(ITF::SPERR_REENTER_SYNCHRONIZE),
            ITF::SPERR_STATE_WITH_NO_ARCS => RawError::Kind(ITF::SPERR_STATE_WITH_NO_ARCS),
            ITF::SPERR_NOT_ACTIVE_SESSION => RawError::Kind(ITF::SPERR_NOT_ACTIVE_SESSION),
            ITF::SPERR_ALREADY_DELETED => RawError::Kind(ITF::SPERR_ALREADY_DELETED),
            ITF::SPERR_RECOXML_GENERATION_FAIL => RawError::Kind(ITF::SPERR_RECOXML_GENERATION_FAIL),
            ITF::SPERR_SML_GENERATION_FAIL => RawError::Kind(ITF::SPERR_SML_GENERATION_FAIL),
            ITF::SPERR_NOT_PROMPT_VOICE => RawError::Kind(ITF::SPERR_NOT_PROMPT_VOICE),
            ITF::SPERR_ROOTRULE_ALREADY_DEFINED => RawError::Kind(ITF::SPERR_ROOTRULE_ALREADY_DEFINED),
            ITF::SPERR_SCRIPT_DISALLOWED => RawError::Kind(ITF::SPERR_SCRIPT_DISALLOWED),
            ITF::SPERR_REMOTE_CALL_TIMED_OUT_START => RawError::Kind(ITF::SPERR_REMOTE_CALL_TIMED_OUT_START),
            ITF::SPERR_REMOTE_CALL_TIMED_OUT_CONNECT => RawError::Kind(ITF::SPERR_REMOTE_CALL_TIMED_OUT_CONNECT),
            ITF::SPERR_SECMGR_CHANGE_NOT_ALLOWED => RawError::Kind(ITF::SPERR_SECMGR_CHANGE_NOT_ALLOWED),
            ITF::SPERR_FAILED_TO_DELETE_FILE => RawError::Kind(ITF::SPERR_FAILED_TO_DELETE_FILE),
            ITF::SPERR_SHARED_ENGINE_DISABLED => RawError::Kind(ITF::SPERR_SHARED_ENGINE_DISABLED),
            ITF::SPERR_RECOGNIZER_NOT_FOUND => RawError::Kind(ITF::SPERR_RECOGNIZER_NOT_FOUND),
            ITF::SPERR_AUDIO_NOT_FOUND => RawError::Kind(ITF::SPERR_AUDIO_NOT_FOUND),
            ITF::SPERR_NO_VOWEL => RawError::Kind(ITF::SPERR_NO_VOWEL),
            ITF::SPERR_UNSUPPORTED_PHONEME => RawError::Kind(ITF::SPERR_UNSUPPORTED_PHONEME),
            ITF::SPERR_WORD_NEEDS_NORMALIZATION => RawError::Kind(ITF::SPERR_WORD_NEEDS_NORMALIZATION),
            ITF::SPERR_CANNOT_NORMALIZE => RawError::Kind(ITF::SPERR_CANNOT_NORMALIZE),
            ITF::SPERR_TOPIC_NOT_ADAPTABLE => RawError::Kind(ITF::SPERR_TOPIC_NOT_ADAPTABLE),
            ITF::SPERR_PHONEME_CONVERSION => RawError::Kind(ITF::SPERR_PHONEME_CONVERSION),
            ITF::SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER => RawError::Kind(ITF::SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER),
            ITF::SPERR_OVERLOAD => RawError::Kind(ITF::SPERR_OVERLOAD),
            ITF::SPERR_LEX_INVALID_DATA => RawError::Kind(ITF::SPERR_LEX_INVALID_DATA),
            ITF::SPERR_CFG_INVALID_DATA => RawError::Kind(ITF::SPERR_CFG_INVALID_DATA),
            ITF::SPERR_LEX_UNEXPECTED_FORMAT => RawError::Kind(ITF::SPERR_LEX_UNEXPECTED_FORMAT),
            ITF::SPERR_STRING_TOO_LONG => RawError::Kind(ITF::SPERR_STRING_TOO_LONG),
            ITF::SPERR_STRING_EMPTY => RawError::Kind(ITF::SPERR_STRING_EMPTY),
            ITF::SPERR_NON_WORD_TRANSITION => RawError::Kind(ITF::SPERR_NON_WORD_TRANSITION),
            ITF::SPERR_SISR_ATTRIBUTES_NOT_ALLOWED => RawError::Kind(ITF::SPERR_SISR_ATTRIBUTES_NOT_ALLOWED),
            ITF::SPERR_SISR_MIXED_NOT_ALLOWED => RawError::Kind(ITF::SPERR_SISR_MIXED_NOT_ALLOWED),
            ITF::SPERR_VOICE_NOT_FOUND => RawError::Kind(ITF::SPERR_VOICE_NOT_FOUND),
            ITF::FSRM_E_NOT_FOUND => RawError::Kind(ITF::FSRM_E_NOT_FOUND),
            ITF::FSRM_E_INVALID_SCHEDULER_ARGUMENT => RawError::Kind(ITF::FSRM_E_INVALID_SCHEDULER_ARGUMENT),
            ITF::FSRM_E_ALREADY_EXISTS => RawError::Kind(ITF::FSRM_E_ALREADY_EXISTS),
            ITF::FSRM_E_PATH_NOT_FOUND => RawError::Kind(ITF::FSRM_E_PATH_NOT_FOUND),
            ITF::FSRM_E_INVALID_USER => RawError::Kind(ITF::FSRM_E_INVALID_USER),
            ITF::FSRM_E_INVALID_PATH => RawError::Kind(ITF::FSRM_E_INVALID_PATH),
            ITF::FSRM_E_INVALID_LIMIT => RawError::Kind(ITF::FSRM_E_INVALID_LIMIT),
            ITF::FSRM_E_INVALID_NAME => RawError::Kind(ITF::FSRM_E_INVALID_NAME),
            ITF::FSRM_E_FAIL_BATCH => RawError::Kind(ITF::FSRM_E_FAIL_BATCH),
            ITF::FSRM_E_INVALID_TEXT => RawError::Kind(ITF::FSRM_E_INVALID_TEXT),
            ITF::FSRM_E_INVALID_IMPORT_VERSION => RawError::Kind(ITF::FSRM_E_INVALID_IMPORT_VERSION),
            ITF::FSRM_E_OUT_OF_RANGE => RawError::Kind(ITF::FSRM_E_OUT_OF_RANGE),
            ITF::FSRM_E_REQD_PARAM_MISSING => RawError::Kind(ITF::FSRM_E_REQD_PARAM_MISSING),
            ITF::FSRM_E_INVALID_COMBINATION => RawError::Kind(ITF::FSRM_E_INVALID_COMBINATION),
            ITF::FSRM_E_DUPLICATE_NAME => RawError::Kind(ITF::FSRM_E_DUPLICATE_NAME),
            ITF::FSRM_E_NOT_SUPPORTED => RawError::Kind(ITF::FSRM_E_NOT_SUPPORTED),
            ITF::FSRM_E_DRIVER_NOT_READY => RawError::Kind(ITF::FSRM_E_DRIVER_NOT_READY),
            ITF::FSRM_E_INSUFFICIENT_DISK => RawError::Kind(ITF::FSRM_E_INSUFFICIENT_DISK),
            ITF::FSRM_E_VOLUME_UNSUPPORTED => RawError::Kind(ITF::FSRM_E_VOLUME_UNSUPPORTED),
            ITF::FSRM_E_UNEXPECTED => RawError::Kind(ITF::FSRM_E_UNEXPECTED),
            ITF::FSRM_E_INSECURE_PATH => RawError::Kind(ITF::FSRM_E_INSECURE_PATH),
            ITF::FSRM_E_INVALID_SMTP_SERVER => RawError::Kind(ITF::FSRM_E_INVALID_SMTP_SERVER),
            ITF::FSRM_E_EMAIL_NOT_SENT => RawError::Kind(ITF::FSRM_E_EMAIL_NOT_SENT),
            ITF::FSRM_E_INVALID_EMAIL_ADDRESS => RawError::Kind(ITF::FSRM_E_INVALID_EMAIL_ADDRESS),
            ITF::FSRM_E_FILE_SYSTEM_CORRUPT => RawError::Kind(ITF::FSRM_E_FILE_SYSTEM_CORRUPT),
            ITF::FSRM_E_LONG_CMDLINE => RawError::Kind(ITF::FSRM_E_LONG_CMDLINE),
            ITF::FSRM_E_INVALID_FILEGROUP_DEFINITION => RawError::Kind(ITF::FSRM_E_INVALID_FILEGROUP_DEFINITION),
            ITF::FSRM_E_INVALID_DATASCREEN_DEFINITION => RawError::Kind(ITF::FSRM_E_INVALID_DATASCREEN_DEFINITION),
            ITF::FSRM_E_INVALID_REPORT_FORMAT => RawError::Kind(ITF::FSRM_E_INVALID_REPORT_FORMAT),
            ITF::FSRM_E_INVALID_REPORT_DESC => RawError::Kind(ITF::FSRM_E_INVALID_REPORT_DESC),
            ITF::FSRM_E_INVALID_FILENAME => RawError::Kind(ITF::FSRM_E_INVALID_FILENAME),
            ITF::FSRM_E_SHADOW_COPY => RawError::Kind(ITF::FSRM_E_SHADOW_COPY),
            ITF::FSRM_E_XML_CORRUPTED => RawError::Kind(ITF::FSRM_E_XML_CORRUPTED),
            ITF::FSRM_E_CLUSTER_NOT_RUNNING => RawError::Kind(ITF::FSRM_E_CLUSTER_NOT_RUNNING),
            ITF::FSRM_E_STORE_NOT_INSTALLED => RawError::Kind(ITF::FSRM_E_STORE_NOT_INSTALLED),
            ITF::FSRM_E_NOT_CLUSTER_VOLUME => RawError::Kind(ITF::FSRM_E_NOT_CLUSTER_VOLUME),
            ITF::FSRM_E_DIFFERENT_CLUSTER_GROUP => RawError::Kind(ITF::FSRM_E_DIFFERENT_CLUSTER_GROUP),
            ITF::FSRM_E_REPORT_TYPE_ALREADY_EXISTS => RawError::Kind(ITF::FSRM_E_REPORT_TYPE_ALREADY_EXISTS),
            ITF::FSRM_E_REPORT_JOB_ALREADY_RUNNING => RawError::Kind(ITF::FSRM_E_REPORT_JOB_ALREADY_RUNNING),
            ITF::FSRM_E_REPORT_GENERATION_ERR => RawError::Kind(ITF::FSRM_E_REPORT_GENERATION_ERR),
            ITF::FSRM_E_REPORT_TASK_TRIGGER => RawError::Kind(ITF::FSRM_E_REPORT_TASK_TRIGGER),
            ITF::FSRM_E_LOADING_DISABLED_MODULE => RawError::Kind(ITF::FSRM_E_LOADING_DISABLED_MODULE),
            ITF::FSRM_E_CANNOT_AGGREGATE => RawError::Kind(ITF::FSRM_E_CANNOT_AGGREGATE),
            ITF::FSRM_E_MESSAGE_LIMIT_EXCEEDED => RawError::Kind(ITF::FSRM_E_MESSAGE_LIMIT_EXCEEDED),
            ITF::FSRM_E_OBJECT_IN_USE => RawError::Kind(ITF::FSRM_E_OBJECT_IN_USE),
            ITF::FSRM_E_CANNOT_RENAME_PROPERTY => RawError::Kind(ITF::FSRM_E_CANNOT_RENAME_PROPERTY),
            ITF::FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE => RawError::Kind(ITF::FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE),
            ITF::FSRM_E_MAX_PROPERTY_DEFINITIONS => RawError::Kind(ITF::FSRM_E_MAX_PROPERTY_DEFINITIONS),
            ITF::FSRM_E_CLASSIFICATION_ALREADY_RUNNING => RawError::Kind(ITF::FSRM_E_CLASSIFICATION_ALREADY_RUNNING),
            ITF::FSRM_E_CLASSIFICATION_NOT_RUNNING => RawError::Kind(ITF::FSRM_E_CLASSIFICATION_NOT_RUNNING),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION),
            ITF::FSRM_E_FILE_OPEN_ERROR => RawError::Kind(ITF::FSRM_E_FILE_OPEN_ERROR),
            ITF::FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE => RawError::Kind(ITF::FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE),
            ITF::FSRM_E_CACHE_INVALID => RawError::Kind(ITF::FSRM_E_CACHE_INVALID),
            ITF::FSRM_E_CACHE_MODULE_ALREADY_EXISTS => RawError::Kind(ITF::FSRM_E_CACHE_MODULE_ALREADY_EXISTS),
            ITF::FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS),
            ITF::FSRM_E_PROPERTY_DELETED => RawError::Kind(ITF::FSRM_E_PROPERTY_DELETED),
            ITF::FSRM_E_LAST_ACCESS_UPDATE_DISABLED => RawError::Kind(ITF::FSRM_E_LAST_ACCESS_UPDATE_DISABLED),
            ITF::FSRM_E_NO_PROPERTY_VALUE => RawError::Kind(ITF::FSRM_E_NO_PROPERTY_VALUE),
            ITF::FSRM_E_INPROC_MODULE_BLOCKED => RawError::Kind(ITF::FSRM_E_INPROC_MODULE_BLOCKED),
            ITF::FSRM_E_ENUM_PROPERTIES_FAILED => RawError::Kind(ITF::FSRM_E_ENUM_PROPERTIES_FAILED),
            ITF::FSRM_E_SET_PROPERTY_FAILED => RawError::Kind(ITF::FSRM_E_SET_PROPERTY_FAILED),
            ITF::FSRM_E_CANNOT_STORE_PROPERTIES => RawError::Kind(ITF::FSRM_E_CANNOT_STORE_PROPERTIES),
            ITF::FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG => RawError::Kind(ITF::FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG),
            ITF::FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND => RawError::Kind(ITF::FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND),
            ITF::FSRM_E_TEXTREADER_NOT_INITIALIZED => RawError::Kind(ITF::FSRM_E_TEXTREADER_NOT_INITIALIZED),
            ITF::FSRM_E_TEXTREADER_IFILTER_NOT_FOUND => RawError::Kind(ITF::FSRM_E_TEXTREADER_IFILTER_NOT_FOUND),
            ITF::FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED => RawError::Kind(ITF::FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED),
            ITF::FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED => RawError::Kind(ITF::FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED),
            ITF::FSRM_E_TEXTREADER_STREAM_ERROR => RawError::Kind(ITF::FSRM_E_TEXTREADER_STREAM_ERROR),
            ITF::FSRM_E_TEXTREADER_FILENAME_TOO_LONG => RawError::Kind(ITF::FSRM_E_TEXTREADER_FILENAME_TOO_LONG),
            ITF::FSRM_E_INCOMPATIBLE_FORMAT => RawError::Kind(ITF::FSRM_E_INCOMPATIBLE_FORMAT),
            ITF::FSRM_E_FILE_ENCRYPTED => RawError::Kind(ITF::FSRM_E_FILE_ENCRYPTED),
            ITF::FSRM_E_PERSIST_PROPERTIES_FAILED => RawError::Kind(ITF::FSRM_E_PERSIST_PROPERTIES_FAILED),
            ITF::FSRM_E_VOLUME_OFFLINE => RawError::Kind(ITF::FSRM_E_VOLUME_OFFLINE),
            ITF::FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT),
            ITF::FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED),
            ITF::FSRM_E_MODULE_INVALID_PARAM => RawError::Kind(ITF::FSRM_E_MODULE_INVALID_PARAM),
            ITF::FSRM_E_MODULE_INITIALIZATION => RawError::Kind(ITF::FSRM_E_MODULE_INITIALIZATION),
            ITF::FSRM_E_MODULE_SESSION_INITIALIZATION => RawError::Kind(ITF::FSRM_E_MODULE_SESSION_INITIALIZATION),
            ITF::FSRM_E_CLASSIFICATION_SCAN_FAIL => RawError::Kind(ITF::FSRM_E_CLASSIFICATION_SCAN_FAIL),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS),
            ITF::FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY => RawError::Kind(ITF::FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY),
            ITF::FSRM_E_SYNC_TASK_TIMEOUT => RawError::Kind(ITF::FSRM_E_SYNC_TASK_TIMEOUT),
            ITF::FSRM_E_CANNOT_USE_DELETED_PROPERTY => RawError::Kind(ITF::FSRM_E_CANNOT_USE_DELETED_PROPERTY),
            ITF::FSRM_E_INVALID_AD_CLAIM => RawError::Kind(ITF::FSRM_E_INVALID_AD_CLAIM),
            ITF::FSRM_E_CLASSIFICATION_CANCELED => RawError::Kind(ITF::FSRM_E_CLASSIFICATION_CANCELED),
            ITF::FSRM_E_INVALID_FOLDER_PROPERTY_STORE => RawError::Kind(ITF::FSRM_E_INVALID_FOLDER_PROPERTY_STORE),
            ITF::FSRM_E_REBUILDING_FODLER_TYPE_INDEX => RawError::Kind(ITF::FSRM_E_REBUILDING_FODLER_TYPE_INDEX),
            ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FILES => RawError::Kind(ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FILES),
            ITF::FSRM_E_CLASSIFICATION_TIMEOUT => RawError::Kind(ITF::FSRM_E_CLASSIFICATION_TIMEOUT),
            ITF::FSRM_E_CLASSIFICATION_PARTIAL_BATCH => RawError::Kind(ITF::FSRM_E_CLASSIFICATION_PARTIAL_BATCH),
            ITF::FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY => RawError::Kind(ITF::FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY),
            ITF::FSRM_E_FILE_IN_USE => RawError::Kind(ITF::FSRM_E_FILE_IN_USE),
            ITF::FSRM_E_ERROR_NOT_ENABLED => RawError::Kind(ITF::FSRM_E_ERROR_NOT_ENABLED),
            ITF::FSRM_E_CANNOT_CREATE_TEMP_COPY => RawError::Kind(ITF::FSRM_E_CANNOT_CREATE_TEMP_COPY),
            ITF::FSRM_E_NO_EMAIL_ADDRESS => RawError::Kind(ITF::FSRM_E_NO_EMAIL_ADDRESS),
            ITF::FSRM_E_ADR_MAX_EMAILS_SENT => RawError::Kind(ITF::FSRM_E_ADR_MAX_EMAILS_SENT),
            ITF::FSRM_E_PATH_NOT_IN_NAMESPACE => RawError::Kind(ITF::FSRM_E_PATH_NOT_IN_NAMESPACE),
            ITF::FSRM_E_RMS_TEMPLATE_NOT_FOUND => RawError::Kind(ITF::FSRM_E_RMS_TEMPLATE_NOT_FOUND),
            ITF::FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED => RawError::Kind(ITF::FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED),
            ITF::FSRM_E_RMS_NO_PROTECTORS_INSTALLED => RawError::Kind(ITF::FSRM_E_RMS_NO_PROTECTORS_INSTALLED),
            ITF::FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE => RawError::Kind(ITF::FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE),
            ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS => RawError::Kind(ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS),
            ITF::FSRM_E_PROPERTY_MUST_BE_SECURE => RawError::Kind(ITF::FSRM_E_PROPERTY_MUST_BE_SECURE),
            ITF::FSRM_E_PROPERTY_MUST_BE_GLOBAL => RawError::Kind(ITF::FSRM_E_PROPERTY_MUST_BE_GLOBAL),
            ITF::FSRM_E_WMI_FAILURE => RawError::Kind(ITF::FSRM_E_WMI_FAILURE),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_RMS => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_RMS),
            ITF::FSRM_E_SYNC_TASK_HAD_ERRORS => RawError::Kind(ITF::FSRM_E_SYNC_TASK_HAD_ERRORS),
            ITF::FSRM_E_ADR_SRV_NOT_SUPPORTED => RawError::Kind(ITF::FSRM_E_ADR_SRV_NOT_SUPPORTED),
            ITF::FSRM_E_ADR_PATH_IS_LOCAL => RawError::Kind(ITF::FSRM_E_ADR_PATH_IS_LOCAL),
            ITF::FSRM_E_ADR_NOT_DOMAIN_JOINED => RawError::Kind(ITF::FSRM_E_ADR_NOT_DOMAIN_JOINED),
            ITF::FSRM_E_CANNOT_REMOVE_READONLY => RawError::Kind(ITF::FSRM_E_CANNOT_REMOVE_READONLY),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG),
            ITF::FSRM_E_LEGACY_SCHEDULE => RawError::Kind(ITF::FSRM_E_LEGACY_SCHEDULE),
            ITF::FSRM_E_CSC_PATH_NOT_SUPPORTED => RawError::Kind(ITF::FSRM_E_CSC_PATH_NOT_SUPPORTED),
            ITF::FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE => RawError::Kind(ITF::FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE),
            ITF::FSRM_E_EXPIRATION_PATH_TOO_LONG => RawError::Kind(ITF::FSRM_E_EXPIRATION_PATH_TOO_LONG),
            ITF::FSRM_E_EXPIRATION_VOLUME_NOT_NTFS => RawError::Kind(ITF::FSRM_E_EXPIRATION_VOLUME_NOT_NTFS),
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED => RawError::Kind(ITF::FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED),
            ITF::FSRM_E_MODULE_TIMEOUT => RawError::Kind(ITF::FSRM_E_MODULE_TIMEOUT),
            ITF::IFED_S_MORE_ENTRIES => RawError::Kind(ITF::IFED_S_MORE_ENTRIES),
            ITF::IFED_S_EMPTY_DICTIONARY => RawError::Kind(ITF::IFED_S_EMPTY_DICTIONARY),
            ITF::IFED_S_WORD_EXISTS => RawError::Kind(ITF::IFED_S_WORD_EXISTS),
            ITF::IFED_S_COMMENT_CHANGED => RawError::Kind(ITF::IFED_S_COMMENT_CHANGED),
            ITF::IFED_E_NOT_FOUND => RawError::Kind(ITF::IFED_E_NOT_FOUND),
            ITF::IFED_E_INVALID_FORMAT => RawError::Kind(ITF::IFED_E_INVALID_FORMAT),
            ITF::IFED_E_OPEN_FAILED => RawError::Kind(ITF::IFED_E_OPEN_FAILED),
            ITF::IFED_E_WRITE_FAILED => RawError::Kind(ITF::IFED_E_WRITE_FAILED),
            ITF::IFED_E_NO_ENTRY => RawError::Kind(ITF::IFED_E_NO_ENTRY),
            ITF::IFED_E_REGISTER_FAILED => RawError::Kind(ITF::IFED_E_REGISTER_FAILED),
            ITF::IFED_E_NOT_USER_DIC => RawError::Kind(ITF::IFED_E_NOT_USER_DIC),
            ITF::IFED_E_NOT_SUPPORTED => RawError::Kind(ITF::IFED_E_NOT_SUPPORTED),
            ITF::IFED_E_USER_COMMENT => RawError::Kind(ITF::IFED_E_USER_COMMENT),
            ITF::IFED_E_REGISTER_ILLEGAL_POS => RawError::Kind(ITF::IFED_E_REGISTER_ILLEGAL_POS),
            ITF::IFED_E_REGISTER_IMPROPER_WORD => RawError::Kind(ITF::IFED_E_REGISTER_IMPROPER_WORD),
            ITF::IFED_E_REGISTER_DISCONNECTED => RawError::Kind(ITF::IFED_E_REGISTER_DISCONNECTED),
            ITF::NETCFG_E_ALREADY_INITIALIZED => RawError::Kind(ITF::NETCFG_E_ALREADY_INITIALIZED),
            ITF::UPNP_E_REQUIRED_ELEMENT_ERROR => RawError::Kind(ITF::UPNP_E_REQUIRED_ELEMENT_ERROR),
            ITF::NETCFG_E_NOT_INITIALIZED => RawError::Kind(ITF::NETCFG_E_NOT_INITIALIZED),
            ITF::UPNP_E_DUPLICATE_NOT_ALLOWED => RawError::Kind(ITF::UPNP_E_DUPLICATE_NOT_ALLOWED),
            ITF::NETCFG_E_IN_USE => RawError::Kind(ITF::NETCFG_E_IN_USE),
            ITF::UPNP_E_DUPLICATE_SERVICE_ID => RawError::Kind(ITF::UPNP_E_DUPLICATE_SERVICE_ID),
            ITF::UPNP_E_INVALID_DESCRIPTION => RawError::Kind(ITF::UPNP_E_INVALID_DESCRIPTION),
            ITF::NETCFG_E_NO_WRITE_LOCK => RawError::Kind(ITF::NETCFG_E_NO_WRITE_LOCK),
            ITF::UPNP_E_INVALID_SERVICE => RawError::Kind(ITF::UPNP_E_INVALID_SERVICE),
            ITF::NETCFG_E_NEED_REBOOT => RawError::Kind(ITF::NETCFG_E_NEED_REBOOT),
            ITF::UPNP_E_INVALID_ICON => RawError::Kind(ITF::UPNP_E_INVALID_ICON),
            ITF::NETCFG_E_ACTIVE_RAS_CONNECTIONS => RawError::Kind(ITF::NETCFG_E_ACTIVE_RAS_CONNECTIONS),
            ITF::UPNP_E_INVALID_XML => RawError::Kind(ITF::UPNP_E_INVALID_XML),
            ITF::NETCFG_E_ADAPTER_NOT_FOUND => RawError::Kind(ITF::NETCFG_E_ADAPTER_NOT_FOUND),
            ITF::UPNP_E_INVALID_ROOT_NAMESPACE => RawError::Kind(ITF::UPNP_E_INVALID_ROOT_NAMESPACE),
            ITF::NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT => RawError::Kind(ITF::NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT),
            ITF::UPNP_E_SUFFIX_TOO_LONG => RawError::Kind(ITF::UPNP_E_SUFFIX_TOO_LONG),
            ITF::NETCFG_E_MAX_FILTER_LIMIT => RawError::Kind(ITF::NETCFG_E_MAX_FILTER_LIMIT),
            ITF::UPNP_E_URLBASE_PRESENT => RawError::Kind(ITF::UPNP_E_URLBASE_PRESENT),
            ITF::NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER => RawError::Kind(ITF::NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER),
            ITF::NETCFG_E_DUPLICATE_INSTANCEID => RawError::Kind(ITF::NETCFG_E_DUPLICATE_INSTANCEID),
            ITF::UPNP_E_VALUE_TOO_LONG => RawError::Kind(ITF::UPNP_E_VALUE_TOO_LONG),
            ITF::UPNP_E_DEVICE_RUNNING => RawError::Kind(ITF::UPNP_E_DEVICE_RUNNING),
            ITF::UPNP_E_DEVICE_NOTREGISTERED => RawError::Kind(ITF::UPNP_E_DEVICE_NOTREGISTERED),
            ITF::WTS_E_FAILEDEXTRACTION => RawError::Kind(ITF::WTS_E_FAILEDEXTRACTION),
            ITF::WTS_E_EXTRACTIONTIMEDOUT => RawError::Kind(ITF::WTS_E_EXTRACTIONTIMEDOUT),
            ITF::WTS_E_SURROGATEUNAVAILABLE => RawError::Kind(ITF::WTS_E_SURROGATEUNAVAILABLE),
            ITF::WTS_E_FASTEXTRACTIONNOTSUPPORTED => RawError::Kind(ITF::WTS_E_FASTEXTRACTIONNOTSUPPORTED),
            ITF::WTS_E_DATAFILEUNAVAILABLE => RawError::Kind(ITF::WTS_E_DATAFILEUNAVAILABLE),
            ITF::FTE_E_CB_OUT_OF_MEMORY => RawError::Kind(ITF::FTE_E_CB_OUT_OF_MEMORY),
            ITF::FTE_E_CB_CBID_OUT_OF_BOUND => RawError::Kind(ITF::FTE_E_CB_CBID_OUT_OF_BOUND),
            ITF::FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM => RawError::Kind(ITF::FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM),
            ITF::FTE_E_CB_NOT_ENOUGH_OCC_BUFFER => RawError::Kind(ITF::FTE_E_CB_NOT_ENOUGH_OCC_BUFFER),
            ITF::FTE_E_CORRUPT_WORDLIST => RawError::Kind(ITF::FTE_E_CORRUPT_WORDLIST),
            ITF::XACT_E_ALREADYOTHERSINGLEPHASE => RawError::Kind(ITF::XACT_E_ALREADYOTHERSINGLEPHASE),
            ITF::XACT_E_CANTRETAIN => RawError::Kind(ITF::XACT_E_CANTRETAIN),
            ITF::XACT_E_COMMITFAILED => RawError::Kind(ITF::XACT_E_COMMITFAILED),
            ITF::XACT_E_COMMITPREVENTED => RawError::Kind(ITF::XACT_E_COMMITPREVENTED),
            ITF::XACT_E_HEURISTICABORT => RawError::Kind(ITF::XACT_E_HEURISTICABORT),
            ITF::XACT_E_HEURISTICCOMMIT => RawError::Kind(ITF::XACT_E_HEURISTICCOMMIT),
            ITF::XACT_E_HEURISTICDAMAGE => RawError::Kind(ITF::XACT_E_HEURISTICDAMAGE),
            ITF::XACT_E_HEURISTICDANGER => RawError::Kind(ITF::XACT_E_HEURISTICDANGER),
            ITF::XACT_E_ISOLATIONLEVEL => RawError::Kind(ITF::XACT_E_ISOLATIONLEVEL),
            ITF::XACT_E_NOASYNC => RawError::Kind(ITF::XACT_E_NOASYNC),
            ITF::XACT_E_NOENLIST => RawError::Kind(ITF::XACT_E_NOENLIST),
            ITF::XACT_E_NOISORETAIN => RawError::Kind(ITF::XACT_E_NOISORETAIN),
            ITF::XACT_E_NORESOURCE => RawError::Kind(ITF::XACT_E_NORESOURCE),
            ITF::XACT_E_NOTCURRENT => RawError::Kind(ITF::XACT_E_NOTCURRENT),
            ITF::XACT_E_NOTRANSACTION => RawError::Kind(ITF::XACT_E_NOTRANSACTION),
            ITF::XACT_E_NOTSUPPORTED => RawError::Kind(ITF::XACT_E_NOTSUPPORTED),
            ITF::XACT_E_UNKNOWNRMGRID => RawError::Kind(ITF::XACT_E_UNKNOWNRMGRID),
            ITF::XACT_E_WRONGSTATE => RawError::Kind(ITF::XACT_E_WRONGSTATE),
            ITF::XACT_E_WRONGUOW => RawError::Kind(ITF::XACT_E_WRONGUOW),
            ITF::XACT_E_XTIONEXISTS => RawError::Kind(ITF::XACT_E_XTIONEXISTS),
            ITF::XACT_E_NOIMPORTOBJECT => RawError::Kind(ITF::XACT_E_NOIMPORTOBJECT),
            ITF::XACT_E_INVALIDCOOKIE => RawError::Kind(ITF::XACT_E_INVALIDCOOKIE),
            ITF::XACT_E_INDOUBT => RawError::Kind(ITF::XACT_E_INDOUBT),
            ITF::XACT_E_NOTIMEOUT => RawError::Kind(ITF::XACT_E_NOTIMEOUT),
            ITF::XACT_E_ALREADYINPROGRESS => RawError::Kind(ITF::XACT_E_ALREADYINPROGRESS),
            ITF::XACT_E_ABORTED => RawError::Kind(ITF::XACT_E_ABORTED),
            ITF::XACT_E_LOGFULL => RawError::Kind(ITF::XACT_E_LOGFULL),
            ITF::XACT_E_TMNOTAVAILABLE => RawError::Kind(ITF::XACT_E_TMNOTAVAILABLE),
            ITF::XACT_E_CONNECTION_DOWN => RawError::Kind(ITF::XACT_E_CONNECTION_DOWN),
            ITF::XACT_E_CONNECTION_DENIED => RawError::Kind(ITF::XACT_E_CONNECTION_DENIED),
            ITF::XACT_E_REENLISTTIMEOUT => RawError::Kind(ITF::XACT_E_REENLISTTIMEOUT),
            ITF::XACT_E_TIP_CONNECT_FAILED => RawError::Kind(ITF::XACT_E_TIP_CONNECT_FAILED),
            ITF::XACT_E_TIP_PROTOCOL_ERROR => RawError::Kind(ITF::XACT_E_TIP_PROTOCOL_ERROR),
            ITF::XACT_E_TIP_PULL_FAILED => RawError::Kind(ITF::XACT_E_TIP_PULL_FAILED),
            ITF::XACT_E_DEST_TMNOTAVAILABLE => RawError::Kind(ITF::XACT_E_DEST_TMNOTAVAILABLE),
            ITF::XACT_E_TIP_DISABLED => RawError::Kind(ITF::XACT_E_TIP_DISABLED),
            ITF::XACT_E_NETWORK_TX_DISABLED => RawError::Kind(ITF::XACT_E_NETWORK_TX_DISABLED),
            ITF::XACT_E_PARTNER_NETWORK_TX_DISABLED => RawError::Kind(ITF::XACT_E_PARTNER_NETWORK_TX_DISABLED),
            ITF::XACT_E_XA_TX_DISABLED => RawError::Kind(ITF::XACT_E_XA_TX_DISABLED),
            ITF::XACT_E_UNABLE_TO_READ_DTC_CONFIG => RawError::Kind(ITF::XACT_E_UNABLE_TO_READ_DTC_CONFIG),
            ITF::XACT_E_UNABLE_TO_LOAD_DTC_PROXY => RawError::Kind(ITF::XACT_E_UNABLE_TO_LOAD_DTC_PROXY),
            ITF::XACT_E_ABORTING => RawError::Kind(ITF::XACT_E_ABORTING),
            ITF::XACT_E_PUSH_COMM_FAILURE => RawError::Kind(ITF::XACT_E_PUSH_COMM_FAILURE),
            ITF::XACT_E_PULL_COMM_FAILURE => RawError::Kind(ITF::XACT_E_PULL_COMM_FAILURE),
            ITF::XACT_E_LU_TX_DISABLED => RawError::Kind(ITF::XACT_E_LU_TX_DISABLED),
            ITF::XACT_E_CLERKNOTFOUND => RawError::Kind(ITF::XACT_E_CLERKNOTFOUND),
            ITF::XACT_E_CLERKEXISTS => RawError::Kind(ITF::XACT_E_CLERKEXISTS),
            ITF::XACT_E_RECOVERYINPROGRESS => RawError::Kind(ITF::XACT_E_RECOVERYINPROGRESS),
            ITF::XACT_E_TRANSACTIONCLOSED => RawError::Kind(ITF::XACT_E_TRANSACTIONCLOSED),
            ITF::XACT_E_INVALIDLSN => RawError::Kind(ITF::XACT_E_INVALIDLSN),
            ITF::XACT_E_REPLAYREQUEST => RawError::Kind(ITF::XACT_E_REPLAYREQUEST),
            ITF::XACT_E_CONNECTION_REQUEST_DENIED => RawError::Kind(ITF::XACT_E_CONNECTION_REQUEST_DENIED),
            ITF::XACT_E_TOOMANY_ENLISTMENTS => RawError::Kind(ITF::XACT_E_TOOMANY_ENLISTMENTS),
            ITF::XACT_E_DUPLICATE_GUID => RawError::Kind(ITF::XACT_E_DUPLICATE_GUID),
            ITF::SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED),
            ITF::XACT_E_NOTSINGLEPHASE => RawError::Kind(ITF::XACT_E_NOTSINGLEPHASE),
            ITF::XACT_E_RECOVERYALREADYDONE => RawError::Kind(ITF::XACT_E_RECOVERYALREADYDONE),
            ITF::XACT_E_PROTOCOL => RawError::Kind(ITF::XACT_E_PROTOCOL),
            ITF::XACT_E_RM_FAILURE => RawError::Kind(ITF::XACT_E_RM_FAILURE),
            ITF::XACT_E_RECOVERY_FAILED => RawError::Kind(ITF::XACT_E_RECOVERY_FAILED),
            ITF::XACT_E_LU_NOT_FOUND => RawError::Kind(ITF::XACT_E_LU_NOT_FOUND),
            ITF::XACT_E_DUPLICATE_LU => RawError::Kind(ITF::XACT_E_DUPLICATE_LU),
            ITF::XACT_E_LU_NOT_CONNECTED => RawError::Kind(ITF::XACT_E_LU_NOT_CONNECTED),
            ITF::XACT_E_DUPLICATE_TRANSID => RawError::Kind(ITF::XACT_E_DUPLICATE_TRANSID),
            ITF::SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED),
            ITF::XACT_E_LU_BUSY => RawError::Kind(ITF::XACT_E_LU_BUSY),
            ITF::XACT_E_LU_NO_RECOVERY_PROCESS => RawError::Kind(ITF::XACT_E_LU_NO_RECOVERY_PROCESS),
            ITF::XACT_E_LU_DOWN => RawError::Kind(ITF::XACT_E_LU_DOWN),
            ITF::XACT_E_LU_RECOVERING => RawError::Kind(ITF::XACT_E_LU_RECOVERING),
            ITF::XACT_E_LU_RECOVERY_MISMATCH => RawError::Kind(ITF::XACT_E_LU_RECOVERY_MISMATCH),
            ITF::XACT_E_RM_UNAVAILABLE => RawError::Kind(ITF::XACT_E_RM_UNAVAILABLE),
            ITF::CONTEXT_E_ABORTED => RawError::Kind(ITF::CONTEXT_E_ABORTED),
            ITF::CONTEXT_E_ABORTING => RawError::Kind(ITF::CONTEXT_E_ABORTING),
            ITF::CONTEXT_E_NOCONTEXT => RawError::Kind(ITF::CONTEXT_E_NOCONTEXT),
            ITF::CONTEXT_E_WOULD_DEADLOCK => RawError::Kind(ITF::CONTEXT_E_WOULD_DEADLOCK),
            ITF::CONTEXT_E_SYNCH_TIMEOUT => RawError::Kind(ITF::CONTEXT_E_SYNCH_TIMEOUT),
            ITF::CONTEXT_E_OLDREF => RawError::Kind(ITF::CONTEXT_E_OLDREF),
            ITF::CONTEXT_E_ROLENOTFOUND => RawError::Kind(ITF::CONTEXT_E_ROLENOTFOUND),
            ITF::CONTEXT_E_TMNOTAVAILABLE => RawError::Kind(ITF::CONTEXT_E_TMNOTAVAILABLE),
            ITF::CO_E_ACTIVATIONFAILED => RawError::Kind(ITF::CO_E_ACTIVATIONFAILED),
            ITF::CO_E_ACTIVATIONFAILED_EVENTLOGGED => RawError::Kind(ITF::CO_E_ACTIVATIONFAILED_EVENTLOGGED),
            ITF::CO_E_ACTIVATIONFAILED_CATALOGERROR => RawError::Kind(ITF::CO_E_ACTIVATIONFAILED_CATALOGERROR),
            ITF::CO_E_ACTIVATIONFAILED_TIMEOUT => RawError::Kind(ITF::CO_E_ACTIVATIONFAILED_TIMEOUT),
            ITF::CO_E_INITIALIZATIONFAILED => RawError::Kind(ITF::CO_E_INITIALIZATIONFAILED),
            ITF::CONTEXT_E_NOJIT => RawError::Kind(ITF::CONTEXT_E_NOJIT),
            ITF::SL_E_INVALID_USE_OF_ADD_ON_PKEY => RawError::Kind(ITF::SL_E_INVALID_USE_OF_ADD_ON_PKEY),
            ITF::CONTEXT_E_NOTRANSACTION => RawError::Kind(ITF::CONTEXT_E_NOTRANSACTION),
            ITF::CO_E_THREADINGMODEL_CHANGED => RawError::Kind(ITF::CO_E_THREADINGMODEL_CHANGED),
            ITF::CO_E_NOIISINTRINSICS => RawError::Kind(ITF::CO_E_NOIISINTRINSICS),
            ITF::CO_E_NOCOOKIES => RawError::Kind(ITF::CO_E_NOCOOKIES),
            ITF::CO_E_DBERROR => RawError::Kind(ITF::CO_E_DBERROR),
            ITF::CO_E_NOTPOOLED => RawError::Kind(ITF::CO_E_NOTPOOLED),
            ITF::CO_E_NOTCONSTRUCTED => RawError::Kind(ITF::CO_E_NOTCONSTRUCTED),
            ITF::CO_E_NOSYNCHRONIZATION => RawError::Kind(ITF::CO_E_NOSYNCHRONIZATION),
            ITF::CO_E_ISOLEVELMISMATCH => RawError::Kind(ITF::CO_E_ISOLEVELMISMATCH),
            ITF::CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED => RawError::Kind(ITF::CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED),
            ITF::CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED => RawError::Kind(ITF::CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED),
            ITF::SL_E_SFS_INVALID_FS_VERSION => RawError::Kind(ITF::SL_E_SFS_INVALID_FS_VERSION),
            ITF::SL_E_SFS_INVALID_FD_TABLE => RawError::Kind(ITF::SL_E_SFS_INVALID_FD_TABLE),
            ITF::SL_E_SFS_INVALID_SYNC => RawError::Kind(ITF::SL_E_SFS_INVALID_SYNC),
            ITF::SL_E_SFS_BAD_TOKEN_NAME => RawError::Kind(ITF::SL_E_SFS_BAD_TOKEN_NAME),
            ITF::SL_E_SFS_BAD_TOKEN_EXT => RawError::Kind(ITF::SL_E_SFS_BAD_TOKEN_EXT),
            ITF::SL_E_SFS_DUPLICATE_TOKEN_NAME => RawError::Kind(ITF::SL_E_SFS_DUPLICATE_TOKEN_NAME),
            ITF::SL_E_SFS_TOKEN_SIZE_MISMATCH => RawError::Kind(ITF::SL_E_SFS_TOKEN_SIZE_MISMATCH),
            ITF::SL_E_SFS_INVALID_TOKEN_DATA_HASH => RawError::Kind(ITF::SL_E_SFS_INVALID_TOKEN_DATA_HASH),
            ITF::SL_E_SFS_FILE_READ_ERROR => RawError::Kind(ITF::SL_E_SFS_FILE_READ_ERROR),
            ITF::SL_E_SFS_FILE_WRITE_ERROR => RawError::Kind(ITF::SL_E_SFS_FILE_WRITE_ERROR),
            ITF::SL_E_SFS_INVALID_FILE_POSITION => RawError::Kind(ITF::SL_E_SFS_INVALID_FILE_POSITION),
            ITF::SL_E_SFS_NO_ACTIVE_TRANSACTION => RawError::Kind(ITF::SL_E_SFS_NO_ACTIVE_TRANSACTION),
            ITF::SL_E_SFS_INVALID_FS_HEADER => RawError::Kind(ITF::SL_E_SFS_INVALID_FS_HEADER),
            ITF::SL_E_SFS_INVALID_TOKEN_DESCRIPTOR => RawError::Kind(ITF::SL_E_SFS_INVALID_TOKEN_DESCRIPTOR),
            ITF::FTE_E_FD_NO_IPERSIST_INTERFACE => RawError::Kind(ITF::FTE_E_FD_NO_IPERSIST_INTERFACE),
            ITF::FTE_E_FD_IFILTER_INIT_FAILED => RawError::Kind(ITF::FTE_E_FD_IFILTER_INIT_FAILED),
            ITF::FTE_E_FD_FAILED_TO_LOAD_IFILTER => RawError::Kind(ITF::FTE_E_FD_FAILED_TO_LOAD_IFILTER),
            ITF::FTE_E_FD_DOC_TIMEOUT => RawError::Kind(ITF::FTE_E_FD_DOC_TIMEOUT),
            ITF::FTE_E_FD_UNEXPECTED_EXIT => RawError::Kind(ITF::FTE_E_FD_UNEXPECTED_EXIT),
            ITF::FTE_E_FD_DOC_UNEXPECTED_EXIT => RawError::Kind(ITF::FTE_E_FD_DOC_UNEXPECTED_EXIT),
            ITF::FTE_E_FD_NOISE_NO_TEXT_FILTER => RawError::Kind(ITF::FTE_E_FD_NOISE_NO_TEXT_FILTER),
            ITF::FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER => RawError::Kind(ITF::FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER),
            ITF::FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED => RawError::Kind(ITF::FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED),
            ITF::FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED => RawError::Kind(ITF::FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED),
            ITF::FTE_E_FD_OCCURRENCE_OVERFLOW => RawError::Kind(ITF::FTE_E_FD_OCCURRENCE_OVERFLOW),
            ITF::FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION => RawError::Kind(ITF::FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION),
            ITF::IO_ERR_CONFIGURATION_ERROR => RawError::Kind(ITF::IO_ERR_CONFIGURATION_ERROR),
            ITF::IO_ERR_DRIVER_ERROR => RawError::Kind(ITF::IO_ERR_DRIVER_ERROR),
            ITF::IO_ERR_PARITY => RawError::Kind(ITF::IO_ERR_PARITY),
            ITF::IO_ERR_SEEK_ERROR => RawError::Kind(ITF::IO_ERR_SEEK_ERROR),
            ITF::IO_ERR_BAD_BLOCK => RawError::Kind(ITF::IO_ERR_BAD_BLOCK),
            ITF::IO_ERR_OVERRUN_ERROR => RawError::Kind(ITF::IO_ERR_OVERRUN_ERROR),
            ITF::IO_ERR_TIMEOUT => RawError::Kind(ITF::IO_ERR_TIMEOUT),
            ITF::IO_ERR_SEQUENCE => RawError::Kind(ITF::IO_ERR_SEQUENCE),
            ITF::IO_ERR_CONTROLLER_ERROR => RawError::Kind(ITF::IO_ERR_CONTROLLER_ERROR),
            ITF::IO_ERR_INTERNAL_ERROR => RawError::Kind(ITF::IO_ERR_INTERNAL_ERROR),
            ITF::IO_ERR_INCORRECT_IRQL => RawError::Kind(ITF::IO_ERR_INCORRECT_IRQL),
            ITF::IO_ERR_INVALID_IOBASE => RawError::Kind(ITF::IO_ERR_INVALID_IOBASE),
            ITF::IO_ERR_NOT_READY => RawError::Kind(ITF::IO_ERR_NOT_READY),
            ITF::IO_ERR_INVALID_REQUEST => RawError::Kind(ITF::IO_ERR_INVALID_REQUEST),
            ITF::IO_ERR_VERSION => RawError::Kind(ITF::IO_ERR_VERSION),
            ITF::IO_ERR_LAYERED_FAILURE => RawError::Kind(ITF::IO_ERR_LAYERED_FAILURE),
            ITF::IO_ERR_RESET => RawError::Kind(ITF::IO_ERR_RESET),
            ITF::IO_ERR_PROTOCOL => RawError::Kind(ITF::IO_ERR_PROTOCOL),
            ITF::IO_ERR_MEMORY_CONFLICT_DETECTED => RawError::Kind(ITF::IO_ERR_MEMORY_CONFLICT_DETECTED),
            ITF::IO_ERR_PORT_CONFLICT_DETECTED => RawError::Kind(ITF::IO_ERR_PORT_CONFLICT_DETECTED),
            ITF::IO_ERR_DMA_CONFLICT_DETECTED => RawError::Kind(ITF::IO_ERR_DMA_CONFLICT_DETECTED),
            ITF::IO_ERR_IRQ_CONFLICT_DETECTED => RawError::Kind(ITF::IO_ERR_IRQ_CONFLICT_DETECTED),
            ITF::IO_ERR_BAD_FIRMWARE => RawError::Kind(ITF::IO_ERR_BAD_FIRMWARE),
            ITF::IO_ERR_DMA_RESOURCE_CONFLICT => RawError::Kind(ITF::IO_ERR_DMA_RESOURCE_CONFLICT),
            ITF::IO_ERR_INTERRUPT_RESOURCE_CONFLICT => RawError::Kind(ITF::IO_ERR_INTERRUPT_RESOURCE_CONFLICT),
            ITF::IO_ERR_MEMORY_RESOURCE_CONFLICT => RawError::Kind(ITF::IO_ERR_MEMORY_RESOURCE_CONFLICT),
            ITF::IO_ERR_PORT_RESOURCE_CONFLICT => RawError::Kind(ITF::IO_ERR_PORT_RESOURCE_CONFLICT),
            ITF::IO_BAD_BLOCK_WITH_NAME => RawError::Kind(ITF::IO_BAD_BLOCK_WITH_NAME),
            ITF::IO_FILE_SYSTEM_CORRUPT => RawError::Kind(ITF::IO_FILE_SYSTEM_CORRUPT),
            ITF::IO_FILE_QUOTA_CORRUPT => RawError::Kind(ITF::IO_FILE_QUOTA_CORRUPT),
            ITF::IO_SYSTEM_SLEEP_FAILED => RawError::Kind(ITF::IO_SYSTEM_SLEEP_FAILED),
            ITF::IO_DUMP_POINTER_FAILURE => RawError::Kind(ITF::IO_DUMP_POINTER_FAILURE),
            ITF::IO_DUMP_DRIVER_LOAD_FAILURE => RawError::Kind(ITF::IO_DUMP_DRIVER_LOAD_FAILURE),
            ITF::IO_DUMP_INITIALIZATION_FAILURE => RawError::Kind(ITF::IO_DUMP_INITIALIZATION_FAILURE),
            ITF::IO_DUMP_DUMPFILE_CONFLICT => RawError::Kind(ITF::IO_DUMP_DUMPFILE_CONFLICT),
            ITF::IO_DUMP_DIRECT_CONFIG_FAILED => RawError::Kind(ITF::IO_DUMP_DIRECT_CONFIG_FAILED),
            ITF::IO_DUMP_PAGE_CONFIG_FAILED => RawError::Kind(ITF::IO_DUMP_PAGE_CONFIG_FAILED),
            ITF::IO_FILE_SYSTEM_CORRUPT_WITH_NAME => RawError::Kind(ITF::IO_FILE_SYSTEM_CORRUPT_WITH_NAME),
            ITF::IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER => RawError::Kind(ITF::IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER),
            ITF::IO_ERR_PORT_TIMEOUT => RawError::Kind(ITF::IO_ERR_PORT_TIMEOUT),
            ITF::IO_ERROR_DISK_RESOURCES_EXHAUSTED => RawError::Kind(ITF::IO_ERROR_DISK_RESOURCES_EXHAUSTED),
            ITF::IO_ERROR_IO_HARDWARE_ERROR => RawError::Kind(ITF::IO_ERROR_IO_HARDWARE_ERROR),
            ITF::ES_E_INVALID_RESPONSE => RawError::Kind(ITF::ES_E_INVALID_RESPONSE),
            ITF::ES_E_UNPROVISIONED_HARDWARE => RawError::Kind(ITF::ES_E_UNPROVISIONED_HARDWARE),
            ITF::ES_E_UNSUPPORTED_HARDWARE => RawError::Kind(ITF::ES_E_UNSUPPORTED_HARDWARE),
            ITF::ES_E_INCOMPLETE_COMMAND => RawError::Kind(ITF::ES_E_INCOMPLETE_COMMAND),
            ITF::ES_E_BAD_SEQUENCE => RawError::Kind(ITF::ES_E_BAD_SEQUENCE),
            ITF::ES_E_NO_PROBE => RawError::Kind(ITF::ES_E_NO_PROBE),
            ITF::ES_E_INVALID_SILO => RawError::Kind(ITF::ES_E_INVALID_SILO),
            ITF::ES_E_INVALID_CAPABILITY => RawError::Kind(ITF::ES_E_INVALID_CAPABILITY),
            ITF::ES_E_GROUP_POLICY_FORBIDDEN_USE => RawError::Kind(ITF::ES_E_GROUP_POLICY_FORBIDDEN_USE),
            ITF::ES_E_GROUP_POLICY_FORBIDDEN_OPERATION => RawError::Kind(ITF::ES_E_GROUP_POLICY_FORBIDDEN_OPERATION),
            ITF::ES_E_INVALID_PARAM_COMBINATION => RawError::Kind(ITF::ES_E_INVALID_PARAM_COMBINATION),
            ITF::ES_E_INVALID_PARAM_LENGTH => RawError::Kind(ITF::ES_E_INVALID_PARAM_LENGTH),
            ITF::ES_E_INCONSISTENT_PARAM_LENGTH => RawError::Kind(ITF::ES_E_INCONSISTENT_PARAM_LENGTH),
            ITF::ES_E_NO_AUTHENTICATION_REQUIRED => RawError::Kind(ITF::ES_E_NO_AUTHENTICATION_REQUIRED),
            ITF::GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED => RawError::Kind(ITF::GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED),
            ITF::ES_E_INVALID_FIELD_IDENTIFIER => RawError::Kind(ITF::ES_E_INVALID_FIELD_IDENTIFIER),
            ITF::ES_E_CHALLENGE_MISMATCH => RawError::Kind(ITF::ES_E_CHALLENGE_MISMATCH),
            ITF::ES_E_CHALLENGE_SIZE_MISMATCH => RawError::Kind(ITF::ES_E_CHALLENGE_SIZE_MISMATCH),
            ITF::ES_E_FRIENDLY_NAME_TOO_LONG => RawError::Kind(ITF::ES_E_FRIENDLY_NAME_TOO_LONG),
            ITF::ES_E_SILO_NAME_TOO_LONG => RawError::Kind(ITF::ES_E_SILO_NAME_TOO_LONG),
            ITF::ES_E_PASSWORD_TOO_LONG => RawError::Kind(ITF::ES_E_PASSWORD_TOO_LONG),
            ITF::ES_E_PASSWORD_HINT_TOO_LONG => RawError::Kind(ITF::ES_E_PASSWORD_HINT_TOO_LONG),
            ITF::ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE => RawError::Kind(ITF::ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE),
            ITF::ES_E_DEVICE_DIGEST_MISSING => RawError::Kind(ITF::ES_E_DEVICE_DIGEST_MISSING),
            ITF::ES_E_NOT_AUTHORIZED_UNEXPECTED => RawError::Kind(ITF::ES_E_NOT_AUTHORIZED_UNEXPECTED),
            ITF::ES_E_AUTHORIZED_UNEXPECTED => RawError::Kind(ITF::ES_E_AUTHORIZED_UNEXPECTED),
            ITF::ES_E_PROVISIONED_UNEXPECTED => RawError::Kind(ITF::ES_E_PROVISIONED_UNEXPECTED),
            ITF::ES_E_UNKNOWN_DIGEST_ALGORITHM => RawError::Kind(ITF::ES_E_UNKNOWN_DIGEST_ALGORITHM),
            ITF::QUTIL_E_INVALID_CODEPAGE => RawError::Kind(ITF::QUTIL_E_INVALID_CODEPAGE),
            ITF::FILTER_E_CONTENTINDEXCORRUPT => RawError::Kind(ITF::FILTER_E_CONTENTINDEXCORRUPT),
            ITF::CI_CORRUPT_DATABASE => RawError::Kind(ITF::CI_CORRUPT_DATABASE),
            ITF::CI_CORRUPT_CATALOG => RawError::Kind(ITF::CI_CORRUPT_CATALOG),
            ITF::CI_INVALID_PARTITION => RawError::Kind(ITF::CI_INVALID_PARTITION),
            ITF::CI_INVALID_PRIORITY => RawError::Kind(ITF::CI_INVALID_PRIORITY),
            ITF::CI_NO_STARTING_KEY => RawError::Kind(ITF::CI_NO_STARTING_KEY),
            ITF::CI_OUT_OF_INDEX_IDS => RawError::Kind(ITF::CI_OUT_OF_INDEX_IDS),
            ITF::CI_NO_CATALOG => RawError::Kind(ITF::CI_NO_CATALOG),
            ITF::CI_CORRUPT_FILTER_BUFFER => RawError::Kind(ITF::CI_CORRUPT_FILTER_BUFFER),
            ITF::CI_INVALID_INDEX => RawError::Kind(ITF::CI_INVALID_INDEX),
            ITF::CI_PROPSTORE_INCONSISTENCY => RawError::Kind(ITF::CI_PROPSTORE_INCONSISTENCY),
            ITF::CI_INCORRECT_VERSION => RawError::Kind(ITF::CI_INCORRECT_VERSION),
            ITF::CI_E_ENUMERATION_STARTED => RawError::Kind(ITF::CI_E_ENUMERATION_STARTED),
            ITF::CI_E_PROPERTY_TOOLARGE => RawError::Kind(ITF::CI_E_PROPERTY_TOOLARGE),
            ITF::CI_E_CLIENT_FILTER_ABORT => RawError::Kind(ITF::CI_E_CLIENT_FILTER_ABORT),
            ITF::CI_E_CORRUPT_FWIDX => RawError::Kind(ITF::CI_E_CORRUPT_FWIDX),
            ITF::CI_E_DIACRITIC_SETTINGS_DIFFER => RawError::Kind(ITF::CI_E_DIACRITIC_SETTINGS_DIFFER),
            ITF::CI_E_NO_CATALOG_MANAGER => RawError::Kind(ITF::CI_E_NO_CATALOG_MANAGER),
            ITF::FTE_E_NO_PROPERTY_STORE => RawError::Kind(ITF::FTE_E_NO_PROPERTY_STORE),
            ITF::SL_E_SRV_INVALID_PUBLISH_LICENSE => RawError::Kind(ITF::SL_E_SRV_INVALID_PUBLISH_LICENSE),
            ITF::SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE => RawError::Kind(ITF::SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE),
            ITF::SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE => RawError::Kind(ITF::SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE),
            ITF::SL_E_SRV_INVALID_LICENSE_STRUCTURE => RawError::Kind(ITF::SL_E_SRV_INVALID_LICENSE_STRUCTURE),
            ITF::SL_E_SRV_AUTHORIZATION_FAILED => RawError::Kind(ITF::SL_E_SRV_AUTHORIZATION_FAILED),
            ITF::SL_E_SRV_INVALID_BINDING => RawError::Kind(ITF::SL_E_SRV_INVALID_BINDING),
            ITF::SL_E_SRV_SERVER_PONG => RawError::Kind(ITF::SL_E_SRV_SERVER_PONG),
            ITF::SL_E_SRV_INVALID_PAYLOAD => RawError::Kind(ITF::SL_E_SRV_INVALID_PAYLOAD),
            ITF::SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE => RawError::Kind(ITF::SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE),
            ITF::SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND => RawError::Kind(ITF::SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND),
            ITF::SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC => RawError::Kind(ITF::SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC),
            ITF::SL_E_SRV_GENERAL_ERROR => RawError::Kind(ITF::SL_E_SRV_GENERAL_ERROR),
            ITF::SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE => RawError::Kind(ITF::SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE),
            ITF::SL_E_CHPA_INVALID_BINDING => RawError::Kind(ITF::SL_E_CHPA_INVALID_BINDING),
            ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED => RawError::Kind(ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED),
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY => RawError::Kind(ITF::SL_E_CHPA_INVALID_PRODUCT_KEY),
            ITF::SL_E_CHPA_BINDING_NOT_FOUND => RawError::Kind(ITF::SL_E_CHPA_BINDING_NOT_FOUND),
            ITF::SL_E_CHPA_BINDING_MAPPING_NOT_FOUND => RawError::Kind(ITF::SL_E_CHPA_BINDING_MAPPING_NOT_FOUND),
            ITF::SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY => RawError::Kind(ITF::SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY),
            ITF::SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED => RawError::Kind(ITF::SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED),
            ITF::SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND => RawError::Kind(ITF::SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND),
            ITF::SL_E_CHPA_INVALID_PRODUCT_DATA_ID => RawError::Kind(ITF::SL_E_CHPA_INVALID_PRODUCT_DATA_ID),
            ITF::SL_E_CHPA_INVALID_PRODUCT_DATA => RawError::Kind(ITF::SL_E_CHPA_INVALID_PRODUCT_DATA),
            ITF::SL_E_CHPA_SYSTEM_ERROR => RawError::Kind(ITF::SL_E_CHPA_SYSTEM_ERROR),
            ITF::SL_E_CHPA_INVALID_ACTCONFIG_ID => RawError::Kind(ITF::SL_E_CHPA_INVALID_ACTCONFIG_ID),
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH => RawError::Kind(ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH),
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT => RawError::Kind(ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT),
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR => RawError::Kind(ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR),
            ITF::SL_E_CHPA_INVALID_BINDING_URI => RawError::Kind(ITF::SL_E_CHPA_INVALID_BINDING_URI),
            ITF::SL_E_CHPA_NETWORK_ERROR => RawError::Kind(ITF::SL_E_CHPA_NETWORK_ERROR),
            ITF::SL_E_CHPA_DATABASE_ERROR => RawError::Kind(ITF::SL_E_CHPA_DATABASE_ERROR),
            ITF::SL_E_CHPA_INVALID_ARGUMENT => RawError::Kind(ITF::SL_E_CHPA_INVALID_ARGUMENT),
            ITF::SL_E_CHPA_RESPONSE_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_CHPA_RESPONSE_NOT_AVAILABLE),
            ITF::SL_E_CHPA_OEM_SLP_COA0 => RawError::Kind(ITF::SL_E_CHPA_OEM_SLP_COA0),
            ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION => RawError::Kind(ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION),
            ITF::SL_E_CHPA_DMAK_LIMIT_EXCEEDED => RawError::Kind(ITF::SL_E_CHPA_DMAK_LIMIT_EXCEEDED),
            ITF::SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED => RawError::Kind(ITF::SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED),
            ITF::SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND => RawError::Kind(ITF::SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND),
            ITF::SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND => RawError::Kind(ITF::SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND),
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE => RawError::Kind(ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE),
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE => RawError::Kind(ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE),
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE),
            ITF::SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED => RawError::Kind(ITF::SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED),
            ITF::SL_E_CHPA_NO_RULES_TO_ACTIVATE => RawError::Kind(ITF::SL_E_CHPA_NO_RULES_TO_ACTIVATE),
            ITF::SL_E_CHPA_GENERAL_ERROR => RawError::Kind(ITF::SL_E_CHPA_GENERAL_ERROR),
            ITF::SL_E_CHPA_DIGITALMARKER_INVALID_BINDING => RawError::Kind(ITF::SL_E_CHPA_DIGITALMARKER_INVALID_BINDING),
            ITF::SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED => RawError::Kind(ITF::SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED),
            ITF::SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY => RawError::Kind(ITF::SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY),
            ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE => RawError::Kind(ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE),
            ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED => RawError::Kind(ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED),
            ITF::SL_E_INVALID_TEMPLATE_ID => RawError::Kind(ITF::SL_E_INVALID_TEMPLATE_ID),
            ITF::SL_E_INVALID_XML_BLOB => RawError::Kind(ITF::SL_E_INVALID_XML_BLOB),
            ITF::SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND => RawError::Kind(ITF::SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND),
            ITF::SL_E_INVALID_CLIENT_TOKEN => RawError::Kind(ITF::SL_E_INVALID_CLIENT_TOKEN),
            ITF::SL_E_INVALID_OFFLINE_BLOB => RawError::Kind(ITF::SL_E_INVALID_OFFLINE_BLOB),
            ITF::SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND => RawError::Kind(ITF::SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND),
            ITF::SL_E_INVALID_OSVERSION_TEMPLATEID => RawError::Kind(ITF::SL_E_INVALID_OSVERSION_TEMPLATEID),
            ITF::SL_E_OFFLINE_GENUINE_BLOB_REVOKED => RawError::Kind(ITF::SL_E_OFFLINE_GENUINE_BLOB_REVOKED),
            ITF::SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND => RawError::Kind(ITF::SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND),
            ITF::SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA => RawError::Kind(ITF::SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA),
            ITF::SL_E_INVALID_OS_FOR_PRODUCT_KEY => RawError::Kind(ITF::SL_E_INVALID_OS_FOR_PRODUCT_KEY),
            ITF::SL_E_INVALID_FILE_HASH => RawError::Kind(ITF::SL_E_INVALID_FILE_HASH),
            ITF::SL_E_VALIDATION_BLOCKED_PRODUCT_KEY => RawError::Kind(ITF::SL_E_VALIDATION_BLOCKED_PRODUCT_KEY),
            ITF::SL_E_MISMATCHED_KEY_TYPES => RawError::Kind(ITF::SL_E_MISMATCHED_KEY_TYPES),
            ITF::SL_E_VALIDATION_INVALID_PRODUCT_KEY => RawError::Kind(ITF::SL_E_VALIDATION_INVALID_PRODUCT_KEY),
            ITF::SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA => RawError::Kind(ITF::SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA),
            ITF::SL_E_INVALID_LICENSE_STATE => RawError::Kind(ITF::SL_E_INVALID_LICENSE_STATE),
            ITF::SL_E_IP_LOCATION_FALIED => RawError::Kind(ITF::SL_E_IP_LOCATION_FALIED),
            ITF::SL_E_SOFTMOD_EXPLOIT_DETECTED => RawError::Kind(ITF::SL_E_SOFTMOD_EXPLOIT_DETECTED),
            ITF::SL_E_INVALID_TOKEN_DATA => RawError::Kind(ITF::SL_E_INVALID_TOKEN_DATA),
            ITF::SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES => RawError::Kind(ITF::SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES),
            ITF::SL_E_HEALTH_CHECK_FAILED_MUI_FILES => RawError::Kind(ITF::SL_E_HEALTH_CHECK_FAILED_MUI_FILES),
            ITF::SL_E_INVALID_AD_DATA => RawError::Kind(ITF::SL_E_INVALID_AD_DATA),
            ITF::SL_E_INVALID_RSDP_COUNT => RawError::Kind(ITF::SL_E_INVALID_RSDP_COUNT),
            ITF::SL_E_ENGINE_DETECTED_EXPLOIT => RawError::Kind(ITF::SL_E_ENGINE_DETECTED_EXPLOIT),
            ITF::SL_E_NOTIFICATION_BREACH_DETECTED => RawError::Kind(ITF::SL_E_NOTIFICATION_BREACH_DETECTED),
            ITF::SL_E_NOTIFICATION_GRACE_EXPIRED => RawError::Kind(ITF::SL_E_NOTIFICATION_GRACE_EXPIRED),
            ITF::SL_E_NOTIFICATION_OTHER_REASONS => RawError::Kind(ITF::SL_E_NOTIFICATION_OTHER_REASONS),
            ITF::SL_E_NON_GENUINE_STATUS_LAST => RawError::Kind(ITF::SL_E_NON_GENUINE_STATUS_LAST),
            ITF::SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND => RawError::Kind(ITF::SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND),
            ITF::SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID => RawError::Kind(ITF::SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID),
            ITF::SL_E_CHPA_UNKNOWN_PROPERTY_NAME => RawError::Kind(ITF::SL_E_CHPA_UNKNOWN_PROPERTY_NAME),
            ITF::SL_E_CHPA_UNKNOWN_PROPERTY_ID => RawError::Kind(ITF::SL_E_CHPA_UNKNOWN_PROPERTY_ID),
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING),
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING),
            ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING),
            ITF::SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML),
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY),
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY),
            ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY),
            ITF::SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE => RawError::Kind(ITF::SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE),
            ITF::SL_E_CHPA_PRODUCT_KEY_BEING_USED => RawError::Kind(ITF::SL_E_CHPA_PRODUCT_KEY_BEING_USED),
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD),
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD => RawError::Kind(ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD),
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_LICENSE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_INVALID_LICENSE),
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE),
            ITF::SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS),
            ITF::SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY),
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_HANDLE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_INVALID_HANDLE),
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH),
            ITF::SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER),
            ITF::SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED),
            ITF::SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED),
            ITF::SL_REMAPPING_SP_STATUS_GENERIC_FAILURE => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_GENERIC_FAILURE),
            ITF::SL_REMAPPING_SP_STATUS_INVALIDARG => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_INVALIDARG),
            ITF::SL_REMAPPING_SP_STATUS_ALREADY_EXISTS => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_ALREADY_EXISTS),
            ITF::SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER),
            ITF::SL_REMAPPING_SP_STATUS_INVALIDDATA => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_INVALIDDATA),
            ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL),
            ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION),
            ITF::SL_REMAPPING_SP_STATUS_NO_MORE_DATA => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_NO_MORE_DATA),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT),
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED),
            ITF::SL_REMAPPING_SP_PUB_TS_REARMED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_REARMED),
            ITF::SL_REMAPPING_SP_PUB_TS_RECREATED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_RECREATED),
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND),
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS),
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG),
            ITF::SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED),
            ITF::SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG),
            ITF::SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING),
            ITF::SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS),
            ITF::SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND),
            ITF::SL_REMAPPING_SP_PUB_TIMER_EXPIRED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TIMER_EXPIRED),
            ITF::SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG),
            ITF::SL_REMAPPING_SP_PUB_TS_FULL => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_FULL),
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY),
            ITF::SL_REMAPPING_SP_PUB_TIMER_READ_ONLY => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TIMER_READ_ONLY),
            ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY),
            ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND),
            ITF::SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED),
            ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND),
            ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH),
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH),
            ITF::SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION),
            ITF::SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED),
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER),
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED),
            ITF::SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT => RawError::Kind(ITF::SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT),
            ITF::SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER => RawError::Kind(ITF::SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER),
            ITF::SL_E_INVALID_CONTEXT => RawError::Kind(ITF::SL_E_INVALID_CONTEXT),
            ITF::SL_E_TOKEN_STORE_INVALID_STATE => RawError::Kind(ITF::SL_E_TOKEN_STORE_INVALID_STATE),
            ITF::SL_E_EVALUATION_FAILED => RawError::Kind(ITF::SL_E_EVALUATION_FAILED),
            ITF::SL_E_NOT_EVALUATED => RawError::Kind(ITF::SL_E_NOT_EVALUATED),
            ITF::SL_E_NOT_ACTIVATED => RawError::Kind(ITF::SL_E_NOT_ACTIVATED),
            ITF::SL_E_INVALID_GUID => RawError::Kind(ITF::SL_E_INVALID_GUID),
            ITF::SL_E_TOKSTO_TOKEN_NOT_FOUND => RawError::Kind(ITF::SL_E_TOKSTO_TOKEN_NOT_FOUND),
            ITF::SL_E_TOKSTO_NO_PROPERTIES => RawError::Kind(ITF::SL_E_TOKSTO_NO_PROPERTIES),
            ITF::SL_E_TOKSTO_NOT_INITIALIZED => RawError::Kind(ITF::SL_E_TOKSTO_NOT_INITIALIZED),
            ITF::SL_E_TOKSTO_ALREADY_INITIALIZED => RawError::Kind(ITF::SL_E_TOKSTO_ALREADY_INITIALIZED),
            ITF::SL_E_TOKSTO_NO_ID_SET => RawError::Kind(ITF::SL_E_TOKSTO_NO_ID_SET),
            ITF::SL_E_TOKSTO_CANT_CREATE_FILE => RawError::Kind(ITF::SL_E_TOKSTO_CANT_CREATE_FILE),
            ITF::SL_E_TOKSTO_CANT_WRITE_TO_FILE => RawError::Kind(ITF::SL_E_TOKSTO_CANT_WRITE_TO_FILE),
            ITF::SL_E_TOKSTO_CANT_READ_FILE => RawError::Kind(ITF::SL_E_TOKSTO_CANT_READ_FILE),
            ITF::SL_E_TOKSTO_CANT_PARSE_PROPERTIES => RawError::Kind(ITF::SL_E_TOKSTO_CANT_PARSE_PROPERTIES),
            ITF::SL_E_TOKSTO_PROPERTY_NOT_FOUND => RawError::Kind(ITF::SL_E_TOKSTO_PROPERTY_NOT_FOUND),
            ITF::SL_E_TOKSTO_INVALID_FILE => RawError::Kind(ITF::SL_E_TOKSTO_INVALID_FILE),
            ITF::SL_E_TOKSTO_CANT_CREATE_MUTEX => RawError::Kind(ITF::SL_E_TOKSTO_CANT_CREATE_MUTEX),
            ITF::SL_E_TOKSTO_CANT_ACQUIRE_MUTEX => RawError::Kind(ITF::SL_E_TOKSTO_CANT_ACQUIRE_MUTEX),
            ITF::SL_E_TOKSTO_NO_TOKEN_DATA => RawError::Kind(ITF::SL_E_TOKSTO_NO_TOKEN_DATA),
            ITF::SL_E_EUL_CONSUMPTION_FAILED => RawError::Kind(ITF::SL_E_EUL_CONSUMPTION_FAILED),
            ITF::SL_E_PKEY_INVALID_CONFIG => RawError::Kind(ITF::SL_E_PKEY_INVALID_CONFIG),
            ITF::SL_E_PKEY_INVALID_UNIQUEID => RawError::Kind(ITF::SL_E_PKEY_INVALID_UNIQUEID),
            ITF::SL_E_PKEY_INVALID_ALGORITHM => RawError::Kind(ITF::SL_E_PKEY_INVALID_ALGORITHM),
            ITF::SL_E_PKEY_INTERNAL_ERROR => RawError::Kind(ITF::SL_E_PKEY_INTERNAL_ERROR),
            ITF::SL_E_LICENSE_INVALID_ADDON_INFO => RawError::Kind(ITF::SL_E_LICENSE_INVALID_ADDON_INFO),
            ITF::SL_E_HWID_ERROR => RawError::Kind(ITF::SL_E_HWID_ERROR),
            ITF::SL_E_PKEY_INVALID_KEYCHANGE1 => RawError::Kind(ITF::SL_E_PKEY_INVALID_KEYCHANGE1),
            ITF::SL_E_PKEY_INVALID_KEYCHANGE2 => RawError::Kind(ITF::SL_E_PKEY_INVALID_KEYCHANGE2),
            ITF::SL_E_PKEY_INVALID_KEYCHANGE3 => RawError::Kind(ITF::SL_E_PKEY_INVALID_KEYCHANGE3),
            ITF::SL_E_POLICY_OTHERINFO_MISMATCH => RawError::Kind(ITF::SL_E_POLICY_OTHERINFO_MISMATCH),
            ITF::SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID => RawError::Kind(ITF::SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID),
            ITF::SL_E_SECURE_STORE_ID_MISMATCH => RawError::Kind(ITF::SL_E_SECURE_STORE_ID_MISMATCH),
            ITF::SL_E_INVALID_RULESET_RULE => RawError::Kind(ITF::SL_E_INVALID_RULESET_RULE),
            ITF::SL_E_INVALID_CONTEXT_DATA => RawError::Kind(ITF::SL_E_INVALID_CONTEXT_DATA),
            ITF::SL_E_INVALID_HASH => RawError::Kind(ITF::SL_E_INVALID_HASH),
            ITF::SL_E_WINDOWS_VERSION_MISMATCH => RawError::Kind(ITF::SL_E_WINDOWS_VERSION_MISMATCH),
            ITF::SL_E_ACTIVATION_IN_PROGRESS => RawError::Kind(ITF::SL_E_ACTIVATION_IN_PROGRESS),
            ITF::SL_E_STORE_UPGRADE_TOKEN_REQUIRED => RawError::Kind(ITF::SL_E_STORE_UPGRADE_TOKEN_REQUIRED),
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION => RawError::Kind(ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION),
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_PID => RawError::Kind(ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_PID),
            ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED => RawError::Kind(ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED),
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION => RawError::Kind(ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION),
            ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED => RawError::Kind(ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED),
            ITF::SL_E_INTERNAL_ERROR => RawError::Kind(ITF::SL_E_INTERNAL_ERROR),
            ITF::SL_E_RIGHT_NOT_CONSUMED => RawError::Kind(ITF::SL_E_RIGHT_NOT_CONSUMED),
            ITF::SL_E_USE_LICENSE_NOT_INSTALLED => RawError::Kind(ITF::SL_E_USE_LICENSE_NOT_INSTALLED),
            ITF::SL_E_MISMATCHED_PKEY_RANGE => RawError::Kind(ITF::SL_E_MISMATCHED_PKEY_RANGE),
            ITF::SL_E_MISMATCHED_PID => RawError::Kind(ITF::SL_E_MISMATCHED_PID),
            ITF::SL_E_EXTERNAL_SIGNATURE_NOT_FOUND => RawError::Kind(ITF::SL_E_EXTERNAL_SIGNATURE_NOT_FOUND),
            ITF::SL_E_RAC_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_RAC_NOT_AVAILABLE),
            ITF::SL_E_SPC_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_SPC_NOT_AVAILABLE),
            ITF::SL_E_GRACE_TIME_EXPIRED => RawError::Kind(ITF::SL_E_GRACE_TIME_EXPIRED),
            ITF::SL_E_MISMATCHED_APPID => RawError::Kind(ITF::SL_E_MISMATCHED_APPID),
            ITF::SL_E_NO_PID_CONFIG_DATA => RawError::Kind(ITF::SL_E_NO_PID_CONFIG_DATA),
            ITF::SL_E_MISMATCHED_SECURITY_PROCESSOR => RawError::Kind(ITF::SL_E_MISMATCHED_SECURITY_PROCESSOR),
            ITF::SL_E_OUT_OF_TOLERANCE => RawError::Kind(ITF::SL_E_OUT_OF_TOLERANCE),
            ITF::SL_E_INVALID_PKEY => RawError::Kind(ITF::SL_E_INVALID_PKEY),
            ITF::SL_E_LICENSE_FILE_NOT_INSTALLED => RawError::Kind(ITF::SL_E_LICENSE_FILE_NOT_INSTALLED),
            ITF::SL_E_VALUE_NOT_FOUND => RawError::Kind(ITF::SL_E_VALUE_NOT_FOUND),
            ITF::SL_E_RIGHT_NOT_GRANTED => RawError::Kind(ITF::SL_E_RIGHT_NOT_GRANTED),
            ITF::SL_E_PKEY_NOT_INSTALLED => RawError::Kind(ITF::SL_E_PKEY_NOT_INSTALLED),
            ITF::SL_E_PRODUCT_SKU_NOT_INSTALLED => RawError::Kind(ITF::SL_E_PRODUCT_SKU_NOT_INSTALLED),
            ITF::SL_E_NOT_SUPPORTED => RawError::Kind(ITF::SL_E_NOT_SUPPORTED),
            ITF::SL_E_PUBLISHING_LICENSE_NOT_INSTALLED => RawError::Kind(ITF::SL_E_PUBLISHING_LICENSE_NOT_INSTALLED),
            ITF::SL_E_LICENSE_SERVER_URL_NOT_FOUND => RawError::Kind(ITF::SL_E_LICENSE_SERVER_URL_NOT_FOUND),
            ITF::SL_E_INVALID_EVENT_ID => RawError::Kind(ITF::SL_E_INVALID_EVENT_ID),
            ITF::SL_E_EVENT_NOT_REGISTERED => RawError::Kind(ITF::SL_E_EVENT_NOT_REGISTERED),
            ITF::SL_E_EVENT_ALREADY_REGISTERED => RawError::Kind(ITF::SL_E_EVENT_ALREADY_REGISTERED),
            ITF::SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE),
            ITF::SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED => RawError::Kind(ITF::SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED),
            ITF::SL_E_DATATYPE_MISMATCHED => RawError::Kind(ITF::SL_E_DATATYPE_MISMATCHED),
            ITF::SL_E_INVALID_LICENSE => RawError::Kind(ITF::SL_E_INVALID_LICENSE),
            ITF::SL_E_INVALID_PACKAGE => RawError::Kind(ITF::SL_E_INVALID_PACKAGE),
            ITF::SL_E_VALIDITY_TIME_EXPIRED => RawError::Kind(ITF::SL_E_VALIDITY_TIME_EXPIRED),
            ITF::SL_E_LICENSE_AUTHORIZATION_FAILED => RawError::Kind(ITF::SL_E_LICENSE_AUTHORIZATION_FAILED),
            ITF::SL_E_LICENSE_DECRYPTION_FAILED => RawError::Kind(ITF::SL_E_LICENSE_DECRYPTION_FAILED),
            ITF::SL_E_WINDOWS_INVALID_LICENSE_STATE => RawError::Kind(ITF::SL_E_WINDOWS_INVALID_LICENSE_STATE),
            ITF::SL_E_LUA_ACCESSDENIED => RawError::Kind(ITF::SL_E_LUA_ACCESSDENIED),
            ITF::SL_E_PROXY_KEY_NOT_FOUND => RawError::Kind(ITF::SL_E_PROXY_KEY_NOT_FOUND),
            ITF::SL_E_TAMPER_DETECTED => RawError::Kind(ITF::SL_E_TAMPER_DETECTED),
            ITF::SL_E_POLICY_CACHE_INVALID => RawError::Kind(ITF::SL_E_POLICY_CACHE_INVALID),
            ITF::SL_E_INVALID_RUNNING_MODE => RawError::Kind(ITF::SL_E_INVALID_RUNNING_MODE),
            ITF::SL_E_SLP_NOT_SIGNED => RawError::Kind(ITF::SL_E_SLP_NOT_SIGNED),
            ITF::SL_E_CIDIID_INVALID_DATA => RawError::Kind(ITF::SL_E_CIDIID_INVALID_DATA),
            ITF::SL_E_CIDIID_INVALID_VERSION => RawError::Kind(ITF::SL_E_CIDIID_INVALID_VERSION),
            ITF::SL_E_CIDIID_VERSION_NOT_SUPPORTED => RawError::Kind(ITF::SL_E_CIDIID_VERSION_NOT_SUPPORTED),
            ITF::SL_E_CIDIID_INVALID_DATA_LENGTH => RawError::Kind(ITF::SL_E_CIDIID_INVALID_DATA_LENGTH),
            ITF::SL_E_CIDIID_NOT_DEPOSITED => RawError::Kind(ITF::SL_E_CIDIID_NOT_DEPOSITED),
            ITF::SL_E_CIDIID_MISMATCHED => RawError::Kind(ITF::SL_E_CIDIID_MISMATCHED),
            ITF::SL_E_INVALID_BINDING_BLOB => RawError::Kind(ITF::SL_E_INVALID_BINDING_BLOB),
            ITF::SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED => RawError::Kind(ITF::SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED),
            ITF::SL_E_EUL_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_EUL_NOT_AVAILABLE),
            ITF::SL_E_VL_NOT_WINDOWS_SLP => RawError::Kind(ITF::SL_E_VL_NOT_WINDOWS_SLP),
            ITF::SL_E_VL_NOT_ENOUGH_COUNT => RawError::Kind(ITF::SL_E_VL_NOT_ENOUGH_COUNT),
            ITF::SL_E_VL_BINDING_SERVICE_NOT_ENABLED => RawError::Kind(ITF::SL_E_VL_BINDING_SERVICE_NOT_ENABLED),
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED => RawError::Kind(ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED),
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH => RawError::Kind(ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH),
            ITF::SL_E_PROXY_POLICY_NOT_UPDATED => RawError::Kind(ITF::SL_E_PROXY_POLICY_NOT_UPDATED),
            ITF::SL_E_CIDIID_INVALID_CHECK_DIGITS => RawError::Kind(ITF::SL_E_CIDIID_INVALID_CHECK_DIGITS),
            ITF::SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND => RawError::Kind(ITF::SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND),
            ITF::SL_E_INVALID_PRODUCT_KEY => RawError::Kind(ITF::SL_E_INVALID_PRODUCT_KEY),
            ITF::SL_E_BLOCKED_PRODUCT_KEY => RawError::Kind(ITF::SL_E_BLOCKED_PRODUCT_KEY),
            ITF::SL_E_DUPLICATE_POLICY => RawError::Kind(ITF::SL_E_DUPLICATE_POLICY),
            ITF::SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE => RawError::Kind(ITF::SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE),
            ITF::SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED => RawError::Kind(ITF::SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED),
            ITF::SL_E_BASE_SKU_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_BASE_SKU_NOT_AVAILABLE),
            ITF::SL_E_VL_MACHINE_NOT_BOUND => RawError::Kind(ITF::SL_E_VL_MACHINE_NOT_BOUND),
            ITF::SL_E_SLP_MISSING_ACPI_SLIC => RawError::Kind(ITF::SL_E_SLP_MISSING_ACPI_SLIC),
            ITF::SL_E_SLP_MISSING_SLP_MARKER => RawError::Kind(ITF::SL_E_SLP_MISSING_SLP_MARKER),
            ITF::SL_E_SLP_BAD_FORMAT => RawError::Kind(ITF::SL_E_SLP_BAD_FORMAT),
            ITF::SL_E_INVALID_PACKAGE_VERSION => RawError::Kind(ITF::SL_E_INVALID_PACKAGE_VERSION),
            ITF::SL_E_PKEY_INVALID_UPGRADE => RawError::Kind(ITF::SL_E_PKEY_INVALID_UPGRADE),
            ITF::SL_E_ISSUANCE_LICENSE_NOT_INSTALLED => RawError::Kind(ITF::SL_E_ISSUANCE_LICENSE_NOT_INSTALLED),
            ITF::SL_E_SLP_OEM_CERT_MISSING => RawError::Kind(ITF::SL_E_SLP_OEM_CERT_MISSING),
            ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED => RawError::Kind(ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED),
            ITF::SL_E_DEPENDENT_PROPERTY_NOT_SET => RawError::Kind(ITF::SL_E_DEPENDENT_PROPERTY_NOT_SET),
            ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2 => RawError::Kind(ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2),
            ITF::SL_E_MISMATCHED_PRODUCT_SKU => RawError::Kind(ITF::SL_E_MISMATCHED_PRODUCT_SKU),
            ITF::SL_E_OPERATION_NOT_ALLOWED => RawError::Kind(ITF::SL_E_OPERATION_NOT_ALLOWED),
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED => RawError::Kind(ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED),
            ITF::SL_E_VL_INVALID_TIMESTAMP => RawError::Kind(ITF::SL_E_VL_INVALID_TIMESTAMP),
            ITF::SL_E_PLUGIN_INVALID_MANIFEST => RawError::Kind(ITF::SL_E_PLUGIN_INVALID_MANIFEST),
            ITF::SL_E_APPLICATION_POLICIES_MISSING => RawError::Kind(ITF::SL_E_APPLICATION_POLICIES_MISSING),
            ITF::SL_E_APPLICATION_POLICIES_NOT_LOADED => RawError::Kind(ITF::SL_E_APPLICATION_POLICIES_NOT_LOADED),
            ITF::SL_E_VL_BINDING_SERVICE_UNAVAILABLE => RawError::Kind(ITF::SL_E_VL_BINDING_SERVICE_UNAVAILABLE),
            ITF::SL_E_SERVICE_STOPPING => RawError::Kind(ITF::SL_E_SERVICE_STOPPING),
            ITF::SL_E_PLUGIN_NOT_REGISTERED => RawError::Kind(ITF::SL_E_PLUGIN_NOT_REGISTERED),
            ITF::SL_E_AUTHN_WRONG_VERSION => RawError::Kind(ITF::SL_E_AUTHN_WRONG_VERSION),
            ITF::SL_E_AUTHN_MISMATCHED_KEY => RawError::Kind(ITF::SL_E_AUTHN_MISMATCHED_KEY),
            ITF::SL_E_AUTHN_CHALLENGE_NOT_SET => RawError::Kind(ITF::SL_E_AUTHN_CHALLENGE_NOT_SET),
            ITF::SL_E_AUTHN_CANT_VERIFY => RawError::Kind(ITF::SL_E_AUTHN_CANT_VERIFY),
            ITF::SL_E_SERVICE_RUNNING => RawError::Kind(ITF::SL_E_SERVICE_RUNNING),
            ITF::SL_E_SLP_INVALID_MARKER_VERSION => RawError::Kind(ITF::SL_E_SLP_INVALID_MARKER_VERSION),
            ITF::SL_E_INVALID_PRODUCT_KEY_TYPE => RawError::Kind(ITF::SL_E_INVALID_PRODUCT_KEY_TYPE),
            ITF::SL_E_CIDIID_MISMATCHED_PKEY => RawError::Kind(ITF::SL_E_CIDIID_MISMATCHED_PKEY),
            ITF::SL_E_CIDIID_NOT_BOUND => RawError::Kind(ITF::SL_E_CIDIID_NOT_BOUND),
            ITF::SL_E_LICENSE_NOT_BOUND => RawError::Kind(ITF::SL_E_LICENSE_NOT_BOUND),
            ITF::SL_E_VL_AD_AO_NOT_FOUND => RawError::Kind(ITF::SL_E_VL_AD_AO_NOT_FOUND),
            ITF::SL_E_VL_AD_AO_NAME_TOO_LONG => RawError::Kind(ITF::SL_E_VL_AD_AO_NAME_TOO_LONG),
            ITF::SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED => RawError::Kind(ITF::SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED),
            ITF::SL_E_NOT_GENUINE => RawError::Kind(ITF::SL_E_NOT_GENUINE),
            ITF::SL_E_EDITION_MISMATCHED => RawError::Kind(ITF::SL_E_EDITION_MISMATCHED),
            ITF::SL_E_TKA_CHALLENGE_EXPIRED => RawError::Kind(ITF::SL_E_TKA_CHALLENGE_EXPIRED),
            ITF::SL_E_TKA_SILENT_ACTIVATION_FAILURE => RawError::Kind(ITF::SL_E_TKA_SILENT_ACTIVATION_FAILURE),
            ITF::SL_E_TKA_INVALID_CERT_CHAIN => RawError::Kind(ITF::SL_E_TKA_INVALID_CERT_CHAIN),
            ITF::SL_E_TKA_GRANT_NOT_FOUND => RawError::Kind(ITF::SL_E_TKA_GRANT_NOT_FOUND),
            ITF::SL_E_TKA_CERT_NOT_FOUND => RawError::Kind(ITF::SL_E_TKA_CERT_NOT_FOUND),
            ITF::SL_E_TKA_INVALID_SKU_ID => RawError::Kind(ITF::SL_E_TKA_INVALID_SKU_ID),
            ITF::SL_E_TKA_INVALID_BLOB => RawError::Kind(ITF::SL_E_TKA_INVALID_BLOB),
            ITF::SL_E_TKA_TAMPERED_CERT_CHAIN => RawError::Kind(ITF::SL_E_TKA_TAMPERED_CERT_CHAIN),
            ITF::SL_E_TKA_CHALLENGE_MISMATCH => RawError::Kind(ITF::SL_E_TKA_CHALLENGE_MISMATCH),
            ITF::SL_E_TKA_INVALID_CERTIFICATE => RawError::Kind(ITF::SL_E_TKA_INVALID_CERTIFICATE),
            ITF::SL_E_TKA_INVALID_SMARTCARD => RawError::Kind(ITF::SL_E_TKA_INVALID_SMARTCARD),
            ITF::SL_E_TKA_FAILED_GRANT_PARSING => RawError::Kind(ITF::SL_E_TKA_FAILED_GRANT_PARSING),
            ITF::SL_E_TKA_INVALID_THUMBPRINT => RawError::Kind(ITF::SL_E_TKA_INVALID_THUMBPRINT),
            ITF::SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND => RawError::Kind(ITF::SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND),
            ITF::SL_E_TKA_CRITERIA_MISMATCH => RawError::Kind(ITF::SL_E_TKA_CRITERIA_MISMATCH),
            ITF::SL_E_TKA_TPID_MISMATCH => RawError::Kind(ITF::SL_E_TKA_TPID_MISMATCH),
            ITF::SL_E_TKA_SOFT_CERT_DISALLOWED => RawError::Kind(ITF::SL_E_TKA_SOFT_CERT_DISALLOWED),
            ITF::SL_E_TKA_SOFT_CERT_INVALID => RawError::Kind(ITF::SL_E_TKA_SOFT_CERT_INVALID),
            ITF::SL_E_TKA_CERT_CNG_NOT_AVAILABLE => RawError::Kind(ITF::SL_E_TKA_CERT_CNG_NOT_AVAILABLE),
            ITF::E_RM_UNKNOWN_ERROR => RawError::Kind(ITF::E_RM_UNKNOWN_ERROR),
            ITF::SL_E_VALIDITY_PERIOD_EXPIRED => RawError::Kind(ITF::SL_E_VALIDITY_PERIOD_EXPIRED),
            ITF::SL_E_IA_THROTTLE_LIMIT_EXCEEDED => RawError::Kind(ITF::SL_E_IA_THROTTLE_LIMIT_EXCEEDED),
            ITF::SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM => RawError::Kind(ITF::SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM),
            ITF::SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED => RawError::Kind(ITF::SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED),
            ITF::SL_E_IA_ID_MISMATCH => RawError::Kind(ITF::SL_E_IA_ID_MISMATCH),
            ITF::SL_E_IA_MACHINE_NOT_BOUND => RawError::Kind(ITF::SL_E_IA_MACHINE_NOT_BOUND),
            ITF::SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION => RawError::Kind(ITF::SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            ITF::OLE_S_USEREG => "Use the registry database to provide the requested information.",
            ITF::OLE_S_STATIC => "Success, but static.",
            ITF::MS_S_PENDING => "Sample update is not yet complete.",
            ITF::OLE_S_MAC_CLIPFORMAT => "Macintosh clipboard format.",
            ITF::MS_S_NOUPDATE => "Sample was not updated after forced completion.",
            ITF::MS_S_ENDOFSTREAM => "End of stream. Sample not updated.",
            ITF::OLE_S_LAST => "Description is missing",
            ITF::DRAGDROP_S_DROP => "Successful drop took place.",
            ITF::DRAGDROP_S_CANCEL => "Drag-drop operation canceled.",
            ITF::DRAGDROP_S_USEDEFAULTCURSORS => "Use the default cursor.",
            ITF::VFW_S_NO_MORE_ITEMS => "DirectShow: There are no more items in the list.",
            ITF::DATA_S_SAMEFORMATETC => "Data has same FORMATETC.",
            ITF::VIEW_S_ALREADY_FROZEN => "View is already frozen.",
            ITF::CACHE_S_FORMATETC_NOTSUPPORTED => "FORMATETC not supported.",
            ITF::CACHE_S_SAMECACHE => "Same cache.",
            ITF::CACHE_S_SOMECACHES_NOTUPDATED => "Some cache(s) not updated.",
            ITF::OLEOBJ_S_INVALIDVERB => "Invalid verb for OLE object.",
            ITF::OLEOBJ_S_CANNOT_DOVERB_NOW => "Verb number is valid but verb cannot be done now.",
            ITF::OLEOBJ_S_INVALIDHWND => "Invalid window handle passed.",
            ITF::INPLACE_S_TRUNCATED => "Message is too long; some of it had to be truncated before displaying.",
            ITF::CONVERT10_S_NO_PRESENTATION => "Unable to convert OLESTREAM to IStorage.",
            ITF::MK_S_REDUCED_TO_SELF => "Moniker reduced to itself.",
            ITF::MK_S_ME => "Common prefix is this moniker.",
            ITF::MK_S_HIM => "Common prefix is input moniker.",
            ITF::MK_S_US => "Common prefix is both monikers.",
            ITF::MK_S_MONIKERALREADYREGISTERED => "Moniker is already registered in running object table.",
            ITF::MK_S_ASYNCHRONOUS => "Description is missing",
            ITF::EVENT_S_SOME_SUBSCRIBERS_FAILED => "An event was able to invoke some but not all of the subscribers.",
            ITF::IMAPI_S_PROPERTIESIGNORED => "An unknown property was passed in a property set and it was ignored.",
            ITF::MPEG2_S_MORE_DATA_AVAILABLE => "The record contains at least one more descriptor with this tag",
            ITF::IMAPI_S_BUFFER_TO_SMALL => "The output buffer is too small.",
            ITF::MPEG2_S_NO_MORE_DATA_AVAILABLE => "The record does not contain any more descriptors with this tag.",
            ITF::EVENT_S_NOSUBSCRIBERS => "An event was delivered but there were no subscribers.",
            ITF::MPEG2_S_SG_INFO_FOUND => "Service gateway information was found in the PMT.",
            ITF::_MAPI_W_NO_SERVICE => "The MAPI service is unavailable.",
            ITF::MPEG2_S_SG_INFO_NOT_FOUND => "Service gateway information was not found in the PMT.",
            ITF::MPEG2_S_MPE_INFO_FOUND => "Service gateway information was not found in the PMT.",
            ITF::MPEG2_S_MPE_INFO_NOT_FOUND => "MPE information was not found in the PMT.",
            ITF::MPEG2_S_NEW_MODULE_VERSION => "Description is missing",
            ITF::VFW_S_DUPLICATE_NAME => "DirectShow: An attempt to add a filter with a duplicate name succeeded with a modified name.",
            ITF::VFW_S_STATE_INTERMEDIATE => "DirectShow: The state transition is not complete.",
            ITF::VFW_S_PARTIAL_RENDER => "DirectShow: Some of the streams in this movie are in an unsupported format.",
            ITF::VFW_S_SOME_DATA_IGNORED => "DirectShow: The file contained some property settings that were not used.",
            ITF::VFW_S_CONNECTIONS_DEFERRED => "DirectShow: Some connections failed and were deferred.",
            ITF::VFW_S_RESOURCE_NOT_NEEDED => "DirectShow: The resource specified is no longer needed.",
            ITF::TPC_S_TRUNCATED => "TabletPC inking error code. String was truncated.",
            ITF::TPC_S_INTERRUPTED => "TabletPC inking error code. Recognition or training was interrupted.",
            ITF::TPC_S_NO_DATA_TO_PROCESS => "TabletPC inking error code. No personalization update to the recognizer because no training data found.",
            ITF::VFW_S_MEDIA_TYPE_IGNORED => "DirectShow: Could not connect with the media type in the persistent graph.",
            ITF::VFW_S_VIDEO_NOT_RENDERED => "DirectShow: Cannot play back the video stream: could not find a suitable renderer.",
            ITF::VFW_S_AUDIO_NOT_RENDERED => "DirectShow: Cannot play back the audio stream: could not find a suitable renderer.",
            ITF::VFW_S_RPZA => "DirectShow: Cannot play back the video stream: format 'RPZA' is not supported.",
            ITF::VFW_S_ESTIMATED => "DirectShow: The value returned had to be estimated. Its accuracy cannot be guaranteed.",
            ITF::VFW_S_RESERVED => "DirectShow: This success code is reserved for internal purposes within DirectShow.",
            ITF::VFW_S_STREAM_OFF => "DirectShow: The stream was turned off.",
            ITF::VFW_S_CANT_CUE => "DirectShow: The graph cannot be cued because it lacks data or contains corrupt data.",
            ITF::VFW_S_NOPREVIEWPIN => "There was no preview pin available, so the capture pin output is being split to provide both capture and preview.%0.",
            ITF::VFW_S_DVD_NON_ONE_SEQUENTIAL => "The current title was not a sequential set of chapters (PGC), and the returned timing information might not be continuous.%0.",
            ITF::VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE => "The audio stream did not contain sufficient information to determine the contents of each channel.%0.",
            ITF::VFW_S_DVD_NOT_ACCURATE => "The seek into the movie was not frame accurate.%0.",
            ITF::TF_S_ASYNC => "The data will be obtained asynchronously.",
            ITF::TS_S_ASYNC => "Text Store: Document successfully received an asynchronous lock.",
            ITF::CM_S_NODATASERVERS => "No connection to a Search server can be established.",
            ITF::QRY_S_NOROWSFOUND => "No matching items were found for this query.",
            ITF::QRY_S_TERMIGNORED => "The query term was successfully ignored.",
            ITF::QRY_S_INEXACTRESULTS => "The query found some matching items, but is unable to compile the entire result set.",
            ITF::IDS_MON_DEFAULT_ERROR => "Parser Error.",
            ITF::IDS_MON_ILLEGAL_PASSTHROUGH => "The PASSTHROUGH query is not allowed: '%1'.",
            ITF::IDS_MON_PARSE_ERR_1_PARAM => "The syntax near '%1' is incorrect. SQLSTATE=42000.",
            ITF::IDS_MON_PARSE_ERR_2_PARAM => "The syntax near '%1' is incorrect. Expected %2. SQLSTATE=42000.",
            ITF::IDS_MON_SEMI_COLON => "Multiple statement commands are not supported. SQLSTATE=42000.",
            ITF::IDS_MON_ORDINAL_OUT_OF_RANGE => "ORDER BY ordinal (%1) must be between 1 and %2. SQLSTATE=42000.",
            ITF::IDS_MON_VIEW_NOT_DEFINED => "View '%1' was not defined in catalog '%2'. SQLSTATE=42S02.",
            ITF::IDS_MON_COLUMN_NOT_DEFINED => "Column '%1' was not defined. SQLSTATE=42S22.",
            ITF::IDS_MON_BUILTIN_VIEW => "The view name conflicts with a predefined view definition.",
            ITF::IDS_MON_OUT_OF_MEMORY => "Out of memory.",
            ITF::IDS_MON_SELECT_STAR => "SELECT * is only allowed on views.",
            ITF::IDS_MON_OR_NOT => "<content search condition> OR NOT <content boolean term> is not allowed.",
            ITF::IDS_MON_CANNOT_CONVERT => "'%1'cannot be converted to type %2.",
            ITF::IDS_MON_OUT_OF_RANGE => "%1 is out of range for type %2.",
            ITF::IDS_MON_RELATIVE_INTERVAL => "The specification of <relative interval> must be negative.",
            ITF::IDS_MON_NOT_COLUMN_OF_VIEW => "'%1' is not a column in the view definition.",
            ITF::IDS_MON_BUILTIN_PROPERTY => "The property name conflicts with a predefined property definition.",
            ITF::IDS_MON_WEIGHT_OUT_OF_RANGE => "Weight value must be between 0.0 and 1.0.",
            ITF::IDS_MON_MATCH_STRING => "The matches string contains an error.",
            ITF::IDS_MON_PROPERTY_NAME_IN_VIEW => "The property name cannot be set because it is already being used in a VIEW. SQLSTATE=42000.",
            ITF::IDS_MON_VIEW_ALREADY_DEFINED => "View '%1' already exists in the index '%2' and cannot be redefined. SQLSTATE=42S01.",
            ITF::IDS_MON_INVALID_CATALOG => "The index name '%1' is invalid. SQLSTATE=42000.",
            ITF::IDS_MON_INVALIDSELECT_COALESCE => "The select list for the coalesce table is invalid.",
            ITF::IDS_MON_CANNOT_CAST => "The literal value cannot cast to the requested type.",
            ITF::IDS_MON_DATE_OUT_OF_RANGE => "The relative interval given in the DATEADD function is too large.",
            ITF::IDS_MON_INVALID_IN_GROUP_CLAUSE => "The IN GROUP identifier is invalid.",
            ITF::GTHR_S_STATUS_CHANGE_IGNORED => "The status change request was ignored, because the same status change is already pending.",
            ITF::GTHR_S_STATUS_END_CRAWL => "The update ended.",
            ITF::GTHR_S_STATUS_RESET => "Reset.",
            ITF::GTHR_S_STATUS_THROTTLE => "Preparing to propagate.",
            ITF::GTHR_S_STATUS_RESUME => "Resume.",
            ITF::GTHR_S_STATUS_PAUSE => "Pause.",
            ITF::GTHR_S_END_STD_CHUNKS => "The gatherer has finished filtering standard properties.",
            ITF::GTHR_S_NO_CRAWL_SEEDS => "The update cannot begin without content sources. Add at least one content source that is not used for alerts.",
            ITF::GTHR_S_CANNOT_FILTER => "Failed to load document into IFilter. Possibly caused by unrecognized document format or document corruption. Only metadata obtained from the document storage was indexed.",
            ITF::GTHR_S_STATUS_STOP => "Stop.",
            ITF::GTHR_S_STATUS_START => "Start Update.",
            ITF::GTHR_S_CONFIG_HAS_ACCOUNTS => "The index configuration contains account information.",
            ITF::GTHR_S_PROB_NOT_MODIFIED => "The content was not likely to be modified during the adaptive update, so the gatherer is not going to check the document for changes.",
            ITF::GTHR_S_CRAWL_SCHEDULED => "The update will start as soon as all content sources are released by other updates that are already in progress.",
            ITF::GTHR_S_TRANSACTION_IGNORED => "The transaction was ignored as redundant, because another transaction for the same URL was active at the same time.",
            ITF::GTHR_S_START_FILTER_FROM_PROTOCOL => "The gatherer started getting properties using the filter from the protocol handler.",
            ITF::GTHR_S_BAD_FILE_LINK => "This file link cannot be followed.",
            ITF::GTHR_S_NOT_ALL_PARTS => "Some parts of this document cannot be accessed.",
            ITF::GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE => "The process notify queue was stopped successfully.",
            ITF::GTHR_S_START_FILTER_FROM_BODY => "The gatherer started getting properties using the document filter.",
            ITF::GTHR_S_MODIFIED_PARTS => "Some parts of the document were modified, and others were not. The gatherer will refilter the entire document.",
            ITF::GTHR_S_CRAWL_FULL => "Full.",
            ITF::GTHR_S_CRAWL_INCREMENTAL => "Incremental.",
            ITF::GTHR_S_CRAWL_ADAPTIVE => "Adaptive.",
            ITF::GTHR_S_NO_INDEX => "Content for this URL is excluded by the server because a no-index attribute.",
            ITF::GTHR_S_PAUSE_REASON_EXTERNAL => "by user.",
            ITF::GTHR_S_PAUSE_REASON_UPGRADING => "for upgrade.",
            ITF::GTHR_S_PAUSE_REASON_BACKOFF => "low resources.",
            ITF::GTHR_S_OFFICE_CHILD => "This document is a child of another document. It will not be cataloged separately.",
            ITF::GTHR_S_CANNOT_WORDBREAK => "The document contains text that can not be broken into words. The document won't be indexed.",
            ITF::GTHR_S_USE_MIME_FILTER => "This is a success code that indicates that the MIME filter should be used to filter the document stream. This is an internal error code and should not be reported to users. Call Microsoft Product Support.",
            ITF::GTHR_S_PAUSE_REASON_PROFILE_IMPORT => "for profile import.",
            ITF::DB_S_ROWLIMITEXCEEDED => "Fetching requested number of rows will exceed total number of active rows supported by the rowset.",
            ITF::DB_S_COLUMNTYPEMISMATCH => "One or more column types are incompatible. Conversion errors will occur during copying.",
            ITF::DB_S_TYPEINFOOVERRIDDEN => "Parameter type information was overridden by caller.",
            ITF::DB_S_BOOKMARKSKIPPED => "Bookmark was skipped for deleted or nonmember row.",
            ITF::DB_S_NONEXTROWSET => "No more rowsets.",
            ITF::DB_S_ENDOFROWSET => "Start or end of rowset or chapter was reached.",
            ITF::DB_S_COMMANDREEXECUTED => "Command was reexecuted.",
            ITF::DB_S_BUFFERFULL => "Operation succeeded, but status array or string buffer could not be allocated.",
            ITF::DB_S_NORESULT => "No more results.",
            ITF::DB_S_CANTRELEASE => "Server cannot release or downgrade a lock until the end of the transaction.",
            ITF::DB_S_GOALCHANGED => "Weight is not supported or exceeded the supported limit, and was set to 0 or the supported limit.",
            ITF::DB_S_UNWANTEDOPERATION => "Consumer does not want to receive further notification calls for this operation.",
            ITF::DB_S_DIALECTIGNORED => "Input dialect was ignored and command was processed using default dialect.",
            ITF::DB_S_UNWANTEDPHASE => "Consumer does not want to receive further notification calls for this phase.",
            ITF::DB_S_UNWANTEDREASON => "Consumer does not want to receive further notification calls for this reason.",
            ITF::DB_S_ASYNCHRONOUS => "Operation is being processed asynchronously.",
            ITF::DB_S_COLUMNSCHANGED => "Command was executed to reposition to the start of the rowset. Either the order of the columns changed, or columns were added to or removed from the rowset.",
            ITF::DB_S_ERRORSRETURNED => "Method had some errors, which were returned in the error array.",
            ITF::DB_S_BADROWHANDLE => "Row handle is invalid.",
            ITF::DB_S_DELETEDROW => "Row handle referred to a deleted row.",
            ITF::DB_S_TOOMANYCHANGES => "Provider cannot keep track of all the changes. Client must refetch the data associated with the watch region by using another method.",
            ITF::DB_S_STOPLIMITREACHED => "Execution stopped because a resource limit was reached. Results obtained so far were returned, but execution cannot resume.",
            ITF::DB_S_NOTSINGLETON => "Row object was requested on a non-singleton result. First row was returned.",
            ITF::DB_S_LOCKUPGRADED => "Lock was upgraded from the value specified.",
            ITF::DB_S_PROPERTIESCHANGED => "One or more properties were changed as allowed by provider.",
            ITF::DB_S_ERRORSOCCURRED => "Multiple-step operation completed with one or more errors. Check each status value.",
            ITF::DB_S_PARAMUNAVAILABLE => "Parameter is invalid.",
            ITF::DB_S_MULTIPLECHANGES => "Updating a row caused more than one row to be updated in the data source.",
            ITF::DB_S_NOROWSPECIFICCOLUMNS => "Row has no row-specific columns.",
            ITF::REC_S_IDIDTHEUPDATES => "Briefcase Reconciler: Reconciliation was completed successfully, and all the objects involved (the object implementing the Reconcile method and all the other objects described by rgpmkOtherInput) have been updated appropriately. The initiator does not need, therefore, to do anything further to propagate the changes. The variable pointed to by plOutIndex should be set to -1L if Reconcile returns this value. The initiator will not save the source object's storage if Reconcile returns this value. This value may only be returned if RECONCILEF_YOUMAYDOTHEUPDATES was set in dwFlags.",
            ITF::REC_S_NOTCOMPLETE => "Briefcase Reconciler: The briefcase reconciler completed some, but not all, of the reconciliation. It may need user interaction. The changes will not be propagated to other objects.",
            ITF::SEO_S_MOREDATA => "SEO: Success, the buffer was not large enough to contain all of the data.",
            ITF::REC_S_NOTCOMPLETEBUTPROPAGATE => "Briefcase Reconciler: The briefcase reconciler completed some, but not all, of the reconciliation. It may need user interaction. The changes will be propagated to the other objects.",
            ITF::IDX_S_NO_BUILD_IN_PROGRESS => "There is no update in progress. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_S_SEARCH_SERVER_ALREADY_EXISTS => "The Search server already exists.",
            ITF::IDX_S_SEARCH_SERVER_DOES_NOT_EXIST => "The search server does not exist. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_S_DSS_NOT_AVAILABLE => "The search server was added successfully, but cannot be contacted. Check that the search service is executing on the remote computer, and that you can connect to the remote computer.",
            ITF::JPS_S_DUPLICATE_DOC_DETECTED => "The content index server detected a previously crawled document with the same content. This is an internal error code and should not be reported to users. Call Microsoft Product Support.",
            ITF::PRTH_S_NOT_MODIFIED => "The content did not change.",
            ITF::PRTH_S_MAX_GROWTH => "Filtering of this file ended because the file reached the maximum filter output limit. Check that the filter does not generate a large amount of data relative to the size of the document.",
            ITF::PRTH_S_MAX_DOWNLOAD => "The file reached the maximum download limit. Check that the full text of the document can be meaningfully crawled.",
            ITF::PRTH_S_ACL_IS_READ_EVERYONE => "The Access Control List was successfully changed to be readable by everyone.",
            ITF::PRTH_S_USE_ROSEBUD => "You must use Rosebud to access this address.",
            ITF::PRTH_S_NOT_ALL_PARTS => "Some parts of this document cannot be accessed.",
            ITF::PRTH_S_TRY_IMPERSONATING => "The item should be accessed while impersonating a user. Protocol handler is expected to implement IUrlAccessor3.",
            ITF::SCHED_S_TASK_READY => "The task is ready to run at its next scheduled time.",
            ITF::SCHED_S_TASK_RUNNING => "The task is currently running.",
            ITF::SCHED_S_TASK_DISABLED => "The task will not run at the scheduled times because it has been disabled.",
            ITF::SCHED_S_TASK_HAS_NOT_RUN => "The task has not yet run.",
            ITF::SCHED_S_TASK_NO_MORE_RUNS => "There are no more runs scheduled for this task.",
            ITF::SCHED_S_TASK_NOT_SCHEDULED => "One or more of the properties that are needed to run this task on a schedule have not been set.",
            ITF::SCHED_S_TASK_TERMINATED => "The last run of the task was terminated by the user.",
            ITF::SCHED_S_TASK_NO_VALID_TRIGGERS => "Either the task has no triggers or the existing triggers are disabled or not set.",
            ITF::SCHED_S_EVENT_TRIGGER => "Event triggers don't have set run times.",
            ITF::SCHED_S_SOME_TRIGGERS_FAILED => "The task is registered, but not all specified triggers will start the task, check task scheduler event log for detailed information.",
            ITF::SCHED_S_BATCH_LOGON_PROBLEM => "The task is registered, but may fail to start. Batch logon privilege needs to be enabled for the task principal.",
            ITF::SCHED_S_TASK_QUEUED => "The Task Scheduler service has asked the task to run.",
            ITF::QPLIST_S_DUPLICATE => "Exact duplicate property defined.",
            ITF::FDAEMON_W_WORDLISTFULL => "Wordlist has reached maximum size. Additional documents should not be filtered.",
            ITF::FDAEMON_W_EMPTYWORDLIST => "Final wordlist was empty.",
            ITF::SEARCH_S_NOMOREHITS => "End of hits has been reached.",
            ITF::FILTER_W_MONIKER_CLIPPED => "Moniker doesn't cover entire region.",
            ITF::FILTER_S_LAST_TEXT => "This is the last text in the current chunk.",
            ITF::FILTER_S_LAST_VALUES => "This is the last value in the current chunk.",
            ITF::FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE => "A partial content scan of the disk needs to be scheduled for immediate execution.",
            ITF::FILTER_S_FULL_CONTENTSCAN_IMMEDIATE => "A full content scan of the disk needs to be scheduled for immediate execution.",
            ITF::FILTER_S_CONTENTSCAN_DELAYED => "A content scan of the disk needs to be scheduled for execution later.",
            ITF::FILTER_S_DISK_FULL => "The disk is getting full.",
            ITF::FILTER_S_NO_PROPSETS => "The document has no property sets.",
            ITF::FILTER_S_NO_SECURITY_DESCRIPTOR => "The document has no security descriptor.",
            ITF::LANGUAGE_S_LARGE_WORD => "Word larger than maximum length. May be truncated by word sink.",
            ITF::PSINK_S_LARGE_WORD => "Word larger than maximum length. May be truncated by phrase sink.",
            ITF::CI_S_WORKID_DELETED => "The workid is deleted.",
            ITF::CI_S_END_OF_ENUMERATION => "There are no more documents to enumerate.",
            ITF::CI_S_NO_DOCSTORE => "For administrative connections from client without association to a docstore.",
            ITF::CI_S_CAT_STOPPED => "The catalog has been stopped.",
            ITF::CI_S_NEW_AUXMETADATA => "This is a new entry in the auxiliary metadata storage.",
            ITF::CI_S_CLIENT_REQUESTED_ABORT => "The client requested that the document be stopped.",
            ITF::CI_S_RETRY_DOCUMENT => "The client can now try to crawl a document.",
            ITF::CI_S_CATALOG_RESET => "The catalog was reset due to diacritic difference or corruption.",
            ITF::NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED => "At least one content index definition was not initialized. Check the amount of free disk space, and verify that the registry configuration is correct.",
            ITF::VSS_S_ASYNC_PENDING => "The asynchronous operation is pending.",
            ITF::VSS_S_ASYNC_FINISHED => "The asynchronous operation has completed.",
            ITF::VSS_S_ASYNC_CANCELLED => "The asynchronous operation has been cancelled.",
            ITF::VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED => "Some shadow copies were not successfully imported.",
            ITF::VDS_S_DISK_PARTIALLY_CLEANED => "The disk is not fully cleaned due to I/O error.",
            ITF::VDS_S_PROVIDER_ERROR_LOADING_CACHE => "The provider encountered errors while loading the cache. See the NT Event Log for more information.",
            ITF::VDS_S_UPDATE_BOOTFILE_FAILED => "Failed to update the boot configuration data.",
            ITF::VDS_S_BOOT_PARTITION_NUMBER_CHANGE => "The boot partition's partition number will change as a result of the operation.",
            ITF::VDS_S_VOLUME_COMPRESS_FAILED => "Failed to compress the volume.",
            ITF::VDS_S_IN_PROGRESS => "The asynchronous operation is in progress.",
            ITF::VDS_S_IA64_BOOT_MIRRORED_TO_MBR => "You have mirrored your boot volume on a GPT disk, to an MBR disk. You will not be able to boot your machine from the secondary plex.",
            ITF::VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES => "Unable to retrieve the GPT attributes for this volume, (hidden, read only and no drive letter).",
            ITF::VDS_S_EXTEND_FILE_SYSTEM_FAILED => "The volume was extended successfully but the file system failed to extend.",
            ITF::VDS_S_MBR_BOOT_MIRRORED_TO_GPT => "You have mirrored your boot volume on an MBR disk, to a GPT disk. You will not be able to boot your machine from the secondary plex.",
            ITF::VDS_S_DISK_IS_MISSING => "The disk is missing, not all information could be returned.",
            ITF::VDS_S_NONCONFORMANT_PARTITION_INFO => "The disk's partition information is does not conform to that expected on a dynamic disk.",
            ITF::VDS_S_SYSTEM_PARTITION => "Warning, there was a failure while checking for the system partition.",
            ITF::VDS_S_NO_NOTIFICATION => "No volume arrival notification was received. Refresh the Disk Management display.",
            ITF::VDS_S_DEFAULT_PLEX_MEMBER_IDS => "Defaults have been used for the member ids or plex ids.",
            ITF::VDS_S_DISMOUNT_FAILED => "Failed to dismount the volume after setting the volume flags.",
            ITF::VDS_S_REMOUNT_FAILED => "Failed to remount the volume after setting the volume flags.",
            ITF::VDS_S_RESYNC_NOTIFICATION_TASK_FAILED => "Failure. If the volume is a mirror volume or a raid5 volume, no resynchronization notifications will be sent.",
            ITF::VDS_S_VSS_FLUSH_AND_HOLD_WRITES => "Failed to flush and hold Volume Snapshot Service writes.",
            ITF::VDS_S_VSS_RELEASE_WRITES => "Failed to release Volume Snapshot Service writes.",
            ITF::VDS_S_FS_LOCK => "Failed to obtain a file system lock.",
            ITF::VDS_S_PLEX_NOT_LOADED_TO_CACHE => "This plex is present in the driver, but has not yet been loaded to the provider cache. A volume modified notification will be sent by the service once the plex has been loaded to the provider cache.",
            ITF::VDS_S_WINPE_BOOTENTRY => "The boot entries cannot be updated automatically on WinPE. You may need to manually update the boot entry for any installed operating systems.",
            ITF::NOTESPH_S_IGNORE_ID => "The group or person was successfully ignored.",
            ITF::NOTESPH_S_LISTKNOWNFIELDS => "One or more Lotus Notes database forms cannot be read. Some fields might not be available.",
            ITF::VDS_S_NAME_TRUNCATED => "The name was accepted but had to be truncated.",
            ITF::VDS_S_STATUSES_INCOMPLETELY_SET => "At least one path status is not set successfully due to a non-fatal error, for example the status conflicts with the current load balance policy.",
            ITF::VDS_S_ALREADY_EXISTS => "The object already exists and does not need to be further created or added.",
            ITF::VDS_S_PROPERTIES_INCOMPLETE => "Unable to retrieve all properties for this object. Some attributes may be incomplete or missing.",
            ITF::VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED => "No iSCSI sessions to the target were found, but the persistent login setup to the target was removed.",
            ITF::VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED => "If a persistent login was set up for the target, it may not have been removed. Check the iSCSI Initiator Control Panel to remove it if necessary.",
            ITF::VDS_S_ISCSI_LOGIN_ALREAD_EXISTS => "Login failed because the target is already logged in.",
            ITF::VDS_S_DISK_MOUNT_FAILED => "Failed to mount one or more of the volumes on the disk.",
            ITF::VDS_S_DISK_DISMOUNT_FAILED => "Failed to dismount one or more of the volumes on the disk.",
            ITF::REXSPH_S_REDIRECTED => "The URL was redirected and will be handled automatically.",
            ITF::FTE_S_RESOURCES_STARTING_TO_GET_LOW => "The Full Text Engine's input queue is getting full. This batch has been accepted for processing. This success code is intended to help pause input until the queue is less full.",
            ITF::FTE_S_BEYOND_QUOTA => "The Full Text Engine's input queue is full. This batch has been accepted for processing; however, the Full Text Engine will soon go into a forced paused state until the queue is less full.",
            ITF::FTE_S_REDUNDANT => "This transaction was superseded by a subsequent transaction, so it will not be completed.",
            ITF::FTE_S_STATUS_CHANGE_REQUEST => "The project state has changed or is changing due to a status change request.",
            ITF::FTE_S_RESUME => "This is an internal error: The project will be resumed.",
            ITF::FTE_S_PROPERTY_STORE_END_OF_ENUMERATION => "The enumeration has finished for the property store.",
            ITF::FTE_S_READONLY_CATALOG => "The catalog has been opened for read-only operations.",
            ITF::FTE_S_TRY_TO_FLUSH => "Internal Success Code. Crawl is done. Chunk buffers can be flushed; there is no additional input data.",
            ITF::FTE_S_CATALOG_BLOB_MISMATCHED => "The property requested from the catalog blob received doesn't match the current value of the catalog property. The property value used by the catalog was successfully returned. The caller should either call SetProperty with the value returned or dismount the catalog and mount it back with the blob.",
            ITF::FTE_S_PROPERTY_RESET => "One or more properties were reset to the default value.",
            ITF::VDS_S_ACCESS_PATH_NOT_DELETED => "The access paths on the volume may not be deleted.",
            ITF::SP_END_OF_STREAM => "The operation has reached the end of stream.",
            ITF::SP_INSUFFICIENTDATA => "Description is missing",
            ITF::SP_AUDIO_PAUSED => "This will be returned only on input (read) streams when the stream is paused. Reads on paused streams will not block, and this return code indicates that all of the data has been removed from the stream.",
            ITF::SP_AUDIO_CONVERSION_ENABLED => "The operation was successful, but only with automatic stream format conversion.",
            ITF::SP_NO_HYPOTHESIS_AVAILABLE => "There is currently no hypothesis recognition available.",
            ITF::SP_ALREADY_IN_LEX => "The word, pronunciation, or POS pair being added is already in lexicon.",
            ITF::SP_LEX_NOTHING_TO_SYNC => "The client is currently synced with the lexicon.",
            ITF::SP_REQUEST_PENDING => "This success code indicates that an SR method called with the SPRIF_ASYNC flag is being processed. When it has finished processing, an SPFEI_ASYNC_COMPLETED event will be generated.",
            ITF::SP_NO_PARSE_FOUND => "Parse path cannot be parsed given the currently active rules.",
            ITF::SP_UNSUPPORTED_ON_STREAM_INPUT => "The operation is not supported for stream input.",
            ITF::SP_WORD_EXISTS_WITHOUT_PRONUNCIATION => "The word exists but without pronunciation.",
            ITF::SP_RECOGNIZER_INACTIVE => "Operation could not be completed because the recognizer is inactive. It is inactive either because the recognition state is currently inactive or because no rules are active.",
            ITF::SP_PARTIAL_PARSE_FOUND => "A grammar-ending parse has been found that does not use all available words.",
            ITF::SP_NO_RULE_ACTIVE => "An attempt to parse when no rule was active.",
            ITF::SP_STREAM_UNINITIALIZED => "An attempt to activate a rule/dictation/etc without calling SetInput first in the inproc case.",
            ITF::SP_AUDIO_STOPPED => "This can be returned from Read or Write calls audio streams when the stream is stopped.",
            ITF::SP_COMPLETE_BUT_EXTENDABLE => "Parse is valid but could be extendable (internal use only).",
            ITF::SP_NO_RULES_TO_ACTIVATE => "The grammar does not have any root or top-level active rules to activate.",
            ITF::SP_NO_WORDENTRY_NOTIFICATION => "The engine does not need SAPI word entry handles for this grammar.",
            ITF::S_LIMIT_REACHED => "The word being normalized has generated more than the maximum number of allowed normalized results indicates that returned list is not exhaustive, but contains as many alternatives as the engine is willing to provide.",
            ITF::S_NOTSUPPORTED => "We currently don't support this combination of function call + input.",
            ITF::FSRM_S_PARTIAL_BATCH => "At least one failure occurred in a batch operation.",
            ITF::FSRM_S_PARTIAL_CLASSIFICATION => "The file may only have partial classification because a failure occurred while loading or classifying the file properties.",
            ITF::FSRM_S_CLASSIFICATION_SCAN_FAILURES => "Classification failed on one or more volumes. Check the application event log for more information.",
            ITF::FSRM_E_AUTO_QUOTA => "Auto apply quota configuration for one or more folders failed. Check the application event log for more information.",
            ITF::NETCFG_S_REBOOT => "Indicates that the operation failed, and the system needs to be rebooted. For example, this code is returned if calls to the INetCfgClassSetup::Install or INetCfgClassSetup::DeInstall methods fail.",
            ITF::NETCFG_S_DISABLE_QUERY => "Returned by a component's notify object to indicate that it has disabled a binding path in response to a call to the INetCfgComponentNotifyBinding::QueryBindingPath or INetCfgComponentNotifyGlobal::SysQueryBindingPath methods.",
            ITF::NETCFG_S_STILL_REFERENCED => "Returned by a component's notify object to indicate that it has disabled a binding pathIndicates that a component is being removed from the system, but another component still references the component that is being removed. in response to a call to the INetCfgComponentNotifyBinding::QueryBindingPath or INetCfgComponentNotifyGlobal::SysQueryBindingPath methods.",
            ITF::NETCFG_S_CAUSED_SETUP_CHANGE => "Description is missing",
            ITF::NETCFG_S_COMMIT_NOW => "Returned by a component's notify object from the INetCfgComponentPropertyUi::ApplyProperties method. This code indicates that the changes made by the user should be applied immediately.",
            ITF::XACT_S_ASYNC => "An asynchronous operation was specified. The operation has begun, but its outcome is not known yet.",
            ITF::XACT_S_DEFECT => "XACT_S_DEFECT.",
            ITF::XACT_S_READONLY => "The method call succeeded because the transaction was read-only.",
            ITF::XACT_S_SOMENORETAIN => "The transaction was successfully aborted. However, this is a coordinated transaction, and some number of enlisted resources were aborted outright because they could not support abort-retaining semantics.",
            ITF::XACT_S_OKINFORM => "No changes were made during this call, but the sink wants another chance to look if any other sinks make further changes.",
            ITF::XACT_S_MADECHANGESCONTENT => "The sink is content and wishes the transaction to proceed. Changes were made to one or more resources during this call.",
            ITF::XACT_S_MADECHANGESINFORM => "The sink is for the moment and wishes the transaction to proceed, but if other changes are made following this return by other event sinks then this sink wants another chance to look.",
            ITF::XACT_S_ALLNORETAIN => "The transaction was successfully aborted. However, the abort was non-retaining.",
            ITF::XACT_S_ABORTING => "An abort operation was already in progress.",
            ITF::XACT_S_SINGLEPHASE => "The resource manager has performed a single-phase commit of the transaction.",
            ITF::XACT_S_LOCALLY_OK => "The local transaction has not aborted.",
            ITF::XACT_S_LASTRESOURCEMANAGER => "The resource manager has requested to be the coordinator (last resource manager) for the transaction.",
            ITF::S_DEVCAP_OUTPUT_FULL_REPLACEMENT => "Description is missing",
            ITF::IO_FILE_QUOTA_THRESHOLD => "A user hit their quota threshold on volume %2.",
            ITF::IO_FILE_QUOTA_LIMIT => "A user hit their quota limit on volume %2.",
            ITF::IO_FILE_QUOTA_STARTED => "The system has started rebuilding the user disk quota information on device %1 with label '%2'.",
            ITF::IO_FILE_QUOTA_SUCCEEDED => "The system has successfully rebuilt the user disk quota information on device %1 with label '%2'.",
            ITF::IO_INFO_THROTTLE_COMPLETE => "The driver for device %1 delayed non-paging Io requests for %2 ms to recover from a low memory condition.",
            ITF::IO_CDROM_EXCLUSIVE_LOCK => "Device %1 is locked for exclusive access.",
            ITF::MSG_TEST_MESSAGE => "The %1 message facility is running.",
            ITF::SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK => "Trusted time is already up-to-date.",
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL => "Kernel Mode Cache was not changed.",
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED => "Reboot-requiring policies have changed.",
            ITF::SL_I_OOB_GRACE_PERIOD => "The Software Licensing Service reported that the application is running within the valid grace period.",
            ITF::SL_I_OOT_GRACE_PERIOD => "The Software Licensing Service reported that the application is running within the valid out of tolerance grace period.",
            ITF::SL_E_VL_INFO_PRODUCT_USER_RIGHT => "The Software Licensing Service reported that the product was activated but the owner should verify the Product Use Rights.",
            ITF::SL_I_NONGENUINE_GRACE_PERIOD => "The Software Licensing Service reported that the application is running within the valid non-genuine grace period.",
            ITF::SL_I_NONGENUINE_GRACE_PERIOD_2 => "The Software Licensing Service reported that the application is running within the valid non-genuine grace period (type 2).",
            ITF::SL_I_TIMEBASED_VALIDITY_PERIOD => "The Software Licensing Service reported that the application is running within the timebased validity period.",
            ITF::SL_I_PERPETUAL_OOB_GRACE_PERIOD => "The Software Licensing Service reported that the application has a perpetual grace period.",
            ITF::SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD => "The Software Licensing Service reported that the application is running within the valid extended grace period.",
            ITF::OLE_E_OLEVERB => "Invalid OLEVERB structure.",
            ITF::OLE_E_ADVF => "Invalid advise flags.",
            ITF::E_NOTVALIDFORANIMATEDIMAGE => "IShellImageData: The image is an animated image and cannot be rotated.",
            ITF::OLE_E_ENUM_NOMORE => "Can't enumerate any more, because the associated data is missing.",
            ITF::OLE_E_ADVISENOTSUPPORTED => "This implementation doesn't take advises.",
            ITF::TAPI_E_NOTSUPPORTED => "This method is not supported.",
            ITF::OLE_E_NOCONNECTION => "There is no connection for this connection ID.",
            ITF::TAPI_E_INVALIDMEDIATYPE => "The MEDIATYPE passed in to this method was invalid.",
            ITF::OLE_E_NOTRUNNING => "Need to run the object to perform this operation.",
            ITF::TAPI_E_OPERATIONFAILED => "The operation failed for an unspecified reason.",
            ITF::OLE_E_NOCACHE => "There is no cache to operate on.",
            ITF::TAPI_E_ALLOCATED => "The device is already in use.",
            ITF::OLE_E_BLANK => "Uninitialized object.",
            ITF::TAPI_E_CALLUNAVAIL => "No call appearance available.",
            ITF::OLE_E_CLASSDIFF => "Linked object's source class has changed.",
            ITF::TAPI_E_COMPLETIONOVERRUN => "Too many call completions outstanding.",
            ITF::OLE_E_CANT_GETMONIKER => "Not able to get the moniker of the object.",
            ITF::TAPI_E_CONFERENCEFULL => "The conference is full.",
            ITF::OLE_E_CANT_BINDTOSOURCE => "Not able to bind to the source.",
            ITF::TAPI_E_DIALMODIFIERNOTSUPPORTED => "The dial modifier is not supported.",
            ITF::OLE_E_STATIC => "Object is static; operation not allowed.",
            ITF::TAPI_E_INUSE => "The device is already in use.",
            ITF::OLE_E_PROMPTSAVECANCELLED => "User canceled out of save dialog.",
            ITF::TAPI_E_INVALADDRESS => "The phone number is invalid or not properly formatted.",
            ITF::OLE_E_INVALIDRECT => "Invalid rectangle.",
            ITF::TAPI_E_INVALADDRESSSTATE => "Operation not permitted in current address state.",
            ITF::OLE_E_WRONGCOMPOBJ => "compobj.dll is too old for the ole2.dll initialized.",
            ITF::TAPI_E_INVALCALLPARAMS => "Invalid LINECALLPARAMS structure.",
            ITF::OLE_E_INVALIDHWND => "Invalid window handle.",
            ITF::TAPI_E_INVALCALLPRIVILEGE => "Invalid call privilege.",
            ITF::OLE_E_NOT_INPLACEACTIVE => "Object is not in any of the inplace active states.",
            ITF::TAPI_E_INVALCALLSTATE => "Operation not permitted in current call state.",
            ITF::OLE_E_CANTCONVERT => "Not able to convert object.",
            ITF::TAPI_E_INVALCARD => "Invalid calling card.",
            ITF::OLE_E_NOSTORAGE => "Not able to perform the operation because object is not given storage yet.",
            ITF::TAPI_E_INVALCOMPLETIONID => "Invalid call completion ID.",
            ITF::TAPI_E_INVALCOUNTRYCODE => "Invalid country code.",
            ITF::TAPI_E_INVALDEVICECLASS => "Invalid device class identifier.",
            ITF::TAPI_E_INVALDIALPARAMS => "Invalid dialing parameters.",
            ITF::TAPI_E_INVALDIGITS => "Invalid digits.",
            ITF::TAPI_E_INVALGROUPID => "Invalid group pickup ID.",
            ITF::TAPI_E_INVALLOCATION => "Invalid location ID.",
            ITF::TAPI_E_INVALMESSAGEID => "Invalid message ID.",
            ITF::TAPI_E_INVALPARKID => "Invalid park ID.",
            ITF::IO_WRN_BAD_FIRMWARE => "The driver has detected that device %1 has old or out-of-date firmware. Reduced performance may result.",
            ITF::TAPI_E_INVALRATE => "Invalid rate.",
            ITF::TAPI_E_INVALTIMEOUT => "Invalid timeout value.",
            ITF::TAPI_E_INVALTONE => "Invalid tone.",
            ITF::TAPI_E_INVALLIST => "Invalid list passed as a parameter.",
            ITF::TAPI_E_INVALMODE => "Invalid mode passed as a parameter.",
            ITF::TAPI_E_NOCONFERENCE => "The call is not part of a conference.",
            ITF::IO_WRITE_CACHE_ENABLED => "The driver detected that the device %1 has its write cache enabled. Data corruption may occur.",
            ITF::TAPI_E_NODEVICE => "The device was removed, or the device class is not recognized.",
            ITF::IO_RECOVERED_VIA_ECC => "Data was recovered using error correction code on device %1.",
            ITF::TAPI_E_NOREQUEST => "No Assisted Telephony requests are pending.",
            ITF::IO_WRITE_CACHE_DISABLED => "The driver disabled the write cache on device %1.",
            ITF::TAPI_E_NOTOWNER => "The application is does not have OWNER privilege on the call.",
            ITF::TAPI_E_NOTREGISTERED => "The application is not registered to handle requests.",
            ITF::TAPI_E_REQUESTOVERRUN => "The request queue is already full.",
            ITF::TAPI_E_TARGETNOTFOUND => "The call handoff failed because the specified target was not found.",
            ITF::TAPI_E_TARGETSELF => "No higher priority target exists for the call handoff.",
            ITF::TAPI_E_USERUSERINFOTOOBIG => "The amount of user-user info exceeds the maximum permitted.",
            ITF::IO_FILE_QUOTA_FAILED => "The system has encounted an error rebuilding the user disk quota information on device %1 with label &quot;%2&quot;.",
            ITF::TAPI_E_REINIT => "The operation cannot be completed until all TAPI applications shutdown and reinitialize.",
            ITF::TAPI_E_ADDRESSBLOCKED => "You are not permitted to call this number.",
            ITF::TAPI_E_BILLINGREJECTED => "The calling card number or other billing information was rejected.",
            ITF::TAPI_E_INVALFEATURE => "Invalid device-specific feature.",
            ITF::TAPI_E_INVALBUTTONLAMPID => "Invalid button or lamp ID.",
            ITF::TAPI_E_INVALBUTTONSTATE => "Invalid button state.",
            ITF::TAPI_E_INVALDATAID => "Invalid data segment ID.",
            ITF::TAPI_E_INVALHOOKSWITCHDEV => "Invalid hookswitch device ID.",
            ITF::TAPI_E_DROPPED => "The call was disconnected.",
            ITF::TAPI_E_NOREQUESTRECIPIENT => "No program is available to handle the request.",
            ITF::IO_LOST_DELAYED_WRITE => "{Delayed Write Failed} Windows was unable to save all the data for the file %2. The data has been lost. This error may be caused by a failure of your computer hardware or network connection. Please try to save this file elsewhere.",
            ITF::TAPI_E_REQUESTQUEUEFULL => "The queue of call requests is full.",
            ITF::IO_WARNING_PAGING_FAILURE => "An error was detected on device %1 during a paging operation.",
            ITF::TAPI_E_DESTBUSY => "The called number is busy.",
            ITF::IO_WRN_FAILURE_PREDICTED => "The driver has detected that device %1 has predicted that it will fail. Immediately back up your data and replace your hard disk drive. A failure may be imminent.",
            ITF::TAPI_E_DESTNOANSWER => "The called party does not answer.",
            ITF::IO_WARNING_INTERRUPT_STILL_PENDING => "A pending interrupt was detected on device %1 during a timeout operation. A large number of these warnings may indicate that the system is not correctly receiving or processing interrupts from the device.",
            ITF::TAPI_E_DESTUNAVAIL => "The called number could not be reached.",
            ITF::IO_DRIVER_CANCEL_TIMEOUT => "An Io Request to the device %1 did not complete or canceled within the specific timeout. This can occur if the device driver does not set a cancel routine for a given IO request packet.",
            ITF::TAPI_E_REQUESTFAILED => "The request failed for unspecified reasons.",
            ITF::TAPI_E_REQUESTCANCELLED => "The request was cancelled.",
            ITF::IO_WARNING_ALLOCATION_FAILED => "The driver failed to allocate memory.",
            ITF::TAPI_E_INVALPRIVILEGE => "Invalid privilege.",
            ITF::IO_WARNING_LOG_FLUSH_FAILED => "The system failed to flush data to the transaction log. Corruption may occur.",
            ITF::TAPI_E_INVALIDDIRECTION => "The TERMINAL_DIRECTION passed in was invalid.",
            ITF::IO_WARNING_DUPLICATE_SIGNATURE => "The disk signature of disk %2 is equal to the disk signature of disk %3.",
            ITF::TAPI_E_INVALIDTERMINAL => "The Terminal passed in was invalid for this operation.",
            ITF::IO_WARNING_DUPLICATE_PATH => "Disk %2 will not be used because it is a redundant path for disk %3.",
            ITF::TAPI_E_INVALIDTERMINALCLASS => "The Terminal Class is invalid.",
            ITF::TAPI_E_NODRIVER => "The service provider was removed.",
            ITF::TAPI_E_MAXSTREAMS => "The maximum number of streams was reached.",
            ITF::TAPI_E_NOTERMINALSELECTED => "The operation could not be performed because it requires terminals to be selected.",
            ITF::TAPI_E_TERMINALINUSE => "The operation could not be performed because the terminal is in use.",
            ITF::TAPI_E_NOTSTOPPED => "The operation could not be performed because it requires the stream to be stopped.",
            ITF::TAPI_E_MAXTERMINALS => "The maximum number of terminals has been reached.",
            ITF::TAPI_E_INVALIDSTREAM => "The Stream passed in was invalid for this operation.",
            ITF::TAPI_E_TIMEOUT => "The call failed due to a timeout.",
            ITF::TAPI_E_CALLCENTER_GROUP_REMOVED => "The ACD Proxy has removed this Group. Operations on this object are invalid.",
            ITF::TAPI_E_CALLCENTER_QUEUE_REMOVED => "The ACD Proxy has removed this Queue. Operations on this object are invalid.",
            ITF::TAPI_E_CALLCENTER_NO_AGENT_ID => "The Agent object was created with CreateAgent. It does not have an ID, use CreateAgentWithID.",
            ITF::TAPI_E_CALLCENTER_INVALAGENTID => "Invalid agent ID.",
            ITF::TAPI_E_CALLCENTER_INVALAGENTGROUP => "Invalid agent group.",
            ITF::TAPI_E_CALLCENTER_INVALPASSWORD => "Invalid agent password.",
            ITF::TAPI_E_CALLCENTER_INVALAGENTSTATE => "Invalid agent state.",
            ITF::TAPI_E_CALLCENTER_INVALAGENTACTIVITY => "Invalid agent activity.",
            ITF::TAPI_E_REGISTRY_SETTING_CORRUPT => "Registry Setting is Corrupt.",
            ITF::TAPI_E_TERMINAL_PEER => "The peer for one of these bridge terminals has already been assigned.",
            ITF::TAPI_E_PEER_NOT_SET => "The peer for this bridge terminal must be set to complete this operation.",
            ITF::TAPI_E_NOEVENT => "There is no event in the MSP's event queue.",
            ITF::TAPI_E_INVALADDRESSTYPE => "The specified address type is not supported by this address.",
            ITF::TAPI_E_RESOURCEUNAVAIL => "A resource needed to fulfill the request is not available.",
            ITF::TAPI_E_PHONENOTOPEN => "The phone is not open.",
            ITF::TAPI_E_CALLNOTSELECTED => "The specified call is not currently selected.",
            ITF::TAPI_E_WRONGEVENT => "This information is not available for this type of event.",
            ITF::TAPI_E_NOFORMAT => "The format is unknown.",
            ITF::TAPI_E_INVALIDSTREAMSTATE => "The operation is not permitted in current stream state.",
            ITF::TAPI_E_WRONG_STATE => "The operation requested is not permitted for the current state.",
            ITF::TAPI_E_NOT_INITIALIZED => "The object has not been initialized.",
            ITF::TAPI_E_SERVICE_NOT_RUNNING => "The Telephony Service could not be contacted.",
            ITF::DV_E_FORMATETC => "Invalid FORMATETC structure.",
            ITF::DV_E_DVTARGETDEVICE => "Invalid DVTARGETDEVICE structure.",
            ITF::DV_E_STGMEDIUM => "Invalid STDGMEDIUM structure.",
            ITF::DV_E_STATDATA => "Invalid STATDATA structure.",
            ITF::DV_E_LINDEX => "Invalid lindex.",
            ITF::DV_E_TYMED => "Invalid tymed.",
            ITF::DV_E_CLIPFORMAT => "Invalid clipboard format.",
            ITF::DV_E_DVASPECT => "Invalid aspect(s).",
            ITF::DV_E_DVTARGETDEVICE_SIZE => "tdSize parameter of the DVTARGETDEVICE structure is invalid.",
            ITF::DV_E_NOIVIEWOBJECT => "Object doesn't support IViewObject interface.",
            ITF::IO_WARNING_BUS_RESET => "The driver for device %1 performed a bus reset upon request.",
            ITF::IO_WARNING_RESET => "Reset to device, %1, was issued.",
            ITF::IO_WARNING_WRITE_FUA_PROBLEM => "Device %1 is not correctly processing some write requests. In Device Manager, ensure that the Write Cache option is disabled for this device or data corruption may occur.",
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED => "{Delayed Write Failed} Windows was unable to save all the data for the file %2; the data has been lost. This error may be caused by network connectivity issues. Please try to save this file elsewhere.",
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR => "{Delayed Write Failed} Windows was unable to save all the data for the file %2; the data has been lost. This error was returned by the server on which the file exists. Please try to save this file elsewhere.",
            ITF::IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR => "{Delayed Write Failed} Windows was unable to save all the data for the file %2; the data has been lost. This error may be caused if the device has been removed or the media is write-protected.",
            ITF::IO_WARNING_VOLUME_LOST_DISK_EXTENT => "Extent %4 on disk %3 that is part of the fault-tolerant volume %2 is no longer accessible.",
            ITF::IO_WARNING_DEVICE_HAS_INTERNAL_DUMP => "The storage device produced an internal dump.",
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED => "Disk %2 has crossed a capacity utilization threshold.",
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX => "Disk %2 has crossed a capacity utilization threshold and used %3 bytes. When the threshold was crossed, there were %4 bytes of remaining capacity.",
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN => "Disk %2 has crossed a capacity utilization threshold and used %3 bytes. When the threshold was crossed, the disk had %4 bytes of remaining capacity.",
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL => "Disk %2 has crossed a capacity utilization threshold and used %3 bytes. When the threshold was crossed, the pool had %4 bytes of remaining capacity.",
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN => "Disk %2 has crossed a capacity utilization threshold. When the threshold was crossed, %3 bytes from the pool were used and the disk had %4 bytes of remaining capacity.",
            ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL => "Disk %2 has crossed a capacity utilization threshold. When the threshold was crossed, %3 bytes from the pool were used and the pool had %4 bytes of remaining capacity.",
            ITF::IO_WARNING_DISK_CAPACITY_CHANGED => "The capacity of Disk %2 has changed.",
            ITF::IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED => "The logical block provisioning type for Disk %2 has changed.",
            ITF::IO_WARNING_IO_OPERATION_RETRIED => "The IO operation at logical block address %2 for Disk %3 (PDO name: %4) was retried.",
            ITF::IO_WARNING_COMPLETION_TIME => "The IO operation at logical block address %2 for Disk %3 took %4 milliseconds. This was longer than the maximum expected time of %5 milliseconds.",
            ITF::IO_WARNING_DUMP_DISABLED_DEVICE_GONE => "Crash dump is disabled. Crash dump device is not present in the system.",
            ITF::IO_WARNING_DISK_SURPRISE_REMOVED => "Disk %2 has been surprise removed.",
            ITF::IO_WARNING_REPEATED_DISK_GUID => "Disk %2 has the same disk identifiers as one or more disks connected to the system. Go to Microsoft's support website (http://support.microsoft.com) and search for KB2983588 to resolve the issue.",
            ITF::OLE_E_LAST => "Description is missing",
            ITF::DRAGDROP_E_NOTREGISTERED => "Trying to revoke a drop target that has not been registered.",
            ITF::DRAGDROP_E_ALREADYREGISTERED => "This window has already been registered as a drop target.",
            ITF::DRAGDROP_E_INVALIDHWND => "Invalid window handle.",
            ITF::_MAPI_E_NO_SUPPORT => "MAPI: This is not supported",
            ITF::DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED => "A drag operation is already in progress.",
            ITF::_MAPI_E_BAD_CHARWIDTH => "MAPI: The character width is bad.",
            ITF::_MAPI_E_STRING_TOO_LONG => "MAPI: The string is too long.",
            ITF::_MAPI_E_UNKNOWN_FLAGS => "MAPI: The caller passed an invalid parameter or flag.",
            ITF::_MAPI_E_INVALID_ENTRYID => "MAPI: The entry ID is invalid.",
            ITF::_MAPI_E_INVALID_OBJECT => "The MAPI object is invalid.",
            ITF::_MAPI_E_OBJECT_CHANGED => "The MAPI object was changed.",
            ITF::_MAPI_E_OBJECT_DELETED => "The MAPI object was deleted.",
            ITF::_MAPI_E_BUSY => "MAPI: The server is busy.",
            ITF::_MAPI_E_NOT_ENOUGH_DISK => "MAPI: The computer is out of disk space.",
            ITF::_MAPI_E_NOT_ENOUGH_RESOURCES => "MAPI: Not enough system resources were available to complete the operation.",
            ITF::_MAPI_E_NOT_FOUND => "The MAPI object was not found.",
            ITF::CLASS_E_NOAGGREGATION => "Class does not support aggregation (or class object is remote).",
            ITF::_MAPI_E_VERSION => "The version of OLE installed on the workstation is not compatible with this version of MAPI.",
            ITF::CLASS_E_CLASSNOTAVAILABLE => "ClassFactory cannot supply requested class.",
            ITF::_MAPI_E_LOGON_FAILED => "MAPI: Logon failed.",
            ITF::CLASS_E_NOTLICENSED => "Class is not licensed for use.",
            ITF::_MAPI_E_SESSION_LIMIT => "MAPI: The session limit was exceeded.",
            ITF::_MAPI_E_USER_CANCEL => "MAPI: The user cancelled the operation.",
            ITF::_MAPI_E_UNABLE_TO_ABORT => "MAPI: The operation cannot be stopped.",
            ITF::_MAPI_E_NETWORK_ERROR => "MAPI: A network error occurred.",
            ITF::_MAPI_E_DISK_ERROR => "MAPI: A disk error occurred.",
            ITF::_MAPI_E_TOO_COMPLEX => "The calling process is an NT service, and registry keys required by MAPI could not be initialized.",
            ITF::_MAPI_E_BAD_COLUMN => "MAPI: A bad column was requested.",
            ITF::_MAPI_E_EXTENDED_ERROR => "MAPI:An extended error occurred.",
            ITF::_MAPI_E_COMPUTED => "MAPI: Computed.",
            ITF::_MAPI_E_CORRUPT_DATA => "MAPI: The data is corrupt.",
            ITF::_MAPI_E_UNCONFIGURED => "MAPI: Not configured.",
            ITF::_MAPI_E_FAILONEPROVIDER => "MAPI: At least one provider failed.",
            ITF::_MAPI_E_UNKNOWN_CPID => "MAPI: A code page ID is unknown.",
            ITF::_MAPI_E_UNKNOWN_LCID => "MAPI: A locale ID is unknown.",
            ITF::_MAPI_E_PASSWORD_CHANGE_REQUIRED => "MAPI: Access is denied. Change your password.",
            ITF::_MAPI_E_PASSWORD_EXPIRED => "MAPI: Access is denied, because the password has expired.",
            ITF::_MAPI_E_INVALID_WORKSTATION_ACCOUNT => "MAPI: Access is denied, because the workstation account is invalid.",
            ITF::_MAPI_E_INVALID_ACCESS_TIME => "MAPI: Access is denied, because the access time is invalid.",
            ITF::_MAPI_E_ACCOUNT_DISABLED => "MAPI: Access is denied, because the account is disabled.",
            ITF::VIEW_E_DRAW => "Error drawing view.",
            ITF::REGDB_E_READREGDB => "Could not read key from registry.",
            ITF::REGDB_E_WRITEREGDB => "Could not write key to registry.",
            ITF::REGDB_E_KEYMISSING => "Could not find the key in the registry.",
            ITF::REGDB_E_INVALIDVALUE => "Invalid value for registry.",
            ITF::REGDB_E_CLASSNOTREG => "Class not registered.",
            ITF::E_CLASSNOTREG => "Class not registered.",
            ITF::REGDB_E_IIDNOTREG => "Interface not registered.",
            ITF::REGDB_E_BADTHREADINGMODEL => "Threading model entry is not valid.",
            ITF::REGDB_E_PACKAGEPOLICYVIOLATION => "A registration in a package violates package-specific policies.",
            ITF::CAT_E_CATIDNOEXIST => "CATID does not exist.",
            ITF::CAT_E_NODESCRIPTION => "Description not found.",
            ITF::CS_E_PACKAGE_NOTFOUND => "No package in the software installation data in the Active Directory meets this criteria.",
            ITF::CS_E_NOT_DELETABLE => "Deleting this will break the referential integrity of the software installation data in the Active Directory.",
            ITF::CS_E_CLASS_NOTFOUND => "The CLSID was not found in the software installation data in the Active Directory.",
            ITF::CS_E_INVALID_VERSION => "The software installation data in the Active Directory is corrupt.",
            ITF::CS_E_NO_CLASSSTORE => "There is no software installation data in the Active Directory.",
            ITF::CS_E_OBJECT_NOTFOUND => "There is no software installation data object in the Active Directory.",
            ITF::CS_E_OBJECT_ALREADY_EXISTS => "The software installation data object in the Active Directory already exists.",
            ITF::CS_E_INVALID_PATH => "The path to the software installation data in the Active Directory is not correct.",
            ITF::CS_E_NETWORK_ERROR => "A network error interrupted the operation.",
            ITF::CS_E_ADMIN_LIMIT_EXCEEDED => "The size of this object exceeds the maximum size set by the Administrator.",
            ITF::CS_E_SCHEMA_MISMATCH => "The schema for the software installation data in the Active Directory does not match the required schema.",
            ITF::CS_E_INTERNAL_ERROR => "An error occurred in the software installation data in the Active Directory.",
            ITF::CACHE_E_NOCACHE_UPDATED => "Cache not updated.",
            ITF::OLEOBJ_E_NOVERBS => "No verbs for OLE object.",
            ITF::OLEOBJ_E_INVALIDVERB => "Invalid verb for OLE object.",
            ITF::INPLACE_E_NOTUNDOABLE => "Undo is not available.",
            ITF::INPLACE_E_NOTOOLSPACE => "Space for tools is not available.",
            ITF::CONVERT10_E_OLESTREAM_GET => "OLESTREAM Get method failed.",
            ITF::CONVERT10_E_OLESTREAM_PUT => "OLESTREAM Put method failed.",
            ITF::CONVERT10_E_OLESTREAM_FMT => "Contents of the OLESTREAM not in correct format.",
            ITF::CONVERT10_E_OLESTREAM_BITMAP_TO_DIB => "There was an error in a Windows GDI call while converting the bitmap to a DIB.",
            ITF::CONVERT10_E_STG_FMT => "Contents of the IStorage not in correct format.",
            ITF::CONVERT10_E_STG_NO_STD_STREAM => "Contents of IStorage is missing one of the standard streams.",
            ITF::CONVERT10_E_STG_DIB_TO_BITMAP => "There was an error in a Windows GDI call while converting the DIB to a bitmap.",
            ITF::CLIPBRD_E_CANT_OPEN => "OpenClipboard Failed.",
            ITF::CLIPBRD_E_CANT_EMPTY => "EmptyClipboard Failed.",
            ITF::CLIPBRD_E_CANT_SET => "SetClipboard Failed.",
            ITF::CLIPBRD_E_BAD_DATA => "Data on clipboard is invalid.",
            ITF::CLIPBRD_E_CANT_CLOSE => "CloseClipboard Failed.",
            ITF::MK_E_CONNECTMANUALLY => "Moniker needs to be connected manually.",
            ITF::MK_E_EXCEEDEDDEADLINE => "Operation exceeded deadline.",
            ITF::MK_E_NEEDGENERIC => "Moniker needs to be generic.",
            ITF::MK_E_UNAVAILABLE => "Operation unavailable.",
            ITF::MK_E_SYNTAX => "Invalid syntax.",
            ITF::MK_E_NOOBJECT => "No object for moniker.",
            ITF::MK_E_INVALIDEXTENSION => "Bad extension for file.",
            ITF::MK_E_INTERMEDIATEINTERFACENOTSUPPORTED => "Intermediate operation failed.",
            ITF::MK_E_NOTBINDABLE => "Moniker is not bindable.",
            ITF::MK_E_NOTBOUND => "Moniker is not bound.",
            ITF::MK_E_CANTOPENFILE => "Moniker cannot open file.",
            ITF::MK_E_MUSTBOTHERUSER => "User input required for operation to succeed.",
            ITF::MK_E_NOINVERSE => "Moniker class has no inverse.",
            ITF::MK_E_NOSTORAGE => "Moniker does not refer to storage.",
            ITF::MK_E_NOPREFIX => "No common prefix.",
            ITF::MK_E_ENUMERATION_FAILED => "Moniker could not be enumerated.",
            ITF::CO_E_NOTINITIALIZED => "CoInitialize has not been called.",
            ITF::DDERR_NOTINITIALIZED => "An attempt was made to call an interface method of a DirectDraw object created by CoCreateInstance before the object was initialized.",
            ITF::CO_E_ALREADYINITIALIZED => "CoInitialize has already been called.",
            ITF::CO_E_CANTDETERMINECLASS => "Class of object cannot be determined.",
            ITF::CO_E_CLASSSTRING => "Invalid class string.",
            ITF::CO_E_IIDSTRING => "Invalid interface string.",
            ITF::CO_E_APPNOTFOUND => "Application not found.",
            ITF::CO_E_APPSINGLEUSE => "Application cannot be run more than once.",
            ITF::CO_E_ERRORINAPP => "Some error in application program.",
            ITF::CO_E_DLLNOTFOUND => "DLL for class not found.",
            ITF::CO_E_ERRORINDLL => "Error in the DLL.",
            ITF::CO_E_WRONGOSFORAPP => "Wrong OS or OS version for application.",
            ITF::CO_E_OBJNOTREG => "Object is not registered.",
            ITF::CO_E_OBJISREG => "Object is already registered.",
            ITF::CO_E_OBJNOTCONNECTED => "Object is not connected to server.",
            ITF::CO_E_APPDIDNTREG => "Application was launched but it didn't register a class factory.",
            ITF::CO_E_RELEASED => "Object has been released.",
            ITF::VFW_E_INVALIDMEDIATYPE => "DirectShow: The specified media type is invalid.",
            ITF::_MAPI_E_END_OF_SESSION => "MAPI: The session has ended.",
            ITF::MPEG2_E_UNINITIALIZED => "The Initialize method was not called.",
            ITF::TF_E_INVALIDPOS => "The character position is invalid.",
            ITF::TS_E_INVALIDPOS => "Text Store: Range specified extends outside the document.",
            ITF::UPNP_E_ROOT_ELEMENT_EXPECTED => "UPnP Description Document: XML document does not have a root element at the top level of the document.",
            ITF::USP_E_SCRIPT_NOT_IN_FONT => "USP (Unicode Complex Script processor): Script doesn&#x27;t exist in font.",
            ITF::EVENT_E_ALL_SUBSCRIBERS_FAILED => "An event was unable to invoke any of the subscribers.",
            ITF::VFW_E_INVALIDSUBTYPE => "DirectShow: The specified media subtype is invalid.",
            ITF::CDO_E_UNCAUGHT_EXCEPTION => "Exception %1 was generated at address %2",
            ITF::_MAPI_E_UNKNOWN_ENTRYID => "MAPI: An entry ID is unknown.",
            ITF::MPEG2_E_ALREADY_INITIALIZED => "The object is already initialized.",
            ITF::TF_E_NOLOCK => "The caller does not have the necessary type of document.",
            ITF::TS_E_NOLOCK => "Text Store: Application does not have a read-only lock or read/write lock for the document.",
            ITF::UPNP_E_DEVICE_ELEMENT_EXPECTED => "UPnP Description Document: XML document does not have a root element at the top level of the documXML document does not have a device element. It is missing either from the root element or the DeviceList element.ent.",
            ITF::VFW_E_NEED_OWNER => "DirectShow: This object can only be created as an aggregated object.",
            ITF::CDO_E_NOT_OPENED => "No data source has been opened for the object.",
            ITF::_MAPI_E_MISSING_REQUIRED_COLUMN => "MAPI: A required column is missing.",
            ITF::MPEG2_E_OUT_OF_BOUNDS => "Index out of bounds.",
            ITF::TF_E_NOOBJECT => "No embedded object exists at the specified position.",
            ITF::TS_E_NOOBJECT => "Text Store: Embedded content offset is not positioned before a TF_CHAR_EMBEDDED character.",
            ITF::UPNP_E_SERVICE_ELEMENT_EXPECTED => "UPnP Description Document: XML document does not have a service element. It is missing from the ServiceList element, or the DeviceList element does not contain a ServiceList element.",
            ITF::EVENT_E_QUERYSYNTAX => "A syntax error occurred trying to evaluate a query string.",
            ITF::VFW_E_ENUM_OUT_OF_SYNC => "DirectShow: The enumerator has become invalid.",
            ITF::CDO_E_UNSUPPORTED_DATASOURCE => "The object does not support this type of data source.",
            ITF::MPEG2_E_MALFORMED_TABLE => "Malformed table.",
            ITF::TF_E_NOSERVICE => "The specified service does not exists or cannot be created.",
            ITF::TS_E_NOSERVICE => "Text Store: Content cannot be returned to match the service GUID.",
            ITF::UPNP_E_SERVICE_NODE_INCOMPLETE => "UPnP Description Document: XML document is missing one of the required elements from the Service element.",
            ITF::EVENT_E_QUERYFIELD => "An invalid field name was used in a query string.",
            ITF::VFW_E_ALREADY_CONNECTED => "DirectShow: At least one of the pins involved in the operation is already connected.",
            ITF::CDO_E_INVALID_PROPERTYNAME => "The object does not support the requested property name or namespace.",
            ITF::MPEG2_E_UNDEFINED => "The table does not contain this field.",
            ITF::TF_E_NOINTERFACE => "The object does not support the requested interface.",
            ITF::TS_E_NOINTERFACE => "Text Store: Object does not support the requested interface.",
            ITF::UPNP_E_DEVICE_NODE_INCOMPLETE => "UPnP Description Document: XML document is missing one of the required elements from the Device element.",
            ITF::EVENT_E_INTERNALEXCEPTION => "An unexpected exception was raised.",
            ITF::VFW_E_FILTER_ACTIVE => "DirectShow: This operation cannot be performed because the filter is active.",
            ITF::CDO_E_PROP_UNSUPPORTED => "The object does not support the requested property.",
            ITF::MPEG2_E_NOT_PRESENT => "The specified tag was not found.",
            ITF::TF_E_NOSELECTION => "No selection exists within the context.",
            ITF::TS_E_NOSELECTION => "Text Store: Document has no selection.",
            ITF::UPNP_E_ICON_ELEMENT_EXPECTED => "UPnP Description Document: XML document does not have an icon element. It is missing from the IconList element, or the DeviceList element does not contain an IconList element.",
            ITF::EVENT_E_INTERNALERROR => "An unexpected internal error was detected.",
            ITF::VFW_E_NO_TYPES => "DirectShow: One of the specified pins supports no media types.",
            ITF::CDO_E_INACTIVE => "The object is not active. It may have been deleted or it may not have been opened.",
            ITF::MPEG2_E_SECTION_NOT_FOUND => "The filter did not receive the table in the allotted time.",
            ITF::TF_E_NOLAYOUT => "The text layout has not been calculated.",
            ITF::TS_E_NOLAYOUT => "Text Store: Application has not calculated a text layout.",
            ITF::UPNP_E_ICON_NODE_INCOMPLETE => "UPnP Description Document: XML document is missing one of the required elements from the Icon element.",
            ITF::EVENT_E_INVALID_PER_USER_SID => "The owner SID on a per-user subscription doesn't exist.",
            ITF::VFW_E_NO_ACCEPTABLE_TYPES => "DirectShow: There is no common media type between these pins.",
            ITF::CDO_E_NO_SUPPORT_FOR_OBJECTS => "The object does not support storing persistent state information for objects.",
            ITF::MPEG2_E_TX_STREAM_UNAVAILABLE => "Description is missing",
            ITF::TF_E_INVALIDPOINT => "The screen coordinates are invalid.",
            ITF::TS_E_INVALIDPOINT => "Text Store: Parameter is not within the bounding box of any character.",
            ITF::UPNP_E_INVALID_ACTION => "This service does not support the specified action. This is a standard UPnP error. Evaluates to 401.",
            ITF::EVENT_E_USER_EXCEPTION => "A user-supplied component or subscriber raised an exception.",
            ITF::VFW_E_INVALID_DIRECTION => "DirectShow: Two pins of the same direction cannot be connected.",
            ITF::CDO_E_NOT_AVAILABLE => "The requested property or feature, while supported, is not available at this time or in this context.",
            ITF::MPEG2_E_SERVICE_ID_NOT_FOUND => "Description is missing",
            ITF::TF_E_SYNCHRONOUS => "A synchronous read-only lock cannot be obtained.",
            ITF::TS_E_SYNCHRONOUS => "Text Store: Document cannot be locked synchronously.",
            ITF::UPNP_E_INVALID_ARGUMENTS => "One or more of the arguments passed in vInActionArgs is invalid.",
            ITF::EVENT_E_TOO_MANY_METHODS => "An interface has too many methods to fire events from.",
            ITF::VFW_E_NOT_CONNECTED => "DirectShow: The operation cannot be performed because the pins are not connected.",
            ITF::CDO_E_NO_DEFAULT_DROP_DIR => "No default drop directory has been configured for this server.",
            ITF::MPEG2_E_SERVICE_PMT_NOT_FOUND => "Description is missing",
            ITF::TF_E_READONLY => "The edit context is read-only.",
            ITF::TS_E_READONLY => "Text Store: Document is read-only. Cannot modify content.",
            ITF::UPNP_E_OUT_OF_SYNC => "Invalid Sequence Number",
            ITF::EVENT_E_MISSING_EVENTCLASS => "A subscription cannot be stored unless its event class already exists.",
            ITF::VFW_E_NO_ALLOCATOR => "DirectShow: No sample buffer allocator is available.",
            ITF::CDO_E_SMTP_SERVER_REQUIRED => "The SMTP server name is required, and was not found in the configuration source.",
            ITF::MPEG2_E_DSI_NOT_FOUND => "Description is missing",
            ITF::TF_E_FORMAT => "Context owner cannot handle objects of the type provided by the pDataObject parameter.",
            ITF::TS_E_FORMAT => "Text Store: Application does not support the data type contained in the&#xA0;IDataObject&#xA0;object to be inserted using&#xA0;ITextStoreACP::InsertEmbedded.",
            ITF::EVENT_E_NOT_ALL_REMOVED => "Not all the objects requested could be removed.",
            ITF::VFW_E_RUNTIME_ERROR => "DirectShow: A run-time error occurred.",
            ITF::CDO_E_NNTP_SERVER_REQUIRED => "The NNTP server name is required, and was not found in the configuration source.",
            ITF::IMAPI_E_NOTOPENED => "A call to&#xA0;IDiscMaster::Open&#xA0;has not been made.",
            ITF::MPEG2_E_SERVER_UNAVAILABLE => "Description is missing",
            ITF::EVENT_E_COMPLUS_NOT_INSTALLED => "COM+ is required for this operation, but is not installed.",
            ITF::VFW_E_BUFFER_NOTSET => "DirectShow: No buffer space has been set.",
            ITF::CDO_E_RECIPIENT_MISSING => "At least one recipient is required, but none were found.",
            ITF::IMAPI_E_NOTINITIALIZED => "A recorder object has not been initialized.",
            ITF::MPEG2_E_INVALID_CAROUSEL_ID => "Description is missing",
            ITF::EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT => "Cannot modify or delete an object that was not added using the COM+ Admin SDK.",
            ITF::VFW_E_BUFFER_OVERFLOW => "DirectShow: The buffer is not big enough.",
            ITF::CDO_E_FROM_MISSING => "At least one of the From or Sender fields is required, and neither was found.",
            ITF::IMAPI_E_USERABORT => "The user canceled the operation.",
            ITF::MPEG2_E_MALFORMED_DSMCC_MESSAGE => "Description is missing",
            ITF::EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT => "Cannot modify or delete an object that was added using the COM+ Admin SDK.",
            ITF::VFW_E_BADALIGN => "DirectShow: An invalid alignment was specified.",
            ITF::CDO_E_SENDER_REJECTED => "The server rejected the sender address. The server response was: %1",
            ITF::IMAPI_E_GENERIC => "A generic error occurred.",
            ITF::MPEG2_E_INVALID_SG_OBJECT_KIND => "Description is missing",
            ITF::EVENT_E_INVALID_EVENT_CLASS_PARTITION => "The event class for this subscription is in an invalid partition.",
            ITF::VFW_E_ALREADY_COMMITTED => "DirectShow: Cannot change allocated memory while the filter is active.",
            ITF::CDO_E_RECIPIENTS_REJECTED => "The server rejected one or more recipient addresses. The server response was: %1",
            ITF::IMAPI_E_MEDIUM_NOTPRESENT => "There is no disc in the device.",
            ITF::MPEG2_E_OBJECT_NOT_FOUND => "Description is missing",
            ITF::EVENT_E_PER_USER_SID_NOT_LOGGED_ON => "The owner of the PerUser subscription is not logged on to the system specified.",
            ITF::VFW_E_BUFFERS_OUTSTANDING => "DirectShow: One or more buffers are still active.",
            ITF::CDO_E_NNTP_POST_FAILED => "The message could not be posted to the NNTP server. The transport error code was %2. The server response was %1",
            ITF::IMAPI_E_MEDIUM_INVALIDTYPE => "The media is not a type that can be used.",
            ITF::MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY => "Description is missing",
            ITF::UPNP_E_ACTION_REQUEST_FAILED => "The device had an internal error; the request could not be executed.",
            ITF::VFW_E_NOT_COMMITTED => "DirectShow: Cannot allocate a sample when the allocator is not active.",
            ITF::CDO_E_SMTP_SEND_FAILED => "The message could not be sent to the SMTP server. The transport error code was %2. The server response was %1",
            ITF::IMAPI_E_DEVICE_NOPROPERTIES => "The recorder does not support any properties.",
            ITF::MPEG2_E_OBJECT_KIND_NOT_A_FILE => "Description is missing",
            ITF::UPNP_E_TRANSPORT_ERROR => "An HTTP error occurred. Use the IUPnPService::LastTransportStatus property to obtain the actual HTTP status code. (Note: This error code is also returned when the SOAP response exceeds 100 kilobytes.)",
            ITF::TPC_E_NO_DEFAULT_TABLET => "TabletPC inking error code. No default tablet.",
            ITF::VFW_E_SIZENOTSET => "DirectShow: Cannot allocate memory because no size has been set.",
            ITF::CDO_E_CONNECTION_DROPPED => "The transport lost its connection to the server.",
            ITF::IMAPI_E_DEVICE_NOTACCESSIBLE => "The device cannot be used or is already in use.",
            ITF::MPEG2_E_FILE_OFFSET_TOO_BIG => "Description is missing",
            ITF::UPNP_E_VARIABLE_VALUE_UNKNOWN => "The variable is evented, but the UPnP software cannot return a value because it is still waiting for an event notification.",
            ITF::VFW_E_NO_CLOCK => "DirectShow: Cannot lock for synchronization because no clock has been defined.",
            ITF::CDO_E_FAILED_TO_CONNECT => "The transport failed to connect to the server.",
            ITF::IMAPI_E_DEVICE_NOTPRESENT => "The device is not present or has been removed.",
            ITF::MPEG2_E_STREAM_STOPPED => "Description is missing",
            ITF::UPNP_E_INVALID_VARIABLE => "The variable does not exist.",
            ITF::VFW_E_NO_SINK => "DirectShow: Quality messages could not be sent because no quality sink has been defined.",
            ITF::CDO_E_INVALID_POST => "The Subject, From, and Newsgroup fields are all required, and one or more was not found.",
            ITF::IMAPI_E_DEVICE_INVALIDTYPE => "The recorder does not support an operation.",
            ITF::MPEG2_E_REGISTRY_ACCESS_FAILED => "Description is missing",
            ITF::UPNP_E_DEVICE_ERROR => "An unknown error occurred.",
            ITF::VFW_E_NO_INTERFACE => "DirectShow: A required interface has not been implemented.",
            ITF::CDO_E_AUTHENTICATION_FAILURE => "The server rejected the logon attempt due to authentication failure. The server response was: %1",
            ITF::IMAPI_E_INITIALIZE_WRITE => "The drive interface could not be initialized for writing.",
            ITF::MPEG2_E_INVALID_UDP_PORT => "Description is missing",
            ITF::UPNP_E_PROTOCOL_ERROR => "An error occurred at the UPnP control-protocol level.",
            ITF::VFW_E_NOT_FOUND => "DirectShow: An object or name was not found.",
            ITF::CDO_E_INVALID_CONTENT_TYPE => "The content type was not valid in this context. For example, the root of an MHTML message must be an HTML document.",
            ITF::IMAPI_E_INITIALIZE_ENDWRITE => "The drive interface could not be initialized for closing.",
            ITF::MPEG2_E_DATA_SOURCE_FAILED => "Description is missing",
            ITF::UPNP_E_ERROR_PROCESSING_RESPONSE => "The device has sent a response that cannot be processed; for example, the response was corrupted.",
            ITF::VFW_E_CANNOT_CONNECT => "DirectShow: No combination of intermediate filters could be found to make the connection.",
            ITF::CDO_E_LOGON_FAILURE => "The transport was unable to log on to the server.",
            ITF::IMAPI_E_FILESYSTEM => "An error occurred while enabling/disabling file system access or during auto-insertion detection.",
            ITF::MPEG2_E_DII_NOT_FOUND => "Description is missing",
            ITF::UPNP_E_DEVICE_TIMEOUT => "The device has not responded within the 30 second time-out period.",
            ITF::VFW_E_CANNOT_RENDER => "DirectShow: No combination of filters could be found to render the stream.",
            ITF::CDO_E_HTTP_NOT_FOUND => "The requested resource could not be found. The server response was: %1.",
            ITF::IMAPI_E_FILEACCESS => "An error occurred while writing the image file.",
            ITF::MPEG2_E_DSHOW_PIN_NOT_FOUND => "Description is missing",
            ITF::TPC_E_INVALID_INPUT_RECT => "TabletPC inking error code. An invalid input rectangle was specified.",
            ITF::VFW_E_CHANGING_FORMAT => "DirectShow: Could not change formats dynamically.",
            ITF::CDO_E_HTTP_FORBIDDEN => "Access to the requested resource is denied. The server response was: %1.",
            ITF::IMAPI_E_DISCINFO => "An error occurred while trying to read disc data from the device.",
            ITF::MPEG2_E_BUFFER_TOO_SMALL => "Description is missing",
            ITF::VFW_E_NO_COLOR_KEY_SET => "DirectShow: No color key has been set.",
            ITF::CDO_E_HTTP_FAILED => "The HTTP request failed. The server response was: %1.",
            ITF::IMAPI_E_TRACKNOTOPEN => "An audio track is not open for writing.",
            ITF::MPEG2_E_MISSING_SECTIONS => "Description is missing",
            ITF::TPC_E_UNKNOWN_PROPERTY => "TabletPC inking error code. Unknown property specified.",
            ITF::VFW_E_NOT_OVERLAY_CONNECTION => "DirectShow: Current pin connection is not using the&#xA0;IOverlay&#xA0;transport.",
            ITF::CDO_E_MULTIPART_NO_DATA => "This is a multipart body part. It has no content other than the body parts contained within it.",
            ITF::IMAPI_E_TRACKOPEN => "An open audio track is already being staged.",
            ITF::MPEG2_E_TOO_MANY_SECTIONS => "Description is missing",
            ITF::VFW_E_NOT_SAMPLE_CONNECTION => "DirectShow: Current pin connection is not using the IMemInputPintransport.",
            ITF::CDO_E_INVALID_ENCODING_FOR_MULTIPART => "Multipart body parts must be encoded as 7bit, 8bit, or binary.",
            ITF::IMAPI_E_DISCFULL => "The disc cannot hold any more data.",
            ITF::MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE => "Description is missing",
            ITF::VFW_E_PALETTE_SET => "DirectShow: Setting a color key would conflict with the palette already set.",
            ITF::CDO_E_UNSAFE_OPERATION => "The requested operation is not allowed in secure mode.",
            ITF::IMAPI_E_BADJOLIETNAME => "The application tried to add a badly named element to a disc.",
            ITF::MPEG2_E_INCORRECT_DESCRIPTOR_TAG => "Description is missing",
            ITF::VFW_E_COLOR_KEY_SET => "DirectShow: Setting a palette would conflict with the color key already set.",
            ITF::CDO_E_PROP_NOT_FOUND => "The requested property was not found.",
            ITF::IMAPI_E_INVALIDIMAGE => "The staged image is not suitable for a burn. It has been corrupted or cleared and has no usable content.",
            ITF::VFW_E_NO_COLOR_KEY_FOUND => "DirectShow: No matching color key is available.",
            ITF::IMAPI_E_NOACTIVEFORMAT => "An active format master has not been selected using&#xA0;IDiscMaster::SetActiveDiscMasterFormat.",
            ITF::VFW_E_NO_PALETTE_AVAILABLE => "DirectShow: No palette is available.",
            ITF::CDO_E_INVALID_SEND_OPTION => "The &quot;SendUsing&quot; configuration value is invalid.",
            ITF::IMAPI_E_NOACTIVERECORDER => "An active disc recorder has not been selected using&#xA0;IDiscMaster::SetActiveDiscRecorder.",
            ITF::VFW_E_NO_DISPLAY_PALETTE => "DirectShow: Display does not use a palette.",
            ITF::CDO_E_INVALID_POST_OPTION => "The &quot;PostUsing&quot; configuration value is invalid.",
            ITF::IMAPI_E_WRONGFORMAT => "A call to&#xA0;IJolietDiscMaster&#xA0;has been made when&#xA0;IRedbookDiscMaster&#xA0;is the active format, or vice versa. To use a different format, change the format and clear the image file contents.",
            ITF::TPC_E_INVALID_STROKE => "TabletPC inking error code. The stroke object was deleted.",
            ITF::VFW_E_TOO_MANY_COLORS => "DirectShow: Too many colors for the current display settings.",
            ITF::CDO_E_NO_PICKUP_DIR => "The pickup directory path is required and was not specified.",
            ITF::IMAPI_E_ALREADYOPEN => "A call to&#xA0;IDiscMaster::Open&#xA0;has already been made against this object by your application.",
            ITF::TPC_E_INITIALIZE_FAIL => "TabletPC inking error code. Initialization failure.",
            ITF::VFW_E_STATE_CHANGED => "DirectShow: The state changed while waiting to process the sample.",
            ITF::CDO_E_NOT_ALL_DELETED => "One or more messages could not be deleted.",
            ITF::IMAPI_E_WRONGDISC => "The IMAPI multi-session disc has been removed from the active recorder.",
            ITF::VFW_E_NOT_STOPPED => "DirectShow: The operation could not be performed because the filter is not stopped.",
            ITF::CDO_E_NO_METHOD => "The requested operation is not available on the underlying object.",
            ITF::IMAPI_E_FILEEXISTS => "The file to add is already in the image file and the overwrite flag was not set.",
            ITF::VFW_E_NOT_PAUSED => "DirectShow: The operation could not be performed because the filter is not paused.",
            ITF::IMAPI_E_STASHINUSE => "Another application is already using the IMAPI stash file required to stage a disc image. Try again later.",
            ITF::VFW_E_NOT_RUNNING => "DirectShow: The operation could not be performed because the filter is not running.",
            ITF::IMAPI_E_DEVICE_STILL_IN_USE => "Another application is already using this device, so IMAPI cannot access the device.",
            ITF::VFW_E_WRONG_STATE => "DirectShow: The operation could not be performed because the filter is in the wrong state.",
            ITF::CDO_E_PROP_READONLY => "The property is read-only.",
            ITF::IMAPI_E_LOSS_OF_STREAMING => "Content streaming was lost; a buffer under-run may have occurred.",
            ITF::VFW_E_START_TIME_AFTER_END => "DirectShow: The sample start time is after the sample end time.",
            ITF::CDO_E_PROP_CANNOT_DELETE => "The property cannot be deleted.",
            ITF::IMAPI_E_COMPRESSEDSTASH => "The stash is located on a compressed volume and cannot be read.",
            ITF::VFW_E_INVALID_RECT => "DirectShow: The supplied rectangle is invalid.",
            ITF::CDO_E_BAD_DATA => "Data written to the object are inconsistent or invalid.",
            ITF::IMAPI_E_ENCRYPTEDSTASH => "The stash is located on an encrypted volume and cannot be read.",
            ITF::VFW_E_TYPE_NOT_ACCEPTED => "DirectShow: This pin cannot use the supplied media type.",
            ITF::CDO_E_PROP_NONHEADER => "The requested property is not in the mail header namespace.",
            ITF::IMAPI_E_NOTENOUGHDISKFORSTASH => "There is not enough free space to create the stash file on the specified volume.",
            ITF::VFW_E_SAMPLE_REJECTED => "DirectShow: This sample cannot be rendered.",
            ITF::CDO_E_INVALID_CHARSET => "The requested character set is not installed on the computer.",
            ITF::IMAPI_E_REMOVABLESTASH => "The selected stash location is on a removable media.",
            ITF::VFW_E_SAMPLE_REJECTED_EOS => "DirectShow: This sample cannot be rendered because the end of the stream has been reached.",
            ITF::CDO_E_ADOSTREAM_NOT_BOUND => "The ADO stream has not been opened.",
            ITF::IMAPI_E_CANNOT_WRITE_TO_MEDIA => "The media cannot be written to.",
            ITF::VFW_E_DUPLICATE_NAME => "DirectShow: An attempt to add a filter with a duplicate name failed.",
            ITF::CDO_E_CONTENTPROPXML_NOT_FOUND => "The content properties are missing.",
            ITF::IMAPI_E_TRACK_NOT_BIG_ENOUGH => "The track is not big enough.",
            ITF::VFW_E_TIMEOUT => "DirectShow: A time-out has expired.",
            ITF::CDO_E_CONTENTPROPXML_WRONG_CHARSET => "Content properties XML must be encoded using UTF-8.",
            ITF::VFW_E_INVALID_FILE_FORMAT => "DirectShow: The file format is invalid.",
            ITF::CDO_E_CONTENTPROPXML_PARSE_FAILED => "Failed to parse content properties XML.",
            ITF::VFW_E_ENUM_OUT_OF_RANGE => "DirectShow: The list has already been exhausted.",
            ITF::CDO_E_CONTENTPROPXML_CONVERT_FAILED => "Failed to convert a property from XML to a requested type.",
            ITF::VFW_E_CIRCULAR_GRAPH => "DirectShow: The filter graph is circular.",
            ITF::CDO_E_NO_DIRECTORIES_SPECIFIED => "No directories were specified for resolution.",
            ITF::TPC_E_NOT_RELEVANT => "TabletPC inking error code. The data required for the operation was not supplied.",
            ITF::VFW_E_NOT_ALLOWED_TO_SAVE => "DirectShow: Updates are not allowed in this state.",
            ITF::CDO_E_DIRECTORIES_UNREACHABLE => "Failed to resolve against one or more of the specified directories.",
            ITF::TPC_E_INVALID_PACKET_DESCRIPTION => "TabletPC inking error code. Invalid packet description.",
            ITF::VFW_E_TIME_ALREADY_PASSED => "DirectShow: An attempt was made to queue a command for a time in the past.",
            ITF::CDO_E_BAD_SENDER => "Could not find the Sender&#x27;s mailbox.",
            ITF::VFW_E_ALREADY_CANCELLED => "DirectShow: The queued command was already canceled.",
            ITF::CDO_E_SELF_BINDING => "Binding to self is not allowed.",
            ITF::TPC_E_RECOGNIZER_NOT_REGISTERED => "TabletPC inking error code. There are no handwriting recognizers registered.",
            ITF::VFW_E_CORRUPT_GRAPH_FILE => "DirectShow: Cannot render the file because it is corrupt.",
            ITF::CDO_E_BAD_ATTENDEE_DATA => "Data of the Attendees in the object are inconsistent or invalid.",
            ITF::TPC_E_INVALID_RIGHTS => "TabletPC inking error code. User does not have the necessary rights to read recognizer information.",
            ITF::VFW_E_ADVISE_ALREADY_SET => "DirectShow: An&#xA0;IOverlay&#xA0;link already exists.",
            ITF::CDO_E_ROLE_NOMORE_AVAILABLE => "No more roles of the desired type are available - maxed out.",
            ITF::TPC_E_OUT_OF_ORDER_CALL => "TabletPC inking error code. API calls were made in an incorrect order.",
            ITF::CDO_E_BAD_TASKTYPE_ONASSIGN => "The task with its current task type does not permit a call on Assign. Please call CreateUnassignedCopy instead.",
            ITF::TPC_E_QUEUE_FULL => "TabletPC inking error code. Queue is full.",
            ITF::VFW_E_NO_MODEX_AVAILABLE => "DirectShow: No full-screen modes are available.",
            ITF::CDO_E_NOT_ASSIGNEDTO_USER => "The task is not assigned to the current user.",
            ITF::TPC_E_INVALID_CONFIGURATION => "TabletPC inking error code. RtpEnabled called multiple times.",
            ITF::VFW_E_NO_ADVISE_SET => "DirectShow: This advise cannot be canceled because it was not successfully set.",
            ITF::CDO_E_OUTOFDATE => "The item being accessed or manipulated is out of date.",
            ITF::TPC_E_INVALID_DATA_FROM_RECOGNIZER => "TabletPC inking error code. A recognizer returned invalid data.",
            ITF::VFW_E_NO_FULLSCREEN => "DirectShow: Full-screen mode is not available.",
            ITF::VFW_E_IN_FULLSCREEN_MODE => "DirectShow: Cannot call IVideoWindowmethods while in full-screen mode.",
            ITF::VFW_E_UNKNOWN_FILE_TYPE => "DirectShow: The media type of this file is not recognized.",
            ITF::TPC_E_INVALID_PROPERTY => "TabletPC inking error code. The property was not found, or supported by the recognizer.",
            ITF::VFW_E_CANNOT_LOAD_SOURCE_FILTER => "DirectShow: The source filter for this file could not be loaded.",
            ITF::VFW_E_FILE_TOO_SHORT => "DirectShow: A file appeared to be incomplete.",
            ITF::VFW_E_INVALID_FILE_VERSION => "DirectShow: The file's version number is invalid.",
            ITF::VFW_E_INVALID_CLSID => "DirectShow: This file is corrupt: it contains an invalid class identifier.",
            ITF::VFW_E_INVALID_MEDIA_TYPE => "DirectShow: This file is corrupt: it contains an invalid media type.",
            ITF::VFW_E_SAMPLE_TIME_NOT_SET => "DirectShow: No time stamp has been set for this sample.",
            ITF::VFW_E_MEDIA_TIME_NOT_SET => "DirectShow: No media time stamp was set for this sample.",
            ITF::VFW_E_NO_TIME_FORMAT_SET => "DirectShow: No media time format was selected.",
            ITF::VFW_E_MONO_AUDIO_HW => "DirectShow: Cannot change balance because audio device is monoaural only.",
            ITF::VFW_E_NO_DECOMPRESSOR => "DirectShow: Cannot play back the video stream: could not find a suitable decompressor.",
            ITF::VFW_E_NO_AUDIO_HARDWARE => "DirectShow: Cannot play back the audio stream: no audio hardware is available, or the hardware is not supported.",
            ITF::VFW_E_RPZA => "DirectShow: Cannot play back the video stream: format 'RPZA' is not supported.",
            ITF::VFW_E_PROCESSOR_NOT_SUITABLE => "DirectShow: DirectShow cannot play MPEG movies on this processor.",
            ITF::VFW_E_UNSUPPORTED_AUDIO => "DirectShow: Cannot play back the audio stream: the audio format is not supported.",
            ITF::VFW_E_UNSUPPORTED_VIDEO => "DirectShow: Cannot play back the video stream: the video format is not supported.",
            ITF::VFW_E_MPEG_NOT_CONSTRAINED => "DirectShow: DirectShow cannot play this video stream because it falls outside the constrained standard.",
            ITF::VFW_E_NOT_IN_GRAPH => "DirectShow: Cannot perform the requested function on an object that is not in the filter graph.",
            ITF::VFW_E_NO_TIME_FORMAT => "DirectShow: Cannot access the time format on an object.",
            ITF::VFW_E_READ_ONLY => "DirectShow: Could not make the connection because the stream is read-only and the filter alters the data.",
            ITF::VFW_E_BUFFER_UNDERFLOW => "DirectShow: The buffer is not full enough.",
            ITF::VFW_E_UNSUPPORTED_STREAM => "DirectShow: Cannot play back the file: the format is not supported.",
            ITF::VFW_E_NO_TRANSPORT => "DirectShow: Pins cannot connect because they do not support the same transport.",
            ITF::VFW_E_BAD_VIDEOCD => "DirectShow: The Video CD cannot be read correctly by the device or is the data is corrupt.",
            ITF::VFW_S_NO_STOP_TIME => "DirectShow: The sample had a start time but not a stop time. In this case, the stop time returned is set to the start time plus one. The IMediaSample::GetTime method can return this success code.",
            ITF::VFW_E_OUT_OF_VIDEO_MEMORY => "DirectShow: There is not enough video memory at this display resolution and number of colors. Reducing resolution might help.",
            ITF::VFW_E_VP_NEGOTIATION_FAILED => "DirectShow: The video port connection negotiation process has failed.",
            ITF::VFW_E_DDRAW_CAPS_NOT_SUITABLE => "DirectShow: Either Microsoft DirectDraw® has not been installed or the video card capabilities are not suitable. Make sure the display is not in 16-color mode.",
            ITF::VFW_E_NO_VP_HARDWARE => "DirectShow: No video port hardware is available, or the hardware is not responding.",
            ITF::VFW_E_NO_CAPTURE_HARDWARE => "DirectShow: No capture hardware is available, or the hardware is not responding.",
            ITF::VFW_E_DVD_OPERATION_INHIBITED => "DirectShow: DVD operation error.",
            ITF::VFW_E_DVD_INVALIDDOMAIN => "DirectShow: DVD operation error.",
            ITF::VFW_E_DVD_NO_BUTTON => "DirectShow: DVD operation error.",
            ITF::VFW_E_DVD_GRAPHNOTREADY => "DirectShow: DVD operation error.",
            ITF::VFW_E_DVD_RENDERFAIL => "DirectShow: DVD operation error.",
            ITF::VFW_E_DVD_DECNOTENOUGH => "DirectShow: DVD operation error.",
            ITF::VFW_E_DDRAW_VERSION_NOT_SUITABLE => "Version number of DirectDraw not suitable. Make sure to install dx5 or higher version.%0.",
            ITF::VFW_E_COPYPROT_FAILED => "Copy protection cannot be enabled. Please make sure any other copy protected content is not being shown now.%0.",
            ITF::VFW_E_TIME_EXPIRED => "This object cannot be used anymore as its time has expired.%0.",
            ITF::VFW_E_DVD_WRONG_SPEED => "The operation cannot be performed at the current playback speed.%0.",
            ITF::VFW_E_DVD_MENU_DOES_NOT_EXIST => "The specified menu doesn't exist.%0.",
            ITF::VFW_E_DVD_CMD_CANCELLED => "The specified command was either cancelled or no longer exists.%0.",
            ITF::VFW_E_DVD_STATE_WRONG_VERSION => "The data did not contain a recognized version.%0.",
            ITF::VFW_E_DVD_STATE_CORRUPT => "The state data was corrupt.%0.",
            ITF::VFW_E_DVD_STATE_WRONG_DISC => "The state data is from a different disc.%0.",
            ITF::VFW_E_DVD_INCOMPATIBLE_REGION => "The region was not compatible with the current drive.%0.",
            ITF::VFW_E_DVD_NO_ATTRIBUTES => "The requested DVD stream attribute does not exist.%0.",
            ITF::VFW_E_DVD_NO_GOUP_PGC => "Currently there is no GoUp (Annex J user function) program chain (PGC).%0.",
            ITF::VFW_E_DVD_LOW_PARENTAL_LEVEL => "The current parental level was too low.%0.",
            ITF::VFW_E_DVD_NOT_IN_KARAOKE_MODE => "The current audio is not karaoke content.%0.",
            ITF::VFW_E_FRAME_STEP_UNSUPPORTED => "Frame step is not supported on this configuration.%0.",
            ITF::VFW_E_DVD_STREAM_DISABLED => "The specified stream is disabled and cannot be selected.%0.",
            ITF::VFW_E_DVD_TITLE_UNKNOWN => "The operation depends on the current title number, however the navigator has not yet entered the VTSM or the title domains, so the 'current' title index is unknown.%0.",
            ITF::VFW_E_DVD_INVALID_DISC => "The specified path does not point to a valid DVD disc.%0.",
            ITF::VFW_E_DVD_NO_RESUME_INFORMATION => "There is currently no resume information.%0.",
            ITF::VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD => "This thread has already blocked this output pin. There is no need to call IPinFlowControl::Block() again.%0.",
            ITF::VFW_E_PIN_ALREADY_BLOCKED => "IPinFlowControl::Block() has been called on another thread. The current thread cannot make any assumptions about this pin's block state.%0.",
            ITF::VFW_E_CERTIFICATION_FAILURE => "An operation failed due to a certification failure.%0.",
            ITF::VFW_E_VMR_NOT_IN_MIXER_MODE => "The VMR has not yet created a mixing component. That is, IVMRFilterConfig::SetNumberofStreams has not yet been called.%0.",
            ITF::VFW_E_VMR_NO_AP_SUPPLIED => "The application has not yet provided the VMR filter with a valid allocator-presenter object.%0.",
            ITF::VFW_E_VMR_NO_DEINTERLACE_HW => "The VMR could not find any de-interlacing hardware on the current display device.%0.",
            ITF::VFW_E_VMR_NO_PROCAMP_HW => "The VMR could not find any ProcAmp hardware on the current display device.%0.",
            ITF::VFW_E_DVD_VMR9_INCOMPATIBLEDEC => "VMR9 does not work with VPE-based hardware decoders.%0.",
            ITF::VFW_E_NO_COPP_HW => "The current display device does not support Content Output Protection Protocol (COPP) H/W.%0.",
            ITF::VFW_E_DVD_NONBLOCKING => "Nonblocking APIs are enabled and the nav cannot perform the operation at this time (IDVDControl) or partially incomplete information may be returned (DVDInfo).%0.",
            ITF::VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH => "The DVD Graph Builder cannot build a DVD playback filter graph if the EVR and another renderer are in the graph builder's filter graph.",
            ITF::VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH => "AM_DVD_EVR_ONLY cannot be passed to RenderDvdVideoVolume if the graph builder's filter graph contains a renderer which is not the EVR.",
            ITF::VFW_E_DVD_RESOLUTION_ERROR => "DVD Video Output is not at a proper resolution.",
            ITF::NET_E_GENERAL => "A network read or write operation has failed.",
            ITF::FHCFG_E_CORRUPT_CONFIG_FILE => "Configuration Manager: The Config File is corrupted and hence invalid",
            ITF::UPNP_E_ACTION_SPECIFIC_BASE => "Symbol which helps finding standard and nonstandard Device Error Codes",
            ITF::FHCFG_E_CONFIG_FILE_NOT_FOUND => "Configuration Manager: The Config File not found.",
            ITF::FHCFG_E_CONFIG_ALREADY_EXISTS => "Configuration Manager: The Config File already exists.",
            ITF::NET_E_DISCONNECTED => "The network connection was lost. Try the query again.",
            ITF::FHCFG_E_NO_VALID_CONFIGURATION_LOADED => "Configuration Manager: A valid configuration has not been loaded",
            ITF::FHCFG_E_TARGET_NOT_CONNECTED => "Configuration Manager: Target is not connected.",
            ITF::FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED => "Configuration Manager: Configuration has been loaded previously.",
            ITF::FHCFG_E_TARGET_VERIFICATION_FAILED => "Configuration Manager: Default target verification failed.",
            ITF::FHCFG_E_TARGET_NOT_CONFIGURED => "Configuration Manager: Target is not configured.",
            ITF::NET_E_INVALIDPARAMS => "The parameters passed were not valid.",
            ITF::FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE => "Configuration Manager: Target doesn&#x27;t have enough free space",
            ITF::NET_E_OPERATIONINPROGRESS => "Another operation is already in progress on this socket. Try the query again.",
            ITF::FHCFG_E_TARGET_CANNOT_BE_USED => "Configuration Manager: Target cannot be used for File History",
            ITF::VFW_E_CODECAPI_LINEAR_RANGE => "Parameter has linear range.%0.",
            ITF::FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED => "Configuration Manager: Changing target recommendation is not allowed",
            ITF::VFW_E_CODECAPI_ENUMERATED => "Parameter is enumerated. It has no range.%0.",
            ITF::FHCFG_E_TARGET_REHYDRATED_ELSEWHERE => "Configuration Manager: The target was rehydrated on another PC.",
            ITF::FHCFG_E_LEGACY_TARGET_UNSUPPORTED => "Configuration Manager: The legacy backup target was not supported by FileHistory.",
            ITF::VFW_E_CODECAPI_NO_DEFAULT => "No default value.%0.",
            ITF::FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED => "Configuration Manager: The validation result of the legacy backup target was not supported",
            ITF::VFW_E_CODECAPI_NO_CURRENT_VALUE => "No current value.%0.",
            ITF::FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED => "Configuration Manager: The legacy backup user was fully excluded from backups",
            ITF::VFW_E_DVD_CHAPTER_DOES_NOT_EXIST => "The operation failed since the chapter does not exist.%0.",
            ITF::FHCFG_E_LEGACY_BACKUP_NOT_FOUND => "Configuration Manager: The legacy backup was not found",
            ITF::VFW_E_BAD_KEY => "DirectShow: A registry entry is corrupt.",
            ITF::DS_E_NOMOREDATA => "There is no more data to return.",
            ITF::DS_E_INVALIDDATASOURCE => "The requested content index name is not valid. Use a valid content index name.",
            ITF::MS_E_SAMPLEALLOC => "An&#xA0;IMediaStream&#xA0;object could not be removed from an&#xA0;IMultiMediaStream&#xA0;object because it still contains at least one allocated sample.",
            ITF::DS_E_DATASOURCENOTAVAILABLE => "The requested content index is disabled on the search server. Contact the system administrator to enable the content index. Check the event log for possible errors.",
            ITF::MS_E_PURPOSEID => "The specified purpose ID can&#x27;t be used for the call.",
            ITF::DS_E_QUERYCANCELED => "The query was cancelled at the user's request.",
            ITF::MS_E_NOSTREAM => "No stream can be found with the specified attributes.",
            ITF::DS_E_UNKNOWNREQUEST => "The request code is not valid.",
            ITF::MS_E_NOSEEKING => "Seeking not supported for this&#xA0;IMultiMediaStream&#xA0;object.",
            ITF::DS_E_BADREQUEST => "The request data is not valid for the given request type.",
            ITF::MS_E_INCOMPATIBLE => "The stream formats are not compatible.",
            ITF::DS_E_SERVERCAPACITY => "The request cannot be processed, because the system is low on resources. Try again later, or contact your system administrator to free up system resources.",
            ITF::MS_E_BUSY => "The sample is busy.",
            ITF::DS_E_BADSEQUENCE => "The request or function call is out of sequence. Check for programming errors.",
            ITF::MS_E_NOTINIT => "The object can&#x27;t accept the call because its initialize function or equivalent has not been called.",
            ITF::DS_E_MESSAGETOOLONG => "The query text is too long.",
            ITF::MS_E_SOURCEALREADYDEFINED => "Source already defined.",
            ITF::DS_E_SERVERERROR => "The request cannot be processed because of an error in the search server.",
            ITF::MS_E_INVALIDSTREAMTYPE => "The stream type is not valid for this operation.",
            ITF::DS_E_CONFIGBAD => "The configuration file for the content index is not valid.",
            ITF::MS_E_NOTRUNNING => "The&#xA0;IMultiMediaStream&#xA0;object is not in running state.",
            ITF::DS_E_DATANOTPRESENT => "The search server cannot find one or more catalog files. Check the event log for related failures.",
            ITF::DS_E_SETSTATUSINPROGRESS => "The SetStatus operation cannot be completed, because another SetStatus operation is already in progress. Try again after the current operation is completed.",
            ITF::DS_E_DUPLICATEID => "The content index cannot be created, because another content index with the same name already exists. Create the content index using a different name.",
            ITF::DS_E_TOOMANYDATASOURCES => "The content index cannot be created, because the limit on the number of indexes was reached.",
            ITF::DS_E_REGISTRY => "The search server cannot read or write to the registry. Check that the search server is running with administrative privileges.",
            ITF::DS_E_DATASOURCENOTDISABLED => "The content index cannot be removed in the current state. Disable and remove the content index.",
            ITF::DS_E_INVALIDTAGDB => "The tag database is not valid. Contact your system administrator.",
            ITF::DS_E_INVALIDCATALOGNAME => "The content index name is in the wrong format. Use a name without spaces or punctuation.",
            ITF::DS_E_CONFIGNOTRIGHTTYPE => "The configuration file is not the correct type.",
            ITF::DS_E_PROTOCOLVERSION => "There is a mismatch in the protocol between the search service and the client. Install the correct version of the client.",
            ITF::DS_E_ALREADYENABLED => "The index is already enabled.",
            ITF::DS_E_INDEXDIRECTORY => "The content index directory structure cannot be created. See the event log for related errors.",
            ITF::DS_E_VALUETOOLARGE => "The value exceeds the maximum length.",
            ITF::DS_E_UNKNOWNPARAM => "The requested parameter is unknown.",
            ITF::DS_E_BUFFERTOOSMALL => "The buffer is too small.",
            ITF::DS_E_PARAMOUTOFRANGE => "The parameter value is out of range.",
            ITF::DS_E_ALREADYDISABLED => "The content index is already disabled.",
            ITF::DS_E_QUERYHUNG => "The operation cannot be completed, because one or more queries failed to terminate in a timely manner.",
            ITF::DS_E_BADRESULT => "The result is invalid.",
            ITF::DS_E_CANNOTWRITEREGISTRY => "The registry data cannot be written. Check that the search service is running with administrator privileges.",
            ITF::DS_E_CANNOTREMOVECONCURRENT => "DS_E_CANNOTREMOVECONCURRENT.",
            ITF::DS_E_SEARCHCATNAMECOLLISION => "The content index cannot be created because an index with the same name already exists on the search server. Create the content index using a different name.",
            ITF::DS_E_PROPVERSIONMISMATCH => "The content index cannot be enabled because its propagation version cannot be verified against the dedicated index server. This can occur when either the dedicated index server is offline or the content index is out-of-date.",
            ITF::DS_E_MISSINGCATALOG => ".",
            ITF::UPNP_E_ACTION_SPECIFIC_MAX => "Symbol which helps finding standard and nonstandard Device Error Codes.",
            ITF::TF_E_LOCKED => "The context is already locked.",
            ITF::UPNP_E_INVALID_DOCUMENT => "The service description contained an error.",
            ITF::COLL_E_BADSEQUENCE => "The requested operation is not valid at this time.",
            ITF::TF_E_STACKFULL => "The context stack is full.",
            ITF::UPNP_E_EVENT_SUBSCRIPTION_FAILED => "Failed to subscribe to the event source.",
            ITF::COLL_E_NOMOREDATA => "There is no more data to return.",
            ITF::TF_E_NOTOWNEDRANGE => "The TSF manager does not own the range.",
            ITF::COLL_E_INCOMPATIBLECOLUMNS => "The query cannot be collated, because columns using the same name have different types.",
            ITF::TF_E_NOPROVIDER => "No function provider exists for the specified function.",
            ITF::COLL_E_BUFFERTOOSMALL => "Not enough buffer space is available to collate search results.",
            ITF::TF_E_DISCONNECTED => "The context object is not on a document stack.",
            ITF::TF_E_INVALIDVIEW => "The context view is invalid.",
            ITF::COLL_E_BADRESULT => "The result row is corrupted.",
            ITF::TF_E_ALREADY_EXISTS => "The preserved key is registered.",
            ITF::COLL_E_NOSORTCOLUMN => "The search server did not return a column required for collation.",
            ITF::TF_E_RANGE_NOT_COVERED => "The range is not within an active composition.",
            ITF::COLL_E_DUPLICATEDBID => "The database ID is a duplicate.",
            ITF::TF_E_COMPOSITION_REJECTED => "The context owner rejected the composition.",
            ITF::COLL_E_TOOMANYMERGECOLUMNS => "The data source merge exceeded the number of result columns.",
            ITF::TF_E_EMPTYCONTEXT => "The context is empty.",
            ITF::COLL_E_NODEFAULTCATALOG => "No default index was set.",
            ITF::COLL_E_MAXCONNEXCEEDED => "The maximum number of open provider connections was exceeded.",
            ITF::FHSVC_E_BACKUP_BLOCKED => "File History Service: Backups are blocked for the given configuration.",
            ITF::CM_E_TOOMANYDATASERVERS => "The limit on the number of search servers was reached.",
            ITF::FHSVC_E_NOT_CONFIGURED => "File History Service: File History is not configured for the user",
            ITF::CM_E_TOOMANYDATASOURCES => "The limit on the number of indexes was reached.",
            ITF::FHSVC_E_CONFIG_DISABLED => "File History Service: The specified configuration is disabled by the user",
            ITF::CM_E_NOQUERYCONNECTIONS => "No query connections to the server can be established.",
            ITF::FHSVC_E_CONFIG_DISABLED_GP => "File History Service: The specified configuration is disabled via Group Policy",
            ITF::CM_E_DATASOURCENOTAVAILABLE => "The requested content index is disabled.",
            ITF::FHSVC_E_FATAL_CONFIG_ERROR => "File History Service: There is a fatal error with the specified configuration, backup cannot be even started",
            ITF::CM_E_CONNECTIONTIMEOUT => "The network timed out trying to acquire a connection to a search server.",
            ITF::FHSVC_E_CONFIG_REHYDRATING => "File History Service: The specified configuration is undergoing rehydration",
            ITF::CM_E_SERVERNOTFOUND => "The specified server cannot be found.",
            ITF::CM_E_REGISTRY => "The Windows NT registry cannot be accessed.",
            ITF::CM_E_INVALIDDATASOURCE => "The requested content index is empty or has not been added to the search server.",
            ITF::CM_E_TIMEOUT => "The query timed out.",
            ITF::CM_E_INSUFFICIENTBUFFER => "The buffer area passed to the function is not large enough.",
            ITF::QRY_E_QUERYSYNTAX => "The query syntax is not valid.",
            ITF::QRY_E_TYPEMISMATCH => "The column type in the search query does not match the column type in the index.",
            ITF::QRY_E_UNHANDLEDTYPE => "The query type specified is unknown.",
            ITF::QRY_E_TOOMANYCOLUMNS => "The number of columns requested exceeds the limit.",
            ITF::QRY_E_TOOMANYDATABASES => "The query contained too many content index IDs.",
            ITF::QRY_E_STARTHITTOBIG => "The query start hit is larger than the total number of results.",
            ITF::QRY_E_TOOMANYQUERYTERMS => "The query contains too many terms.",
            ITF::QRY_E_NODATASOURCES => "No indexes were specified.",
            ITF::QRY_E_TIMEOUT => "The query operation timed out.",
            ITF::QRY_E_COLUMNNOTSORTABLE => "The query specified sorting a non-sortable column.",
            ITF::QRY_E_COLUMNNOTSEARCHABLE => "The query specified searching a non-searchable column.",
            ITF::QRY_E_INVALIDCOLUMN => "The query specified a nonexistent column.",
            ITF::QRY_E_QUERYCORRUPT => "The query data is not valid or is inconsistent.",
            ITF::QRY_E_PREFIXWILDCARD => "A query term begins with a wildcard character.",
            ITF::QRY_E_INFIXWILDCARD => "A query term contains an invalid embedded wildcard character.",
            ITF::QRY_E_WILDCARDPREFIXLENGTH => "A wildcard term in the query does not contain a sufficiently long prefix.",
            ITF::QRY_E_ENGINEFAILED => "The search server is unable to process the query.",
            ITF::QRY_E_SEARCHTOOBIG => "The search criteria are too general or matched too many terms.",
            ITF::QRY_E_NULLQUERY => "The query does not contain any meaningful restrictions.",
            ITF::QRY_E_NOCOLUMNS => "The query did not specify any return columns.",
            ITF::QRY_E_INVALIDSCOPES => "The scopes specified for the query were incorrectly formatted.",
            ITF::QRY_E_INVALIDCATALOG => "The indexes specified for the query were incorrectly formatted.",
            ITF::QRY_E_SCOPECARDINALIDY => "The number of scopes or depths was not valid.",
            ITF::QRY_E_UNEXPECTED => "The operation is invalid in the current context.",
            ITF::QRY_E_INVALIDPATH => "An invalid path was supplied.",
            ITF::QRY_E_LMNOTINITIALIZED => "The log manager is not initialized.",
            ITF::QRY_E_INVALIDINTERVAL => "An invalid interval was passed to the log manager.",
            ITF::QRY_E_NOLOGMANAGER => "No log manager was attached to the logger.",
            ITF::SCHEMA_E_LOAD_SPECIAL => "The configuration file attempted to load a reserved column. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::SCHEMA_E_FILENOTFOUND => "The configuration file cannot be found. Reinstall the application.",
            ITF::SCHEMA_E_NESTEDTAG => "The tag nesting configuration for the application is not valid. Reinstall the application.",
            ITF::SCHEMA_E_UNEXPECTEDTAG => "The configuration file for the application contains an invalid tag. Reinstall the application.",
            ITF::SCHEMA_E_VERSIONMISMATCH => "The configuration file version number for the application is invalid. Reinstall the application.",
            ITF::SCHEMA_E_CANNOTCREATEFILE => "The output configuration file cannot be created. Stop and restart the system, and then reinstall the application.",
            ITF::SCHEMA_E_CANNOTWRITEFILE => "Data cannot be written to the output configuration file. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::SCHEMA_E_EMPTYFILE => "The configuration file for the application contains invalid information. Reinstall the application.",
            ITF::SCHEMA_E_INVALIDFILETYPE => "The configuration file type for the application is not recognized. Reinstall the application.",
            ITF::SCHEMA_E_INVALIDDATATYPE => "The configuration file column data type for the application is not recognized. Reinstall the application.",
            ITF::SCHEMA_E_CANNOTCREATENOISEWORDFILE => "The noise word file cannot be created. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::SCHEMA_E_ADDSTOPWORDS => "There was an error writing to the temporary noise word file. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::SCHEMA_E_NAMEEXISTS => "The specified column name already exists. The application's configuration was corrupted. Reinstall the application.",
            ITF::SCHEMA_E_INVALIDVALUE => "The value for the attribute is invalid. The application's configuration was corrupted. Reinstall the application.",
            ITF::SCHEMA_E_BADPROPSPEC => "The property set GUID is invalid. The application's configuration was corrupted. Reinstall the application.",
            ITF::SCHEMA_E_NOMORECOLUMNS => "No more columns. This is an internal error code and should not be reported to users. Call Microsoft Product Support.",
            ITF::SCHEMA_E_FILECHANGED => "The system cannot write to the configuration file, because it was modified since it was last read. Stop and restart the search service. If this problem persists, reinstall search.",
            ITF::SCHEMA_E_BADCOLUMNNAME => "The specified column name is invalid. The application's configuration has been corrupted. Reinstall the application.",
            ITF::SCHEMA_E_BADPROPPID => "The property ID specified is invalid. The application's configuration has been corrupted. Reinstall the application.",
            ITF::SCHEMA_E_BADATTRIBUTE => "An invalid attribute was specified for this tag, or a required attribute is missing. The application's configuration was corrupted. Reinstall the application.",
            ITF::SCHEMA_E_BADFILENAME => "The specified file name is invalid. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::SCHEMA_E_PROPEXISTS => "A column having the specified property set and PID already exists. The application's configuration has been corrupted. Reinstall the application.",
            ITF::SCHEMA_E_DUPLICATENOISE => "The configuration describing a language and sublanguage contains unexpected duplicate information. The application's configuration may be corrupted. Though basic functionality is unlikely to be impacted, it is recommended that you reinstall the application.",
            ITF::GTHR_E_DUPLICATE_OBJECT => "The object you are trying to create already exists. Try again using a different name.",
            ITF::GTHR_E_UNABLE_TO_READ_REGISTRY => "The registry value cannot be read because the configuration is invalid. Recreate the content index configuration by removing the content index.",
            ITF::GTHR_E_ERROR_WRITING_REGISTRY => "The value cannot be set, because the object was already deleted or was not initialized properly. Check that the object reference is still valid, increase the registry size, or recreate the content index configuration.",
            ITF::GTHR_E_ERROR_INITIALIZING_PERFMON => "Performance monitoring cannot be initialized. This affects performance counters only. Try restarting the service or restarting the server.",
            ITF::GTHR_E_ERROR_OBJECT_NOT_FOUND => "The specified object cannot be found. Specify the name of an existing object.",
            ITF::GTHR_E_URL_EXCLUDED => "The specified address was excluded from the index. The site path rules may have to be modified to include this address.",
            ITF::GTHR_E_CONFIG_DUP_PROJECT => "A duplicate index entry exists in the registry. No other indexes are affected, but it is recommended that the duplicate entry be deleted.",
            ITF::GTHR_E_CONFIG_DUP_EXTENSION => "A duplicate extension entry exists in the registry. The duplicate extension should be deleted, but all other extensions are unaffected.",
            ITF::GTHR_E_DUPLICATE_URL => "The URL was already processed during this update. If you received this message while processing alerts, then the alerts are redundant, or else Modify should be used instead of Add.",
            ITF::GTHR_E_TOO_MANY_PLUGINS => "The gatherer attempted to create more gatherer plug-in objects than are allowed. Remove another plug-in before adding this one.",
            ITF::GTHR_E_INVALIDFUNCTION => "The function is not implemented in this context, and cannot be called. This error is internal, and cannot normally occur. Reinstall the application.",
            ITF::GTHR_E_NOFILTERSINK => "The plug-in did not provide a filter sink object. You may have installed a custom plug-in that is not supported.",
            ITF::GTHR_E_FILTER_PROCESS_TERMINATED => "The filtering process ended and is now unavailable. The address will be retried, but it is possible that the system is low in resources. Free some system resources, or restart the update when resources are available.",
            ITF::GTHR_E_FILTER_INVALID_MESSAGE => "An unexpected message was received from the filtering process. The address will be retried, but if this occurs frequently, your system is low on resources. Free some system resources, or restart the update when resources are available.",
            ITF::GTHR_E_UNSUPPORTED_PROPERTY_TYPE => "The filtering process returned an unsupported property type. Fix the filter to allow successful use of the document.",
            ITF::GTHR_E_NAME_TOO_LONG => "The specified name for this object exceeds the maximum length, which is usually 2047 characters. Use a shorter name for the object.",
            ITF::GTHR_E_NO_IDENTITY => "The user agent or e-mail address was not specified. Specify the e-mail address to use in the protocol headers.",
            ITF::GTHR_E_FILTER_NOT_FOUND => "A filter for the document cannot be created. Install the corresponding filter for this document format.",
            ITF::GTHR_E_FILTER_NO_MORE_THREADS => "All threads in the filtering process are currently in use.",
            ITF::GTHR_E_PRT_HNDLR_PROGID_MISSING => "The ProgID for a protocol handler cannot be obtained, and the protocol handler registration is invalid. Reregister the protocol handlers.",
            ITF::GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA => "The filtering process was stopped because its memory quota was exceeded.",
            ITF::GTHR_E_UNKNOWN_PROTOCOL => "The protocol handler cannot be found. Check that the handler has been installed.",
            ITF::GTHR_E_PROJECT_NOT_INITIALIZED => "The gatherer index was not initialized. The content index must be remounted. If the index is still not initialized, remove it.",
            ITF::GTHR_E_INVALID_PROJECT_NAME => "The catalog name is invalid. Choose a catalog name that is shorter or does not contain special characters.",
            ITF::GTHR_E_SHUTTING_DOWN => "The gatherer is shutting down.",
            ITF::GTHR_E_VALUE_NOT_AVAILABLE => "The requested value was not set by the filter process. This is a recoverable internal error. The document may still succeed.",
            ITF::GTHR_E_OUT_OF_DOC_ID => "All valid document IDs were used. Recreate the content index.",
            ITF::GTHR_E_NOTIFICATION_START_PAGE => "This content source cannot be crawled, because its is set up to accept alerts.",
            ITF::GTHR_E_DUP_PROPERTY_MAPPING => "The property mapping is duplicated in the schema. Remove the duplicate property schema.",
            ITF::GTHR_E_INVALID_ACCOUNT => "The specified account information is incorrect or invalid. Check that the correct account and password are being used.",
            ITF::GTHR_E_FILTER_INIT => "The document cannot be filtered, because the document and filter versions do not appear to match. Install a matching document filter.",
            ITF::GTHR_E_INVALID_ACCOUNT_SYNTAX => "The specified account name cannot be used because it contains invalid characters, such as '\'. Use a valid account name.",
            ITF::GTHR_E_PROXY_NAME => "The proxy server name is missing. Specify a proxy server, and try again.",
            ITF::GTHR_E_SERVER_UNAVAILABLE => "The server is unavailable and cannot be accessed. The server is probably disconnected from the network. Access attempts will be delayed for ten minutes.",
            ITF::GTHR_E_INVALID_PATH => "This path does not correspond to the selected site. Use a path name that matches the site, or use a wildcard (*).",
            ITF::GTHR_E_FILTER_NO_CODEPAGE => "The document cannot be filtered, because the required code page is not installed. Install the code page for this document.",
            ITF::GTHR_E_NO_PRTCLHNLR => "No protocol handler is available. Install a protocol handler that can process this URL type.",
            ITF::GTHR_E_IE_OFFLINE => "Internet Explorer is set to offline mode. Change Internet Explorer to online mode, and continue.",
            ITF::GTHR_E_BAD_FILTER_DAEMON => "The filter process cannot be started. The system is most likely low on resources, or the filter process binary was modified. If the resources are available, check the search binaries with an antivirus program.",
            ITF::GTHR_E_INVALID_MAPPING => "The specified URL mapping is invalid. The 'from'' mapping is empty, or the ''from'' mapping is the same as the ''to'' mapping. Specify a valid ''from'' mapping that differs from the ''to'' mapping.",
            ITF::GTHR_E_USER_AGENT_NOT_SPECIFIED => "The user agent string was not specified or contains invalid characters. Specify a user agent which is not empty and does not contain double quotation marks.",
            ITF::GTHR_E_FROM_NOT_SPECIFIED => "The e-mail address is missing. Type an e-mail address.",
            ITF::GTHR_E_INVALID_STREAM_LOGS_COUNT => "The specified number of logs to keep is invalid. Set the number of logs to be greater than zero.",
            ITF::GTHR_E_INVALID_EXTENSION => "The extension string is not specified or is invalid. Specify an extension string that does not contain the following characters: [./?*:\#] or spaces.",
            ITF::GTHR_E_INVALID_GROW_FACTOR => "The specified maximum grow factor is invalid. Set the maximum grow factor to be greater than or equal to zero.",
            ITF::GTHR_E_INVALID_TIME_OUT => "The specified time out value is invalid. Set the time out value to be greater than or equal to zero.",
            ITF::GTHR_E_INVALID_RETRIES => "The specified retry limit value is invalid. Set the retry limit value to be greater than or equal to zero.",
            ITF::GTHR_E_INVALID_LOG_FILE_NAME => "The gatherer log file name is not specified. Specify a log file name.",
            ITF::GTHR_E_INVALID_HOST_NAME => "The site name is not specified or is invalid. Specify a site name that does not contain the following characters: [/\\@#|] or spaces.",
            ITF::GTHR_E_INVALID_START_PAGE => "The content source is not specified or is invalid. Type a host name that does not contain * or spaces.",
            ITF::GTHR_E_DUPLICATE_PROJECT => "A catalog with the name specified already exists. Create the catalog using a different name.",
            ITF::GTHR_E_INVALID_DIRECTORY => "The path is not specified or contains invalid characters, such as ['' ?*]. Specify a path that does not contain these characters.",
            ITF::GTHR_E_FILTER_INTERRUPTED => "The filtering was stopped because of a user action, such as stopping the crawl.",
            ITF::GTHR_E_INVALID_PROXY_PORT => "The specified port for the HTTP proxy is invalid. Specify a port between 0 and 0xffff.",
            ITF::GTHR_E_SECRET_NOT_FOUND => "The account password was not specified. Specify the password.",
            ITF::GTHR_E_INVALID_PATH_EXPRESSION => "The path expression cannot contain the reserved escape character '|'. Use an expression without reserved characters. |' - a reserved escape character. Use an expression without reserved characters.",
            ITF::GTHR_E_INVALID_START_PAGE_HOST => "The specification for the content source is missing the host name. Specify a valid URL.",
            ITF::GTHR_E_INVALID_START_PAGE_PATH => "The path specification for the content source cannot contain wildcard characters, such as [?*]. Remove all wildcards from the path specification.",
            ITF::GTHR_E_APPLICATION_NOT_FOUND => "The specified gatherer application cannot be found. Use the name of an existing application, or reinstall the application.",
            ITF::GTHR_E_CANNOT_REMOVE_PLUGINMGR => "The application plug-in manager cannot be removed, because one or more content indexes was configured to use the plug-in. Remove all indexes, and then remove the plug-in manager.",
            ITF::GTHR_E_INVALID_APPLICATION_NAME => "The application name is invalid, because it contains special characters. Specify a different application name without special characters.",
            ITF::GTHR_E_FILTER_FAULT => "The data size returned by the filter is greater than the allocated buffer. Download and install an update for the filter.",
            ITF::GTHR_E_NON_FIXED_DRIVE => "The object cannot be created on a non-fixed drive. Create the object on another drive.",
            ITF::GTHR_E_FILTER_SINGLE_THREADED => "The system attempted to load a filter marked as apartment in a multi-threaded filter daemon. The document will be retried in a single-threaded filter. Since multithreaded filtering is more efficient, try to obtain the version of the filter that is multi-threaded.",
            ITF::GTHR_E_URL_UNIDENTIFIED => "The identified content was not crawled for this address. Recreate the content index.",
            ITF::GTHR_E_FORCE_NOTIFICATION_RESET => "The gatherer cannot handle the alert stream. All alert sources will be crawled again.",
            ITF::GTHR_E_CONTENT_ID_CONFLICT => "A duplicate of this document was detected, and the document will be retried. If this problem persists, recreate the content index.",
            ITF::GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE => "The administrative data from the Exchange store or registry cannot be read. Check that the Exchange store is started, and that it was properly restored.",
            ITF::GTHR_E_RECOVERABLE_EXOLEDB_ERROR => "Read access to the Exchange store is temporarily unavailable. If this message persists, restart the Exchange store.",
            ITF::GTHR_E_INVALID_CALL_FROM_WBREAKER => "The function is unavailable, because it was called while the word breaker was attempting to fill the text buffer. Download and install an update for the word breaker.",
            ITF::GTHR_E_PROPERTY_LIST_NOT_INITIALIZED => "The property list for the content class of this document cannot be loaded, and the schema cannot be accessed. Check that the schema is correctly configured.",
            ITF::GHTR_E_LOCAL_SERVER_UNAVAILABLE => "Crawling cannot continue because the local server is not responding. Restart Microsoft SQL Server 2000.",
            ITF::GTHR_E_SCHEMA_ERRORS_OCCURRED => "Schema/schema cache error (%1) occurred. Schema collection ref: %2, content class: %3. This error is internal, for debugging.",
            ITF::GTHR_E_TIMEOUT => "Document filtering cannot be completed because the document server did not respond within the specified timeout. Try crawling the server later, or increase the timeout values.",
            ITF::GTHR_E_NOTIFICATION_START_ADDRESS_INVALID => "The content source for this alert must refer to a valid file system directory.",
            ITF::GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED => "Alerts for this content source are not supported.",
            ITF::GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE => "Alerts for this content source cannot be established because information about the file share cannot be obtained.",
            ITF::GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE => "Alerts for a content source with a local address are only supported for a fixed media drive type. Use the UNC name for remote file shares.",
            ITF::GHTR_E_INSUFFICIENT_DISK_SPACE => "The new content index cannot be added because there is not enough disk space. Free up at least 10 megabytes of free space, and then try again.",
            ITF::GTHR_E_INVALID_RESOURCE_ID => "The document received an invalid document resource ID. The document must be crawled again.",
            ITF::GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES => "Hierarchical content sources such as those in the file system cannot be nested.",
            ITF::GTHR_E_RETRY => "The first attempt to crawl this object failed. Another attempt is being made.",
            ITF::GTHR_E_JET_BACKUP_ERROR => "Backup and restore failed during an ESE database phase. For more detailed information, check the event log.",
            ITF::GTHR_E_JET_RESTORE_ERROR => "Backup and restore failed during an ESE database phase. For more detailed information, check the event log.",
            ITF::GTHR_E_PLUGIN_NOT_REGISTERED => "The plug-in is not properly registered on this computer. Check that the application is properly installed, or contact Microsoft Product Support.",
            ITF::GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED => "Alerts for this scope were interrupted so that authentication tokens can be updated.",
            ITF::GTHR_E_DIRMON_NOT_INITIALZED => "File system alerts were not initialized successfully If the problem persists after restarting the service, try rerunning Setup.",
            ITF::GTHR_E_NOTIF_BEING_REMOVED => "File system alerts for this scope are stopped because the scope is being removed.",
            ITF::GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT => "Alerts failed because of network failures or because the internal cache size was exceeded. If the problem persists, change the content source type to adaptive or crawl.",
            ITF::GTHR_E_INVALID_PATH_SPEC => "The operation could not be completed because the specified path is invalid. Try again using a valid path.",
            ITF::GTHR_E_INSUFFICIENT_FEATURE_TERMS => "There were not enough keywords in the sample documents to train the Topic Assistant. Try again when more sample documents are available.",
            ITF::GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES => "The Topic Assistant requires sample documents from at least two categories. Try again when sample documents for more categories are available.",
            ITF::GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS => "There were not enough sample documents to train the Topic Assistant. Try again when more sample documents are available.",
            ITF::GTHR_E_AUTOCAT_UNEXPECTED => "An error occurred using the topic assistant. Check the event log for related failures.",
            ITF::GTHR_E_SINGLE_THREADED_EMBEDDING => "The system attempted to load a filter marked as apartment from an embedded component in a multi-threaded filter daemon. The document will be retried in a single-threaded filter. Since multithreaded filtering is more efficient, try to obtain the version of the filter that is multi-threaded.",
            ITF::GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE => "The data for this folder will not be crawled because it is configured to be crawled by (%1).",
            ITF::GTHR_E_EMPTY_DACL => "The security descriptor for this document only contained built-in access control entries. The built-in ACEs have to be removed because they won't be valid for this document during queries.",
            ITF::GTHR_E_OBJECT_NOT_VALID => "The context for this object is no longer valid. Refresh the context for this object.",
            ITF::GTHR_E_CANNOT_ENABLE_CHECKPOINT => "The checkpoint cannot be enabled, because the content index is not idle. Wait until the index is idle, and then try again.",
            ITF::GTHR_E_SCOPES_EXCEEDED => "The maximum number of search scopes was reached. Use one of the existing scopes.",
            ITF::GTHR_E_PROPERTIES_EXCEEDED => "Maximum number of properties per document has been reached. The document is most likely corrupt, or it represents a denial of service threat, the indexing of this document has been aborted.",
            ITF::GTHR_E_INVALID_START_ADDRESS => "The start address is invalid because it is a local path. Please enter a valid start address.",
            ITF::GTHR_E_PIPE_NOT_CONNECTTED => "The filtering process has been terminated.",
            ITF::GTHR_E_BACKUP_VALIDATION_FAIL => "The backup image cannot be verified because the image may be corrupted. To preserve your data, it is recommended that you run Data Backup and Restore again.",
            ITF::GTHR_E_BAD_FILTER_HOST => "The filter host process cannot be started. The system is most likely low on resources, or the filter host process binary was modified. If the resources are available, check the search binaries with an antivirus program.",
            ITF::GTHR_E_FILTERPOOL_NOTFOUND => "The per-user filter pool could not be found.",
            ITF::GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT => "Some of the links were not successfully added to the queue. Parent transaction will be retried.",
            ITF::DB_E_BADACCESSORHANDLE => "Accessor is invalid.",
            ITF::DB_E_ROWLIMITEXCEEDED => "Row could not be inserted into the rowset without exceeding provider's maximum number of active rows.",
            ITF::DB_E_READONLYACCESSOR => "Accessor is read-only. Operation failed.",
            ITF::DB_E_SCHEMAVIOLATION => "Values violate the database schema.",
            ITF::DB_E_BADROWHANDLE => "Row handle is invalid.",
            ITF::DB_E_OBJECTOPEN => "Object was open.",
            ITF::DB_E_BADCHAPTER => "Chapter is invalid.",
            ITF::DB_E_CANTCONVERTVALUE => "Data or literal value could not be converted to the type of the column in the data source, and the provider was unable to determine which columns could not be converted. Data overflow or sign mismatch was not the cause.",
            ITF::DB_E_BADBINDINFO => "Binding information is invalid.",
            ITF::DB_SEC_E_PERMISSIONDENIED => "Permission denied.",
            ITF::DB_E_NOTAREFERENCECOLUMN => "Column does not contain bookmarks or chapters.",
            ITF::DB_E_LIMITREJECTED => "Cost limits were rejected.",
            ITF::DB_E_NOCOMMAND => "Command text was not set for the command object.",
            ITF::DB_E_COSTLIMIT => "Query plan within the cost limit cannot be found.",
            ITF::DB_E_BADBOOKMARK => "Bookmark is invalid.",
            ITF::DB_E_BADLOCKMODE => "Lock mode is invalid.",
            ITF::DB_E_PARAMNOTOPTIONAL => "No value given for one or more required parameters.",
            ITF::DB_E_BADCOLUMNID => "Column ID is invalid.",
            ITF::DB_E_BADRATIO => "Numerator was greater than denominator. Values must express ratio between zero and 1.",
            ITF::DB_E_BADVALUES => "Value is invalid.",
            ITF::DB_E_ERRORSINCOMMAND => "One or more errors occurred during processing of command.",
            ITF::DB_E_CANTCANCEL => "Command cannot be canceled.",
            ITF::DB_E_DIALECTNOTSUPPORTED => "Command dialect is not supported by this provider.",
            ITF::DB_E_DUPLICATEDATASOURCE => "Data source object could not be created because the named data source already exists.",
            ITF::DB_E_CANNOTRESTART => "Rowset position cannot be restarted.",
            ITF::DB_E_NOTFOUND => "Object or data matching the name, range, or selection criteria was not found within the scope of this operation.",
            ITF::DB_E_CANNOTFREE => "Provider has ownership of this tree.",
            ITF::DB_E_NEWLYINSERTED => "Identity cannot be determined for newly inserted rows.",
            ITF::DB_E_GOALREJECTED => "Goal was rejected because no nonzero weights were specified for any goals supported. Current goal was not changed.",
            ITF::DB_E_UNSUPPORTEDCONVERSION => "Requested conversion is not supported.",
            ITF::DB_E_BADSTARTPOSITION => "No rows were returned because the offset value moves the position before the beginning or after the end of the rowset.",
            ITF::DB_E_NOQUERY => "Information was requested for a query and the query was not set.",
            ITF::DB_E_NOTREENTRANT => "Consumer's event handler called a non-reentrant method in the provider.",
            ITF::DB_E_ERRORSOCCURRED => "Multiple-step OLE DB operation generated errors. Check each OLE DB status value, if available. No work was done.",
            ITF::DB_E_NOAGGREGATION => "Non-NULL controlling IUnknown was specified, and either the requested interface was not IUnknown, or the provider does not support COM aggregation.",
            ITF::DB_E_DELETEDROW => "Row handle referred to a deleted row or a row marked for deletion.",
            ITF::DB_E_CANTFETCHBACKWARDS => "Rowset does not support fetching backward.",
            ITF::DB_E_ROWSNOTRELEASED => "Row handles must all be released before new ones can be obtained.",
            ITF::DB_E_BADSTORAGEFLAG => "One or more storage flags are not supported.",
            ITF::DB_E_BADCOMPAREOP => "Comparison operator is invalid.",
            ITF::DB_E_BADSTATUSVALUE => "Status flag was neither DBCOLUMNSTATUS_OK nor DBCOLUMNSTATUS_ISNULL.",
            ITF::DB_E_CANTSCROLLBACKWARDS => "Rowset does not support scrolling backward.",
            ITF::DB_E_BADREGIONHANDLE => "Region handle is invalid.",
            ITF::DB_E_NONCONTIGUOUSRANGE => "Set of rows is not contiguous to, or does not overlap, the rows in the watch region.",
            ITF::DB_E_INVALIDTRANSITION => "Transition from ALL* to MOVE* or EXTEND* was specified.",
            ITF::DB_E_NOTASUBREGION => "Region is not a proper subregion of the region identified by the watch region handle.",
            ITF::DB_E_MULTIPLESTATEMENTS => "Multiple-statement commands are not supported by this provider.",
            ITF::DB_E_INTEGRITYVIOLATION => "Value violated the integrity constraints for a column or table.",
            ITF::DB_E_BADTYPENAME => "Type name is invalid.",
            ITF::DB_E_ABORTLIMITREACHED => "Execution stopped because a resource limit was reached. No results were returned.",
            ITF::DB_E_ROWSETINCOMMAND => "Command object whose command tree contains a rowset or rowsets cannot be cloned.",
            ITF::DB_E_CANTTRANSLATE => "Current tree cannot be represented as text.",
            ITF::DB_E_DUPLICATEINDEXID => "Index already exists.",
            ITF::DB_E_NOINDEX => "Index does not exist.",
            ITF::DB_E_INDEXINUSE => "Index is in use.",
            ITF::DB_E_NOTABLE => "Table does not exist.",
            ITF::DB_E_CONCURRENCYVIOLATION => "Rowset used optimistic concurrency and the value of a column has changed since it was last read.",
            ITF::DB_E_BADCOPY => "Errors detected during the copy.",
            ITF::DB_E_BADPRECISION => "Precision is invalid.",
            ITF::DB_E_BADSCALE => "Scale is invalid.",
            ITF::DB_E_BADTABLEID => "Table ID is invalid.",
            ITF::DB_E_BADTYPE => "Type is invalid.",
            ITF::DB_E_DUPLICATECOLUMNID => "Column ID already exists or occurred more than once in the array of columns.",
            ITF::DB_E_DUPLICATETABLEID => "Table already exists.",
            ITF::DB_E_TABLEINUSE => "Table is in use.",
            ITF::DB_E_NOLOCALE => "Locale ID is not supported.",
            ITF::DB_E_BADRECORDNUM => "Record number is invalid.",
            ITF::DB_E_BOOKMARKSKIPPED => "Form of bookmark is valid, but no row was found to match it.",
            ITF::DB_E_BADPROPERTYVALUE => "Property value is invalid.",
            ITF::DB_E_INVALID => "Rowset is not chaptered.",
            ITF::DB_E_BADACCESSORFLAGS => "One or more accessor flags were invalid.",
            ITF::DB_E_BADSTORAGEFLAGS => "One or more storage flags are invalid.",
            ITF::DB_E_BYREFACCESSORNOTSUPPORTED => "Reference accessors are not supported by this provider.",
            ITF::DB_E_NULLACCESSORNOTSUPPORTED => "Null accessors are not supported by this provider.",
            ITF::DB_E_NOTPREPARED => "Command was not prepared.",
            ITF::DB_E_BADACCESSORTYPE => "Accessor is not a parameter accessor.",
            ITF::DB_E_WRITEONLYACCESSOR => "Accessor is write-only.",
            ITF::DB_SEC_E_AUTH_FAILED => "Authentication failed.",
            ITF::DB_E_CANCELED => "Operation was canceled.",
            ITF::DB_E_CHAPTERNOTRELEASED => "Rowset is single-chaptered. The chapter was not released.",
            ITF::DB_E_BADSOURCEHANDLE => "Source handle is invalid.",
            ITF::DB_E_PARAMUNAVAILABLE => "Provider cannot derive parameter information and SetParameterInfo has not been called.",
            ITF::DB_E_ALREADYINITIALIZED => "Data source object is already initialized.",
            ITF::DB_E_NOTSUPPORTED => "Method is not supported by this provider.",
            ITF::DB_E_MAXPENDCHANGESEXCEEDED => "Number of rows with pending changes exceeded the limit.",
            ITF::DB_E_BADORDINAL => "Column does not exist.",
            ITF::DB_E_PENDINGCHANGES => "Pending changes exist on a row with a reference count of zero.",
            ITF::DB_E_DATAOVERFLOW => "Literal value in the command exceeded the range of the type of the associated column.",
            ITF::DB_E_BADHRESULT => "HRESULT is invalid.",
            ITF::DB_E_BADLOOKUPID => "Lookup ID is invalid.",
            ITF::DB_E_BADDYNAMICERRORID => "DynamicError ID is invalid.",
            ITF::DB_E_PENDINGINSERT => "Most recent data for a newly inserted row could not be retrieved because the insert is pending.",
            ITF::DB_E_BADCONVERTFLAG => "Conversion flag is invalid.",
            ITF::DB_E_BADPARAMETERNAME => "Parameter name is unrecognized.",
            ITF::DB_E_MULTIPLESTORAGE => "Multiple storage objects cannot be open simultaneously.",
            ITF::DB_E_CANTFILTER => "Filter cannot be opened.",
            ITF::DB_E_CANTORDER => "Order cannot be opened.",
            ITF::MD_E_BADTUPLE => "Tuple is invalid.",
            ITF::MD_E_BADCOORDINATE => "Coordinate is invalid.",
            ITF::MD_E_INVALIDAXIS => "Axis is invalid.",
            ITF::MD_E_INVALIDCELLRANGE => "One or more cell ordinals is invalid.",
            ITF::DB_E_NOCOLUMN => "Column ID is invalid.",
            ITF::DB_E_COMMANDNOTPERSISTED => "Command does not have a DBID.",
            ITF::DB_E_DUPLICATEID => "DBID already exists.",
            ITF::DB_E_OBJECTCREATIONLIMITREACHED => "Session cannot be created because maximum number of active sessions was already reached. Consumer must release one or more sessions before creating a new session object.",
            ITF::SEC_E_BADTRUSTEEID => "Trustee is invalid.",
            ITF::SEC_E_NOTRUSTEEID => "Trustee was not recognized for this data source.",
            ITF::SEC_E_NOMEMBERSHIPSUPPORT => "Trustee does not support memberships or collections.",
            ITF::SEC_E_INVALIDOBJECT => "Object is invalid or unknown to the provider.",
            ITF::SEC_E_NOOWNER => "Object does not have an owner.",
            ITF::SEC_E_INVALIDACCESSENTRYLIST => "Access entry list is invalid.",
            ITF::SEC_E_INVALIDOWNER => "Trustee supplied as owner is invalid or unknown to the provider.",
            ITF::SEC_E_INVALIDACCESSENTRY => "Permission in the access entry list is invalid.",
            ITF::DB_E_BADINDEXID => "Index ID is invalid.",
            ITF::DB_E_BADINITSTRING => "Format of the initialization string does not conform to the OLE DB specification.",
            ITF::DB_E_NOPROVIDERSREGISTERED => "No OLE DB providers of this source type are registered.",
            ITF::DB_E_MISMATCHEDPROVIDER => "Initialization string specifies a provider that does not match the active provider.",
            ITF::DB_E_BADCOMMANDID => "DBID is invalid.",
            ITF::DB_E_BADCONSTRAINTTYPE => "ConstraintType is invalid or not supported by the provider.",
            ITF::DB_E_BADCONSTRAINTFORM => "ConstraintType is not DBCONSTRAINTTYPE_FOREIGNKEY and cForeignKeyColumns is not zero.",
            ITF::DB_E_BADDEFERRABILITY => "Specified deferrability flag is invalid or not supported by the provider.",
            ITF::DB_E_BADMATCHTYPE => "MatchType is invalid or the value is not supported by the provider.",
            ITF::DB_E_BADUPDATEDELETERULE => "Constraint update rule or delete rule is invalid.",
            ITF::DB_E_BADCONSTRAINTID => "Constraint ID is invalid.",
            ITF::DB_E_BADCOMMANDFLAGS => "Command persistence flag is invalid.",
            ITF::DB_E_OBJECTMISMATCH => "rguidColumnType points to a GUID that does not match the object type of this column, or this column was not set.",
            ITF::DB_E_RESOURCEOUTOFSCOPE => "URL is outside of scope.",
            ITF::DB_E_DROPRESTRICTED => "Column or constraint could not be dropped because it is referenced by a dependent view or constraint.",
            ITF::DB_E_NOSOURCEOBJECT => "Source row does not exist.",
            ITF::DB_E_RESOURCELOCKED => "OLE DB object represented by this URL is locked by one or more other processes.",
            ITF::DB_E_NOTCOLLECTION => "Client requested an object type that is valid only for a collection.",
            ITF::DB_E_READONLY => "Caller requested write access to a read-only object.",
            ITF::DB_E_ASYNCNOTSUPPORTED => "Asynchronous binding is not supported by this provider.",
            ITF::DB_E_CANNOTCONNECT => "Connection to the server for this URL cannot be established.",
            ITF::DB_E_TIMEOUT => "Timeout occurred when attempting to bind to the object.",
            ITF::DB_E_RESOURCEEXISTS => "Object cannot be created at this URL because an object named by this URL already exists.",
            ITF::DB_E_DUPLICATECONSTRAINTID => "Constraint already exists.",
            ITF::DB_E_OUTOFSPACE => "Object cannot be created at this URL because the server is out of physical storage.",
            ITF::DB_SEC_E_SAFEMODE_DENIED => "Safety settings on this computer prohibit accessing a data source on another domain.",
            ITF::DB_E_NOSTATISTIC => "The specified statistic does not exist in the current data source or did not apply to the specified table or it does not support a histogram.",
            ITF::DB_E_ALTERRESTRICTED => "Column or table could not be altered because it is referenced by a constraint.",
            ITF::DB_E_RESOURCENOTSUPPORTED => "Requested object type is not supported by the provider.",
            ITF::DB_E_NOCONSTRAINT => "Constraint does not exist.",
            ITF::DB_E_COLUMNUNAVAILABLE => "Requested column is valid, but could not be retrieved. This could be due to a forward only cursor attempting to go backwards in a row.",
            ITF::DB_E_BOGUS => "Dummy error - need this error so that mc puts the above defines inside the FACILITY_WINDOWS guard, instead of leaving it empty.",
            ITF::DXVA2_E_NOT_INITIALIZED => "Description is missing",
            ITF::MF_E_DXGI_DEVICE_NOT_INITIALIZED => "DXVA2_E_NOT_INITIALIZED",
            ITF::SYNC_E_ID_FORMAT_MISMATCH => "Specified synchronization ID is not of the specified format for IDs of that type.",
            ITF::REC_E_ABORTED => "Briefcase Reconciler: The briefcase reconciler stopped reconciliation in response to a termination request from the initiator (see SetAbortCallback for more information). The state of the object is unspecified.",
            ITF::ROUTER_E_NOTINTERESTED => "Router sinks will not participate in routing the particular message.",
            ITF::DXVA2_E_NEW_VIDEO_DEVICE => "Description is missing",
            ITF::MF_E_DXGI_NEW_VIDEO_DEVICE => "DXVA2_E_NEW_VIDEO_DEVICE",
            ITF::SYNC_E_INVALID_OPERATION => "Operation is not valid due to the current state of the object.",
            ITF::REC_E_NOCALLBACK => "Briefcase Reconciler: The initiator does not support termination of reconciliation operations and does not hold the specified object",
            ITF::DXVA2_E_VIDEO_DEVICE_LOCKED => "Description is missing",
            ITF::MF_E_DXGI_VIDEO_DEVICE_LOCKED => "DXVA2_E_VIDEO_DEVICE_LOCKED",
            ITF::SYNC_E_REPLICA_NOT_FOUND => "Replica with the specified key was not found.",
            ITF::REC_E_NORESIDUES => "Briefcase Reconciler: The briefcase reconciler does not support the generation of residues, so the request for residues is denied. The state of the object is unchanged.",
            ITF::SEO_E_NOTPRESENT => "SEO: Failure, the item is not present.",
            ITF::DXVA2_E_NOT_AVAILABLE => "Description is missing",
            ITF::SYNC_E_CHANGE_COUNT_MISMATCH => "Item changes provided were not of the expected quantity.",
            ITF::REC_E_TOODIFFERENT => "Briefcase Reconciler: Reconciliation cannot be carried out because the provided document versions are too dissimilar.",
            ITF::SEO_E_TIMEOUT => "SEO: Failure, the timeout expired.",
            ITF::SYNC_E_CHANGE_UNIT_COUNT_MISMATCH => "Change units provided were not of the expected quantity.",
            ITF::REC_E_INEEDTODOTHEUPDATES => "Briefcase Reconciler: The RECONCILEF_YOUMAYDOTHEUPDATES flag was not set when the object&#x27;s Reconcile implementation was called; this implementation requires that this value be set in the dwFlags parameter.",
            ITF::SEO_S_DONEPROCESSING => "SEO: Success, the message should not be handed to any other extension objects at this binding point.",
            ITF::SYNC_E_KNOWLEDGE_DECREASED => "Knowledge has unexpectedly decreased.",
            ITF::EVENTS_E_BADDATA => "SEO: Failure, bad data was presented.",
            ITF::SYNC_E_CHANGE_NOT_IN_KNOWLEDGE => "Change version was not contained in knowledge as expected.",
            ITF::EVENTS_E_TIMEOUT => "SEO: Failure, the timeout expired.",
            ITF::SYNC_E_ITEM_MUST_EXIST => "The item does not exist at the destination, but the creation version of the item is contained in the destination knowledge.",
            ITF::EVENTS_E_DISABLED => "SEO: Failure, the binding is disabled.",
            ITF::SYNC_E_HAS_NO_DATA => "Item for which data was requested has no data either because it is a tombstone or it does not exist.",
            ITF::SYNC_E_CHANGE_NEEDS_KNOWLEDGE => "Change was provided that has no associated knowledge.",
            ITF::SYNC_E_RANGE_OUT_OF_ORDER => "Range was provided out of expected order. Ranges should be provided in increasing order.",
            ITF::SYNC_E_NOT_EXPECTED_CHANGE => "Change was provided that was not expected either because it is out-of-order or incorrect.",
            ITF::SYNC_E_DESERIALIZATION => "Deserialization failed. This is typically due to serialization data that is not valid being supplied to the deserializer.",
            ITF::SYNC_E_SINGLE_RANGE_ONLY => "Only one and exactly one range may be specified per batch during forgotten knowledge recovery.",
            ITF::SYNC_E_ITEM_HAS_CHANGE_UNITS => "Operation is not valid as the specified item has change units.",
            ITF::SYNC_E_ITEM_HAS_NO_CHANGE_UNITS => "Operation is not valid as the specified item does not have change units.",
            ITF::SYNC_E_ITEM_HAS_NO_VERSION_DATA => "Operation is not valid as the specified item has no version data.",
            ITF::SYNC_E_OBJECT_NEEDS_STATE => "Object was not correctly initialized. Object state info must be provided as the state could not be derived from sync session context.",
            ITF::SYNC_E_FEEDSYNC_INVALID_FEED => "The specified feed is invalid.",
            ITF::SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA => "Item was not found in feed metadata as expected.",
            ITF::SYNC_E_FEEDSYNC_CALLBACK_EXPECTED => "A feed item or item ID conversion result was unexpectedly not available.",
            ITF::SYNC_E_INVALID_VERSION => "Specified version is not supported.",
            ITF::SYNC_E_DUPLICATE_ITEM => "Item already exists.",
            ITF::SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS => "Clock vector elements are provided with the wrong order.",
            ITF::SYNC_E_INVALID_SYNC_TIME => "SYNC_TIME value is not valid.",
            ITF::SYNC_E_INCOMPLETE_REPLICA_KEY_MAP => "Incomplete replica key map.",
            ITF::SYNC_E_INVALID_REPLICA_KEY => "Clock vector element has a replica key not present in the replica key map.",
            ITF::SYNC_E_NEGATIVE_RANGE_EXCEPTION => "Negative range exceptions are not supported.",
            ITF::SYNC_E_BATCH_NEEDS_KNOWLEDGE => "Change batch provided unexpectedly did not contain knowledge.",
            ITF::SYNC_E_INTERNAL_ERROR => "An internal error occurred in the synchronization runtime.",
            ITF::SYNC_E_CHANGE_BATCH_IS_READ_ONLY => "The operation could not be completed as the specified change batch has become read-only.",
            ITF::SYNC_E_DATA_MODIFIED_CONCURRENTLY => "The operation could not be completed as an item changed unexpectedly during synchronization.",
            ITF::SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM => "A failure during creation may not be recorded per change unit. Item creation may only fail for the entire item.",
            ITF::SYNC_E_FILTER_NOT_SUPPORTED => "The specified filter is not supported.",
            ITF::SYNC_E_LOAD_CONFLICT_DATA_FAILED => "The requested data could not be loaded. This occurs when a recoverable error is set while loading the data or if data conversion fails. Possible resolutions include deferring the conflict or resolving the conflict without change data.",
            ITF::SYNC_E_INVALID_SERIALIZATION_VERSION => "Specified serialization version is not supported or cannot be used.",
            ITF::SYNC_E_MARKER_MISMATCH => "Marker type is not valid.",
            ITF::SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED => "The forgotten knowledge is not contained in the knowledge.",
            ITF::SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT => "There is an active change application context being used.",
            ITF::SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED => "The item list filtered full enumeration synchronization is not supported.",
            ITF::SYNC_E_FULL_ENUMERATION_MUST_BE_USED => "Full enumeration synchronization must be used to apply full enumeration change.",
            ITF::SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE => "One or more filter forgotten knowledges were not set on the change batch.",
            ITF::SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED => "A constraint conflict is not allowed for the current save action.",
            ITF::SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER => "Source provider does not track the specified filter.",
            ITF::IDX_E_INVALIDTAG => "The tag is invalid. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_METAFILE_CORRUPT => "The propagation configuration file cannot be read. Check that the same versions of search are used on both the content index and search servers. If the problem persists, recrawl and repropagate the content index.",
            ITF::IDX_E_TOO_MANY_SEARCH_SERVERS => "The number of search servers exceeded the limit. Ensure that the number of propagated content indexes is less than the documented maximum. If so, start and restart the search service, and then try again.",
            ITF::IDX_E_SEARCH_SERVER_ALREADY_EXISTS => "The specified search server already exists. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_BUILD_IN_PROGRESS => "An update is already in progress. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_IDXLSTFILE_CORRUPT => "The index list file cannot be read. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_REGISTRY_ENTRY => "A registry entry required for content index creation cannot be read or created. Delete and recreate the content index. If the problem persists, you may need to reinstall search.",
            ITF::IDX_E_OBJECT_NOT_FOUND => "One or more files required for content index creation were not found. Stop and restart the search service. If the problem persists, delete and recreate the content index.",
            ITF::IDX_E_SEARCH_SERVER_NOT_FOUND => "The search server was not found. Stop and restart the search service. If propagation is being used, stop and restart the search service on the remote computers.",
            ITF::IDX_E_WB_NOTFOUND => "A word breaker was not found for the given language. Check your current language settings and ensure that search supports the current language. If the problem persists, reinstall search.",
            ITF::IDX_E_NOISELIST_NOTFOUND => "A noise word list was not found for the given language. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_STEMMER_NOTFOUND => "A stemmer was not found for the given language. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_PROP_STOPPED => "Index propagation was stopped. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_DISKFULL => "The disk is full. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_INVALID_INDEX => "The index data is invalid. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_CORRUPT_INDEX => "The index data is corrupt. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_PROPSTORE_INIT_FAILED => "The property store cannot be initialized. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_PROP_STATE_CORRUPT => "The propagation state information cannot be read. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_NOT_LOADED => "The content index is not loaded. Stop and restart the search service. If the problem persists, review other errors in the event log. If necessary, delete and recreate the content index.",
            ITF::IDX_E_PROP_MAJOR_VERSION_MISMATCH => "There is a mismatch in the major version number. Check that the same versions of search are used on both the content index and search servers. If necessary, crawl the index again and repropagate the index.",
            ITF::IDX_E_PROP_MINOR_VERSION_MISMATCH => "The index is a mismatch in the minor version number. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::IDX_E_DSS_NOT_CONNECTED => "A connection with the Search service on a remote machine could not be established. Check the connectivity with the remote machine. If necessary, stop and restart the Search service on the remote machine.",
            ITF::IDX_E_DOCUMENT_ABORTED => "Crawling of documents was stopped. This is an internal error code and should not be reported to users. Call Microsoft Product Support.",
            ITF::IDX_E_CATALOG_DISMOUNTED => "The index was dismounted because it is being removed or the search service stopped. If the problem persists, restart the search service.",
            ITF::IDX_E_USE_DEFAULT_CONTENTCLASS => "No index level information exists for this index. Use application level tables for this index.",
            ITF::IDX_E_USE_APPGLOBAL_PROPTABLE => "Information for this content class was not found. Use the default content class. This error is obsolete and should no longer be reported. Call Microsoft Product Support.",
            ITF::JPS_E_JET_ERR => "The content index server cannot update or access information because of a database error. Stop and restart the search service. If the problem persists, reset and recrawl the content index. In some cases it may be necessary to delete and recreate the content index.",
            ITF::JPS_E_CATALOG_DECSRIPTION_MISSING => "The content index server cannot find a description of the content index in its database. Search will automatically attempt to recreate the content index description. If this problem persists, stop and restart the search service and, if necessary, delete and recreate the content index.",
            ITF::JPS_E_MISSING_INFORMATION => "The content index server cannot find needed information in its database. Reset and recrawl the content index.",
            ITF::JPS_E_INSUFFICIENT_VERSION_STORAGE => "The content index server cannot update or access its database, because the version store has insufficient resources. Increase the system resource usage setting for the search service. If the problem persists, stop and restart the search service.",
            ITF::JPS_E_INSUFFICIENT_DATABASE_SESSIONS => "The content index server cannot update or access its database because sessions are unavailable. Increase the system resource usage setting for the search service. If the problem persists, stop and restart the search service.",
            ITF::JPS_E_INSUFFICIENT_DATABASE_RESOURCES => "The content index server cannot update or access its database because insufficient system resources are available. Increase the system resource usage setting for the search service. If the problem persists, stop and restart the search service.",
            ITF::JPS_E_SCHEMA_ERROR => "The content index server cannot update an unrecognized or recently defined property attribute. Reset and recrawl the content index.",
            ITF::JPS_E_PROPAGATION_FILE => "The property store was unable to open, close, or delete a data file used in propagation. Check that your index volume has enough disk space.",
            ITF::JPS_E_PROPAGATION_CORRUPTION => "The property store encountered propagation data files that cannot be used. Try propagation again.",
            ITF::JPS_E_PROPAGATION_VERSION_MISMATCH => "There is a mismatch in the property store version numbers. Ensure that the same versions of search are used on both the content index and search servers. If necessary, recrawl the content index and try to propagate the content index again.",
            ITF::JPS_E_SHARING_VIOLATION => "The content index server cannot update or access information because of a sharing violation. Stop and restart the search service. If the problem persists, reset and recrawl the content index. In some cases it may be necessary to delete and recreate the content index.",
            ITF::EXCI_E_NO_CONFIG => "The configuration properties for Microsoft Exchange 5.5 were not set. Specify these properties, and then try again.",
            ITF::EXCI_E_INVALID_SERVER_CONFIG => "The name of the Microsoft Exchange 5.5 server specified in the content source does not match the Exchange server specified in the Microsoft Exchange 5.5 configuration properties. Change the name of the Exchange server in the content source or configuration properties to match, and then try again.",
            ITF::EXCI_E_ACCESS_DENIED => "There is insufficient privilege to access the Microsoft Exchange 5.5 server. Check that the Microsoft Exchange 5.5 configuration is valid and that the search service is running in the context of a user having administrative privileges on the Exchange server configuration node.",
            ITF::EXCI_E_INVALID_EXCHANGE_SERVER => "The Microsoft Exchange 5.5 server name specified in the address does not match the one specified in the Microsoft Exchange 5.5 configuration.",
            ITF::EXCI_E_BADCONFIG_OR_ACCESSDENIED => "There is insufficient privilege to access the Microsoft Exchange 5.5 Server. Verify that the Microsoft Exchange 5.5 configuration is valid and that the Search Service is running in the context of a user having administrative privileges on the Exchange Server configuration node.",
            ITF::EXCI_E_WRONG_SERVER_OR_ACCT => "The service cannot access the Exchange 5.5 server. The configured Microsoft Exchange 5.5 server name may be invalid, the Exchange 5.5 server may be temporarily unavailable, or the account used by the search service may not have administrative access to the Exchange 5.5 server. Check all of these properties, and then try again.",
            ITF::EXCI_E_NOT_ADMIN_OR_WRONG_SITE => "The service cannot access the Exchange 5.5 service. The account used by the search service may not be an Exchange administrator, or the site or organization settings on the search host may be invalid.",
            ITF::EXCI_E_NO_MAPI => "Outlook is not installed on this machine, or is missing the CDO or MSEMS components. Please install and configure Outlook, then try again.",
            ITF::EXCI_E_INVALID_ACCOUNT_INFO => "The account information specified for accessing the Exchange 5.5 server cannot be used. Verify the account and password information.",
            ITF::PRTH_E_COMM_ERROR => "A communication error occurred.",
            ITF::PRTH_E_OBJ_NOT_FOUND => "The object was not found.",
            ITF::PRTH_E_REQUEST_ERROR => "The options used are not supported. Check that your version of Internet Explorer is supported.",
            ITF::PRTH_E_INTERNAL_ERROR => "An unrecognized HTTP status was received. Check that the address can be accessed using Internet Explorer.",
            ITF::PRTH_E_ACCESS_DENIED => "Access is denied. Check that the Default Content Access Account in Windows Search Central Administration is correct, or follow the 'Exclude and Include Content' link to add a rule to specify the proper crawling account to access this URL.",
            ITF::PRTH_E_SERVER_ERROR => "A server error occurred. Check that the server is available.",
            ITF::PRTH_E_NOT_REDIRECTED => "You have been redirected to an address that does not exist. Check that the source address is redirecting to an accessible address.",
            ITF::PRTH_E_BAD_REQUEST => "The address appears to be in error. Check that the address is valid.",
            ITF::PRTH_E_HTTP_CANNOT_CONNECT => "Cannot Connect to the server. Please make sure the site is accessible.",
            ITF::PRTH_E_WININET => "The address cannot be accessed. Check that the address can be accessed from Internet Explorer.",
            ITF::PRTH_E_RETRY => "The attempt to access the URL again failed.",
            ITF::PRTH_E_MIME_EXCLUDED => "The URL was excluded because its content type (multipart/x-mixed-replace) is not supported.",
            ITF::PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL => "Search was unable to convert the Access Control List of the crawled store into a Windows NT Access Control List. Check that local information is not used in the store.",
            ITF::PRTH_E_CANT_TRANSFORM_DENIED_ACE => "An object cannot be processed because search cannot convert a Notes Access-Denied entry in the Access Control List into a Windows NT identity. Check the Notes to Windows NT identity mapping.",
            ITF::PRTH_E_ACL_IS_READ_NONE => "The item will not be crawled because the Access Control List allows no one to read the item. Check that this is intended.",
            ITF::PRTH_E_ACL_TOO_BIG => "Search cannot crawl the item, because its Access Control List exceeded 64 KB. Check that the item has a valid Access Control List.",
            ITF::PRTH_E_NO_PROPERTY => "The item cannot be processed further because search failed to find one of its properties. Check that the item is valid in the store.",
            ITF::PRTH_E_DATABASE_OPEN_ERROR => "The database cannot be opened. Check that the database is functional.",
            ITF::PRTH_E_OPLOCK_BROKEN => "Filtering was interrupted because of a sharing conflict with another process. Crawl the file again when it is not in use.",
            ITF::PRTH_E_LOAD_FAILED => "The protocol handler cannot be loaded.",
            ITF::PRTH_E_INIT_FAILED => "The protocol handler cannot be initialized.",
            ITF::PRTH_E_VOLUME_MOUNT_POINT => "The volume mount point is not supported.",
            ITF::PRTH_E_TRUNCATED => "Some data was truncated. Check that the content can still be read.",
            ITF::GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR => "An internal error occurred while expanding local groups.",
            ITF::PRTH_E_HTTPS_CERTIFICATE_ERROR => "Error found in the Secure Sockets Layer (SSL) certificate sent by the server.",
            ITF::PRTH_E_HTTPS_REQUIRE_CERTIFICATE => "Accessing this site requires a client certificate. Specify a client certificate in the site path rules.",
            ITF::SCHED_E_TRIGGER_NOT_FOUND => "Trigger not found.",
            ITF::SCHED_E_TASK_NOT_READY => "One or more of the properties that are needed to run this task have not been set.",
            ITF::SCHED_E_TASK_NOT_RUNNING => "There is no running instance of the task.",
            ITF::SCHED_E_SERVICE_NOT_INSTALLED => "The Task Scheduler Service is not installed on this computer.",
            ITF::SCHED_E_CANNOT_OPEN_TASK => "The task object could not be opened.",
            ITF::SCHED_E_INVALID_TASK => "The object is either an invalid task object or is not a task object.",
            ITF::SCHED_E_ACCOUNT_INFORMATION_NOT_SET => "No account information could be found in the Task Scheduler security database for the task indicated.",
            ITF::SCHED_E_ACCOUNT_NAME_NOT_FOUND => "Unable to establish existence of the account specified.",
            ITF::SCHED_E_ACCOUNT_DBASE_CORRUPT => "Corruption was detected in the Task Scheduler security database; the database has been reset.",
            ITF::SCHED_E_NO_SECURITY_SERVICES => "Task Scheduler security services are available only on Windows NT.",
            ITF::SCHED_E_UNKNOWN_OBJECT_VERSION => "The task object version is either unsupported or invalid.",
            ITF::SCHED_E_UNSUPPORTED_ACCOUNT_OPTION => "The task has been configured with an unsupported combination of account settings and run time options.",
            ITF::SCHED_E_SERVICE_NOT_RUNNING => "The Task Scheduler Service is not running.",
            ITF::SCHED_E_UNEXPECTEDNODE => "The task XML contains an unexpected node.",
            ITF::SCHED_E_NAMESPACE => "The task XML contains an element or attribute from an unexpected namespace.",
            ITF::SCHED_E_INVALIDVALUE => "The task XML contains a value which is incorrectly formatted or out of range.",
            ITF::SCHED_E_MISSINGNODE => "The task XML is missing a required element or attribute.",
            ITF::SCHED_E_MALFORMEDXML => "The task XML is malformed.",
            ITF::SCHED_E_TOO_MANY_NODES => "The task XML contains too many nodes of the same type.",
            ITF::SCHED_E_PAST_END_BOUNDARY => "The task cannot be started after the trigger's end boundary.",
            ITF::SCHED_E_ALREADY_RUNNING => "An instance of this task is already running.",
            ITF::SCHED_E_USER_NOT_LOGGED_ON => "The task will not run because the user is not logged on.",
            ITF::SCHED_E_INVALID_TASK_HASH => "The task image is corrupt or has been tampered with.",
            ITF::SCHED_E_SERVICE_NOT_AVAILABLE => "The Task Scheduler service is not available.",
            ITF::SCHED_E_SERVICE_TOO_BUSY => "The Task Scheduler service is too busy to handle your request. Please try again later.",
            ITF::SCHED_E_TASK_ATTEMPTED => "The Task Scheduler service attempted to run the task, but the task did not run due to one of the constraints in the task definition.",
            ITF::SCHED_E_TASK_DISABLED => "The task is disabled.",
            ITF::SCHED_E_TASK_NOT_V1_COMPAT => "The task has properties that are not compatible with previous versions of Windows.",
            ITF::SCHED_E_START_ON_DEMAND => "The task settings do not allow the task to start on demand.",
            ITF::SCHED_E_TASK_NOT_UBPM_COMPAT => "The combination of properties that task is using is not compatible with the scheduling engine.",
            ITF::SCHED_E_DEPRECATED_FEATURE_USED => "The task definition uses a deprecated feature.",
            ITF::SEC_E_INITFAILED => "The Exchange search provider cannot be initialized. You may have to reinstall the application.",
            ITF::SEC_E_NOTINITIALIZED => "The security provider was not initialized. You may have to reinstall the application.",
            ITF::SEC_E_INVALIDCONTEXT => "The search service is running as a local System service. To access Exchange documents, check that the search service is running in a user account with administrative privileges on the Exchange server.",
            ITF::SEC_E_ACCESSDENIED => "Access is denied. You may not have sufficient privileges to perform the operation.",
            ITF::CMDLINE_E_UNEXPECTED => "An unexpected error occurred.",
            ITF::CMDLINE_E_PAREN => "There is an unmatched parenthesis on the command line.",
            ITF::CMDLINE_E_PARAM_SIZE => "The parameter is too long.",
            ITF::CMDLINE_E_NOT_INIT => "The object is not initialized. Call Init() first to initialize the object.",
            ITF::CMDLINE_E_ALREADY_INIT => "The object is already initialized.",
            ITF::CMDLINE_E_NUM_PARAMS => "There are too many parameters.",
            ITF::QUERY_E_FAILED => "Call failed for unknown reason.",
            ITF::SYNC_E_REGISTRATION_INTERNAL_ERROR => "An internal error occurred in the sync registration runtime.",
            ITF::QUERY_E_INVALIDQUERY => "Invalid parameter.",
            ITF::SYNC_E_REGISTRATION_ALREADY_REGISTERED => "The requested item has already been registered.",
            ITF::QUERY_E_INVALIDRESTRICTION => "The query restriction could not be parsed.",
            ITF::SYNC_E_REGISTRATION_NOT_REGISTERED => "The requested item does not exist in the registration store.",
            ITF::QUERY_E_INVALIDSORT => "An invalid sort order was requested.",
            ITF::SYNC_E_REGISTRATION_CORRUPT_DATA => "The data for this item is corrupted and cannot be read.",
            ITF::QUERY_E_INVALIDCATEGORIZE => "An invalid categorization order was requested.",
            ITF::SYNC_E_REGISTRATION_ALREADY_COMMITTED => "The properties for this item have already been committed on another instance.",
            ITF::QUERY_E_ALLNOISE => "The query contained only ignored words.",
            ITF::QUERY_E_TOOCOMPLEX => "The query was too complex to be executed.",
            ITF::QUERY_E_TIMEDOUT => "The query exceeded its execution time limit.",
            ITF::QUERY_E_DUPLICATE_OUTPUT_COLUMN => "One or more columns in the output column list is a duplicate.",
            ITF::QUERY_E_INVALID_OUTPUT_COLUMN => "One or more columns in the output column list is not valid.",
            ITF::QUERY_E_INVALID_DIRECTORY => "Invalid directory name.",
            ITF::QUERY_E_DIR_ON_REMOVABLE_DRIVE => "Specified directory is on a removable medium.",
            ITF::QUERY_S_NO_QUERY => "The catalog is in a state where indexing continues, but queries are not allowed.",
            ITF::QUERY_E_ALLNOISE_AND_NO_RELDOC => "The relevant specified documents were not found, because a clause of the query contained only words that are ignored.",
            ITF::QUERY_E_NO_RELDOC => "None of the relevant documents specified in the query can be found.",
            ITF::QUERY_E_ALLNOISE_AND_NO_RELPROP => "No information was found in the relevant documents with the specified properties, because a clause of the query contained only words that are ignored.",
            ITF::QUERY_E_NO_RELPROP => "No relevant information is found in the relevant documents with the specified properties for this query.",
            ITF::QUERY_E_REPEATED_RELDOC => "The same relevant document is specified multiple times.",
            ITF::QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED => "The reldoc specification is not supported.",
            ITF::QUERY_E_INVALID_DOCUMENT_IDENTIFIER => "The specified document identifier is not valid.",
            ITF::QUERY_E_INCORRECT_VERSION => "The server is running an older version of software that cannot handle this query.",
            ITF::QUERY_E_INVALIDSCOPE_COALESCE => "Scopes should be the same in all of the components of a coalesce query.",
            ITF::QUERY_E_INVALIDSORT_COALESCE => "Order by list should be same in all the components of a coalesce query.",
            ITF::QUERY_E_INVALIDCOALESCE => "Coalesce is either not used properly or this form is not currently supported. Check for possible mixing of grouping with coalesce.",
            ITF::QUERY_E_UPGRADEINPROGRESS => "Queries are disabled because the index is being updated. Try your query again in a few minutes.",
            ITF::QUERY_E_AGGREGATE_NOT_SUPPORTED => "Aggregate is not supported.",
            ITF::QUERY_E_TOP_LEVEL_IN_GROUP => "The top level group does not support ORDER IN GROUP since there is no parent group.",
            ITF::QUERY_E_DUPLICATE_RANGE_NAME => "Each name for a ranged label must be unique.",
            ITF::QPLIST_E_CANT_OPEN_FILE => "Can not open file.",
            ITF::QPLIST_E_READ_ERROR => "Read error in file.",
            ITF::QPLIST_E_EXPECTING_NAME => "Expecting property name.",
            ITF::QPLIST_E_EXPECTING_TYPE => "Expecting type specifier.",
            ITF::QPLIST_E_UNRECOGNIZED_TYPE => "Unrecognized type.",
            ITF::QPLIST_E_EXPECTING_INTEGER => "Expecting integer.",
            ITF::QPLIST_E_EXPECTING_CLOSE_PAREN => "Expecting closing parenthesis.",
            ITF::QPLIST_E_EXPECTING_GUID => "Expecting GUID.",
            ITF::QPLIST_E_BAD_GUID => "Invalid guid.",
            ITF::QPLIST_E_EXPECTING_PROP_SPEC => "Expecting property specifier.",
            ITF::QPLIST_E_CANT_SET_PROPERTY => "Failed to set property name.",
            ITF::QPLIST_E_DUPLICATE => "Duplicate property name.",
            ITF::QPLIST_E_VECTORBYREF_USED_ALONE => "DBTYPE_VECTOR or DBTYPE_BYREF used alone.",
            ITF::QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE => "DBTYPE_BYREF must be used with DBTYPE_STR, DBTYPE_WSTR, DBTYPE_GUID or DBTYPE_UI1 types.",
            ITF::QPARSE_E_UNEXPECTED_NOT => "Unexpected NOT operator.",
            ITF::QPARSE_E_EXPECTING_INTEGER => "Expecting integer.",
            ITF::QPARSE_E_EXPECTING_REAL => "Expecting real number.",
            ITF::QPARSE_E_EXPECTING_DATE => "Expecting date.",
            ITF::QPARSE_E_EXPECTING_CURRENCY => "Expecting currency.",
            ITF::QPARSE_E_EXPECTING_GUID => "Expecting GUID.",
            ITF::QPARSE_E_EXPECTING_BRACE => "Expecting closing square bracket ']'.",
            ITF::QPARSE_E_EXPECTING_PAREN => "Expecting closing parenthesis ')'.",
            ITF::QPARSE_E_EXPECTING_PROPERTY => "Expecting property name.",
            ITF::QPARSE_E_NOT_YET_IMPLEMENTED => "Not yet implemented.",
            ITF::QPARSE_E_EXPECTING_PHRASE => "Expecting phrase.",
            ITF::QPARSE_E_UNSUPPORTED_PROPERTY_TYPE => "Unsupported property type.",
            ITF::QPARSE_E_EXPECTING_REGEX => "Expecting regular expression.",
            ITF::QPARSE_E_EXPECTING_REGEX_PROPERTY => "Regular expressions require a property of type string.",
            ITF::QPARSE_E_INVALID_LITERAL => "Invalid literal.",
            ITF::QPARSE_E_NO_SUCH_PROPERTY => "No such property.",
            ITF::QPARSE_E_EXPECTING_EOS => "Expecting end of string.",
            ITF::QPARSE_E_EXPECTING_COMMA => "Expecting comma.",
            ITF::QPARSE_E_UNEXPECTED_EOS => "Unexpected end of string.",
            ITF::QPARSE_E_WEIGHT_OUT_OF_RANGE => "Weight must be between 0 and 1000 in short form queries and between 0.0 and 1.0 in long form queries.",
            ITF::QPARSE_E_NO_SUCH_SORT_PROPERTY => "An invalid property was found in the sort specification.",
            ITF::QPARSE_E_INVALID_SORT_ORDER => "An invalid sort order was specified. Only [a] and [d] are supported.",
            ITF::QUTIL_E_CANT_CONVERT_VROOT => "Couldn't convert a virtual path to a physical path.",
            ITF::QPARSE_E_INVALID_GROUPING => "An unsupported grouping type was specified.",
            ITF::QPARSE_E_INVALID_QUERY => "Invalid query.",
            ITF::QPARSE_E_INVALID_RANKMETHOD => "Invalid rank method.",
            ITF::FDAEMON_E_LOWRESOURCE => "The system is running out of one of more resources needed for filtering, usually memory.",
            ITF::FDAEMON_E_FATALERROR => "A critical error occurred during document filtering. Consult system administrator.",
            ITF::FDAEMON_E_PARTITIONDELETED => "Documents not stored in content index because partition has been deleted.",
            ITF::FDAEMON_E_CHANGEUPDATEFAILED => "Documents not stored in content index because update of changelist failed.",
            ITF::FDAEMON_E_WORDLISTCOMMITFAILED => "Commit of wordlist failed. Data not available for query.",
            ITF::FDAEMON_E_NOWORDLIST => "No wordlist is being constructed. May happen after fatal filter error.",
            ITF::FDAEMON_E_TOOMANYFILTEREDBLOCKS => "During document filtering the limit on buffers has been exceeded.",
            ITF::SEARCH_E_NOMONIKER => "Retrival of hits as monikers is not supported (by filter passed into Init).",
            ITF::SEARCH_E_NOREGION => "Retrival of hits as filter regions is not supported (by filter passed into Init).",
            ITF::FILTER_E_END_OF_CHUNKS => "No more chunks of text available in object.",
            ITF::FILTER_E_NO_MORE_TEXT => "No more text available in chunk.",
            ITF::FILTER_E_NO_MORE_VALUES => "No more property values available in chunk.",
            ITF::FILTER_E_ACCESS => "Unable to access object.",
            ITF::FILTER_E_NO_TEXT => "No text in current chunk.",
            ITF::FILTER_E_NO_VALUES => "No values in current chunk.",
            ITF::FILTER_E_EMBEDDING_UNAVAILABLE => "Unable to bind IFilter for embedded object.",
            ITF::FILTER_E_LINK_UNAVAILABLE => "Unable to bind IFilter for linked object.",
            ITF::FILTER_E_PASSWORD => "File was not filtered due to password protection.",
            ITF::FILTER_E_UNKNOWNFORMAT => "The document format is not recognized by the flter.",
            ITF::FILTER_E_TOO_BIG => "File is too large to filter.",
            ITF::FILTER_E_ALREADY_OPEN => "A file is already open. Cannot open another one while a file is open.",
            ITF::FILTER_E_UNREACHABLE => "The file is not reachable.",
            ITF::FILTER_E_IN_USE => "The document is in use by another process.",
            ITF::FILTER_E_NOT_OPEN => "The document is not opened.",
            ITF::FILTER_E_NO_SUCH_PROPERTY => "There is no property with the given GUID.",
            ITF::FILTER_E_OFFLINE => "The document is offline.",
            ITF::FILTER_E_PARTIALLY_FILTERED => "The document was too large to filter in its entirety. Portions of the document were not emitted.",
            ITF::WBREAK_E_END_OF_TEXT => "End of text reached in text source.",
            ITF::WBREAK_E_QUERY_ONLY => "Feature only available in query mode.",
            ITF::WBREAK_E_BUFFER_TOO_SMALL => "Buffer too small to hold composed phrase.",
            ITF::LANGUAGE_E_DATABASE_NOT_FOUND => "Langauge database/cache file could not be found.",
            ITF::WBREAK_E_INIT_FAILED => "Initialization of word breaker failed.",
            ITF::PSINK_E_QUERY_ONLY => "Feature only available in query mode.",
            ITF::PSINK_E_INDEX_ONLY => "Feature only available in index mode.",
            ITF::PSINK_E_LARGE_ATTACHMENT => "Attachment type beyond valid range.",
            ITF::CI_E_ALREADY_INITIALIZED => "The object is already initialzed.",
            ITF::CI_E_NOT_INITIALIZED => "The object is not initialzed.",
            ITF::CI_E_BUFFERTOOSMALL => "The buffer is too small.",
            ITF::CI_E_PROPERTY_NOT_CACHED => "The given property is not cached.",
            ITF::CI_E_INVALID_STATE => "The object is not in a valid state.",
            ITF::CI_E_FILTERING_DISABLED => "Filtering is disabled in this content index.",
            ITF::CI_E_DISK_FULL => "The disk is full and the specified operation cannot be done.",
            ITF::CI_E_SHUTDOWN => "Content Index has been shutdown.",
            ITF::CI_E_WORKID_NOTVALID => "The workid is not valid.",
            ITF::CI_E_NOT_FOUND => "The object was not found.",
            ITF::CI_E_USE_DEFAULT_PID => "The passed-in property id is not supported.",
            ITF::CI_E_DUPLICATE_NOTIFICATION => "There were two notifications for the same workid.",
            ITF::CI_E_UPDATES_DISABLED => "A document update was rejected because updates were disabled.",
            ITF::CI_E_INVALID_FLAGS_COMBINATION => "The combination of flags specified is invalid.",
            ITF::CI_E_OUTOFSEQ_INCREMENT_DATA => "The incremental data given to Load is not valid. It may be out of sequence.",
            ITF::CI_E_SHARING_VIOLATION => "A sharing or locking violation caused a failure.",
            ITF::CI_E_LOGON_FAILURE => "A logon permission violation caused a failure.",
            ITF::CI_E_NO_CATALOG => "There is no catalog.",
            ITF::CI_E_STRANGE_PAGEORSECTOR_SIZE => "Page size is not an integral multiple of the sector size of the volume where index is located.",
            ITF::CI_E_TIMEOUT => "Service is too busy.",
            ITF::CI_E_NOT_RUNNING => "Service is not running.",
            ITF::CI_E_CARDINALITY_MISMATCH => "Mismatch in cardinality of machine(s)/catalog(s)/scope(s).",
            ITF::CI_E_CONFIG_DISK_FULL => "The disk has reached its configured space limit.",
            ITF::CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED => "Groupby clause is not supported on a distributed query.",
            ITF::CI_E_NO_AUXMETADATA => "The property store is not configured to handle auxiliary metadata storage.",
            ITF::CI_E_INVALID_CATALOG_LIST_VERSION => "The specified index list version is outdated or invalid.",
            ITF::NLADMIN_E_DUPLICATE_CATALOG => "A catalog with the name specified already exists. Choose another name to create a new catalog.",
            ITF::NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE => "The account cannot be granted a privilege to 'log on as service'' on the domain controller. The domain security administrator needs to grant the default account this privilege. All of the default accounts specified for the server need this account privilege.",
            ITF::NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED => "The selected content index definition did not initialize and cannot be used. Check server status, content index configuration, and user access to the server.",
            ITF::FAX_E_SRV_OUTOFMEMORY => "The fax server failed to allocate memory.",
            ITF::FAX_E_GROUP_NOT_FOUND => "The fax server failed to locate an outbound routing group by name.",
            ITF::FAX_E_BAD_GROUP_CONFIGURATION => "The fax server encountered an outbound routing group with bad configuration.",
            ITF::FAX_E_GROUP_IN_USE => "The fax server cannot remove an outbound routing group because it is in use by one or more outbound routing rules.",
            ITF::FAX_E_RULE_NOT_FOUND => "The fax server failed to locate an outbound routing rule by country/region code and area code.",
            ITF::FAX_E_NOT_NTFS => "The fax server cannot set an archive folder to a non-NTFS partition.",
            ITF::FAX_E_DIRECTORY_IN_USE => "The fax server cannot use the same folder for both the inbox and the sent-items archives.",
            ITF::FAX_E_FILE_ACCESS_DENIED => "The fax server cannot access the specified file or folder.",
            ITF::FAX_E_MESSAGE_NOT_FOUND => "The fax server cannot find the job or message by its ID.",
            ITF::FAX_E_DEVICE_NUM_LIMIT_EXCEEDED => "The fax server cannot complete the operation because the number of active fax devices allowed for this version of Windows was exceeded.",
            ITF::FAX_E_NOT_SUPPORTED_ON_THIS_SKU => "The fax server cannot complete the operation because it is not supported for this version of Windows.",
            ITF::FAX_E_VERSION_MISMATCH => "The fax server API version does not support the requested operation.",
            ITF::FAX_E_RECIPIENTS_LIMIT => "The limit on the number of recipients for a single fax broadcast was reached.",
            ITF::SCRIPTPI_E_CHUNK_NOT_TEXT => "The chunk type was not text.",
            ITF::SCRIPTPI_E_PID_NOT_NAME => "The property ID type was not name.",
            ITF::SCRIPTPI_E_PID_NOT_NUMERIC => "The property ID type was not numeric.",
            ITF::SCRIPTPI_E_CHUNK_NOT_VALUE => "The chunk type is not value.",
            ITF::SCRIPTPI_E_CANNOT_ALTER_CHUNK => "The chunk does not allow changes. To set properties on a chunk, create it using IGatherScriptFilterSink::CreateChunk.",
            ITF::SCRIPTPI_E_ALREADY_COMPLETED => "The resource completion code was already set.",
            ITF::MSS_E_INVALIDAPPNAME => "The specified application name is not valid. Check to see whether a search application with that name already exists.",
            ITF::MSS_E_APPNOTFOUND => "The specified search application name was not found. It may have already been deleted.",
            ITF::MSS_E_APPALREADYEXISTS => "The search application name already exists. Use a different name.",
            ITF::MSS_E_CATALOGNOTFOUND => "The specified catalog was not found. Check to see if it was deleted, or if there are errors in your application code.",
            ITF::MSS_E_CATALOGSTOPPING => "The content index cannot be deleted while the search service is stopped. Restart the search service and try again.",
            ITF::MSS_E_UNICODEFILEHEADERMISSING => "This file is shorter than 2 bytes. Unicode text file must begin with a wide character that indicates byte order.",
            ITF::MSS_E_CATALOGALREADYEXISTS => "The specified catalog already exists.",
            ITF::XML_E_NODEFAULTNS => "This scope has no default namespace. Add a default namespace before continuing.",
            ITF::XML_E_BADSXQL => "The SXQL is invalid.",
            ITF::VSS_E_BAD_STATE => "A function call was made when the object was in an incorrect state for that function.",
            ITF::VSS_E_UNEXPECTED => "A Volume Shadow Copy Service component encountered an unexpected error. Check the Application event log for more information.",
            ITF::VSS_E_PROVIDER_ALREADY_REGISTERED => "The provider has already been registered.",
            ITF::VSS_E_PROVIDER_NOT_REGISTERED => "The volume shadow copy provider is not registered in the system.",
            ITF::VSS_E_PROVIDER_VETO => "The shadow copy provider had an error. Check the System and Application event logs for more information.",
            ITF::VSS_E_PROVIDER_IN_USE => "The shadow copy provider is currently in use and cannot be unregistered.",
            ITF::VSS_E_OBJECT_NOT_FOUND => "The specified object was not found.",
            ITF::VSS_E_VOLUME_NOT_SUPPORTED => "Shadow copying the specified volume is not supported.",
            ITF::VSS_E_OBJECT_ALREADY_EXISTS => "The object already exists.",
            ITF::VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER => "The given shadow copy provider does not support shadow copying the specified volume.",
            ITF::VSS_E_UNEXPECTED_PROVIDER_ERROR => "The shadow copy provider had an unexpected error while trying to process the specified operation.",
            ITF::VSS_E_CORRUPT_XML_DOCUMENT => "The given XML document is invalid. It is either incorrectly-formed XML or it does not match the schema. This error code is deprecated.",
            ITF::VSS_E_INVALID_XML_DOCUMENT => "The given XML document is invalid. It is either incorrectly-formed XML or it does not match the schema.",
            ITF::VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED => "The maximum number of volumes for this operation has been reached.",
            ITF::VSS_E_FLUSH_WRITES_TIMEOUT => "The shadow copy provider timed out while flushing data to the volume being shadow copied. This is probably due to excessive activity on the volume. Try again later when the volume is not being used so heavily.",
            ITF::VSS_E_HOLD_WRITES_TIMEOUT => "The shadow copy provider timed out while holding writes to the volume being shadow copied. This is probably due to excessive activity on the volume by an application or a system service. Try again later when activity on the volume is reduced.",
            ITF::VSS_E_UNEXPECTED_WRITER_ERROR => "VSS encountered problems while sending events to writers.",
            ITF::VSS_E_SNAPSHOT_SET_IN_PROGRESS => "Another shadow copy creation is already in progress. Wait a few moments and try again.",
            ITF::VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED => "The specified volume has already reached its maximum number of shadow copies.",
            ITF::VSS_E_WRITER_INFRASTRUCTURE => "An error was detected in the Volume Shadow Copy Service (VSS). The problem occurred while trying to contact VSS writers. Verify that the Event System service and the VSS service are running and check for associated errors in the event logs.",
            ITF::VSS_E_WRITER_NOT_RESPONDING => "A writer did not respond to a GatherWriterStatus call. The writer may either have terminated or it may be stuck. Check the System and Application event logs for more information.",
            ITF::VSS_E_WRITER_ALREADY_SUBSCRIBED => "The writer has already successfully called the Subscribe function. It cannot call Subscribe multiple times.",
            ITF::VSS_E_UNSUPPORTED_CONTEXT => "The shadow copy provider does not support the specified shadow copy type.",
            ITF::VSS_E_VOLUME_IN_USE => "The specified shadow copy storage association is in use and so can't be deleted.",
            ITF::VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED => "Maximum number of shadow copy storage associations already reached.",
            ITF::VSS_E_INSUFFICIENT_STORAGE => "Insufficient storage available to create either the shadow copy storage file or other shadow copy data.",
            ITF::VSS_E_NO_SNAPSHOTS_IMPORTED => "No shadow copies were successfully imported.",
            ITF::VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED => "Some shadow copies were not successfully imported.",
            ITF::VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED => "The maximum number of remote machines for this operation has been reached.",
            ITF::VSS_E_REMOTE_SERVER_UNAVAILABLE => "The remote server is unavailable.",
            ITF::VSS_E_REMOTE_SERVER_UNSUPPORTED => "The remote server is running a version of the Volume Shadow Copy Service that does not support remote shadow-copy creation.",
            ITF::VSS_E_REVERT_IN_PROGRESS => "A revert is currently in progress for the specified volume. Another revert cannot be initiated until the current revert completes.",
            ITF::VSS_E_REVERT_VOLUME_LOST => "The volume being reverted was lost during revert.",
            ITF::VSS_E_REBOOT_REQUIRED => "A reboot is required after completing this operation.",
            ITF::VSS_E_TRANSACTION_FREEZE_TIMEOUT => "A timeout occurred while freezing a transaction manager.",
            ITF::VSS_E_TRANSACTION_THAW_TIMEOUT => "Too much time elapsed between freezing a transaction manager and thawing the transaction manager.",
            ITF::VSS_E_UNSELECTED_VOLUME => "The requested operation would overwrite a volume that is not explicitly selected. For more information, check the Application event log.",
            ITF::VSS_E_SNAPSHOT_NOT_IN_SET => "The shadow copy ID was not found in the backup components document for the shadow copy set.",
            ITF::VSS_E_NESTED_VOLUME_LIMIT => "The specified volume is nested too deeply to participate in the VSS operation.",
            ITF::VSS_E_VOLUME_NOT_LOCAL => "The volume being backed up is not mounted on the local host.",
            ITF::VSS_E_CLUSTER_TIMEOUT => "A timeout occurred while preparing a cluster shared volume for backup.",
            ITF::VSS_E_NOT_SUPPORTED => "The requested operation is not supported.",
            ITF::VSS_E_WRITERERROR_PARTIAL_FAILURE => "The writer experienced a partial failure. Check the component level error state for more information.",
            ITF::VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT => "The shadow-copy set only contains only a subset of the volumes needed to correctly backup the selected components of the writer.",
            ITF::VSS_E_WRITERERROR_OUTOFRESOURCES => "A resource allocation failed while processing this operation.",
            ITF::VSS_E_WRITERERROR_TIMEOUT => "The writer's timeout expired between the Freeze and Thaw events.",
            ITF::VSS_E_WRITERERROR_RETRYABLE => "The writer experienced a transient error. If the backup process is retried, the error may not reoccur.",
            ITF::VSS_E_WRITERERROR_NONRETRYABLE => "The writer experienced a non-transient error. If the backup process is retried, the error is likely to reoccur.",
            ITF::VSS_E_WRITERERROR_RECOVERY_FAILED => "The writer experienced an error while trying to recover the shadow-copy volume.",
            ITF::VSS_E_BREAK_REVERT_ID_FAILED => "The shadow copy set break operation failed because the disk/partition identities could not be reverted. The target identity already exists on the machine or cluster and must be masked before this operation can succeed.",
            ITF::VSS_E_LEGACY_PROVIDER => "This version of the hardware provider does not support this operation.",
            ITF::VSS_E_MISSING_DISK => "An expected disk did not arrive in the system.",
            ITF::VSS_E_MISSING_HIDDEN_VOLUME => "An expected hidden volume did not arrive in the system. Check the Application event log for more information.",
            ITF::VSS_E_MISSING_VOLUME => "An expected volume did not arrive in the system. Check the Application event log for more information.",
            ITF::VSS_E_AUTORECOVERY_FAILED => "The autorecovery operation failed to complete on the shadow copy.",
            ITF::VSS_E_DYNAMIC_DISK_ERROR => "An error occurred in processing the dynamic disks involved in the operation.",
            ITF::VSS_E_NONTRANSPORTABLE_BCD => "The given Backup Components Document is for a non-transportable shadow copy. This operation can only be done on transportable shadow copies.",
            ITF::VSS_E_CANNOT_REVERT_DISKID => "The MBR signature or GPT ID for one or more disks could not be set to the intended value. Check the Application event log for more information.",
            ITF::VSS_E_RESYNC_IN_PROGRESS => "The LUN resynchronization operation could not be started because another resynchronization operation is already in progress.",
            ITF::VDS_E_NOT_SUPPORTED => "The operation is not supported by the object.",
            ITF::VSS_E_CLUSTER_ERROR => "The clustered disks could not be enumerated or could not be put into cluster maintenance mode. Check the System event log for cluster related events and the Application event log for VSS related events.",
            ITF::FLTRDMN_E_UNEXPECTED => "An unexpected error occurred in the filtering process. Contact Microsoft Product Support.",
            ITF::VDS_E_INITIALIZED_FAILED => "The service failed to initialize.",
            ITF::VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED => "There are too few disks on this computer or one or more of the disks is too small. Add or change disks so they match the disks in the backup, and try the restore again.",
            ITF::FLTRDMN_E_QI_FILTER_FAILED => "The document IFilter cannot provide the needed interface. The IFilter may contain errors.",
            ITF::VDS_E_INITIALIZE_NOT_CALLED => "The initialization method was not called.",
            ITF::VSS_E_ASRERROR_DISK_RECREATION_FAILED => "Windows cannot create a disk on this computer needed to restore from the backup. Make sure the disks are properly connected, or add or change disks, and try the restore again.",
            ITF::VDS_E_ALREADY_REGISTERED => "The provider is already registered.",
            ITF::VSS_E_ASRERROR_NO_ARCPATH => "The computer needs to be restarted to finish preparing a hard disk for restore. To continue, restart your computer and run the restore again.",
            ITF::FLTRDMN_E_FILTER_INIT_FAILED => "A document IFilter cannot be initialized. The document or IFilter may contain errors.",
            ITF::VDS_E_ANOTHER_CALL_IN_PROGRESS => "A concurrent second call is made on an object before the first is completed.",
            ITF::VSS_E_ASRERROR_MISSING_DYNDISK => "The backup failed due to a missing disk for a dynamic volume. Ensure the disk is online and retry the backup.",
            ITF::FLTRDMN_E_ENCRYPTED_DOCUMENT => "An encrypted document cannot be filtered.",
            ITF::VDS_E_OBJECT_NOT_FOUND => "The object is not found.",
            ITF::VSS_E_ASRERROR_SHARED_CRIDISK => "Automated System Recovery failed the shadow copy, because a selected critical volume is located on a cluster shared disk. This is an unsupported configuration.",
            ITF::FLTRDMN_E_CANNOT_DECRYPT_PASSWORD => "The password for the content access account cannot be decrypted because it was stored with different credentials. Re-type the password for the account used to crawl this content.",
            ITF::VDS_E_INVALID_SPACE => "The specified space is not free or not valid.",
            ITF::VSS_E_ASRERROR_DATADISK_RDISK0 => "A data disk is currently set as active in BIOS. Set some other disk as active or use the DiskPart utility to clean the data disk, and then retry the restore operation.",
            ITF::VDS_E_PARTITION_LIMIT_REACHED => "The number of partitions has reached the limit on a disk.",
            ITF::VSS_E_ASRERROR_RDISK0_TOOSMALL => "The disk that is set as active in BIOS is too small to recover the original system disk. Replace the disk with a larger one and retry the restore operation.",
            ITF::VDS_E_PARTITION_NOT_EMPTY => "The extended partition is not empty.",
            ITF::VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL => "Failed to find enough suitable disks for recreating all critical disks. The number of available disks should be same or greater than the number of critical disks at time of backup, and each one of the disks must be of same or greater size.",
            ITF::VDS_E_OPERATION_PENDING => "The operation has not been completed yet.",
            ITF::VSS_E_WRITER_STATUS_NOT_AVAILABLE => "Writer status is not available for one or more writers. A writer may have reached the limit to the number of available backup-restore session states.",
            ITF::VDS_E_OPERATION_DENIED => "This operation is not allowed on the current boot, system or pagefile volume. It is also not allowed on any volume on a basic MBR disk that contains the boot, system or pagefile volume.",
            ITF::VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED => "A critical dynamic disk is a Virtual Hard Disk (VHD). This is an unsupported configuration. Check the Application event log for more details.",
            ITF::VDS_E_OBJECT_DELETED => "The object has been deleted.",
            ITF::VDS_E_CANCEL_TOO_LATE => "The operation cannot be cancelled.",
            ITF::VDS_E_OPERATION_CANCELED => "The operation has been cancelled.",
            ITF::VDS_E_CANNOT_EXTEND => "The volume cannot be extended because the file system does not support it.",
            ITF::VDS_E_NOT_ENOUGH_SPACE => "There is not enough usable space for this operation.",
            ITF::VDS_E_NOT_ENOUGH_DRIVE => "Not enough drives are specified to complete this operation.",
            ITF::VDS_E_BAD_COOKIE => "The cookie is not found.",
            ITF::VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK => "A critical volume selected for backup exists on a disk which cannot be backed up by ASR.",
            ITF::VDS_E_NO_MEDIA => "There is no media in the device.",
            ITF::VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND => "No disk that can be used for recovering the system disk can be found. Try the following: 1) A probable system disk may have been excluded by mistake. a. Review the list of disks that you have excluded from the recovery for a likely disk. b. Type LIST DISK command in the DISKPART command interpreter. The probable system disk is usually the first disk listed in the results. c. If possible, remove the disk from the exclusion list and then retry the recovery. 2) A USB disk may have been assigned as a system disk. a. Detach all USB disks from the computer. b. Reboot into Windows Recovery Environment (Win RE), then reattach USB disks and retry the recovery. 3) An invalid disk may have been assigned as system disk. a. Physically detach the disk from your computer. Then boot into Win RE to retry the recovery.",
            ITF::VDS_E_DEVICE_IN_USE => "The device is in use.",
            ITF::VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE => "Windows did not find any fixed disk that can be used to recreate volumes present in backup. Ensure disks are online, and disk drivers are installed to access the disk(s). &#x27;diskpart.exe&#x27; tool with list disks command can be used to see the list of available fixed disks on the system.",
            ITF::VDS_E_DISK_NOT_EMPTY => "The disk is not empty.",
            ITF::VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION => "Windows did not find any disk which it can use for recreating volumes present in backup. Offline disks, cluster shared disks or disks explicitly excluded by user will not be used by Windows. Ensure that disks are online and no disks are excluded by mistake.",
            ITF::VDS_E_INVALID_OPERATION => "Invalid operation.",
            ITF::VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED => "Restore failed because a disk which was critical at backup is excluded. To continue you need to either remove the disk from exclusion list or detach it from machine or clean it using DiskPart utility, and then retry restore. If you cannot clean or detach it then change the disk signature using DiskPart command UNIQUEID DISK ID.",
            ITF::VDS_E_PATH_NOT_FOUND => "The path is not found.",
            ITF::VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN => "System partition (partition marked &quot;active&quot;) is hidden or contains an unrecognized file system. Backup does not support this configuration.",
            ITF::VDS_E_DISK_NOT_INITIALIZED => "The disk is not initialized.",
            ITF::VSS_E_FSS_TIMEOUT => "A timeout occurred while preparing a file share shadowcopy for backup.",
            ITF::VDS_E_NOT_AN_UNALLOCATED_DISK => "The disk is not unallocated.",
            ITF::VDS_E_UNRECOVERABLE_ERROR => "An unrecoverable error occurred. The service must shut down.",
            ITF::VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED => "The provider failed to connect to the Logical Disk Management Administrative service.",
            ITF::VDS_E_PROVIDER_INITIALIZATION_FAILED => "The provider failed to initialize.",
            ITF::VDS_E_OBJECT_EXISTS => "The object already exists.",
            ITF::VDS_E_NO_DISKS_FOUND => "No disks were found on the target machine.",
            ITF::VDS_E_PROVIDER_CACHE_CORRUPT => "The provider's cache has become corrupt.",
            ITF::VDS_E_DMADMIN_METHOD_CALL_FAILED => "A method call to the Logical Disk Management Administrative service failed.",
            ITF::VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND => "The device form of the volume pathname could not be retrieved.",
            ITF::VDS_E_PROVIDER_VOL_OPEN => "Failed to open the volume device.",
            ITF::VDS_E_DMADMIN_CORRUPT_NOTIFICATION => "A corrupt notification was sent from the Logical Disk Manager Administrative service.",
            ITF::VDS_E_INCOMPATIBLE_FILE_SYSTEM => "The file system is incompatible.",
            ITF::VDS_E_INCOMPATIBLE_MEDIA => "The media is incompatible.",
            ITF::VDS_E_ACCESS_DENIED => "Access is denied.",
            ITF::VDS_E_MEDIA_WRITE_PROTECTED => "The media is write protected.",
            ITF::VDS_E_BAD_LABEL => "The label is illegal.",
            ITF::VDS_E_CANT_QUICK_FORMAT => "Can not quick format the volume.",
            ITF::VDS_E_IO_ERROR => "IO error occured during format.",
            ITF::VDS_E_VOLUME_TOO_SMALL => "The volume size is too small.",
            ITF::VDS_E_VOLUME_TOO_BIG => "The volume size is too big.",
            ITF::VDS_E_CLUSTER_SIZE_TOO_SMALL => "The cluster size is too small.",
            ITF::VDS_E_CLUSTER_SIZE_TOO_BIG => "The cluster size is too big.",
            ITF::VDS_E_CLUSTER_COUNT_BEYOND_32BITS => "The number of clusters is too big for 32 bit integer.",
            ITF::VDS_E_OBJECT_STATUS_FAILED => "The object is in failed status.",
            ITF::VDS_E_VOLUME_INCOMPLETE => "All extents for the volume could not be found.",
            ITF::VDS_E_EXTENT_SIZE_LESS_THAN_MIN => "The size of the extent is less than the minimum.",
            ITF::VDS_E_BOOT_PARTITION_NUMBER_CHANGE => "The boot partition's partition number will change as a result of the migration operation.",
            ITF::VDS_E_NO_FREE_SPACE => "The selected disk does not have enough free space to complete the operation.",
            ITF::VDS_E_ACTIVE_PARTITION => "An active partition was detected on the selected disk, and it is not the active partition used to boot the currently running OS.",
            ITF::VDS_E_PARTITION_OF_UNKNOWN_TYPE => "Cannot read partition information.",
            ITF::VDS_E_LEGACY_VOLUME_FORMAT => "A partition with an unknown type was detected on the selected disk.",
            ITF::VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS => "The selected GPT formatted disk contains a partition which is not of type 'PARTITION_BASIC_DATA_GUID', and is both preceeded and followed by a partition of type 'PARTITION_BASIC_DATA_GUID'.",
            ITF::VDS_E_MIGRATE_OPEN_VOLUME => "A volume on the selected disk could not be opened.",
            ITF::VDS_E_VOLUME_NOT_ONLINE => "The volume is not online.",
            ITF::VDS_E_VOLUME_NOT_HEALTHY => "The volume is not healthy.",
            ITF::VDS_E_VOLUME_SPANS_DISKS => "The volume spans multiple disks.",
            ITF::VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE => "The volume requires contiguous disk extents.",
            ITF::VDS_E_BAD_PROVIDER_DATA => "A provider returned bad data.",
            ITF::VDS_E_PROVIDER_FAILURE => "A provider failed to complete an operation.",
            ITF::VDS_E_PACK_OFFLINE => "The pack is not online.",
            ITF::VDS_E_VOLUME_NOT_A_MIRROR => "The volume is not a mirror.",
            ITF::VDS_E_NO_EXTENTS_FOR_VOLUME => "No extents were found for the volume.",
            ITF::VDS_E_DISK_NOT_LOADED_TO_CACHE => "The disk failed to load to the cache.",
            ITF::VDS_E_INTERNAL_ERROR => "Check the event log for errors.",
            ITF::VDS_E_PROVIDER_TYPE_NOT_SUPPORTED => "The method call is not supported for the specified provider type.",
            ITF::VDS_E_DISK_NOT_ONLINE => "This disk is already offline.",
            ITF::VDS_E_DISK_IN_USE_BY_VOLUME => "The disk is already in use by the volume.",
            ITF::VDS_E_ASYNC_OBJECT_FAILURE => "Failure initializing the asynchronous object.",
            ITF::VDS_E_VOLUME_NOT_MOUNTED => "A file system is not mounted on the volume.",
            ITF::VDS_E_PACK_NOT_FOUND => "The pack was not found.",
            ITF::VDS_E_IMPORT_SET_INCOMPLETE => "Import failed. Attempt to import a subset of the disks in the foreign pack.",
            ITF::VDS_E_DISK_NOT_IMPORTED => "A disk in the import's source pack was not imported.",
            ITF::VDS_E_OBJECT_OUT_OF_SYNC => "The system's information about the object may not be up to date.",
            ITF::VDS_E_MISSING_DISK => "The disk is missing.",
            ITF::VDS_E_DISK_PNP_REG_CORRUPT => "The provider's list of Pnp registered disks has become corrupt.",
            ITF::VDS_E_LBN_REMAP_ENABLED_FLAG => "The provider does not support the LBN REMAP ENABLED volume flag.",
            ITF::VDS_E_NO_DRIVELETTER_FLAG => "The provider does not support the NO DRIVELETTER volume flag.",
            ITF::VDS_E_REVERT_ON_CLOSE => "REVERT ON CLOSE may only be used with GPT flags HIDDEN, READ ONLY, NO DRIVE LETTER or SHADOW COPY.",
            ITF::VDS_E_REVERT_ON_CLOSE_SET => "The REVERT ON CLOSE volume flag is already set for this volume.",
            ITF::VDS_E_IA64_BOOT_MIRRORED_TO_MBR => "Not used! You have mirrored your boot volume on a GPT disk, to an MBR disk. You will not be able to boot your machine from the secondary plex.",
            ITF::VDS_E_VOLUME_TEMPORARILY_DISMOUNTED => "The volume is temporarily dismounted.",
            ITF::VDS_E_VOLUME_PERMANENTLY_DISMOUNTED => "The volume is permanently dismounted.",
            ITF::VDS_E_VOLUME_HAS_PATH => "The volume still has access path to it.",
            ITF::VDS_E_TIMEOUT => "The operation timed out.",
            ITF::VDS_E_REPAIR_VOLUMESTATE => "To repair a volume, both the volume and plex must be online, and must not be healthy or rebuilding.",
            ITF::VDS_E_LDM_TIMEOUT => "The operation timed out in the Logical Disk Manager Administrative service. Retry the operation.",
            ITF::VDS_E_REVERT_ON_CLOSE_MISMATCH => "When clearing volume flags that have been set using revert on close, the same combination of HIDDEN, READ ONLY, NO DRIVE LETTER or SHADOW COPY flags must be passed to both the SetFlags and ClearFlags calls.",
            ITF::VDS_E_RETRY => "The operation failed. Retry the operation.",
            ITF::VDS_E_ONLINE_PACK_EXISTS => "Create pack operation failed. An online pack already exists.",
            ITF::VDS_E_EXTEND_FILE_SYSTEM_FAILED => "The file system failed to extend.",
            ITF::VDS_E_MAX_USABLE_MBR => "Only the first 2TB are usable on large MBR disks. Cannot create partitions beyond the 2TB mark, nor convert the disk to dynamic.",
            ITF::VDS_S_GPT_BOOT_MIRRORED_TO_MBR => "You have mirrored your boot volume on a GPT disk, to an MBR disk. You will not be able to boot your machine from the secondary plex.",
            ITF::OLEDB_BINDER_CUSTOM_ERROR => "A custom error (%1) in the OLEDB provider has occurred. %2.",
            ITF::VDS_E_NO_SOFTWARE_PROVIDERS_LOADED => "There are no software provders loaded.",
            ITF::VDS_E_DISK_NOT_MISSING => "The disk is not missing.",
            ITF::VDS_E_NO_VOLUME_LAYOUT => "Failed to retrieve the volume's layout. Operations on the volume will fail.",
            ITF::VDS_E_CORRUPT_VOLUME_INFO => "The volume's driver information is corrupt. Operations on the volume will fail.",
            ITF::VDS_E_INVALID_ENUMERATOR => "The enumerator is corrupted.",
            ITF::VDS_E_DRIVER_INTERNAL_ERROR => "Internal error in the volume management driver.",
            ITF::VDS_E_VOLUME_INVALID_NAME => "The volume name is invalid.",
            ITF::VDS_E_CORRUPT_PARTITION_INFO => "The disk's partition information is corrupted.",
            ITF::VDS_E_CORRUPT_EXTENT_INFO => "The disk's extent information is corrupted.",
            ITF::VDS_E_DUP_EMPTY_PACK_GUID => "An empty pack already exists. Release the existing empty pack before creating another empty pack.",
            ITF::VDS_E_DRIVER_NO_PACK_NAME => "The volume management driver did not return a pack name. Internal driver error.",
            ITF::VDS_E_BAD_PNP_MESSAGE => "The PNP service sent a corrupted notification to the provider.",
            ITF::VDS_E_NO_PNP_DISK_ARRIVE => "No disk arrival notification was received.",
            ITF::VDS_E_NO_PNP_VOLUME_ARRIVE => "No volume arrival notification was received.",
            ITF::VDS_E_NO_PNP_DISK_REMOVE => "No disk removal notification was received.",
            ITF::VDS_E_NO_PNP_VOLUME_REMOVE => "No volume removal notification was received.",
            ITF::VDS_E_PROVIDER_EXITING => "The provider is exiting.",
            ITF::VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE => "The specified disk extent size exceeds the size of free disk space.",
            ITF::VDS_E_MEMBER_SIZE_INVALID => "The size of the plex member is invalid.",
            ITF::VDS_E_INVALID_DISK => "This operation is not allowed on an invalid disk. The disk may be invalid because it is corrupted or failing, or it may be invalid because it is OFFLINE.",
            ITF::VDS_E_INVALID_PACK => "This operation is not allowed on the invalid disk pack.",
            ITF::VDS_E_VOLUME_ON_DISK => "This operation is not allowed on disks with volumes.",
            ITF::VDS_E_DRIVER_INVALID_PARAM => "The driver returned an invalid parameter error.",
            ITF::VDS_E_TARGET_PACK_NOT_EMPTY => "The target pack is not empty.",
            ITF::VDS_E_CANNOT_SHRINK => "The volume cannot be shrunk because the file system does not support it.",
            ITF::VDS_E_MULTIPLE_PACKS => "Specified disks are not all from the same pack.",
            ITF::VDS_E_PACK_ONLINE => "This operation is not allowed on online packs. The pack must be offline.",
            ITF::VDS_E_INVALID_PLEX_COUNT => "The plex count for the volume must be non-zero.",
            ITF::VDS_E_INVALID_MEMBER_COUNT => "The member count for the volume must be non-zero.",
            ITF::VDS_E_INVALID_PLEX_ORDER => "The plex indexes must be monotonically increasing and begin with zero.",
            ITF::VDS_E_INVALID_MEMBER_ORDER => "The member indexes must be monotonically increasing and begin with zero.",
            ITF::VDS_E_INVALID_STRIPE_SIZE => "The stripe size must be a multiple of 2, between 512 bytes and 1 MB, for stripe and raid5 volumes. The stripe size must be zero for other volume types.",
            ITF::VDS_E_INVALID_DISK_COUNT => "The number of disks specified is invalid for this operation.",
            ITF::VDS_E_INVALID_EXTENT_COUNT => "An invalid number of extents was specified for at least one disk.",
            ITF::VDS_E_SOURCE_IS_TARGET_PACK => "The source and target packs must be distinct.",
            ITF::VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED => "The disk count for the volume exceeds the maximum.",
            ITF::VDS_E_CORRUPT_NOTIFICATION_INFO => "The driver's notification info is corrupt.",
            ITF::VDS_E_INVALID_PLEX_GUID => "GUID_NULL is not a valid plex GUID.",
            ITF::VDS_E_DISK_NOT_FOUND_IN_PACK => "The specified disks do not belong to the same pack.",
            ITF::VDS_E_DUPLICATE_DISK => "The same disk was specified more than once.",
            ITF::VDS_E_LAST_VALID_DISK => "The operation cannot be completed because there is only one valid disk in the pack.",
            ITF::VDS_E_INVALID_SECTOR_SIZE => "All disks holding extents for a given volume must have the same sector size, and the sector size must be valid.",
            ITF::VDS_E_ONE_EXTENT_PER_DISK => "This call requires the parameters to specify one extent per disk. A single disk cannot contribute to multiple members or plexes of the same volume.",
            ITF::VDS_E_INVALID_BLOCK_SIZE => "Neither the volume stripe size or disk sector size was found to be non-zero.",
            ITF::VDS_E_PLEX_SIZE_INVALID => "The size of the volume plex is invalid.",
            ITF::VDS_E_NO_EXTENTS_FOR_PLEX => "No extents were found for the plex.",
            ITF::VDS_E_INVALID_PLEX_TYPE => "The plex type is invalid.",
            ITF::VDS_E_INVALID_PLEX_BLOCK_SIZE => "The plex block size must be non-zero.",
            ITF::VDS_E_NO_HEALTHY_DISKS => "All of the disks involved in the operation are either missing or failed.",
            ITF::VDS_E_CONFIG_LIMIT => "The Logical Disk Manangement database is full, no more volumes or disks may be configured.",
            ITF::VDS_E_DISK_CONFIGURATION_CORRUPTED => "The disk configuration data is corrupted.",
            ITF::VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC => "The disk configuration is not insync with the in-memory configuration.",
            ITF::VDS_E_DISK_CONFIGURATION_UPDATE_FAILED => "One or more disks failed to be updated with the new configuration.",
            ITF::VDS_E_DISK_DYNAMIC => "The disk is already dynamic.",
            ITF::VDS_E_DRIVER_OBJECT_NOT_FOUND => "The object was not found in the driver cache.",
            ITF::VDS_E_PARTITION_NOT_CYLINDER_ALIGNED => "The disk layout contains partitions which are not cylinder aligned.",
            ITF::VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL => "The disk layout contains partitions which less than the minimum required size.",
            ITF::VDS_E_DISK_IO_FAILING => "The IO to the disk is failing.",
            ITF::VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED => "Dynamic disks are not supported by this operating system or server configuration. Dynamic disks are not supported on clusters.",
            ITF::VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED => "The fault tolerant disks are not supported by this operating system.",
            ITF::VDS_E_GPT_ATTRIBUTES_INVALID => "Invalid GPT attributes were specified.",
            ITF::VDS_E_MEMBER_IS_HEALTHY => "The member is not stale or detached.",
            ITF::VDS_E_MEMBER_REGENERATING => "The member is regenerating.",
            ITF::VDS_E_PACK_NAME_INVALID => "The pack name is invalid.",
            ITF::VDS_E_PLEX_IS_HEALTHY => "The plex is not stale or detached.",
            ITF::VDS_E_PLEX_LAST_ACTIVE => "The last healthy plex cannot be removed.",
            ITF::VDS_E_PLEX_MISSING => "The plex is missing.",
            ITF::VDS_E_MEMBER_MISSING => "The member is missing.",
            ITF::VDS_E_PLEX_REGENERATING => "The plex is regenerating.",
            ITF::VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE => "An unexpected layout change occurred external to the volume manager.",
            ITF::VDS_E_INVALID_VOLUME_LENGTH => "The volume length is invalid.",
            ITF::VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE => "The volume length is not a multiple of the sector size.",
            ITF::VDS_E_VOLUME_NOT_RETAINED => "The volume does not have a retained partition association.",
            ITF::VDS_E_VOLUME_RETAINED => "The volume already has a retained partition association.",
            ITF::VDS_E_ALIGN_BEYOND_FIRST_CYLINDER => "The specified alignment is beyond the first cylinder.",
            ITF::VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE => "The specified alignment is not a multiple of the sector size.",
            ITF::VDS_E_ALIGN_NOT_ZERO => "The specified partition type cannot be created with a non-zero alignment.",
            ITF::VDS_E_CACHE_CORRUPT => "The service's cache has become corrupt.",
            ITF::VDS_E_CANNOT_CLEAR_VOLUME_FLAG => "The specified volume flag cannot be cleared.",
            ITF::VDS_E_DISK_BEING_CLEANED => "The operation is not allowed on a disk that is in the process of being cleaned.",
            ITF::VDS_E_DISK_NOT_CONVERTIBLE => "The specified disk is not convertible. CDROMs and DVDs are examples of disks that are not convertable.",
            ITF::VDS_E_DISK_REMOVEABLE => "The operation is not supported on removable media.",
            ITF::VDS_E_DISK_REMOVEABLE_NOT_EMPTY => "The operation is not supported on a non-empty removable disk.",
            ITF::VDS_E_DRIVE_LETTER_NOT_FREE => "The specified drive letter is not free to be assigned.",
            ITF::VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED => "Extending the volume onto multiple disks is not supported by this provider.",
            ITF::VDS_E_INVALID_DRIVE_LETTER => "The specified drive letter is invalid.",
            ITF::VDS_E_INVALID_DRIVE_LETTER_COUNT => "The specified number of drive letters to retrieve is invalid.",
            ITF::VDS_E_INVALID_FS_FLAG => "The specified file system flag is invalid.",
            ITF::VDS_E_INVALID_FS_TYPE => "The specified file system is invalid.",
            ITF::VDS_E_INVALID_OBJECT_TYPE => "The specified object type is invalid.",
            ITF::VDS_E_INVALID_PARTITION_LAYOUT => "The specified partition layout is invalid.",
            ITF::VDS_E_INVALID_PARTITION_STYLE => "The specified disk's partition style is INVALID. VDS only supports MBR or GPT partition style disks.",
            ITF::VDS_E_INVALID_PARTITION_TYPE => "The specified partition type is not valid for this operation.",
            ITF::VDS_E_INVALID_PROVIDER_CLSID => "The specified provider clsid cannot be a NULL GUID.",
            ITF::VDS_E_INVALID_PROVIDER_ID => "The specified provider id cannot be a NULL GUID.",
            ITF::VDS_E_INVALID_PROVIDER_NAME => "The specified provider name is invalid.",
            ITF::VDS_E_INVALID_PROVIDER_TYPE => "The specified provider type is invalid.",
            ITF::VDS_E_INVALID_PROVIDER_VERSION_GUID => "The specified provider version GUID cannot be a NULL GUID.",
            ITF::VDS_E_INVALID_PROVIDER_VERSION_STRING => "The specified provider version string is invalid.",
            ITF::VDS_E_INVALID_QUERY_PROVIDER_FLAG => "The specified query provider flag is invalid.",
            ITF::VDS_E_INVALID_SERVICE_FLAG => "The specified service flag is invalid.",
            ITF::VDS_E_INVALID_VOLUME_FLAG => "The specified volume flag is invalid.",
            ITF::VDS_E_PARTITION_NOT_OEM => "The operation is not supported on non-OEM partitions.",
            ITF::VDS_E_PARTITION_PROTECTED => "Cannot delete a protected partition without the force protected parameter set.",
            ITF::VDS_E_PARTITION_STYLE_MISMATCH => "The specified partition style does not match that of the disk.",
            ITF::VDS_E_PROVIDER_INTERNAL_ERROR => "An internal error has occurred in the provider.",
            ITF::VDS_E_SHRINK_SIZE_LESS_THAN_MIN => "The specified shrink size is less than then minimum shrink size allowed.",
            ITF::VDS_E_SHRINK_SIZE_TOO_BIG => "The specified shrink size is too big and will cause the volume to be smaller than the minimum volume size.",
            ITF::VDS_E_UNRECOVERABLE_PROVIDER_ERROR => "An unrecoverable error occurred in a provider. The service must be shut down to regain full functionality.",
            ITF::VDS_E_VOLUME_HIDDEN => "Cannot assign a mount point to a hidden volume.",
            ITF::VDS_E_FLAG_ALREADY_SET => "Can't set the specified flag as revert-on-close, because it is already set.",
            ITF::VDS_E_DISTINCT_VOLUME => "The input volume id cannot be the id of the volume that is the target of the operation.",
            ITF::VDS_E_VOLUME_NOT_FOUND_IN_PACK => "The specified volumes do not belong to the same pack.",
            ITF::VDS_E_PARTITION_NON_DATA => "The specified partition is a not a primary or logical volume.",
            ITF::VDS_E_CRITICAL_PLEX => "The specified plex is a the current system or boot plex.",
            ITF::VDS_E_VOLUME_SYNCHRONIZING => "The operation cannot be completed because the volume is synchronizing.",
            ITF::VDS_E_VOLUME_REGENERATING => "The operation cannot be completed because the volume is regenerating.",
            ITF::VDS_E_READONLY => "The volume is read only.",
            ITF::VDS_E_INVALID_VOLUME_TYPE => "The volume type is invalid for this operation.",
            ITF::VDS_E_BAD_BOOT_DISK => "The boot disk experienced failures when the driver attempted to online the pack.",
            ITF::VDS_E_LOG_UPDATE => "The driver failed to update the log on at least one disk.",
            ITF::VDS_E_VOLUME_MIRRORED => "This operation is not supported on a mirrored volume.",
            ITF::VDS_E_VOLUME_SIMPLE_SPANNED => "This operation is only supported on simple or spanned volumes.",
            ITF::VDS_E_NO_VALID_LOG_COPIES => "This pack has no valid log copies.",
            ITF::VDS_E_PLEX_NOT_LOADED_TO_CACHE => "This plex is present in the driver, but has not yet been loaded to the provider cache. A volume modified notification will be sent by the service once the plex has been loaded to the provider cache.",
            ITF::VDS_E_PARTITION_MSR => "This operation is not supported on MSR partitions.",
            ITF::VDS_E_PARTITION_LDM => "This operation is not supported on LDM partitions.",
            ITF::VDS_E_ALIGN_NOT_A_POWER_OF_TWO => "The specified alignment is not a power of two.",
            ITF::VDS_E_ALIGN_IS_ZERO => "The specified alignment is zero.",
            ITF::VDS_E_SHRINK_IN_PROGRESS => "A defragmentation or volume shrink operation is already in progress. Only one of these operations can run at a time.",
            ITF::VDS_E_CANT_INVALIDATE_FVE => "BitLocker encryption on the volume could not be removed.",
            ITF::VDS_E_FS_NOT_DETERMINED => "The default file system could not be determined.",
            ITF::VDS_E_DISK_NOT_OFFLINE => "This disk is already online.",
            ITF::VDS_E_FAILED_TO_ONLINE_DISK => "The online operation failed.",
            ITF::VDS_E_FAILED_TO_OFFLINE_DISK => "The offline operation failed.",
            ITF::VDS_E_BAD_REVISION_NUMBER => "The operation could not be completed because the specified revision number is not supported.",
            ITF::VDS_E_SHRINK_USER_CANCELLED => "The shrink operation was cancelled by the user.",
            ITF::VDS_E_SHRINK_DIRTY_VOLUME => "The volume you have selected to shrink may be corrupted. Use Chkdsk to fix the corruption problem, and then try to shrink the volume again.",
            ITF::NOTESPH_E_UNEXPECTED_STATE => "An unexpected error occurred in the Notes protocol handler while processing the URL.",
            ITF::NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE => "Only rich text, HTML, and text types are supported for the content field.",
            ITF::NOTESPH_E_ITEM_NOT_FOUND => "A requested item is not found.",
            ITF::NOTESPH_E_SERVER_CONFIG => "The Notes data cannot be accessed. Check that the server is properly configured for accessing Notes data.",
            ITF::NOTESPH_E_ATTACHMENTS => "One or more attachments cannot be processed.",
            ITF::NOTESPH_E_NO_NTID => "The Windows NT identity does not exist.",
            ITF::NOTESPH_E_DB_ACCESS_DENIED => "Access to %1 is denied to user %1. To allow access, contact your Notes administrator.",
            ITF::NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR => "The user name mapping cannot be read. Check that the database, view, and column names are correct, that the Notes database is accessible, and that the sort option is enabled. For more information, see the Administrator's Guide.",
            ITF::NOTESPH_E_FAIL => "Unknown Lotus Notes Error: %1.",
            ITF::STS_ABORTXMLPARSE => "Stop Parsing XML.",
            ITF::STS_WS_ERROR => "Error in the Site Data Web Service.",
            ITF::SPS_WS_ERROR => "Error in PortalCrawl Web Service.",
            ITF::EXSTOREPH_E_UNEXPECTED => "An unexpected error occurred in the exstore protocol handler. Contact Microsoft Product Support.",
            ITF::VDS_E_NAME_NOT_UNIQUE => "The name is not unique.",
            ITF::VDS_E_ADDRESSES_INCOMPLETELY_SET => "At least one portal's tunnel address is not set successfully.",
            ITF::VDS_E_SECURITY_INCOMPLETELY_SET => "At least one portal's security settings are not set successfully.",
            ITF::VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED => "The initiator does not support setting target-specific shared secrets.",
            ITF::VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED => "The target does not support setting initiator-specific shared secrets.",
            ITF::VDS_E_ISCSI_LOGIN_FAILED => "An iSCSI login session could not be established.",
            ITF::VDS_E_ISCSI_LOGOUT_FAILED => "The attempt to log out from the specified iSCSI session failed.",
            ITF::VDS_E_ISCSI_SESSION_NOT_FOUND => "The specified iSCSI session with a connection matching the specified target, target portal, and/or initiator portal could not be found.",
            ITF::VDS_E_ASSOCIATED_LUNS_EXIST => "LUNs are associated with the specified target and must first be deassociated before the target can be deleted.",
            ITF::VDS_E_ASSOCIATED_PORTALS_EXIST => "Portals are associated with the specified portal group and must first be deassociated before the portal group can be deleted.",
            ITF::VDS_E_NO_DISCOVERY_DOMAIN => "The initiator does not exist in a iSNS discovery domain.",
            ITF::VDS_E_MULTIPLE_DISCOVERY_DOMAINS => "The initiator exists in more than one iSNS discovery domain.",
            ITF::VDS_E_NO_DISK_PATHNAME => "Failed to retrieve the disk's pathname. Some operations on the disk may fail.",
            ITF::VDS_E_ISCSI_LOGOUT_INCOMPLETE => "At least one session did not logout successfully.",
            ITF::VDS_E_NO_VOLUME_PATHNAME => "Failed to retrieve the volume's pathname.",
            ITF::VDS_E_PROVIDER_CACHE_OUTOFSYNC => "The provider's cache is not in-sync with the driver cache.",
            ITF::VDS_E_NO_IMPORT_TARGET => "No import target was set for this subsystem in the registry.",
            ITF::CERT_E_NOT_FOUND_OR_NO_PERMISSSION => "Cannot find or access the client certificate specified for crawling this site.",
            ITF::VDS_E_UNABLE_TO_FIND_BOOT_DISK => "A system error occurred while retrieving the boot disk information.",
            ITF::VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO => "Multiple disk extents reported for the boot volume - system error.",
            ITF::VDS_E_GET_SAN_POLICY => "A driver error was reported when getting the SAN policy.",
            ITF::VDS_E_SET_SAN_POLICY => "A driver error was reported when setting the SAN policy.",
            ITF::VDS_E_BOOT_DISK => "Disk attributes may not be changed on the boot disk.",
            ITF::VDS_E_DISK_IS_OFFLINE => "The operation is not allowed on a disk that is offline.",
            ITF::VDS_E_DISK_IS_READ_ONLY => "The operation is not allowed on a disk that is read only.",
            ITF::VDS_E_PAGEFILE_DISK => "The operation is not allowed on a disk that contains a pagefile volume.",
            ITF::VDS_E_HIBERNATION_FILE_DISK => "The operation is not allowed on a disk that contains a hibernation file volume.",
            ITF::VDS_E_CRASHDUMP_DISK => "The operation is not allowed on a disk that contains a crashdump file volume.",
            ITF::VDS_E_UNABLE_TO_FIND_SYSTEM_DISK => "A system error occurred while retrieving the system disk information.",
            ITF::VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO => "Multiple disk extents reported for the system volume - system error.",
            ITF::VDS_E_SYSTEM_DISK => "Disk attributes may not be changed on the current system disk or BIOS disk 0.",
            ITF::VDS_E_VOLUME_SHRINK_FVE_LOCKED => "The volume could not be shrunk because it is locked by BitLocker. Unlock the volume and try again.",
            ITF::VDS_E_VOLUME_SHRINK_FVE_CORRUPT => "The volume could not be shrunk because it is locked due to a BitLocker error. Use BitLocker tools to recover the volume and try again.",
            ITF::VDS_E_VOLUME_SHRINK_FVE_RECOVERY => "The volume could not be shrunk because it is marked for BitLocker recovery. Use BitLocker tools to recover the volume and try again.",
            ITF::VDS_E_VOLUME_SHRINK_FVE => "The volume could not be shrunk because it is encrypted by BitLocker and Fveapi.dll could not be loaded to determine its status. For this operation to succeed, Fveapi.dll must be available in %SystemRoot%\System32\.",
            ITF::VDS_E_SHRINK_OVER_DATA => "The SHRINK operation against the selected LUN cannot be completed. Completing the operation using the specified parameters will overwrite volumes containing user data.",
            ITF::VDS_E_INVALID_SHRINK_SIZE => "The SHRINK operation against the selected LUN cannot be completed. The specified size is greater than the size of the LUN.",
            ITF::VDS_E_LUN_DISK_MISSING => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is MISSING.",
            ITF::VDS_E_LUN_DISK_FAILED => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is FAILED.",
            ITF::VDS_E_LUN_DISK_NOT_READY => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is NOT READY.",
            ITF::VDS_E_LUN_DISK_NO_MEDIA => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is NO MEDIA.",
            ITF::VDS_E_LUN_NOT_READY => "The SHRINK operation against the selected LUN cannot be completed. The current state of the LUN is NOT READY.",
            ITF::VDS_E_LUN_OFFLINE => "The SHRINK operation against the selected LUN cannot be completed. The current state of the LUN is OFFLINE.",
            ITF::VDS_E_LUN_FAILED => "The SHRINK operation against the selected LUN cannot be completed. The current state of the LUN is FAILED.",
            ITF::VDS_E_VOLUME_EXTEND_FVE_LOCKED => "The volume could not be extended because it is locked by BitLocker. Unlock the volume and retry the operation.",
            ITF::VDS_E_VOLUME_EXTEND_FVE_CORRUPT => "The volume could not be extended because it is locked due to a BitLocker error. Use BitLocker tools to recover the volume and retry the operation.",
            ITF::VDS_E_VOLUME_EXTEND_FVE_RECOVERY => "The volume could not be extended because it is marked for BitLocker recovery. Use BitLocker tools to recover the volume and retry the operation.",
            ITF::VDS_E_VOLUME_EXTEND_FVE => "The volume could not be extended because it is encrypted by BitLocker and Fveapi.dll could not be loaded to determine its status. For this operation to succeed, Fveapi.dll must be available in %SystemRoot%\System32\.",
            ITF::VDS_E_SECTOR_SIZE_ERROR => "The sector size must be non-zero, a power of 2, and less than the maximum sector size.",
            ITF::VDS_E_INITIATOR_ADAPTER_NOT_FOUND => "The initiator adapter was not found. For calls to GetPathInfo(), the initiator adapater is associated with the path end point.",
            ITF::VDS_E_TARGET_PORTAL_NOT_FOUND => "The target portal was not found. For calls to GetPathInfo(), the target portal is associated with the path end point.",
            ITF::VDS_E_INVALID_PORT_PATH => "The path returned for the port is invalid. Either it has an incorrect port type specified, or, the HBA port properties structure is NULL.",
            ITF::VDS_E_INVALID_ISCSI_TARGET_NAME => "An invalid iSCSI target name was returned from the provider.",
            ITF::VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS => "Call to set the iSCSI tunnel mode outer address failed.",
            ITF::VDS_E_ISCSI_GET_IKE_INFO => "Call to get the iSCSI IKE info failed.",
            ITF::VDS_E_ISCSI_SET_IKE_INFO => "Call to set the iSCSI IKE info failed.",
            ITF::VDS_E_SUBSYSTEM_ID_IS_NULL => "The provider returned a NULL subsystem identification string.",
            ITF::VDS_E_ISCSI_INITIATOR_NODE_NAME => "Failed to get the iSCSI initiator node name.",
            ITF::VDS_E_ISCSI_GROUP_PRESHARE_KEY => "Failed to set iSCSI group preshared key.",
            ITF::VDS_E_ISCSI_CHAP_SECRET => "Failed to set iSCSI initiator CHAP secret.",
            ITF::VDS_E_INVALID_IP_ADDRESS => "An invalid IP address was encountered.",
            ITF::VDS_E_REBOOT_REQUIRED => "A reboot is required before any further operations may be initiated. If you do not reboot, machine behavior and machine state, are undefined for any further operations.",
            ITF::VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED => "Volume GUID pathnames are not valid input to this method.",
            ITF::VDS_E_BOOT_PAGEFILE_DRIVE_LETTER => "Assigning or removing drive letters on the current boot or pagefile volume is not allowed.",
            ITF::VDS_E_DELETE_WITH_CRITICAL => "Delete is not allowed on the current boot, system, pagefile, crashdump or hibernation volume.",
            ITF::VDS_E_CLEAN_WITH_DATA => "The FORCE parameter must be set to TRUE in order to clean a disk that contains a data volume.",
            ITF::VDS_E_CLEAN_WITH_OEM => "The FORCE parameter must be set to TRUE in order to clean a disk that contains an OEM volume.",
            ITF::VDS_E_CLEAN_WITH_CRITICAL => "Clean is not allowed on the disk containing the current boot, system, pagefile, crashdump or hibernation volume.",
            ITF::VDS_E_FORMAT_CRITICAL => "Format is not allowed on the current boot, system, pagefile, crashdump or hibernation volume.",
            ITF::VDS_E_NTFS_FORMAT_NOT_SUPPORTED => "The NTFS file system format is not supported on this volume.",
            ITF::VDS_E_FAT32_FORMAT_NOT_SUPPORTED => "The FAT32 file system format is not supported on this volume.",
            ITF::VDS_E_FAT_FORMAT_NOT_SUPPORTED => "The FAT file system format is not supported on this volume.",
            ITF::VDS_E_FORMAT_NOT_SUPPORTED => "The volume is not formattable.",
            ITF::VDS_E_COMPRESSION_NOT_SUPPORTED => "The specified file system does not support compression.",
            ITF::VDS_E_VDISK_NOT_OPEN => "The virtual disk object has not been open yet.",
            ITF::VDS_E_VDISK_INVALID_OP_STATE => "The requested operation cannot be performed on the virtual disk object, because it is not in a state that permits it.",
            ITF::VDS_E_INVALID_PATH => "The path returned for the LUN is invalid. It has an incorrect path type specified.",
            ITF::VDS_E_INVALID_ISCSI_PATH => "The path returned for the LUN is invalid. Either it has an incorrect path type specified, or, the initiator portal properties structure is NULL.",
            ITF::VDS_E_SHRINK_LUN_NOT_UNMASKED => "The SHRINK operation against the selected LUN cannot be completed. The LUN is not unmasked to the local server.",
            ITF::VDS_E_LUN_DISK_READ_ONLY => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is READ ONLY.",
            ITF::VDS_E_LUN_UPDATE_DISK => "The operation against the selected LUN completed, but there was a failure updating the status of the disk associated with the lun. Call REFRESH to retry the status update for the disk.",
            ITF::VDS_E_LUN_DYNAMIC => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is DYNAMIC.",
            ITF::VDS_E_LUN_DYNAMIC_OFFLINE => "The SHRINK operation against the selected LUN cannot be completed. The current state of the disk associated with the LUN is DYNAMIC OFFLINE.",
            ITF::VDS_E_LUN_SHRINK_GPT_HEADER => "The SHRINK operation against the selected LUN cannot be completed. The disk has the GPT partitioning format. The specified new lun size does not allow space for a new GPT backup header to be created. Please increase the resulting lun size.",
            ITF::VDS_E_MIRROR_NOT_SUPPORTED => "Mirrored volumes are not supported by this operating system.",
            ITF::VDS_E_RAID5_NOT_SUPPORTED => "RAID-5 volumes are not supported by this operating system.",
            ITF::VDS_E_DISK_NOT_CONVERTIBLE_SIZE => "The specified disk is not convertible because the size is less than the minimum size required for GPT disks.",
            ITF::VDS_E_OFFLINE_NOT_SUPPORTED => "The volume does not support offlining.",
            ITF::VDS_E_VDISK_PATHNAME_INVALID => "The pathname for a virtual disk must be fully qualified.",
            ITF::VDS_E_EXTEND_TOO_MANY_CLUSTERS => "The volume cannot be extended because the number of clusters will exceed the maximum number of clusters supported by the file system.",
            ITF::VDS_E_EXTEND_UNKNOWN_FILESYSTEM => "The volume cannot be extended because the volume does not contain a recognized file system.",
            ITF::VDS_E_SHRINK_UNKNOWN_FILESYSTEM => "The volume cannot be shrunk because the volume does not contain a recognized file system.",
            ITF::VDS_E_VD_DISK_NOT_OPEN => "The requested operation requires that the virtual disk be opened.",
            ITF::VDS_E_VD_DISK_IS_EXPANDING => "The requested operation cannot be performed while the virtual disk is expanding.",
            ITF::VDS_E_VD_DISK_IS_COMPACTING => "The requested operation cannot be performed while the virtual disk is compacting.",
            ITF::VDS_E_VD_DISK_IS_MERGING => "The requested operation cannot be performed while the virtual disk is merging.",
            ITF::VDS_E_VD_IS_ATTACHED => "The requested operation cannot be performed while the virtual disk is attached.",
            ITF::VDS_E_VD_DISK_ALREADY_OPEN => "The virtual disk is already open and cannot be opened a second time. Please close all clients that may have opened the virtual disk and retry.",
            ITF::VDS_E_VD_DISK_ALREADY_EXPANDING => "The virtual disk is already in the process of expanding.",
            ITF::VDS_E_VD_ALREADY_COMPACTING => "The virtual disk is already in the process of compacting.",
            ITF::VDS_E_VD_ALREADY_MERGING => "The virtual disk is already in the process of merging.",
            ITF::VDS_E_VD_ALREADY_ATTACHED => "The virtual disk is already attached.",
            ITF::VDS_E_VD_ALREADY_DETACHED => "The virtual disk is already detached.",
            ITF::VDS_E_VD_NOT_ATTACHED_READONLY => "The requested operation requires that the virtual disk be attached read only.",
            ITF::VDS_E_VD_IS_BEING_ATTACHED => "The requested operation cannot be performed while the virtual disk is being attached.",
            ITF::VDS_E_VD_IS_BEING_DETACHED => "The requested operation cannot be performed while the virtual disk is being detached.",
            ITF::VDS_E_NO_POOL => "The drive is not contained in a pool.",
            ITF::VDS_E_NO_POOL_CREATED => "No pool is created.",
            ITF::VDS_E_NO_MAINTENANCE_MODE => "The specified disk or volume is managed by the Microsoft Failover Clustering component. The disk must be in cluster maintenance mode and the cluster resource status must be online to perform this operation.",
            ITF::VDS_E_BLOCK_CLUSTERED => "The specified disk or volume is managed by Microsoft Failover Clustering. The disk must be removed from the cluster to perform this operation.",
            ITF::VDS_E_DISK_HAS_BANDS => "The disk could not be converted to dynamic because security is enabled on one or more partitions.",
            ITF::VDS_E_INVALID_STATE => "The requested operation cannot be performed on the object, because it is not in a state that permits it. Call Refresh and retry the operation.",
            ITF::VDS_E_REFS_FORMAT_NOT_SUPPORTED => "The ReFS file system format is not supported on this volume.",
            ITF::VDS_E_DELETE_WITH_BOOTBACKING => "Delete is not allowed on the volume that backs your Windows boot volume.",
            ITF::VDS_E_FORMAT_WITH_BOOTBACKING => "Format is not allowed on the volume that backs your Windows boot volume.",
            ITF::VDS_E_CLEAN_WITH_BOOTBACKING => "Clean is not allowed on the disk containing volume that backs your Windows boot volume.",
            ITF::SRCH_SCHEMA_CACHE_E_UNEXPECTED => "An unexpected error occurred in the in-memory schema cache.",
            ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_READ => "The property mapping information on the content source cannot be read.",
            ITF::CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER => "The content source information code contains unexpected null pointers.",
            ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE => "Parallel vectors for property mapping information on the content source have different dimensions.",
            ITF::CONTENT_SOURCE_E_CONTENT_CLASS_READ => "The content class information for the content source cannot be read.",
            ITF::CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION => "An unexpected exception occurred in the content source information code.",
            ITF::CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR => "The content class of the content source is empty.",
            ITF::CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE => "An unknown data type was found when reading content class information from the content source.",
            ITF::CONTENT_SOURCE_E_OUT_OF_RANGE => "A request for property mapping information is out of range.",
            ITF::CONTENT_SOURCE_E_NULL_URI => "Empty or null URIs are not valid as property mapping.",
            ITF::REXSPH_E_INVALID_CALL => "This is an internal error code. A method was called when it should not be. Call Microsoft Product Support.",
            ITF::REXSPH_E_REDIRECT_ON_SECURITY_UPDATE => "A security update was attempted on an address that was redirected to a different server.",
            ITF::REXSPH_E_MULTIPLE_REDIRECT => "An address was redirected more than once.",
            ITF::REXSPH_E_NO_PROPERTY_ON_ROW => "The requested property does not exist on the row.",
            ITF::REXSPH_E_TYPE_MISMATCH_ON_READ => "The requested read type does not match the data type.",
            ITF::REXSPH_E_UNEXPECTED_DATA_STATUS => "The status of the request data is unexpected. Call Microsoft Product Support.",
            ITF::REXSPH_E_UNKNOWN_DATA_TYPE => "An unknown data type was found. Call Microsoft Product Support.",
            ITF::REXSPH_E_UNEXPECTED_FILTER_STATE => "An unexpected filter state occurred. Call Microsoft Product Support.",
            ITF::REXSPH_E_DUPLICATE_PROPERTY => "A duplicate property was found. Call Microsoft support if this error is encountered.",
            ITF::FTE_E_SECRET_NOT_FOUND => "The account password was not specified. Specify the password.",
            ITF::FTE_E_PIPE_NOT_CONNECTED => "The named pipe used to communicate with the filter daemon has not been connected.",
            ITF::FTE_E_ADMIN_BLOB_CORRUPT => "The configuration data given to the MSFTESQL service is corrupt.",
            ITF::FTE_E_FILTER_SINGLE_THREADED => "The system attempted to load an apartment threading model filter marked in a multi-threaded filter daemon. The document will be retried in a single-threaded filter daemon process. Since multithreaded filtering is more efficient, try to obtain the version of the filter that is multi-threaded.",
            ITF::FTE_E_ERROR_WRITING_REGISTRY => "The value cannot be set, because the object was already deleted or was not initialized properly. Make sure the object reference is still valid, increase the registry size, or recreate the catalog configuration.",
            ITF::FTE_E_PROJECT_SHUTDOWN => "An internal interface is being used after the corresponding catalog has been shutdown. The operation will be aborted.",
            ITF::FTE_E_PROJECT_NOT_INITALIZED => "An internal interface is being used prior to being initialized. The operation will be aborted.",
            ITF::FTE_E_PIPE_DATA_CORRUPTED => "Data transferred between the MSFTESQL service and a filter daemon process is corrupted. This is an internal error.",
            ITF::FTE_E_URB_TOO_BIG => "This is an internal error: The URB has exceeded the maximum size.",
            ITF::FTE_E_INVALID_DOCID => "This is an internal error: Document IDs should be greater than 0 and less than or equal to 0x7fffffff.",
            ITF::FTE_E_PAUSE_EXTERNAL => "An external status change has put the catalog in a paused state.",
            ITF::FTE_E_REJECTED_DUE_TO_PROJECT_STATUS => "A status change is occurring or the project is in a force paused state, so MSFTESQL cannot accept input at this time.",
            ITF::FTE_E_FD_DID_NOT_CONNECT => "The MSFTEFD process was launched but did not connect with the MSFTESQL service.",
            ITF::FTE_E_PROGID_REQUIRED => "This is an internal error: Initialization of the datasink is incorrect. At least one protocol handler PROGID is required.",
            ITF::FTE_E_STATIC_THREAD_INVALID_ARGUMENTS => "This is an internal error: A static thread has gotten invalid arguments and will force batches to be aborted and retried.",
            ITF::FTE_E_CATALOG_ALREADY_EXISTS => "A catalog already exists with this name, so another can be created or mounted.",
            ITF::FTE_E_PATH_TOO_LONG => "A file path exceeds the maximum limit for paths in Windows, so it can't be used.",
            ITF::FTE_INVALID_ADMIN_CLIENT => "Access is denied to the caller of this administration interface.",
            ITF::FTE_E_COM_SIGNATURE_VALIDATION => "Signature validation cannot be performed on modules loaded by COM, so the object will not be created. The object is likely a filter, wordbreaker, stemmer, or protocol handler.",
            ITF::FTE_E_AFFINITY_MASK => "The processor affinity mask is invalid.",
            ITF::FTE_E_FD_OWNERSHIP_OBSOLETE => "This is an internal error that should be handled. The FD has been killed and this chunk buffer has already been reassigned.",
            ITF::FTE_E_EXCEEDED_MAX_PLUGINS => "The maximum number of plug-ins has been exceeded, so a new plug-in can't be loaded.",
            ITF::FTE_E_DUPLICATE_OBJECT => "An object could not be inserted because it was a duplicate of an existing object. The object may be a catalog or other named entity.",
            ITF::FTE_E_REDUNDANT_TRAN_FAILURE => "The transaction that superseded this one ended in error.",
            ITF::FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST => "The transaction that superseded this one ended in error.",
            ITF::FTE_E_FD_SHUTDOWN => "This is an internal error: This request cannot be completed because the Filter Daemon has been shutdown.",
            ITF::FTE_E_CATALOG_DOES_NOT_EXIST => "The catalog does not exist, so the operation can't be performed.",
            ITF::FTE_E_NO_PLUGINS => "There are no plug-in components in the indexing pipeline, so the data collected will not be used.",
            ITF::FTE_E_BATCH_ABORTED => "Processing of this batch of transactions has been aborted.",
            ITF::FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE => "A status change is active on another thread. Since only one status change is allowed at a time this request can't be handled.",
            ITF::FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS => "A previous error prevented further processing of the batch.",
            ITF::FTE_E_FD_TIMEOUT => "The filter daemon process MSFTEFD timed out for an unknown reason. This may indicate a bug in a filter, wordbreaker, or protocol handler.",
            ITF::FTE_E_RESOURCE_SHUTDOWN => "This is an internal error: This activity is no longer valid because the resource is shutdown.",
            ITF::FTE_E_INVALID_PROPERTY => "The property specified is invalid.",
            ITF::FTE_E_NO_MORE_PROPERTIES => "There are no more properties.",
            ITF::FTE_E_UNKNOWN_PLUGIN => "The plug-in specified is not known likely because it isn't loaded, so the operation can't succeed. Only specify plug-ins that are loaded.",
            ITF::FTE_E_LIBRARY_NOT_LOADED => "The performance monitor library could not be loaded.",
            ITF::FTE_E_PERFMON_FULL => "There are no more slots available for this performance monitor instance.",
            ITF::FTE_E_FAILED_TO_CREATE_ACCESSOR => "The filter daemon process MSFTEFD was not able to create an accessor object for the batch.",
            ITF::FTE_E_INVALID_TYPE => "The property type specified is incorrect for this property. Please see the product documentation for the correct data type for this property.",
            ITF::FTE_E_OUT_OF_RANGE => "The value specified is out of range. Please see the product documentation for the valid range.",
            ITF::FTE_E_CORRUPT_PROPERTY_STORE => "The property store for upgrade is corrupted.",
            ITF::FTE_E_PROPERTY_STORE_WORKID_NOTVALID => "The workid is not valid for the property store.",
            ITF::FTE_E_CORRUPT_GATHERER_HASH_MAP => "The gatherer hash map for upgrade is corrupted.",
            ITF::FTE_E_KEY_NOT_CACHED => "The key is not cached in the property store.",
            ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN => "The upgrade interface has already been shutdown.",
            ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED => "The upgrade interface has already been instantiated. Only one instance of the upgrade interface is allowed.",
            ITF::FTE_E_STACK_CORRUPTED => "The stack for a thread in this process is corrupted due to a programming bug. This may be a security threat and indicate your system has been attacked. The process will be shutdown.",
            ITF::FTE_E_INVALID_PROG_ID => "The protocol handler index passed to the OnDataChange function is invalid.",
            ITF::FTE_E_SERIAL_STREAM_CORRUPT => "The serial stream being indexed is corrupted.",
            ITF::FTE_E_READONLY_CATALOG => "The catalog is opened for read-only operations. Writing is prohibited to this catalog.",
            ITF::FTE_E_PERF_NOT_LOADED => "The performance monitor counters cannot be unloaded because they are not loaded in the first place.",
            ITF::FTE_E_RETRY_HUGE_DOC => "This huge document will be retried in dedicated filter daemon MSFTEFD process.",
            ITF::FTE_E_UNKNOWN_FD_TYPE => "This is an internal error: The filter daemon MSFTEFD type is unknown or invalid.",
            ITF::FTE_E_DOC_TOO_HUGE => "There are not enough resources to process the document or row.",
            ITF::FTE_E_DATATYPE_MISALIGNMENT => "This is an internal error: Datatype misalignment was detected likely due to a programming error.",
            ITF::FTE_E_ALREADY_INITIALIZED => "The object is already initialized.",
            ITF::FTE_E_FD_USED_TOO_MUCH_MEMORY => "The filter daemon process MSFTEFD used too much memory and will be terminated.",
            ITF::FTE_E_UNEXPECTED_EXIT => "The MSFTESQL service process exited unexpectedly. Here is the stack Trace: %1.",
            ITF::FTE_E_HIGH_MEMORY_PRESSURE => "High memory pressure was detected by the MSFTESQL memory manager.",
            ITF::FTE_E_INVALID_ISOLATE_ERROR_BATCH => "A batch flagged to isolate a previous error had too many transactions in it.",
            ITF::FTE_E_RETRY_SINGLE_DOC_PER_BATCH => "msftesql should reprocess this document in an isolated fashion to confirm the error.",
            ITF::FTE_E_INVALID_PROJECT_ID => "An internal identifier for naming catalogs has been corrupted.",
            ITF::FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS => "A failure occurred when tracking the completion of wordlists which will cause current activity to be aborted.",
            ITF::FTE_E_INVALID_CODEPAGE => "The specified code page is not installed or not available.",
            ITF::FTE_E_FD_IDLE => "Internal Error Code: Filter Daemon is terminated because it is idle.",
            ITF::FTE_E_FD_UNRESPONSIVE => "Filter Daemon was unresponsive to a directive to shut itself down.",
            ITF::WCN_E_PEER_NOT_FOUND => "Windows Connect Now: The device could not be located on the network.",
            ITF::WCN_E_AUTHENTICATION_FAILED => "Windows Connect Now: Authentification failed, the device used an incorrect password.",
            ITF::WCN_E_CONNECTION_REJECTED => "Windows Connect Now: Connection rejected.",
            ITF::WCN_E_SESSION_TIMEDOUT => "Windows Connect Now: The device took too long to respond.",
            ITF::WCN_E_PROTOCOL_ERROR => "Windows Connect Now: Protocol error.",
            ITF::CDO_E_ARGUMENT1 => "The first argument is invalid.",
            ITF::PEOPLE_IMPORT_E_DBCONNFAIL => "The user profile database connection cannot be made, because of error %1.",
            ITF::CDO_E_ARGUMENT2 => "The second argument is invalid.",
            ITF::PEOPLE_IMPORT_NODSDEFINED => "No data source is defined.",
            ITF::CDO_E_ARGUMENT3 => "The third argument is invalid.",
            ITF::PEOPLE_IMPORT_E_FAILTOGETDSDEF => "The data source definition cannot be retrieved, because of error %1.",
            ITF::CDO_E_ARGUMENT4 => "The fourth argument is invalid.",
            ITF::PEOPLE_IMPORT_NOMAPPINGDEFINED => "No data source property mapping is defined.",
            ITF::CDO_E_ARGUMENT5 => "The fifth argument is invalid.",
            ITF::PEOPLE_IMPORT_E_FAILTOGETDSMAPPING => "Data source mapping cannot be retrieved. Check to see that the mapping entry is valid.",
            ITF::PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED => "Datatype (%1) in the data source is not supported.",
            ITF::PEOPLE_IMPORT_E_NOCASTINGSUPPORTED => "(%1) cannot be converted to type (%2).",
            ITF::PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE => "Incremental import information cannot be updated.",
            ITF::PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE => "A zero-length cookie was retrieved at the end of a Dirsync search. The account may not have the appropriate rights.",
            ITF::PEOPLE_IMPORT_E_LDAPPATH_TOOLONG => "The specified LDAP distinguished name is too long.",
            ITF::PEOPLE_IMPORT_E_CANONICALURL_TOOLONG => "The canonical URL is too long.",
            ITF::PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED => "The user account name can not be resolved within the Active Directory. You would need to verify whether the user is a real user or just a temporary user object generated for some application purpose. You might be able to refine the LDAP search filter to avoid this error.",
            ITF::PEOPLE_IMPORT_E_DC_NOT_AVAILABLE => "Error (%1) occurred, which may have resulted from the unavailability of directory service server (%2). If the auto discovery option is turned on, import will re-try it with the newly discovered domain controller. Otherwise, verify your import settings and make sure the server is still available.",
            ITF::PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED => "The attempt to discover domain controller for domain (%1) was failed with error (%2). Please make sure whether there is problem in network connectivity or the domain is renamed.",
            ITF::PEOPLE_IMPORT_E_FAILTOGETLCID => "Fail to retrieve locale from site database - Error (%1) occured.",
            ITF::PEOPLE_IMPORT_E_DOMAIN_REMOVED => "The specified domain (%1) has been removed from import configuration.",
            ITF::PEOPLE_IMPORT_E_ENUM_ACCESSDENIED => "Access was denied on domain: (%1), and user information from the domain was not imported. Check the user name and password of the access account specified on the Configure Profile Import page. If incremental import is enabled and you are importing from a Windows 2000 domain, check that the access account has the Replicate Changes permission for Active Directory directory services.",
            ITF::PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED => "You do not have sufficient permissions for incremental import, or the DirSync cookie stored in the user profile database is corrupt. If you are importing from a Windows 2000 domain, check that the import account has the Replicate Changes permission for Active Directory directory services. If the import account has the permission, start a full import to refresh the cookie.",
            ITF::SPERR_UNINITIALIZED => "The object has not been properly initialized.",
            ITF::SPERR_ALREADY_INITIALIZED => "The object has already been initialized.",
            ITF::SPERR_UNSUPPORTED_FORMAT => "The caller has specified an unsupported format.",
            ITF::SPERR_INVALID_FLAGS => "The caller has specified invalid flags for this operation.",
            ITF::SPERR_DEVICE_BUSY => "The wave device is busy.",
            ITF::SPERR_DEVICE_NOT_SUPPORTED => "The wave device is not supported.",
            ITF::SPERR_DEVICE_NOT_ENABLED => "The wave device is not enabled.",
            ITF::SPERR_NO_DRIVER => "There is no wave driver installed.",
            ITF::SPERR_FILEMUSTBEUNICODE => "The file must be Unicode.",
            ITF::SPERR_INVALID_PHRASE_ID => "The phrase ID specified does not exist or is out of range.",
            ITF::SPERR_BUFFER_TOO_SMALL => "The caller provided a buffer too small to return a result.",
            ITF::SPERR_FORMAT_NOT_SPECIFIED => "Caller did not specify a format prior to opening a stream.",
            ITF::SPERR_AUDIO_STOPPED => "This method is deprecated. Use SP_AUDIO_STOPPED instead.",
            ITF::SPERR_RULE_NOT_FOUND => "Invalid rule name passed to ActivateGrammar.",
            ITF::SPERR_TTS_ENGINE_EXCEPTION => "An exception was raised during a call to the current TTS driver.",
            ITF::SPERR_TTS_NLP_EXCEPTION => "An exception was raised during a call to an application sentence filter.",
            ITF::SPERR_ENGINE_BUSY => "In speech recognition, the current method can not be performed while a grammar rule is active.",
            ITF::SPERR_CANT_CREATE => "Can not create a new object instance for the specified object category.",
            ITF::SPERR_NOT_IN_LEX => "The word does not exist in the lexicon.",
            ITF::SPERR_LEX_VERY_OUT_OF_SYNC => "The client is excessively out of sync with the lexicon. Mismatches may not be incrementally sync'd.",
            ITF::SPERR_UNDEFINED_FORWARD_RULE_REF => "A rule reference in a grammar was made to a named rule that was never defined.",
            ITF::SPERR_EMPTY_RULE => "A non-dynamic grammar rule that has no body.",
            ITF::SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR => "The grammar compiler failed due to an internal state error.",
            ITF::SPERR_RULE_NOT_DYNAMIC => "An attempt was made to modify a non-dynamic rule.",
            ITF::SPERR_DUPLICATE_RULE_NAME => "A rule name was duplicated.",
            ITF::SPERR_DUPLICATE_RESOURCE_NAME => "A resource name was duplicated for a given rule.",
            ITF::SPERR_TOO_MANY_GRAMMARS => "Too many grammars have been loaded.",
            ITF::SPERR_CIRCULAR_REFERENCE => "Circular reference in import rules of grammars.",
            ITF::SPERR_INVALID_IMPORT => "A rule reference to an imported grammar that could not be resolved.",
            ITF::SPERR_INVALID_WAV_FILE => "The format of the WAV file is not supported.",
            ITF::SPERR_ALL_WORDS_OPTIONAL => "A grammar rule was defined with a null path through the rule. That is, it is possible to satisfy the rule conditions with no words.",
            ITF::SPERR_INSTANCE_CHANGE_INVALID => "It is not possible to change the current engine or input. This occurs in the following cases: 1) SelectEngine called while a recognition context exists, or 2) SetInput called in the shared instance case.",
            ITF::SPERR_RULE_NAME_ID_CONFLICT => "A rule exists with matching IDs (names) but different names (IDs).",
            ITF::SPERR_NO_RULES => "A grammar contains no top-level, dynamic, or exported rules. There is no possible way to activate or otherwise use any rule in this grammar.",
            ITF::SPERR_CIRCULAR_RULE_REF => "Rule 'A' refers to a second rule 'B' which, in turn, refers to rule 'A'.",
            ITF::SPERR_NO_PARSE_FOUND => "Parse path cannot be parsed given the currently active rules.",
            ITF::SPERR_REMOTE_CALL_TIMED_OUT => "A marshaled remote call failed to respond.",
            ITF::SPERR_AUDIO_BUFFER_OVERFLOW => "This will only be returned on input (read) streams when the stream is paused because the SR driver has not retrieved data recently.",
            ITF::SPERR_NO_AUDIO_DATA => "The result does not contain any audio, nor does the portion of the element chain of the result contain any audio.",
            ITF::SPERR_DEAD_ALTERNATE => "This alternate is no longer a valid alternate to the result it was obtained from. Returned from ISpPhraseAlt methods.",
            ITF::SPERR_HIGH_LOW_CONFIDENCE => "The result does not contain any audio, nor does the portion of the element chain of the result contain any audio. Returned from ISpResult::GetAudio and ISpResult::SpeakAudio.",
            ITF::SPERR_INVALID_FORMAT_STRING => "The XML format string for this RULEREF is invalid, e.g. not a GUID or REFCLSID.",
            ITF::SPERR_APPLEX_READ_ONLY => "The operation is invalid for all but newly created application lexicons.",
            ITF::SPERR_NO_TERMINATING_RULE_PATH => "Description is missing",
            ITF::SPERR_STREAM_CLOSED => "An operation was attempted on a stream object that has been closed.",
            ITF::SPERR_NO_MORE_ITEMS => "When enumerating items, the requested index is greater than the count of items.",
            ITF::SPERR_NOT_FOUND => "The requested data item (data key, value, etc.) was not found.",
            ITF::SPERR_INVALID_AUDIO_STATE => "Audio state passed to SetState() is invalid.",
            ITF::SPERR_GENERIC_MMSYS_ERROR => "A generic MMSYS error not caught by _MMRESULT_TO_HRESULT.",
            ITF::SPERR_MARSHALER_EXCEPTION => "An exception was raised during a call to the marshaling code.",
            ITF::SPERR_NOT_DYNAMIC_GRAMMAR => "Attempt was made to manipulate a non-dynamic grammar.",
            ITF::SPERR_AMBIGUOUS_PROPERTY => "Cannot add ambiguous property.",
            ITF::SPERR_INVALID_REGISTRY_KEY => "The key specified is invalid.",
            ITF::SPERR_INVALID_TOKEN_ID => "The token specified is invalid.",
            ITF::SPERR_XML_BAD_SYNTAX => "The xml parser failed due to bad syntax.",
            ITF::SPERR_XML_RESOURCE_NOT_FOUND => "The xml parser failed to load a required resource (e.g., voice, phoneconverter, etc.).",
            ITF::SPERR_TOKEN_IN_USE => "Attempted to remove registry data from a token that is already in use elsewhere.",
            ITF::SPERR_TOKEN_DELETED => "Attempted to perform an action on an object token that has had associated registry key deleted.",
            ITF::SPERR_MULTI_LINGUAL_NOT_SUPPORTED => "The selected voice was registered as multi-lingual. SAPI does not support multi-lingual registration.",
            ITF::SPERR_EXPORT_DYNAMIC_RULE => "Exported rules cannot refer directly or indirectly to a dynamic rule.",
            ITF::SPERR_STGF_ERROR => "Error parsing the SAPI Text Grammar Format (XML grammar).",
            ITF::SPERR_WORDFORMAT_ERROR => "Incorrect word format, probably due to incorrect pronunciation string.",
            ITF::SPERR_STREAM_NOT_ACTIVE => "Methods associated with active audio stream cannot be called unless stream is active.",
            ITF::SPERR_ENGINE_RESPONSE_INVALID => "Arguments or data supplied by the engine are in an invalid format or are inconsistent.",
            ITF::SPERR_SR_ENGINE_EXCEPTION => "An exception was raised during a call to the current SR engine.",
            ITF::SPERR_STREAM_POS_INVALID => "Stream position information supplied from engine is inconsistent.",
            ITF::SPERR_REMOTE_CALL_ON_WRONG_THREAD => "When making a remote call to the server, the call was made on the wrong thread.",
            ITF::SPERR_REMOTE_PROCESS_TERMINATED => "The remote process terminated unexpectedly.",
            ITF::SPERR_REMOTE_PROCESS_ALREADY_RUNNING => "The remote process is already running; it cannot be started a second time.",
            ITF::SPERR_LANGID_MISMATCH => "An attempt to load a CFG grammar with a LANGID different than other loaded grammars.",
            ITF::SPERR_NOT_TOPLEVEL_RULE => "An attempt to deactivate or activate a non-toplevel rule.",
            ITF::SPERR_LEX_REQUIRES_COOKIE => "An attempt to ask a container lexicon for all words at once.",
            ITF::SPERR_UNSUPPORTED_LANG => "The requested language is not supported.",
            ITF::SPERR_VOICE_PAUSED => "The operation cannot be performed because the voice is currently paused.",
            ITF::SPERR_AUDIO_BUFFER_UNDERFLOW => "This will only be returned on input (read) streams when the real time audio device stops returning data for a long period of time.",
            ITF::SPERR_AUDIO_STOPPED_UNEXPECTEDLY => "An audio device stopped returning data from the Read() method even though it was in the run state. This error is only returned in the END_SR_STREAM event.",
            ITF::SPERR_NO_WORD_PRONUNCIATION => "The SR engine is unable to add this word to a grammar. The application may need to supply an explicit pronunciation for this word.",
            ITF::SPERR_ALTERNATES_WOULD_BE_INCONSISTENT => "An attempt to call ScaleAudio on a recognition result having previously called GetAlternates. Allowing the call to succeed would result in the previously created alternates located in incorrect audio stream positions.",
            ITF::SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER => "The method called is not supported for the shared recognizer. For example, ISpRecognizer::GetInputStream().",
            ITF::SPERR_TIMEOUT => "A task could not complete because the SR engine had timed out.",
            ITF::SPERR_REENTER_SYNCHRONIZE => "A SR engine called synchronize while inside of a synchronize call.",
            ITF::SPERR_STATE_WITH_NO_ARCS => "The grammar contains a node no arcs.",
            ITF::SPERR_NOT_ACTIVE_SESSION => "Neither audio output and input is supported for non-active console sessions.",
            ITF::SPERR_ALREADY_DELETED => "The object is a stale reference and is invalid to use. For example having a ISpeechGrammarRule object reference and then calling ISpeechRecoGrammar::Reset() will cause the rule object to be invalidated. Calling any methods after is will result in this error.",
            ITF::SPERR_RECOXML_GENERATION_FAIL => "The Recognition Parse Tree couldn't be genrated. For example, that the rule name begins with a digit. XML parser doesn't allow element name beginning with a digit.",
            ITF::SPERR_SML_GENERATION_FAIL => "The SML couldn't be genrated. For example, the transformation xslt template is not well formed.",
            ITF::SPERR_NOT_PROMPT_VOICE => "The current voice is not a prompt voice, so the ISpPromptVoice functions don't work.",
            ITF::SPERR_ROOTRULE_ALREADY_DEFINED => "There is already a root rule for this grammar Defining another root rule will fail.",
            ITF::SPERR_SCRIPT_DISALLOWED => "Support for embedded script not supported because browser security settings have disabled it.",
            ITF::SPERR_REMOTE_CALL_TIMED_OUT_START => "A time out occurred starting the sapi server.",
            ITF::SPERR_REMOTE_CALL_TIMED_OUT_CONNECT => "A timeout occurred obtaining the lock for starting or connecting to sapi server.",
            ITF::SPERR_SECMGR_CHANGE_NOT_ALLOWED => "When there is a cfg grammar loaded, we don't allow changing the security manager.",
            ITF::SPERR_FAILED_TO_DELETE_FILE => "Tried and failed to delete an existing file.",
            ITF::SPERR_SHARED_ENGINE_DISABLED => "The user has chosen to disable speech from running on the machine, or the system is not set up to run speech {e.g. initial setup and tutorial has not been run}.",
            ITF::SPERR_RECOGNIZER_NOT_FOUND => "No recognizer is installed.",
            ITF::SPERR_AUDIO_NOT_FOUND => "No audio device is installed.",
            ITF::SPERR_NO_VOWEL => "No Vowel in a word.",
            ITF::SPERR_UNSUPPORTED_PHONEME => "Unknown phoneme.",
            ITF::SPERR_WORD_NEEDS_NORMALIZATION => "The word passed to the GetPronunciations interface needs normalizing first.",
            ITF::SPERR_CANNOT_NORMALIZE => "The word passed to the normalize interface cannot be normalized.",
            ITF::SPERR_TOPIC_NOT_ADAPTABLE => "This topic is not adaptable.",
            ITF::SPERR_PHONEME_CONVERSION => "Cannot convert the phonemes to the specified phonetic alphabet.",
            ITF::SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER => "The method called is not supported for the in-process recognizer. For example: SetTextFeedback.",
            ITF::SPERR_OVERLOAD => "The operation cannot be carried out due to overload and should be attempted again.",
            ITF::SPERR_LEX_INVALID_DATA => "The lexicon data is invalid or corrupted.",
            ITF::SPERR_CFG_INVALID_DATA => "The data in the CFG grammar is invalid or corrupted.",
            ITF::SPERR_LEX_UNEXPECTED_FORMAT => "The lexicon is not in the expected format.",
            ITF::SPERR_STRING_TOO_LONG => "The string is too long.",
            ITF::SPERR_STRING_EMPTY => "The string cannot be empty.",
            ITF::SPERR_NON_WORD_TRANSITION => "One of the parse transitions is not a word transition.",
            ITF::SPERR_SISR_ATTRIBUTES_NOT_ALLOWED => "Attributes are not allowed at the top level.",
            ITF::SPERR_SISR_MIXED_NOT_ALLOWED => "Mixed content is not allowed at the top level.",
            ITF::SPERR_VOICE_NOT_FOUND => "NO given voice is found.",
            ITF::FSRM_E_NOT_FOUND => "The requested object was not found.",
            ITF::FSRM_E_INVALID_SCHEDULER_ARGUMENT => "One or more of the arguments supplied to the task scheduler are not valid.",
            ITF::FSRM_E_ALREADY_EXISTS => "The specified object already exists.",
            ITF::FSRM_E_PATH_NOT_FOUND => "The specified path was not found.",
            ITF::FSRM_E_INVALID_USER => "The specified user is invalid.",
            ITF::FSRM_E_INVALID_PATH => "The specified path is invalid.",
            ITF::FSRM_E_INVALID_LIMIT => "The specified limit is invalid.",
            ITF::FSRM_E_INVALID_NAME => "The specified name is invalid.",
            ITF::FSRM_E_FAIL_BATCH => "All items in a batch operation failed.",
            ITF::FSRM_E_INVALID_TEXT => "The specified text is invalid.",
            ITF::FSRM_E_INVALID_IMPORT_VERSION => "The version of the configuration file you are trying to import is not supported. You cannot import configuration files with database versions earlier than 2.0.",
            ITF::FSRM_E_OUT_OF_RANGE => "The specified property is out of range.",
            ITF::FSRM_E_REQD_PARAM_MISSING => "The specified required property is missing.",
            ITF::FSRM_E_INVALID_COMBINATION => "The specified property combination is invalid.",
            ITF::FSRM_E_DUPLICATE_NAME => "Duplicate names were detected for the same object.",
            ITF::FSRM_E_NOT_SUPPORTED => "The operation or the specified combination of parameters is not supported.",
            ITF::FSRM_E_DRIVER_NOT_READY => "A required filter driver is not installed, loaded or ready for service.",
            ITF::FSRM_E_INSUFFICIENT_DISK => "There is insufficient disk space to perform the requested operation.",
            ITF::FSRM_E_VOLUME_UNSUPPORTED => "The specified volume is unsupported.",
            ITF::FSRM_E_UNEXPECTED => "The File Server Resource Manager service encountered an unexpected error. Check the application event log for more information.",
            ITF::FSRM_E_INSECURE_PATH => "The specified path is insecure.",
            ITF::FSRM_E_INVALID_SMTP_SERVER => "The SMTP server is invalid.",
            ITF::FSRM_E_EMAIL_NOT_SENT => "The File Server Resource Manager service could not send email due to an error. Check the application event log for more information.",
            ITF::FSRM_E_INVALID_EMAIL_ADDRESS => "The specified email address is invalid.",
            ITF::FSRM_E_FILE_SYSTEM_CORRUPT => "The file system might be corrupted. Please run the CHKDSK utility.",
            ITF::FSRM_E_LONG_CMDLINE => "The specified command-line executable path is longer than MAX_PATH.",
            ITF::FSRM_E_INVALID_FILEGROUP_DEFINITION => "The specified file group definition is invalid.",
            ITF::FSRM_E_INVALID_DATASCREEN_DEFINITION => "The specified file screen is invalid.",
            ITF::FSRM_E_INVALID_REPORT_FORMAT => "The specified report format is invalid.",
            ITF::FSRM_E_INVALID_REPORT_DESC => "The specified report description is invalid.",
            ITF::FSRM_E_INVALID_FILENAME => "The specified file name is invalid.",
            ITF::FSRM_E_SHADOW_COPY => "A volume shadow copy could not be created or was unexpectedly deleted.",
            ITF::FSRM_E_XML_CORRUPTED => "A File Server Resource Manager XML configuration file or import-export file is corrupted.",
            ITF::FSRM_E_CLUSTER_NOT_RUNNING => "File Server Resource Manager global configuration cannot be accessed since the cluster service is not running.",
            ITF::FSRM_E_STORE_NOT_INSTALLED => "File Server Resource Manager global configuration cannot be accessed since it is not installed yet.",
            ITF::FSRM_E_NOT_CLUSTER_VOLUME => "The volume does not reside on a cluster shared disk with an associated cluster resource.",
            ITF::FSRM_E_DIFFERENT_CLUSTER_GROUP => "There are at least two paths which reside on different cluster shared disks which are not in the same cluster resource group.",
            ITF::FSRM_E_REPORT_TYPE_ALREADY_EXISTS => "A report of the specified type already exists in the report job.",
            ITF::FSRM_E_REPORT_JOB_ALREADY_RUNNING => "The report job is already running or queued for running.",
            ITF::FSRM_E_REPORT_GENERATION_ERR => "An error occurred during report generation.",
            ITF::FSRM_E_REPORT_TASK_TRIGGER => "The task contains zero or unsupported triggers.",
            ITF::FSRM_E_LOADING_DISABLED_MODULE => "A rule or policy attempted to load/use a disabled module.",
            ITF::FSRM_E_CANNOT_AGGREGATE => "File Server Resource Manager cannot aggregate the value for the specified file property.",
            ITF::FSRM_E_MESSAGE_LIMIT_EXCEEDED => "The limit of the number of messages that the current pipeline context can add to the property bag has been reached.",
            ITF::FSRM_E_OBJECT_IN_USE => "The object is in use and cannot be deleted.",
            ITF::FSRM_E_CANNOT_RENAME_PROPERTY => "Cannot change the name of a property definition once it is set.",
            ITF::FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE => "Cannot change the type of a property definition once it is set.",
            ITF::FSRM_E_MAX_PROPERTY_DEFINITIONS => "A new property definition cannot be created. The maximum number of property definitions, {0}, has been reached.",
            ITF::FSRM_E_CLASSIFICATION_ALREADY_RUNNING => "A classification job is currently running. Only one classification job can be running at a time.",
            ITF::FSRM_E_CLASSIFICATION_NOT_RUNNING => "Classification is not currently running.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING => "The file management task is already running or queued for running.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION => "Cannot expire a file while running a file management task.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM => "Cannot perform a custom action on a file while running a file management task.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION => "Cannot send a notification for a file management task.",
            ITF::FSRM_E_FILE_OPEN_ERROR => "File Server Resource Manager cannot open the file.",
            ITF::FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE => "File Server Resource Manager failed to perform a secure link with a hosted module process.",
            ITF::FSRM_E_CACHE_INVALID => "The property cache for the file is invalid and could not be read.",
            ITF::FSRM_E_CACHE_MODULE_ALREADY_EXISTS => "A cache storage module already exists.",
            ITF::FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE => "The expiration directory cannot be within the file management scope.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS => "A file management task of the specified name already exists.",
            ITF::FSRM_E_PROPERTY_DELETED => "The specified file property has been deleted.",
            ITF::FSRM_E_LAST_ACCESS_UPDATE_DISABLED => "The updating of last access times is disabled on this server. To create a report or file management task that uses the last access time the updating of last access time must be enabled.",
            ITF::FSRM_E_NO_PROPERTY_VALUE => "The specified file property should not be assigned a value.",
            ITF::FSRM_E_INPROC_MODULE_BLOCKED => "An unknown module cannot be run inside the service process.",
            ITF::FSRM_E_ENUM_PROPERTIES_FAILED => "File Server Resource Manager failed to enumerate file properties because a failure occurred while loading or classifying the file properties.",
            ITF::FSRM_E_SET_PROPERTY_FAILED => "File Server Resource Manager failed to set a file property to the file because a failure occurred while saving the file properties.",
            ITF::FSRM_E_CANNOT_STORE_PROPERTIES => "Classification properties will not be stored because a failure occurred while loading or classifying the file properties.",
            ITF::FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG => "Classification is not supported on the specified reparse point. File Server Resource Manager does not recognize the reparse point's identifier tag for the purposes of classification.",
            ITF::FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND => "The requested property was not found. The file may only have partial classification because a failure occurred while loading or classifying the file properties.",
            ITF::FSRM_E_TEXTREADER_NOT_INITIALIZED => "The File Server Resource Manager text reader was not initialized.",
            ITF::FSRM_E_TEXTREADER_IFILTER_NOT_FOUND => "There is no IFilter registered for this extension.",
            ITF::FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED => "File Server Resource Manager failed to write the properties to the file because the file is either corrupt or protected by Rights Management Services.",
            ITF::FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED => "The IFilter for this extension is not registered correctly.",
            ITF::FSRM_E_TEXTREADER_STREAM_ERROR => "There was an error obtaining the file's streaming interface.",
            ITF::FSRM_E_TEXTREADER_FILENAME_TOO_LONG => "The file name's extension is too long.",
            ITF::FSRM_E_INCOMPATIBLE_FORMAT => "The module will not process the specified file because it is unable to determine a compatible file format.",
            ITF::FSRM_E_FILE_ENCRYPTED => "File Server Resource Manager could not access the file because it is encrypted.",
            ITF::FSRM_E_PERSIST_PROPERTIES_FAILED => "File Server Resource Manager failed to persist the properties to the file.",
            ITF::FSRM_E_VOLUME_OFFLINE => "File Server Resource Manager failed to access the volume. It may be offline.",
            ITF::FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT => "The file management action command timed out.",
            ITF::FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED => "The file management action completed successfully, but the exit code cannot be obtained.",
            ITF::FSRM_E_MODULE_INVALID_PARAM => "The module encountered an invalid parameter or a valid parameter with an invalid value or an expected module parameter is not found. Check the application event log for more information.",
            ITF::FSRM_E_MODULE_INITIALIZATION => "The module initialization failed. Check the application event log for more information.",
            ITF::FSRM_E_MODULE_SESSION_INITIALIZATION => "The module session initialization failed. Check the application event log for more information.",
            ITF::FSRM_E_CLASSIFICATION_SCAN_FAIL => "Classification failed on all volumes. Check the application event log for more information.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE => "The file management task cannot be accessed because task conditions were modified by using WMI or Windows PowerShell interfaces. To access or edit the file management task, use the WMI or Windows PowerShell interfaces.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS => "The file management task has reached its maximum number of conditions.",
            ITF::FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY => "This object uses a property definition that is deprecated. You must change it to use a non-deprecated property definition.",
            ITF::FSRM_E_SYNC_TASK_TIMEOUT => "The property definition sync task timed out.",
            ITF::FSRM_E_CANNOT_USE_DELETED_PROPERTY => "This object uses a property definition that doesn't exist. You must change it to use an existing property definition.",
            ITF::FSRM_E_INVALID_AD_CLAIM => "File Server Resource Manager encountered an invalid resource claim in Active Directory.",
            ITF::FSRM_E_CLASSIFICATION_CANCELED => "The classification operation was canceled.",
            ITF::FSRM_E_INVALID_FOLDER_PROPERTY_STORE => "File Server Resource Manager encountered an invalid folder property store.",
            ITF::FSRM_E_REBUILDING_FODLER_TYPE_INDEX => "File Server Resource Manager is rebuilding the index of Folder Usage property values.",
            ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FILES => "The specified property definition doesn't apply to files.",
            ITF::FSRM_E_CLASSIFICATION_TIMEOUT => "The classification request timed out.",
            ITF::FSRM_E_CLASSIFICATION_PARTIAL_BATCH => "Classification failed on one or more files in the batch operation.",
            ITF::FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY => "This property is a system property and cannot be deleted.",
            ITF::FSRM_E_FILE_IN_USE => "The file is being used by another application and cannot be accessed at this time.",
            ITF::FSRM_E_ERROR_NOT_ENABLED => "Access-denied assistance is not enabled for this error.",
            ITF::FSRM_E_CANNOT_CREATE_TEMP_COPY => "File Server Resource Manager could not create a temporary file copy.",
            ITF::FSRM_E_NO_EMAIL_ADDRESS => "Access-denied assistance cannot send an email because an email address could not be found for the path specified, and sending email to the administrator is not enabled.",
            ITF::FSRM_E_ADR_MAX_EMAILS_SENT => "The current user has sent the maximum number of requests for access-denied assistance.",
            ITF::FSRM_E_PATH_NOT_IN_NAMESPACE => "The path is not included in a classification rule.",
            ITF::FSRM_E_RMS_TEMPLATE_NOT_FOUND => "The RMS template used to configure the file management task no longer exists. Please select another template.",
            ITF::FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED => "The computer hosting the file or folder does not support setting secure properties. This can occur if the computer is running Windows Server 2008 R2, Windows 7, or earlier, or if the computer is not running Windows.",
            ITF::FSRM_E_RMS_NO_PROTECTORS_INSTALLED => "File Server Resource Manager cannot run the file management task because no RMS protectors are installed.",
            ITF::FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE => "File Server Resource Manager cannot protect the file because an RMS protector for the file type is not installed.",
            ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS => "The specified property definition doesn't apply to folders.",
            ITF::FSRM_E_PROPERTY_MUST_BE_SECURE => "The specified property definition type is not secure.",
            ITF::FSRM_E_PROPERTY_MUST_BE_GLOBAL => "The specified property definition type is not global.",
            ITF::FSRM_E_WMI_FAILURE => "Unexpected failure from a WMI call.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_RMS => "Cannot protect a file while running a file management task.",
            ITF::FSRM_E_SYNC_TASK_HAD_ERRORS => "The property definition sync task encountered errors. Check the application event log for more information.",
            ITF::FSRM_E_ADR_SRV_NOT_SUPPORTED => "The server does not provide access-denied assistance.",
            ITF::FSRM_E_ADR_PATH_IS_LOCAL => "Access-denied assistance cannot be provided for local paths.",
            ITF::FSRM_E_ADR_NOT_DOMAIN_JOINED => "Access-denied assistance requires that the server be joined to a domain.",
            ITF::FSRM_E_CANNOT_REMOVE_READONLY => "File Server Resource Manager could not remove the read-only attribute from a file.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG => "A continuous file management job cannot have conditions based on the file's last accessed/modified or created times and cannot define any notifications.",
            ITF::FSRM_E_LEGACY_SCHEDULE => "The object contains a schedule that was created by using an earlier version of File Server Resource Manager and that is incompatible with the current version of Windows Server. Edit the schedule on this computer to update it.",
            ITF::FSRM_E_CSC_PATH_NOT_SUPPORTED => "This operation is not supported for paths on which Offline Files is enabled.",
            ITF::FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE => "Cannot write to the specified expiration directory. Confirm that the permissions of the expiration directory grant Write permission to the computer account of the server performing the file expiration task.",
            ITF::FSRM_E_EXPIRATION_PATH_TOO_LONG => "The expiration path must be 150 characters or shorter.",
            ITF::FSRM_E_EXPIRATION_VOLUME_NOT_NTFS => "The expiration directory must be on a volume formatted with the NTFS file system.",
            ITF::FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED => "This file management job is deprecated. Please check the configuration of the file management job and verify that it is up-to-date.",
            ITF::FSRM_E_MODULE_TIMEOUT => "A module was restarted due to excessive processing time of a file. Check the application event log for more information.",
            ITF::IFED_S_MORE_ENTRIES => "Microsoft IME user dictionary: no more entries in the dictionary.",
            ITF::IFED_S_EMPTY_DICTIONARY => "Microsoft IME user dictionary: dictionary is empty, no header information is returned.",
            ITF::IFED_S_WORD_EXISTS => "Microsoft IME user dictionary: word already exists in dictionary.",
            ITF::IFED_S_COMMENT_CHANGED => "Microsoft IME user dictionary: word already exists in dictionary but only comment data is updated.",
            ITF::IFED_E_NOT_FOUND => "Microsoft IME user dictionary: dictionary is not found.",
            ITF::IFED_E_INVALID_FORMAT => "Microsoft IME user dictionary: invalid dictionary format.",
            ITF::IFED_E_OPEN_FAILED => "Microsoft IME user dictionary: failed to open file.",
            ITF::IFED_E_WRITE_FAILED => "Microsoft IME user dictionary: failed to write to file.",
            ITF::IFED_E_NO_ENTRY => "Microsoft IME user dictionary: no entry found in dictionary.",
            ITF::IFED_E_REGISTER_FAILED => "Microsoft IME user dictionary: this routines doesn't support the current dictionary.",
            ITF::IFED_E_NOT_USER_DIC => "Microsoft IME user dictionary: not a user dictionary.",
            ITF::IFED_E_NOT_SUPPORTED => "Microsoft IME user dictionary: not supported.",
            ITF::IFED_E_USER_COMMENT => "Microsoft IME user dictionary: failed to insert user comment.",
            ITF::IFED_E_REGISTER_ILLEGAL_POS => "Microsoft IME user dictionary: improper POS is to be registered.",
            ITF::IFED_E_REGISTER_IMPROPER_WORD => "Microsoft IME user dictionary: improper word is to be registered.",
            ITF::IFED_E_REGISTER_DISCONNECTED => "Microsoft IME user dictionary: dictionary is disconnected.",
            ITF::NETCFG_E_ALREADY_INITIALIZED => "Indicates that the INetCfgComponent interface is not expected to be initialized, but it is already initialized. For example, this code is returned if the INetCfgComponent interface is already initialized before the INetCfg::Initialize method has been called.",
            ITF::UPNP_E_REQUIRED_ELEMENT_ERROR => "A required element is missing.",
            ITF::NETCFG_E_NOT_INITIALIZED => "Indicates that the INetCfg interface is expected to be initialized, but it is not yet initialized.",
            ITF::UPNP_E_DUPLICATE_NOT_ALLOWED => "A duplicate element exists.",
            ITF::NETCFG_E_IN_USE => "Obsolete.",
            ITF::UPNP_E_DUPLICATE_SERVICE_ID => "A duplicate service ID for a service within the same parent device exists.",
            ITF::UPNP_E_INVALID_DESCRIPTION => "The device description is not valid.",
            ITF::NETCFG_E_NO_WRITE_LOCK => "Indicates that a call to the INetCfgLock::AcquireWriteLock method did not succeed. This code returns if another application currently owns the lock on network configuration.",
            ITF::UPNP_E_INVALID_SERVICE => "An error is present in a service element in the device description.",
            ITF::NETCFG_E_NEED_REBOOT => "Description is missing",
            ITF::UPNP_E_INVALID_ICON => "An error is present in the icon element of the device description.",
            ITF::NETCFG_E_ACTIVE_RAS_CONNECTIONS => "Obsolete.",
            ITF::UPNP_E_INVALID_XML => "An error is present in the device description.",
            ITF::NETCFG_E_ADAPTER_NOT_FOUND => "Indicates that the physical adapter corresponding to the component is not present on the system.",
            ITF::UPNP_E_INVALID_ROOT_NAMESPACE => "An error is present in the root namespace of the device description.",
            ITF::NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT => "The component was removed and cannot be added until the system is rebooted.",
            ITF::UPNP_E_SUFFIX_TOO_LONG => "A suffix is too long in the device description.",
            ITF::NETCFG_E_MAX_FILTER_LIMIT => "Indicates that the application is trying to install a filter device, but the maximum number of filter devices that the system supports has already been reached.",
            ITF::UPNP_E_URLBASE_PRESENT => "The element UrlBase is missing from the device description.",
            ITF::NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER => "Description is missing",
            ITF::NETCFG_E_DUPLICATE_INSTANCEID => "Another component exists with the same NetCfgInstanceId(Lwf).",
            ITF::UPNP_E_VALUE_TOO_LONG => "A value is too long in the device description.",
            ITF::UPNP_E_DEVICE_RUNNING => "The device is currently running. Use ReregisterRunningDevice to reregister a device while it is running.",
            ITF::UPNP_E_DEVICE_NOTREGISTERED => "The device has not been registered. Use RegisterRunningDevice to register an unregistered device.",
            ITF::WTS_E_FAILEDEXTRACTION => "Thumbnail Cache: The Shell item does not support thumbnail extraction. For example, .exe or .lnk items.",
            ITF::WTS_E_EXTRACTIONTIMEDOUT => "Thumbnail Cache: The extraction took longer than the maximum allowable time. The extraction was not completed.",
            ITF::WTS_E_SURROGATEUNAVAILABLE => "Thumbnail Cache: A surrogate process was not available to be used for the extraction process.",
            ITF::WTS_E_FASTEXTRACTIONNOTSUPPORTED => "Thumbnail Cache: The WTS_FASTEXTRACT flag was set, but fast extraction is not available.",
            ITF::WTS_E_DATAFILEUNAVAILABLE => "Thumbnail Cache:.",
            ITF::FTE_E_CB_OUT_OF_MEMORY => "This is an internal error: The chunk buffer is out of memory.",
            ITF::FTE_E_CB_CBID_OUT_OF_BOUND => "This is an internal error: The chunk buffer id is out of bounds.",
            ITF::FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM => "There is not enough available physical or virtual memory for chunk buffers. Chunk buffers are needed to index data. Please free up memory.",
            ITF::FTE_E_CB_NOT_ENOUGH_OCC_BUFFER => "There is not enough occurrence buffer memory available. Possible causes include too many processors, too many filter threads, or the occurrence buffer is not being returned.",
            ITF::FTE_E_CORRUPT_WORDLIST => "The in-memory wordlist is corrupted. This is due to a faulty filter, wordbreaker, or other indexing component.",
            ITF::XACT_E_ALREADYOTHERSINGLEPHASE => "Another single phase resource manager has already been enlisted in this transaction.",
            ITF::XACT_E_CANTRETAIN => "A retaining commit or abort is not supported.",
            ITF::XACT_E_COMMITFAILED => "The transaction failed to commit for an unknown reason. The transaction was aborted.",
            ITF::XACT_E_COMMITPREVENTED => "Cannot call commit on this transaction object because the calling application did not initiate the transaction.",
            ITF::XACT_E_HEURISTICABORT => "Instead of committing, the resource heuristically aborted.",
            ITF::XACT_E_HEURISTICCOMMIT => "Instead of aborting, the resource heuristically committed.",
            ITF::XACT_E_HEURISTICDAMAGE => "Some of the states of the resource were committed while others were aborted, likely because of heuristic decisions.",
            ITF::XACT_E_HEURISTICDANGER => "Some of the states of the resource may have been committed while others may have been aborted, likely because of heuristic decisions.",
            ITF::XACT_E_ISOLATIONLEVEL => "The requested isolation level is not valid or supported.",
            ITF::XACT_E_NOASYNC => "The transaction manager doesn't support an asynchronous operation for this method.",
            ITF::XACT_E_NOENLIST => "Unable to enlist in the transaction.",
            ITF::XACT_E_NOISORETAIN => "The requested semantics of retention of isolation across retaining commit and abort boundaries cannot be supported by this transaction implementation, or isoFlags was not equal to zero.",
            ITF::XACT_E_NORESOURCE => "There is no resource presently associated with this enlistment.",
            ITF::XACT_E_NOTCURRENT => "The transaction failed to commit due to the failure of optimistic concurrency control in at least one of the resource managers.",
            ITF::XACT_E_NOTRANSACTION => "The transaction has already been implicitly or explicitly committed or aborted.",
            ITF::XACT_E_NOTSUPPORTED => "An invalid combination of flags was specified.",
            ITF::XACT_E_UNKNOWNRMGRID => "The resource manager id is not associated with this transaction or the transaction manager.",
            ITF::XACT_E_WRONGSTATE => "This method was called in the wrong state.",
            ITF::XACT_E_WRONGUOW => "The indicated unit of work does not match the unit of work expected by the resource manager.",
            ITF::XACT_E_XTIONEXISTS => "An enlistment in a transaction already exists.",
            ITF::XACT_E_NOIMPORTOBJECT => "An import object for the transaction could not be found.",
            ITF::XACT_E_INVALIDCOOKIE => "The transaction cookie is invalid.",
            ITF::XACT_E_INDOUBT => "The transaction status is in doubt. A communication failure occurred, or a transaction manager or resource manager has failed.",
            ITF::XACT_E_NOTIMEOUT => "A time-out was specified, but time-outs are not supported.",
            ITF::XACT_E_ALREADYINPROGRESS => "The requested operation is already in progress for the transaction.",
            ITF::XACT_E_ABORTED => "The transaction has already been aborted.",
            ITF::XACT_E_LOGFULL => "The Transaction Manager returned a log full error.",
            ITF::XACT_E_TMNOTAVAILABLE => "The Transaction Manager is not available.",
            ITF::XACT_E_CONNECTION_DOWN => "A connection with the transaction manager was lost.",
            ITF::XACT_E_CONNECTION_DENIED => "A request to establish a connection with the transaction manager was denied.",
            ITF::XACT_E_REENLISTTIMEOUT => "Resource manager reenlistment to determine transaction status timed out.",
            ITF::XACT_E_TIP_CONNECT_FAILED => "This transaction manager failed to establish a connection with another TIP transaction manager.",
            ITF::XACT_E_TIP_PROTOCOL_ERROR => "This transaction manager encountered a protocol error with another TIP transaction manager.",
            ITF::XACT_E_TIP_PULL_FAILED => "This transaction manager could not propagate a transaction from another TIP transaction manager.",
            ITF::XACT_E_DEST_TMNOTAVAILABLE => "The Transaction Manager on the destination machine is not available.",
            ITF::XACT_E_TIP_DISABLED => "The Transaction Manager has disabled its support for TIP.",
            ITF::XACT_E_NETWORK_TX_DISABLED => "The transaction manager has disabled its support for remote/network transactions.",
            ITF::XACT_E_PARTNER_NETWORK_TX_DISABLED => "The partner transaction manager has disabled its support for remote/network transactions.",
            ITF::XACT_E_XA_TX_DISABLED => "The transaction manager has disabled its support for XA transactions.",
            ITF::XACT_E_UNABLE_TO_READ_DTC_CONFIG => "MSDTC was unable to read its configuration information.",
            ITF::XACT_E_UNABLE_TO_LOAD_DTC_PROXY => "MSDTC was unable to load the dtc proxy dll.",
            ITF::XACT_E_ABORTING => "The local transaction has aborted.",
            ITF::XACT_E_PUSH_COMM_FAILURE => "The MSDTC transaction manager was unable to push the transaction to the destination transaction manager due to communication problems. Possible causes are: a firewall is present and it doesn't have an exception for the MSDTC process, the two machines cannot find each other by their NetBIOS names, or the support for network transactions is not enabled for one of the two transaction managers.",
            ITF::XACT_E_PULL_COMM_FAILURE => "The MSDTC transaction manager was unable to pull the transaction from the source transaction manager due to communication problems. Possible causes are: a firewall is present and it doesn't have an exception for the MSDTC process, the two machines cannot find each other by their NetBIOS names, or the support for network transactions is not enabled for one of the two transaction managers.",
            ITF::XACT_E_LU_TX_DISABLED => "The MSDTC transaction manager has disabled its support for SNA LU 6.2 transactions.",
            ITF::XACT_E_CLERKNOTFOUND => "XACT_E_CLERKNOTFOUND.",
            ITF::XACT_E_CLERKEXISTS => "XACT_E_CLERKEXISTS.",
            ITF::XACT_E_RECOVERYINPROGRESS => "XACT_E_RECOVERYINPROGRESS.",
            ITF::XACT_E_TRANSACTIONCLOSED => "XACT_E_TRANSACTIONCLOSED.",
            ITF::XACT_E_INVALIDLSN => "XACT_E_INVALIDLSN.",
            ITF::XACT_E_REPLAYREQUEST => "XACT_E_REPLAYREQUEST.",
            ITF::XACT_E_CONNECTION_REQUEST_DENIED => "The request to connect to the specified transaction coordinator was denied.",
            ITF::XACT_E_TOOMANY_ENLISTMENTS => "The maximum number of enlistments for the specified transaction has been reached.",
            ITF::XACT_E_DUPLICATE_GUID => "A resource manager with the same identifier is already registered with the specified transaction coordinator.",
            ITF::SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED => "The security processor reported that the machine time is inconsistent with the trusted time.",
            ITF::XACT_E_NOTSINGLEPHASE => "The prepare request given was not eligible for single-phase optimizations.",
            ITF::XACT_E_RECOVERYALREADYDONE => "RecoveryComplete has already been called for the given resource manager.",
            ITF::XACT_E_PROTOCOL => "The interface call made was incorrect for the current state of the protocol.",
            ITF::XACT_E_RM_FAILURE => "The xa_open call failed for the XA resource.",
            ITF::XACT_E_RECOVERY_FAILED => "The xa_recover call failed for the XA resource.",
            ITF::XACT_E_LU_NOT_FOUND => "The logical unit of work specified cannot be found.",
            ITF::XACT_E_DUPLICATE_LU => "The specified logical unit of work already exists.",
            ITF::XACT_E_LU_NOT_CONNECTED => "Subordinate creation failed. The specified logical unit of work was not connected.",
            ITF::XACT_E_DUPLICATE_TRANSID => "A transaction with the given identifier already exists.",
            ITF::SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED => "The security processor cannot operate while a debugger is attached.",
            ITF::XACT_E_LU_BUSY => "The resource is in use.",
            ITF::XACT_E_LU_NO_RECOVERY_PROCESS => "The LU Recovery process is down.",
            ITF::XACT_E_LU_DOWN => "The remote session was lost.",
            ITF::XACT_E_LU_RECOVERING => "The resource is currently recovering.",
            ITF::XACT_E_LU_RECOVERY_MISMATCH => "There was a mismatch in driving recovery.",
            ITF::XACT_E_RM_UNAVAILABLE => "An error occurred with the XA resource.",
            ITF::CONTEXT_E_ABORTED => "The root transaction wanted to commit, but transaction aborted.",
            ITF::CONTEXT_E_ABORTING => "You made a method call on a COM+ component that has a transaction that has already aborted or in the process of aborting.",
            ITF::CONTEXT_E_NOCONTEXT => "There is no MTS object context.",
            ITF::CONTEXT_E_WOULD_DEADLOCK => "The component is configured to use synchronization and this method call would cause a deadlock to occur.",
            ITF::CONTEXT_E_SYNCH_TIMEOUT => "The component is configured to use synchronization and a thread has timed out waiting to enter the context.",
            ITF::CONTEXT_E_OLDREF => "You made a method call on a COM+ component that has a transaction that has already committed or aborted.",
            ITF::CONTEXT_E_ROLENOTFOUND => "The specified role was not configured for the application.",
            ITF::CONTEXT_E_TMNOTAVAILABLE => "COM+ was unable to talk to the Microsoft Distributed Transaction Coordinator.",
            ITF::CO_E_ACTIVATIONFAILED => "An unexpected error occurred during COM+ Activation.",
            ITF::CO_E_ACTIVATIONFAILED_EVENTLOGGED => "COM+ Activation failed. Check the event log for more information.",
            ITF::CO_E_ACTIVATIONFAILED_CATALOGERROR => "COM+ Activation failed due to a catalog or configuration error.",
            ITF::CO_E_ACTIVATIONFAILED_TIMEOUT => "COM+ activation failed because the activation could not be completed in the specified amount of time.",
            ITF::CO_E_INITIALIZATIONFAILED => "COM+ Activation failed because an initialization function failed. Check the event log for more information.",
            ITF::CONTEXT_E_NOJIT => "The requested operation requires that JIT be in the current context and it is not.",
            ITF::SL_E_INVALID_USE_OF_ADD_ON_PKEY => "The Software Licensing Service reported that a valid product key for an add-on sku was entered where a Windows product key was expected.",
            ITF::CONTEXT_E_NOTRANSACTION => "The requested operation requires that the current context have a Transaction, and it does not.",
            ITF::CO_E_THREADINGMODEL_CHANGED => "The components threading model has changed after install into a COM+ Application. Please re-install component.",
            ITF::CO_E_NOIISINTRINSICS => "IIS intrinsics not available. Start your work with IIS.",
            ITF::CO_E_NOCOOKIES => "An attempt to write a cookie failed.",
            ITF::CO_E_DBERROR => "An attempt to use a database generated a database specific error.",
            ITF::CO_E_NOTPOOLED => "The COM+ component you created must use object pooling to work.",
            ITF::CO_E_NOTCONSTRUCTED => "The COM+ component you created must use object construction to work correctly.",
            ITF::CO_E_NOSYNCHRONIZATION => "The COM+ component requires synchronization, and it is not configured for it.",
            ITF::CO_E_ISOLEVELMISMATCH => "The TxIsolation Level property for the COM+ component being created is stronger than the TxIsolationLevel for the 'root' component for the transaction. The creation failed.",
            ITF::CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED => "The component attempted to make a cross-context call between invocations of EnterTransactionScopeand ExitTransactionScope. This is not allowed. Cross-context calls cannot be made while inside of a transaction scope.",
            ITF::CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED => "The component made a call to EnterTransactionScope, but did not make a corresponding call to ExitTransactionScope before returning.",
            ITF::SL_E_SFS_INVALID_FS_VERSION => "The Software Licensing Service reported that the Token Store file version is invalid.",
            ITF::SL_E_SFS_INVALID_FD_TABLE => "The Software Licensing Service reported that the Token Store contains an invalid descriptor table.",
            ITF::SL_E_SFS_INVALID_SYNC => "The Software Licensing Service reported that the Token Store contains a token with an invalid header/footer.",
            ITF::SL_E_SFS_BAD_TOKEN_NAME => "The Software Licensing Service reported that a Token Store token has an invalid name.",
            ITF::SL_E_SFS_BAD_TOKEN_EXT => "The Software Licensing Service reported that a Token Store token has an invalid extension.",
            ITF::SL_E_SFS_DUPLICATE_TOKEN_NAME => "The Software Licensing Service reported that the Token Store contains a duplicate token.",
            ITF::SL_E_SFS_TOKEN_SIZE_MISMATCH => "The Software Licensing Service reported that a token in the Token Store has a size mismatch.",
            ITF::SL_E_SFS_INVALID_TOKEN_DATA_HASH => "The Software Licensing Service reported that a token in the Token Store contains an invalid hash.",
            ITF::SL_E_SFS_FILE_READ_ERROR => "The Software Licensing Service reported that the Token Store was unable to read a token.",
            ITF::SL_E_SFS_FILE_WRITE_ERROR => "The Software Licensing Service reported that the Token Store was unable to write a token.",
            ITF::SL_E_SFS_INVALID_FILE_POSITION => "The Software Licensing Service reported that the Token Store attempted an invalid file operation.",
            ITF::SL_E_SFS_NO_ACTIVE_TRANSACTION => "The Software Licensing Service reported that there is no active transaction.",
            ITF::SL_E_SFS_INVALID_FS_HEADER => "The Software Licensing Service reported that the Token Store file header is invalid.",
            ITF::SL_E_SFS_INVALID_TOKEN_DESCRIPTOR => "The Software Licensing Service reported that a Token Store token descriptor is invalid.",
            ITF::FTE_E_FD_NO_IPERSIST_INTERFACE => "The IPersistStream and IPersistFile interfaces were unavailable from an IFilter filter DLL to load data for indexing.",
            ITF::FTE_E_FD_IFILTER_INIT_FAILED => "The IFilter::Init() function call failed.",
            ITF::FTE_E_FD_FAILED_TO_LOAD_IFILTER => "The filter daemon MSFTEFD failed to load an IFilter interface for document, so it can't be indexed.",
            ITF::FTE_E_FD_DOC_TIMEOUT => "The document being indexed timed out for an unknown reason. This may be due to a bug in a filter or wordbreaker.",
            ITF::FTE_E_FD_UNEXPECTED_EXIT => "The filter daemon process MSFTEFD exited unexpectedly. Here is the stack trace: %1.",
            ITF::FTE_E_FD_DOC_UNEXPECTED_EXIT => "The filter daemon process MSFTEFD exited unexpectedly because of document %1. Batch Id: %2 Locale Id: %3 Property Id: %4 Stack Trace: %5.",
            ITF::FTE_E_FD_NOISE_NO_TEXT_FILTER => "The system failed to load the text filter for parsing a noise word file.",
            ITF::FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER => "The system failed to load noise words stream into text filter because text filter does not support IPersistStream.",
            ITF::FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED => "The system failed to load noise words stream into text filter because the IPersistStream::Load() function failed.",
            ITF::FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED => "The system failed to load noise words stream into text filter because IFilter::Init() function failed.",
            ITF::FTE_E_FD_OCCURRENCE_OVERFLOW => "Occurrence counter overflow, document is not indexed.",
            ITF::FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION => "The filter has caused a sharing violation.",
            ITF::IO_ERR_CONFIGURATION_ERROR => "Driver or device is incorrectly configured for %1.",
            ITF::IO_ERR_DRIVER_ERROR => "Driver detected an internal error in its data structures for %1.",
            ITF::IO_ERR_PARITY => "A parity error was detected on %1.",
            ITF::IO_ERR_SEEK_ERROR => "The device, %1, had a seek error.",
            ITF::IO_ERR_BAD_BLOCK => "The device, %1, has a bad block.",
            ITF::IO_ERR_OVERRUN_ERROR => "An overrun occurred on %1.",
            ITF::IO_ERR_TIMEOUT => "The device, %1, did not respond within the timeout period.",
            ITF::IO_ERR_SEQUENCE => "The driver detected an unexpected sequence by the device, %1.",
            ITF::IO_ERR_CONTROLLER_ERROR => "The driver detected a controller error on %1.",
            ITF::IO_ERR_INTERNAL_ERROR => "The driver detected an internal driver error on %1.",
            ITF::IO_ERR_INCORRECT_IRQL => "The driver was configured with an incorrect interrupt for %1.",
            ITF::IO_ERR_INVALID_IOBASE => "The driver was configured with an invalid I/O base address for %1.",
            ITF::IO_ERR_NOT_READY => "The device, %1, is not ready for access yet.",
            ITF::IO_ERR_INVALID_REQUEST => "The request is incorrectly formatted for %1.",
            ITF::IO_ERR_VERSION => "The wrong version of the driver has been loaded.",
            ITF::IO_ERR_LAYERED_FAILURE => "The driver beneath this one has failed in some way for %1.",
            ITF::IO_ERR_RESET => "The device, %1, has been reset.",
            ITF::IO_ERR_PROTOCOL => "A transport driver received a frame which violated the protocol.",
            ITF::IO_ERR_MEMORY_CONFLICT_DETECTED => "A conflict has been detected between two drivers which claimed two overlapping memory regions. Driver %2, with device <%3>, claimed a memory range with starting address in data address 0x28 and 0x2c, and length in data address 0x30.",
            ITF::IO_ERR_PORT_CONFLICT_DETECTED => "A conflict has been detected between two drivers which claimed two overlapping Io port regions. Driver %2, with device <%3>, claimed an IO port range with starting address in data address 0x28 and 0x2c, and length in data address 0x30.",
            ITF::IO_ERR_DMA_CONFLICT_DETECTED => "A conflict has been detected between two drivers which claimed equivalent DMA channels. Driver %2, with device <%3>, claimed the DMA Channel in data address 0x28, with optinal port in data address 0x2c.",
            ITF::IO_ERR_IRQ_CONFLICT_DETECTED => "A conflict has been detected between two drivers which claimed equivalent IRQs. Driver %2, with device <%3>, claimed an interrupt with Level in data address 0x28, vector in data address 0x2c and Affinity in data address 0x30.",
            ITF::IO_ERR_BAD_FIRMWARE => "The driver has detected a device with old or out-of-date firmware. The device will not be used.",
            ITF::IO_ERR_DMA_RESOURCE_CONFLICT => "The device could not allocate one or more required resources due to conflicts with other devices. The device DMA setting of '%2' could not be satisified due to a conflict with Driver '%3'.",
            ITF::IO_ERR_INTERRUPT_RESOURCE_CONFLICT => "The device could not allocate one or more required resources due to conflicts with other devices. The device interrupt setting of '%2' could not be satisified due to a conflict with Driver '%3'.",
            ITF::IO_ERR_MEMORY_RESOURCE_CONFLICT => "The device could not allocate one or more required resources due to conflicts with other devices. The device memory setting of '%2' could not be satisified due to a conflict with Driver '%3'.",
            ITF::IO_ERR_PORT_RESOURCE_CONFLICT => "The device could not allocate one or more required resources due to conflicts with other devices. The device port setting of '%2' could not be satisified due to a conflict with Driver '%3'.",
            ITF::IO_BAD_BLOCK_WITH_NAME => "The file %2 on device %1 contains a bad disk block.",
            ITF::IO_FILE_SYSTEM_CORRUPT => "The file system structure on the disk is corrupt and unusable. Please run the chkdsk utility on the device %1 with label '%2'.",
            ITF::IO_FILE_QUOTA_CORRUPT => "The user disk quota information is unusable. To ensure accuracy, the file system quota information on the device %1 with label '%2' will be rebuilt.",
            ITF::IO_SYSTEM_SLEEP_FAILED => "The system sleep operation failed.",
            ITF::IO_DUMP_POINTER_FAILURE => "The system could not get file retrieval pointers for the dump file.",
            ITF::IO_DUMP_DRIVER_LOAD_FAILURE => "The system could not sucessfully load the crash dump driver.",
            ITF::IO_DUMP_INITIALIZATION_FAILURE => "Crash dump initialization failed!.",
            ITF::IO_DUMP_DUMPFILE_CONFLICT => "A valid crash dump was found in the paging file while trying to configure a direct dump. Direct dump is disabled! This occurs when the direct dump option is set in the registry but a stop error occured before configuration completed.",
            ITF::IO_DUMP_DIRECT_CONFIG_FAILED => "Direct dump configuration failed. Validate the filename and make sure the target device is not a Fault Tolerant set member, remote, or floppy device. The failure may be because there is not enough room on the dump device to create the dump file.",
            ITF::IO_DUMP_PAGE_CONFIG_FAILED => "Configuring the Page file for crash dump failed. Make sure there is a page file on the boot partition and that is large enough to contain all physical memory.",
            ITF::IO_FILE_SYSTEM_CORRUPT_WITH_NAME => "The file system structure on the disk is corrupt and unusable. Please run the chkdsk utility on the volume %2.",
            ITF::IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER => "The driver %3 for the %2 device %1 got stuck in an infinite loop. This usually indicates a problem with the device itself or with the device driver programming the hardware incorrectly. Please check with your hardware device vendor for any driver updates.",
            ITF::IO_ERR_PORT_TIMEOUT => "The driver for device %1 detected a port timeout due to prolonged inactivity. All associated busses were reset in an effort to clear the condition.",
            ITF::IO_ERROR_DISK_RESOURCES_EXHAUSTED => "Disk %2 has reached a logical block provisioning permanent resource exhaustion condition.",
            ITF::IO_ERROR_IO_HARDWARE_ERROR => "The IO operation at logical block address %2 for Disk %3 (PDO name: %4) failed due to a hardware error.",
            ITF::ES_E_INVALID_RESPONSE => "Hardware return invalid response.",
            ITF::ES_E_UNPROVISIONED_HARDWARE => "Hardware is not provision.",
            ITF::ES_E_UNSUPPORTED_HARDWARE => "Hardware is not supported.",
            ITF::ES_E_INCOMPLETE_COMMAND => "An incomplete command was received.",
            ITF::ES_E_BAD_SEQUENCE => "Command rejected for being out of sequence.",
            ITF::ES_E_NO_PROBE => "Non-Probe command received before Probe command.",
            ITF::ES_E_INVALID_SILO => "Invalid silo specified.",
            ITF::ES_E_INVALID_CAPABILITY => "Invalid capability requested.",
            ITF::ES_E_GROUP_POLICY_FORBIDDEN_USE => "Group policy setting forbids use.",
            ITF::ES_E_GROUP_POLICY_FORBIDDEN_OPERATION => "Group policy setting forbids operation.",
            ITF::ES_E_INVALID_PARAM_COMBINATION => "Invalid combination of parameters specified in input data.",
            ITF::ES_E_INVALID_PARAM_LENGTH => "Parameter Byte Length specified in the payload is invalid.",
            ITF::ES_E_INCONSISTENT_PARAM_LENGTH => "Parameter Byte Length specified in the payload is not consistent with the number of bytes transferred.",
            ITF::ES_E_NO_AUTHENTICATION_REQUIRED => "Hardware does not require authentication.",
            ITF::GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED => "Notification client is not subscribed.",
            ITF::ES_E_INVALID_FIELD_IDENTIFIER => "An invalid field identifier was found in the data provided by the device.",
            ITF::ES_E_CHALLENGE_MISMATCH => "The challenge provided by the device does not match the one provided in an earlier step in the authentication sequence.",
            ITF::ES_E_CHALLENGE_SIZE_MISMATCH => "The size of the challenge specified by the device does not match the choice of the digest algorithm.",
            ITF::ES_E_FRIENDLY_NAME_TOO_LONG => "The friendly name specified for User is too long.",
            ITF::ES_E_SILO_NAME_TOO_LONG => "The silo name specified is too long.",
            ITF::ES_E_PASSWORD_TOO_LONG => "The password specified is too long.",
            ITF::ES_E_PASSWORD_HINT_TOO_LONG => "The password hint specified is too long.",
            ITF::ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE => "Cannot enable IEEE 1667 password security since another security protocol is still active on the device.",
            ITF::ES_E_DEVICE_DIGEST_MISSING => "Device digest was expected but was not found in the payload.",
            ITF::ES_E_NOT_AUTHORIZED_UNEXPECTED => "Expected the silo to be in Authorized state, but it was not.",
            ITF::ES_E_AUTHORIZED_UNEXPECTED => "Expected the silo to be in Not Authorized state, but it was not.",
            ITF::ES_E_PROVISIONED_UNEXPECTED => "Expected the silo to be in Not Provisioned state, but it was not.",
            ITF::ES_E_UNKNOWN_DIGEST_ALGORITHM => "The digest algorithm supported by the device is not supported in Windows.",
            ITF::QUTIL_E_INVALID_CODEPAGE => "Invalid CiCodepage was specified.",
            ITF::FILTER_E_CONTENTINDEXCORRUPT => "The content index is corrupt. A content scan will to be scheduled after chkdsk or autochk is run.",
            ITF::CI_CORRUPT_DATABASE => "The content index is corrupt.",
            ITF::CI_CORRUPT_CATALOG => "The content index meta data is corrupt.",
            ITF::CI_INVALID_PARTITION => "The content index partition is invalid.",
            ITF::CI_INVALID_PRIORITY => "The priority is invalid.",
            ITF::CI_NO_STARTING_KEY => "There is no starting key.",
            ITF::CI_OUT_OF_INDEX_IDS => "The content index is out of index ids.",
            ITF::CI_NO_CATALOG => "There is no catalog.",
            ITF::CI_CORRUPT_FILTER_BUFFER => "The filter buffer is corrupt.",
            ITF::CI_INVALID_INDEX => "The index is invalid.",
            ITF::CI_PROPSTORE_INCONSISTENCY => "Inconsistency in property store detected.",
            ITF::CI_INCORRECT_VERSION => "The content index data on disk is for the wrong version.",
            ITF::CI_E_ENUMERATION_STARTED => "Enumeration has already been started for this query.",
            ITF::CI_E_PROPERTY_TOOLARGE => "The specified variable length property is too large for the property cache.",
            ITF::CI_E_CLIENT_FILTER_ABORT => "Filtering of object was aborted by client.",
            ITF::CI_E_CORRUPT_FWIDX => "The forward index cannot be read.",
            ITF::CI_E_DIACRITIC_SETTINGS_DIFFER => "Catalog was created with different diacritic settings.",
            ITF::CI_E_NO_CATALOG_MANAGER => "The catalog manager does not exist.",
            ITF::FTE_E_NO_PROPERTY_STORE => "Property Store is not found in the indexer. The possible causes are that the call came during a catalog reset or that the property store plug-in failed to load during indexer initialization.",
            ITF::SL_E_SRV_INVALID_PUBLISH_LICENSE => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_INVALID_LICENSE_STRUCTURE => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_AUTHORIZATION_FAILED => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_INVALID_BINDING => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_SERVER_PONG => "The activation server reported that the computer could not connect to the activation server.",
            ITF::SL_E_SRV_INVALID_PAYLOAD => "The activation server determined that the product could not be activated.",
            ITF::SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE => "The activation server determined that the license is invalid.",
            ITF::SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND => "The activation server determined that required business token entry cannot be found.",
            ITF::SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC => "The activation server determined that your computer clock time is not correct. You must correct your clock before you can activate.",
            ITF::SL_E_SRV_GENERAL_ERROR => "The activation server determined that the product could not be activated.",
            ITF::SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE => "The activation server determined the specified product key is invalid.",
            ITF::SL_E_CHPA_INVALID_BINDING => "The activation server determined there is a problem with the specified product key.",
            ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED => "The activation server determined the specified product key has been blocked.",
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY => "The activation server determined the specified product key is invalid.",
            ITF::SL_E_CHPA_BINDING_NOT_FOUND => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_BINDING_MAPPING_NOT_FOUND => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY => "The activation server determined the specified product key is invalid.",
            ITF::SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED => "The activation server reported that the product key has exceeded its unlock limit.",
            ITF::SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_INVALID_PRODUCT_DATA_ID => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_INVALID_PRODUCT_DATA => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_SYSTEM_ERROR => "The activation server experienced an error.",
            ITF::SL_E_CHPA_INVALID_ACTCONFIG_ID => "The activation server determined the product key is not valid.",
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH => "The activation server determined the specified product key is invalid.",
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT => "The activation server determined the specified product key is invalid.",
            ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR => "The activation server determined the specified product key is invalid.",
            ITF::SL_E_CHPA_INVALID_BINDING_URI => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_NETWORK_ERROR => "The activation server experienced a network error.",
            ITF::SL_E_CHPA_DATABASE_ERROR => "The activation server experienced an error.",
            ITF::SL_E_CHPA_INVALID_ARGUMENT => "The activation server experienced an error.",
            ITF::SL_E_CHPA_RESPONSE_NOT_AVAILABLE => "The activation server experienced an error.",
            ITF::SL_E_CHPA_OEM_SLP_COA0 => "The activation server reported that the specified product key cannot be used for online activation.",
            ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION => "The activation server determined the specified product key has been blocked for this geographic location.",
            ITF::SL_E_CHPA_DMAK_LIMIT_EXCEEDED => "The activation server reported that the Multiple Activation Key has exceeded its limit.",
            ITF::SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED => "The activation server reported that the Multiple Activation Key extension limit has been exceeded.",
            ITF::SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND => "The activation server reported that the re-issuance limit was not found.",
            ITF::SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND => "The activation server reported that the override request was not found.",
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE => "The activation server reported that time based activation attempted before start date.",
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE => "The activation server reported that time based activation attempted after end date.",
            ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE => "The activation server reported that new time based activation is not available.",
            ITF::SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED => "The activation server reported that the time based product key is not configured for activation.",
            ITF::SL_E_CHPA_NO_RULES_TO_ACTIVATE => "The activation server reported that no business rules available to activate specified product key.",
            ITF::SL_E_CHPA_GENERAL_ERROR => "The activation server experienced a general error.",
            ITF::SL_E_CHPA_DIGITALMARKER_INVALID_BINDING => "The activation server determined the license is invalid.",
            ITF::SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED => "The activation server determined there is a problem with the specified product key.",
            ITF::SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY => "The activation server determined the specified product key has been blocked.",
            ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE => "Genuine Validation determined the license state is invalid.",
            ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED => "Genuine Validation determined the license state is invalid.",
            ITF::SL_E_INVALID_TEMPLATE_ID => "Genuine Validation determined the validation input template identifier is invalid.",
            ITF::SL_E_INVALID_XML_BLOB => "Genuine Validation determined the validation input data blob is invalid.",
            ITF::SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND => "Genuine Validation determined the validation input data blob parameter is invalid.",
            ITF::SL_E_INVALID_CLIENT_TOKEN => "Genuine Validation determined the client token data is invalid.",
            ITF::SL_E_INVALID_OFFLINE_BLOB => "Genuine Validation determined the offline data blob is invalid.",
            ITF::SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND => "Genuine Validation determined the offline data blob parameter is invalid.",
            ITF::SL_E_INVALID_OSVERSION_TEMPLATEID => "Genuine Validation determined the validation template identifier is invalid for this version of the Windows operating system.",
            ITF::SL_E_OFFLINE_GENUINE_BLOB_REVOKED => "Genuine Validation determined the offline genuine blob is revoked.",
            ITF::SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND => "Genuine Validation determined the offline genuine blob is not found.",
            ITF::SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA => "The activation server determined the VGA service response is not available in the expected format.",
            ITF::SL_E_INVALID_OS_FOR_PRODUCT_KEY => "Genuine Validation determined the product key is invalid for this version of the Windows operating system.",
            ITF::SL_E_INVALID_FILE_HASH => "Genuine Validation determined the file hash is invalid.",
            ITF::SL_E_VALIDATION_BLOCKED_PRODUCT_KEY => "Genuine Validation determined the product key has been blocked.",
            ITF::SL_E_MISMATCHED_KEY_TYPES => "Genuine Validation determined the product key type is invalid.",
            ITF::SL_E_VALIDATION_INVALID_PRODUCT_KEY => "Genuine Validation determined the product key is invalid.",
            ITF::SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA => "Genuine Validation determined the OEM or Volume binding data is invalid.",
            ITF::SL_E_INVALID_LICENSE_STATE => "Genuine Validation determined the license state is invalid.",
            ITF::SL_E_IP_LOCATION_FALIED => "Genuine Validation determined the specified product key has been blocked for this geographic location.",
            ITF::SL_E_SOFTMOD_EXPLOIT_DETECTED => "Genuine Validation detected Windows licensing exploits.",
            ITF::SL_E_INVALID_TOKEN_DATA => "Genuine Validation determined the token activation data is invalid.",
            ITF::SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES => "Genuine Validation detected tampered Windows binaries.",
            ITF::SL_E_HEALTH_CHECK_FAILED_MUI_FILES => "Genuine Validation detected tampered Windows binaries.",
            ITF::SL_E_INVALID_AD_DATA => "Genuine Validation determined the active directory activation data is invalid.",
            ITF::SL_E_INVALID_RSDP_COUNT => "Genuine Validation detected Windows licensing exploits.",
            ITF::SL_E_ENGINE_DETECTED_EXPLOIT => "Genuine Validation detected Windows licensing exploits.",
            ITF::SL_E_NOTIFICATION_BREACH_DETECTED => "Genuine Validation detected Windows licensing exploits.",
            ITF::SL_E_NOTIFICATION_GRACE_EXPIRED => "Genuine Validation determined the license state is in notification due to expired grace.",
            ITF::SL_E_NOTIFICATION_OTHER_REASONS => "Genuine Validation determined the license state is in notification.",
            ITF::SL_E_NON_GENUINE_STATUS_LAST => "Genuine Validation determined your copy of Windows is not genuine.",
            ITF::SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND => "The activation server reported that business rule cound not find required input.",
            ITF::SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID => "The activation server reported that NULL value specified for business property name and Id.",
            ITF::SL_E_CHPA_UNKNOWN_PROPERTY_NAME => "The activation server reported that property name specifies unknown property.",
            ITF::SL_E_CHPA_UNKNOWN_PROPERTY_ID => "The activation server reported that property Id specifies unknown property.",
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING => "The activation server reported that it failed to update product key binding.",
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING => "The activation server reported that it failed to insert product key binding.",
            ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING => "The activation server reported that it failed to delete product key binding.",
            ITF::SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML => "The activation server reported that it failed to process input XML for product key bindings.",
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY => "The activation server reported that it failed to insert product key property.",
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY => "The activation server reported that it failed to update product key property.",
            ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY => "The activation server reported that it failed to delete product key property.",
            ITF::SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE => "The activation server reported that the product key type is unknown.",
            ITF::SL_E_CHPA_PRODUCT_KEY_BEING_USED => "The activation server reported that the product key type is being used by another user.",
            ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD => "The activation server reported that it failed to insert product key record.",
            ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD => "The activation server reported that it failed to update product key record.",
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_LICENSE => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_HANDLE => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER => "Owner, write description pls.",
            ITF::SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED => "The handle was used before calling SPCommit with it.",
            ITF::SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED => "The security processor reported an initialization error.",
            ITF::SL_REMAPPING_SP_STATUS_GENERIC_FAILURE => "The security processor reported that an error has occurred.",
            ITF::SL_REMAPPING_SP_STATUS_INVALIDARG => "The security processor reported that invalid data was used.",
            ITF::SL_REMAPPING_SP_STATUS_ALREADY_EXISTS => "The security processor reported that the value already exists.",
            ITF::SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER => "The security processor reported that an insufficient buffer was used.",
            ITF::SL_REMAPPING_SP_STATUS_INVALIDDATA => "The security processor reported that invalid data was used.",
            ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL => "The security processor reported that an invalid call was made.",
            ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION => "The security processor reported a version mismatch error.",
            ITF::SL_REMAPPING_SP_STATUS_NO_MORE_DATA => "No more data is available.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH => "The length of the cryptopgraphic key material/blob is invalid.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH => "The block length is not correct for this algorithm.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER => "The Cryptopgrahic cipher/algorithm type is invalid.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE => "The specified cipher mode is invalid. For example both encrypt and decrypt cannot be specified for symmetric keys.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID => "The SPAPIID for the specified Cryptographic Provider is unknown.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID => "The SPAPIID for the specified Cryptographic Key (type) is unknown.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID => "The SPAPIID for the specified Cryptographic Hash is unknown.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID => "The SPAPIID for the specified Cryptographic Attribute is unknown.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED => "The hash object has been finalized and can no longer be updated.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE => "The key is not available within the current state.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND => "The key does not exist. It may not have have been created yet.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED => "The data length is not a multiple of the algorithm's block length.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH => "The length of the signature is not valid.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE => "The signature does not correlate with the comparison hash.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK => "The RSA block is not valid.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT => "The format of the RSA block is not valid.",
            ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING => "The CBC padding is not valid.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED => "The security processor reported that the trusted data store was tampered.",
            ITF::SL_REMAPPING_SP_PUB_TS_REARMED => "The security processor reported that the trusted data store was rearmed.",
            ITF::SL_REMAPPING_SP_PUB_TS_RECREATED => "The security processor reported that the trusted store has been recreated.",
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND => "The security processor reported that entry key was not found in the trusted data store.",
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS => "The security processor reported that the entry key already exists in the trusted data store.",
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG => "The security processor reported that the entry key is too big to fit in the trusted data store.",
            ITF::SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED => "The security processor reported that the maximum allowed number of re-arms has been exceeded. You must re-install the OS before trying to re-arm again.",
            ITF::SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG => "The security processor has reported that entry data size is too big to fit in the trusted data store.",
            ITF::SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING => "The security processor has reported that the machine has gone out of hardware tolerance.",
            ITF::SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS => "The security processor has reported that the secure timer already exists.",
            ITF::SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND => "The security processor has reported that the secure timer was not found.",
            ITF::SL_REMAPPING_SP_PUB_TIMER_EXPIRED => "The security processor has reported that the secure timer has expired.",
            ITF::SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG => "The security processor has reported that the secure timer name is too long.",
            ITF::SL_REMAPPING_SP_PUB_TS_FULL => "The security processor reported that the trusted data store is full.",
            ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY => "Read-only entry cannot be modified.",
            ITF::SL_REMAPPING_SP_PUB_TIMER_READ_ONLY => "Read-only timer cannot be modified.",
            ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY => "Read-only attribute cannot be modified.",
            ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND => "Attribute not found.",
            ITF::SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED => "Trusted Store access denied.",
            ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND => "Namespace not found.",
            ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE => "Namespace in use.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID => "Trusted store tampered.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION => "Trusted store tampered.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA => "Trusted store tampered.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA => "Trusted store tampered.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH => "Trusted store tampered.",
            ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH => "Trusted store tampered.",
            ITF::SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION => "The security processor reported a system file mismatch error.",
            ITF::SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED => "The security processor reported a system file mismatch error.",
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER => "The security processor reported an error with the kernel data.",
            ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED => "Kernel Mode Cache is tampered and the restore attempt failed.",
            ITF::SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT => "External decryption key was already set for specified feature.",
            ITF::SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER => "Error occured during proxy execution.",
            ITF::SL_E_INVALID_CONTEXT => "The Software Licensing Service determined that the specified context is invalid.",
            ITF::SL_E_TOKEN_STORE_INVALID_STATE => "The Software Licensing Service reported that the license store contains inconsistent data.",
            ITF::SL_E_EVALUATION_FAILED => "The Software Licensing Service reported that license evaluation failed.",
            ITF::SL_E_NOT_EVALUATED => "The Software Licensing Service reported that the license has not been evaluated.",
            ITF::SL_E_NOT_ACTIVATED => "The Software Licensing Service reported that the license is not activated.",
            ITF::SL_E_INVALID_GUID => "The Software Licensing Service reported that the license contains invalid data.",
            ITF::SL_E_TOKSTO_TOKEN_NOT_FOUND => "The Software Licensing Service reported that the license store does not contain the requested license.",
            ITF::SL_E_TOKSTO_NO_PROPERTIES => "The Software Licensing Service reported that the license property is invalid.",
            ITF::SL_E_TOKSTO_NOT_INITIALIZED => "The Software Licensing Service reported that the license store is not initialized.",
            ITF::SL_E_TOKSTO_ALREADY_INITIALIZED => "The Software Licensing Service reported that the license store is already initialized.",
            ITF::SL_E_TOKSTO_NO_ID_SET => "The Software Licensing Service reported that the license property is invalid.",
            ITF::SL_E_TOKSTO_CANT_CREATE_FILE => "The Software Licensing Service reported that the license could not be opened or created.",
            ITF::SL_E_TOKSTO_CANT_WRITE_TO_FILE => "The Software Licensing Service reported that the license could not be written.",
            ITF::SL_E_TOKSTO_CANT_READ_FILE => "The Software Licensing Service reported that the license store could not read the license file.",
            ITF::SL_E_TOKSTO_CANT_PARSE_PROPERTIES => "The Software Licensing Service reported that the license property is corrupted.",
            ITF::SL_E_TOKSTO_PROPERTY_NOT_FOUND => "The Software Licensing Service reported that the license property is missing.",
            ITF::SL_E_TOKSTO_INVALID_FILE => "The Software Licensing Service reported that the license store contains an invalid license file.",
            ITF::SL_E_TOKSTO_CANT_CREATE_MUTEX => "The Software Licensing Service reported that the license store failed to start synchronization properly.",
            ITF::SL_E_TOKSTO_CANT_ACQUIRE_MUTEX => "The Software Licensing Service reported that the license store failed to synchronize properly.",
            ITF::SL_E_TOKSTO_NO_TOKEN_DATA => "The Software Licensing Service reported that the license property is invalid.",
            ITF::SL_E_EUL_CONSUMPTION_FAILED => "The Software Licensing Service reported that license consumption failed.",
            ITF::SL_E_PKEY_INVALID_CONFIG => "The Software Licensing Service reported that the product key is invalid.",
            ITF::SL_E_PKEY_INVALID_UNIQUEID => "The Software Licensing Service reported that the product key is invalid.",
            ITF::SL_E_PKEY_INVALID_ALGORITHM => "The Software Licensing Service reported that the product key is invalid.",
            ITF::SL_E_PKEY_INTERNAL_ERROR => "The Software Licensing Service determined that validation of the specified product key failed.",
            ITF::SL_E_LICENSE_INVALID_ADDON_INFO => "The Software Licensing Service reported that invalid add-on information was found.",
            ITF::SL_E_HWID_ERROR => "The Software Licensing Service reported that not all hardware information could be collected.",
            ITF::SL_E_PKEY_INVALID_KEYCHANGE1 => "This evaluation product key is no longer valid.",
            ITF::SL_E_PKEY_INVALID_KEYCHANGE2 => "The new product key cannot be used on this installation of Windows. Type a different product key. (CD-AB).",
            ITF::SL_E_PKEY_INVALID_KEYCHANGE3 => "The new product key cannot be used on this installation of Windows. Type a different product key. (AB-AB).",
            ITF::SL_E_POLICY_OTHERINFO_MISMATCH => "The Software Licensing Service reported that there is a mismatched between a policy value and information stored in the OtherInfo section.",
            ITF::SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID => "The Software Licensing Service reported that the Genuine information contained in the license is not consistent.",
            ITF::SL_E_SECURE_STORE_ID_MISMATCH => "The Software Licensing Service reported that the secure store id value in license does not match with the current value.",
            ITF::SL_E_INVALID_RULESET_RULE => "The Software Licensing Service reported that the notification rules appear to be invalid.",
            ITF::SL_E_INVALID_CONTEXT_DATA => "The Software Licensing Service reported that the reported machine data appears to be invalid.",
            ITF::SL_E_INVALID_HASH => "The Software Licensing Service reported that the data hash does not correspond to the data.",
            ITF::SL_E_WINDOWS_VERSION_MISMATCH => "The Software Licensing Service reported that the version of SPPSvc does not match the policy.",
            ITF::SL_E_ACTIVATION_IN_PROGRESS => "The Software Licensing Service reported that there is another activation attempt in progress for this sku. Please wait for that attempt to complete before trying again.",
            ITF::SL_E_STORE_UPGRADE_TOKEN_REQUIRED => "The Software Licensing Service reported that the activated license requires a corresponding Store upgrade license in order to work. Please visit the Store to purchase a new license or re-download an existing one.",
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION => "The Software Licensing Service reported that the Store upgrade license is not enabled for the current OS edition. Please visit the Store to purchase the appropriate license.",
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_PID => "The Software Licensing Service reported that the Store upgrade license does not match the current active product key. Please visit the Store to purchase a new license or re-download an existing one.",
            ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED => "The Software Licensing Service reported that the Store upgrade license does not match the current signing level for the installed Operating System. Please visit the Store to purchase a new license or re-download an existing one.",
            ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION => "The Software Licensing Service reported that the Store upgrade license does not enable the current version of the installed Operating System. Please visit the Store to purchase a new license or re-download an existing one.",
            ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED => "The Software Licensing Service reported that the Store upgrade license could not be authorized. Please visit the Store to purchase a new license or re-download an existing one.",
            ITF::SL_E_INTERNAL_ERROR => "The Software Licensing Service reported an internal error.",
            ITF::SL_E_RIGHT_NOT_CONSUMED => "The Software Licensing Service reported that rights consumption failed.",
            ITF::SL_E_USE_LICENSE_NOT_INSTALLED => "The Software Licensing Service reported that the required license could not be found.",
            ITF::SL_E_MISMATCHED_PKEY_RANGE => "The Software Licensing Service reported that the product key does not match the range defined in the license.",
            ITF::SL_E_MISMATCHED_PID => "The Software Licensing Service reported that the product key does not match the product key for the license.",
            ITF::SL_E_EXTERNAL_SIGNATURE_NOT_FOUND => "The Software Licensing Service reported that the signature file for the license is not available.",
            ITF::SL_E_RAC_NOT_AVAILABLE => "The Software Licensing Service reported that the license could not be found.",
            ITF::SL_E_SPC_NOT_AVAILABLE => "The Software Licensing Service reported that the license could not be found.",
            ITF::SL_E_GRACE_TIME_EXPIRED => "The Software Licensing Service reported that the grace period expired.",
            ITF::SL_E_MISMATCHED_APPID => "The Software Licensing Service reported that the application ID does not match the application ID for the license.",
            ITF::SL_E_NO_PID_CONFIG_DATA => "The Software Licensing Service reported that the product identification data is not available.",
            ITF::SL_E_MISMATCHED_SECURITY_PROCESSOR => "The Software Licensing Service determined that the license could not be used by the current version of the security processor component.",
            ITF::SL_E_OUT_OF_TOLERANCE => "The Software Licensing Service reported that the hardware ID binding is beyond the level of tolerance.",
            ITF::SL_E_INVALID_PKEY => "The Software Licensing Service reported that the product key is invalid.",
            ITF::SL_E_LICENSE_FILE_NOT_INSTALLED => "The Software Licensing Service reported that the license file is not installed.",
            ITF::SL_E_VALUE_NOT_FOUND => "The Software Licensing Service reported that the call has failed because the value for the input key was not found.",
            ITF::SL_E_RIGHT_NOT_GRANTED => "The Software Licensing Service determined that there is no permission to run the software.",
            ITF::SL_E_PKEY_NOT_INSTALLED => "The Software Licensing Service reported that the product key is not available.",
            ITF::SL_E_PRODUCT_SKU_NOT_INSTALLED => "The Software Licensing Service reported that the license is not installed.",
            ITF::SL_E_NOT_SUPPORTED => "The Software Licensing Service determined that the request is not supported.",
            ITF::SL_E_PUBLISHING_LICENSE_NOT_INSTALLED => "The Software Licensing Service reported that the license is not installed.",
            ITF::SL_E_LICENSE_SERVER_URL_NOT_FOUND => "The Software Licensing Service reported that the license does not contain valid location data for the activation server.",
            ITF::SL_E_INVALID_EVENT_ID => "The Software Licensing Service determined that the requested event ID is invalid.",
            ITF::SL_E_EVENT_NOT_REGISTERED => "The Software Licensing Service determined that the requested event is not registered with the service.",
            ITF::SL_E_EVENT_ALREADY_REGISTERED => "The Software Licensing Service reported that the event ID is already registered.",
            ITF::SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE => "The Software Licensing Service reported that the license is not installed.",
            ITF::SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED => "The Software Licensing Service reported that the verification of the license failed.",
            ITF::SL_E_DATATYPE_MISMATCHED => "The Software Licensing Service determined that the input data type does not match the data type in the license.",
            ITF::SL_E_INVALID_LICENSE => "The Software Licensing Service determined that the license is invalid.",
            ITF::SL_E_INVALID_PACKAGE => "The Software Licensing Service determined that the license package is invalid.",
            ITF::SL_E_VALIDITY_TIME_EXPIRED => "The Software Licensing Service reported that the validity period of the license has expired.",
            ITF::SL_E_LICENSE_AUTHORIZATION_FAILED => "The Software Licensing Service reported that the license authorization failed.",
            ITF::SL_E_LICENSE_DECRYPTION_FAILED => "The Software Licensing Service reported that the license is invalid.",
            ITF::SL_E_WINDOWS_INVALID_LICENSE_STATE => "The Software Licensing Service reported that the license is invalid.",
            ITF::SL_E_LUA_ACCESSDENIED => "The Software Licensing Service reported that the action requires administrator privilege.",
            ITF::SL_E_PROXY_KEY_NOT_FOUND => "The Software Licensing Service reported that the required data is not found.",
            ITF::SL_E_TAMPER_DETECTED => "The Software Licensing Service reported that the license is tampered.",
            ITF::SL_E_POLICY_CACHE_INVALID => "The Software Licensing Service reported that the policy cache is invalid.",
            ITF::SL_E_INVALID_RUNNING_MODE => "The Software Licensing Service cannot be started in the current OS mode.",
            ITF::SL_E_SLP_NOT_SIGNED => "The Software Licensing Service reported that the license is invalid.",
            ITF::SL_E_CIDIID_INVALID_DATA => "The Software Licensing Service reported that the format for the offline activation data is incorrect.",
            ITF::SL_E_CIDIID_INVALID_VERSION => "The Software Licensing Service determined that the version of the offline Confirmation ID (CID) is incorrect.",
            ITF::SL_E_CIDIID_VERSION_NOT_SUPPORTED => "The Software Licensing Service determined that the version of the offline Confirmation ID (CID) is not supported.",
            ITF::SL_E_CIDIID_INVALID_DATA_LENGTH => "The Software Licensing Service reported that the length of the offline Confirmation ID (CID) is incorrect.",
            ITF::SL_E_CIDIID_NOT_DEPOSITED => "The Software Licensing Service determined that the Installation ID (IID) or the Confirmation ID (CID) could not been saved.",
            ITF::SL_E_CIDIID_MISMATCHED => "The Installation ID (IID) and the Confirmation ID (CID) do not match. Please confirm the IID and reacquire a new CID if necessary.",
            ITF::SL_E_INVALID_BINDING_BLOB => "The Software Licensing Service determined that the binding data is invalid.",
            ITF::SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED => "The Software Licensing Service reported that the product key is not allowed to be installed. Please see the eventlog for details.",
            ITF::SL_E_EUL_NOT_AVAILABLE => "The Software Licensing Service reported that the license could not be found or was invalid.",
            ITF::SL_E_VL_NOT_WINDOWS_SLP => "The Software Licensing Service reported that the computer could not be activated with a Volume license product key. Volume-licensed systems require upgrading from a qualifying operating system. Please contact your system administrator or use a different type of key.",
            ITF::SL_E_VL_NOT_ENOUGH_COUNT => "The Software Licensing Service reported that the product could not be activated. The count reported by your Key Management Service (KMS) is insufficient. Please contact your system administrator.",
            ITF::SL_E_VL_BINDING_SERVICE_NOT_ENABLED => "The Software Licensing Service reported that the product could not be activated. The Key Management Service (KMS) is not enabled.",
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED => "The Software Licensing Service determined that the Key Management Service (KMS) is not activated. KMS needs to be activated. Please contact system administrator.",
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH => "The Software Licensing Service determined that the specified Key Management Service (KMS) cannot be used.",
            ITF::SL_E_PROXY_POLICY_NOT_UPDATED => "The Software Licensing Service reported that the proxy policy has not been updated.",
            ITF::SL_E_CIDIID_INVALID_CHECK_DIGITS => "The Software Licensing Service determined that the Installation ID (IID) or the Confirmation ID (CID) is invalid.",
            ITF::SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND => "The Software Licensing Service reported that license management information was not found in the licenses.",
            ITF::SL_E_INVALID_PRODUCT_KEY => "The Software Licensing Service reported that the product key is invalid.",
            ITF::SL_E_BLOCKED_PRODUCT_KEY => "The Software Licensing Service reported that the product key is blocked.",
            ITF::SL_E_DUPLICATE_POLICY => "The Software Licensing Service reported that the licenses contain duplicated properties.",
            ITF::SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE => "The Software Licensing Service determined that the license is invalid. The license contains an override policy that is not configured properly.",
            ITF::SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED => "The Software Licensing Service reported that license management information has duplicated data.",
            ITF::SL_E_BASE_SKU_NOT_AVAILABLE => "The Software Licensing Service reported that the base SKU is not available.",
            ITF::SL_E_VL_MACHINE_NOT_BOUND => "The Software Licensing Service reported that the product could not be activated using the Key Management Service (KMS).",
            ITF::SL_E_SLP_MISSING_ACPI_SLIC => "The Software Licensing Service reported that the computer BIOS is missing a required license.",
            ITF::SL_E_SLP_MISSING_SLP_MARKER => "The Software Licensing Service reported that the computer BIOS is missing a required license.",
            ITF::SL_E_SLP_BAD_FORMAT => "The Software Licensing Service reported that a license in the computer BIOS is invalid.",
            ITF::SL_E_INVALID_PACKAGE_VERSION => "The Software Licensing Service determined that the version of the license package is invalid.",
            ITF::SL_E_PKEY_INVALID_UPGRADE => "The Software Licensing Service determined that this specified product key can only be used for upgrading, not for clean installations.",
            ITF::SL_E_ISSUANCE_LICENSE_NOT_INSTALLED => "The Software Licensing Service reported that a required license could not be found.",
            ITF::SL_E_SLP_OEM_CERT_MISSING => "The Software Licensing Service reported that the computer is missing a required OEM license.",
            ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED => "The Software Licensing Service reported that the non-genuine grace period expired.",
            ITF::SL_E_DEPENDENT_PROPERTY_NOT_SET => "The Software Licensing Service reported that the genuine information property can not be set before dependent property been set.",
            ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2 => "The Software Licensing Service reported that the non-genuine grace period expired (type 2).",
            ITF::SL_E_MISMATCHED_PRODUCT_SKU => "The Software Licensing Service reported that the product SKU is not found.",
            ITF::SL_E_OPERATION_NOT_ALLOWED => "The Software Licensing Service reported that the requested operation is not allowed.",
            ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED => "The Software Licensing Service determined that it is running in a virtual machine. The Key Management Service (KMS) is not supported in this mode.",
            ITF::SL_E_VL_INVALID_TIMESTAMP => "The Software Licensing Service reported that the product could not be activated. The Key Management Service (KMS) determined that the request timestamp is invalid.",
            ITF::SL_E_PLUGIN_INVALID_MANIFEST => "The Software Licensing Service reported that the plug-in manifest file is incorrect.",
            ITF::SL_E_APPLICATION_POLICIES_MISSING => "The Software Licensing Service reported that the license policies for fast query could not be found.",
            ITF::SL_E_APPLICATION_POLICIES_NOT_LOADED => "The Software Licensing Service reported that the license policies for fast query have not been loaded.",
            ITF::SL_E_VL_BINDING_SERVICE_UNAVAILABLE => "The Software Licensing Service reported that the product could not be activated. No Key Management Service (KMS) could be contacted. Please see the Application Event Log for additional information.",
            ITF::SL_E_SERVICE_STOPPING => "The Software Licensing Service reported that the operation cannot be completed because the service is stopping.",
            ITF::SL_E_PLUGIN_NOT_REGISTERED => "The Software Licensing Service reported that the requested plug-in cannot be found.",
            ITF::SL_E_AUTHN_WRONG_VERSION => "The Software Licensing Service determined incompatible version of authentication data.",
            ITF::SL_E_AUTHN_MISMATCHED_KEY => "The Software Licensing Service reported that the key is mismatched.",
            ITF::SL_E_AUTHN_CHALLENGE_NOT_SET => "The Software Licensing Service reported that the authentication data is not set.",
            ITF::SL_E_AUTHN_CANT_VERIFY => "The Software Licensing Service reported that the verification could not be done.",
            ITF::SL_E_SERVICE_RUNNING => "The requested operation is unavailable while the Software Licensing Service is running.",
            ITF::SL_E_SLP_INVALID_MARKER_VERSION => "The Software Licensing Service determined that the version of the computer BIOS is invalid.",
            ITF::SL_E_INVALID_PRODUCT_KEY_TYPE => "The Software Licensing Service reported that the product key cannot be used for this type of activation.",
            ITF::SL_E_CIDIID_MISMATCHED_PKEY => "The Installation ID (IID) and the Confirmation ID (CID) do not match the product key.",
            ITF::SL_E_CIDIID_NOT_BOUND => "The Installation ID (IID) and the Confirmation ID (CID) are not bound to the current environment.",
            ITF::SL_E_LICENSE_NOT_BOUND => "The Software Licensing Service reported that the license is not bound to the current environment.",
            ITF::SL_E_VL_AD_AO_NOT_FOUND => "The Software Licensing Service reported that the Active Directory Activation Object could not be found or was invalid.",
            ITF::SL_E_VL_AD_AO_NAME_TOO_LONG => "The Software Licensing Service reported that the name specified for the Active Directory Activation Object is too long.",
            ITF::SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED => "The Software Licensing Service reported that Active Directory-Based Activation is not supported in the current Active Directory schema.",
            ITF::SL_E_NOT_GENUINE => "The Software Licensing Service reported that current state is not genuine.",
            ITF::SL_E_EDITION_MISMATCHED => "The Software Licensing Service reported that the license edition does match the computer edition.",
            ITF::SL_E_TKA_CHALLENGE_EXPIRED => "The Software Licensing Service reported that the product could not be activated. The token-based activation challenge has expired.",
            ITF::SL_E_TKA_SILENT_ACTIVATION_FAILURE => "The Software Licensing Service reported that Silent Activation failed. The Software Licensing Service reported that there are no certificates found in the system that could activate the product without user interaction.",
            ITF::SL_E_TKA_INVALID_CERT_CHAIN => "The Software Licensing Service reported that the certificate chain could not be built or failed validation.",
            ITF::SL_E_TKA_GRANT_NOT_FOUND => "The Software Licensing Service reported that required license could not be found.",
            ITF::SL_E_TKA_CERT_NOT_FOUND => "The Software Licensing Service reported that there are no certificates found in the system that could activate the product.",
            ITF::SL_E_TKA_INVALID_SKU_ID => "The Software Licensing Service reported that this software edition does not support token-based activation.",
            ITF::SL_E_TKA_INVALID_BLOB => "The Software Licensing Service reported that the product could not be activated. Activation data is invalid.",
            ITF::SL_E_TKA_TAMPERED_CERT_CHAIN => "The Software Licensing Service reported that the product could not be activated. Activation data is tampered.",
            ITF::SL_E_TKA_CHALLENGE_MISMATCH => "The Software Licensing Service reported that the product could not be activated. Activation challenge and response do not match.",
            ITF::SL_E_TKA_INVALID_CERTIFICATE => "The Software Licensing Service reported that the product could not be activated. The certificate does not match the conditions in the license.",
            ITF::SL_E_TKA_INVALID_SMARTCARD => "The Software Licensing Service reported that the inserted smartcard could not be used to activate the product.",
            ITF::SL_E_TKA_FAILED_GRANT_PARSING => "The Software Licensing Service reported that the token-based activation license content is invalid.",
            ITF::SL_E_TKA_INVALID_THUMBPRINT => "The Software Licensing Service reported that the product could not be activated. The thumbprint is invalid.",
            ITF::SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND => "The Software Licensing Service reported that the product could not be activated. The thumbprint does not match any certificate.",
            ITF::SL_E_TKA_CRITERIA_MISMATCH => "The Software Licensing Service reported that the product could not be activated. The certificate does not match the criteria specified in the issuance license.",
            ITF::SL_E_TKA_TPID_MISMATCH => "The Software Licensing Service reported that the product could not be activated. The certificate does not match the trust point identifier (TPID) specified in the issuance license.",
            ITF::SL_E_TKA_SOFT_CERT_DISALLOWED => "The Software Licensing Service reported that the product could not be activated. A soft token cannot be used for activation.",
            ITF::SL_E_TKA_SOFT_CERT_INVALID => "The Software Licensing Service reported that the product could not be activated. The certificate cannot be used because its private key is exportable.",
            ITF::SL_E_TKA_CERT_CNG_NOT_AVAILABLE => "The Software Licensing Service reported that the CNG encryption library could not be loaded. The current certificate may not be available on this version of Windows.",
            ITF::E_RM_UNKNOWN_ERROR => "A networking problem has occurred while activating your copy of Windows.",
            ITF::SL_E_VALIDITY_PERIOD_EXPIRED => "The Software Licensing Service reported that the validity period expired.",
            ITF::SL_E_IA_THROTTLE_LIMIT_EXCEEDED => "You've reached the request limit for automatic virtual machine activation. Try again later.",
            ITF::SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM => "Windows isn't running on a supported Microsoft Hyper-V virtualization platform.",
            ITF::SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED => "Windows isn't activated on the host machine. Please contact your system administrator.",
            ITF::SL_E_IA_ID_MISMATCH => "The host machine can't activate the edition of Windows on the virtual machine.",
            ITF::SL_E_IA_MACHINE_NOT_BOUND => "Windows isn't activated.",
            ITF::SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION => "The Software Licensing Service reported that activation is required to recover from tampering of SL Service trusted store.",
        }
    }

    pub fn from_name(name: &str) -> ITF {
        return match name {
            "OLE_S_USEREG" => ITF::OLE_S_USEREG,
            "OLE_S_STATIC" => ITF::OLE_S_STATIC,
            "MS_S_PENDING" => ITF::MS_S_PENDING,
            "OLE_S_MAC_CLIPFORMAT" => ITF::OLE_S_MAC_CLIPFORMAT,
            "MS_S_NOUPDATE" => ITF::MS_S_NOUPDATE,
            "MS_S_ENDOFSTREAM" => ITF::MS_S_ENDOFSTREAM,
            "OLE_S_LAST" => ITF::OLE_S_LAST,
            "DRAGDROP_S_DROP" => ITF::DRAGDROP_S_DROP,
            "DRAGDROP_S_CANCEL" => ITF::DRAGDROP_S_CANCEL,
            "DRAGDROP_S_USEDEFAULTCURSORS" => ITF::DRAGDROP_S_USEDEFAULTCURSORS,
            "VFW_S_NO_MORE_ITEMS" => ITF::VFW_S_NO_MORE_ITEMS,
            "DATA_S_SAMEFORMATETC" => ITF::DATA_S_SAMEFORMATETC,
            "VIEW_S_ALREADY_FROZEN" => ITF::VIEW_S_ALREADY_FROZEN,
            "CACHE_S_FORMATETC_NOTSUPPORTED" => ITF::CACHE_S_FORMATETC_NOTSUPPORTED,
            "CACHE_S_SAMECACHE" => ITF::CACHE_S_SAMECACHE,
            "CACHE_S_SOMECACHES_NOTUPDATED" => ITF::CACHE_S_SOMECACHES_NOTUPDATED,
            "OLEOBJ_S_INVALIDVERB" => ITF::OLEOBJ_S_INVALIDVERB,
            "OLEOBJ_S_CANNOT_DOVERB_NOW" => ITF::OLEOBJ_S_CANNOT_DOVERB_NOW,
            "OLEOBJ_S_INVALIDHWND" => ITF::OLEOBJ_S_INVALIDHWND,
            "INPLACE_S_TRUNCATED" => ITF::INPLACE_S_TRUNCATED,
            "CONVERT10_S_NO_PRESENTATION" => ITF::CONVERT10_S_NO_PRESENTATION,
            "MK_S_REDUCED_TO_SELF" => ITF::MK_S_REDUCED_TO_SELF,
            "MK_S_ME" => ITF::MK_S_ME,
            "MK_S_HIM" => ITF::MK_S_HIM,
            "MK_S_US" => ITF::MK_S_US,
            "MK_S_MONIKERALREADYREGISTERED" => ITF::MK_S_MONIKERALREADYREGISTERED,
            "MK_S_ASYNCHRONOUS" => ITF::MK_S_ASYNCHRONOUS,
            "EVENT_S_SOME_SUBSCRIBERS_FAILED" => ITF::EVENT_S_SOME_SUBSCRIBERS_FAILED,
            "IMAPI_S_PROPERTIESIGNORED" => ITF::IMAPI_S_PROPERTIESIGNORED,
            "MPEG2_S_MORE_DATA_AVAILABLE" => ITF::MPEG2_S_MORE_DATA_AVAILABLE,
            "IMAPI_S_BUFFER_TO_SMALL" => ITF::IMAPI_S_BUFFER_TO_SMALL,
            "MPEG2_S_NO_MORE_DATA_AVAILABLE" => ITF::MPEG2_S_NO_MORE_DATA_AVAILABLE,
            "EVENT_S_NOSUBSCRIBERS" => ITF::EVENT_S_NOSUBSCRIBERS,
            "MPEG2_S_SG_INFO_FOUND" => ITF::MPEG2_S_SG_INFO_FOUND,
            "_MAPI_W_NO_SERVICE" => ITF::_MAPI_W_NO_SERVICE,
            "MPEG2_S_SG_INFO_NOT_FOUND" => ITF::MPEG2_S_SG_INFO_NOT_FOUND,
            "MPEG2_S_MPE_INFO_FOUND" => ITF::MPEG2_S_MPE_INFO_FOUND,
            "MPEG2_S_MPE_INFO_NOT_FOUND" => ITF::MPEG2_S_MPE_INFO_NOT_FOUND,
            "MPEG2_S_NEW_MODULE_VERSION" => ITF::MPEG2_S_NEW_MODULE_VERSION,
            "VFW_S_DUPLICATE_NAME" => ITF::VFW_S_DUPLICATE_NAME,
            "VFW_S_STATE_INTERMEDIATE" => ITF::VFW_S_STATE_INTERMEDIATE,
            "VFW_S_PARTIAL_RENDER" => ITF::VFW_S_PARTIAL_RENDER,
            "VFW_S_SOME_DATA_IGNORED" => ITF::VFW_S_SOME_DATA_IGNORED,
            "VFW_S_CONNECTIONS_DEFERRED" => ITF::VFW_S_CONNECTIONS_DEFERRED,
            "VFW_S_RESOURCE_NOT_NEEDED" => ITF::VFW_S_RESOURCE_NOT_NEEDED,
            "TPC_S_TRUNCATED" => ITF::TPC_S_TRUNCATED,
            "TPC_S_INTERRUPTED" => ITF::TPC_S_INTERRUPTED,
            "TPC_S_NO_DATA_TO_PROCESS" => ITF::TPC_S_NO_DATA_TO_PROCESS,
            "VFW_S_MEDIA_TYPE_IGNORED" => ITF::VFW_S_MEDIA_TYPE_IGNORED,
            "VFW_S_VIDEO_NOT_RENDERED" => ITF::VFW_S_VIDEO_NOT_RENDERED,
            "VFW_S_AUDIO_NOT_RENDERED" => ITF::VFW_S_AUDIO_NOT_RENDERED,
            "VFW_S_RPZA" => ITF::VFW_S_RPZA,
            "VFW_S_ESTIMATED" => ITF::VFW_S_ESTIMATED,
            "VFW_S_RESERVED" => ITF::VFW_S_RESERVED,
            "VFW_S_STREAM_OFF" => ITF::VFW_S_STREAM_OFF,
            "VFW_S_CANT_CUE" => ITF::VFW_S_CANT_CUE,
            "VFW_S_NOPREVIEWPIN" => ITF::VFW_S_NOPREVIEWPIN,
            "VFW_S_DVD_NON_ONE_SEQUENTIAL" => ITF::VFW_S_DVD_NON_ONE_SEQUENTIAL,
            "VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE" => ITF::VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE,
            "VFW_S_DVD_NOT_ACCURATE" => ITF::VFW_S_DVD_NOT_ACCURATE,
            "TF_S_ASYNC" => ITF::TF_S_ASYNC,
            "TS_S_ASYNC" => ITF::TS_S_ASYNC,
            "CM_S_NODATASERVERS" => ITF::CM_S_NODATASERVERS,
            "QRY_S_NOROWSFOUND" => ITF::QRY_S_NOROWSFOUND,
            "QRY_S_TERMIGNORED" => ITF::QRY_S_TERMIGNORED,
            "QRY_S_INEXACTRESULTS" => ITF::QRY_S_INEXACTRESULTS,
            "IDS_MON_DEFAULT_ERROR" => ITF::IDS_MON_DEFAULT_ERROR,
            "IDS_MON_ILLEGAL_PASSTHROUGH" => ITF::IDS_MON_ILLEGAL_PASSTHROUGH,
            "IDS_MON_PARSE_ERR_1_PARAM" => ITF::IDS_MON_PARSE_ERR_1_PARAM,
            "IDS_MON_PARSE_ERR_2_PARAM" => ITF::IDS_MON_PARSE_ERR_2_PARAM,
            "IDS_MON_SEMI_COLON" => ITF::IDS_MON_SEMI_COLON,
            "IDS_MON_ORDINAL_OUT_OF_RANGE" => ITF::IDS_MON_ORDINAL_OUT_OF_RANGE,
            "IDS_MON_VIEW_NOT_DEFINED" => ITF::IDS_MON_VIEW_NOT_DEFINED,
            "IDS_MON_COLUMN_NOT_DEFINED" => ITF::IDS_MON_COLUMN_NOT_DEFINED,
            "IDS_MON_BUILTIN_VIEW" => ITF::IDS_MON_BUILTIN_VIEW,
            "IDS_MON_OUT_OF_MEMORY" => ITF::IDS_MON_OUT_OF_MEMORY,
            "IDS_MON_SELECT_STAR" => ITF::IDS_MON_SELECT_STAR,
            "IDS_MON_OR_NOT" => ITF::IDS_MON_OR_NOT,
            "IDS_MON_CANNOT_CONVERT" => ITF::IDS_MON_CANNOT_CONVERT,
            "IDS_MON_OUT_OF_RANGE" => ITF::IDS_MON_OUT_OF_RANGE,
            "IDS_MON_RELATIVE_INTERVAL" => ITF::IDS_MON_RELATIVE_INTERVAL,
            "IDS_MON_NOT_COLUMN_OF_VIEW" => ITF::IDS_MON_NOT_COLUMN_OF_VIEW,
            "IDS_MON_BUILTIN_PROPERTY" => ITF::IDS_MON_BUILTIN_PROPERTY,
            "IDS_MON_WEIGHT_OUT_OF_RANGE" => ITF::IDS_MON_WEIGHT_OUT_OF_RANGE,
            "IDS_MON_MATCH_STRING" => ITF::IDS_MON_MATCH_STRING,
            "IDS_MON_PROPERTY_NAME_IN_VIEW" => ITF::IDS_MON_PROPERTY_NAME_IN_VIEW,
            "IDS_MON_VIEW_ALREADY_DEFINED" => ITF::IDS_MON_VIEW_ALREADY_DEFINED,
            "IDS_MON_INVALID_CATALOG" => ITF::IDS_MON_INVALID_CATALOG,
            "IDS_MON_INVALIDSELECT_COALESCE" => ITF::IDS_MON_INVALIDSELECT_COALESCE,
            "IDS_MON_CANNOT_CAST" => ITF::IDS_MON_CANNOT_CAST,
            "IDS_MON_DATE_OUT_OF_RANGE" => ITF::IDS_MON_DATE_OUT_OF_RANGE,
            "IDS_MON_INVALID_IN_GROUP_CLAUSE" => ITF::IDS_MON_INVALID_IN_GROUP_CLAUSE,
            "GTHR_S_STATUS_CHANGE_IGNORED" => ITF::GTHR_S_STATUS_CHANGE_IGNORED,
            "GTHR_S_STATUS_END_CRAWL" => ITF::GTHR_S_STATUS_END_CRAWL,
            "GTHR_S_STATUS_RESET" => ITF::GTHR_S_STATUS_RESET,
            "GTHR_S_STATUS_THROTTLE" => ITF::GTHR_S_STATUS_THROTTLE,
            "GTHR_S_STATUS_RESUME" => ITF::GTHR_S_STATUS_RESUME,
            "GTHR_S_STATUS_PAUSE" => ITF::GTHR_S_STATUS_PAUSE,
            "GTHR_S_END_STD_CHUNKS" => ITF::GTHR_S_END_STD_CHUNKS,
            "GTHR_S_NO_CRAWL_SEEDS" => ITF::GTHR_S_NO_CRAWL_SEEDS,
            "GTHR_S_CANNOT_FILTER" => ITF::GTHR_S_CANNOT_FILTER,
            "GTHR_S_STATUS_STOP" => ITF::GTHR_S_STATUS_STOP,
            "GTHR_S_STATUS_START" => ITF::GTHR_S_STATUS_START,
            "GTHR_S_CONFIG_HAS_ACCOUNTS" => ITF::GTHR_S_CONFIG_HAS_ACCOUNTS,
            "GTHR_S_PROB_NOT_MODIFIED" => ITF::GTHR_S_PROB_NOT_MODIFIED,
            "GTHR_S_CRAWL_SCHEDULED" => ITF::GTHR_S_CRAWL_SCHEDULED,
            "GTHR_S_TRANSACTION_IGNORED" => ITF::GTHR_S_TRANSACTION_IGNORED,
            "GTHR_S_START_FILTER_FROM_PROTOCOL" => ITF::GTHR_S_START_FILTER_FROM_PROTOCOL,
            "GTHR_S_BAD_FILE_LINK" => ITF::GTHR_S_BAD_FILE_LINK,
            "GTHR_S_NOT_ALL_PARTS" => ITF::GTHR_S_NOT_ALL_PARTS,
            "GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE" => ITF::GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE,
            "GTHR_S_START_FILTER_FROM_BODY" => ITF::GTHR_S_START_FILTER_FROM_BODY,
            "GTHR_S_MODIFIED_PARTS" => ITF::GTHR_S_MODIFIED_PARTS,
            "GTHR_S_CRAWL_FULL" => ITF::GTHR_S_CRAWL_FULL,
            "GTHR_S_CRAWL_INCREMENTAL" => ITF::GTHR_S_CRAWL_INCREMENTAL,
            "GTHR_S_CRAWL_ADAPTIVE" => ITF::GTHR_S_CRAWL_ADAPTIVE,
            "GTHR_S_NO_INDEX" => ITF::GTHR_S_NO_INDEX,
            "GTHR_S_PAUSE_REASON_EXTERNAL" => ITF::GTHR_S_PAUSE_REASON_EXTERNAL,
            "GTHR_S_PAUSE_REASON_UPGRADING" => ITF::GTHR_S_PAUSE_REASON_UPGRADING,
            "GTHR_S_PAUSE_REASON_BACKOFF" => ITF::GTHR_S_PAUSE_REASON_BACKOFF,
            "GTHR_S_OFFICE_CHILD" => ITF::GTHR_S_OFFICE_CHILD,
            "GTHR_S_CANNOT_WORDBREAK" => ITF::GTHR_S_CANNOT_WORDBREAK,
            "GTHR_S_USE_MIME_FILTER" => ITF::GTHR_S_USE_MIME_FILTER,
            "GTHR_S_PAUSE_REASON_PROFILE_IMPORT" => ITF::GTHR_S_PAUSE_REASON_PROFILE_IMPORT,
            "DB_S_ROWLIMITEXCEEDED" => ITF::DB_S_ROWLIMITEXCEEDED,
            "DB_S_COLUMNTYPEMISMATCH" => ITF::DB_S_COLUMNTYPEMISMATCH,
            "DB_S_TYPEINFOOVERRIDDEN" => ITF::DB_S_TYPEINFOOVERRIDDEN,
            "DB_S_BOOKMARKSKIPPED" => ITF::DB_S_BOOKMARKSKIPPED,
            "DB_S_NONEXTROWSET" => ITF::DB_S_NONEXTROWSET,
            "DB_S_ENDOFROWSET" => ITF::DB_S_ENDOFROWSET,
            "DB_S_COMMANDREEXECUTED" => ITF::DB_S_COMMANDREEXECUTED,
            "DB_S_BUFFERFULL" => ITF::DB_S_BUFFERFULL,
            "DB_S_NORESULT" => ITF::DB_S_NORESULT,
            "DB_S_CANTRELEASE" => ITF::DB_S_CANTRELEASE,
            "DB_S_GOALCHANGED" => ITF::DB_S_GOALCHANGED,
            "DB_S_UNWANTEDOPERATION" => ITF::DB_S_UNWANTEDOPERATION,
            "DB_S_DIALECTIGNORED" => ITF::DB_S_DIALECTIGNORED,
            "DB_S_UNWANTEDPHASE" => ITF::DB_S_UNWANTEDPHASE,
            "DB_S_UNWANTEDREASON" => ITF::DB_S_UNWANTEDREASON,
            "DB_S_ASYNCHRONOUS" => ITF::DB_S_ASYNCHRONOUS,
            "DB_S_COLUMNSCHANGED" => ITF::DB_S_COLUMNSCHANGED,
            "DB_S_ERRORSRETURNED" => ITF::DB_S_ERRORSRETURNED,
            "DB_S_BADROWHANDLE" => ITF::DB_S_BADROWHANDLE,
            "DB_S_DELETEDROW" => ITF::DB_S_DELETEDROW,
            "DB_S_TOOMANYCHANGES" => ITF::DB_S_TOOMANYCHANGES,
            "DB_S_STOPLIMITREACHED" => ITF::DB_S_STOPLIMITREACHED,
            "DB_S_NOTSINGLETON" => ITF::DB_S_NOTSINGLETON,
            "DB_S_LOCKUPGRADED" => ITF::DB_S_LOCKUPGRADED,
            "DB_S_PROPERTIESCHANGED" => ITF::DB_S_PROPERTIESCHANGED,
            "DB_S_ERRORSOCCURRED" => ITF::DB_S_ERRORSOCCURRED,
            "DB_S_PARAMUNAVAILABLE" => ITF::DB_S_PARAMUNAVAILABLE,
            "DB_S_MULTIPLECHANGES" => ITF::DB_S_MULTIPLECHANGES,
            "DB_S_NOROWSPECIFICCOLUMNS" => ITF::DB_S_NOROWSPECIFICCOLUMNS,
            "REC_S_IDIDTHEUPDATES" => ITF::REC_S_IDIDTHEUPDATES,
            "REC_S_NOTCOMPLETE" => ITF::REC_S_NOTCOMPLETE,
            "SEO_S_MOREDATA" => ITF::SEO_S_MOREDATA,
            "REC_S_NOTCOMPLETEBUTPROPAGATE" => ITF::REC_S_NOTCOMPLETEBUTPROPAGATE,
            "IDX_S_NO_BUILD_IN_PROGRESS" => ITF::IDX_S_NO_BUILD_IN_PROGRESS,
            "IDX_S_SEARCH_SERVER_ALREADY_EXISTS" => ITF::IDX_S_SEARCH_SERVER_ALREADY_EXISTS,
            "IDX_S_SEARCH_SERVER_DOES_NOT_EXIST" => ITF::IDX_S_SEARCH_SERVER_DOES_NOT_EXIST,
            "IDX_S_DSS_NOT_AVAILABLE" => ITF::IDX_S_DSS_NOT_AVAILABLE,
            "JPS_S_DUPLICATE_DOC_DETECTED" => ITF::JPS_S_DUPLICATE_DOC_DETECTED,
            "PRTH_S_NOT_MODIFIED" => ITF::PRTH_S_NOT_MODIFIED,
            "PRTH_S_MAX_GROWTH" => ITF::PRTH_S_MAX_GROWTH,
            "PRTH_S_MAX_DOWNLOAD" => ITF::PRTH_S_MAX_DOWNLOAD,
            "PRTH_S_ACL_IS_READ_EVERYONE" => ITF::PRTH_S_ACL_IS_READ_EVERYONE,
            "PRTH_S_USE_ROSEBUD" => ITF::PRTH_S_USE_ROSEBUD,
            "PRTH_S_NOT_ALL_PARTS" => ITF::PRTH_S_NOT_ALL_PARTS,
            "PRTH_S_TRY_IMPERSONATING" => ITF::PRTH_S_TRY_IMPERSONATING,
            "SCHED_S_TASK_READY" => ITF::SCHED_S_TASK_READY,
            "SCHED_S_TASK_RUNNING" => ITF::SCHED_S_TASK_RUNNING,
            "SCHED_S_TASK_DISABLED" => ITF::SCHED_S_TASK_DISABLED,
            "SCHED_S_TASK_HAS_NOT_RUN" => ITF::SCHED_S_TASK_HAS_NOT_RUN,
            "SCHED_S_TASK_NO_MORE_RUNS" => ITF::SCHED_S_TASK_NO_MORE_RUNS,
            "SCHED_S_TASK_NOT_SCHEDULED" => ITF::SCHED_S_TASK_NOT_SCHEDULED,
            "SCHED_S_TASK_TERMINATED" => ITF::SCHED_S_TASK_TERMINATED,
            "SCHED_S_TASK_NO_VALID_TRIGGERS" => ITF::SCHED_S_TASK_NO_VALID_TRIGGERS,
            "SCHED_S_EVENT_TRIGGER" => ITF::SCHED_S_EVENT_TRIGGER,
            "SCHED_S_SOME_TRIGGERS_FAILED" => ITF::SCHED_S_SOME_TRIGGERS_FAILED,
            "SCHED_S_BATCH_LOGON_PROBLEM" => ITF::SCHED_S_BATCH_LOGON_PROBLEM,
            "SCHED_S_TASK_QUEUED" => ITF::SCHED_S_TASK_QUEUED,
            "QPLIST_S_DUPLICATE" => ITF::QPLIST_S_DUPLICATE,
            "FDAEMON_W_WORDLISTFULL" => ITF::FDAEMON_W_WORDLISTFULL,
            "FDAEMON_W_EMPTYWORDLIST" => ITF::FDAEMON_W_EMPTYWORDLIST,
            "SEARCH_S_NOMOREHITS" => ITF::SEARCH_S_NOMOREHITS,
            "FILTER_W_MONIKER_CLIPPED" => ITF::FILTER_W_MONIKER_CLIPPED,
            "FILTER_S_LAST_TEXT" => ITF::FILTER_S_LAST_TEXT,
            "FILTER_S_LAST_VALUES" => ITF::FILTER_S_LAST_VALUES,
            "FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE" => ITF::FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE,
            "FILTER_S_FULL_CONTENTSCAN_IMMEDIATE" => ITF::FILTER_S_FULL_CONTENTSCAN_IMMEDIATE,
            "FILTER_S_CONTENTSCAN_DELAYED" => ITF::FILTER_S_CONTENTSCAN_DELAYED,
            "FILTER_S_DISK_FULL" => ITF::FILTER_S_DISK_FULL,
            "FILTER_S_NO_PROPSETS" => ITF::FILTER_S_NO_PROPSETS,
            "FILTER_S_NO_SECURITY_DESCRIPTOR" => ITF::FILTER_S_NO_SECURITY_DESCRIPTOR,
            "LANGUAGE_S_LARGE_WORD" => ITF::LANGUAGE_S_LARGE_WORD,
            "PSINK_S_LARGE_WORD" => ITF::PSINK_S_LARGE_WORD,
            "CI_S_WORKID_DELETED" => ITF::CI_S_WORKID_DELETED,
            "CI_S_END_OF_ENUMERATION" => ITF::CI_S_END_OF_ENUMERATION,
            "CI_S_NO_DOCSTORE" => ITF::CI_S_NO_DOCSTORE,
            "CI_S_CAT_STOPPED" => ITF::CI_S_CAT_STOPPED,
            "CI_S_NEW_AUXMETADATA" => ITF::CI_S_NEW_AUXMETADATA,
            "CI_S_CLIENT_REQUESTED_ABORT" => ITF::CI_S_CLIENT_REQUESTED_ABORT,
            "CI_S_RETRY_DOCUMENT" => ITF::CI_S_RETRY_DOCUMENT,
            "CI_S_CATALOG_RESET" => ITF::CI_S_CATALOG_RESET,
            "NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED" => ITF::NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED,
            "VSS_S_ASYNC_PENDING" => ITF::VSS_S_ASYNC_PENDING,
            "VSS_S_ASYNC_FINISHED" => ITF::VSS_S_ASYNC_FINISHED,
            "VSS_S_ASYNC_CANCELLED" => ITF::VSS_S_ASYNC_CANCELLED,
            "VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED" => ITF::VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED,
            "VDS_S_DISK_PARTIALLY_CLEANED" => ITF::VDS_S_DISK_PARTIALLY_CLEANED,
            "VDS_S_PROVIDER_ERROR_LOADING_CACHE" => ITF::VDS_S_PROVIDER_ERROR_LOADING_CACHE,
            "VDS_S_UPDATE_BOOTFILE_FAILED" => ITF::VDS_S_UPDATE_BOOTFILE_FAILED,
            "VDS_S_BOOT_PARTITION_NUMBER_CHANGE" => ITF::VDS_S_BOOT_PARTITION_NUMBER_CHANGE,
            "VDS_S_VOLUME_COMPRESS_FAILED" => ITF::VDS_S_VOLUME_COMPRESS_FAILED,
            "VDS_S_IN_PROGRESS" => ITF::VDS_S_IN_PROGRESS,
            "VDS_S_IA64_BOOT_MIRRORED_TO_MBR" => ITF::VDS_S_IA64_BOOT_MIRRORED_TO_MBR,
            "VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES" => ITF::VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES,
            "VDS_S_EXTEND_FILE_SYSTEM_FAILED" => ITF::VDS_S_EXTEND_FILE_SYSTEM_FAILED,
            "VDS_S_MBR_BOOT_MIRRORED_TO_GPT" => ITF::VDS_S_MBR_BOOT_MIRRORED_TO_GPT,
            "VDS_S_DISK_IS_MISSING" => ITF::VDS_S_DISK_IS_MISSING,
            "VDS_S_NONCONFORMANT_PARTITION_INFO" => ITF::VDS_S_NONCONFORMANT_PARTITION_INFO,
            "VDS_S_SYSTEM_PARTITION" => ITF::VDS_S_SYSTEM_PARTITION,
            "VDS_S_NO_NOTIFICATION" => ITF::VDS_S_NO_NOTIFICATION,
            "VDS_S_DEFAULT_PLEX_MEMBER_IDS" => ITF::VDS_S_DEFAULT_PLEX_MEMBER_IDS,
            "VDS_S_DISMOUNT_FAILED" => ITF::VDS_S_DISMOUNT_FAILED,
            "VDS_S_REMOUNT_FAILED" => ITF::VDS_S_REMOUNT_FAILED,
            "VDS_S_RESYNC_NOTIFICATION_TASK_FAILED" => ITF::VDS_S_RESYNC_NOTIFICATION_TASK_FAILED,
            "VDS_S_VSS_FLUSH_AND_HOLD_WRITES" => ITF::VDS_S_VSS_FLUSH_AND_HOLD_WRITES,
            "VDS_S_VSS_RELEASE_WRITES" => ITF::VDS_S_VSS_RELEASE_WRITES,
            "VDS_S_FS_LOCK" => ITF::VDS_S_FS_LOCK,
            "VDS_S_PLEX_NOT_LOADED_TO_CACHE" => ITF::VDS_S_PLEX_NOT_LOADED_TO_CACHE,
            "VDS_S_WINPE_BOOTENTRY" => ITF::VDS_S_WINPE_BOOTENTRY,
            "NOTESPH_S_IGNORE_ID" => ITF::NOTESPH_S_IGNORE_ID,
            "NOTESPH_S_LISTKNOWNFIELDS" => ITF::NOTESPH_S_LISTKNOWNFIELDS,
            "VDS_S_NAME_TRUNCATED" => ITF::VDS_S_NAME_TRUNCATED,
            "VDS_S_STATUSES_INCOMPLETELY_SET" => ITF::VDS_S_STATUSES_INCOMPLETELY_SET,
            "VDS_S_ALREADY_EXISTS" => ITF::VDS_S_ALREADY_EXISTS,
            "VDS_S_PROPERTIES_INCOMPLETE" => ITF::VDS_S_PROPERTIES_INCOMPLETE,
            "VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED" => ITF::VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED,
            "VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED" => ITF::VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED,
            "VDS_S_ISCSI_LOGIN_ALREAD_EXISTS" => ITF::VDS_S_ISCSI_LOGIN_ALREAD_EXISTS,
            "VDS_S_DISK_MOUNT_FAILED" => ITF::VDS_S_DISK_MOUNT_FAILED,
            "VDS_S_DISK_DISMOUNT_FAILED" => ITF::VDS_S_DISK_DISMOUNT_FAILED,
            "REXSPH_S_REDIRECTED" => ITF::REXSPH_S_REDIRECTED,
            "FTE_S_RESOURCES_STARTING_TO_GET_LOW" => ITF::FTE_S_RESOURCES_STARTING_TO_GET_LOW,
            "FTE_S_BEYOND_QUOTA" => ITF::FTE_S_BEYOND_QUOTA,
            "FTE_S_REDUNDANT" => ITF::FTE_S_REDUNDANT,
            "FTE_S_STATUS_CHANGE_REQUEST" => ITF::FTE_S_STATUS_CHANGE_REQUEST,
            "FTE_S_RESUME" => ITF::FTE_S_RESUME,
            "FTE_S_PROPERTY_STORE_END_OF_ENUMERATION" => ITF::FTE_S_PROPERTY_STORE_END_OF_ENUMERATION,
            "FTE_S_READONLY_CATALOG" => ITF::FTE_S_READONLY_CATALOG,
            "FTE_S_TRY_TO_FLUSH" => ITF::FTE_S_TRY_TO_FLUSH,
            "FTE_S_CATALOG_BLOB_MISMATCHED" => ITF::FTE_S_CATALOG_BLOB_MISMATCHED,
            "FTE_S_PROPERTY_RESET" => ITF::FTE_S_PROPERTY_RESET,
            "VDS_S_ACCESS_PATH_NOT_DELETED" => ITF::VDS_S_ACCESS_PATH_NOT_DELETED,
            "SP_END_OF_STREAM" => ITF::SP_END_OF_STREAM,
            "SP_INSUFFICIENTDATA" => ITF::SP_INSUFFICIENTDATA,
            "SP_AUDIO_PAUSED" => ITF::SP_AUDIO_PAUSED,
            "SP_AUDIO_CONVERSION_ENABLED" => ITF::SP_AUDIO_CONVERSION_ENABLED,
            "SP_NO_HYPOTHESIS_AVAILABLE" => ITF::SP_NO_HYPOTHESIS_AVAILABLE,
            "SP_ALREADY_IN_LEX" => ITF::SP_ALREADY_IN_LEX,
            "SP_LEX_NOTHING_TO_SYNC" => ITF::SP_LEX_NOTHING_TO_SYNC,
            "SP_REQUEST_PENDING" => ITF::SP_REQUEST_PENDING,
            "SP_NO_PARSE_FOUND" => ITF::SP_NO_PARSE_FOUND,
            "SP_UNSUPPORTED_ON_STREAM_INPUT" => ITF::SP_UNSUPPORTED_ON_STREAM_INPUT,
            "SP_WORD_EXISTS_WITHOUT_PRONUNCIATION" => ITF::SP_WORD_EXISTS_WITHOUT_PRONUNCIATION,
            "SP_RECOGNIZER_INACTIVE" => ITF::SP_RECOGNIZER_INACTIVE,
            "SP_PARTIAL_PARSE_FOUND" => ITF::SP_PARTIAL_PARSE_FOUND,
            "SP_NO_RULE_ACTIVE" => ITF::SP_NO_RULE_ACTIVE,
            "SP_STREAM_UNINITIALIZED" => ITF::SP_STREAM_UNINITIALIZED,
            "SP_AUDIO_STOPPED" => ITF::SP_AUDIO_STOPPED,
            "SP_COMPLETE_BUT_EXTENDABLE" => ITF::SP_COMPLETE_BUT_EXTENDABLE,
            "SP_NO_RULES_TO_ACTIVATE" => ITF::SP_NO_RULES_TO_ACTIVATE,
            "SP_NO_WORDENTRY_NOTIFICATION" => ITF::SP_NO_WORDENTRY_NOTIFICATION,
            "S_LIMIT_REACHED" => ITF::S_LIMIT_REACHED,
            "S_NOTSUPPORTED" => ITF::S_NOTSUPPORTED,
            "FSRM_S_PARTIAL_BATCH" => ITF::FSRM_S_PARTIAL_BATCH,
            "FSRM_S_PARTIAL_CLASSIFICATION" => ITF::FSRM_S_PARTIAL_CLASSIFICATION,
            "FSRM_S_CLASSIFICATION_SCAN_FAILURES" => ITF::FSRM_S_CLASSIFICATION_SCAN_FAILURES,
            "FSRM_E_AUTO_QUOTA" => ITF::FSRM_E_AUTO_QUOTA,
            "NETCFG_S_REBOOT" => ITF::NETCFG_S_REBOOT,
            "NETCFG_S_DISABLE_QUERY" => ITF::NETCFG_S_DISABLE_QUERY,
            "NETCFG_S_STILL_REFERENCED" => ITF::NETCFG_S_STILL_REFERENCED,
            "NETCFG_S_CAUSED_SETUP_CHANGE" => ITF::NETCFG_S_CAUSED_SETUP_CHANGE,
            "NETCFG_S_COMMIT_NOW" => ITF::NETCFG_S_COMMIT_NOW,
            "XACT_S_ASYNC" => ITF::XACT_S_ASYNC,
            "XACT_S_DEFECT" => ITF::XACT_S_DEFECT,
            "XACT_S_READONLY" => ITF::XACT_S_READONLY,
            "XACT_S_SOMENORETAIN" => ITF::XACT_S_SOMENORETAIN,
            "XACT_S_OKINFORM" => ITF::XACT_S_OKINFORM,
            "XACT_S_MADECHANGESCONTENT" => ITF::XACT_S_MADECHANGESCONTENT,
            "XACT_S_MADECHANGESINFORM" => ITF::XACT_S_MADECHANGESINFORM,
            "XACT_S_ALLNORETAIN" => ITF::XACT_S_ALLNORETAIN,
            "XACT_S_ABORTING" => ITF::XACT_S_ABORTING,
            "XACT_S_SINGLEPHASE" => ITF::XACT_S_SINGLEPHASE,
            "XACT_S_LOCALLY_OK" => ITF::XACT_S_LOCALLY_OK,
            "XACT_S_LASTRESOURCEMANAGER" => ITF::XACT_S_LASTRESOURCEMANAGER,
            "S_DEVCAP_OUTPUT_FULL_REPLACEMENT" => ITF::S_DEVCAP_OUTPUT_FULL_REPLACEMENT,
            "IO_FILE_QUOTA_THRESHOLD" => ITF::IO_FILE_QUOTA_THRESHOLD,
            "IO_FILE_QUOTA_LIMIT" => ITF::IO_FILE_QUOTA_LIMIT,
            "IO_FILE_QUOTA_STARTED" => ITF::IO_FILE_QUOTA_STARTED,
            "IO_FILE_QUOTA_SUCCEEDED" => ITF::IO_FILE_QUOTA_SUCCEEDED,
            "IO_INFO_THROTTLE_COMPLETE" => ITF::IO_INFO_THROTTLE_COMPLETE,
            "IO_CDROM_EXCLUSIVE_LOCK" => ITF::IO_CDROM_EXCLUSIVE_LOCK,
            "MSG_TEST_MESSAGE" => ITF::MSG_TEST_MESSAGE,
            "SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK" => ITF::SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK,
            "SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL" => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL,
            "SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED" => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED,
            "SL_I_OOB_GRACE_PERIOD" => ITF::SL_I_OOB_GRACE_PERIOD,
            "SL_I_OOT_GRACE_PERIOD" => ITF::SL_I_OOT_GRACE_PERIOD,
            "SL_E_VL_INFO_PRODUCT_USER_RIGHT" => ITF::SL_E_VL_INFO_PRODUCT_USER_RIGHT,
            "SL_I_NONGENUINE_GRACE_PERIOD" => ITF::SL_I_NONGENUINE_GRACE_PERIOD,
            "SL_I_NONGENUINE_GRACE_PERIOD_2" => ITF::SL_I_NONGENUINE_GRACE_PERIOD_2,
            "SL_I_TIMEBASED_VALIDITY_PERIOD" => ITF::SL_I_TIMEBASED_VALIDITY_PERIOD,
            "SL_I_PERPETUAL_OOB_GRACE_PERIOD" => ITF::SL_I_PERPETUAL_OOB_GRACE_PERIOD,
            "SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD" => ITF::SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD,
            "OLE_E_OLEVERB" => ITF::OLE_E_OLEVERB,
            "OLE_E_ADVF" => ITF::OLE_E_ADVF,
            "E_NOTVALIDFORANIMATEDIMAGE" => ITF::E_NOTVALIDFORANIMATEDIMAGE,
            "OLE_E_ENUM_NOMORE" => ITF::OLE_E_ENUM_NOMORE,
            "OLE_E_ADVISENOTSUPPORTED" => ITF::OLE_E_ADVISENOTSUPPORTED,
            "TAPI_E_NOTSUPPORTED" => ITF::TAPI_E_NOTSUPPORTED,
            "OLE_E_NOCONNECTION" => ITF::OLE_E_NOCONNECTION,
            "TAPI_E_INVALIDMEDIATYPE" => ITF::TAPI_E_INVALIDMEDIATYPE,
            "OLE_E_NOTRUNNING" => ITF::OLE_E_NOTRUNNING,
            "TAPI_E_OPERATIONFAILED" => ITF::TAPI_E_OPERATIONFAILED,
            "OLE_E_NOCACHE" => ITF::OLE_E_NOCACHE,
            "TAPI_E_ALLOCATED" => ITF::TAPI_E_ALLOCATED,
            "OLE_E_BLANK" => ITF::OLE_E_BLANK,
            "TAPI_E_CALLUNAVAIL" => ITF::TAPI_E_CALLUNAVAIL,
            "OLE_E_CLASSDIFF" => ITF::OLE_E_CLASSDIFF,
            "TAPI_E_COMPLETIONOVERRUN" => ITF::TAPI_E_COMPLETIONOVERRUN,
            "OLE_E_CANT_GETMONIKER" => ITF::OLE_E_CANT_GETMONIKER,
            "TAPI_E_CONFERENCEFULL" => ITF::TAPI_E_CONFERENCEFULL,
            "OLE_E_CANT_BINDTOSOURCE" => ITF::OLE_E_CANT_BINDTOSOURCE,
            "TAPI_E_DIALMODIFIERNOTSUPPORTED" => ITF::TAPI_E_DIALMODIFIERNOTSUPPORTED,
            "OLE_E_STATIC" => ITF::OLE_E_STATIC,
            "TAPI_E_INUSE" => ITF::TAPI_E_INUSE,
            "OLE_E_PROMPTSAVECANCELLED" => ITF::OLE_E_PROMPTSAVECANCELLED,
            "TAPI_E_INVALADDRESS" => ITF::TAPI_E_INVALADDRESS,
            "OLE_E_INVALIDRECT" => ITF::OLE_E_INVALIDRECT,
            "TAPI_E_INVALADDRESSSTATE" => ITF::TAPI_E_INVALADDRESSSTATE,
            "OLE_E_WRONGCOMPOBJ" => ITF::OLE_E_WRONGCOMPOBJ,
            "TAPI_E_INVALCALLPARAMS" => ITF::TAPI_E_INVALCALLPARAMS,
            "OLE_E_INVALIDHWND" => ITF::OLE_E_INVALIDHWND,
            "TAPI_E_INVALCALLPRIVILEGE" => ITF::TAPI_E_INVALCALLPRIVILEGE,
            "OLE_E_NOT_INPLACEACTIVE" => ITF::OLE_E_NOT_INPLACEACTIVE,
            "TAPI_E_INVALCALLSTATE" => ITF::TAPI_E_INVALCALLSTATE,
            "OLE_E_CANTCONVERT" => ITF::OLE_E_CANTCONVERT,
            "TAPI_E_INVALCARD" => ITF::TAPI_E_INVALCARD,
            "OLE_E_NOSTORAGE" => ITF::OLE_E_NOSTORAGE,
            "TAPI_E_INVALCOMPLETIONID" => ITF::TAPI_E_INVALCOMPLETIONID,
            "TAPI_E_INVALCOUNTRYCODE" => ITF::TAPI_E_INVALCOUNTRYCODE,
            "TAPI_E_INVALDEVICECLASS" => ITF::TAPI_E_INVALDEVICECLASS,
            "TAPI_E_INVALDIALPARAMS" => ITF::TAPI_E_INVALDIALPARAMS,
            "TAPI_E_INVALDIGITS" => ITF::TAPI_E_INVALDIGITS,
            "TAPI_E_INVALGROUPID" => ITF::TAPI_E_INVALGROUPID,
            "TAPI_E_INVALLOCATION" => ITF::TAPI_E_INVALLOCATION,
            "TAPI_E_INVALMESSAGEID" => ITF::TAPI_E_INVALMESSAGEID,
            "TAPI_E_INVALPARKID" => ITF::TAPI_E_INVALPARKID,
            "IO_WRN_BAD_FIRMWARE" => ITF::IO_WRN_BAD_FIRMWARE,
            "TAPI_E_INVALRATE" => ITF::TAPI_E_INVALRATE,
            "TAPI_E_INVALTIMEOUT" => ITF::TAPI_E_INVALTIMEOUT,
            "TAPI_E_INVALTONE" => ITF::TAPI_E_INVALTONE,
            "TAPI_E_INVALLIST" => ITF::TAPI_E_INVALLIST,
            "TAPI_E_INVALMODE" => ITF::TAPI_E_INVALMODE,
            "TAPI_E_NOCONFERENCE" => ITF::TAPI_E_NOCONFERENCE,
            "IO_WRITE_CACHE_ENABLED" => ITF::IO_WRITE_CACHE_ENABLED,
            "TAPI_E_NODEVICE" => ITF::TAPI_E_NODEVICE,
            "IO_RECOVERED_VIA_ECC" => ITF::IO_RECOVERED_VIA_ECC,
            "TAPI_E_NOREQUEST" => ITF::TAPI_E_NOREQUEST,
            "IO_WRITE_CACHE_DISABLED" => ITF::IO_WRITE_CACHE_DISABLED,
            "TAPI_E_NOTOWNER" => ITF::TAPI_E_NOTOWNER,
            "TAPI_E_NOTREGISTERED" => ITF::TAPI_E_NOTREGISTERED,
            "TAPI_E_REQUESTOVERRUN" => ITF::TAPI_E_REQUESTOVERRUN,
            "TAPI_E_TARGETNOTFOUND" => ITF::TAPI_E_TARGETNOTFOUND,
            "TAPI_E_TARGETSELF" => ITF::TAPI_E_TARGETSELF,
            "TAPI_E_USERUSERINFOTOOBIG" => ITF::TAPI_E_USERUSERINFOTOOBIG,
            "IO_FILE_QUOTA_FAILED" => ITF::IO_FILE_QUOTA_FAILED,
            "TAPI_E_REINIT" => ITF::TAPI_E_REINIT,
            "TAPI_E_ADDRESSBLOCKED" => ITF::TAPI_E_ADDRESSBLOCKED,
            "TAPI_E_BILLINGREJECTED" => ITF::TAPI_E_BILLINGREJECTED,
            "TAPI_E_INVALFEATURE" => ITF::TAPI_E_INVALFEATURE,
            "TAPI_E_INVALBUTTONLAMPID" => ITF::TAPI_E_INVALBUTTONLAMPID,
            "TAPI_E_INVALBUTTONSTATE" => ITF::TAPI_E_INVALBUTTONSTATE,
            "TAPI_E_INVALDATAID" => ITF::TAPI_E_INVALDATAID,
            "TAPI_E_INVALHOOKSWITCHDEV" => ITF::TAPI_E_INVALHOOKSWITCHDEV,
            "TAPI_E_DROPPED" => ITF::TAPI_E_DROPPED,
            "TAPI_E_NOREQUESTRECIPIENT" => ITF::TAPI_E_NOREQUESTRECIPIENT,
            "IO_LOST_DELAYED_WRITE" => ITF::IO_LOST_DELAYED_WRITE,
            "TAPI_E_REQUESTQUEUEFULL" => ITF::TAPI_E_REQUESTQUEUEFULL,
            "IO_WARNING_PAGING_FAILURE" => ITF::IO_WARNING_PAGING_FAILURE,
            "TAPI_E_DESTBUSY" => ITF::TAPI_E_DESTBUSY,
            "IO_WRN_FAILURE_PREDICTED" => ITF::IO_WRN_FAILURE_PREDICTED,
            "TAPI_E_DESTNOANSWER" => ITF::TAPI_E_DESTNOANSWER,
            "IO_WARNING_INTERRUPT_STILL_PENDING" => ITF::IO_WARNING_INTERRUPT_STILL_PENDING,
            "TAPI_E_DESTUNAVAIL" => ITF::TAPI_E_DESTUNAVAIL,
            "IO_DRIVER_CANCEL_TIMEOUT" => ITF::IO_DRIVER_CANCEL_TIMEOUT,
            "TAPI_E_REQUESTFAILED" => ITF::TAPI_E_REQUESTFAILED,
            "TAPI_E_REQUESTCANCELLED" => ITF::TAPI_E_REQUESTCANCELLED,
            "IO_WARNING_ALLOCATION_FAILED" => ITF::IO_WARNING_ALLOCATION_FAILED,
            "TAPI_E_INVALPRIVILEGE" => ITF::TAPI_E_INVALPRIVILEGE,
            "IO_WARNING_LOG_FLUSH_FAILED" => ITF::IO_WARNING_LOG_FLUSH_FAILED,
            "TAPI_E_INVALIDDIRECTION" => ITF::TAPI_E_INVALIDDIRECTION,
            "IO_WARNING_DUPLICATE_SIGNATURE" => ITF::IO_WARNING_DUPLICATE_SIGNATURE,
            "TAPI_E_INVALIDTERMINAL" => ITF::TAPI_E_INVALIDTERMINAL,
            "IO_WARNING_DUPLICATE_PATH" => ITF::IO_WARNING_DUPLICATE_PATH,
            "TAPI_E_INVALIDTERMINALCLASS" => ITF::TAPI_E_INVALIDTERMINALCLASS,
            "TAPI_E_NODRIVER" => ITF::TAPI_E_NODRIVER,
            "TAPI_E_MAXSTREAMS" => ITF::TAPI_E_MAXSTREAMS,
            "TAPI_E_NOTERMINALSELECTED" => ITF::TAPI_E_NOTERMINALSELECTED,
            "TAPI_E_TERMINALINUSE" => ITF::TAPI_E_TERMINALINUSE,
            "TAPI_E_NOTSTOPPED" => ITF::TAPI_E_NOTSTOPPED,
            "TAPI_E_MAXTERMINALS" => ITF::TAPI_E_MAXTERMINALS,
            "TAPI_E_INVALIDSTREAM" => ITF::TAPI_E_INVALIDSTREAM,
            "TAPI_E_TIMEOUT" => ITF::TAPI_E_TIMEOUT,
            "TAPI_E_CALLCENTER_GROUP_REMOVED" => ITF::TAPI_E_CALLCENTER_GROUP_REMOVED,
            "TAPI_E_CALLCENTER_QUEUE_REMOVED" => ITF::TAPI_E_CALLCENTER_QUEUE_REMOVED,
            "TAPI_E_CALLCENTER_NO_AGENT_ID" => ITF::TAPI_E_CALLCENTER_NO_AGENT_ID,
            "TAPI_E_CALLCENTER_INVALAGENTID" => ITF::TAPI_E_CALLCENTER_INVALAGENTID,
            "TAPI_E_CALLCENTER_INVALAGENTGROUP" => ITF::TAPI_E_CALLCENTER_INVALAGENTGROUP,
            "TAPI_E_CALLCENTER_INVALPASSWORD" => ITF::TAPI_E_CALLCENTER_INVALPASSWORD,
            "TAPI_E_CALLCENTER_INVALAGENTSTATE" => ITF::TAPI_E_CALLCENTER_INVALAGENTSTATE,
            "TAPI_E_CALLCENTER_INVALAGENTACTIVITY" => ITF::TAPI_E_CALLCENTER_INVALAGENTACTIVITY,
            "TAPI_E_REGISTRY_SETTING_CORRUPT" => ITF::TAPI_E_REGISTRY_SETTING_CORRUPT,
            "TAPI_E_TERMINAL_PEER" => ITF::TAPI_E_TERMINAL_PEER,
            "TAPI_E_PEER_NOT_SET" => ITF::TAPI_E_PEER_NOT_SET,
            "TAPI_E_NOEVENT" => ITF::TAPI_E_NOEVENT,
            "TAPI_E_INVALADDRESSTYPE" => ITF::TAPI_E_INVALADDRESSTYPE,
            "TAPI_E_RESOURCEUNAVAIL" => ITF::TAPI_E_RESOURCEUNAVAIL,
            "TAPI_E_PHONENOTOPEN" => ITF::TAPI_E_PHONENOTOPEN,
            "TAPI_E_CALLNOTSELECTED" => ITF::TAPI_E_CALLNOTSELECTED,
            "TAPI_E_WRONGEVENT" => ITF::TAPI_E_WRONGEVENT,
            "TAPI_E_NOFORMAT" => ITF::TAPI_E_NOFORMAT,
            "TAPI_E_INVALIDSTREAMSTATE" => ITF::TAPI_E_INVALIDSTREAMSTATE,
            "TAPI_E_WRONG_STATE" => ITF::TAPI_E_WRONG_STATE,
            "TAPI_E_NOT_INITIALIZED" => ITF::TAPI_E_NOT_INITIALIZED,
            "TAPI_E_SERVICE_NOT_RUNNING" => ITF::TAPI_E_SERVICE_NOT_RUNNING,
            "DV_E_FORMATETC" => ITF::DV_E_FORMATETC,
            "DV_E_DVTARGETDEVICE" => ITF::DV_E_DVTARGETDEVICE,
            "DV_E_STGMEDIUM" => ITF::DV_E_STGMEDIUM,
            "DV_E_STATDATA" => ITF::DV_E_STATDATA,
            "DV_E_LINDEX" => ITF::DV_E_LINDEX,
            "DV_E_TYMED" => ITF::DV_E_TYMED,
            "DV_E_CLIPFORMAT" => ITF::DV_E_CLIPFORMAT,
            "DV_E_DVASPECT" => ITF::DV_E_DVASPECT,
            "DV_E_DVTARGETDEVICE_SIZE" => ITF::DV_E_DVTARGETDEVICE_SIZE,
            "DV_E_NOIVIEWOBJECT" => ITF::DV_E_NOIVIEWOBJECT,
            "IO_WARNING_BUS_RESET" => ITF::IO_WARNING_BUS_RESET,
            "IO_WARNING_RESET" => ITF::IO_WARNING_RESET,
            "IO_WARNING_WRITE_FUA_PROBLEM" => ITF::IO_WARNING_WRITE_FUA_PROBLEM,
            "IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED" => ITF::IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED,
            "IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR" => ITF::IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR,
            "IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR" => ITF::IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR,
            "IO_WARNING_VOLUME_LOST_DISK_EXTENT" => ITF::IO_WARNING_VOLUME_LOST_DISK_EXTENT,
            "IO_WARNING_DEVICE_HAS_INTERNAL_DUMP" => ITF::IO_WARNING_DEVICE_HAS_INTERNAL_DUMP,
            "IO_WARNING_SOFT_THRESHOLD_REACHED" => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED,
            "IO_WARNING_SOFT_THRESHOLD_REACHED_EX" => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX,
            "IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN" => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN,
            "IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL" => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL,
            "IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN" => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN,
            "IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL" => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL,
            "IO_WARNING_DISK_CAPACITY_CHANGED" => ITF::IO_WARNING_DISK_CAPACITY_CHANGED,
            "IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED" => ITF::IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED,
            "IO_WARNING_IO_OPERATION_RETRIED" => ITF::IO_WARNING_IO_OPERATION_RETRIED,
            "IO_WARNING_COMPLETION_TIME" => ITF::IO_WARNING_COMPLETION_TIME,
            "IO_WARNING_DUMP_DISABLED_DEVICE_GONE" => ITF::IO_WARNING_DUMP_DISABLED_DEVICE_GONE,
            "IO_WARNING_DISK_SURPRISE_REMOVED" => ITF::IO_WARNING_DISK_SURPRISE_REMOVED,
            "IO_WARNING_REPEATED_DISK_GUID" => ITF::IO_WARNING_REPEATED_DISK_GUID,
            "OLE_E_LAST" => ITF::OLE_E_LAST,
            "DRAGDROP_E_NOTREGISTERED" => ITF::DRAGDROP_E_NOTREGISTERED,
            "DRAGDROP_E_ALREADYREGISTERED" => ITF::DRAGDROP_E_ALREADYREGISTERED,
            "DRAGDROP_E_INVALIDHWND" => ITF::DRAGDROP_E_INVALIDHWND,
            "_MAPI_E_NO_SUPPORT" => ITF::_MAPI_E_NO_SUPPORT,
            "DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED" => ITF::DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED,
            "_MAPI_E_BAD_CHARWIDTH" => ITF::_MAPI_E_BAD_CHARWIDTH,
            "_MAPI_E_STRING_TOO_LONG" => ITF::_MAPI_E_STRING_TOO_LONG,
            "_MAPI_E_UNKNOWN_FLAGS" => ITF::_MAPI_E_UNKNOWN_FLAGS,
            "_MAPI_E_INVALID_ENTRYID" => ITF::_MAPI_E_INVALID_ENTRYID,
            "_MAPI_E_INVALID_OBJECT" => ITF::_MAPI_E_INVALID_OBJECT,
            "_MAPI_E_OBJECT_CHANGED" => ITF::_MAPI_E_OBJECT_CHANGED,
            "_MAPI_E_OBJECT_DELETED" => ITF::_MAPI_E_OBJECT_DELETED,
            "_MAPI_E_BUSY" => ITF::_MAPI_E_BUSY,
            "_MAPI_E_NOT_ENOUGH_DISK" => ITF::_MAPI_E_NOT_ENOUGH_DISK,
            "_MAPI_E_NOT_ENOUGH_RESOURCES" => ITF::_MAPI_E_NOT_ENOUGH_RESOURCES,
            "_MAPI_E_NOT_FOUND" => ITF::_MAPI_E_NOT_FOUND,
            "CLASS_E_NOAGGREGATION" => ITF::CLASS_E_NOAGGREGATION,
            "_MAPI_E_VERSION" => ITF::_MAPI_E_VERSION,
            "CLASS_E_CLASSNOTAVAILABLE" => ITF::CLASS_E_CLASSNOTAVAILABLE,
            "_MAPI_E_LOGON_FAILED" => ITF::_MAPI_E_LOGON_FAILED,
            "CLASS_E_NOTLICENSED" => ITF::CLASS_E_NOTLICENSED,
            "_MAPI_E_SESSION_LIMIT" => ITF::_MAPI_E_SESSION_LIMIT,
            "_MAPI_E_USER_CANCEL" => ITF::_MAPI_E_USER_CANCEL,
            "_MAPI_E_UNABLE_TO_ABORT" => ITF::_MAPI_E_UNABLE_TO_ABORT,
            "_MAPI_E_NETWORK_ERROR" => ITF::_MAPI_E_NETWORK_ERROR,
            "_MAPI_E_DISK_ERROR" => ITF::_MAPI_E_DISK_ERROR,
            "_MAPI_E_TOO_COMPLEX" => ITF::_MAPI_E_TOO_COMPLEX,
            "_MAPI_E_BAD_COLUMN" => ITF::_MAPI_E_BAD_COLUMN,
            "_MAPI_E_EXTENDED_ERROR" => ITF::_MAPI_E_EXTENDED_ERROR,
            "_MAPI_E_COMPUTED" => ITF::_MAPI_E_COMPUTED,
            "_MAPI_E_CORRUPT_DATA" => ITF::_MAPI_E_CORRUPT_DATA,
            "_MAPI_E_UNCONFIGURED" => ITF::_MAPI_E_UNCONFIGURED,
            "_MAPI_E_FAILONEPROVIDER" => ITF::_MAPI_E_FAILONEPROVIDER,
            "_MAPI_E_UNKNOWN_CPID" => ITF::_MAPI_E_UNKNOWN_CPID,
            "_MAPI_E_UNKNOWN_LCID" => ITF::_MAPI_E_UNKNOWN_LCID,
            "_MAPI_E_PASSWORD_CHANGE_REQUIRED" => ITF::_MAPI_E_PASSWORD_CHANGE_REQUIRED,
            "_MAPI_E_PASSWORD_EXPIRED" => ITF::_MAPI_E_PASSWORD_EXPIRED,
            "_MAPI_E_INVALID_WORKSTATION_ACCOUNT" => ITF::_MAPI_E_INVALID_WORKSTATION_ACCOUNT,
            "_MAPI_E_INVALID_ACCESS_TIME" => ITF::_MAPI_E_INVALID_ACCESS_TIME,
            "_MAPI_E_ACCOUNT_DISABLED" => ITF::_MAPI_E_ACCOUNT_DISABLED,
            "VIEW_E_DRAW" => ITF::VIEW_E_DRAW,
            "REGDB_E_READREGDB" => ITF::REGDB_E_READREGDB,
            "REGDB_E_WRITEREGDB" => ITF::REGDB_E_WRITEREGDB,
            "REGDB_E_KEYMISSING" => ITF::REGDB_E_KEYMISSING,
            "REGDB_E_INVALIDVALUE" => ITF::REGDB_E_INVALIDVALUE,
            "REGDB_E_CLASSNOTREG" => ITF::REGDB_E_CLASSNOTREG,
            "E_CLASSNOTREG" => ITF::E_CLASSNOTREG,
            "REGDB_E_IIDNOTREG" => ITF::REGDB_E_IIDNOTREG,
            "REGDB_E_BADTHREADINGMODEL" => ITF::REGDB_E_BADTHREADINGMODEL,
            "REGDB_E_PACKAGEPOLICYVIOLATION" => ITF::REGDB_E_PACKAGEPOLICYVIOLATION,
            "CAT_E_CATIDNOEXIST" => ITF::CAT_E_CATIDNOEXIST,
            "CAT_E_NODESCRIPTION" => ITF::CAT_E_NODESCRIPTION,
            "CS_E_PACKAGE_NOTFOUND" => ITF::CS_E_PACKAGE_NOTFOUND,
            "CS_E_NOT_DELETABLE" => ITF::CS_E_NOT_DELETABLE,
            "CS_E_CLASS_NOTFOUND" => ITF::CS_E_CLASS_NOTFOUND,
            "CS_E_INVALID_VERSION" => ITF::CS_E_INVALID_VERSION,
            "CS_E_NO_CLASSSTORE" => ITF::CS_E_NO_CLASSSTORE,
            "CS_E_OBJECT_NOTFOUND" => ITF::CS_E_OBJECT_NOTFOUND,
            "CS_E_OBJECT_ALREADY_EXISTS" => ITF::CS_E_OBJECT_ALREADY_EXISTS,
            "CS_E_INVALID_PATH" => ITF::CS_E_INVALID_PATH,
            "CS_E_NETWORK_ERROR" => ITF::CS_E_NETWORK_ERROR,
            "CS_E_ADMIN_LIMIT_EXCEEDED" => ITF::CS_E_ADMIN_LIMIT_EXCEEDED,
            "CS_E_SCHEMA_MISMATCH" => ITF::CS_E_SCHEMA_MISMATCH,
            "CS_E_INTERNAL_ERROR" => ITF::CS_E_INTERNAL_ERROR,
            "CACHE_E_NOCACHE_UPDATED" => ITF::CACHE_E_NOCACHE_UPDATED,
            "OLEOBJ_E_NOVERBS" => ITF::OLEOBJ_E_NOVERBS,
            "OLEOBJ_E_INVALIDVERB" => ITF::OLEOBJ_E_INVALIDVERB,
            "INPLACE_E_NOTUNDOABLE" => ITF::INPLACE_E_NOTUNDOABLE,
            "INPLACE_E_NOTOOLSPACE" => ITF::INPLACE_E_NOTOOLSPACE,
            "CONVERT10_E_OLESTREAM_GET" => ITF::CONVERT10_E_OLESTREAM_GET,
            "CONVERT10_E_OLESTREAM_PUT" => ITF::CONVERT10_E_OLESTREAM_PUT,
            "CONVERT10_E_OLESTREAM_FMT" => ITF::CONVERT10_E_OLESTREAM_FMT,
            "CONVERT10_E_OLESTREAM_BITMAP_TO_DIB" => ITF::CONVERT10_E_OLESTREAM_BITMAP_TO_DIB,
            "CONVERT10_E_STG_FMT" => ITF::CONVERT10_E_STG_FMT,
            "CONVERT10_E_STG_NO_STD_STREAM" => ITF::CONVERT10_E_STG_NO_STD_STREAM,
            "CONVERT10_E_STG_DIB_TO_BITMAP" => ITF::CONVERT10_E_STG_DIB_TO_BITMAP,
            "CLIPBRD_E_CANT_OPEN" => ITF::CLIPBRD_E_CANT_OPEN,
            "CLIPBRD_E_CANT_EMPTY" => ITF::CLIPBRD_E_CANT_EMPTY,
            "CLIPBRD_E_CANT_SET" => ITF::CLIPBRD_E_CANT_SET,
            "CLIPBRD_E_BAD_DATA" => ITF::CLIPBRD_E_BAD_DATA,
            "CLIPBRD_E_CANT_CLOSE" => ITF::CLIPBRD_E_CANT_CLOSE,
            "MK_E_CONNECTMANUALLY" => ITF::MK_E_CONNECTMANUALLY,
            "MK_E_EXCEEDEDDEADLINE" => ITF::MK_E_EXCEEDEDDEADLINE,
            "MK_E_NEEDGENERIC" => ITF::MK_E_NEEDGENERIC,
            "MK_E_UNAVAILABLE" => ITF::MK_E_UNAVAILABLE,
            "MK_E_SYNTAX" => ITF::MK_E_SYNTAX,
            "MK_E_NOOBJECT" => ITF::MK_E_NOOBJECT,
            "MK_E_INVALIDEXTENSION" => ITF::MK_E_INVALIDEXTENSION,
            "MK_E_INTERMEDIATEINTERFACENOTSUPPORTED" => ITF::MK_E_INTERMEDIATEINTERFACENOTSUPPORTED,
            "MK_E_NOTBINDABLE" => ITF::MK_E_NOTBINDABLE,
            "MK_E_NOTBOUND" => ITF::MK_E_NOTBOUND,
            "MK_E_CANTOPENFILE" => ITF::MK_E_CANTOPENFILE,
            "MK_E_MUSTBOTHERUSER" => ITF::MK_E_MUSTBOTHERUSER,
            "MK_E_NOINVERSE" => ITF::MK_E_NOINVERSE,
            "MK_E_NOSTORAGE" => ITF::MK_E_NOSTORAGE,
            "MK_E_NOPREFIX" => ITF::MK_E_NOPREFIX,
            "MK_E_ENUMERATION_FAILED" => ITF::MK_E_ENUMERATION_FAILED,
            "CO_E_NOTINITIALIZED" => ITF::CO_E_NOTINITIALIZED,
            "DDERR_NOTINITIALIZED" => ITF::DDERR_NOTINITIALIZED,
            "CO_E_ALREADYINITIALIZED" => ITF::CO_E_ALREADYINITIALIZED,
            "CO_E_CANTDETERMINECLASS" => ITF::CO_E_CANTDETERMINECLASS,
            "CO_E_CLASSSTRING" => ITF::CO_E_CLASSSTRING,
            "CO_E_IIDSTRING" => ITF::CO_E_IIDSTRING,
            "CO_E_APPNOTFOUND" => ITF::CO_E_APPNOTFOUND,
            "CO_E_APPSINGLEUSE" => ITF::CO_E_APPSINGLEUSE,
            "CO_E_ERRORINAPP" => ITF::CO_E_ERRORINAPP,
            "CO_E_DLLNOTFOUND" => ITF::CO_E_DLLNOTFOUND,
            "CO_E_ERRORINDLL" => ITF::CO_E_ERRORINDLL,
            "CO_E_WRONGOSFORAPP" => ITF::CO_E_WRONGOSFORAPP,
            "CO_E_OBJNOTREG" => ITF::CO_E_OBJNOTREG,
            "CO_E_OBJISREG" => ITF::CO_E_OBJISREG,
            "CO_E_OBJNOTCONNECTED" => ITF::CO_E_OBJNOTCONNECTED,
            "CO_E_APPDIDNTREG" => ITF::CO_E_APPDIDNTREG,
            "CO_E_RELEASED" => ITF::CO_E_RELEASED,
            "VFW_E_INVALIDMEDIATYPE" => ITF::VFW_E_INVALIDMEDIATYPE,
            "_MAPI_E_END_OF_SESSION" => ITF::_MAPI_E_END_OF_SESSION,
            "MPEG2_E_UNINITIALIZED" => ITF::MPEG2_E_UNINITIALIZED,
            "TF_E_INVALIDPOS" => ITF::TF_E_INVALIDPOS,
            "TS_E_INVALIDPOS" => ITF::TS_E_INVALIDPOS,
            "UPNP_E_ROOT_ELEMENT_EXPECTED" => ITF::UPNP_E_ROOT_ELEMENT_EXPECTED,
            "USP_E_SCRIPT_NOT_IN_FONT" => ITF::USP_E_SCRIPT_NOT_IN_FONT,
            "EVENT_E_ALL_SUBSCRIBERS_FAILED" => ITF::EVENT_E_ALL_SUBSCRIBERS_FAILED,
            "VFW_E_INVALIDSUBTYPE" => ITF::VFW_E_INVALIDSUBTYPE,
            "CDO_E_UNCAUGHT_EXCEPTION" => ITF::CDO_E_UNCAUGHT_EXCEPTION,
            "_MAPI_E_UNKNOWN_ENTRYID" => ITF::_MAPI_E_UNKNOWN_ENTRYID,
            "MPEG2_E_ALREADY_INITIALIZED" => ITF::MPEG2_E_ALREADY_INITIALIZED,
            "TF_E_NOLOCK" => ITF::TF_E_NOLOCK,
            "TS_E_NOLOCK" => ITF::TS_E_NOLOCK,
            "UPNP_E_DEVICE_ELEMENT_EXPECTED" => ITF::UPNP_E_DEVICE_ELEMENT_EXPECTED,
            "VFW_E_NEED_OWNER" => ITF::VFW_E_NEED_OWNER,
            "CDO_E_NOT_OPENED" => ITF::CDO_E_NOT_OPENED,
            "_MAPI_E_MISSING_REQUIRED_COLUMN" => ITF::_MAPI_E_MISSING_REQUIRED_COLUMN,
            "MPEG2_E_OUT_OF_BOUNDS" => ITF::MPEG2_E_OUT_OF_BOUNDS,
            "TF_E_NOOBJECT" => ITF::TF_E_NOOBJECT,
            "TS_E_NOOBJECT" => ITF::TS_E_NOOBJECT,
            "UPNP_E_SERVICE_ELEMENT_EXPECTED" => ITF::UPNP_E_SERVICE_ELEMENT_EXPECTED,
            "EVENT_E_QUERYSYNTAX" => ITF::EVENT_E_QUERYSYNTAX,
            "VFW_E_ENUM_OUT_OF_SYNC" => ITF::VFW_E_ENUM_OUT_OF_SYNC,
            "CDO_E_UNSUPPORTED_DATASOURCE" => ITF::CDO_E_UNSUPPORTED_DATASOURCE,
            "MPEG2_E_MALFORMED_TABLE" => ITF::MPEG2_E_MALFORMED_TABLE,
            "TF_E_NOSERVICE" => ITF::TF_E_NOSERVICE,
            "TS_E_NOSERVICE" => ITF::TS_E_NOSERVICE,
            "UPNP_E_SERVICE_NODE_INCOMPLETE" => ITF::UPNP_E_SERVICE_NODE_INCOMPLETE,
            "EVENT_E_QUERYFIELD" => ITF::EVENT_E_QUERYFIELD,
            "VFW_E_ALREADY_CONNECTED" => ITF::VFW_E_ALREADY_CONNECTED,
            "CDO_E_INVALID_PROPERTYNAME" => ITF::CDO_E_INVALID_PROPERTYNAME,
            "MPEG2_E_UNDEFINED" => ITF::MPEG2_E_UNDEFINED,
            "TF_E_NOINTERFACE" => ITF::TF_E_NOINTERFACE,
            "TS_E_NOINTERFACE" => ITF::TS_E_NOINTERFACE,
            "UPNP_E_DEVICE_NODE_INCOMPLETE" => ITF::UPNP_E_DEVICE_NODE_INCOMPLETE,
            "EVENT_E_INTERNALEXCEPTION" => ITF::EVENT_E_INTERNALEXCEPTION,
            "VFW_E_FILTER_ACTIVE" => ITF::VFW_E_FILTER_ACTIVE,
            "CDO_E_PROP_UNSUPPORTED" => ITF::CDO_E_PROP_UNSUPPORTED,
            "MPEG2_E_NOT_PRESENT" => ITF::MPEG2_E_NOT_PRESENT,
            "TF_E_NOSELECTION" => ITF::TF_E_NOSELECTION,
            "TS_E_NOSELECTION" => ITF::TS_E_NOSELECTION,
            "UPNP_E_ICON_ELEMENT_EXPECTED" => ITF::UPNP_E_ICON_ELEMENT_EXPECTED,
            "EVENT_E_INTERNALERROR" => ITF::EVENT_E_INTERNALERROR,
            "VFW_E_NO_TYPES" => ITF::VFW_E_NO_TYPES,
            "CDO_E_INACTIVE" => ITF::CDO_E_INACTIVE,
            "MPEG2_E_SECTION_NOT_FOUND" => ITF::MPEG2_E_SECTION_NOT_FOUND,
            "TF_E_NOLAYOUT" => ITF::TF_E_NOLAYOUT,
            "TS_E_NOLAYOUT" => ITF::TS_E_NOLAYOUT,
            "UPNP_E_ICON_NODE_INCOMPLETE" => ITF::UPNP_E_ICON_NODE_INCOMPLETE,
            "EVENT_E_INVALID_PER_USER_SID" => ITF::EVENT_E_INVALID_PER_USER_SID,
            "VFW_E_NO_ACCEPTABLE_TYPES" => ITF::VFW_E_NO_ACCEPTABLE_TYPES,
            "CDO_E_NO_SUPPORT_FOR_OBJECTS" => ITF::CDO_E_NO_SUPPORT_FOR_OBJECTS,
            "MPEG2_E_TX_STREAM_UNAVAILABLE" => ITF::MPEG2_E_TX_STREAM_UNAVAILABLE,
            "TF_E_INVALIDPOINT" => ITF::TF_E_INVALIDPOINT,
            "TS_E_INVALIDPOINT" => ITF::TS_E_INVALIDPOINT,
            "UPNP_E_INVALID_ACTION" => ITF::UPNP_E_INVALID_ACTION,
            "EVENT_E_USER_EXCEPTION" => ITF::EVENT_E_USER_EXCEPTION,
            "VFW_E_INVALID_DIRECTION" => ITF::VFW_E_INVALID_DIRECTION,
            "CDO_E_NOT_AVAILABLE" => ITF::CDO_E_NOT_AVAILABLE,
            "MPEG2_E_SERVICE_ID_NOT_FOUND" => ITF::MPEG2_E_SERVICE_ID_NOT_FOUND,
            "TF_E_SYNCHRONOUS" => ITF::TF_E_SYNCHRONOUS,
            "TS_E_SYNCHRONOUS" => ITF::TS_E_SYNCHRONOUS,
            "UPNP_E_INVALID_ARGUMENTS" => ITF::UPNP_E_INVALID_ARGUMENTS,
            "EVENT_E_TOO_MANY_METHODS" => ITF::EVENT_E_TOO_MANY_METHODS,
            "VFW_E_NOT_CONNECTED" => ITF::VFW_E_NOT_CONNECTED,
            "CDO_E_NO_DEFAULT_DROP_DIR" => ITF::CDO_E_NO_DEFAULT_DROP_DIR,
            "MPEG2_E_SERVICE_PMT_NOT_FOUND" => ITF::MPEG2_E_SERVICE_PMT_NOT_FOUND,
            "TF_E_READONLY" => ITF::TF_E_READONLY,
            "TS_E_READONLY" => ITF::TS_E_READONLY,
            "UPNP_E_OUT_OF_SYNC" => ITF::UPNP_E_OUT_OF_SYNC,
            "EVENT_E_MISSING_EVENTCLASS" => ITF::EVENT_E_MISSING_EVENTCLASS,
            "VFW_E_NO_ALLOCATOR" => ITF::VFW_E_NO_ALLOCATOR,
            "CDO_E_SMTP_SERVER_REQUIRED" => ITF::CDO_E_SMTP_SERVER_REQUIRED,
            "MPEG2_E_DSI_NOT_FOUND" => ITF::MPEG2_E_DSI_NOT_FOUND,
            "TF_E_FORMAT" => ITF::TF_E_FORMAT,
            "TS_E_FORMAT" => ITF::TS_E_FORMAT,
            "EVENT_E_NOT_ALL_REMOVED" => ITF::EVENT_E_NOT_ALL_REMOVED,
            "VFW_E_RUNTIME_ERROR" => ITF::VFW_E_RUNTIME_ERROR,
            "CDO_E_NNTP_SERVER_REQUIRED" => ITF::CDO_E_NNTP_SERVER_REQUIRED,
            "IMAPI_E_NOTOPENED" => ITF::IMAPI_E_NOTOPENED,
            "MPEG2_E_SERVER_UNAVAILABLE" => ITF::MPEG2_E_SERVER_UNAVAILABLE,
            "EVENT_E_COMPLUS_NOT_INSTALLED" => ITF::EVENT_E_COMPLUS_NOT_INSTALLED,
            "VFW_E_BUFFER_NOTSET" => ITF::VFW_E_BUFFER_NOTSET,
            "CDO_E_RECIPIENT_MISSING" => ITF::CDO_E_RECIPIENT_MISSING,
            "IMAPI_E_NOTINITIALIZED" => ITF::IMAPI_E_NOTINITIALIZED,
            "MPEG2_E_INVALID_CAROUSEL_ID" => ITF::MPEG2_E_INVALID_CAROUSEL_ID,
            "EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT" => ITF::EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT,
            "VFW_E_BUFFER_OVERFLOW" => ITF::VFW_E_BUFFER_OVERFLOW,
            "CDO_E_FROM_MISSING" => ITF::CDO_E_FROM_MISSING,
            "IMAPI_E_USERABORT" => ITF::IMAPI_E_USERABORT,
            "MPEG2_E_MALFORMED_DSMCC_MESSAGE" => ITF::MPEG2_E_MALFORMED_DSMCC_MESSAGE,
            "EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT" => ITF::EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT,
            "VFW_E_BADALIGN" => ITF::VFW_E_BADALIGN,
            "CDO_E_SENDER_REJECTED" => ITF::CDO_E_SENDER_REJECTED,
            "IMAPI_E_GENERIC" => ITF::IMAPI_E_GENERIC,
            "MPEG2_E_INVALID_SG_OBJECT_KIND" => ITF::MPEG2_E_INVALID_SG_OBJECT_KIND,
            "EVENT_E_INVALID_EVENT_CLASS_PARTITION" => ITF::EVENT_E_INVALID_EVENT_CLASS_PARTITION,
            "VFW_E_ALREADY_COMMITTED" => ITF::VFW_E_ALREADY_COMMITTED,
            "CDO_E_RECIPIENTS_REJECTED" => ITF::CDO_E_RECIPIENTS_REJECTED,
            "IMAPI_E_MEDIUM_NOTPRESENT" => ITF::IMAPI_E_MEDIUM_NOTPRESENT,
            "MPEG2_E_OBJECT_NOT_FOUND" => ITF::MPEG2_E_OBJECT_NOT_FOUND,
            "EVENT_E_PER_USER_SID_NOT_LOGGED_ON" => ITF::EVENT_E_PER_USER_SID_NOT_LOGGED_ON,
            "VFW_E_BUFFERS_OUTSTANDING" => ITF::VFW_E_BUFFERS_OUTSTANDING,
            "CDO_E_NNTP_POST_FAILED" => ITF::CDO_E_NNTP_POST_FAILED,
            "IMAPI_E_MEDIUM_INVALIDTYPE" => ITF::IMAPI_E_MEDIUM_INVALIDTYPE,
            "MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY" => ITF::MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY,
            "UPNP_E_ACTION_REQUEST_FAILED" => ITF::UPNP_E_ACTION_REQUEST_FAILED,
            "VFW_E_NOT_COMMITTED" => ITF::VFW_E_NOT_COMMITTED,
            "CDO_E_SMTP_SEND_FAILED" => ITF::CDO_E_SMTP_SEND_FAILED,
            "IMAPI_E_DEVICE_NOPROPERTIES" => ITF::IMAPI_E_DEVICE_NOPROPERTIES,
            "MPEG2_E_OBJECT_KIND_NOT_A_FILE" => ITF::MPEG2_E_OBJECT_KIND_NOT_A_FILE,
            "UPNP_E_TRANSPORT_ERROR" => ITF::UPNP_E_TRANSPORT_ERROR,
            "TPC_E_NO_DEFAULT_TABLET" => ITF::TPC_E_NO_DEFAULT_TABLET,
            "VFW_E_SIZENOTSET" => ITF::VFW_E_SIZENOTSET,
            "CDO_E_CONNECTION_DROPPED" => ITF::CDO_E_CONNECTION_DROPPED,
            "IMAPI_E_DEVICE_NOTACCESSIBLE" => ITF::IMAPI_E_DEVICE_NOTACCESSIBLE,
            "MPEG2_E_FILE_OFFSET_TOO_BIG" => ITF::MPEG2_E_FILE_OFFSET_TOO_BIG,
            "UPNP_E_VARIABLE_VALUE_UNKNOWN" => ITF::UPNP_E_VARIABLE_VALUE_UNKNOWN,
            "VFW_E_NO_CLOCK" => ITF::VFW_E_NO_CLOCK,
            "CDO_E_FAILED_TO_CONNECT" => ITF::CDO_E_FAILED_TO_CONNECT,
            "IMAPI_E_DEVICE_NOTPRESENT" => ITF::IMAPI_E_DEVICE_NOTPRESENT,
            "MPEG2_E_STREAM_STOPPED" => ITF::MPEG2_E_STREAM_STOPPED,
            "UPNP_E_INVALID_VARIABLE" => ITF::UPNP_E_INVALID_VARIABLE,
            "VFW_E_NO_SINK" => ITF::VFW_E_NO_SINK,
            "CDO_E_INVALID_POST" => ITF::CDO_E_INVALID_POST,
            "IMAPI_E_DEVICE_INVALIDTYPE" => ITF::IMAPI_E_DEVICE_INVALIDTYPE,
            "MPEG2_E_REGISTRY_ACCESS_FAILED" => ITF::MPEG2_E_REGISTRY_ACCESS_FAILED,
            "UPNP_E_DEVICE_ERROR" => ITF::UPNP_E_DEVICE_ERROR,
            "VFW_E_NO_INTERFACE" => ITF::VFW_E_NO_INTERFACE,
            "CDO_E_AUTHENTICATION_FAILURE" => ITF::CDO_E_AUTHENTICATION_FAILURE,
            "IMAPI_E_INITIALIZE_WRITE" => ITF::IMAPI_E_INITIALIZE_WRITE,
            "MPEG2_E_INVALID_UDP_PORT" => ITF::MPEG2_E_INVALID_UDP_PORT,
            "UPNP_E_PROTOCOL_ERROR" => ITF::UPNP_E_PROTOCOL_ERROR,
            "VFW_E_NOT_FOUND" => ITF::VFW_E_NOT_FOUND,
            "CDO_E_INVALID_CONTENT_TYPE" => ITF::CDO_E_INVALID_CONTENT_TYPE,
            "IMAPI_E_INITIALIZE_ENDWRITE" => ITF::IMAPI_E_INITIALIZE_ENDWRITE,
            "MPEG2_E_DATA_SOURCE_FAILED" => ITF::MPEG2_E_DATA_SOURCE_FAILED,
            "UPNP_E_ERROR_PROCESSING_RESPONSE" => ITF::UPNP_E_ERROR_PROCESSING_RESPONSE,
            "VFW_E_CANNOT_CONNECT" => ITF::VFW_E_CANNOT_CONNECT,
            "CDO_E_LOGON_FAILURE" => ITF::CDO_E_LOGON_FAILURE,
            "IMAPI_E_FILESYSTEM" => ITF::IMAPI_E_FILESYSTEM,
            "MPEG2_E_DII_NOT_FOUND" => ITF::MPEG2_E_DII_NOT_FOUND,
            "UPNP_E_DEVICE_TIMEOUT" => ITF::UPNP_E_DEVICE_TIMEOUT,
            "VFW_E_CANNOT_RENDER" => ITF::VFW_E_CANNOT_RENDER,
            "CDO_E_HTTP_NOT_FOUND" => ITF::CDO_E_HTTP_NOT_FOUND,
            "IMAPI_E_FILEACCESS" => ITF::IMAPI_E_FILEACCESS,
            "MPEG2_E_DSHOW_PIN_NOT_FOUND" => ITF::MPEG2_E_DSHOW_PIN_NOT_FOUND,
            "TPC_E_INVALID_INPUT_RECT" => ITF::TPC_E_INVALID_INPUT_RECT,
            "VFW_E_CHANGING_FORMAT" => ITF::VFW_E_CHANGING_FORMAT,
            "CDO_E_HTTP_FORBIDDEN" => ITF::CDO_E_HTTP_FORBIDDEN,
            "IMAPI_E_DISCINFO" => ITF::IMAPI_E_DISCINFO,
            "MPEG2_E_BUFFER_TOO_SMALL" => ITF::MPEG2_E_BUFFER_TOO_SMALL,
            "VFW_E_NO_COLOR_KEY_SET" => ITF::VFW_E_NO_COLOR_KEY_SET,
            "CDO_E_HTTP_FAILED" => ITF::CDO_E_HTTP_FAILED,
            "IMAPI_E_TRACKNOTOPEN" => ITF::IMAPI_E_TRACKNOTOPEN,
            "MPEG2_E_MISSING_SECTIONS" => ITF::MPEG2_E_MISSING_SECTIONS,
            "TPC_E_UNKNOWN_PROPERTY" => ITF::TPC_E_UNKNOWN_PROPERTY,
            "VFW_E_NOT_OVERLAY_CONNECTION" => ITF::VFW_E_NOT_OVERLAY_CONNECTION,
            "CDO_E_MULTIPART_NO_DATA" => ITF::CDO_E_MULTIPART_NO_DATA,
            "IMAPI_E_TRACKOPEN" => ITF::IMAPI_E_TRACKOPEN,
            "MPEG2_E_TOO_MANY_SECTIONS" => ITF::MPEG2_E_TOO_MANY_SECTIONS,
            "VFW_E_NOT_SAMPLE_CONNECTION" => ITF::VFW_E_NOT_SAMPLE_CONNECTION,
            "CDO_E_INVALID_ENCODING_FOR_MULTIPART" => ITF::CDO_E_INVALID_ENCODING_FOR_MULTIPART,
            "IMAPI_E_DISCFULL" => ITF::IMAPI_E_DISCFULL,
            "MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE" => ITF::MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE,
            "VFW_E_PALETTE_SET" => ITF::VFW_E_PALETTE_SET,
            "CDO_E_UNSAFE_OPERATION" => ITF::CDO_E_UNSAFE_OPERATION,
            "IMAPI_E_BADJOLIETNAME" => ITF::IMAPI_E_BADJOLIETNAME,
            "MPEG2_E_INCORRECT_DESCRIPTOR_TAG" => ITF::MPEG2_E_INCORRECT_DESCRIPTOR_TAG,
            "VFW_E_COLOR_KEY_SET" => ITF::VFW_E_COLOR_KEY_SET,
            "CDO_E_PROP_NOT_FOUND" => ITF::CDO_E_PROP_NOT_FOUND,
            "IMAPI_E_INVALIDIMAGE" => ITF::IMAPI_E_INVALIDIMAGE,
            "VFW_E_NO_COLOR_KEY_FOUND" => ITF::VFW_E_NO_COLOR_KEY_FOUND,
            "IMAPI_E_NOACTIVEFORMAT" => ITF::IMAPI_E_NOACTIVEFORMAT,
            "VFW_E_NO_PALETTE_AVAILABLE" => ITF::VFW_E_NO_PALETTE_AVAILABLE,
            "CDO_E_INVALID_SEND_OPTION" => ITF::CDO_E_INVALID_SEND_OPTION,
            "IMAPI_E_NOACTIVERECORDER" => ITF::IMAPI_E_NOACTIVERECORDER,
            "VFW_E_NO_DISPLAY_PALETTE" => ITF::VFW_E_NO_DISPLAY_PALETTE,
            "CDO_E_INVALID_POST_OPTION" => ITF::CDO_E_INVALID_POST_OPTION,
            "IMAPI_E_WRONGFORMAT" => ITF::IMAPI_E_WRONGFORMAT,
            "TPC_E_INVALID_STROKE" => ITF::TPC_E_INVALID_STROKE,
            "VFW_E_TOO_MANY_COLORS" => ITF::VFW_E_TOO_MANY_COLORS,
            "CDO_E_NO_PICKUP_DIR" => ITF::CDO_E_NO_PICKUP_DIR,
            "IMAPI_E_ALREADYOPEN" => ITF::IMAPI_E_ALREADYOPEN,
            "TPC_E_INITIALIZE_FAIL" => ITF::TPC_E_INITIALIZE_FAIL,
            "VFW_E_STATE_CHANGED" => ITF::VFW_E_STATE_CHANGED,
            "CDO_E_NOT_ALL_DELETED" => ITF::CDO_E_NOT_ALL_DELETED,
            "IMAPI_E_WRONGDISC" => ITF::IMAPI_E_WRONGDISC,
            "VFW_E_NOT_STOPPED" => ITF::VFW_E_NOT_STOPPED,
            "CDO_E_NO_METHOD" => ITF::CDO_E_NO_METHOD,
            "IMAPI_E_FILEEXISTS" => ITF::IMAPI_E_FILEEXISTS,
            "VFW_E_NOT_PAUSED" => ITF::VFW_E_NOT_PAUSED,
            "IMAPI_E_STASHINUSE" => ITF::IMAPI_E_STASHINUSE,
            "VFW_E_NOT_RUNNING" => ITF::VFW_E_NOT_RUNNING,
            "IMAPI_E_DEVICE_STILL_IN_USE" => ITF::IMAPI_E_DEVICE_STILL_IN_USE,
            "VFW_E_WRONG_STATE" => ITF::VFW_E_WRONG_STATE,
            "CDO_E_PROP_READONLY" => ITF::CDO_E_PROP_READONLY,
            "IMAPI_E_LOSS_OF_STREAMING" => ITF::IMAPI_E_LOSS_OF_STREAMING,
            "VFW_E_START_TIME_AFTER_END" => ITF::VFW_E_START_TIME_AFTER_END,
            "CDO_E_PROP_CANNOT_DELETE" => ITF::CDO_E_PROP_CANNOT_DELETE,
            "IMAPI_E_COMPRESSEDSTASH" => ITF::IMAPI_E_COMPRESSEDSTASH,
            "VFW_E_INVALID_RECT" => ITF::VFW_E_INVALID_RECT,
            "CDO_E_BAD_DATA" => ITF::CDO_E_BAD_DATA,
            "IMAPI_E_ENCRYPTEDSTASH" => ITF::IMAPI_E_ENCRYPTEDSTASH,
            "VFW_E_TYPE_NOT_ACCEPTED" => ITF::VFW_E_TYPE_NOT_ACCEPTED,
            "CDO_E_PROP_NONHEADER" => ITF::CDO_E_PROP_NONHEADER,
            "IMAPI_E_NOTENOUGHDISKFORSTASH" => ITF::IMAPI_E_NOTENOUGHDISKFORSTASH,
            "VFW_E_SAMPLE_REJECTED" => ITF::VFW_E_SAMPLE_REJECTED,
            "CDO_E_INVALID_CHARSET" => ITF::CDO_E_INVALID_CHARSET,
            "IMAPI_E_REMOVABLESTASH" => ITF::IMAPI_E_REMOVABLESTASH,
            "VFW_E_SAMPLE_REJECTED_EOS" => ITF::VFW_E_SAMPLE_REJECTED_EOS,
            "CDO_E_ADOSTREAM_NOT_BOUND" => ITF::CDO_E_ADOSTREAM_NOT_BOUND,
            "IMAPI_E_CANNOT_WRITE_TO_MEDIA" => ITF::IMAPI_E_CANNOT_WRITE_TO_MEDIA,
            "VFW_E_DUPLICATE_NAME" => ITF::VFW_E_DUPLICATE_NAME,
            "CDO_E_CONTENTPROPXML_NOT_FOUND" => ITF::CDO_E_CONTENTPROPXML_NOT_FOUND,
            "IMAPI_E_TRACK_NOT_BIG_ENOUGH" => ITF::IMAPI_E_TRACK_NOT_BIG_ENOUGH,
            "VFW_E_TIMEOUT" => ITF::VFW_E_TIMEOUT,
            "CDO_E_CONTENTPROPXML_WRONG_CHARSET" => ITF::CDO_E_CONTENTPROPXML_WRONG_CHARSET,
            "VFW_E_INVALID_FILE_FORMAT" => ITF::VFW_E_INVALID_FILE_FORMAT,
            "CDO_E_CONTENTPROPXML_PARSE_FAILED" => ITF::CDO_E_CONTENTPROPXML_PARSE_FAILED,
            "VFW_E_ENUM_OUT_OF_RANGE" => ITF::VFW_E_ENUM_OUT_OF_RANGE,
            "CDO_E_CONTENTPROPXML_CONVERT_FAILED" => ITF::CDO_E_CONTENTPROPXML_CONVERT_FAILED,
            "VFW_E_CIRCULAR_GRAPH" => ITF::VFW_E_CIRCULAR_GRAPH,
            "CDO_E_NO_DIRECTORIES_SPECIFIED" => ITF::CDO_E_NO_DIRECTORIES_SPECIFIED,
            "TPC_E_NOT_RELEVANT" => ITF::TPC_E_NOT_RELEVANT,
            "VFW_E_NOT_ALLOWED_TO_SAVE" => ITF::VFW_E_NOT_ALLOWED_TO_SAVE,
            "CDO_E_DIRECTORIES_UNREACHABLE" => ITF::CDO_E_DIRECTORIES_UNREACHABLE,
            "TPC_E_INVALID_PACKET_DESCRIPTION" => ITF::TPC_E_INVALID_PACKET_DESCRIPTION,
            "VFW_E_TIME_ALREADY_PASSED" => ITF::VFW_E_TIME_ALREADY_PASSED,
            "CDO_E_BAD_SENDER" => ITF::CDO_E_BAD_SENDER,
            "VFW_E_ALREADY_CANCELLED" => ITF::VFW_E_ALREADY_CANCELLED,
            "CDO_E_SELF_BINDING" => ITF::CDO_E_SELF_BINDING,
            "TPC_E_RECOGNIZER_NOT_REGISTERED" => ITF::TPC_E_RECOGNIZER_NOT_REGISTERED,
            "VFW_E_CORRUPT_GRAPH_FILE" => ITF::VFW_E_CORRUPT_GRAPH_FILE,
            "CDO_E_BAD_ATTENDEE_DATA" => ITF::CDO_E_BAD_ATTENDEE_DATA,
            "TPC_E_INVALID_RIGHTS" => ITF::TPC_E_INVALID_RIGHTS,
            "VFW_E_ADVISE_ALREADY_SET" => ITF::VFW_E_ADVISE_ALREADY_SET,
            "CDO_E_ROLE_NOMORE_AVAILABLE" => ITF::CDO_E_ROLE_NOMORE_AVAILABLE,
            "TPC_E_OUT_OF_ORDER_CALL" => ITF::TPC_E_OUT_OF_ORDER_CALL,
            "CDO_E_BAD_TASKTYPE_ONASSIGN" => ITF::CDO_E_BAD_TASKTYPE_ONASSIGN,
            "TPC_E_QUEUE_FULL" => ITF::TPC_E_QUEUE_FULL,
            "VFW_E_NO_MODEX_AVAILABLE" => ITF::VFW_E_NO_MODEX_AVAILABLE,
            "CDO_E_NOT_ASSIGNEDTO_USER" => ITF::CDO_E_NOT_ASSIGNEDTO_USER,
            "TPC_E_INVALID_CONFIGURATION" => ITF::TPC_E_INVALID_CONFIGURATION,
            "VFW_E_NO_ADVISE_SET" => ITF::VFW_E_NO_ADVISE_SET,
            "CDO_E_OUTOFDATE" => ITF::CDO_E_OUTOFDATE,
            "TPC_E_INVALID_DATA_FROM_RECOGNIZER" => ITF::TPC_E_INVALID_DATA_FROM_RECOGNIZER,
            "VFW_E_NO_FULLSCREEN" => ITF::VFW_E_NO_FULLSCREEN,
            "VFW_E_IN_FULLSCREEN_MODE" => ITF::VFW_E_IN_FULLSCREEN_MODE,
            "VFW_E_UNKNOWN_FILE_TYPE" => ITF::VFW_E_UNKNOWN_FILE_TYPE,
            "TPC_E_INVALID_PROPERTY" => ITF::TPC_E_INVALID_PROPERTY,
            "VFW_E_CANNOT_LOAD_SOURCE_FILTER" => ITF::VFW_E_CANNOT_LOAD_SOURCE_FILTER,
            "VFW_E_FILE_TOO_SHORT" => ITF::VFW_E_FILE_TOO_SHORT,
            "VFW_E_INVALID_FILE_VERSION" => ITF::VFW_E_INVALID_FILE_VERSION,
            "VFW_E_INVALID_CLSID" => ITF::VFW_E_INVALID_CLSID,
            "VFW_E_INVALID_MEDIA_TYPE" => ITF::VFW_E_INVALID_MEDIA_TYPE,
            "VFW_E_SAMPLE_TIME_NOT_SET" => ITF::VFW_E_SAMPLE_TIME_NOT_SET,
            "VFW_E_MEDIA_TIME_NOT_SET" => ITF::VFW_E_MEDIA_TIME_NOT_SET,
            "VFW_E_NO_TIME_FORMAT_SET" => ITF::VFW_E_NO_TIME_FORMAT_SET,
            "VFW_E_MONO_AUDIO_HW" => ITF::VFW_E_MONO_AUDIO_HW,
            "VFW_E_NO_DECOMPRESSOR" => ITF::VFW_E_NO_DECOMPRESSOR,
            "VFW_E_NO_AUDIO_HARDWARE" => ITF::VFW_E_NO_AUDIO_HARDWARE,
            "VFW_E_RPZA" => ITF::VFW_E_RPZA,
            "VFW_E_PROCESSOR_NOT_SUITABLE" => ITF::VFW_E_PROCESSOR_NOT_SUITABLE,
            "VFW_E_UNSUPPORTED_AUDIO" => ITF::VFW_E_UNSUPPORTED_AUDIO,
            "VFW_E_UNSUPPORTED_VIDEO" => ITF::VFW_E_UNSUPPORTED_VIDEO,
            "VFW_E_MPEG_NOT_CONSTRAINED" => ITF::VFW_E_MPEG_NOT_CONSTRAINED,
            "VFW_E_NOT_IN_GRAPH" => ITF::VFW_E_NOT_IN_GRAPH,
            "VFW_E_NO_TIME_FORMAT" => ITF::VFW_E_NO_TIME_FORMAT,
            "VFW_E_READ_ONLY" => ITF::VFW_E_READ_ONLY,
            "VFW_E_BUFFER_UNDERFLOW" => ITF::VFW_E_BUFFER_UNDERFLOW,
            "VFW_E_UNSUPPORTED_STREAM" => ITF::VFW_E_UNSUPPORTED_STREAM,
            "VFW_E_NO_TRANSPORT" => ITF::VFW_E_NO_TRANSPORT,
            "VFW_E_BAD_VIDEOCD" => ITF::VFW_E_BAD_VIDEOCD,
            "VFW_S_NO_STOP_TIME" => ITF::VFW_S_NO_STOP_TIME,
            "VFW_E_OUT_OF_VIDEO_MEMORY" => ITF::VFW_E_OUT_OF_VIDEO_MEMORY,
            "VFW_E_VP_NEGOTIATION_FAILED" => ITF::VFW_E_VP_NEGOTIATION_FAILED,
            "VFW_E_DDRAW_CAPS_NOT_SUITABLE" => ITF::VFW_E_DDRAW_CAPS_NOT_SUITABLE,
            "VFW_E_NO_VP_HARDWARE" => ITF::VFW_E_NO_VP_HARDWARE,
            "VFW_E_NO_CAPTURE_HARDWARE" => ITF::VFW_E_NO_CAPTURE_HARDWARE,
            "VFW_E_DVD_OPERATION_INHIBITED" => ITF::VFW_E_DVD_OPERATION_INHIBITED,
            "VFW_E_DVD_INVALIDDOMAIN" => ITF::VFW_E_DVD_INVALIDDOMAIN,
            "VFW_E_DVD_NO_BUTTON" => ITF::VFW_E_DVD_NO_BUTTON,
            "VFW_E_DVD_GRAPHNOTREADY" => ITF::VFW_E_DVD_GRAPHNOTREADY,
            "VFW_E_DVD_RENDERFAIL" => ITF::VFW_E_DVD_RENDERFAIL,
            "VFW_E_DVD_DECNOTENOUGH" => ITF::VFW_E_DVD_DECNOTENOUGH,
            "VFW_E_DDRAW_VERSION_NOT_SUITABLE" => ITF::VFW_E_DDRAW_VERSION_NOT_SUITABLE,
            "VFW_E_COPYPROT_FAILED" => ITF::VFW_E_COPYPROT_FAILED,
            "VFW_E_TIME_EXPIRED" => ITF::VFW_E_TIME_EXPIRED,
            "VFW_E_DVD_WRONG_SPEED" => ITF::VFW_E_DVD_WRONG_SPEED,
            "VFW_E_DVD_MENU_DOES_NOT_EXIST" => ITF::VFW_E_DVD_MENU_DOES_NOT_EXIST,
            "VFW_E_DVD_CMD_CANCELLED" => ITF::VFW_E_DVD_CMD_CANCELLED,
            "VFW_E_DVD_STATE_WRONG_VERSION" => ITF::VFW_E_DVD_STATE_WRONG_VERSION,
            "VFW_E_DVD_STATE_CORRUPT" => ITF::VFW_E_DVD_STATE_CORRUPT,
            "VFW_E_DVD_STATE_WRONG_DISC" => ITF::VFW_E_DVD_STATE_WRONG_DISC,
            "VFW_E_DVD_INCOMPATIBLE_REGION" => ITF::VFW_E_DVD_INCOMPATIBLE_REGION,
            "VFW_E_DVD_NO_ATTRIBUTES" => ITF::VFW_E_DVD_NO_ATTRIBUTES,
            "VFW_E_DVD_NO_GOUP_PGC" => ITF::VFW_E_DVD_NO_GOUP_PGC,
            "VFW_E_DVD_LOW_PARENTAL_LEVEL" => ITF::VFW_E_DVD_LOW_PARENTAL_LEVEL,
            "VFW_E_DVD_NOT_IN_KARAOKE_MODE" => ITF::VFW_E_DVD_NOT_IN_KARAOKE_MODE,
            "VFW_E_FRAME_STEP_UNSUPPORTED" => ITF::VFW_E_FRAME_STEP_UNSUPPORTED,
            "VFW_E_DVD_STREAM_DISABLED" => ITF::VFW_E_DVD_STREAM_DISABLED,
            "VFW_E_DVD_TITLE_UNKNOWN" => ITF::VFW_E_DVD_TITLE_UNKNOWN,
            "VFW_E_DVD_INVALID_DISC" => ITF::VFW_E_DVD_INVALID_DISC,
            "VFW_E_DVD_NO_RESUME_INFORMATION" => ITF::VFW_E_DVD_NO_RESUME_INFORMATION,
            "VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD" => ITF::VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD,
            "VFW_E_PIN_ALREADY_BLOCKED" => ITF::VFW_E_PIN_ALREADY_BLOCKED,
            "VFW_E_CERTIFICATION_FAILURE" => ITF::VFW_E_CERTIFICATION_FAILURE,
            "VFW_E_VMR_NOT_IN_MIXER_MODE" => ITF::VFW_E_VMR_NOT_IN_MIXER_MODE,
            "VFW_E_VMR_NO_AP_SUPPLIED" => ITF::VFW_E_VMR_NO_AP_SUPPLIED,
            "VFW_E_VMR_NO_DEINTERLACE_HW" => ITF::VFW_E_VMR_NO_DEINTERLACE_HW,
            "VFW_E_VMR_NO_PROCAMP_HW" => ITF::VFW_E_VMR_NO_PROCAMP_HW,
            "VFW_E_DVD_VMR9_INCOMPATIBLEDEC" => ITF::VFW_E_DVD_VMR9_INCOMPATIBLEDEC,
            "VFW_E_NO_COPP_HW" => ITF::VFW_E_NO_COPP_HW,
            "VFW_E_DVD_NONBLOCKING" => ITF::VFW_E_DVD_NONBLOCKING,
            "VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH" => ITF::VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH,
            "VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH" => ITF::VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH,
            "VFW_E_DVD_RESOLUTION_ERROR" => ITF::VFW_E_DVD_RESOLUTION_ERROR,
            "NET_E_GENERAL" => ITF::NET_E_GENERAL,
            "FHCFG_E_CORRUPT_CONFIG_FILE" => ITF::FHCFG_E_CORRUPT_CONFIG_FILE,
            "UPNP_E_ACTION_SPECIFIC_BASE" => ITF::UPNP_E_ACTION_SPECIFIC_BASE,
            "FHCFG_E_CONFIG_FILE_NOT_FOUND" => ITF::FHCFG_E_CONFIG_FILE_NOT_FOUND,
            "FHCFG_E_CONFIG_ALREADY_EXISTS" => ITF::FHCFG_E_CONFIG_ALREADY_EXISTS,
            "NET_E_DISCONNECTED" => ITF::NET_E_DISCONNECTED,
            "FHCFG_E_NO_VALID_CONFIGURATION_LOADED" => ITF::FHCFG_E_NO_VALID_CONFIGURATION_LOADED,
            "FHCFG_E_TARGET_NOT_CONNECTED" => ITF::FHCFG_E_TARGET_NOT_CONNECTED,
            "FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED" => ITF::FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED,
            "FHCFG_E_TARGET_VERIFICATION_FAILED" => ITF::FHCFG_E_TARGET_VERIFICATION_FAILED,
            "FHCFG_E_TARGET_NOT_CONFIGURED" => ITF::FHCFG_E_TARGET_NOT_CONFIGURED,
            "NET_E_INVALIDPARAMS" => ITF::NET_E_INVALIDPARAMS,
            "FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE" => ITF::FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE,
            "NET_E_OPERATIONINPROGRESS" => ITF::NET_E_OPERATIONINPROGRESS,
            "FHCFG_E_TARGET_CANNOT_BE_USED" => ITF::FHCFG_E_TARGET_CANNOT_BE_USED,
            "VFW_E_CODECAPI_LINEAR_RANGE" => ITF::VFW_E_CODECAPI_LINEAR_RANGE,
            "FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED" => ITF::FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED,
            "VFW_E_CODECAPI_ENUMERATED" => ITF::VFW_E_CODECAPI_ENUMERATED,
            "FHCFG_E_TARGET_REHYDRATED_ELSEWHERE" => ITF::FHCFG_E_TARGET_REHYDRATED_ELSEWHERE,
            "FHCFG_E_LEGACY_TARGET_UNSUPPORTED" => ITF::FHCFG_E_LEGACY_TARGET_UNSUPPORTED,
            "VFW_E_CODECAPI_NO_DEFAULT" => ITF::VFW_E_CODECAPI_NO_DEFAULT,
            "FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED" => ITF::FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED,
            "VFW_E_CODECAPI_NO_CURRENT_VALUE" => ITF::VFW_E_CODECAPI_NO_CURRENT_VALUE,
            "FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED" => ITF::FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED,
            "VFW_E_DVD_CHAPTER_DOES_NOT_EXIST" => ITF::VFW_E_DVD_CHAPTER_DOES_NOT_EXIST,
            "FHCFG_E_LEGACY_BACKUP_NOT_FOUND" => ITF::FHCFG_E_LEGACY_BACKUP_NOT_FOUND,
            "VFW_E_BAD_KEY" => ITF::VFW_E_BAD_KEY,
            "DS_E_NOMOREDATA" => ITF::DS_E_NOMOREDATA,
            "DS_E_INVALIDDATASOURCE" => ITF::DS_E_INVALIDDATASOURCE,
            "MS_E_SAMPLEALLOC" => ITF::MS_E_SAMPLEALLOC,
            "DS_E_DATASOURCENOTAVAILABLE" => ITF::DS_E_DATASOURCENOTAVAILABLE,
            "MS_E_PURPOSEID" => ITF::MS_E_PURPOSEID,
            "DS_E_QUERYCANCELED" => ITF::DS_E_QUERYCANCELED,
            "MS_E_NOSTREAM" => ITF::MS_E_NOSTREAM,
            "DS_E_UNKNOWNREQUEST" => ITF::DS_E_UNKNOWNREQUEST,
            "MS_E_NOSEEKING" => ITF::MS_E_NOSEEKING,
            "DS_E_BADREQUEST" => ITF::DS_E_BADREQUEST,
            "MS_E_INCOMPATIBLE" => ITF::MS_E_INCOMPATIBLE,
            "DS_E_SERVERCAPACITY" => ITF::DS_E_SERVERCAPACITY,
            "MS_E_BUSY" => ITF::MS_E_BUSY,
            "DS_E_BADSEQUENCE" => ITF::DS_E_BADSEQUENCE,
            "MS_E_NOTINIT" => ITF::MS_E_NOTINIT,
            "DS_E_MESSAGETOOLONG" => ITF::DS_E_MESSAGETOOLONG,
            "MS_E_SOURCEALREADYDEFINED" => ITF::MS_E_SOURCEALREADYDEFINED,
            "DS_E_SERVERERROR" => ITF::DS_E_SERVERERROR,
            "MS_E_INVALIDSTREAMTYPE" => ITF::MS_E_INVALIDSTREAMTYPE,
            "DS_E_CONFIGBAD" => ITF::DS_E_CONFIGBAD,
            "MS_E_NOTRUNNING" => ITF::MS_E_NOTRUNNING,
            "DS_E_DATANOTPRESENT" => ITF::DS_E_DATANOTPRESENT,
            "DS_E_SETSTATUSINPROGRESS" => ITF::DS_E_SETSTATUSINPROGRESS,
            "DS_E_DUPLICATEID" => ITF::DS_E_DUPLICATEID,
            "DS_E_TOOMANYDATASOURCES" => ITF::DS_E_TOOMANYDATASOURCES,
            "DS_E_REGISTRY" => ITF::DS_E_REGISTRY,
            "DS_E_DATASOURCENOTDISABLED" => ITF::DS_E_DATASOURCENOTDISABLED,
            "DS_E_INVALIDTAGDB" => ITF::DS_E_INVALIDTAGDB,
            "DS_E_INVALIDCATALOGNAME" => ITF::DS_E_INVALIDCATALOGNAME,
            "DS_E_CONFIGNOTRIGHTTYPE" => ITF::DS_E_CONFIGNOTRIGHTTYPE,
            "DS_E_PROTOCOLVERSION" => ITF::DS_E_PROTOCOLVERSION,
            "DS_E_ALREADYENABLED" => ITF::DS_E_ALREADYENABLED,
            "DS_E_INDEXDIRECTORY" => ITF::DS_E_INDEXDIRECTORY,
            "DS_E_VALUETOOLARGE" => ITF::DS_E_VALUETOOLARGE,
            "DS_E_UNKNOWNPARAM" => ITF::DS_E_UNKNOWNPARAM,
            "DS_E_BUFFERTOOSMALL" => ITF::DS_E_BUFFERTOOSMALL,
            "DS_E_PARAMOUTOFRANGE" => ITF::DS_E_PARAMOUTOFRANGE,
            "DS_E_ALREADYDISABLED" => ITF::DS_E_ALREADYDISABLED,
            "DS_E_QUERYHUNG" => ITF::DS_E_QUERYHUNG,
            "DS_E_BADRESULT" => ITF::DS_E_BADRESULT,
            "DS_E_CANNOTWRITEREGISTRY" => ITF::DS_E_CANNOTWRITEREGISTRY,
            "DS_E_CANNOTREMOVECONCURRENT" => ITF::DS_E_CANNOTREMOVECONCURRENT,
            "DS_E_SEARCHCATNAMECOLLISION" => ITF::DS_E_SEARCHCATNAMECOLLISION,
            "DS_E_PROPVERSIONMISMATCH" => ITF::DS_E_PROPVERSIONMISMATCH,
            "DS_E_MISSINGCATALOG" => ITF::DS_E_MISSINGCATALOG,
            "UPNP_E_ACTION_SPECIFIC_MAX" => ITF::UPNP_E_ACTION_SPECIFIC_MAX,
            "TF_E_LOCKED" => ITF::TF_E_LOCKED,
            "UPNP_E_INVALID_DOCUMENT" => ITF::UPNP_E_INVALID_DOCUMENT,
            "COLL_E_BADSEQUENCE" => ITF::COLL_E_BADSEQUENCE,
            "TF_E_STACKFULL" => ITF::TF_E_STACKFULL,
            "UPNP_E_EVENT_SUBSCRIPTION_FAILED" => ITF::UPNP_E_EVENT_SUBSCRIPTION_FAILED,
            "COLL_E_NOMOREDATA" => ITF::COLL_E_NOMOREDATA,
            "TF_E_NOTOWNEDRANGE" => ITF::TF_E_NOTOWNEDRANGE,
            "COLL_E_INCOMPATIBLECOLUMNS" => ITF::COLL_E_INCOMPATIBLECOLUMNS,
            "TF_E_NOPROVIDER" => ITF::TF_E_NOPROVIDER,
            "COLL_E_BUFFERTOOSMALL" => ITF::COLL_E_BUFFERTOOSMALL,
            "TF_E_DISCONNECTED" => ITF::TF_E_DISCONNECTED,
            "TF_E_INVALIDVIEW" => ITF::TF_E_INVALIDVIEW,
            "COLL_E_BADRESULT" => ITF::COLL_E_BADRESULT,
            "TF_E_ALREADY_EXISTS" => ITF::TF_E_ALREADY_EXISTS,
            "COLL_E_NOSORTCOLUMN" => ITF::COLL_E_NOSORTCOLUMN,
            "TF_E_RANGE_NOT_COVERED" => ITF::TF_E_RANGE_NOT_COVERED,
            "COLL_E_DUPLICATEDBID" => ITF::COLL_E_DUPLICATEDBID,
            "TF_E_COMPOSITION_REJECTED" => ITF::TF_E_COMPOSITION_REJECTED,
            "COLL_E_TOOMANYMERGECOLUMNS" => ITF::COLL_E_TOOMANYMERGECOLUMNS,
            "TF_E_EMPTYCONTEXT" => ITF::TF_E_EMPTYCONTEXT,
            "COLL_E_NODEFAULTCATALOG" => ITF::COLL_E_NODEFAULTCATALOG,
            "COLL_E_MAXCONNEXCEEDED" => ITF::COLL_E_MAXCONNEXCEEDED,
            "FHSVC_E_BACKUP_BLOCKED" => ITF::FHSVC_E_BACKUP_BLOCKED,
            "CM_E_TOOMANYDATASERVERS" => ITF::CM_E_TOOMANYDATASERVERS,
            "FHSVC_E_NOT_CONFIGURED" => ITF::FHSVC_E_NOT_CONFIGURED,
            "CM_E_TOOMANYDATASOURCES" => ITF::CM_E_TOOMANYDATASOURCES,
            "FHSVC_E_CONFIG_DISABLED" => ITF::FHSVC_E_CONFIG_DISABLED,
            "CM_E_NOQUERYCONNECTIONS" => ITF::CM_E_NOQUERYCONNECTIONS,
            "FHSVC_E_CONFIG_DISABLED_GP" => ITF::FHSVC_E_CONFIG_DISABLED_GP,
            "CM_E_DATASOURCENOTAVAILABLE" => ITF::CM_E_DATASOURCENOTAVAILABLE,
            "FHSVC_E_FATAL_CONFIG_ERROR" => ITF::FHSVC_E_FATAL_CONFIG_ERROR,
            "CM_E_CONNECTIONTIMEOUT" => ITF::CM_E_CONNECTIONTIMEOUT,
            "FHSVC_E_CONFIG_REHYDRATING" => ITF::FHSVC_E_CONFIG_REHYDRATING,
            "CM_E_SERVERNOTFOUND" => ITF::CM_E_SERVERNOTFOUND,
            "CM_E_REGISTRY" => ITF::CM_E_REGISTRY,
            "CM_E_INVALIDDATASOURCE" => ITF::CM_E_INVALIDDATASOURCE,
            "CM_E_TIMEOUT" => ITF::CM_E_TIMEOUT,
            "CM_E_INSUFFICIENTBUFFER" => ITF::CM_E_INSUFFICIENTBUFFER,
            "QRY_E_QUERYSYNTAX" => ITF::QRY_E_QUERYSYNTAX,
            "QRY_E_TYPEMISMATCH" => ITF::QRY_E_TYPEMISMATCH,
            "QRY_E_UNHANDLEDTYPE" => ITF::QRY_E_UNHANDLEDTYPE,
            "QRY_E_TOOMANYCOLUMNS" => ITF::QRY_E_TOOMANYCOLUMNS,
            "QRY_E_TOOMANYDATABASES" => ITF::QRY_E_TOOMANYDATABASES,
            "QRY_E_STARTHITTOBIG" => ITF::QRY_E_STARTHITTOBIG,
            "QRY_E_TOOMANYQUERYTERMS" => ITF::QRY_E_TOOMANYQUERYTERMS,
            "QRY_E_NODATASOURCES" => ITF::QRY_E_NODATASOURCES,
            "QRY_E_TIMEOUT" => ITF::QRY_E_TIMEOUT,
            "QRY_E_COLUMNNOTSORTABLE" => ITF::QRY_E_COLUMNNOTSORTABLE,
            "QRY_E_COLUMNNOTSEARCHABLE" => ITF::QRY_E_COLUMNNOTSEARCHABLE,
            "QRY_E_INVALIDCOLUMN" => ITF::QRY_E_INVALIDCOLUMN,
            "QRY_E_QUERYCORRUPT" => ITF::QRY_E_QUERYCORRUPT,
            "QRY_E_PREFIXWILDCARD" => ITF::QRY_E_PREFIXWILDCARD,
            "QRY_E_INFIXWILDCARD" => ITF::QRY_E_INFIXWILDCARD,
            "QRY_E_WILDCARDPREFIXLENGTH" => ITF::QRY_E_WILDCARDPREFIXLENGTH,
            "QRY_E_ENGINEFAILED" => ITF::QRY_E_ENGINEFAILED,
            "QRY_E_SEARCHTOOBIG" => ITF::QRY_E_SEARCHTOOBIG,
            "QRY_E_NULLQUERY" => ITF::QRY_E_NULLQUERY,
            "QRY_E_NOCOLUMNS" => ITF::QRY_E_NOCOLUMNS,
            "QRY_E_INVALIDSCOPES" => ITF::QRY_E_INVALIDSCOPES,
            "QRY_E_INVALIDCATALOG" => ITF::QRY_E_INVALIDCATALOG,
            "QRY_E_SCOPECARDINALIDY" => ITF::QRY_E_SCOPECARDINALIDY,
            "QRY_E_UNEXPECTED" => ITF::QRY_E_UNEXPECTED,
            "QRY_E_INVALIDPATH" => ITF::QRY_E_INVALIDPATH,
            "QRY_E_LMNOTINITIALIZED" => ITF::QRY_E_LMNOTINITIALIZED,
            "QRY_E_INVALIDINTERVAL" => ITF::QRY_E_INVALIDINTERVAL,
            "QRY_E_NOLOGMANAGER" => ITF::QRY_E_NOLOGMANAGER,
            "SCHEMA_E_LOAD_SPECIAL" => ITF::SCHEMA_E_LOAD_SPECIAL,
            "SCHEMA_E_FILENOTFOUND" => ITF::SCHEMA_E_FILENOTFOUND,
            "SCHEMA_E_NESTEDTAG" => ITF::SCHEMA_E_NESTEDTAG,
            "SCHEMA_E_UNEXPECTEDTAG" => ITF::SCHEMA_E_UNEXPECTEDTAG,
            "SCHEMA_E_VERSIONMISMATCH" => ITF::SCHEMA_E_VERSIONMISMATCH,
            "SCHEMA_E_CANNOTCREATEFILE" => ITF::SCHEMA_E_CANNOTCREATEFILE,
            "SCHEMA_E_CANNOTWRITEFILE" => ITF::SCHEMA_E_CANNOTWRITEFILE,
            "SCHEMA_E_EMPTYFILE" => ITF::SCHEMA_E_EMPTYFILE,
            "SCHEMA_E_INVALIDFILETYPE" => ITF::SCHEMA_E_INVALIDFILETYPE,
            "SCHEMA_E_INVALIDDATATYPE" => ITF::SCHEMA_E_INVALIDDATATYPE,
            "SCHEMA_E_CANNOTCREATENOISEWORDFILE" => ITF::SCHEMA_E_CANNOTCREATENOISEWORDFILE,
            "SCHEMA_E_ADDSTOPWORDS" => ITF::SCHEMA_E_ADDSTOPWORDS,
            "SCHEMA_E_NAMEEXISTS" => ITF::SCHEMA_E_NAMEEXISTS,
            "SCHEMA_E_INVALIDVALUE" => ITF::SCHEMA_E_INVALIDVALUE,
            "SCHEMA_E_BADPROPSPEC" => ITF::SCHEMA_E_BADPROPSPEC,
            "SCHEMA_E_NOMORECOLUMNS" => ITF::SCHEMA_E_NOMORECOLUMNS,
            "SCHEMA_E_FILECHANGED" => ITF::SCHEMA_E_FILECHANGED,
            "SCHEMA_E_BADCOLUMNNAME" => ITF::SCHEMA_E_BADCOLUMNNAME,
            "SCHEMA_E_BADPROPPID" => ITF::SCHEMA_E_BADPROPPID,
            "SCHEMA_E_BADATTRIBUTE" => ITF::SCHEMA_E_BADATTRIBUTE,
            "SCHEMA_E_BADFILENAME" => ITF::SCHEMA_E_BADFILENAME,
            "SCHEMA_E_PROPEXISTS" => ITF::SCHEMA_E_PROPEXISTS,
            "SCHEMA_E_DUPLICATENOISE" => ITF::SCHEMA_E_DUPLICATENOISE,
            "GTHR_E_DUPLICATE_OBJECT" => ITF::GTHR_E_DUPLICATE_OBJECT,
            "GTHR_E_UNABLE_TO_READ_REGISTRY" => ITF::GTHR_E_UNABLE_TO_READ_REGISTRY,
            "GTHR_E_ERROR_WRITING_REGISTRY" => ITF::GTHR_E_ERROR_WRITING_REGISTRY,
            "GTHR_E_ERROR_INITIALIZING_PERFMON" => ITF::GTHR_E_ERROR_INITIALIZING_PERFMON,
            "GTHR_E_ERROR_OBJECT_NOT_FOUND" => ITF::GTHR_E_ERROR_OBJECT_NOT_FOUND,
            "GTHR_E_URL_EXCLUDED" => ITF::GTHR_E_URL_EXCLUDED,
            "GTHR_E_CONFIG_DUP_PROJECT" => ITF::GTHR_E_CONFIG_DUP_PROJECT,
            "GTHR_E_CONFIG_DUP_EXTENSION" => ITF::GTHR_E_CONFIG_DUP_EXTENSION,
            "GTHR_E_DUPLICATE_URL" => ITF::GTHR_E_DUPLICATE_URL,
            "GTHR_E_TOO_MANY_PLUGINS" => ITF::GTHR_E_TOO_MANY_PLUGINS,
            "GTHR_E_INVALIDFUNCTION" => ITF::GTHR_E_INVALIDFUNCTION,
            "GTHR_E_NOFILTERSINK" => ITF::GTHR_E_NOFILTERSINK,
            "GTHR_E_FILTER_PROCESS_TERMINATED" => ITF::GTHR_E_FILTER_PROCESS_TERMINATED,
            "GTHR_E_FILTER_INVALID_MESSAGE" => ITF::GTHR_E_FILTER_INVALID_MESSAGE,
            "GTHR_E_UNSUPPORTED_PROPERTY_TYPE" => ITF::GTHR_E_UNSUPPORTED_PROPERTY_TYPE,
            "GTHR_E_NAME_TOO_LONG" => ITF::GTHR_E_NAME_TOO_LONG,
            "GTHR_E_NO_IDENTITY" => ITF::GTHR_E_NO_IDENTITY,
            "GTHR_E_FILTER_NOT_FOUND" => ITF::GTHR_E_FILTER_NOT_FOUND,
            "GTHR_E_FILTER_NO_MORE_THREADS" => ITF::GTHR_E_FILTER_NO_MORE_THREADS,
            "GTHR_E_PRT_HNDLR_PROGID_MISSING" => ITF::GTHR_E_PRT_HNDLR_PROGID_MISSING,
            "GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA" => ITF::GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA,
            "GTHR_E_UNKNOWN_PROTOCOL" => ITF::GTHR_E_UNKNOWN_PROTOCOL,
            "GTHR_E_PROJECT_NOT_INITIALIZED" => ITF::GTHR_E_PROJECT_NOT_INITIALIZED,
            "GTHR_E_INVALID_PROJECT_NAME" => ITF::GTHR_E_INVALID_PROJECT_NAME,
            "GTHR_E_SHUTTING_DOWN" => ITF::GTHR_E_SHUTTING_DOWN,
            "GTHR_E_VALUE_NOT_AVAILABLE" => ITF::GTHR_E_VALUE_NOT_AVAILABLE,
            "GTHR_E_OUT_OF_DOC_ID" => ITF::GTHR_E_OUT_OF_DOC_ID,
            "GTHR_E_NOTIFICATION_START_PAGE" => ITF::GTHR_E_NOTIFICATION_START_PAGE,
            "GTHR_E_DUP_PROPERTY_MAPPING" => ITF::GTHR_E_DUP_PROPERTY_MAPPING,
            "GTHR_E_INVALID_ACCOUNT" => ITF::GTHR_E_INVALID_ACCOUNT,
            "GTHR_E_FILTER_INIT" => ITF::GTHR_E_FILTER_INIT,
            "GTHR_E_INVALID_ACCOUNT_SYNTAX" => ITF::GTHR_E_INVALID_ACCOUNT_SYNTAX,
            "GTHR_E_PROXY_NAME" => ITF::GTHR_E_PROXY_NAME,
            "GTHR_E_SERVER_UNAVAILABLE" => ITF::GTHR_E_SERVER_UNAVAILABLE,
            "GTHR_E_INVALID_PATH" => ITF::GTHR_E_INVALID_PATH,
            "GTHR_E_FILTER_NO_CODEPAGE" => ITF::GTHR_E_FILTER_NO_CODEPAGE,
            "GTHR_E_NO_PRTCLHNLR" => ITF::GTHR_E_NO_PRTCLHNLR,
            "GTHR_E_IE_OFFLINE" => ITF::GTHR_E_IE_OFFLINE,
            "GTHR_E_BAD_FILTER_DAEMON" => ITF::GTHR_E_BAD_FILTER_DAEMON,
            "GTHR_E_INVALID_MAPPING" => ITF::GTHR_E_INVALID_MAPPING,
            "GTHR_E_USER_AGENT_NOT_SPECIFIED" => ITF::GTHR_E_USER_AGENT_NOT_SPECIFIED,
            "GTHR_E_FROM_NOT_SPECIFIED" => ITF::GTHR_E_FROM_NOT_SPECIFIED,
            "GTHR_E_INVALID_STREAM_LOGS_COUNT" => ITF::GTHR_E_INVALID_STREAM_LOGS_COUNT,
            "GTHR_E_INVALID_EXTENSION" => ITF::GTHR_E_INVALID_EXTENSION,
            "GTHR_E_INVALID_GROW_FACTOR" => ITF::GTHR_E_INVALID_GROW_FACTOR,
            "GTHR_E_INVALID_TIME_OUT" => ITF::GTHR_E_INVALID_TIME_OUT,
            "GTHR_E_INVALID_RETRIES" => ITF::GTHR_E_INVALID_RETRIES,
            "GTHR_E_INVALID_LOG_FILE_NAME" => ITF::GTHR_E_INVALID_LOG_FILE_NAME,
            "GTHR_E_INVALID_HOST_NAME" => ITF::GTHR_E_INVALID_HOST_NAME,
            "GTHR_E_INVALID_START_PAGE" => ITF::GTHR_E_INVALID_START_PAGE,
            "GTHR_E_DUPLICATE_PROJECT" => ITF::GTHR_E_DUPLICATE_PROJECT,
            "GTHR_E_INVALID_DIRECTORY" => ITF::GTHR_E_INVALID_DIRECTORY,
            "GTHR_E_FILTER_INTERRUPTED" => ITF::GTHR_E_FILTER_INTERRUPTED,
            "GTHR_E_INVALID_PROXY_PORT" => ITF::GTHR_E_INVALID_PROXY_PORT,
            "GTHR_E_SECRET_NOT_FOUND" => ITF::GTHR_E_SECRET_NOT_FOUND,
            "GTHR_E_INVALID_PATH_EXPRESSION" => ITF::GTHR_E_INVALID_PATH_EXPRESSION,
            "GTHR_E_INVALID_START_PAGE_HOST" => ITF::GTHR_E_INVALID_START_PAGE_HOST,
            "GTHR_E_INVALID_START_PAGE_PATH" => ITF::GTHR_E_INVALID_START_PAGE_PATH,
            "GTHR_E_APPLICATION_NOT_FOUND" => ITF::GTHR_E_APPLICATION_NOT_FOUND,
            "GTHR_E_CANNOT_REMOVE_PLUGINMGR" => ITF::GTHR_E_CANNOT_REMOVE_PLUGINMGR,
            "GTHR_E_INVALID_APPLICATION_NAME" => ITF::GTHR_E_INVALID_APPLICATION_NAME,
            "GTHR_E_FILTER_FAULT" => ITF::GTHR_E_FILTER_FAULT,
            "GTHR_E_NON_FIXED_DRIVE" => ITF::GTHR_E_NON_FIXED_DRIVE,
            "GTHR_E_FILTER_SINGLE_THREADED" => ITF::GTHR_E_FILTER_SINGLE_THREADED,
            "GTHR_E_URL_UNIDENTIFIED" => ITF::GTHR_E_URL_UNIDENTIFIED,
            "GTHR_E_FORCE_NOTIFICATION_RESET" => ITF::GTHR_E_FORCE_NOTIFICATION_RESET,
            "GTHR_E_CONTENT_ID_CONFLICT" => ITF::GTHR_E_CONTENT_ID_CONFLICT,
            "GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE" => ITF::GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE,
            "GTHR_E_RECOVERABLE_EXOLEDB_ERROR" => ITF::GTHR_E_RECOVERABLE_EXOLEDB_ERROR,
            "GTHR_E_INVALID_CALL_FROM_WBREAKER" => ITF::GTHR_E_INVALID_CALL_FROM_WBREAKER,
            "GTHR_E_PROPERTY_LIST_NOT_INITIALIZED" => ITF::GTHR_E_PROPERTY_LIST_NOT_INITIALIZED,
            "GHTR_E_LOCAL_SERVER_UNAVAILABLE" => ITF::GHTR_E_LOCAL_SERVER_UNAVAILABLE,
            "GTHR_E_SCHEMA_ERRORS_OCCURRED" => ITF::GTHR_E_SCHEMA_ERRORS_OCCURRED,
            "GTHR_E_TIMEOUT" => ITF::GTHR_E_TIMEOUT,
            "GTHR_E_NOTIFICATION_START_ADDRESS_INVALID" => ITF::GTHR_E_NOTIFICATION_START_ADDRESS_INVALID,
            "GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED" => ITF::GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED,
            "GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE" => ITF::GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE,
            "GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE" => ITF::GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE,
            "GHTR_E_INSUFFICIENT_DISK_SPACE" => ITF::GHTR_E_INSUFFICIENT_DISK_SPACE,
            "GTHR_E_INVALID_RESOURCE_ID" => ITF::GTHR_E_INVALID_RESOURCE_ID,
            "GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES" => ITF::GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES,
            "GTHR_E_RETRY" => ITF::GTHR_E_RETRY,
            "GTHR_E_JET_BACKUP_ERROR" => ITF::GTHR_E_JET_BACKUP_ERROR,
            "GTHR_E_JET_RESTORE_ERROR" => ITF::GTHR_E_JET_RESTORE_ERROR,
            "GTHR_E_PLUGIN_NOT_REGISTERED" => ITF::GTHR_E_PLUGIN_NOT_REGISTERED,
            "GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED" => ITF::GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED,
            "GTHR_E_DIRMON_NOT_INITIALZED" => ITF::GTHR_E_DIRMON_NOT_INITIALZED,
            "GTHR_E_NOTIF_BEING_REMOVED" => ITF::GTHR_E_NOTIF_BEING_REMOVED,
            "GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT" => ITF::GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT,
            "GTHR_E_INVALID_PATH_SPEC" => ITF::GTHR_E_INVALID_PATH_SPEC,
            "GTHR_E_INSUFFICIENT_FEATURE_TERMS" => ITF::GTHR_E_INSUFFICIENT_FEATURE_TERMS,
            "GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES" => ITF::GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES,
            "GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS" => ITF::GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS,
            "GTHR_E_AUTOCAT_UNEXPECTED" => ITF::GTHR_E_AUTOCAT_UNEXPECTED,
            "GTHR_E_SINGLE_THREADED_EMBEDDING" => ITF::GTHR_E_SINGLE_THREADED_EMBEDDING,
            "GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE" => ITF::GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE,
            "GTHR_E_EMPTY_DACL" => ITF::GTHR_E_EMPTY_DACL,
            "GTHR_E_OBJECT_NOT_VALID" => ITF::GTHR_E_OBJECT_NOT_VALID,
            "GTHR_E_CANNOT_ENABLE_CHECKPOINT" => ITF::GTHR_E_CANNOT_ENABLE_CHECKPOINT,
            "GTHR_E_SCOPES_EXCEEDED" => ITF::GTHR_E_SCOPES_EXCEEDED,
            "GTHR_E_PROPERTIES_EXCEEDED" => ITF::GTHR_E_PROPERTIES_EXCEEDED,
            "GTHR_E_INVALID_START_ADDRESS" => ITF::GTHR_E_INVALID_START_ADDRESS,
            "GTHR_E_PIPE_NOT_CONNECTTED" => ITF::GTHR_E_PIPE_NOT_CONNECTTED,
            "GTHR_E_BACKUP_VALIDATION_FAIL" => ITF::GTHR_E_BACKUP_VALIDATION_FAIL,
            "GTHR_E_BAD_FILTER_HOST" => ITF::GTHR_E_BAD_FILTER_HOST,
            "GTHR_E_FILTERPOOL_NOTFOUND" => ITF::GTHR_E_FILTERPOOL_NOTFOUND,
            "GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT" => ITF::GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT,
            "DB_E_BADACCESSORHANDLE" => ITF::DB_E_BADACCESSORHANDLE,
            "DB_E_ROWLIMITEXCEEDED" => ITF::DB_E_ROWLIMITEXCEEDED,
            "DB_E_READONLYACCESSOR" => ITF::DB_E_READONLYACCESSOR,
            "DB_E_SCHEMAVIOLATION" => ITF::DB_E_SCHEMAVIOLATION,
            "DB_E_BADROWHANDLE" => ITF::DB_E_BADROWHANDLE,
            "DB_E_OBJECTOPEN" => ITF::DB_E_OBJECTOPEN,
            "DB_E_BADCHAPTER" => ITF::DB_E_BADCHAPTER,
            "DB_E_CANTCONVERTVALUE" => ITF::DB_E_CANTCONVERTVALUE,
            "DB_E_BADBINDINFO" => ITF::DB_E_BADBINDINFO,
            "DB_SEC_E_PERMISSIONDENIED" => ITF::DB_SEC_E_PERMISSIONDENIED,
            "DB_E_NOTAREFERENCECOLUMN" => ITF::DB_E_NOTAREFERENCECOLUMN,
            "DB_E_LIMITREJECTED" => ITF::DB_E_LIMITREJECTED,
            "DB_E_NOCOMMAND" => ITF::DB_E_NOCOMMAND,
            "DB_E_COSTLIMIT" => ITF::DB_E_COSTLIMIT,
            "DB_E_BADBOOKMARK" => ITF::DB_E_BADBOOKMARK,
            "DB_E_BADLOCKMODE" => ITF::DB_E_BADLOCKMODE,
            "DB_E_PARAMNOTOPTIONAL" => ITF::DB_E_PARAMNOTOPTIONAL,
            "DB_E_BADCOLUMNID" => ITF::DB_E_BADCOLUMNID,
            "DB_E_BADRATIO" => ITF::DB_E_BADRATIO,
            "DB_E_BADVALUES" => ITF::DB_E_BADVALUES,
            "DB_E_ERRORSINCOMMAND" => ITF::DB_E_ERRORSINCOMMAND,
            "DB_E_CANTCANCEL" => ITF::DB_E_CANTCANCEL,
            "DB_E_DIALECTNOTSUPPORTED" => ITF::DB_E_DIALECTNOTSUPPORTED,
            "DB_E_DUPLICATEDATASOURCE" => ITF::DB_E_DUPLICATEDATASOURCE,
            "DB_E_CANNOTRESTART" => ITF::DB_E_CANNOTRESTART,
            "DB_E_NOTFOUND" => ITF::DB_E_NOTFOUND,
            "DB_E_CANNOTFREE" => ITF::DB_E_CANNOTFREE,
            "DB_E_NEWLYINSERTED" => ITF::DB_E_NEWLYINSERTED,
            "DB_E_GOALREJECTED" => ITF::DB_E_GOALREJECTED,
            "DB_E_UNSUPPORTEDCONVERSION" => ITF::DB_E_UNSUPPORTEDCONVERSION,
            "DB_E_BADSTARTPOSITION" => ITF::DB_E_BADSTARTPOSITION,
            "DB_E_NOQUERY" => ITF::DB_E_NOQUERY,
            "DB_E_NOTREENTRANT" => ITF::DB_E_NOTREENTRANT,
            "DB_E_ERRORSOCCURRED" => ITF::DB_E_ERRORSOCCURRED,
            "DB_E_NOAGGREGATION" => ITF::DB_E_NOAGGREGATION,
            "DB_E_DELETEDROW" => ITF::DB_E_DELETEDROW,
            "DB_E_CANTFETCHBACKWARDS" => ITF::DB_E_CANTFETCHBACKWARDS,
            "DB_E_ROWSNOTRELEASED" => ITF::DB_E_ROWSNOTRELEASED,
            "DB_E_BADSTORAGEFLAG" => ITF::DB_E_BADSTORAGEFLAG,
            "DB_E_BADCOMPAREOP" => ITF::DB_E_BADCOMPAREOP,
            "DB_E_BADSTATUSVALUE" => ITF::DB_E_BADSTATUSVALUE,
            "DB_E_CANTSCROLLBACKWARDS" => ITF::DB_E_CANTSCROLLBACKWARDS,
            "DB_E_BADREGIONHANDLE" => ITF::DB_E_BADREGIONHANDLE,
            "DB_E_NONCONTIGUOUSRANGE" => ITF::DB_E_NONCONTIGUOUSRANGE,
            "DB_E_INVALIDTRANSITION" => ITF::DB_E_INVALIDTRANSITION,
            "DB_E_NOTASUBREGION" => ITF::DB_E_NOTASUBREGION,
            "DB_E_MULTIPLESTATEMENTS" => ITF::DB_E_MULTIPLESTATEMENTS,
            "DB_E_INTEGRITYVIOLATION" => ITF::DB_E_INTEGRITYVIOLATION,
            "DB_E_BADTYPENAME" => ITF::DB_E_BADTYPENAME,
            "DB_E_ABORTLIMITREACHED" => ITF::DB_E_ABORTLIMITREACHED,
            "DB_E_ROWSETINCOMMAND" => ITF::DB_E_ROWSETINCOMMAND,
            "DB_E_CANTTRANSLATE" => ITF::DB_E_CANTTRANSLATE,
            "DB_E_DUPLICATEINDEXID" => ITF::DB_E_DUPLICATEINDEXID,
            "DB_E_NOINDEX" => ITF::DB_E_NOINDEX,
            "DB_E_INDEXINUSE" => ITF::DB_E_INDEXINUSE,
            "DB_E_NOTABLE" => ITF::DB_E_NOTABLE,
            "DB_E_CONCURRENCYVIOLATION" => ITF::DB_E_CONCURRENCYVIOLATION,
            "DB_E_BADCOPY" => ITF::DB_E_BADCOPY,
            "DB_E_BADPRECISION" => ITF::DB_E_BADPRECISION,
            "DB_E_BADSCALE" => ITF::DB_E_BADSCALE,
            "DB_E_BADTABLEID" => ITF::DB_E_BADTABLEID,
            "DB_E_BADTYPE" => ITF::DB_E_BADTYPE,
            "DB_E_DUPLICATECOLUMNID" => ITF::DB_E_DUPLICATECOLUMNID,
            "DB_E_DUPLICATETABLEID" => ITF::DB_E_DUPLICATETABLEID,
            "DB_E_TABLEINUSE" => ITF::DB_E_TABLEINUSE,
            "DB_E_NOLOCALE" => ITF::DB_E_NOLOCALE,
            "DB_E_BADRECORDNUM" => ITF::DB_E_BADRECORDNUM,
            "DB_E_BOOKMARKSKIPPED" => ITF::DB_E_BOOKMARKSKIPPED,
            "DB_E_BADPROPERTYVALUE" => ITF::DB_E_BADPROPERTYVALUE,
            "DB_E_INVALID" => ITF::DB_E_INVALID,
            "DB_E_BADACCESSORFLAGS" => ITF::DB_E_BADACCESSORFLAGS,
            "DB_E_BADSTORAGEFLAGS" => ITF::DB_E_BADSTORAGEFLAGS,
            "DB_E_BYREFACCESSORNOTSUPPORTED" => ITF::DB_E_BYREFACCESSORNOTSUPPORTED,
            "DB_E_NULLACCESSORNOTSUPPORTED" => ITF::DB_E_NULLACCESSORNOTSUPPORTED,
            "DB_E_NOTPREPARED" => ITF::DB_E_NOTPREPARED,
            "DB_E_BADACCESSORTYPE" => ITF::DB_E_BADACCESSORTYPE,
            "DB_E_WRITEONLYACCESSOR" => ITF::DB_E_WRITEONLYACCESSOR,
            "DB_SEC_E_AUTH_FAILED" => ITF::DB_SEC_E_AUTH_FAILED,
            "DB_E_CANCELED" => ITF::DB_E_CANCELED,
            "DB_E_CHAPTERNOTRELEASED" => ITF::DB_E_CHAPTERNOTRELEASED,
            "DB_E_BADSOURCEHANDLE" => ITF::DB_E_BADSOURCEHANDLE,
            "DB_E_PARAMUNAVAILABLE" => ITF::DB_E_PARAMUNAVAILABLE,
            "DB_E_ALREADYINITIALIZED" => ITF::DB_E_ALREADYINITIALIZED,
            "DB_E_NOTSUPPORTED" => ITF::DB_E_NOTSUPPORTED,
            "DB_E_MAXPENDCHANGESEXCEEDED" => ITF::DB_E_MAXPENDCHANGESEXCEEDED,
            "DB_E_BADORDINAL" => ITF::DB_E_BADORDINAL,
            "DB_E_PENDINGCHANGES" => ITF::DB_E_PENDINGCHANGES,
            "DB_E_DATAOVERFLOW" => ITF::DB_E_DATAOVERFLOW,
            "DB_E_BADHRESULT" => ITF::DB_E_BADHRESULT,
            "DB_E_BADLOOKUPID" => ITF::DB_E_BADLOOKUPID,
            "DB_E_BADDYNAMICERRORID" => ITF::DB_E_BADDYNAMICERRORID,
            "DB_E_PENDINGINSERT" => ITF::DB_E_PENDINGINSERT,
            "DB_E_BADCONVERTFLAG" => ITF::DB_E_BADCONVERTFLAG,
            "DB_E_BADPARAMETERNAME" => ITF::DB_E_BADPARAMETERNAME,
            "DB_E_MULTIPLESTORAGE" => ITF::DB_E_MULTIPLESTORAGE,
            "DB_E_CANTFILTER" => ITF::DB_E_CANTFILTER,
            "DB_E_CANTORDER" => ITF::DB_E_CANTORDER,
            "MD_E_BADTUPLE" => ITF::MD_E_BADTUPLE,
            "MD_E_BADCOORDINATE" => ITF::MD_E_BADCOORDINATE,
            "MD_E_INVALIDAXIS" => ITF::MD_E_INVALIDAXIS,
            "MD_E_INVALIDCELLRANGE" => ITF::MD_E_INVALIDCELLRANGE,
            "DB_E_NOCOLUMN" => ITF::DB_E_NOCOLUMN,
            "DB_E_COMMANDNOTPERSISTED" => ITF::DB_E_COMMANDNOTPERSISTED,
            "DB_E_DUPLICATEID" => ITF::DB_E_DUPLICATEID,
            "DB_E_OBJECTCREATIONLIMITREACHED" => ITF::DB_E_OBJECTCREATIONLIMITREACHED,
            "SEC_E_BADTRUSTEEID" => ITF::SEC_E_BADTRUSTEEID,
            "SEC_E_NOTRUSTEEID" => ITF::SEC_E_NOTRUSTEEID,
            "SEC_E_NOMEMBERSHIPSUPPORT" => ITF::SEC_E_NOMEMBERSHIPSUPPORT,
            "SEC_E_INVALIDOBJECT" => ITF::SEC_E_INVALIDOBJECT,
            "SEC_E_NOOWNER" => ITF::SEC_E_NOOWNER,
            "SEC_E_INVALIDACCESSENTRYLIST" => ITF::SEC_E_INVALIDACCESSENTRYLIST,
            "SEC_E_INVALIDOWNER" => ITF::SEC_E_INVALIDOWNER,
            "SEC_E_INVALIDACCESSENTRY" => ITF::SEC_E_INVALIDACCESSENTRY,
            "DB_E_BADINDEXID" => ITF::DB_E_BADINDEXID,
            "DB_E_BADINITSTRING" => ITF::DB_E_BADINITSTRING,
            "DB_E_NOPROVIDERSREGISTERED" => ITF::DB_E_NOPROVIDERSREGISTERED,
            "DB_E_MISMATCHEDPROVIDER" => ITF::DB_E_MISMATCHEDPROVIDER,
            "DB_E_BADCOMMANDID" => ITF::DB_E_BADCOMMANDID,
            "DB_E_BADCONSTRAINTTYPE" => ITF::DB_E_BADCONSTRAINTTYPE,
            "DB_E_BADCONSTRAINTFORM" => ITF::DB_E_BADCONSTRAINTFORM,
            "DB_E_BADDEFERRABILITY" => ITF::DB_E_BADDEFERRABILITY,
            "DB_E_BADMATCHTYPE" => ITF::DB_E_BADMATCHTYPE,
            "DB_E_BADUPDATEDELETERULE" => ITF::DB_E_BADUPDATEDELETERULE,
            "DB_E_BADCONSTRAINTID" => ITF::DB_E_BADCONSTRAINTID,
            "DB_E_BADCOMMANDFLAGS" => ITF::DB_E_BADCOMMANDFLAGS,
            "DB_E_OBJECTMISMATCH" => ITF::DB_E_OBJECTMISMATCH,
            "DB_E_RESOURCEOUTOFSCOPE" => ITF::DB_E_RESOURCEOUTOFSCOPE,
            "DB_E_DROPRESTRICTED" => ITF::DB_E_DROPRESTRICTED,
            "DB_E_NOSOURCEOBJECT" => ITF::DB_E_NOSOURCEOBJECT,
            "DB_E_RESOURCELOCKED" => ITF::DB_E_RESOURCELOCKED,
            "DB_E_NOTCOLLECTION" => ITF::DB_E_NOTCOLLECTION,
            "DB_E_READONLY" => ITF::DB_E_READONLY,
            "DB_E_ASYNCNOTSUPPORTED" => ITF::DB_E_ASYNCNOTSUPPORTED,
            "DB_E_CANNOTCONNECT" => ITF::DB_E_CANNOTCONNECT,
            "DB_E_TIMEOUT" => ITF::DB_E_TIMEOUT,
            "DB_E_RESOURCEEXISTS" => ITF::DB_E_RESOURCEEXISTS,
            "DB_E_DUPLICATECONSTRAINTID" => ITF::DB_E_DUPLICATECONSTRAINTID,
            "DB_E_OUTOFSPACE" => ITF::DB_E_OUTOFSPACE,
            "DB_SEC_E_SAFEMODE_DENIED" => ITF::DB_SEC_E_SAFEMODE_DENIED,
            "DB_E_NOSTATISTIC" => ITF::DB_E_NOSTATISTIC,
            "DB_E_ALTERRESTRICTED" => ITF::DB_E_ALTERRESTRICTED,
            "DB_E_RESOURCENOTSUPPORTED" => ITF::DB_E_RESOURCENOTSUPPORTED,
            "DB_E_NOCONSTRAINT" => ITF::DB_E_NOCONSTRAINT,
            "DB_E_COLUMNUNAVAILABLE" => ITF::DB_E_COLUMNUNAVAILABLE,
            "DB_E_BOGUS" => ITF::DB_E_BOGUS,
            "DXVA2_E_NOT_INITIALIZED" => ITF::DXVA2_E_NOT_INITIALIZED,
            "MF_E_DXGI_DEVICE_NOT_INITIALIZED" => ITF::MF_E_DXGI_DEVICE_NOT_INITIALIZED,
            "SYNC_E_ID_FORMAT_MISMATCH" => ITF::SYNC_E_ID_FORMAT_MISMATCH,
            "REC_E_ABORTED" => ITF::REC_E_ABORTED,
            "ROUTER_E_NOTINTERESTED" => ITF::ROUTER_E_NOTINTERESTED,
            "DXVA2_E_NEW_VIDEO_DEVICE" => ITF::DXVA2_E_NEW_VIDEO_DEVICE,
            "MF_E_DXGI_NEW_VIDEO_DEVICE" => ITF::MF_E_DXGI_NEW_VIDEO_DEVICE,
            "SYNC_E_INVALID_OPERATION" => ITF::SYNC_E_INVALID_OPERATION,
            "REC_E_NOCALLBACK" => ITF::REC_E_NOCALLBACK,
            "DXVA2_E_VIDEO_DEVICE_LOCKED" => ITF::DXVA2_E_VIDEO_DEVICE_LOCKED,
            "MF_E_DXGI_VIDEO_DEVICE_LOCKED" => ITF::MF_E_DXGI_VIDEO_DEVICE_LOCKED,
            "SYNC_E_REPLICA_NOT_FOUND" => ITF::SYNC_E_REPLICA_NOT_FOUND,
            "REC_E_NORESIDUES" => ITF::REC_E_NORESIDUES,
            "SEO_E_NOTPRESENT" => ITF::SEO_E_NOTPRESENT,
            "DXVA2_E_NOT_AVAILABLE" => ITF::DXVA2_E_NOT_AVAILABLE,
            "SYNC_E_CHANGE_COUNT_MISMATCH" => ITF::SYNC_E_CHANGE_COUNT_MISMATCH,
            "REC_E_TOODIFFERENT" => ITF::REC_E_TOODIFFERENT,
            "SEO_E_TIMEOUT" => ITF::SEO_E_TIMEOUT,
            "SYNC_E_CHANGE_UNIT_COUNT_MISMATCH" => ITF::SYNC_E_CHANGE_UNIT_COUNT_MISMATCH,
            "REC_E_INEEDTODOTHEUPDATES" => ITF::REC_E_INEEDTODOTHEUPDATES,
            "SEO_S_DONEPROCESSING" => ITF::SEO_S_DONEPROCESSING,
            "SYNC_E_KNOWLEDGE_DECREASED" => ITF::SYNC_E_KNOWLEDGE_DECREASED,
            "EVENTS_E_BADDATA" => ITF::EVENTS_E_BADDATA,
            "SYNC_E_CHANGE_NOT_IN_KNOWLEDGE" => ITF::SYNC_E_CHANGE_NOT_IN_KNOWLEDGE,
            "EVENTS_E_TIMEOUT" => ITF::EVENTS_E_TIMEOUT,
            "SYNC_E_ITEM_MUST_EXIST" => ITF::SYNC_E_ITEM_MUST_EXIST,
            "EVENTS_E_DISABLED" => ITF::EVENTS_E_DISABLED,
            "SYNC_E_HAS_NO_DATA" => ITF::SYNC_E_HAS_NO_DATA,
            "SYNC_E_CHANGE_NEEDS_KNOWLEDGE" => ITF::SYNC_E_CHANGE_NEEDS_KNOWLEDGE,
            "SYNC_E_RANGE_OUT_OF_ORDER" => ITF::SYNC_E_RANGE_OUT_OF_ORDER,
            "SYNC_E_NOT_EXPECTED_CHANGE" => ITF::SYNC_E_NOT_EXPECTED_CHANGE,
            "SYNC_E_DESERIALIZATION" => ITF::SYNC_E_DESERIALIZATION,
            "SYNC_E_SINGLE_RANGE_ONLY" => ITF::SYNC_E_SINGLE_RANGE_ONLY,
            "SYNC_E_ITEM_HAS_CHANGE_UNITS" => ITF::SYNC_E_ITEM_HAS_CHANGE_UNITS,
            "SYNC_E_ITEM_HAS_NO_CHANGE_UNITS" => ITF::SYNC_E_ITEM_HAS_NO_CHANGE_UNITS,
            "SYNC_E_ITEM_HAS_NO_VERSION_DATA" => ITF::SYNC_E_ITEM_HAS_NO_VERSION_DATA,
            "SYNC_E_OBJECT_NEEDS_STATE" => ITF::SYNC_E_OBJECT_NEEDS_STATE,
            "SYNC_E_FEEDSYNC_INVALID_FEED" => ITF::SYNC_E_FEEDSYNC_INVALID_FEED,
            "SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA" => ITF::SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA,
            "SYNC_E_FEEDSYNC_CALLBACK_EXPECTED" => ITF::SYNC_E_FEEDSYNC_CALLBACK_EXPECTED,
            "SYNC_E_INVALID_VERSION" => ITF::SYNC_E_INVALID_VERSION,
            "SYNC_E_DUPLICATE_ITEM" => ITF::SYNC_E_DUPLICATE_ITEM,
            "SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS" => ITF::SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS,
            "SYNC_E_INVALID_SYNC_TIME" => ITF::SYNC_E_INVALID_SYNC_TIME,
            "SYNC_E_INCOMPLETE_REPLICA_KEY_MAP" => ITF::SYNC_E_INCOMPLETE_REPLICA_KEY_MAP,
            "SYNC_E_INVALID_REPLICA_KEY" => ITF::SYNC_E_INVALID_REPLICA_KEY,
            "SYNC_E_NEGATIVE_RANGE_EXCEPTION" => ITF::SYNC_E_NEGATIVE_RANGE_EXCEPTION,
            "SYNC_E_BATCH_NEEDS_KNOWLEDGE" => ITF::SYNC_E_BATCH_NEEDS_KNOWLEDGE,
            "SYNC_E_INTERNAL_ERROR" => ITF::SYNC_E_INTERNAL_ERROR,
            "SYNC_E_CHANGE_BATCH_IS_READ_ONLY" => ITF::SYNC_E_CHANGE_BATCH_IS_READ_ONLY,
            "SYNC_E_DATA_MODIFIED_CONCURRENTLY" => ITF::SYNC_E_DATA_MODIFIED_CONCURRENTLY,
            "SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM" => ITF::SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM,
            "SYNC_E_FILTER_NOT_SUPPORTED" => ITF::SYNC_E_FILTER_NOT_SUPPORTED,
            "SYNC_E_LOAD_CONFLICT_DATA_FAILED" => ITF::SYNC_E_LOAD_CONFLICT_DATA_FAILED,
            "SYNC_E_INVALID_SERIALIZATION_VERSION" => ITF::SYNC_E_INVALID_SERIALIZATION_VERSION,
            "SYNC_E_MARKER_MISMATCH" => ITF::SYNC_E_MARKER_MISMATCH,
            "SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED" => ITF::SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED,
            "SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT" => ITF::SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT,
            "SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED" => ITF::SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED,
            "SYNC_E_FULL_ENUMERATION_MUST_BE_USED" => ITF::SYNC_E_FULL_ENUMERATION_MUST_BE_USED,
            "SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE" => ITF::SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE,
            "SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED" => ITF::SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED,
            "SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER" => ITF::SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER,
            "IDX_E_INVALIDTAG" => ITF::IDX_E_INVALIDTAG,
            "IDX_E_METAFILE_CORRUPT" => ITF::IDX_E_METAFILE_CORRUPT,
            "IDX_E_TOO_MANY_SEARCH_SERVERS" => ITF::IDX_E_TOO_MANY_SEARCH_SERVERS,
            "IDX_E_SEARCH_SERVER_ALREADY_EXISTS" => ITF::IDX_E_SEARCH_SERVER_ALREADY_EXISTS,
            "IDX_E_BUILD_IN_PROGRESS" => ITF::IDX_E_BUILD_IN_PROGRESS,
            "IDX_E_IDXLSTFILE_CORRUPT" => ITF::IDX_E_IDXLSTFILE_CORRUPT,
            "IDX_E_REGISTRY_ENTRY" => ITF::IDX_E_REGISTRY_ENTRY,
            "IDX_E_OBJECT_NOT_FOUND" => ITF::IDX_E_OBJECT_NOT_FOUND,
            "IDX_E_SEARCH_SERVER_NOT_FOUND" => ITF::IDX_E_SEARCH_SERVER_NOT_FOUND,
            "IDX_E_WB_NOTFOUND" => ITF::IDX_E_WB_NOTFOUND,
            "IDX_E_NOISELIST_NOTFOUND" => ITF::IDX_E_NOISELIST_NOTFOUND,
            "IDX_E_STEMMER_NOTFOUND" => ITF::IDX_E_STEMMER_NOTFOUND,
            "IDX_E_PROP_STOPPED" => ITF::IDX_E_PROP_STOPPED,
            "IDX_E_DISKFULL" => ITF::IDX_E_DISKFULL,
            "IDX_E_INVALID_INDEX" => ITF::IDX_E_INVALID_INDEX,
            "IDX_E_CORRUPT_INDEX" => ITF::IDX_E_CORRUPT_INDEX,
            "IDX_E_PROPSTORE_INIT_FAILED" => ITF::IDX_E_PROPSTORE_INIT_FAILED,
            "IDX_E_PROP_STATE_CORRUPT" => ITF::IDX_E_PROP_STATE_CORRUPT,
            "IDX_E_NOT_LOADED" => ITF::IDX_E_NOT_LOADED,
            "IDX_E_PROP_MAJOR_VERSION_MISMATCH" => ITF::IDX_E_PROP_MAJOR_VERSION_MISMATCH,
            "IDX_E_PROP_MINOR_VERSION_MISMATCH" => ITF::IDX_E_PROP_MINOR_VERSION_MISMATCH,
            "IDX_E_DSS_NOT_CONNECTED" => ITF::IDX_E_DSS_NOT_CONNECTED,
            "IDX_E_DOCUMENT_ABORTED" => ITF::IDX_E_DOCUMENT_ABORTED,
            "IDX_E_CATALOG_DISMOUNTED" => ITF::IDX_E_CATALOG_DISMOUNTED,
            "IDX_E_USE_DEFAULT_CONTENTCLASS" => ITF::IDX_E_USE_DEFAULT_CONTENTCLASS,
            "IDX_E_USE_APPGLOBAL_PROPTABLE" => ITF::IDX_E_USE_APPGLOBAL_PROPTABLE,
            "JPS_E_JET_ERR" => ITF::JPS_E_JET_ERR,
            "JPS_E_CATALOG_DECSRIPTION_MISSING" => ITF::JPS_E_CATALOG_DECSRIPTION_MISSING,
            "JPS_E_MISSING_INFORMATION" => ITF::JPS_E_MISSING_INFORMATION,
            "JPS_E_INSUFFICIENT_VERSION_STORAGE" => ITF::JPS_E_INSUFFICIENT_VERSION_STORAGE,
            "JPS_E_INSUFFICIENT_DATABASE_SESSIONS" => ITF::JPS_E_INSUFFICIENT_DATABASE_SESSIONS,
            "JPS_E_INSUFFICIENT_DATABASE_RESOURCES" => ITF::JPS_E_INSUFFICIENT_DATABASE_RESOURCES,
            "JPS_E_SCHEMA_ERROR" => ITF::JPS_E_SCHEMA_ERROR,
            "JPS_E_PROPAGATION_FILE" => ITF::JPS_E_PROPAGATION_FILE,
            "JPS_E_PROPAGATION_CORRUPTION" => ITF::JPS_E_PROPAGATION_CORRUPTION,
            "JPS_E_PROPAGATION_VERSION_MISMATCH" => ITF::JPS_E_PROPAGATION_VERSION_MISMATCH,
            "JPS_E_SHARING_VIOLATION" => ITF::JPS_E_SHARING_VIOLATION,
            "EXCI_E_NO_CONFIG" => ITF::EXCI_E_NO_CONFIG,
            "EXCI_E_INVALID_SERVER_CONFIG" => ITF::EXCI_E_INVALID_SERVER_CONFIG,
            "EXCI_E_ACCESS_DENIED" => ITF::EXCI_E_ACCESS_DENIED,
            "EXCI_E_INVALID_EXCHANGE_SERVER" => ITF::EXCI_E_INVALID_EXCHANGE_SERVER,
            "EXCI_E_BADCONFIG_OR_ACCESSDENIED" => ITF::EXCI_E_BADCONFIG_OR_ACCESSDENIED,
            "EXCI_E_WRONG_SERVER_OR_ACCT" => ITF::EXCI_E_WRONG_SERVER_OR_ACCT,
            "EXCI_E_NOT_ADMIN_OR_WRONG_SITE" => ITF::EXCI_E_NOT_ADMIN_OR_WRONG_SITE,
            "EXCI_E_NO_MAPI" => ITF::EXCI_E_NO_MAPI,
            "EXCI_E_INVALID_ACCOUNT_INFO" => ITF::EXCI_E_INVALID_ACCOUNT_INFO,
            "PRTH_E_COMM_ERROR" => ITF::PRTH_E_COMM_ERROR,
            "PRTH_E_OBJ_NOT_FOUND" => ITF::PRTH_E_OBJ_NOT_FOUND,
            "PRTH_E_REQUEST_ERROR" => ITF::PRTH_E_REQUEST_ERROR,
            "PRTH_E_INTERNAL_ERROR" => ITF::PRTH_E_INTERNAL_ERROR,
            "PRTH_E_ACCESS_DENIED" => ITF::PRTH_E_ACCESS_DENIED,
            "PRTH_E_SERVER_ERROR" => ITF::PRTH_E_SERVER_ERROR,
            "PRTH_E_NOT_REDIRECTED" => ITF::PRTH_E_NOT_REDIRECTED,
            "PRTH_E_BAD_REQUEST" => ITF::PRTH_E_BAD_REQUEST,
            "PRTH_E_HTTP_CANNOT_CONNECT" => ITF::PRTH_E_HTTP_CANNOT_CONNECT,
            "PRTH_E_WININET" => ITF::PRTH_E_WININET,
            "PRTH_E_RETRY" => ITF::PRTH_E_RETRY,
            "PRTH_E_MIME_EXCLUDED" => ITF::PRTH_E_MIME_EXCLUDED,
            "PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL" => ITF::PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL,
            "PRTH_E_CANT_TRANSFORM_DENIED_ACE" => ITF::PRTH_E_CANT_TRANSFORM_DENIED_ACE,
            "PRTH_E_ACL_IS_READ_NONE" => ITF::PRTH_E_ACL_IS_READ_NONE,
            "PRTH_E_ACL_TOO_BIG" => ITF::PRTH_E_ACL_TOO_BIG,
            "PRTH_E_NO_PROPERTY" => ITF::PRTH_E_NO_PROPERTY,
            "PRTH_E_DATABASE_OPEN_ERROR" => ITF::PRTH_E_DATABASE_OPEN_ERROR,
            "PRTH_E_OPLOCK_BROKEN" => ITF::PRTH_E_OPLOCK_BROKEN,
            "PRTH_E_LOAD_FAILED" => ITF::PRTH_E_LOAD_FAILED,
            "PRTH_E_INIT_FAILED" => ITF::PRTH_E_INIT_FAILED,
            "PRTH_E_VOLUME_MOUNT_POINT" => ITF::PRTH_E_VOLUME_MOUNT_POINT,
            "PRTH_E_TRUNCATED" => ITF::PRTH_E_TRUNCATED,
            "GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR" => ITF::GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR,
            "PRTH_E_HTTPS_CERTIFICATE_ERROR" => ITF::PRTH_E_HTTPS_CERTIFICATE_ERROR,
            "PRTH_E_HTTPS_REQUIRE_CERTIFICATE" => ITF::PRTH_E_HTTPS_REQUIRE_CERTIFICATE,
            "SCHED_E_TRIGGER_NOT_FOUND" => ITF::SCHED_E_TRIGGER_NOT_FOUND,
            "SCHED_E_TASK_NOT_READY" => ITF::SCHED_E_TASK_NOT_READY,
            "SCHED_E_TASK_NOT_RUNNING" => ITF::SCHED_E_TASK_NOT_RUNNING,
            "SCHED_E_SERVICE_NOT_INSTALLED" => ITF::SCHED_E_SERVICE_NOT_INSTALLED,
            "SCHED_E_CANNOT_OPEN_TASK" => ITF::SCHED_E_CANNOT_OPEN_TASK,
            "SCHED_E_INVALID_TASK" => ITF::SCHED_E_INVALID_TASK,
            "SCHED_E_ACCOUNT_INFORMATION_NOT_SET" => ITF::SCHED_E_ACCOUNT_INFORMATION_NOT_SET,
            "SCHED_E_ACCOUNT_NAME_NOT_FOUND" => ITF::SCHED_E_ACCOUNT_NAME_NOT_FOUND,
            "SCHED_E_ACCOUNT_DBASE_CORRUPT" => ITF::SCHED_E_ACCOUNT_DBASE_CORRUPT,
            "SCHED_E_NO_SECURITY_SERVICES" => ITF::SCHED_E_NO_SECURITY_SERVICES,
            "SCHED_E_UNKNOWN_OBJECT_VERSION" => ITF::SCHED_E_UNKNOWN_OBJECT_VERSION,
            "SCHED_E_UNSUPPORTED_ACCOUNT_OPTION" => ITF::SCHED_E_UNSUPPORTED_ACCOUNT_OPTION,
            "SCHED_E_SERVICE_NOT_RUNNING" => ITF::SCHED_E_SERVICE_NOT_RUNNING,
            "SCHED_E_UNEXPECTEDNODE" => ITF::SCHED_E_UNEXPECTEDNODE,
            "SCHED_E_NAMESPACE" => ITF::SCHED_E_NAMESPACE,
            "SCHED_E_INVALIDVALUE" => ITF::SCHED_E_INVALIDVALUE,
            "SCHED_E_MISSINGNODE" => ITF::SCHED_E_MISSINGNODE,
            "SCHED_E_MALFORMEDXML" => ITF::SCHED_E_MALFORMEDXML,
            "SCHED_E_TOO_MANY_NODES" => ITF::SCHED_E_TOO_MANY_NODES,
            "SCHED_E_PAST_END_BOUNDARY" => ITF::SCHED_E_PAST_END_BOUNDARY,
            "SCHED_E_ALREADY_RUNNING" => ITF::SCHED_E_ALREADY_RUNNING,
            "SCHED_E_USER_NOT_LOGGED_ON" => ITF::SCHED_E_USER_NOT_LOGGED_ON,
            "SCHED_E_INVALID_TASK_HASH" => ITF::SCHED_E_INVALID_TASK_HASH,
            "SCHED_E_SERVICE_NOT_AVAILABLE" => ITF::SCHED_E_SERVICE_NOT_AVAILABLE,
            "SCHED_E_SERVICE_TOO_BUSY" => ITF::SCHED_E_SERVICE_TOO_BUSY,
            "SCHED_E_TASK_ATTEMPTED" => ITF::SCHED_E_TASK_ATTEMPTED,
            "SCHED_E_TASK_DISABLED" => ITF::SCHED_E_TASK_DISABLED,
            "SCHED_E_TASK_NOT_V1_COMPAT" => ITF::SCHED_E_TASK_NOT_V1_COMPAT,
            "SCHED_E_START_ON_DEMAND" => ITF::SCHED_E_START_ON_DEMAND,
            "SCHED_E_TASK_NOT_UBPM_COMPAT" => ITF::SCHED_E_TASK_NOT_UBPM_COMPAT,
            "SCHED_E_DEPRECATED_FEATURE_USED" => ITF::SCHED_E_DEPRECATED_FEATURE_USED,
            "SEC_E_INITFAILED" => ITF::SEC_E_INITFAILED,
            "SEC_E_NOTINITIALIZED" => ITF::SEC_E_NOTINITIALIZED,
            "SEC_E_INVALIDCONTEXT" => ITF::SEC_E_INVALIDCONTEXT,
            "SEC_E_ACCESSDENIED" => ITF::SEC_E_ACCESSDENIED,
            "CMDLINE_E_UNEXPECTED" => ITF::CMDLINE_E_UNEXPECTED,
            "CMDLINE_E_PAREN" => ITF::CMDLINE_E_PAREN,
            "CMDLINE_E_PARAM_SIZE" => ITF::CMDLINE_E_PARAM_SIZE,
            "CMDLINE_E_NOT_INIT" => ITF::CMDLINE_E_NOT_INIT,
            "CMDLINE_E_ALREADY_INIT" => ITF::CMDLINE_E_ALREADY_INIT,
            "CMDLINE_E_NUM_PARAMS" => ITF::CMDLINE_E_NUM_PARAMS,
            "QUERY_E_FAILED" => ITF::QUERY_E_FAILED,
            "SYNC_E_REGISTRATION_INTERNAL_ERROR" => ITF::SYNC_E_REGISTRATION_INTERNAL_ERROR,
            "QUERY_E_INVALIDQUERY" => ITF::QUERY_E_INVALIDQUERY,
            "SYNC_E_REGISTRATION_ALREADY_REGISTERED" => ITF::SYNC_E_REGISTRATION_ALREADY_REGISTERED,
            "QUERY_E_INVALIDRESTRICTION" => ITF::QUERY_E_INVALIDRESTRICTION,
            "SYNC_E_REGISTRATION_NOT_REGISTERED" => ITF::SYNC_E_REGISTRATION_NOT_REGISTERED,
            "QUERY_E_INVALIDSORT" => ITF::QUERY_E_INVALIDSORT,
            "SYNC_E_REGISTRATION_CORRUPT_DATA" => ITF::SYNC_E_REGISTRATION_CORRUPT_DATA,
            "QUERY_E_INVALIDCATEGORIZE" => ITF::QUERY_E_INVALIDCATEGORIZE,
            "SYNC_E_REGISTRATION_ALREADY_COMMITTED" => ITF::SYNC_E_REGISTRATION_ALREADY_COMMITTED,
            "QUERY_E_ALLNOISE" => ITF::QUERY_E_ALLNOISE,
            "QUERY_E_TOOCOMPLEX" => ITF::QUERY_E_TOOCOMPLEX,
            "QUERY_E_TIMEDOUT" => ITF::QUERY_E_TIMEDOUT,
            "QUERY_E_DUPLICATE_OUTPUT_COLUMN" => ITF::QUERY_E_DUPLICATE_OUTPUT_COLUMN,
            "QUERY_E_INVALID_OUTPUT_COLUMN" => ITF::QUERY_E_INVALID_OUTPUT_COLUMN,
            "QUERY_E_INVALID_DIRECTORY" => ITF::QUERY_E_INVALID_DIRECTORY,
            "QUERY_E_DIR_ON_REMOVABLE_DRIVE" => ITF::QUERY_E_DIR_ON_REMOVABLE_DRIVE,
            "QUERY_S_NO_QUERY" => ITF::QUERY_S_NO_QUERY,
            "QUERY_E_ALLNOISE_AND_NO_RELDOC" => ITF::QUERY_E_ALLNOISE_AND_NO_RELDOC,
            "QUERY_E_NO_RELDOC" => ITF::QUERY_E_NO_RELDOC,
            "QUERY_E_ALLNOISE_AND_NO_RELPROP" => ITF::QUERY_E_ALLNOISE_AND_NO_RELPROP,
            "QUERY_E_NO_RELPROP" => ITF::QUERY_E_NO_RELPROP,
            "QUERY_E_REPEATED_RELDOC" => ITF::QUERY_E_REPEATED_RELDOC,
            "QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED" => ITF::QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED,
            "QUERY_E_INVALID_DOCUMENT_IDENTIFIER" => ITF::QUERY_E_INVALID_DOCUMENT_IDENTIFIER,
            "QUERY_E_INCORRECT_VERSION" => ITF::QUERY_E_INCORRECT_VERSION,
            "QUERY_E_INVALIDSCOPE_COALESCE" => ITF::QUERY_E_INVALIDSCOPE_COALESCE,
            "QUERY_E_INVALIDSORT_COALESCE" => ITF::QUERY_E_INVALIDSORT_COALESCE,
            "QUERY_E_INVALIDCOALESCE" => ITF::QUERY_E_INVALIDCOALESCE,
            "QUERY_E_UPGRADEINPROGRESS" => ITF::QUERY_E_UPGRADEINPROGRESS,
            "QUERY_E_AGGREGATE_NOT_SUPPORTED" => ITF::QUERY_E_AGGREGATE_NOT_SUPPORTED,
            "QUERY_E_TOP_LEVEL_IN_GROUP" => ITF::QUERY_E_TOP_LEVEL_IN_GROUP,
            "QUERY_E_DUPLICATE_RANGE_NAME" => ITF::QUERY_E_DUPLICATE_RANGE_NAME,
            "QPLIST_E_CANT_OPEN_FILE" => ITF::QPLIST_E_CANT_OPEN_FILE,
            "QPLIST_E_READ_ERROR" => ITF::QPLIST_E_READ_ERROR,
            "QPLIST_E_EXPECTING_NAME" => ITF::QPLIST_E_EXPECTING_NAME,
            "QPLIST_E_EXPECTING_TYPE" => ITF::QPLIST_E_EXPECTING_TYPE,
            "QPLIST_E_UNRECOGNIZED_TYPE" => ITF::QPLIST_E_UNRECOGNIZED_TYPE,
            "QPLIST_E_EXPECTING_INTEGER" => ITF::QPLIST_E_EXPECTING_INTEGER,
            "QPLIST_E_EXPECTING_CLOSE_PAREN" => ITF::QPLIST_E_EXPECTING_CLOSE_PAREN,
            "QPLIST_E_EXPECTING_GUID" => ITF::QPLIST_E_EXPECTING_GUID,
            "QPLIST_E_BAD_GUID" => ITF::QPLIST_E_BAD_GUID,
            "QPLIST_E_EXPECTING_PROP_SPEC" => ITF::QPLIST_E_EXPECTING_PROP_SPEC,
            "QPLIST_E_CANT_SET_PROPERTY" => ITF::QPLIST_E_CANT_SET_PROPERTY,
            "QPLIST_E_DUPLICATE" => ITF::QPLIST_E_DUPLICATE,
            "QPLIST_E_VECTORBYREF_USED_ALONE" => ITF::QPLIST_E_VECTORBYREF_USED_ALONE,
            "QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE" => ITF::QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE,
            "QPARSE_E_UNEXPECTED_NOT" => ITF::QPARSE_E_UNEXPECTED_NOT,
            "QPARSE_E_EXPECTING_INTEGER" => ITF::QPARSE_E_EXPECTING_INTEGER,
            "QPARSE_E_EXPECTING_REAL" => ITF::QPARSE_E_EXPECTING_REAL,
            "QPARSE_E_EXPECTING_DATE" => ITF::QPARSE_E_EXPECTING_DATE,
            "QPARSE_E_EXPECTING_CURRENCY" => ITF::QPARSE_E_EXPECTING_CURRENCY,
            "QPARSE_E_EXPECTING_GUID" => ITF::QPARSE_E_EXPECTING_GUID,
            "QPARSE_E_EXPECTING_BRACE" => ITF::QPARSE_E_EXPECTING_BRACE,
            "QPARSE_E_EXPECTING_PAREN" => ITF::QPARSE_E_EXPECTING_PAREN,
            "QPARSE_E_EXPECTING_PROPERTY" => ITF::QPARSE_E_EXPECTING_PROPERTY,
            "QPARSE_E_NOT_YET_IMPLEMENTED" => ITF::QPARSE_E_NOT_YET_IMPLEMENTED,
            "QPARSE_E_EXPECTING_PHRASE" => ITF::QPARSE_E_EXPECTING_PHRASE,
            "QPARSE_E_UNSUPPORTED_PROPERTY_TYPE" => ITF::QPARSE_E_UNSUPPORTED_PROPERTY_TYPE,
            "QPARSE_E_EXPECTING_REGEX" => ITF::QPARSE_E_EXPECTING_REGEX,
            "QPARSE_E_EXPECTING_REGEX_PROPERTY" => ITF::QPARSE_E_EXPECTING_REGEX_PROPERTY,
            "QPARSE_E_INVALID_LITERAL" => ITF::QPARSE_E_INVALID_LITERAL,
            "QPARSE_E_NO_SUCH_PROPERTY" => ITF::QPARSE_E_NO_SUCH_PROPERTY,
            "QPARSE_E_EXPECTING_EOS" => ITF::QPARSE_E_EXPECTING_EOS,
            "QPARSE_E_EXPECTING_COMMA" => ITF::QPARSE_E_EXPECTING_COMMA,
            "QPARSE_E_UNEXPECTED_EOS" => ITF::QPARSE_E_UNEXPECTED_EOS,
            "QPARSE_E_WEIGHT_OUT_OF_RANGE" => ITF::QPARSE_E_WEIGHT_OUT_OF_RANGE,
            "QPARSE_E_NO_SUCH_SORT_PROPERTY" => ITF::QPARSE_E_NO_SUCH_SORT_PROPERTY,
            "QPARSE_E_INVALID_SORT_ORDER" => ITF::QPARSE_E_INVALID_SORT_ORDER,
            "QUTIL_E_CANT_CONVERT_VROOT" => ITF::QUTIL_E_CANT_CONVERT_VROOT,
            "QPARSE_E_INVALID_GROUPING" => ITF::QPARSE_E_INVALID_GROUPING,
            "QPARSE_E_INVALID_QUERY" => ITF::QPARSE_E_INVALID_QUERY,
            "QPARSE_E_INVALID_RANKMETHOD" => ITF::QPARSE_E_INVALID_RANKMETHOD,
            "FDAEMON_E_LOWRESOURCE" => ITF::FDAEMON_E_LOWRESOURCE,
            "FDAEMON_E_FATALERROR" => ITF::FDAEMON_E_FATALERROR,
            "FDAEMON_E_PARTITIONDELETED" => ITF::FDAEMON_E_PARTITIONDELETED,
            "FDAEMON_E_CHANGEUPDATEFAILED" => ITF::FDAEMON_E_CHANGEUPDATEFAILED,
            "FDAEMON_E_WORDLISTCOMMITFAILED" => ITF::FDAEMON_E_WORDLISTCOMMITFAILED,
            "FDAEMON_E_NOWORDLIST" => ITF::FDAEMON_E_NOWORDLIST,
            "FDAEMON_E_TOOMANYFILTEREDBLOCKS" => ITF::FDAEMON_E_TOOMANYFILTEREDBLOCKS,
            "SEARCH_E_NOMONIKER" => ITF::SEARCH_E_NOMONIKER,
            "SEARCH_E_NOREGION" => ITF::SEARCH_E_NOREGION,
            "FILTER_E_END_OF_CHUNKS" => ITF::FILTER_E_END_OF_CHUNKS,
            "FILTER_E_NO_MORE_TEXT" => ITF::FILTER_E_NO_MORE_TEXT,
            "FILTER_E_NO_MORE_VALUES" => ITF::FILTER_E_NO_MORE_VALUES,
            "FILTER_E_ACCESS" => ITF::FILTER_E_ACCESS,
            "FILTER_E_NO_TEXT" => ITF::FILTER_E_NO_TEXT,
            "FILTER_E_NO_VALUES" => ITF::FILTER_E_NO_VALUES,
            "FILTER_E_EMBEDDING_UNAVAILABLE" => ITF::FILTER_E_EMBEDDING_UNAVAILABLE,
            "FILTER_E_LINK_UNAVAILABLE" => ITF::FILTER_E_LINK_UNAVAILABLE,
            "FILTER_E_PASSWORD" => ITF::FILTER_E_PASSWORD,
            "FILTER_E_UNKNOWNFORMAT" => ITF::FILTER_E_UNKNOWNFORMAT,
            "FILTER_E_TOO_BIG" => ITF::FILTER_E_TOO_BIG,
            "FILTER_E_ALREADY_OPEN" => ITF::FILTER_E_ALREADY_OPEN,
            "FILTER_E_UNREACHABLE" => ITF::FILTER_E_UNREACHABLE,
            "FILTER_E_IN_USE" => ITF::FILTER_E_IN_USE,
            "FILTER_E_NOT_OPEN" => ITF::FILTER_E_NOT_OPEN,
            "FILTER_E_NO_SUCH_PROPERTY" => ITF::FILTER_E_NO_SUCH_PROPERTY,
            "FILTER_E_OFFLINE" => ITF::FILTER_E_OFFLINE,
            "FILTER_E_PARTIALLY_FILTERED" => ITF::FILTER_E_PARTIALLY_FILTERED,
            "WBREAK_E_END_OF_TEXT" => ITF::WBREAK_E_END_OF_TEXT,
            "WBREAK_E_QUERY_ONLY" => ITF::WBREAK_E_QUERY_ONLY,
            "WBREAK_E_BUFFER_TOO_SMALL" => ITF::WBREAK_E_BUFFER_TOO_SMALL,
            "LANGUAGE_E_DATABASE_NOT_FOUND" => ITF::LANGUAGE_E_DATABASE_NOT_FOUND,
            "WBREAK_E_INIT_FAILED" => ITF::WBREAK_E_INIT_FAILED,
            "PSINK_E_QUERY_ONLY" => ITF::PSINK_E_QUERY_ONLY,
            "PSINK_E_INDEX_ONLY" => ITF::PSINK_E_INDEX_ONLY,
            "PSINK_E_LARGE_ATTACHMENT" => ITF::PSINK_E_LARGE_ATTACHMENT,
            "CI_E_ALREADY_INITIALIZED" => ITF::CI_E_ALREADY_INITIALIZED,
            "CI_E_NOT_INITIALIZED" => ITF::CI_E_NOT_INITIALIZED,
            "CI_E_BUFFERTOOSMALL" => ITF::CI_E_BUFFERTOOSMALL,
            "CI_E_PROPERTY_NOT_CACHED" => ITF::CI_E_PROPERTY_NOT_CACHED,
            "CI_E_INVALID_STATE" => ITF::CI_E_INVALID_STATE,
            "CI_E_FILTERING_DISABLED" => ITF::CI_E_FILTERING_DISABLED,
            "CI_E_DISK_FULL" => ITF::CI_E_DISK_FULL,
            "CI_E_SHUTDOWN" => ITF::CI_E_SHUTDOWN,
            "CI_E_WORKID_NOTVALID" => ITF::CI_E_WORKID_NOTVALID,
            "CI_E_NOT_FOUND" => ITF::CI_E_NOT_FOUND,
            "CI_E_USE_DEFAULT_PID" => ITF::CI_E_USE_DEFAULT_PID,
            "CI_E_DUPLICATE_NOTIFICATION" => ITF::CI_E_DUPLICATE_NOTIFICATION,
            "CI_E_UPDATES_DISABLED" => ITF::CI_E_UPDATES_DISABLED,
            "CI_E_INVALID_FLAGS_COMBINATION" => ITF::CI_E_INVALID_FLAGS_COMBINATION,
            "CI_E_OUTOFSEQ_INCREMENT_DATA" => ITF::CI_E_OUTOFSEQ_INCREMENT_DATA,
            "CI_E_SHARING_VIOLATION" => ITF::CI_E_SHARING_VIOLATION,
            "CI_E_LOGON_FAILURE" => ITF::CI_E_LOGON_FAILURE,
            "CI_E_NO_CATALOG" => ITF::CI_E_NO_CATALOG,
            "CI_E_STRANGE_PAGEORSECTOR_SIZE" => ITF::CI_E_STRANGE_PAGEORSECTOR_SIZE,
            "CI_E_TIMEOUT" => ITF::CI_E_TIMEOUT,
            "CI_E_NOT_RUNNING" => ITF::CI_E_NOT_RUNNING,
            "CI_E_CARDINALITY_MISMATCH" => ITF::CI_E_CARDINALITY_MISMATCH,
            "CI_E_CONFIG_DISK_FULL" => ITF::CI_E_CONFIG_DISK_FULL,
            "CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED" => ITF::CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED,
            "CI_E_NO_AUXMETADATA" => ITF::CI_E_NO_AUXMETADATA,
            "CI_E_INVALID_CATALOG_LIST_VERSION" => ITF::CI_E_INVALID_CATALOG_LIST_VERSION,
            "NLADMIN_E_DUPLICATE_CATALOG" => ITF::NLADMIN_E_DUPLICATE_CATALOG,
            "NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE" => ITF::NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE,
            "NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED" => ITF::NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED,
            "FAX_E_SRV_OUTOFMEMORY" => ITF::FAX_E_SRV_OUTOFMEMORY,
            "FAX_E_GROUP_NOT_FOUND" => ITF::FAX_E_GROUP_NOT_FOUND,
            "FAX_E_BAD_GROUP_CONFIGURATION" => ITF::FAX_E_BAD_GROUP_CONFIGURATION,
            "FAX_E_GROUP_IN_USE" => ITF::FAX_E_GROUP_IN_USE,
            "FAX_E_RULE_NOT_FOUND" => ITF::FAX_E_RULE_NOT_FOUND,
            "FAX_E_NOT_NTFS" => ITF::FAX_E_NOT_NTFS,
            "FAX_E_DIRECTORY_IN_USE" => ITF::FAX_E_DIRECTORY_IN_USE,
            "FAX_E_FILE_ACCESS_DENIED" => ITF::FAX_E_FILE_ACCESS_DENIED,
            "FAX_E_MESSAGE_NOT_FOUND" => ITF::FAX_E_MESSAGE_NOT_FOUND,
            "FAX_E_DEVICE_NUM_LIMIT_EXCEEDED" => ITF::FAX_E_DEVICE_NUM_LIMIT_EXCEEDED,
            "FAX_E_NOT_SUPPORTED_ON_THIS_SKU" => ITF::FAX_E_NOT_SUPPORTED_ON_THIS_SKU,
            "FAX_E_VERSION_MISMATCH" => ITF::FAX_E_VERSION_MISMATCH,
            "FAX_E_RECIPIENTS_LIMIT" => ITF::FAX_E_RECIPIENTS_LIMIT,
            "SCRIPTPI_E_CHUNK_NOT_TEXT" => ITF::SCRIPTPI_E_CHUNK_NOT_TEXT,
            "SCRIPTPI_E_PID_NOT_NAME" => ITF::SCRIPTPI_E_PID_NOT_NAME,
            "SCRIPTPI_E_PID_NOT_NUMERIC" => ITF::SCRIPTPI_E_PID_NOT_NUMERIC,
            "SCRIPTPI_E_CHUNK_NOT_VALUE" => ITF::SCRIPTPI_E_CHUNK_NOT_VALUE,
            "SCRIPTPI_E_CANNOT_ALTER_CHUNK" => ITF::SCRIPTPI_E_CANNOT_ALTER_CHUNK,
            "SCRIPTPI_E_ALREADY_COMPLETED" => ITF::SCRIPTPI_E_ALREADY_COMPLETED,
            "MSS_E_INVALIDAPPNAME" => ITF::MSS_E_INVALIDAPPNAME,
            "MSS_E_APPNOTFOUND" => ITF::MSS_E_APPNOTFOUND,
            "MSS_E_APPALREADYEXISTS" => ITF::MSS_E_APPALREADYEXISTS,
            "MSS_E_CATALOGNOTFOUND" => ITF::MSS_E_CATALOGNOTFOUND,
            "MSS_E_CATALOGSTOPPING" => ITF::MSS_E_CATALOGSTOPPING,
            "MSS_E_UNICODEFILEHEADERMISSING" => ITF::MSS_E_UNICODEFILEHEADERMISSING,
            "MSS_E_CATALOGALREADYEXISTS" => ITF::MSS_E_CATALOGALREADYEXISTS,
            "XML_E_NODEFAULTNS" => ITF::XML_E_NODEFAULTNS,
            "XML_E_BADSXQL" => ITF::XML_E_BADSXQL,
            "VSS_E_BAD_STATE" => ITF::VSS_E_BAD_STATE,
            "VSS_E_UNEXPECTED" => ITF::VSS_E_UNEXPECTED,
            "VSS_E_PROVIDER_ALREADY_REGISTERED" => ITF::VSS_E_PROVIDER_ALREADY_REGISTERED,
            "VSS_E_PROVIDER_NOT_REGISTERED" => ITF::VSS_E_PROVIDER_NOT_REGISTERED,
            "VSS_E_PROVIDER_VETO" => ITF::VSS_E_PROVIDER_VETO,
            "VSS_E_PROVIDER_IN_USE" => ITF::VSS_E_PROVIDER_IN_USE,
            "VSS_E_OBJECT_NOT_FOUND" => ITF::VSS_E_OBJECT_NOT_FOUND,
            "VSS_E_VOLUME_NOT_SUPPORTED" => ITF::VSS_E_VOLUME_NOT_SUPPORTED,
            "VSS_E_OBJECT_ALREADY_EXISTS" => ITF::VSS_E_OBJECT_ALREADY_EXISTS,
            "VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER" => ITF::VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER,
            "VSS_E_UNEXPECTED_PROVIDER_ERROR" => ITF::VSS_E_UNEXPECTED_PROVIDER_ERROR,
            "VSS_E_CORRUPT_XML_DOCUMENT" => ITF::VSS_E_CORRUPT_XML_DOCUMENT,
            "VSS_E_INVALID_XML_DOCUMENT" => ITF::VSS_E_INVALID_XML_DOCUMENT,
            "VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED" => ITF::VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED,
            "VSS_E_FLUSH_WRITES_TIMEOUT" => ITF::VSS_E_FLUSH_WRITES_TIMEOUT,
            "VSS_E_HOLD_WRITES_TIMEOUT" => ITF::VSS_E_HOLD_WRITES_TIMEOUT,
            "VSS_E_UNEXPECTED_WRITER_ERROR" => ITF::VSS_E_UNEXPECTED_WRITER_ERROR,
            "VSS_E_SNAPSHOT_SET_IN_PROGRESS" => ITF::VSS_E_SNAPSHOT_SET_IN_PROGRESS,
            "VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED" => ITF::VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED,
            "VSS_E_WRITER_INFRASTRUCTURE" => ITF::VSS_E_WRITER_INFRASTRUCTURE,
            "VSS_E_WRITER_NOT_RESPONDING" => ITF::VSS_E_WRITER_NOT_RESPONDING,
            "VSS_E_WRITER_ALREADY_SUBSCRIBED" => ITF::VSS_E_WRITER_ALREADY_SUBSCRIBED,
            "VSS_E_UNSUPPORTED_CONTEXT" => ITF::VSS_E_UNSUPPORTED_CONTEXT,
            "VSS_E_VOLUME_IN_USE" => ITF::VSS_E_VOLUME_IN_USE,
            "VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED" => ITF::VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED,
            "VSS_E_INSUFFICIENT_STORAGE" => ITF::VSS_E_INSUFFICIENT_STORAGE,
            "VSS_E_NO_SNAPSHOTS_IMPORTED" => ITF::VSS_E_NO_SNAPSHOTS_IMPORTED,
            "VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED" => ITF::VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED,
            "VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED" => ITF::VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED,
            "VSS_E_REMOTE_SERVER_UNAVAILABLE" => ITF::VSS_E_REMOTE_SERVER_UNAVAILABLE,
            "VSS_E_REMOTE_SERVER_UNSUPPORTED" => ITF::VSS_E_REMOTE_SERVER_UNSUPPORTED,
            "VSS_E_REVERT_IN_PROGRESS" => ITF::VSS_E_REVERT_IN_PROGRESS,
            "VSS_E_REVERT_VOLUME_LOST" => ITF::VSS_E_REVERT_VOLUME_LOST,
            "VSS_E_REBOOT_REQUIRED" => ITF::VSS_E_REBOOT_REQUIRED,
            "VSS_E_TRANSACTION_FREEZE_TIMEOUT" => ITF::VSS_E_TRANSACTION_FREEZE_TIMEOUT,
            "VSS_E_TRANSACTION_THAW_TIMEOUT" => ITF::VSS_E_TRANSACTION_THAW_TIMEOUT,
            "VSS_E_UNSELECTED_VOLUME" => ITF::VSS_E_UNSELECTED_VOLUME,
            "VSS_E_SNAPSHOT_NOT_IN_SET" => ITF::VSS_E_SNAPSHOT_NOT_IN_SET,
            "VSS_E_NESTED_VOLUME_LIMIT" => ITF::VSS_E_NESTED_VOLUME_LIMIT,
            "VSS_E_VOLUME_NOT_LOCAL" => ITF::VSS_E_VOLUME_NOT_LOCAL,
            "VSS_E_CLUSTER_TIMEOUT" => ITF::VSS_E_CLUSTER_TIMEOUT,
            "VSS_E_NOT_SUPPORTED" => ITF::VSS_E_NOT_SUPPORTED,
            "VSS_E_WRITERERROR_PARTIAL_FAILURE" => ITF::VSS_E_WRITERERROR_PARTIAL_FAILURE,
            "VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT" => ITF::VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT,
            "VSS_E_WRITERERROR_OUTOFRESOURCES" => ITF::VSS_E_WRITERERROR_OUTOFRESOURCES,
            "VSS_E_WRITERERROR_TIMEOUT" => ITF::VSS_E_WRITERERROR_TIMEOUT,
            "VSS_E_WRITERERROR_RETRYABLE" => ITF::VSS_E_WRITERERROR_RETRYABLE,
            "VSS_E_WRITERERROR_NONRETRYABLE" => ITF::VSS_E_WRITERERROR_NONRETRYABLE,
            "VSS_E_WRITERERROR_RECOVERY_FAILED" => ITF::VSS_E_WRITERERROR_RECOVERY_FAILED,
            "VSS_E_BREAK_REVERT_ID_FAILED" => ITF::VSS_E_BREAK_REVERT_ID_FAILED,
            "VSS_E_LEGACY_PROVIDER" => ITF::VSS_E_LEGACY_PROVIDER,
            "VSS_E_MISSING_DISK" => ITF::VSS_E_MISSING_DISK,
            "VSS_E_MISSING_HIDDEN_VOLUME" => ITF::VSS_E_MISSING_HIDDEN_VOLUME,
            "VSS_E_MISSING_VOLUME" => ITF::VSS_E_MISSING_VOLUME,
            "VSS_E_AUTORECOVERY_FAILED" => ITF::VSS_E_AUTORECOVERY_FAILED,
            "VSS_E_DYNAMIC_DISK_ERROR" => ITF::VSS_E_DYNAMIC_DISK_ERROR,
            "VSS_E_NONTRANSPORTABLE_BCD" => ITF::VSS_E_NONTRANSPORTABLE_BCD,
            "VSS_E_CANNOT_REVERT_DISKID" => ITF::VSS_E_CANNOT_REVERT_DISKID,
            "VSS_E_RESYNC_IN_PROGRESS" => ITF::VSS_E_RESYNC_IN_PROGRESS,
            "VDS_E_NOT_SUPPORTED" => ITF::VDS_E_NOT_SUPPORTED,
            "VSS_E_CLUSTER_ERROR" => ITF::VSS_E_CLUSTER_ERROR,
            "FLTRDMN_E_UNEXPECTED" => ITF::FLTRDMN_E_UNEXPECTED,
            "VDS_E_INITIALIZED_FAILED" => ITF::VDS_E_INITIALIZED_FAILED,
            "VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED" => ITF::VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED,
            "FLTRDMN_E_QI_FILTER_FAILED" => ITF::FLTRDMN_E_QI_FILTER_FAILED,
            "VDS_E_INITIALIZE_NOT_CALLED" => ITF::VDS_E_INITIALIZE_NOT_CALLED,
            "VSS_E_ASRERROR_DISK_RECREATION_FAILED" => ITF::VSS_E_ASRERROR_DISK_RECREATION_FAILED,
            "VDS_E_ALREADY_REGISTERED" => ITF::VDS_E_ALREADY_REGISTERED,
            "VSS_E_ASRERROR_NO_ARCPATH" => ITF::VSS_E_ASRERROR_NO_ARCPATH,
            "FLTRDMN_E_FILTER_INIT_FAILED" => ITF::FLTRDMN_E_FILTER_INIT_FAILED,
            "VDS_E_ANOTHER_CALL_IN_PROGRESS" => ITF::VDS_E_ANOTHER_CALL_IN_PROGRESS,
            "VSS_E_ASRERROR_MISSING_DYNDISK" => ITF::VSS_E_ASRERROR_MISSING_DYNDISK,
            "FLTRDMN_E_ENCRYPTED_DOCUMENT" => ITF::FLTRDMN_E_ENCRYPTED_DOCUMENT,
            "VDS_E_OBJECT_NOT_FOUND" => ITF::VDS_E_OBJECT_NOT_FOUND,
            "VSS_E_ASRERROR_SHARED_CRIDISK" => ITF::VSS_E_ASRERROR_SHARED_CRIDISK,
            "FLTRDMN_E_CANNOT_DECRYPT_PASSWORD" => ITF::FLTRDMN_E_CANNOT_DECRYPT_PASSWORD,
            "VDS_E_INVALID_SPACE" => ITF::VDS_E_INVALID_SPACE,
            "VSS_E_ASRERROR_DATADISK_RDISK0" => ITF::VSS_E_ASRERROR_DATADISK_RDISK0,
            "VDS_E_PARTITION_LIMIT_REACHED" => ITF::VDS_E_PARTITION_LIMIT_REACHED,
            "VSS_E_ASRERROR_RDISK0_TOOSMALL" => ITF::VSS_E_ASRERROR_RDISK0_TOOSMALL,
            "VDS_E_PARTITION_NOT_EMPTY" => ITF::VDS_E_PARTITION_NOT_EMPTY,
            "VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL" => ITF::VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL,
            "VDS_E_OPERATION_PENDING" => ITF::VDS_E_OPERATION_PENDING,
            "VSS_E_WRITER_STATUS_NOT_AVAILABLE" => ITF::VSS_E_WRITER_STATUS_NOT_AVAILABLE,
            "VDS_E_OPERATION_DENIED" => ITF::VDS_E_OPERATION_DENIED,
            "VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED" => ITF::VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED,
            "VDS_E_OBJECT_DELETED" => ITF::VDS_E_OBJECT_DELETED,
            "VDS_E_CANCEL_TOO_LATE" => ITF::VDS_E_CANCEL_TOO_LATE,
            "VDS_E_OPERATION_CANCELED" => ITF::VDS_E_OPERATION_CANCELED,
            "VDS_E_CANNOT_EXTEND" => ITF::VDS_E_CANNOT_EXTEND,
            "VDS_E_NOT_ENOUGH_SPACE" => ITF::VDS_E_NOT_ENOUGH_SPACE,
            "VDS_E_NOT_ENOUGH_DRIVE" => ITF::VDS_E_NOT_ENOUGH_DRIVE,
            "VDS_E_BAD_COOKIE" => ITF::VDS_E_BAD_COOKIE,
            "VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK" => ITF::VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK,
            "VDS_E_NO_MEDIA" => ITF::VDS_E_NO_MEDIA,
            "VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND" => ITF::VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND,
            "VDS_E_DEVICE_IN_USE" => ITF::VDS_E_DEVICE_IN_USE,
            "VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE" => ITF::VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE,
            "VDS_E_DISK_NOT_EMPTY" => ITF::VDS_E_DISK_NOT_EMPTY,
            "VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION" => ITF::VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION,
            "VDS_E_INVALID_OPERATION" => ITF::VDS_E_INVALID_OPERATION,
            "VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED" => ITF::VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED,
            "VDS_E_PATH_NOT_FOUND" => ITF::VDS_E_PATH_NOT_FOUND,
            "VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN" => ITF::VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN,
            "VDS_E_DISK_NOT_INITIALIZED" => ITF::VDS_E_DISK_NOT_INITIALIZED,
            "VSS_E_FSS_TIMEOUT" => ITF::VSS_E_FSS_TIMEOUT,
            "VDS_E_NOT_AN_UNALLOCATED_DISK" => ITF::VDS_E_NOT_AN_UNALLOCATED_DISK,
            "VDS_E_UNRECOVERABLE_ERROR" => ITF::VDS_E_UNRECOVERABLE_ERROR,
            "VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED" => ITF::VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED,
            "VDS_E_PROVIDER_INITIALIZATION_FAILED" => ITF::VDS_E_PROVIDER_INITIALIZATION_FAILED,
            "VDS_E_OBJECT_EXISTS" => ITF::VDS_E_OBJECT_EXISTS,
            "VDS_E_NO_DISKS_FOUND" => ITF::VDS_E_NO_DISKS_FOUND,
            "VDS_E_PROVIDER_CACHE_CORRUPT" => ITF::VDS_E_PROVIDER_CACHE_CORRUPT,
            "VDS_E_DMADMIN_METHOD_CALL_FAILED" => ITF::VDS_E_DMADMIN_METHOD_CALL_FAILED,
            "VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND" => ITF::VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND,
            "VDS_E_PROVIDER_VOL_OPEN" => ITF::VDS_E_PROVIDER_VOL_OPEN,
            "VDS_E_DMADMIN_CORRUPT_NOTIFICATION" => ITF::VDS_E_DMADMIN_CORRUPT_NOTIFICATION,
            "VDS_E_INCOMPATIBLE_FILE_SYSTEM" => ITF::VDS_E_INCOMPATIBLE_FILE_SYSTEM,
            "VDS_E_INCOMPATIBLE_MEDIA" => ITF::VDS_E_INCOMPATIBLE_MEDIA,
            "VDS_E_ACCESS_DENIED" => ITF::VDS_E_ACCESS_DENIED,
            "VDS_E_MEDIA_WRITE_PROTECTED" => ITF::VDS_E_MEDIA_WRITE_PROTECTED,
            "VDS_E_BAD_LABEL" => ITF::VDS_E_BAD_LABEL,
            "VDS_E_CANT_QUICK_FORMAT" => ITF::VDS_E_CANT_QUICK_FORMAT,
            "VDS_E_IO_ERROR" => ITF::VDS_E_IO_ERROR,
            "VDS_E_VOLUME_TOO_SMALL" => ITF::VDS_E_VOLUME_TOO_SMALL,
            "VDS_E_VOLUME_TOO_BIG" => ITF::VDS_E_VOLUME_TOO_BIG,
            "VDS_E_CLUSTER_SIZE_TOO_SMALL" => ITF::VDS_E_CLUSTER_SIZE_TOO_SMALL,
            "VDS_E_CLUSTER_SIZE_TOO_BIG" => ITF::VDS_E_CLUSTER_SIZE_TOO_BIG,
            "VDS_E_CLUSTER_COUNT_BEYOND_32BITS" => ITF::VDS_E_CLUSTER_COUNT_BEYOND_32BITS,
            "VDS_E_OBJECT_STATUS_FAILED" => ITF::VDS_E_OBJECT_STATUS_FAILED,
            "VDS_E_VOLUME_INCOMPLETE" => ITF::VDS_E_VOLUME_INCOMPLETE,
            "VDS_E_EXTENT_SIZE_LESS_THAN_MIN" => ITF::VDS_E_EXTENT_SIZE_LESS_THAN_MIN,
            "VDS_E_BOOT_PARTITION_NUMBER_CHANGE" => ITF::VDS_E_BOOT_PARTITION_NUMBER_CHANGE,
            "VDS_E_NO_FREE_SPACE" => ITF::VDS_E_NO_FREE_SPACE,
            "VDS_E_ACTIVE_PARTITION" => ITF::VDS_E_ACTIVE_PARTITION,
            "VDS_E_PARTITION_OF_UNKNOWN_TYPE" => ITF::VDS_E_PARTITION_OF_UNKNOWN_TYPE,
            "VDS_E_LEGACY_VOLUME_FORMAT" => ITF::VDS_E_LEGACY_VOLUME_FORMAT,
            "VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS" => ITF::VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS,
            "VDS_E_MIGRATE_OPEN_VOLUME" => ITF::VDS_E_MIGRATE_OPEN_VOLUME,
            "VDS_E_VOLUME_NOT_ONLINE" => ITF::VDS_E_VOLUME_NOT_ONLINE,
            "VDS_E_VOLUME_NOT_HEALTHY" => ITF::VDS_E_VOLUME_NOT_HEALTHY,
            "VDS_E_VOLUME_SPANS_DISKS" => ITF::VDS_E_VOLUME_SPANS_DISKS,
            "VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE" => ITF::VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE,
            "VDS_E_BAD_PROVIDER_DATA" => ITF::VDS_E_BAD_PROVIDER_DATA,
            "VDS_E_PROVIDER_FAILURE" => ITF::VDS_E_PROVIDER_FAILURE,
            "VDS_E_PACK_OFFLINE" => ITF::VDS_E_PACK_OFFLINE,
            "VDS_E_VOLUME_NOT_A_MIRROR" => ITF::VDS_E_VOLUME_NOT_A_MIRROR,
            "VDS_E_NO_EXTENTS_FOR_VOLUME" => ITF::VDS_E_NO_EXTENTS_FOR_VOLUME,
            "VDS_E_DISK_NOT_LOADED_TO_CACHE" => ITF::VDS_E_DISK_NOT_LOADED_TO_CACHE,
            "VDS_E_INTERNAL_ERROR" => ITF::VDS_E_INTERNAL_ERROR,
            "VDS_E_PROVIDER_TYPE_NOT_SUPPORTED" => ITF::VDS_E_PROVIDER_TYPE_NOT_SUPPORTED,
            "VDS_E_DISK_NOT_ONLINE" => ITF::VDS_E_DISK_NOT_ONLINE,
            "VDS_E_DISK_IN_USE_BY_VOLUME" => ITF::VDS_E_DISK_IN_USE_BY_VOLUME,
            "VDS_E_ASYNC_OBJECT_FAILURE" => ITF::VDS_E_ASYNC_OBJECT_FAILURE,
            "VDS_E_VOLUME_NOT_MOUNTED" => ITF::VDS_E_VOLUME_NOT_MOUNTED,
            "VDS_E_PACK_NOT_FOUND" => ITF::VDS_E_PACK_NOT_FOUND,
            "VDS_E_IMPORT_SET_INCOMPLETE" => ITF::VDS_E_IMPORT_SET_INCOMPLETE,
            "VDS_E_DISK_NOT_IMPORTED" => ITF::VDS_E_DISK_NOT_IMPORTED,
            "VDS_E_OBJECT_OUT_OF_SYNC" => ITF::VDS_E_OBJECT_OUT_OF_SYNC,
            "VDS_E_MISSING_DISK" => ITF::VDS_E_MISSING_DISK,
            "VDS_E_DISK_PNP_REG_CORRUPT" => ITF::VDS_E_DISK_PNP_REG_CORRUPT,
            "VDS_E_LBN_REMAP_ENABLED_FLAG" => ITF::VDS_E_LBN_REMAP_ENABLED_FLAG,
            "VDS_E_NO_DRIVELETTER_FLAG" => ITF::VDS_E_NO_DRIVELETTER_FLAG,
            "VDS_E_REVERT_ON_CLOSE" => ITF::VDS_E_REVERT_ON_CLOSE,
            "VDS_E_REVERT_ON_CLOSE_SET" => ITF::VDS_E_REVERT_ON_CLOSE_SET,
            "VDS_E_IA64_BOOT_MIRRORED_TO_MBR" => ITF::VDS_E_IA64_BOOT_MIRRORED_TO_MBR,
            "VDS_E_VOLUME_TEMPORARILY_DISMOUNTED" => ITF::VDS_E_VOLUME_TEMPORARILY_DISMOUNTED,
            "VDS_E_VOLUME_PERMANENTLY_DISMOUNTED" => ITF::VDS_E_VOLUME_PERMANENTLY_DISMOUNTED,
            "VDS_E_VOLUME_HAS_PATH" => ITF::VDS_E_VOLUME_HAS_PATH,
            "VDS_E_TIMEOUT" => ITF::VDS_E_TIMEOUT,
            "VDS_E_REPAIR_VOLUMESTATE" => ITF::VDS_E_REPAIR_VOLUMESTATE,
            "VDS_E_LDM_TIMEOUT" => ITF::VDS_E_LDM_TIMEOUT,
            "VDS_E_REVERT_ON_CLOSE_MISMATCH" => ITF::VDS_E_REVERT_ON_CLOSE_MISMATCH,
            "VDS_E_RETRY" => ITF::VDS_E_RETRY,
            "VDS_E_ONLINE_PACK_EXISTS" => ITF::VDS_E_ONLINE_PACK_EXISTS,
            "VDS_E_EXTEND_FILE_SYSTEM_FAILED" => ITF::VDS_E_EXTEND_FILE_SYSTEM_FAILED,
            "VDS_E_MAX_USABLE_MBR" => ITF::VDS_E_MAX_USABLE_MBR,
            "VDS_S_GPT_BOOT_MIRRORED_TO_MBR" => ITF::VDS_S_GPT_BOOT_MIRRORED_TO_MBR,
            "OLEDB_BINDER_CUSTOM_ERROR" => ITF::OLEDB_BINDER_CUSTOM_ERROR,
            "VDS_E_NO_SOFTWARE_PROVIDERS_LOADED" => ITF::VDS_E_NO_SOFTWARE_PROVIDERS_LOADED,
            "VDS_E_DISK_NOT_MISSING" => ITF::VDS_E_DISK_NOT_MISSING,
            "VDS_E_NO_VOLUME_LAYOUT" => ITF::VDS_E_NO_VOLUME_LAYOUT,
            "VDS_E_CORRUPT_VOLUME_INFO" => ITF::VDS_E_CORRUPT_VOLUME_INFO,
            "VDS_E_INVALID_ENUMERATOR" => ITF::VDS_E_INVALID_ENUMERATOR,
            "VDS_E_DRIVER_INTERNAL_ERROR" => ITF::VDS_E_DRIVER_INTERNAL_ERROR,
            "VDS_E_VOLUME_INVALID_NAME" => ITF::VDS_E_VOLUME_INVALID_NAME,
            "VDS_E_CORRUPT_PARTITION_INFO" => ITF::VDS_E_CORRUPT_PARTITION_INFO,
            "VDS_E_CORRUPT_EXTENT_INFO" => ITF::VDS_E_CORRUPT_EXTENT_INFO,
            "VDS_E_DUP_EMPTY_PACK_GUID" => ITF::VDS_E_DUP_EMPTY_PACK_GUID,
            "VDS_E_DRIVER_NO_PACK_NAME" => ITF::VDS_E_DRIVER_NO_PACK_NAME,
            "VDS_E_BAD_PNP_MESSAGE" => ITF::VDS_E_BAD_PNP_MESSAGE,
            "VDS_E_NO_PNP_DISK_ARRIVE" => ITF::VDS_E_NO_PNP_DISK_ARRIVE,
            "VDS_E_NO_PNP_VOLUME_ARRIVE" => ITF::VDS_E_NO_PNP_VOLUME_ARRIVE,
            "VDS_E_NO_PNP_DISK_REMOVE" => ITF::VDS_E_NO_PNP_DISK_REMOVE,
            "VDS_E_NO_PNP_VOLUME_REMOVE" => ITF::VDS_E_NO_PNP_VOLUME_REMOVE,
            "VDS_E_PROVIDER_EXITING" => ITF::VDS_E_PROVIDER_EXITING,
            "VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE" => ITF::VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE,
            "VDS_E_MEMBER_SIZE_INVALID" => ITF::VDS_E_MEMBER_SIZE_INVALID,
            "VDS_E_INVALID_DISK" => ITF::VDS_E_INVALID_DISK,
            "VDS_E_INVALID_PACK" => ITF::VDS_E_INVALID_PACK,
            "VDS_E_VOLUME_ON_DISK" => ITF::VDS_E_VOLUME_ON_DISK,
            "VDS_E_DRIVER_INVALID_PARAM" => ITF::VDS_E_DRIVER_INVALID_PARAM,
            "VDS_E_TARGET_PACK_NOT_EMPTY" => ITF::VDS_E_TARGET_PACK_NOT_EMPTY,
            "VDS_E_CANNOT_SHRINK" => ITF::VDS_E_CANNOT_SHRINK,
            "VDS_E_MULTIPLE_PACKS" => ITF::VDS_E_MULTIPLE_PACKS,
            "VDS_E_PACK_ONLINE" => ITF::VDS_E_PACK_ONLINE,
            "VDS_E_INVALID_PLEX_COUNT" => ITF::VDS_E_INVALID_PLEX_COUNT,
            "VDS_E_INVALID_MEMBER_COUNT" => ITF::VDS_E_INVALID_MEMBER_COUNT,
            "VDS_E_INVALID_PLEX_ORDER" => ITF::VDS_E_INVALID_PLEX_ORDER,
            "VDS_E_INVALID_MEMBER_ORDER" => ITF::VDS_E_INVALID_MEMBER_ORDER,
            "VDS_E_INVALID_STRIPE_SIZE" => ITF::VDS_E_INVALID_STRIPE_SIZE,
            "VDS_E_INVALID_DISK_COUNT" => ITF::VDS_E_INVALID_DISK_COUNT,
            "VDS_E_INVALID_EXTENT_COUNT" => ITF::VDS_E_INVALID_EXTENT_COUNT,
            "VDS_E_SOURCE_IS_TARGET_PACK" => ITF::VDS_E_SOURCE_IS_TARGET_PACK,
            "VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED" => ITF::VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED,
            "VDS_E_CORRUPT_NOTIFICATION_INFO" => ITF::VDS_E_CORRUPT_NOTIFICATION_INFO,
            "VDS_E_INVALID_PLEX_GUID" => ITF::VDS_E_INVALID_PLEX_GUID,
            "VDS_E_DISK_NOT_FOUND_IN_PACK" => ITF::VDS_E_DISK_NOT_FOUND_IN_PACK,
            "VDS_E_DUPLICATE_DISK" => ITF::VDS_E_DUPLICATE_DISK,
            "VDS_E_LAST_VALID_DISK" => ITF::VDS_E_LAST_VALID_DISK,
            "VDS_E_INVALID_SECTOR_SIZE" => ITF::VDS_E_INVALID_SECTOR_SIZE,
            "VDS_E_ONE_EXTENT_PER_DISK" => ITF::VDS_E_ONE_EXTENT_PER_DISK,
            "VDS_E_INVALID_BLOCK_SIZE" => ITF::VDS_E_INVALID_BLOCK_SIZE,
            "VDS_E_PLEX_SIZE_INVALID" => ITF::VDS_E_PLEX_SIZE_INVALID,
            "VDS_E_NO_EXTENTS_FOR_PLEX" => ITF::VDS_E_NO_EXTENTS_FOR_PLEX,
            "VDS_E_INVALID_PLEX_TYPE" => ITF::VDS_E_INVALID_PLEX_TYPE,
            "VDS_E_INVALID_PLEX_BLOCK_SIZE" => ITF::VDS_E_INVALID_PLEX_BLOCK_SIZE,
            "VDS_E_NO_HEALTHY_DISKS" => ITF::VDS_E_NO_HEALTHY_DISKS,
            "VDS_E_CONFIG_LIMIT" => ITF::VDS_E_CONFIG_LIMIT,
            "VDS_E_DISK_CONFIGURATION_CORRUPTED" => ITF::VDS_E_DISK_CONFIGURATION_CORRUPTED,
            "VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC" => ITF::VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC,
            "VDS_E_DISK_CONFIGURATION_UPDATE_FAILED" => ITF::VDS_E_DISK_CONFIGURATION_UPDATE_FAILED,
            "VDS_E_DISK_DYNAMIC" => ITF::VDS_E_DISK_DYNAMIC,
            "VDS_E_DRIVER_OBJECT_NOT_FOUND" => ITF::VDS_E_DRIVER_OBJECT_NOT_FOUND,
            "VDS_E_PARTITION_NOT_CYLINDER_ALIGNED" => ITF::VDS_E_PARTITION_NOT_CYLINDER_ALIGNED,
            "VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL" => ITF::VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL,
            "VDS_E_DISK_IO_FAILING" => ITF::VDS_E_DISK_IO_FAILING,
            "VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED" => ITF::VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED,
            "VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED" => ITF::VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED,
            "VDS_E_GPT_ATTRIBUTES_INVALID" => ITF::VDS_E_GPT_ATTRIBUTES_INVALID,
            "VDS_E_MEMBER_IS_HEALTHY" => ITF::VDS_E_MEMBER_IS_HEALTHY,
            "VDS_E_MEMBER_REGENERATING" => ITF::VDS_E_MEMBER_REGENERATING,
            "VDS_E_PACK_NAME_INVALID" => ITF::VDS_E_PACK_NAME_INVALID,
            "VDS_E_PLEX_IS_HEALTHY" => ITF::VDS_E_PLEX_IS_HEALTHY,
            "VDS_E_PLEX_LAST_ACTIVE" => ITF::VDS_E_PLEX_LAST_ACTIVE,
            "VDS_E_PLEX_MISSING" => ITF::VDS_E_PLEX_MISSING,
            "VDS_E_MEMBER_MISSING" => ITF::VDS_E_MEMBER_MISSING,
            "VDS_E_PLEX_REGENERATING" => ITF::VDS_E_PLEX_REGENERATING,
            "VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE" => ITF::VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE,
            "VDS_E_INVALID_VOLUME_LENGTH" => ITF::VDS_E_INVALID_VOLUME_LENGTH,
            "VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE" => ITF::VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE,
            "VDS_E_VOLUME_NOT_RETAINED" => ITF::VDS_E_VOLUME_NOT_RETAINED,
            "VDS_E_VOLUME_RETAINED" => ITF::VDS_E_VOLUME_RETAINED,
            "VDS_E_ALIGN_BEYOND_FIRST_CYLINDER" => ITF::VDS_E_ALIGN_BEYOND_FIRST_CYLINDER,
            "VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE" => ITF::VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE,
            "VDS_E_ALIGN_NOT_ZERO" => ITF::VDS_E_ALIGN_NOT_ZERO,
            "VDS_E_CACHE_CORRUPT" => ITF::VDS_E_CACHE_CORRUPT,
            "VDS_E_CANNOT_CLEAR_VOLUME_FLAG" => ITF::VDS_E_CANNOT_CLEAR_VOLUME_FLAG,
            "VDS_E_DISK_BEING_CLEANED" => ITF::VDS_E_DISK_BEING_CLEANED,
            "VDS_E_DISK_NOT_CONVERTIBLE" => ITF::VDS_E_DISK_NOT_CONVERTIBLE,
            "VDS_E_DISK_REMOVEABLE" => ITF::VDS_E_DISK_REMOVEABLE,
            "VDS_E_DISK_REMOVEABLE_NOT_EMPTY" => ITF::VDS_E_DISK_REMOVEABLE_NOT_EMPTY,
            "VDS_E_DRIVE_LETTER_NOT_FREE" => ITF::VDS_E_DRIVE_LETTER_NOT_FREE,
            "VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED" => ITF::VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED,
            "VDS_E_INVALID_DRIVE_LETTER" => ITF::VDS_E_INVALID_DRIVE_LETTER,
            "VDS_E_INVALID_DRIVE_LETTER_COUNT" => ITF::VDS_E_INVALID_DRIVE_LETTER_COUNT,
            "VDS_E_INVALID_FS_FLAG" => ITF::VDS_E_INVALID_FS_FLAG,
            "VDS_E_INVALID_FS_TYPE" => ITF::VDS_E_INVALID_FS_TYPE,
            "VDS_E_INVALID_OBJECT_TYPE" => ITF::VDS_E_INVALID_OBJECT_TYPE,
            "VDS_E_INVALID_PARTITION_LAYOUT" => ITF::VDS_E_INVALID_PARTITION_LAYOUT,
            "VDS_E_INVALID_PARTITION_STYLE" => ITF::VDS_E_INVALID_PARTITION_STYLE,
            "VDS_E_INVALID_PARTITION_TYPE" => ITF::VDS_E_INVALID_PARTITION_TYPE,
            "VDS_E_INVALID_PROVIDER_CLSID" => ITF::VDS_E_INVALID_PROVIDER_CLSID,
            "VDS_E_INVALID_PROVIDER_ID" => ITF::VDS_E_INVALID_PROVIDER_ID,
            "VDS_E_INVALID_PROVIDER_NAME" => ITF::VDS_E_INVALID_PROVIDER_NAME,
            "VDS_E_INVALID_PROVIDER_TYPE" => ITF::VDS_E_INVALID_PROVIDER_TYPE,
            "VDS_E_INVALID_PROVIDER_VERSION_GUID" => ITF::VDS_E_INVALID_PROVIDER_VERSION_GUID,
            "VDS_E_INVALID_PROVIDER_VERSION_STRING" => ITF::VDS_E_INVALID_PROVIDER_VERSION_STRING,
            "VDS_E_INVALID_QUERY_PROVIDER_FLAG" => ITF::VDS_E_INVALID_QUERY_PROVIDER_FLAG,
            "VDS_E_INVALID_SERVICE_FLAG" => ITF::VDS_E_INVALID_SERVICE_FLAG,
            "VDS_E_INVALID_VOLUME_FLAG" => ITF::VDS_E_INVALID_VOLUME_FLAG,
            "VDS_E_PARTITION_NOT_OEM" => ITF::VDS_E_PARTITION_NOT_OEM,
            "VDS_E_PARTITION_PROTECTED" => ITF::VDS_E_PARTITION_PROTECTED,
            "VDS_E_PARTITION_STYLE_MISMATCH" => ITF::VDS_E_PARTITION_STYLE_MISMATCH,
            "VDS_E_PROVIDER_INTERNAL_ERROR" => ITF::VDS_E_PROVIDER_INTERNAL_ERROR,
            "VDS_E_SHRINK_SIZE_LESS_THAN_MIN" => ITF::VDS_E_SHRINK_SIZE_LESS_THAN_MIN,
            "VDS_E_SHRINK_SIZE_TOO_BIG" => ITF::VDS_E_SHRINK_SIZE_TOO_BIG,
            "VDS_E_UNRECOVERABLE_PROVIDER_ERROR" => ITF::VDS_E_UNRECOVERABLE_PROVIDER_ERROR,
            "VDS_E_VOLUME_HIDDEN" => ITF::VDS_E_VOLUME_HIDDEN,
            "VDS_E_FLAG_ALREADY_SET" => ITF::VDS_E_FLAG_ALREADY_SET,
            "VDS_E_DISTINCT_VOLUME" => ITF::VDS_E_DISTINCT_VOLUME,
            "VDS_E_VOLUME_NOT_FOUND_IN_PACK" => ITF::VDS_E_VOLUME_NOT_FOUND_IN_PACK,
            "VDS_E_PARTITION_NON_DATA" => ITF::VDS_E_PARTITION_NON_DATA,
            "VDS_E_CRITICAL_PLEX" => ITF::VDS_E_CRITICAL_PLEX,
            "VDS_E_VOLUME_SYNCHRONIZING" => ITF::VDS_E_VOLUME_SYNCHRONIZING,
            "VDS_E_VOLUME_REGENERATING" => ITF::VDS_E_VOLUME_REGENERATING,
            "VDS_E_READONLY" => ITF::VDS_E_READONLY,
            "VDS_E_INVALID_VOLUME_TYPE" => ITF::VDS_E_INVALID_VOLUME_TYPE,
            "VDS_E_BAD_BOOT_DISK" => ITF::VDS_E_BAD_BOOT_DISK,
            "VDS_E_LOG_UPDATE" => ITF::VDS_E_LOG_UPDATE,
            "VDS_E_VOLUME_MIRRORED" => ITF::VDS_E_VOLUME_MIRRORED,
            "VDS_E_VOLUME_SIMPLE_SPANNED" => ITF::VDS_E_VOLUME_SIMPLE_SPANNED,
            "VDS_E_NO_VALID_LOG_COPIES" => ITF::VDS_E_NO_VALID_LOG_COPIES,
            "VDS_E_PLEX_NOT_LOADED_TO_CACHE" => ITF::VDS_E_PLEX_NOT_LOADED_TO_CACHE,
            "VDS_E_PARTITION_MSR" => ITF::VDS_E_PARTITION_MSR,
            "VDS_E_PARTITION_LDM" => ITF::VDS_E_PARTITION_LDM,
            "VDS_E_ALIGN_NOT_A_POWER_OF_TWO" => ITF::VDS_E_ALIGN_NOT_A_POWER_OF_TWO,
            "VDS_E_ALIGN_IS_ZERO" => ITF::VDS_E_ALIGN_IS_ZERO,
            "VDS_E_SHRINK_IN_PROGRESS" => ITF::VDS_E_SHRINK_IN_PROGRESS,
            "VDS_E_CANT_INVALIDATE_FVE" => ITF::VDS_E_CANT_INVALIDATE_FVE,
            "VDS_E_FS_NOT_DETERMINED" => ITF::VDS_E_FS_NOT_DETERMINED,
            "VDS_E_DISK_NOT_OFFLINE" => ITF::VDS_E_DISK_NOT_OFFLINE,
            "VDS_E_FAILED_TO_ONLINE_DISK" => ITF::VDS_E_FAILED_TO_ONLINE_DISK,
            "VDS_E_FAILED_TO_OFFLINE_DISK" => ITF::VDS_E_FAILED_TO_OFFLINE_DISK,
            "VDS_E_BAD_REVISION_NUMBER" => ITF::VDS_E_BAD_REVISION_NUMBER,
            "VDS_E_SHRINK_USER_CANCELLED" => ITF::VDS_E_SHRINK_USER_CANCELLED,
            "VDS_E_SHRINK_DIRTY_VOLUME" => ITF::VDS_E_SHRINK_DIRTY_VOLUME,
            "NOTESPH_E_UNEXPECTED_STATE" => ITF::NOTESPH_E_UNEXPECTED_STATE,
            "NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE" => ITF::NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE,
            "NOTESPH_E_ITEM_NOT_FOUND" => ITF::NOTESPH_E_ITEM_NOT_FOUND,
            "NOTESPH_E_SERVER_CONFIG" => ITF::NOTESPH_E_SERVER_CONFIG,
            "NOTESPH_E_ATTACHMENTS" => ITF::NOTESPH_E_ATTACHMENTS,
            "NOTESPH_E_NO_NTID" => ITF::NOTESPH_E_NO_NTID,
            "NOTESPH_E_DB_ACCESS_DENIED" => ITF::NOTESPH_E_DB_ACCESS_DENIED,
            "NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR" => ITF::NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR,
            "NOTESPH_E_FAIL" => ITF::NOTESPH_E_FAIL,
            "STS_ABORTXMLPARSE" => ITF::STS_ABORTXMLPARSE,
            "STS_WS_ERROR" => ITF::STS_WS_ERROR,
            "SPS_WS_ERROR" => ITF::SPS_WS_ERROR,
            "EXSTOREPH_E_UNEXPECTED" => ITF::EXSTOREPH_E_UNEXPECTED,
            "VDS_E_NAME_NOT_UNIQUE" => ITF::VDS_E_NAME_NOT_UNIQUE,
            "VDS_E_ADDRESSES_INCOMPLETELY_SET" => ITF::VDS_E_ADDRESSES_INCOMPLETELY_SET,
            "VDS_E_SECURITY_INCOMPLETELY_SET" => ITF::VDS_E_SECURITY_INCOMPLETELY_SET,
            "VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED" => ITF::VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED,
            "VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED" => ITF::VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED,
            "VDS_E_ISCSI_LOGIN_FAILED" => ITF::VDS_E_ISCSI_LOGIN_FAILED,
            "VDS_E_ISCSI_LOGOUT_FAILED" => ITF::VDS_E_ISCSI_LOGOUT_FAILED,
            "VDS_E_ISCSI_SESSION_NOT_FOUND" => ITF::VDS_E_ISCSI_SESSION_NOT_FOUND,
            "VDS_E_ASSOCIATED_LUNS_EXIST" => ITF::VDS_E_ASSOCIATED_LUNS_EXIST,
            "VDS_E_ASSOCIATED_PORTALS_EXIST" => ITF::VDS_E_ASSOCIATED_PORTALS_EXIST,
            "VDS_E_NO_DISCOVERY_DOMAIN" => ITF::VDS_E_NO_DISCOVERY_DOMAIN,
            "VDS_E_MULTIPLE_DISCOVERY_DOMAINS" => ITF::VDS_E_MULTIPLE_DISCOVERY_DOMAINS,
            "VDS_E_NO_DISK_PATHNAME" => ITF::VDS_E_NO_DISK_PATHNAME,
            "VDS_E_ISCSI_LOGOUT_INCOMPLETE" => ITF::VDS_E_ISCSI_LOGOUT_INCOMPLETE,
            "VDS_E_NO_VOLUME_PATHNAME" => ITF::VDS_E_NO_VOLUME_PATHNAME,
            "VDS_E_PROVIDER_CACHE_OUTOFSYNC" => ITF::VDS_E_PROVIDER_CACHE_OUTOFSYNC,
            "VDS_E_NO_IMPORT_TARGET" => ITF::VDS_E_NO_IMPORT_TARGET,
            "CERT_E_NOT_FOUND_OR_NO_PERMISSSION" => ITF::CERT_E_NOT_FOUND_OR_NO_PERMISSSION,
            "VDS_E_UNABLE_TO_FIND_BOOT_DISK" => ITF::VDS_E_UNABLE_TO_FIND_BOOT_DISK,
            "VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO" => ITF::VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO,
            "VDS_E_GET_SAN_POLICY" => ITF::VDS_E_GET_SAN_POLICY,
            "VDS_E_SET_SAN_POLICY" => ITF::VDS_E_SET_SAN_POLICY,
            "VDS_E_BOOT_DISK" => ITF::VDS_E_BOOT_DISK,
            "VDS_E_DISK_IS_OFFLINE" => ITF::VDS_E_DISK_IS_OFFLINE,
            "VDS_E_DISK_IS_READ_ONLY" => ITF::VDS_E_DISK_IS_READ_ONLY,
            "VDS_E_PAGEFILE_DISK" => ITF::VDS_E_PAGEFILE_DISK,
            "VDS_E_HIBERNATION_FILE_DISK" => ITF::VDS_E_HIBERNATION_FILE_DISK,
            "VDS_E_CRASHDUMP_DISK" => ITF::VDS_E_CRASHDUMP_DISK,
            "VDS_E_UNABLE_TO_FIND_SYSTEM_DISK" => ITF::VDS_E_UNABLE_TO_FIND_SYSTEM_DISK,
            "VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO" => ITF::VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO,
            "VDS_E_SYSTEM_DISK" => ITF::VDS_E_SYSTEM_DISK,
            "VDS_E_VOLUME_SHRINK_FVE_LOCKED" => ITF::VDS_E_VOLUME_SHRINK_FVE_LOCKED,
            "VDS_E_VOLUME_SHRINK_FVE_CORRUPT" => ITF::VDS_E_VOLUME_SHRINK_FVE_CORRUPT,
            "VDS_E_VOLUME_SHRINK_FVE_RECOVERY" => ITF::VDS_E_VOLUME_SHRINK_FVE_RECOVERY,
            "VDS_E_VOLUME_SHRINK_FVE" => ITF::VDS_E_VOLUME_SHRINK_FVE,
            "VDS_E_SHRINK_OVER_DATA" => ITF::VDS_E_SHRINK_OVER_DATA,
            "VDS_E_INVALID_SHRINK_SIZE" => ITF::VDS_E_INVALID_SHRINK_SIZE,
            "VDS_E_LUN_DISK_MISSING" => ITF::VDS_E_LUN_DISK_MISSING,
            "VDS_E_LUN_DISK_FAILED" => ITF::VDS_E_LUN_DISK_FAILED,
            "VDS_E_LUN_DISK_NOT_READY" => ITF::VDS_E_LUN_DISK_NOT_READY,
            "VDS_E_LUN_DISK_NO_MEDIA" => ITF::VDS_E_LUN_DISK_NO_MEDIA,
            "VDS_E_LUN_NOT_READY" => ITF::VDS_E_LUN_NOT_READY,
            "VDS_E_LUN_OFFLINE" => ITF::VDS_E_LUN_OFFLINE,
            "VDS_E_LUN_FAILED" => ITF::VDS_E_LUN_FAILED,
            "VDS_E_VOLUME_EXTEND_FVE_LOCKED" => ITF::VDS_E_VOLUME_EXTEND_FVE_LOCKED,
            "VDS_E_VOLUME_EXTEND_FVE_CORRUPT" => ITF::VDS_E_VOLUME_EXTEND_FVE_CORRUPT,
            "VDS_E_VOLUME_EXTEND_FVE_RECOVERY" => ITF::VDS_E_VOLUME_EXTEND_FVE_RECOVERY,
            "VDS_E_VOLUME_EXTEND_FVE" => ITF::VDS_E_VOLUME_EXTEND_FVE,
            "VDS_E_SECTOR_SIZE_ERROR" => ITF::VDS_E_SECTOR_SIZE_ERROR,
            "VDS_E_INITIATOR_ADAPTER_NOT_FOUND" => ITF::VDS_E_INITIATOR_ADAPTER_NOT_FOUND,
            "VDS_E_TARGET_PORTAL_NOT_FOUND" => ITF::VDS_E_TARGET_PORTAL_NOT_FOUND,
            "VDS_E_INVALID_PORT_PATH" => ITF::VDS_E_INVALID_PORT_PATH,
            "VDS_E_INVALID_ISCSI_TARGET_NAME" => ITF::VDS_E_INVALID_ISCSI_TARGET_NAME,
            "VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS" => ITF::VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS,
            "VDS_E_ISCSI_GET_IKE_INFO" => ITF::VDS_E_ISCSI_GET_IKE_INFO,
            "VDS_E_ISCSI_SET_IKE_INFO" => ITF::VDS_E_ISCSI_SET_IKE_INFO,
            "VDS_E_SUBSYSTEM_ID_IS_NULL" => ITF::VDS_E_SUBSYSTEM_ID_IS_NULL,
            "VDS_E_ISCSI_INITIATOR_NODE_NAME" => ITF::VDS_E_ISCSI_INITIATOR_NODE_NAME,
            "VDS_E_ISCSI_GROUP_PRESHARE_KEY" => ITF::VDS_E_ISCSI_GROUP_PRESHARE_KEY,
            "VDS_E_ISCSI_CHAP_SECRET" => ITF::VDS_E_ISCSI_CHAP_SECRET,
            "VDS_E_INVALID_IP_ADDRESS" => ITF::VDS_E_INVALID_IP_ADDRESS,
            "VDS_E_REBOOT_REQUIRED" => ITF::VDS_E_REBOOT_REQUIRED,
            "VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED" => ITF::VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED,
            "VDS_E_BOOT_PAGEFILE_DRIVE_LETTER" => ITF::VDS_E_BOOT_PAGEFILE_DRIVE_LETTER,
            "VDS_E_DELETE_WITH_CRITICAL" => ITF::VDS_E_DELETE_WITH_CRITICAL,
            "VDS_E_CLEAN_WITH_DATA" => ITF::VDS_E_CLEAN_WITH_DATA,
            "VDS_E_CLEAN_WITH_OEM" => ITF::VDS_E_CLEAN_WITH_OEM,
            "VDS_E_CLEAN_WITH_CRITICAL" => ITF::VDS_E_CLEAN_WITH_CRITICAL,
            "VDS_E_FORMAT_CRITICAL" => ITF::VDS_E_FORMAT_CRITICAL,
            "VDS_E_NTFS_FORMAT_NOT_SUPPORTED" => ITF::VDS_E_NTFS_FORMAT_NOT_SUPPORTED,
            "VDS_E_FAT32_FORMAT_NOT_SUPPORTED" => ITF::VDS_E_FAT32_FORMAT_NOT_SUPPORTED,
            "VDS_E_FAT_FORMAT_NOT_SUPPORTED" => ITF::VDS_E_FAT_FORMAT_NOT_SUPPORTED,
            "VDS_E_FORMAT_NOT_SUPPORTED" => ITF::VDS_E_FORMAT_NOT_SUPPORTED,
            "VDS_E_COMPRESSION_NOT_SUPPORTED" => ITF::VDS_E_COMPRESSION_NOT_SUPPORTED,
            "VDS_E_VDISK_NOT_OPEN" => ITF::VDS_E_VDISK_NOT_OPEN,
            "VDS_E_VDISK_INVALID_OP_STATE" => ITF::VDS_E_VDISK_INVALID_OP_STATE,
            "VDS_E_INVALID_PATH" => ITF::VDS_E_INVALID_PATH,
            "VDS_E_INVALID_ISCSI_PATH" => ITF::VDS_E_INVALID_ISCSI_PATH,
            "VDS_E_SHRINK_LUN_NOT_UNMASKED" => ITF::VDS_E_SHRINK_LUN_NOT_UNMASKED,
            "VDS_E_LUN_DISK_READ_ONLY" => ITF::VDS_E_LUN_DISK_READ_ONLY,
            "VDS_E_LUN_UPDATE_DISK" => ITF::VDS_E_LUN_UPDATE_DISK,
            "VDS_E_LUN_DYNAMIC" => ITF::VDS_E_LUN_DYNAMIC,
            "VDS_E_LUN_DYNAMIC_OFFLINE" => ITF::VDS_E_LUN_DYNAMIC_OFFLINE,
            "VDS_E_LUN_SHRINK_GPT_HEADER" => ITF::VDS_E_LUN_SHRINK_GPT_HEADER,
            "VDS_E_MIRROR_NOT_SUPPORTED" => ITF::VDS_E_MIRROR_NOT_SUPPORTED,
            "VDS_E_RAID5_NOT_SUPPORTED" => ITF::VDS_E_RAID5_NOT_SUPPORTED,
            "VDS_E_DISK_NOT_CONVERTIBLE_SIZE" => ITF::VDS_E_DISK_NOT_CONVERTIBLE_SIZE,
            "VDS_E_OFFLINE_NOT_SUPPORTED" => ITF::VDS_E_OFFLINE_NOT_SUPPORTED,
            "VDS_E_VDISK_PATHNAME_INVALID" => ITF::VDS_E_VDISK_PATHNAME_INVALID,
            "VDS_E_EXTEND_TOO_MANY_CLUSTERS" => ITF::VDS_E_EXTEND_TOO_MANY_CLUSTERS,
            "VDS_E_EXTEND_UNKNOWN_FILESYSTEM" => ITF::VDS_E_EXTEND_UNKNOWN_FILESYSTEM,
            "VDS_E_SHRINK_UNKNOWN_FILESYSTEM" => ITF::VDS_E_SHRINK_UNKNOWN_FILESYSTEM,
            "VDS_E_VD_DISK_NOT_OPEN" => ITF::VDS_E_VD_DISK_NOT_OPEN,
            "VDS_E_VD_DISK_IS_EXPANDING" => ITF::VDS_E_VD_DISK_IS_EXPANDING,
            "VDS_E_VD_DISK_IS_COMPACTING" => ITF::VDS_E_VD_DISK_IS_COMPACTING,
            "VDS_E_VD_DISK_IS_MERGING" => ITF::VDS_E_VD_DISK_IS_MERGING,
            "VDS_E_VD_IS_ATTACHED" => ITF::VDS_E_VD_IS_ATTACHED,
            "VDS_E_VD_DISK_ALREADY_OPEN" => ITF::VDS_E_VD_DISK_ALREADY_OPEN,
            "VDS_E_VD_DISK_ALREADY_EXPANDING" => ITF::VDS_E_VD_DISK_ALREADY_EXPANDING,
            "VDS_E_VD_ALREADY_COMPACTING" => ITF::VDS_E_VD_ALREADY_COMPACTING,
            "VDS_E_VD_ALREADY_MERGING" => ITF::VDS_E_VD_ALREADY_MERGING,
            "VDS_E_VD_ALREADY_ATTACHED" => ITF::VDS_E_VD_ALREADY_ATTACHED,
            "VDS_E_VD_ALREADY_DETACHED" => ITF::VDS_E_VD_ALREADY_DETACHED,
            "VDS_E_VD_NOT_ATTACHED_READONLY" => ITF::VDS_E_VD_NOT_ATTACHED_READONLY,
            "VDS_E_VD_IS_BEING_ATTACHED" => ITF::VDS_E_VD_IS_BEING_ATTACHED,
            "VDS_E_VD_IS_BEING_DETACHED" => ITF::VDS_E_VD_IS_BEING_DETACHED,
            "VDS_E_NO_POOL" => ITF::VDS_E_NO_POOL,
            "VDS_E_NO_POOL_CREATED" => ITF::VDS_E_NO_POOL_CREATED,
            "VDS_E_NO_MAINTENANCE_MODE" => ITF::VDS_E_NO_MAINTENANCE_MODE,
            "VDS_E_BLOCK_CLUSTERED" => ITF::VDS_E_BLOCK_CLUSTERED,
            "VDS_E_DISK_HAS_BANDS" => ITF::VDS_E_DISK_HAS_BANDS,
            "VDS_E_INVALID_STATE" => ITF::VDS_E_INVALID_STATE,
            "VDS_E_REFS_FORMAT_NOT_SUPPORTED" => ITF::VDS_E_REFS_FORMAT_NOT_SUPPORTED,
            "VDS_E_DELETE_WITH_BOOTBACKING" => ITF::VDS_E_DELETE_WITH_BOOTBACKING,
            "VDS_E_FORMAT_WITH_BOOTBACKING" => ITF::VDS_E_FORMAT_WITH_BOOTBACKING,
            "VDS_E_CLEAN_WITH_BOOTBACKING" => ITF::VDS_E_CLEAN_WITH_BOOTBACKING,
            "SRCH_SCHEMA_CACHE_E_UNEXPECTED" => ITF::SRCH_SCHEMA_CACHE_E_UNEXPECTED,
            "CONTENT_SOURCE_E_PROPERTY_MAPPING_READ" => ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_READ,
            "CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER" => ITF::CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER,
            "CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE" => ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE,
            "CONTENT_SOURCE_E_CONTENT_CLASS_READ" => ITF::CONTENT_SOURCE_E_CONTENT_CLASS_READ,
            "CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION" => ITF::CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION,
            "CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR" => ITF::CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR,
            "CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE" => ITF::CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE,
            "CONTENT_SOURCE_E_OUT_OF_RANGE" => ITF::CONTENT_SOURCE_E_OUT_OF_RANGE,
            "CONTENT_SOURCE_E_NULL_URI" => ITF::CONTENT_SOURCE_E_NULL_URI,
            "REXSPH_E_INVALID_CALL" => ITF::REXSPH_E_INVALID_CALL,
            "REXSPH_E_REDIRECT_ON_SECURITY_UPDATE" => ITF::REXSPH_E_REDIRECT_ON_SECURITY_UPDATE,
            "REXSPH_E_MULTIPLE_REDIRECT" => ITF::REXSPH_E_MULTIPLE_REDIRECT,
            "REXSPH_E_NO_PROPERTY_ON_ROW" => ITF::REXSPH_E_NO_PROPERTY_ON_ROW,
            "REXSPH_E_TYPE_MISMATCH_ON_READ" => ITF::REXSPH_E_TYPE_MISMATCH_ON_READ,
            "REXSPH_E_UNEXPECTED_DATA_STATUS" => ITF::REXSPH_E_UNEXPECTED_DATA_STATUS,
            "REXSPH_E_UNKNOWN_DATA_TYPE" => ITF::REXSPH_E_UNKNOWN_DATA_TYPE,
            "REXSPH_E_UNEXPECTED_FILTER_STATE" => ITF::REXSPH_E_UNEXPECTED_FILTER_STATE,
            "REXSPH_E_DUPLICATE_PROPERTY" => ITF::REXSPH_E_DUPLICATE_PROPERTY,
            "FTE_E_SECRET_NOT_FOUND" => ITF::FTE_E_SECRET_NOT_FOUND,
            "FTE_E_PIPE_NOT_CONNECTED" => ITF::FTE_E_PIPE_NOT_CONNECTED,
            "FTE_E_ADMIN_BLOB_CORRUPT" => ITF::FTE_E_ADMIN_BLOB_CORRUPT,
            "FTE_E_FILTER_SINGLE_THREADED" => ITF::FTE_E_FILTER_SINGLE_THREADED,
            "FTE_E_ERROR_WRITING_REGISTRY" => ITF::FTE_E_ERROR_WRITING_REGISTRY,
            "FTE_E_PROJECT_SHUTDOWN" => ITF::FTE_E_PROJECT_SHUTDOWN,
            "FTE_E_PROJECT_NOT_INITALIZED" => ITF::FTE_E_PROJECT_NOT_INITALIZED,
            "FTE_E_PIPE_DATA_CORRUPTED" => ITF::FTE_E_PIPE_DATA_CORRUPTED,
            "FTE_E_URB_TOO_BIG" => ITF::FTE_E_URB_TOO_BIG,
            "FTE_E_INVALID_DOCID" => ITF::FTE_E_INVALID_DOCID,
            "FTE_E_PAUSE_EXTERNAL" => ITF::FTE_E_PAUSE_EXTERNAL,
            "FTE_E_REJECTED_DUE_TO_PROJECT_STATUS" => ITF::FTE_E_REJECTED_DUE_TO_PROJECT_STATUS,
            "FTE_E_FD_DID_NOT_CONNECT" => ITF::FTE_E_FD_DID_NOT_CONNECT,
            "FTE_E_PROGID_REQUIRED" => ITF::FTE_E_PROGID_REQUIRED,
            "FTE_E_STATIC_THREAD_INVALID_ARGUMENTS" => ITF::FTE_E_STATIC_THREAD_INVALID_ARGUMENTS,
            "FTE_E_CATALOG_ALREADY_EXISTS" => ITF::FTE_E_CATALOG_ALREADY_EXISTS,
            "FTE_E_PATH_TOO_LONG" => ITF::FTE_E_PATH_TOO_LONG,
            "FTE_INVALID_ADMIN_CLIENT" => ITF::FTE_INVALID_ADMIN_CLIENT,
            "FTE_E_COM_SIGNATURE_VALIDATION" => ITF::FTE_E_COM_SIGNATURE_VALIDATION,
            "FTE_E_AFFINITY_MASK" => ITF::FTE_E_AFFINITY_MASK,
            "FTE_E_FD_OWNERSHIP_OBSOLETE" => ITF::FTE_E_FD_OWNERSHIP_OBSOLETE,
            "FTE_E_EXCEEDED_MAX_PLUGINS" => ITF::FTE_E_EXCEEDED_MAX_PLUGINS,
            "FTE_E_DUPLICATE_OBJECT" => ITF::FTE_E_DUPLICATE_OBJECT,
            "FTE_E_REDUNDANT_TRAN_FAILURE" => ITF::FTE_E_REDUNDANT_TRAN_FAILURE,
            "FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST" => ITF::FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST,
            "FTE_E_FD_SHUTDOWN" => ITF::FTE_E_FD_SHUTDOWN,
            "FTE_E_CATALOG_DOES_NOT_EXIST" => ITF::FTE_E_CATALOG_DOES_NOT_EXIST,
            "FTE_E_NO_PLUGINS" => ITF::FTE_E_NO_PLUGINS,
            "FTE_E_BATCH_ABORTED" => ITF::FTE_E_BATCH_ABORTED,
            "FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE" => ITF::FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE,
            "FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS" => ITF::FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS,
            "FTE_E_FD_TIMEOUT" => ITF::FTE_E_FD_TIMEOUT,
            "FTE_E_RESOURCE_SHUTDOWN" => ITF::FTE_E_RESOURCE_SHUTDOWN,
            "FTE_E_INVALID_PROPERTY" => ITF::FTE_E_INVALID_PROPERTY,
            "FTE_E_NO_MORE_PROPERTIES" => ITF::FTE_E_NO_MORE_PROPERTIES,
            "FTE_E_UNKNOWN_PLUGIN" => ITF::FTE_E_UNKNOWN_PLUGIN,
            "FTE_E_LIBRARY_NOT_LOADED" => ITF::FTE_E_LIBRARY_NOT_LOADED,
            "FTE_E_PERFMON_FULL" => ITF::FTE_E_PERFMON_FULL,
            "FTE_E_FAILED_TO_CREATE_ACCESSOR" => ITF::FTE_E_FAILED_TO_CREATE_ACCESSOR,
            "FTE_E_INVALID_TYPE" => ITF::FTE_E_INVALID_TYPE,
            "FTE_E_OUT_OF_RANGE" => ITF::FTE_E_OUT_OF_RANGE,
            "FTE_E_CORRUPT_PROPERTY_STORE" => ITF::FTE_E_CORRUPT_PROPERTY_STORE,
            "FTE_E_PROPERTY_STORE_WORKID_NOTVALID" => ITF::FTE_E_PROPERTY_STORE_WORKID_NOTVALID,
            "FTE_E_CORRUPT_GATHERER_HASH_MAP" => ITF::FTE_E_CORRUPT_GATHERER_HASH_MAP,
            "FTE_E_KEY_NOT_CACHED" => ITF::FTE_E_KEY_NOT_CACHED,
            "FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN" => ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN,
            "FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED" => ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED,
            "FTE_E_STACK_CORRUPTED" => ITF::FTE_E_STACK_CORRUPTED,
            "FTE_E_INVALID_PROG_ID" => ITF::FTE_E_INVALID_PROG_ID,
            "FTE_E_SERIAL_STREAM_CORRUPT" => ITF::FTE_E_SERIAL_STREAM_CORRUPT,
            "FTE_E_READONLY_CATALOG" => ITF::FTE_E_READONLY_CATALOG,
            "FTE_E_PERF_NOT_LOADED" => ITF::FTE_E_PERF_NOT_LOADED,
            "FTE_E_RETRY_HUGE_DOC" => ITF::FTE_E_RETRY_HUGE_DOC,
            "FTE_E_UNKNOWN_FD_TYPE" => ITF::FTE_E_UNKNOWN_FD_TYPE,
            "FTE_E_DOC_TOO_HUGE" => ITF::FTE_E_DOC_TOO_HUGE,
            "FTE_E_DATATYPE_MISALIGNMENT" => ITF::FTE_E_DATATYPE_MISALIGNMENT,
            "FTE_E_ALREADY_INITIALIZED" => ITF::FTE_E_ALREADY_INITIALIZED,
            "FTE_E_FD_USED_TOO_MUCH_MEMORY" => ITF::FTE_E_FD_USED_TOO_MUCH_MEMORY,
            "FTE_E_UNEXPECTED_EXIT" => ITF::FTE_E_UNEXPECTED_EXIT,
            "FTE_E_HIGH_MEMORY_PRESSURE" => ITF::FTE_E_HIGH_MEMORY_PRESSURE,
            "FTE_E_INVALID_ISOLATE_ERROR_BATCH" => ITF::FTE_E_INVALID_ISOLATE_ERROR_BATCH,
            "FTE_E_RETRY_SINGLE_DOC_PER_BATCH" => ITF::FTE_E_RETRY_SINGLE_DOC_PER_BATCH,
            "FTE_E_INVALID_PROJECT_ID" => ITF::FTE_E_INVALID_PROJECT_ID,
            "FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS" => ITF::FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS,
            "FTE_E_INVALID_CODEPAGE" => ITF::FTE_E_INVALID_CODEPAGE,
            "FTE_E_FD_IDLE" => ITF::FTE_E_FD_IDLE,
            "FTE_E_FD_UNRESPONSIVE" => ITF::FTE_E_FD_UNRESPONSIVE,
            "WCN_E_PEER_NOT_FOUND" => ITF::WCN_E_PEER_NOT_FOUND,
            "WCN_E_AUTHENTICATION_FAILED" => ITF::WCN_E_AUTHENTICATION_FAILED,
            "WCN_E_CONNECTION_REJECTED" => ITF::WCN_E_CONNECTION_REJECTED,
            "WCN_E_SESSION_TIMEDOUT" => ITF::WCN_E_SESSION_TIMEDOUT,
            "WCN_E_PROTOCOL_ERROR" => ITF::WCN_E_PROTOCOL_ERROR,
            "CDO_E_ARGUMENT1" => ITF::CDO_E_ARGUMENT1,
            "PEOPLE_IMPORT_E_DBCONNFAIL" => ITF::PEOPLE_IMPORT_E_DBCONNFAIL,
            "CDO_E_ARGUMENT2" => ITF::CDO_E_ARGUMENT2,
            "PEOPLE_IMPORT_NODSDEFINED" => ITF::PEOPLE_IMPORT_NODSDEFINED,
            "CDO_E_ARGUMENT3" => ITF::CDO_E_ARGUMENT3,
            "PEOPLE_IMPORT_E_FAILTOGETDSDEF" => ITF::PEOPLE_IMPORT_E_FAILTOGETDSDEF,
            "CDO_E_ARGUMENT4" => ITF::CDO_E_ARGUMENT4,
            "PEOPLE_IMPORT_NOMAPPINGDEFINED" => ITF::PEOPLE_IMPORT_NOMAPPINGDEFINED,
            "CDO_E_ARGUMENT5" => ITF::CDO_E_ARGUMENT5,
            "PEOPLE_IMPORT_E_FAILTOGETDSMAPPING" => ITF::PEOPLE_IMPORT_E_FAILTOGETDSMAPPING,
            "PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED" => ITF::PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED,
            "PEOPLE_IMPORT_E_NOCASTINGSUPPORTED" => ITF::PEOPLE_IMPORT_E_NOCASTINGSUPPORTED,
            "PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE" => ITF::PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE,
            "PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE" => ITF::PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE,
            "PEOPLE_IMPORT_E_LDAPPATH_TOOLONG" => ITF::PEOPLE_IMPORT_E_LDAPPATH_TOOLONG,
            "PEOPLE_IMPORT_E_CANONICALURL_TOOLONG" => ITF::PEOPLE_IMPORT_E_CANONICALURL_TOOLONG,
            "PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED" => ITF::PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED,
            "PEOPLE_IMPORT_E_DC_NOT_AVAILABLE" => ITF::PEOPLE_IMPORT_E_DC_NOT_AVAILABLE,
            "PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED" => ITF::PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED,
            "PEOPLE_IMPORT_E_FAILTOGETLCID" => ITF::PEOPLE_IMPORT_E_FAILTOGETLCID,
            "PEOPLE_IMPORT_E_DOMAIN_REMOVED" => ITF::PEOPLE_IMPORT_E_DOMAIN_REMOVED,
            "PEOPLE_IMPORT_E_ENUM_ACCESSDENIED" => ITF::PEOPLE_IMPORT_E_ENUM_ACCESSDENIED,
            "PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED" => ITF::PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED,
            "SPERR_UNINITIALIZED" => ITF::SPERR_UNINITIALIZED,
            "SPERR_ALREADY_INITIALIZED" => ITF::SPERR_ALREADY_INITIALIZED,
            "SPERR_UNSUPPORTED_FORMAT" => ITF::SPERR_UNSUPPORTED_FORMAT,
            "SPERR_INVALID_FLAGS" => ITF::SPERR_INVALID_FLAGS,
            "SPERR_DEVICE_BUSY" => ITF::SPERR_DEVICE_BUSY,
            "SPERR_DEVICE_NOT_SUPPORTED" => ITF::SPERR_DEVICE_NOT_SUPPORTED,
            "SPERR_DEVICE_NOT_ENABLED" => ITF::SPERR_DEVICE_NOT_ENABLED,
            "SPERR_NO_DRIVER" => ITF::SPERR_NO_DRIVER,
            "SPERR_FILEMUSTBEUNICODE" => ITF::SPERR_FILEMUSTBEUNICODE,
            "SPERR_INVALID_PHRASE_ID" => ITF::SPERR_INVALID_PHRASE_ID,
            "SPERR_BUFFER_TOO_SMALL" => ITF::SPERR_BUFFER_TOO_SMALL,
            "SPERR_FORMAT_NOT_SPECIFIED" => ITF::SPERR_FORMAT_NOT_SPECIFIED,
            "SPERR_AUDIO_STOPPED" => ITF::SPERR_AUDIO_STOPPED,
            "SPERR_RULE_NOT_FOUND" => ITF::SPERR_RULE_NOT_FOUND,
            "SPERR_TTS_ENGINE_EXCEPTION" => ITF::SPERR_TTS_ENGINE_EXCEPTION,
            "SPERR_TTS_NLP_EXCEPTION" => ITF::SPERR_TTS_NLP_EXCEPTION,
            "SPERR_ENGINE_BUSY" => ITF::SPERR_ENGINE_BUSY,
            "SPERR_CANT_CREATE" => ITF::SPERR_CANT_CREATE,
            "SPERR_NOT_IN_LEX" => ITF::SPERR_NOT_IN_LEX,
            "SPERR_LEX_VERY_OUT_OF_SYNC" => ITF::SPERR_LEX_VERY_OUT_OF_SYNC,
            "SPERR_UNDEFINED_FORWARD_RULE_REF" => ITF::SPERR_UNDEFINED_FORWARD_RULE_REF,
            "SPERR_EMPTY_RULE" => ITF::SPERR_EMPTY_RULE,
            "SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR" => ITF::SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR,
            "SPERR_RULE_NOT_DYNAMIC" => ITF::SPERR_RULE_NOT_DYNAMIC,
            "SPERR_DUPLICATE_RULE_NAME" => ITF::SPERR_DUPLICATE_RULE_NAME,
            "SPERR_DUPLICATE_RESOURCE_NAME" => ITF::SPERR_DUPLICATE_RESOURCE_NAME,
            "SPERR_TOO_MANY_GRAMMARS" => ITF::SPERR_TOO_MANY_GRAMMARS,
            "SPERR_CIRCULAR_REFERENCE" => ITF::SPERR_CIRCULAR_REFERENCE,
            "SPERR_INVALID_IMPORT" => ITF::SPERR_INVALID_IMPORT,
            "SPERR_INVALID_WAV_FILE" => ITF::SPERR_INVALID_WAV_FILE,
            "SPERR_ALL_WORDS_OPTIONAL" => ITF::SPERR_ALL_WORDS_OPTIONAL,
            "SPERR_INSTANCE_CHANGE_INVALID" => ITF::SPERR_INSTANCE_CHANGE_INVALID,
            "SPERR_RULE_NAME_ID_CONFLICT" => ITF::SPERR_RULE_NAME_ID_CONFLICT,
            "SPERR_NO_RULES" => ITF::SPERR_NO_RULES,
            "SPERR_CIRCULAR_RULE_REF" => ITF::SPERR_CIRCULAR_RULE_REF,
            "SPERR_NO_PARSE_FOUND" => ITF::SPERR_NO_PARSE_FOUND,
            "SPERR_REMOTE_CALL_TIMED_OUT" => ITF::SPERR_REMOTE_CALL_TIMED_OUT,
            "SPERR_AUDIO_BUFFER_OVERFLOW" => ITF::SPERR_AUDIO_BUFFER_OVERFLOW,
            "SPERR_NO_AUDIO_DATA" => ITF::SPERR_NO_AUDIO_DATA,
            "SPERR_DEAD_ALTERNATE" => ITF::SPERR_DEAD_ALTERNATE,
            "SPERR_HIGH_LOW_CONFIDENCE" => ITF::SPERR_HIGH_LOW_CONFIDENCE,
            "SPERR_INVALID_FORMAT_STRING" => ITF::SPERR_INVALID_FORMAT_STRING,
            "SPERR_APPLEX_READ_ONLY" => ITF::SPERR_APPLEX_READ_ONLY,
            "SPERR_NO_TERMINATING_RULE_PATH" => ITF::SPERR_NO_TERMINATING_RULE_PATH,
            "SPERR_STREAM_CLOSED" => ITF::SPERR_STREAM_CLOSED,
            "SPERR_NO_MORE_ITEMS" => ITF::SPERR_NO_MORE_ITEMS,
            "SPERR_NOT_FOUND" => ITF::SPERR_NOT_FOUND,
            "SPERR_INVALID_AUDIO_STATE" => ITF::SPERR_INVALID_AUDIO_STATE,
            "SPERR_GENERIC_MMSYS_ERROR" => ITF::SPERR_GENERIC_MMSYS_ERROR,
            "SPERR_MARSHALER_EXCEPTION" => ITF::SPERR_MARSHALER_EXCEPTION,
            "SPERR_NOT_DYNAMIC_GRAMMAR" => ITF::SPERR_NOT_DYNAMIC_GRAMMAR,
            "SPERR_AMBIGUOUS_PROPERTY" => ITF::SPERR_AMBIGUOUS_PROPERTY,
            "SPERR_INVALID_REGISTRY_KEY" => ITF::SPERR_INVALID_REGISTRY_KEY,
            "SPERR_INVALID_TOKEN_ID" => ITF::SPERR_INVALID_TOKEN_ID,
            "SPERR_XML_BAD_SYNTAX" => ITF::SPERR_XML_BAD_SYNTAX,
            "SPERR_XML_RESOURCE_NOT_FOUND" => ITF::SPERR_XML_RESOURCE_NOT_FOUND,
            "SPERR_TOKEN_IN_USE" => ITF::SPERR_TOKEN_IN_USE,
            "SPERR_TOKEN_DELETED" => ITF::SPERR_TOKEN_DELETED,
            "SPERR_MULTI_LINGUAL_NOT_SUPPORTED" => ITF::SPERR_MULTI_LINGUAL_NOT_SUPPORTED,
            "SPERR_EXPORT_DYNAMIC_RULE" => ITF::SPERR_EXPORT_DYNAMIC_RULE,
            "SPERR_STGF_ERROR" => ITF::SPERR_STGF_ERROR,
            "SPERR_WORDFORMAT_ERROR" => ITF::SPERR_WORDFORMAT_ERROR,
            "SPERR_STREAM_NOT_ACTIVE" => ITF::SPERR_STREAM_NOT_ACTIVE,
            "SPERR_ENGINE_RESPONSE_INVALID" => ITF::SPERR_ENGINE_RESPONSE_INVALID,
            "SPERR_SR_ENGINE_EXCEPTION" => ITF::SPERR_SR_ENGINE_EXCEPTION,
            "SPERR_STREAM_POS_INVALID" => ITF::SPERR_STREAM_POS_INVALID,
            "SPERR_REMOTE_CALL_ON_WRONG_THREAD" => ITF::SPERR_REMOTE_CALL_ON_WRONG_THREAD,
            "SPERR_REMOTE_PROCESS_TERMINATED" => ITF::SPERR_REMOTE_PROCESS_TERMINATED,
            "SPERR_REMOTE_PROCESS_ALREADY_RUNNING" => ITF::SPERR_REMOTE_PROCESS_ALREADY_RUNNING,
            "SPERR_LANGID_MISMATCH" => ITF::SPERR_LANGID_MISMATCH,
            "SPERR_NOT_TOPLEVEL_RULE" => ITF::SPERR_NOT_TOPLEVEL_RULE,
            "SPERR_LEX_REQUIRES_COOKIE" => ITF::SPERR_LEX_REQUIRES_COOKIE,
            "SPERR_UNSUPPORTED_LANG" => ITF::SPERR_UNSUPPORTED_LANG,
            "SPERR_VOICE_PAUSED" => ITF::SPERR_VOICE_PAUSED,
            "SPERR_AUDIO_BUFFER_UNDERFLOW" => ITF::SPERR_AUDIO_BUFFER_UNDERFLOW,
            "SPERR_AUDIO_STOPPED_UNEXPECTEDLY" => ITF::SPERR_AUDIO_STOPPED_UNEXPECTEDLY,
            "SPERR_NO_WORD_PRONUNCIATION" => ITF::SPERR_NO_WORD_PRONUNCIATION,
            "SPERR_ALTERNATES_WOULD_BE_INCONSISTENT" => ITF::SPERR_ALTERNATES_WOULD_BE_INCONSISTENT,
            "SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER" => ITF::SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER,
            "SPERR_TIMEOUT" => ITF::SPERR_TIMEOUT,
            "SPERR_REENTER_SYNCHRONIZE" => ITF::SPERR_REENTER_SYNCHRONIZE,
            "SPERR_STATE_WITH_NO_ARCS" => ITF::SPERR_STATE_WITH_NO_ARCS,
            "SPERR_NOT_ACTIVE_SESSION" => ITF::SPERR_NOT_ACTIVE_SESSION,
            "SPERR_ALREADY_DELETED" => ITF::SPERR_ALREADY_DELETED,
            "SPERR_RECOXML_GENERATION_FAIL" => ITF::SPERR_RECOXML_GENERATION_FAIL,
            "SPERR_SML_GENERATION_FAIL" => ITF::SPERR_SML_GENERATION_FAIL,
            "SPERR_NOT_PROMPT_VOICE" => ITF::SPERR_NOT_PROMPT_VOICE,
            "SPERR_ROOTRULE_ALREADY_DEFINED" => ITF::SPERR_ROOTRULE_ALREADY_DEFINED,
            "SPERR_SCRIPT_DISALLOWED" => ITF::SPERR_SCRIPT_DISALLOWED,
            "SPERR_REMOTE_CALL_TIMED_OUT_START" => ITF::SPERR_REMOTE_CALL_TIMED_OUT_START,
            "SPERR_REMOTE_CALL_TIMED_OUT_CONNECT" => ITF::SPERR_REMOTE_CALL_TIMED_OUT_CONNECT,
            "SPERR_SECMGR_CHANGE_NOT_ALLOWED" => ITF::SPERR_SECMGR_CHANGE_NOT_ALLOWED,
            "SPERR_FAILED_TO_DELETE_FILE" => ITF::SPERR_FAILED_TO_DELETE_FILE,
            "SPERR_SHARED_ENGINE_DISABLED" => ITF::SPERR_SHARED_ENGINE_DISABLED,
            "SPERR_RECOGNIZER_NOT_FOUND" => ITF::SPERR_RECOGNIZER_NOT_FOUND,
            "SPERR_AUDIO_NOT_FOUND" => ITF::SPERR_AUDIO_NOT_FOUND,
            "SPERR_NO_VOWEL" => ITF::SPERR_NO_VOWEL,
            "SPERR_UNSUPPORTED_PHONEME" => ITF::SPERR_UNSUPPORTED_PHONEME,
            "SPERR_WORD_NEEDS_NORMALIZATION" => ITF::SPERR_WORD_NEEDS_NORMALIZATION,
            "SPERR_CANNOT_NORMALIZE" => ITF::SPERR_CANNOT_NORMALIZE,
            "SPERR_TOPIC_NOT_ADAPTABLE" => ITF::SPERR_TOPIC_NOT_ADAPTABLE,
            "SPERR_PHONEME_CONVERSION" => ITF::SPERR_PHONEME_CONVERSION,
            "SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER" => ITF::SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER,
            "SPERR_OVERLOAD" => ITF::SPERR_OVERLOAD,
            "SPERR_LEX_INVALID_DATA" => ITF::SPERR_LEX_INVALID_DATA,
            "SPERR_CFG_INVALID_DATA" => ITF::SPERR_CFG_INVALID_DATA,
            "SPERR_LEX_UNEXPECTED_FORMAT" => ITF::SPERR_LEX_UNEXPECTED_FORMAT,
            "SPERR_STRING_TOO_LONG" => ITF::SPERR_STRING_TOO_LONG,
            "SPERR_STRING_EMPTY" => ITF::SPERR_STRING_EMPTY,
            "SPERR_NON_WORD_TRANSITION" => ITF::SPERR_NON_WORD_TRANSITION,
            "SPERR_SISR_ATTRIBUTES_NOT_ALLOWED" => ITF::SPERR_SISR_ATTRIBUTES_NOT_ALLOWED,
            "SPERR_SISR_MIXED_NOT_ALLOWED" => ITF::SPERR_SISR_MIXED_NOT_ALLOWED,
            "SPERR_VOICE_NOT_FOUND" => ITF::SPERR_VOICE_NOT_FOUND,
            "FSRM_E_NOT_FOUND" => ITF::FSRM_E_NOT_FOUND,
            "FSRM_E_INVALID_SCHEDULER_ARGUMENT" => ITF::FSRM_E_INVALID_SCHEDULER_ARGUMENT,
            "FSRM_E_ALREADY_EXISTS" => ITF::FSRM_E_ALREADY_EXISTS,
            "FSRM_E_PATH_NOT_FOUND" => ITF::FSRM_E_PATH_NOT_FOUND,
            "FSRM_E_INVALID_USER" => ITF::FSRM_E_INVALID_USER,
            "FSRM_E_INVALID_PATH" => ITF::FSRM_E_INVALID_PATH,
            "FSRM_E_INVALID_LIMIT" => ITF::FSRM_E_INVALID_LIMIT,
            "FSRM_E_INVALID_NAME" => ITF::FSRM_E_INVALID_NAME,
            "FSRM_E_FAIL_BATCH" => ITF::FSRM_E_FAIL_BATCH,
            "FSRM_E_INVALID_TEXT" => ITF::FSRM_E_INVALID_TEXT,
            "FSRM_E_INVALID_IMPORT_VERSION" => ITF::FSRM_E_INVALID_IMPORT_VERSION,
            "FSRM_E_OUT_OF_RANGE" => ITF::FSRM_E_OUT_OF_RANGE,
            "FSRM_E_REQD_PARAM_MISSING" => ITF::FSRM_E_REQD_PARAM_MISSING,
            "FSRM_E_INVALID_COMBINATION" => ITF::FSRM_E_INVALID_COMBINATION,
            "FSRM_E_DUPLICATE_NAME" => ITF::FSRM_E_DUPLICATE_NAME,
            "FSRM_E_NOT_SUPPORTED" => ITF::FSRM_E_NOT_SUPPORTED,
            "FSRM_E_DRIVER_NOT_READY" => ITF::FSRM_E_DRIVER_NOT_READY,
            "FSRM_E_INSUFFICIENT_DISK" => ITF::FSRM_E_INSUFFICIENT_DISK,
            "FSRM_E_VOLUME_UNSUPPORTED" => ITF::FSRM_E_VOLUME_UNSUPPORTED,
            "FSRM_E_UNEXPECTED" => ITF::FSRM_E_UNEXPECTED,
            "FSRM_E_INSECURE_PATH" => ITF::FSRM_E_INSECURE_PATH,
            "FSRM_E_INVALID_SMTP_SERVER" => ITF::FSRM_E_INVALID_SMTP_SERVER,
            "FSRM_E_EMAIL_NOT_SENT" => ITF::FSRM_E_EMAIL_NOT_SENT,
            "FSRM_E_INVALID_EMAIL_ADDRESS" => ITF::FSRM_E_INVALID_EMAIL_ADDRESS,
            "FSRM_E_FILE_SYSTEM_CORRUPT" => ITF::FSRM_E_FILE_SYSTEM_CORRUPT,
            "FSRM_E_LONG_CMDLINE" => ITF::FSRM_E_LONG_CMDLINE,
            "FSRM_E_INVALID_FILEGROUP_DEFINITION" => ITF::FSRM_E_INVALID_FILEGROUP_DEFINITION,
            "FSRM_E_INVALID_DATASCREEN_DEFINITION" => ITF::FSRM_E_INVALID_DATASCREEN_DEFINITION,
            "FSRM_E_INVALID_REPORT_FORMAT" => ITF::FSRM_E_INVALID_REPORT_FORMAT,
            "FSRM_E_INVALID_REPORT_DESC" => ITF::FSRM_E_INVALID_REPORT_DESC,
            "FSRM_E_INVALID_FILENAME" => ITF::FSRM_E_INVALID_FILENAME,
            "FSRM_E_SHADOW_COPY" => ITF::FSRM_E_SHADOW_COPY,
            "FSRM_E_XML_CORRUPTED" => ITF::FSRM_E_XML_CORRUPTED,
            "FSRM_E_CLUSTER_NOT_RUNNING" => ITF::FSRM_E_CLUSTER_NOT_RUNNING,
            "FSRM_E_STORE_NOT_INSTALLED" => ITF::FSRM_E_STORE_NOT_INSTALLED,
            "FSRM_E_NOT_CLUSTER_VOLUME" => ITF::FSRM_E_NOT_CLUSTER_VOLUME,
            "FSRM_E_DIFFERENT_CLUSTER_GROUP" => ITF::FSRM_E_DIFFERENT_CLUSTER_GROUP,
            "FSRM_E_REPORT_TYPE_ALREADY_EXISTS" => ITF::FSRM_E_REPORT_TYPE_ALREADY_EXISTS,
            "FSRM_E_REPORT_JOB_ALREADY_RUNNING" => ITF::FSRM_E_REPORT_JOB_ALREADY_RUNNING,
            "FSRM_E_REPORT_GENERATION_ERR" => ITF::FSRM_E_REPORT_GENERATION_ERR,
            "FSRM_E_REPORT_TASK_TRIGGER" => ITF::FSRM_E_REPORT_TASK_TRIGGER,
            "FSRM_E_LOADING_DISABLED_MODULE" => ITF::FSRM_E_LOADING_DISABLED_MODULE,
            "FSRM_E_CANNOT_AGGREGATE" => ITF::FSRM_E_CANNOT_AGGREGATE,
            "FSRM_E_MESSAGE_LIMIT_EXCEEDED" => ITF::FSRM_E_MESSAGE_LIMIT_EXCEEDED,
            "FSRM_E_OBJECT_IN_USE" => ITF::FSRM_E_OBJECT_IN_USE,
            "FSRM_E_CANNOT_RENAME_PROPERTY" => ITF::FSRM_E_CANNOT_RENAME_PROPERTY,
            "FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE" => ITF::FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE,
            "FSRM_E_MAX_PROPERTY_DEFINITIONS" => ITF::FSRM_E_MAX_PROPERTY_DEFINITIONS,
            "FSRM_E_CLASSIFICATION_ALREADY_RUNNING" => ITF::FSRM_E_CLASSIFICATION_ALREADY_RUNNING,
            "FSRM_E_CLASSIFICATION_NOT_RUNNING" => ITF::FSRM_E_CLASSIFICATION_NOT_RUNNING,
            "FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING,
            "FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION,
            "FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM,
            "FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION,
            "FSRM_E_FILE_OPEN_ERROR" => ITF::FSRM_E_FILE_OPEN_ERROR,
            "FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE" => ITF::FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE,
            "FSRM_E_CACHE_INVALID" => ITF::FSRM_E_CACHE_INVALID,
            "FSRM_E_CACHE_MODULE_ALREADY_EXISTS" => ITF::FSRM_E_CACHE_MODULE_ALREADY_EXISTS,
            "FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE" => ITF::FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE,
            "FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS,
            "FSRM_E_PROPERTY_DELETED" => ITF::FSRM_E_PROPERTY_DELETED,
            "FSRM_E_LAST_ACCESS_UPDATE_DISABLED" => ITF::FSRM_E_LAST_ACCESS_UPDATE_DISABLED,
            "FSRM_E_NO_PROPERTY_VALUE" => ITF::FSRM_E_NO_PROPERTY_VALUE,
            "FSRM_E_INPROC_MODULE_BLOCKED" => ITF::FSRM_E_INPROC_MODULE_BLOCKED,
            "FSRM_E_ENUM_PROPERTIES_FAILED" => ITF::FSRM_E_ENUM_PROPERTIES_FAILED,
            "FSRM_E_SET_PROPERTY_FAILED" => ITF::FSRM_E_SET_PROPERTY_FAILED,
            "FSRM_E_CANNOT_STORE_PROPERTIES" => ITF::FSRM_E_CANNOT_STORE_PROPERTIES,
            "FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG" => ITF::FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG,
            "FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND" => ITF::FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND,
            "FSRM_E_TEXTREADER_NOT_INITIALIZED" => ITF::FSRM_E_TEXTREADER_NOT_INITIALIZED,
            "FSRM_E_TEXTREADER_IFILTER_NOT_FOUND" => ITF::FSRM_E_TEXTREADER_IFILTER_NOT_FOUND,
            "FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED" => ITF::FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED,
            "FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED" => ITF::FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED,
            "FSRM_E_TEXTREADER_STREAM_ERROR" => ITF::FSRM_E_TEXTREADER_STREAM_ERROR,
            "FSRM_E_TEXTREADER_FILENAME_TOO_LONG" => ITF::FSRM_E_TEXTREADER_FILENAME_TOO_LONG,
            "FSRM_E_INCOMPATIBLE_FORMAT" => ITF::FSRM_E_INCOMPATIBLE_FORMAT,
            "FSRM_E_FILE_ENCRYPTED" => ITF::FSRM_E_FILE_ENCRYPTED,
            "FSRM_E_PERSIST_PROPERTIES_FAILED" => ITF::FSRM_E_PERSIST_PROPERTIES_FAILED,
            "FSRM_E_VOLUME_OFFLINE" => ITF::FSRM_E_VOLUME_OFFLINE,
            "FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT" => ITF::FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT,
            "FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED" => ITF::FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED,
            "FSRM_E_MODULE_INVALID_PARAM" => ITF::FSRM_E_MODULE_INVALID_PARAM,
            "FSRM_E_MODULE_INITIALIZATION" => ITF::FSRM_E_MODULE_INITIALIZATION,
            "FSRM_E_MODULE_SESSION_INITIALIZATION" => ITF::FSRM_E_MODULE_SESSION_INITIALIZATION,
            "FSRM_E_CLASSIFICATION_SCAN_FAIL" => ITF::FSRM_E_CLASSIFICATION_SCAN_FAIL,
            "FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE,
            "FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS,
            "FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY" => ITF::FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY,
            "FSRM_E_SYNC_TASK_TIMEOUT" => ITF::FSRM_E_SYNC_TASK_TIMEOUT,
            "FSRM_E_CANNOT_USE_DELETED_PROPERTY" => ITF::FSRM_E_CANNOT_USE_DELETED_PROPERTY,
            "FSRM_E_INVALID_AD_CLAIM" => ITF::FSRM_E_INVALID_AD_CLAIM,
            "FSRM_E_CLASSIFICATION_CANCELED" => ITF::FSRM_E_CLASSIFICATION_CANCELED,
            "FSRM_E_INVALID_FOLDER_PROPERTY_STORE" => ITF::FSRM_E_INVALID_FOLDER_PROPERTY_STORE,
            "FSRM_E_REBUILDING_FODLER_TYPE_INDEX" => ITF::FSRM_E_REBUILDING_FODLER_TYPE_INDEX,
            "FSRM_E_PROPERTY_MUST_APPLY_TO_FILES" => ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FILES,
            "FSRM_E_CLASSIFICATION_TIMEOUT" => ITF::FSRM_E_CLASSIFICATION_TIMEOUT,
            "FSRM_E_CLASSIFICATION_PARTIAL_BATCH" => ITF::FSRM_E_CLASSIFICATION_PARTIAL_BATCH,
            "FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY" => ITF::FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY,
            "FSRM_E_FILE_IN_USE" => ITF::FSRM_E_FILE_IN_USE,
            "FSRM_E_ERROR_NOT_ENABLED" => ITF::FSRM_E_ERROR_NOT_ENABLED,
            "FSRM_E_CANNOT_CREATE_TEMP_COPY" => ITF::FSRM_E_CANNOT_CREATE_TEMP_COPY,
            "FSRM_E_NO_EMAIL_ADDRESS" => ITF::FSRM_E_NO_EMAIL_ADDRESS,
            "FSRM_E_ADR_MAX_EMAILS_SENT" => ITF::FSRM_E_ADR_MAX_EMAILS_SENT,
            "FSRM_E_PATH_NOT_IN_NAMESPACE" => ITF::FSRM_E_PATH_NOT_IN_NAMESPACE,
            "FSRM_E_RMS_TEMPLATE_NOT_FOUND" => ITF::FSRM_E_RMS_TEMPLATE_NOT_FOUND,
            "FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED" => ITF::FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED,
            "FSRM_E_RMS_NO_PROTECTORS_INSTALLED" => ITF::FSRM_E_RMS_NO_PROTECTORS_INSTALLED,
            "FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE" => ITF::FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE,
            "FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS" => ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS,
            "FSRM_E_PROPERTY_MUST_BE_SECURE" => ITF::FSRM_E_PROPERTY_MUST_BE_SECURE,
            "FSRM_E_PROPERTY_MUST_BE_GLOBAL" => ITF::FSRM_E_PROPERTY_MUST_BE_GLOBAL,
            "FSRM_E_WMI_FAILURE" => ITF::FSRM_E_WMI_FAILURE,
            "FSRM_E_FILE_MANAGEMENT_JOB_RMS" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_RMS,
            "FSRM_E_SYNC_TASK_HAD_ERRORS" => ITF::FSRM_E_SYNC_TASK_HAD_ERRORS,
            "FSRM_E_ADR_SRV_NOT_SUPPORTED" => ITF::FSRM_E_ADR_SRV_NOT_SUPPORTED,
            "FSRM_E_ADR_PATH_IS_LOCAL" => ITF::FSRM_E_ADR_PATH_IS_LOCAL,
            "FSRM_E_ADR_NOT_DOMAIN_JOINED" => ITF::FSRM_E_ADR_NOT_DOMAIN_JOINED,
            "FSRM_E_CANNOT_REMOVE_READONLY" => ITF::FSRM_E_CANNOT_REMOVE_READONLY,
            "FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG,
            "FSRM_E_LEGACY_SCHEDULE" => ITF::FSRM_E_LEGACY_SCHEDULE,
            "FSRM_E_CSC_PATH_NOT_SUPPORTED" => ITF::FSRM_E_CSC_PATH_NOT_SUPPORTED,
            "FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE" => ITF::FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE,
            "FSRM_E_EXPIRATION_PATH_TOO_LONG" => ITF::FSRM_E_EXPIRATION_PATH_TOO_LONG,
            "FSRM_E_EXPIRATION_VOLUME_NOT_NTFS" => ITF::FSRM_E_EXPIRATION_VOLUME_NOT_NTFS,
            "FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED" => ITF::FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED,
            "FSRM_E_MODULE_TIMEOUT" => ITF::FSRM_E_MODULE_TIMEOUT,
            "IFED_S_MORE_ENTRIES" => ITF::IFED_S_MORE_ENTRIES,
            "IFED_S_EMPTY_DICTIONARY" => ITF::IFED_S_EMPTY_DICTIONARY,
            "IFED_S_WORD_EXISTS" => ITF::IFED_S_WORD_EXISTS,
            "IFED_S_COMMENT_CHANGED" => ITF::IFED_S_COMMENT_CHANGED,
            "IFED_E_NOT_FOUND" => ITF::IFED_E_NOT_FOUND,
            "IFED_E_INVALID_FORMAT" => ITF::IFED_E_INVALID_FORMAT,
            "IFED_E_OPEN_FAILED" => ITF::IFED_E_OPEN_FAILED,
            "IFED_E_WRITE_FAILED" => ITF::IFED_E_WRITE_FAILED,
            "IFED_E_NO_ENTRY" => ITF::IFED_E_NO_ENTRY,
            "IFED_E_REGISTER_FAILED" => ITF::IFED_E_REGISTER_FAILED,
            "IFED_E_NOT_USER_DIC" => ITF::IFED_E_NOT_USER_DIC,
            "IFED_E_NOT_SUPPORTED" => ITF::IFED_E_NOT_SUPPORTED,
            "IFED_E_USER_COMMENT" => ITF::IFED_E_USER_COMMENT,
            "IFED_E_REGISTER_ILLEGAL_POS" => ITF::IFED_E_REGISTER_ILLEGAL_POS,
            "IFED_E_REGISTER_IMPROPER_WORD" => ITF::IFED_E_REGISTER_IMPROPER_WORD,
            "IFED_E_REGISTER_DISCONNECTED" => ITF::IFED_E_REGISTER_DISCONNECTED,
            "NETCFG_E_ALREADY_INITIALIZED" => ITF::NETCFG_E_ALREADY_INITIALIZED,
            "UPNP_E_REQUIRED_ELEMENT_ERROR" => ITF::UPNP_E_REQUIRED_ELEMENT_ERROR,
            "NETCFG_E_NOT_INITIALIZED" => ITF::NETCFG_E_NOT_INITIALIZED,
            "UPNP_E_DUPLICATE_NOT_ALLOWED" => ITF::UPNP_E_DUPLICATE_NOT_ALLOWED,
            "NETCFG_E_IN_USE" => ITF::NETCFG_E_IN_USE,
            "UPNP_E_DUPLICATE_SERVICE_ID" => ITF::UPNP_E_DUPLICATE_SERVICE_ID,
            "UPNP_E_INVALID_DESCRIPTION" => ITF::UPNP_E_INVALID_DESCRIPTION,
            "NETCFG_E_NO_WRITE_LOCK" => ITF::NETCFG_E_NO_WRITE_LOCK,
            "UPNP_E_INVALID_SERVICE" => ITF::UPNP_E_INVALID_SERVICE,
            "NETCFG_E_NEED_REBOOT" => ITF::NETCFG_E_NEED_REBOOT,
            "UPNP_E_INVALID_ICON" => ITF::UPNP_E_INVALID_ICON,
            "NETCFG_E_ACTIVE_RAS_CONNECTIONS" => ITF::NETCFG_E_ACTIVE_RAS_CONNECTIONS,
            "UPNP_E_INVALID_XML" => ITF::UPNP_E_INVALID_XML,
            "NETCFG_E_ADAPTER_NOT_FOUND" => ITF::NETCFG_E_ADAPTER_NOT_FOUND,
            "UPNP_E_INVALID_ROOT_NAMESPACE" => ITF::UPNP_E_INVALID_ROOT_NAMESPACE,
            "NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT" => ITF::NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT,
            "UPNP_E_SUFFIX_TOO_LONG" => ITF::UPNP_E_SUFFIX_TOO_LONG,
            "NETCFG_E_MAX_FILTER_LIMIT" => ITF::NETCFG_E_MAX_FILTER_LIMIT,
            "UPNP_E_URLBASE_PRESENT" => ITF::UPNP_E_URLBASE_PRESENT,
            "NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER" => ITF::NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER,
            "NETCFG_E_DUPLICATE_INSTANCEID" => ITF::NETCFG_E_DUPLICATE_INSTANCEID,
            "UPNP_E_VALUE_TOO_LONG" => ITF::UPNP_E_VALUE_TOO_LONG,
            "UPNP_E_DEVICE_RUNNING" => ITF::UPNP_E_DEVICE_RUNNING,
            "UPNP_E_DEVICE_NOTREGISTERED" => ITF::UPNP_E_DEVICE_NOTREGISTERED,
            "WTS_E_FAILEDEXTRACTION" => ITF::WTS_E_FAILEDEXTRACTION,
            "WTS_E_EXTRACTIONTIMEDOUT" => ITF::WTS_E_EXTRACTIONTIMEDOUT,
            "WTS_E_SURROGATEUNAVAILABLE" => ITF::WTS_E_SURROGATEUNAVAILABLE,
            "WTS_E_FASTEXTRACTIONNOTSUPPORTED" => ITF::WTS_E_FASTEXTRACTIONNOTSUPPORTED,
            "WTS_E_DATAFILEUNAVAILABLE" => ITF::WTS_E_DATAFILEUNAVAILABLE,
            "FTE_E_CB_OUT_OF_MEMORY" => ITF::FTE_E_CB_OUT_OF_MEMORY,
            "FTE_E_CB_CBID_OUT_OF_BOUND" => ITF::FTE_E_CB_CBID_OUT_OF_BOUND,
            "FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM" => ITF::FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM,
            "FTE_E_CB_NOT_ENOUGH_OCC_BUFFER" => ITF::FTE_E_CB_NOT_ENOUGH_OCC_BUFFER,
            "FTE_E_CORRUPT_WORDLIST" => ITF::FTE_E_CORRUPT_WORDLIST,
            "XACT_E_ALREADYOTHERSINGLEPHASE" => ITF::XACT_E_ALREADYOTHERSINGLEPHASE,
            "XACT_E_CANTRETAIN" => ITF::XACT_E_CANTRETAIN,
            "XACT_E_COMMITFAILED" => ITF::XACT_E_COMMITFAILED,
            "XACT_E_COMMITPREVENTED" => ITF::XACT_E_COMMITPREVENTED,
            "XACT_E_HEURISTICABORT" => ITF::XACT_E_HEURISTICABORT,
            "XACT_E_HEURISTICCOMMIT" => ITF::XACT_E_HEURISTICCOMMIT,
            "XACT_E_HEURISTICDAMAGE" => ITF::XACT_E_HEURISTICDAMAGE,
            "XACT_E_HEURISTICDANGER" => ITF::XACT_E_HEURISTICDANGER,
            "XACT_E_ISOLATIONLEVEL" => ITF::XACT_E_ISOLATIONLEVEL,
            "XACT_E_NOASYNC" => ITF::XACT_E_NOASYNC,
            "XACT_E_NOENLIST" => ITF::XACT_E_NOENLIST,
            "XACT_E_NOISORETAIN" => ITF::XACT_E_NOISORETAIN,
            "XACT_E_NORESOURCE" => ITF::XACT_E_NORESOURCE,
            "XACT_E_NOTCURRENT" => ITF::XACT_E_NOTCURRENT,
            "XACT_E_NOTRANSACTION" => ITF::XACT_E_NOTRANSACTION,
            "XACT_E_NOTSUPPORTED" => ITF::XACT_E_NOTSUPPORTED,
            "XACT_E_UNKNOWNRMGRID" => ITF::XACT_E_UNKNOWNRMGRID,
            "XACT_E_WRONGSTATE" => ITF::XACT_E_WRONGSTATE,
            "XACT_E_WRONGUOW" => ITF::XACT_E_WRONGUOW,
            "XACT_E_XTIONEXISTS" => ITF::XACT_E_XTIONEXISTS,
            "XACT_E_NOIMPORTOBJECT" => ITF::XACT_E_NOIMPORTOBJECT,
            "XACT_E_INVALIDCOOKIE" => ITF::XACT_E_INVALIDCOOKIE,
            "XACT_E_INDOUBT" => ITF::XACT_E_INDOUBT,
            "XACT_E_NOTIMEOUT" => ITF::XACT_E_NOTIMEOUT,
            "XACT_E_ALREADYINPROGRESS" => ITF::XACT_E_ALREADYINPROGRESS,
            "XACT_E_ABORTED" => ITF::XACT_E_ABORTED,
            "XACT_E_LOGFULL" => ITF::XACT_E_LOGFULL,
            "XACT_E_TMNOTAVAILABLE" => ITF::XACT_E_TMNOTAVAILABLE,
            "XACT_E_CONNECTION_DOWN" => ITF::XACT_E_CONNECTION_DOWN,
            "XACT_E_CONNECTION_DENIED" => ITF::XACT_E_CONNECTION_DENIED,
            "XACT_E_REENLISTTIMEOUT" => ITF::XACT_E_REENLISTTIMEOUT,
            "XACT_E_TIP_CONNECT_FAILED" => ITF::XACT_E_TIP_CONNECT_FAILED,
            "XACT_E_TIP_PROTOCOL_ERROR" => ITF::XACT_E_TIP_PROTOCOL_ERROR,
            "XACT_E_TIP_PULL_FAILED" => ITF::XACT_E_TIP_PULL_FAILED,
            "XACT_E_DEST_TMNOTAVAILABLE" => ITF::XACT_E_DEST_TMNOTAVAILABLE,
            "XACT_E_TIP_DISABLED" => ITF::XACT_E_TIP_DISABLED,
            "XACT_E_NETWORK_TX_DISABLED" => ITF::XACT_E_NETWORK_TX_DISABLED,
            "XACT_E_PARTNER_NETWORK_TX_DISABLED" => ITF::XACT_E_PARTNER_NETWORK_TX_DISABLED,
            "XACT_E_XA_TX_DISABLED" => ITF::XACT_E_XA_TX_DISABLED,
            "XACT_E_UNABLE_TO_READ_DTC_CONFIG" => ITF::XACT_E_UNABLE_TO_READ_DTC_CONFIG,
            "XACT_E_UNABLE_TO_LOAD_DTC_PROXY" => ITF::XACT_E_UNABLE_TO_LOAD_DTC_PROXY,
            "XACT_E_ABORTING" => ITF::XACT_E_ABORTING,
            "XACT_E_PUSH_COMM_FAILURE" => ITF::XACT_E_PUSH_COMM_FAILURE,
            "XACT_E_PULL_COMM_FAILURE" => ITF::XACT_E_PULL_COMM_FAILURE,
            "XACT_E_LU_TX_DISABLED" => ITF::XACT_E_LU_TX_DISABLED,
            "XACT_E_CLERKNOTFOUND" => ITF::XACT_E_CLERKNOTFOUND,
            "XACT_E_CLERKEXISTS" => ITF::XACT_E_CLERKEXISTS,
            "XACT_E_RECOVERYINPROGRESS" => ITF::XACT_E_RECOVERYINPROGRESS,
            "XACT_E_TRANSACTIONCLOSED" => ITF::XACT_E_TRANSACTIONCLOSED,
            "XACT_E_INVALIDLSN" => ITF::XACT_E_INVALIDLSN,
            "XACT_E_REPLAYREQUEST" => ITF::XACT_E_REPLAYREQUEST,
            "XACT_E_CONNECTION_REQUEST_DENIED" => ITF::XACT_E_CONNECTION_REQUEST_DENIED,
            "XACT_E_TOOMANY_ENLISTMENTS" => ITF::XACT_E_TOOMANY_ENLISTMENTS,
            "XACT_E_DUPLICATE_GUID" => ITF::XACT_E_DUPLICATE_GUID,
            "SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED" => ITF::SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED,
            "XACT_E_NOTSINGLEPHASE" => ITF::XACT_E_NOTSINGLEPHASE,
            "XACT_E_RECOVERYALREADYDONE" => ITF::XACT_E_RECOVERYALREADYDONE,
            "XACT_E_PROTOCOL" => ITF::XACT_E_PROTOCOL,
            "XACT_E_RM_FAILURE" => ITF::XACT_E_RM_FAILURE,
            "XACT_E_RECOVERY_FAILED" => ITF::XACT_E_RECOVERY_FAILED,
            "XACT_E_LU_NOT_FOUND" => ITF::XACT_E_LU_NOT_FOUND,
            "XACT_E_DUPLICATE_LU" => ITF::XACT_E_DUPLICATE_LU,
            "XACT_E_LU_NOT_CONNECTED" => ITF::XACT_E_LU_NOT_CONNECTED,
            "XACT_E_DUPLICATE_TRANSID" => ITF::XACT_E_DUPLICATE_TRANSID,
            "SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED" => ITF::SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED,
            "XACT_E_LU_BUSY" => ITF::XACT_E_LU_BUSY,
            "XACT_E_LU_NO_RECOVERY_PROCESS" => ITF::XACT_E_LU_NO_RECOVERY_PROCESS,
            "XACT_E_LU_DOWN" => ITF::XACT_E_LU_DOWN,
            "XACT_E_LU_RECOVERING" => ITF::XACT_E_LU_RECOVERING,
            "XACT_E_LU_RECOVERY_MISMATCH" => ITF::XACT_E_LU_RECOVERY_MISMATCH,
            "XACT_E_RM_UNAVAILABLE" => ITF::XACT_E_RM_UNAVAILABLE,
            "CONTEXT_E_ABORTED" => ITF::CONTEXT_E_ABORTED,
            "CONTEXT_E_ABORTING" => ITF::CONTEXT_E_ABORTING,
            "CONTEXT_E_NOCONTEXT" => ITF::CONTEXT_E_NOCONTEXT,
            "CONTEXT_E_WOULD_DEADLOCK" => ITF::CONTEXT_E_WOULD_DEADLOCK,
            "CONTEXT_E_SYNCH_TIMEOUT" => ITF::CONTEXT_E_SYNCH_TIMEOUT,
            "CONTEXT_E_OLDREF" => ITF::CONTEXT_E_OLDREF,
            "CONTEXT_E_ROLENOTFOUND" => ITF::CONTEXT_E_ROLENOTFOUND,
            "CONTEXT_E_TMNOTAVAILABLE" => ITF::CONTEXT_E_TMNOTAVAILABLE,
            "CO_E_ACTIVATIONFAILED" => ITF::CO_E_ACTIVATIONFAILED,
            "CO_E_ACTIVATIONFAILED_EVENTLOGGED" => ITF::CO_E_ACTIVATIONFAILED_EVENTLOGGED,
            "CO_E_ACTIVATIONFAILED_CATALOGERROR" => ITF::CO_E_ACTIVATIONFAILED_CATALOGERROR,
            "CO_E_ACTIVATIONFAILED_TIMEOUT" => ITF::CO_E_ACTIVATIONFAILED_TIMEOUT,
            "CO_E_INITIALIZATIONFAILED" => ITF::CO_E_INITIALIZATIONFAILED,
            "CONTEXT_E_NOJIT" => ITF::CONTEXT_E_NOJIT,
            "SL_E_INVALID_USE_OF_ADD_ON_PKEY" => ITF::SL_E_INVALID_USE_OF_ADD_ON_PKEY,
            "CONTEXT_E_NOTRANSACTION" => ITF::CONTEXT_E_NOTRANSACTION,
            "CO_E_THREADINGMODEL_CHANGED" => ITF::CO_E_THREADINGMODEL_CHANGED,
            "CO_E_NOIISINTRINSICS" => ITF::CO_E_NOIISINTRINSICS,
            "CO_E_NOCOOKIES" => ITF::CO_E_NOCOOKIES,
            "CO_E_DBERROR" => ITF::CO_E_DBERROR,
            "CO_E_NOTPOOLED" => ITF::CO_E_NOTPOOLED,
            "CO_E_NOTCONSTRUCTED" => ITF::CO_E_NOTCONSTRUCTED,
            "CO_E_NOSYNCHRONIZATION" => ITF::CO_E_NOSYNCHRONIZATION,
            "CO_E_ISOLEVELMISMATCH" => ITF::CO_E_ISOLEVELMISMATCH,
            "CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED" => ITF::CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED,
            "CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED" => ITF::CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED,
            "SL_E_SFS_INVALID_FS_VERSION" => ITF::SL_E_SFS_INVALID_FS_VERSION,
            "SL_E_SFS_INVALID_FD_TABLE" => ITF::SL_E_SFS_INVALID_FD_TABLE,
            "SL_E_SFS_INVALID_SYNC" => ITF::SL_E_SFS_INVALID_SYNC,
            "SL_E_SFS_BAD_TOKEN_NAME" => ITF::SL_E_SFS_BAD_TOKEN_NAME,
            "SL_E_SFS_BAD_TOKEN_EXT" => ITF::SL_E_SFS_BAD_TOKEN_EXT,
            "SL_E_SFS_DUPLICATE_TOKEN_NAME" => ITF::SL_E_SFS_DUPLICATE_TOKEN_NAME,
            "SL_E_SFS_TOKEN_SIZE_MISMATCH" => ITF::SL_E_SFS_TOKEN_SIZE_MISMATCH,
            "SL_E_SFS_INVALID_TOKEN_DATA_HASH" => ITF::SL_E_SFS_INVALID_TOKEN_DATA_HASH,
            "SL_E_SFS_FILE_READ_ERROR" => ITF::SL_E_SFS_FILE_READ_ERROR,
            "SL_E_SFS_FILE_WRITE_ERROR" => ITF::SL_E_SFS_FILE_WRITE_ERROR,
            "SL_E_SFS_INVALID_FILE_POSITION" => ITF::SL_E_SFS_INVALID_FILE_POSITION,
            "SL_E_SFS_NO_ACTIVE_TRANSACTION" => ITF::SL_E_SFS_NO_ACTIVE_TRANSACTION,
            "SL_E_SFS_INVALID_FS_HEADER" => ITF::SL_E_SFS_INVALID_FS_HEADER,
            "SL_E_SFS_INVALID_TOKEN_DESCRIPTOR" => ITF::SL_E_SFS_INVALID_TOKEN_DESCRIPTOR,
            "FTE_E_FD_NO_IPERSIST_INTERFACE" => ITF::FTE_E_FD_NO_IPERSIST_INTERFACE,
            "FTE_E_FD_IFILTER_INIT_FAILED" => ITF::FTE_E_FD_IFILTER_INIT_FAILED,
            "FTE_E_FD_FAILED_TO_LOAD_IFILTER" => ITF::FTE_E_FD_FAILED_TO_LOAD_IFILTER,
            "FTE_E_FD_DOC_TIMEOUT" => ITF::FTE_E_FD_DOC_TIMEOUT,
            "FTE_E_FD_UNEXPECTED_EXIT" => ITF::FTE_E_FD_UNEXPECTED_EXIT,
            "FTE_E_FD_DOC_UNEXPECTED_EXIT" => ITF::FTE_E_FD_DOC_UNEXPECTED_EXIT,
            "FTE_E_FD_NOISE_NO_TEXT_FILTER" => ITF::FTE_E_FD_NOISE_NO_TEXT_FILTER,
            "FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER" => ITF::FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER,
            "FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED" => ITF::FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED,
            "FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED" => ITF::FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED,
            "FTE_E_FD_OCCURRENCE_OVERFLOW" => ITF::FTE_E_FD_OCCURRENCE_OVERFLOW,
            "FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION" => ITF::FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION,
            "IO_ERR_CONFIGURATION_ERROR" => ITF::IO_ERR_CONFIGURATION_ERROR,
            "IO_ERR_DRIVER_ERROR" => ITF::IO_ERR_DRIVER_ERROR,
            "IO_ERR_PARITY" => ITF::IO_ERR_PARITY,
            "IO_ERR_SEEK_ERROR" => ITF::IO_ERR_SEEK_ERROR,
            "IO_ERR_BAD_BLOCK" => ITF::IO_ERR_BAD_BLOCK,
            "IO_ERR_OVERRUN_ERROR" => ITF::IO_ERR_OVERRUN_ERROR,
            "IO_ERR_TIMEOUT" => ITF::IO_ERR_TIMEOUT,
            "IO_ERR_SEQUENCE" => ITF::IO_ERR_SEQUENCE,
            "IO_ERR_CONTROLLER_ERROR" => ITF::IO_ERR_CONTROLLER_ERROR,
            "IO_ERR_INTERNAL_ERROR" => ITF::IO_ERR_INTERNAL_ERROR,
            "IO_ERR_INCORRECT_IRQL" => ITF::IO_ERR_INCORRECT_IRQL,
            "IO_ERR_INVALID_IOBASE" => ITF::IO_ERR_INVALID_IOBASE,
            "IO_ERR_NOT_READY" => ITF::IO_ERR_NOT_READY,
            "IO_ERR_INVALID_REQUEST" => ITF::IO_ERR_INVALID_REQUEST,
            "IO_ERR_VERSION" => ITF::IO_ERR_VERSION,
            "IO_ERR_LAYERED_FAILURE" => ITF::IO_ERR_LAYERED_FAILURE,
            "IO_ERR_RESET" => ITF::IO_ERR_RESET,
            "IO_ERR_PROTOCOL" => ITF::IO_ERR_PROTOCOL,
            "IO_ERR_MEMORY_CONFLICT_DETECTED" => ITF::IO_ERR_MEMORY_CONFLICT_DETECTED,
            "IO_ERR_PORT_CONFLICT_DETECTED" => ITF::IO_ERR_PORT_CONFLICT_DETECTED,
            "IO_ERR_DMA_CONFLICT_DETECTED" => ITF::IO_ERR_DMA_CONFLICT_DETECTED,
            "IO_ERR_IRQ_CONFLICT_DETECTED" => ITF::IO_ERR_IRQ_CONFLICT_DETECTED,
            "IO_ERR_BAD_FIRMWARE" => ITF::IO_ERR_BAD_FIRMWARE,
            "IO_ERR_DMA_RESOURCE_CONFLICT" => ITF::IO_ERR_DMA_RESOURCE_CONFLICT,
            "IO_ERR_INTERRUPT_RESOURCE_CONFLICT" => ITF::IO_ERR_INTERRUPT_RESOURCE_CONFLICT,
            "IO_ERR_MEMORY_RESOURCE_CONFLICT" => ITF::IO_ERR_MEMORY_RESOURCE_CONFLICT,
            "IO_ERR_PORT_RESOURCE_CONFLICT" => ITF::IO_ERR_PORT_RESOURCE_CONFLICT,
            "IO_BAD_BLOCK_WITH_NAME" => ITF::IO_BAD_BLOCK_WITH_NAME,
            "IO_FILE_SYSTEM_CORRUPT" => ITF::IO_FILE_SYSTEM_CORRUPT,
            "IO_FILE_QUOTA_CORRUPT" => ITF::IO_FILE_QUOTA_CORRUPT,
            "IO_SYSTEM_SLEEP_FAILED" => ITF::IO_SYSTEM_SLEEP_FAILED,
            "IO_DUMP_POINTER_FAILURE" => ITF::IO_DUMP_POINTER_FAILURE,
            "IO_DUMP_DRIVER_LOAD_FAILURE" => ITF::IO_DUMP_DRIVER_LOAD_FAILURE,
            "IO_DUMP_INITIALIZATION_FAILURE" => ITF::IO_DUMP_INITIALIZATION_FAILURE,
            "IO_DUMP_DUMPFILE_CONFLICT" => ITF::IO_DUMP_DUMPFILE_CONFLICT,
            "IO_DUMP_DIRECT_CONFIG_FAILED" => ITF::IO_DUMP_DIRECT_CONFIG_FAILED,
            "IO_DUMP_PAGE_CONFIG_FAILED" => ITF::IO_DUMP_PAGE_CONFIG_FAILED,
            "IO_FILE_SYSTEM_CORRUPT_WITH_NAME" => ITF::IO_FILE_SYSTEM_CORRUPT_WITH_NAME,
            "IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER" => ITF::IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER,
            "IO_ERR_PORT_TIMEOUT" => ITF::IO_ERR_PORT_TIMEOUT,
            "IO_ERROR_DISK_RESOURCES_EXHAUSTED" => ITF::IO_ERROR_DISK_RESOURCES_EXHAUSTED,
            "IO_ERROR_IO_HARDWARE_ERROR" => ITF::IO_ERROR_IO_HARDWARE_ERROR,
            "ES_E_INVALID_RESPONSE" => ITF::ES_E_INVALID_RESPONSE,
            "ES_E_UNPROVISIONED_HARDWARE" => ITF::ES_E_UNPROVISIONED_HARDWARE,
            "ES_E_UNSUPPORTED_HARDWARE" => ITF::ES_E_UNSUPPORTED_HARDWARE,
            "ES_E_INCOMPLETE_COMMAND" => ITF::ES_E_INCOMPLETE_COMMAND,
            "ES_E_BAD_SEQUENCE" => ITF::ES_E_BAD_SEQUENCE,
            "ES_E_NO_PROBE" => ITF::ES_E_NO_PROBE,
            "ES_E_INVALID_SILO" => ITF::ES_E_INVALID_SILO,
            "ES_E_INVALID_CAPABILITY" => ITF::ES_E_INVALID_CAPABILITY,
            "ES_E_GROUP_POLICY_FORBIDDEN_USE" => ITF::ES_E_GROUP_POLICY_FORBIDDEN_USE,
            "ES_E_GROUP_POLICY_FORBIDDEN_OPERATION" => ITF::ES_E_GROUP_POLICY_FORBIDDEN_OPERATION,
            "ES_E_INVALID_PARAM_COMBINATION" => ITF::ES_E_INVALID_PARAM_COMBINATION,
            "ES_E_INVALID_PARAM_LENGTH" => ITF::ES_E_INVALID_PARAM_LENGTH,
            "ES_E_INCONSISTENT_PARAM_LENGTH" => ITF::ES_E_INCONSISTENT_PARAM_LENGTH,
            "ES_E_NO_AUTHENTICATION_REQUIRED" => ITF::ES_E_NO_AUTHENTICATION_REQUIRED,
            "GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED" => ITF::GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED,
            "ES_E_INVALID_FIELD_IDENTIFIER" => ITF::ES_E_INVALID_FIELD_IDENTIFIER,
            "ES_E_CHALLENGE_MISMATCH" => ITF::ES_E_CHALLENGE_MISMATCH,
            "ES_E_CHALLENGE_SIZE_MISMATCH" => ITF::ES_E_CHALLENGE_SIZE_MISMATCH,
            "ES_E_FRIENDLY_NAME_TOO_LONG" => ITF::ES_E_FRIENDLY_NAME_TOO_LONG,
            "ES_E_SILO_NAME_TOO_LONG" => ITF::ES_E_SILO_NAME_TOO_LONG,
            "ES_E_PASSWORD_TOO_LONG" => ITF::ES_E_PASSWORD_TOO_LONG,
            "ES_E_PASSWORD_HINT_TOO_LONG" => ITF::ES_E_PASSWORD_HINT_TOO_LONG,
            "ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE" => ITF::ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE,
            "ES_E_DEVICE_DIGEST_MISSING" => ITF::ES_E_DEVICE_DIGEST_MISSING,
            "ES_E_NOT_AUTHORIZED_UNEXPECTED" => ITF::ES_E_NOT_AUTHORIZED_UNEXPECTED,
            "ES_E_AUTHORIZED_UNEXPECTED" => ITF::ES_E_AUTHORIZED_UNEXPECTED,
            "ES_E_PROVISIONED_UNEXPECTED" => ITF::ES_E_PROVISIONED_UNEXPECTED,
            "ES_E_UNKNOWN_DIGEST_ALGORITHM" => ITF::ES_E_UNKNOWN_DIGEST_ALGORITHM,
            "QUTIL_E_INVALID_CODEPAGE" => ITF::QUTIL_E_INVALID_CODEPAGE,
            "FILTER_E_CONTENTINDEXCORRUPT" => ITF::FILTER_E_CONTENTINDEXCORRUPT,
            "CI_CORRUPT_DATABASE" => ITF::CI_CORRUPT_DATABASE,
            "CI_CORRUPT_CATALOG" => ITF::CI_CORRUPT_CATALOG,
            "CI_INVALID_PARTITION" => ITF::CI_INVALID_PARTITION,
            "CI_INVALID_PRIORITY" => ITF::CI_INVALID_PRIORITY,
            "CI_NO_STARTING_KEY" => ITF::CI_NO_STARTING_KEY,
            "CI_OUT_OF_INDEX_IDS" => ITF::CI_OUT_OF_INDEX_IDS,
            "CI_NO_CATALOG" => ITF::CI_NO_CATALOG,
            "CI_CORRUPT_FILTER_BUFFER" => ITF::CI_CORRUPT_FILTER_BUFFER,
            "CI_INVALID_INDEX" => ITF::CI_INVALID_INDEX,
            "CI_PROPSTORE_INCONSISTENCY" => ITF::CI_PROPSTORE_INCONSISTENCY,
            "CI_INCORRECT_VERSION" => ITF::CI_INCORRECT_VERSION,
            "CI_E_ENUMERATION_STARTED" => ITF::CI_E_ENUMERATION_STARTED,
            "CI_E_PROPERTY_TOOLARGE" => ITF::CI_E_PROPERTY_TOOLARGE,
            "CI_E_CLIENT_FILTER_ABORT" => ITF::CI_E_CLIENT_FILTER_ABORT,
            "CI_E_CORRUPT_FWIDX" => ITF::CI_E_CORRUPT_FWIDX,
            "CI_E_DIACRITIC_SETTINGS_DIFFER" => ITF::CI_E_DIACRITIC_SETTINGS_DIFFER,
            "CI_E_NO_CATALOG_MANAGER" => ITF::CI_E_NO_CATALOG_MANAGER,
            "FTE_E_NO_PROPERTY_STORE" => ITF::FTE_E_NO_PROPERTY_STORE,
            "SL_E_SRV_INVALID_PUBLISH_LICENSE" => ITF::SL_E_SRV_INVALID_PUBLISH_LICENSE,
            "SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE" => ITF::SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE,
            "SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE" => ITF::SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE,
            "SL_E_SRV_INVALID_LICENSE_STRUCTURE" => ITF::SL_E_SRV_INVALID_LICENSE_STRUCTURE,
            "SL_E_SRV_AUTHORIZATION_FAILED" => ITF::SL_E_SRV_AUTHORIZATION_FAILED,
            "SL_E_SRV_INVALID_BINDING" => ITF::SL_E_SRV_INVALID_BINDING,
            "SL_E_SRV_SERVER_PONG" => ITF::SL_E_SRV_SERVER_PONG,
            "SL_E_SRV_INVALID_PAYLOAD" => ITF::SL_E_SRV_INVALID_PAYLOAD,
            "SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE" => ITF::SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE,
            "SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND" => ITF::SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND,
            "SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC" => ITF::SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC,
            "SL_E_SRV_GENERAL_ERROR" => ITF::SL_E_SRV_GENERAL_ERROR,
            "SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE" => ITF::SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE,
            "SL_E_CHPA_INVALID_BINDING" => ITF::SL_E_CHPA_INVALID_BINDING,
            "SL_E_CHPA_PRODUCT_KEY_BLOCKED" => ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED,
            "SL_E_CHPA_INVALID_PRODUCT_KEY" => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY,
            "SL_E_CHPA_BINDING_NOT_FOUND" => ITF::SL_E_CHPA_BINDING_NOT_FOUND,
            "SL_E_CHPA_BINDING_MAPPING_NOT_FOUND" => ITF::SL_E_CHPA_BINDING_MAPPING_NOT_FOUND,
            "SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY" => ITF::SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY,
            "SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED" => ITF::SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED,
            "SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND" => ITF::SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND,
            "SL_E_CHPA_INVALID_PRODUCT_DATA_ID" => ITF::SL_E_CHPA_INVALID_PRODUCT_DATA_ID,
            "SL_E_CHPA_INVALID_PRODUCT_DATA" => ITF::SL_E_CHPA_INVALID_PRODUCT_DATA,
            "SL_E_CHPA_SYSTEM_ERROR" => ITF::SL_E_CHPA_SYSTEM_ERROR,
            "SL_E_CHPA_INVALID_ACTCONFIG_ID" => ITF::SL_E_CHPA_INVALID_ACTCONFIG_ID,
            "SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH" => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH,
            "SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT" => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT,
            "SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR" => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR,
            "SL_E_CHPA_INVALID_BINDING_URI" => ITF::SL_E_CHPA_INVALID_BINDING_URI,
            "SL_E_CHPA_NETWORK_ERROR" => ITF::SL_E_CHPA_NETWORK_ERROR,
            "SL_E_CHPA_DATABASE_ERROR" => ITF::SL_E_CHPA_DATABASE_ERROR,
            "SL_E_CHPA_INVALID_ARGUMENT" => ITF::SL_E_CHPA_INVALID_ARGUMENT,
            "SL_E_CHPA_RESPONSE_NOT_AVAILABLE" => ITF::SL_E_CHPA_RESPONSE_NOT_AVAILABLE,
            "SL_E_CHPA_OEM_SLP_COA0" => ITF::SL_E_CHPA_OEM_SLP_COA0,
            "SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION" => ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION,
            "SL_E_CHPA_DMAK_LIMIT_EXCEEDED" => ITF::SL_E_CHPA_DMAK_LIMIT_EXCEEDED,
            "SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED" => ITF::SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED,
            "SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND" => ITF::SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND,
            "SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND" => ITF::SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND,
            "SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE" => ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE,
            "SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE" => ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE,
            "SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE" => ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE,
            "SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED" => ITF::SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED,
            "SL_E_CHPA_NO_RULES_TO_ACTIVATE" => ITF::SL_E_CHPA_NO_RULES_TO_ACTIVATE,
            "SL_E_CHPA_GENERAL_ERROR" => ITF::SL_E_CHPA_GENERAL_ERROR,
            "SL_E_CHPA_DIGITALMARKER_INVALID_BINDING" => ITF::SL_E_CHPA_DIGITALMARKER_INVALID_BINDING,
            "SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED" => ITF::SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED,
            "SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY" => ITF::SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY,
            "SL_E_INVALID_LICENSE_STATE_BREACH_GRACE" => ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE,
            "SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED" => ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED,
            "SL_E_INVALID_TEMPLATE_ID" => ITF::SL_E_INVALID_TEMPLATE_ID,
            "SL_E_INVALID_XML_BLOB" => ITF::SL_E_INVALID_XML_BLOB,
            "SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND" => ITF::SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND,
            "SL_E_INVALID_CLIENT_TOKEN" => ITF::SL_E_INVALID_CLIENT_TOKEN,
            "SL_E_INVALID_OFFLINE_BLOB" => ITF::SL_E_INVALID_OFFLINE_BLOB,
            "SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND" => ITF::SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND,
            "SL_E_INVALID_OSVERSION_TEMPLATEID" => ITF::SL_E_INVALID_OSVERSION_TEMPLATEID,
            "SL_E_OFFLINE_GENUINE_BLOB_REVOKED" => ITF::SL_E_OFFLINE_GENUINE_BLOB_REVOKED,
            "SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND" => ITF::SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND,
            "SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA" => ITF::SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA,
            "SL_E_INVALID_OS_FOR_PRODUCT_KEY" => ITF::SL_E_INVALID_OS_FOR_PRODUCT_KEY,
            "SL_E_INVALID_FILE_HASH" => ITF::SL_E_INVALID_FILE_HASH,
            "SL_E_VALIDATION_BLOCKED_PRODUCT_KEY" => ITF::SL_E_VALIDATION_BLOCKED_PRODUCT_KEY,
            "SL_E_MISMATCHED_KEY_TYPES" => ITF::SL_E_MISMATCHED_KEY_TYPES,
            "SL_E_VALIDATION_INVALID_PRODUCT_KEY" => ITF::SL_E_VALIDATION_INVALID_PRODUCT_KEY,
            "SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA" => ITF::SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA,
            "SL_E_INVALID_LICENSE_STATE" => ITF::SL_E_INVALID_LICENSE_STATE,
            "SL_E_IP_LOCATION_FALIED" => ITF::SL_E_IP_LOCATION_FALIED,
            "SL_E_SOFTMOD_EXPLOIT_DETECTED" => ITF::SL_E_SOFTMOD_EXPLOIT_DETECTED,
            "SL_E_INVALID_TOKEN_DATA" => ITF::SL_E_INVALID_TOKEN_DATA,
            "SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES" => ITF::SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES,
            "SL_E_HEALTH_CHECK_FAILED_MUI_FILES" => ITF::SL_E_HEALTH_CHECK_FAILED_MUI_FILES,
            "SL_E_INVALID_AD_DATA" => ITF::SL_E_INVALID_AD_DATA,
            "SL_E_INVALID_RSDP_COUNT" => ITF::SL_E_INVALID_RSDP_COUNT,
            "SL_E_ENGINE_DETECTED_EXPLOIT" => ITF::SL_E_ENGINE_DETECTED_EXPLOIT,
            "SL_E_NOTIFICATION_BREACH_DETECTED" => ITF::SL_E_NOTIFICATION_BREACH_DETECTED,
            "SL_E_NOTIFICATION_GRACE_EXPIRED" => ITF::SL_E_NOTIFICATION_GRACE_EXPIRED,
            "SL_E_NOTIFICATION_OTHER_REASONS" => ITF::SL_E_NOTIFICATION_OTHER_REASONS,
            "SL_E_NON_GENUINE_STATUS_LAST" => ITF::SL_E_NON_GENUINE_STATUS_LAST,
            "SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND" => ITF::SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND,
            "SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID" => ITF::SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID,
            "SL_E_CHPA_UNKNOWN_PROPERTY_NAME" => ITF::SL_E_CHPA_UNKNOWN_PROPERTY_NAME,
            "SL_E_CHPA_UNKNOWN_PROPERTY_ID" => ITF::SL_E_CHPA_UNKNOWN_PROPERTY_ID,
            "SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING" => ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING,
            "SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING" => ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING,
            "SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING" => ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING,
            "SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML" => ITF::SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML,
            "SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY" => ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY,
            "SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY" => ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY,
            "SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY" => ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY,
            "SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE" => ITF::SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE,
            "SL_E_CHPA_PRODUCT_KEY_BEING_USED" => ITF::SL_E_CHPA_PRODUCT_KEY_BEING_USED,
            "SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD" => ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD,
            "SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD" => ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD,
            "SL_REMAPPING_SP_PUB_API_INVALID_LICENSE" => ITF::SL_REMAPPING_SP_PUB_API_INVALID_LICENSE,
            "SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE" => ITF::SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE,
            "SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS" => ITF::SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS,
            "SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY" => ITF::SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY,
            "SL_REMAPPING_SP_PUB_API_INVALID_HANDLE" => ITF::SL_REMAPPING_SP_PUB_API_INVALID_HANDLE,
            "SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH" => ITF::SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH,
            "SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER" => ITF::SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER,
            "SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED" => ITF::SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED,
            "SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED" => ITF::SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED,
            "SL_REMAPPING_SP_STATUS_GENERIC_FAILURE" => ITF::SL_REMAPPING_SP_STATUS_GENERIC_FAILURE,
            "SL_REMAPPING_SP_STATUS_INVALIDARG" => ITF::SL_REMAPPING_SP_STATUS_INVALIDARG,
            "SL_REMAPPING_SP_STATUS_ALREADY_EXISTS" => ITF::SL_REMAPPING_SP_STATUS_ALREADY_EXISTS,
            "SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER" => ITF::SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER,
            "SL_REMAPPING_SP_STATUS_INVALIDDATA" => ITF::SL_REMAPPING_SP_STATUS_INVALIDDATA,
            "SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL" => ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL,
            "SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION" => ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION,
            "SL_REMAPPING_SP_STATUS_NO_MORE_DATA" => ITF::SL_REMAPPING_SP_STATUS_NO_MORE_DATA,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE,
            "SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID,
            "SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID,
            "SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID,
            "SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID,
            "SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED,
            "SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE,
            "SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND,
            "SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT,
            "SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING" => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED,
            "SL_REMAPPING_SP_PUB_TS_REARMED" => ITF::SL_REMAPPING_SP_PUB_TS_REARMED,
            "SL_REMAPPING_SP_PUB_TS_RECREATED" => ITF::SL_REMAPPING_SP_PUB_TS_RECREATED,
            "SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND" => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND,
            "SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS" => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS,
            "SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG" => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG,
            "SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED" => ITF::SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED,
            "SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG" => ITF::SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG,
            "SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING" => ITF::SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING,
            "SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS" => ITF::SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS,
            "SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND" => ITF::SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND,
            "SL_REMAPPING_SP_PUB_TIMER_EXPIRED" => ITF::SL_REMAPPING_SP_PUB_TIMER_EXPIRED,
            "SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG" => ITF::SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG,
            "SL_REMAPPING_SP_PUB_TS_FULL" => ITF::SL_REMAPPING_SP_PUB_TS_FULL,
            "SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY" => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY,
            "SL_REMAPPING_SP_PUB_TIMER_READ_ONLY" => ITF::SL_REMAPPING_SP_PUB_TIMER_READ_ONLY,
            "SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY" => ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY,
            "SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND" => ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND,
            "SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED" => ITF::SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED,
            "SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND" => ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND,
            "SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE" => ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH,
            "SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH" => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH,
            "SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION" => ITF::SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION,
            "SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED" => ITF::SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED,
            "SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER" => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER,
            "SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED" => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED,
            "SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT" => ITF::SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT,
            "SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER" => ITF::SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER,
            "SL_E_INVALID_CONTEXT" => ITF::SL_E_INVALID_CONTEXT,
            "SL_E_TOKEN_STORE_INVALID_STATE" => ITF::SL_E_TOKEN_STORE_INVALID_STATE,
            "SL_E_EVALUATION_FAILED" => ITF::SL_E_EVALUATION_FAILED,
            "SL_E_NOT_EVALUATED" => ITF::SL_E_NOT_EVALUATED,
            "SL_E_NOT_ACTIVATED" => ITF::SL_E_NOT_ACTIVATED,
            "SL_E_INVALID_GUID" => ITF::SL_E_INVALID_GUID,
            "SL_E_TOKSTO_TOKEN_NOT_FOUND" => ITF::SL_E_TOKSTO_TOKEN_NOT_FOUND,
            "SL_E_TOKSTO_NO_PROPERTIES" => ITF::SL_E_TOKSTO_NO_PROPERTIES,
            "SL_E_TOKSTO_NOT_INITIALIZED" => ITF::SL_E_TOKSTO_NOT_INITIALIZED,
            "SL_E_TOKSTO_ALREADY_INITIALIZED" => ITF::SL_E_TOKSTO_ALREADY_INITIALIZED,
            "SL_E_TOKSTO_NO_ID_SET" => ITF::SL_E_TOKSTO_NO_ID_SET,
            "SL_E_TOKSTO_CANT_CREATE_FILE" => ITF::SL_E_TOKSTO_CANT_CREATE_FILE,
            "SL_E_TOKSTO_CANT_WRITE_TO_FILE" => ITF::SL_E_TOKSTO_CANT_WRITE_TO_FILE,
            "SL_E_TOKSTO_CANT_READ_FILE" => ITF::SL_E_TOKSTO_CANT_READ_FILE,
            "SL_E_TOKSTO_CANT_PARSE_PROPERTIES" => ITF::SL_E_TOKSTO_CANT_PARSE_PROPERTIES,
            "SL_E_TOKSTO_PROPERTY_NOT_FOUND" => ITF::SL_E_TOKSTO_PROPERTY_NOT_FOUND,
            "SL_E_TOKSTO_INVALID_FILE" => ITF::SL_E_TOKSTO_INVALID_FILE,
            "SL_E_TOKSTO_CANT_CREATE_MUTEX" => ITF::SL_E_TOKSTO_CANT_CREATE_MUTEX,
            "SL_E_TOKSTO_CANT_ACQUIRE_MUTEX" => ITF::SL_E_TOKSTO_CANT_ACQUIRE_MUTEX,
            "SL_E_TOKSTO_NO_TOKEN_DATA" => ITF::SL_E_TOKSTO_NO_TOKEN_DATA,
            "SL_E_EUL_CONSUMPTION_FAILED" => ITF::SL_E_EUL_CONSUMPTION_FAILED,
            "SL_E_PKEY_INVALID_CONFIG" => ITF::SL_E_PKEY_INVALID_CONFIG,
            "SL_E_PKEY_INVALID_UNIQUEID" => ITF::SL_E_PKEY_INVALID_UNIQUEID,
            "SL_E_PKEY_INVALID_ALGORITHM" => ITF::SL_E_PKEY_INVALID_ALGORITHM,
            "SL_E_PKEY_INTERNAL_ERROR" => ITF::SL_E_PKEY_INTERNAL_ERROR,
            "SL_E_LICENSE_INVALID_ADDON_INFO" => ITF::SL_E_LICENSE_INVALID_ADDON_INFO,
            "SL_E_HWID_ERROR" => ITF::SL_E_HWID_ERROR,
            "SL_E_PKEY_INVALID_KEYCHANGE1" => ITF::SL_E_PKEY_INVALID_KEYCHANGE1,
            "SL_E_PKEY_INVALID_KEYCHANGE2" => ITF::SL_E_PKEY_INVALID_KEYCHANGE2,
            "SL_E_PKEY_INVALID_KEYCHANGE3" => ITF::SL_E_PKEY_INVALID_KEYCHANGE3,
            "SL_E_POLICY_OTHERINFO_MISMATCH" => ITF::SL_E_POLICY_OTHERINFO_MISMATCH,
            "SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID" => ITF::SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID,
            "SL_E_SECURE_STORE_ID_MISMATCH" => ITF::SL_E_SECURE_STORE_ID_MISMATCH,
            "SL_E_INVALID_RULESET_RULE" => ITF::SL_E_INVALID_RULESET_RULE,
            "SL_E_INVALID_CONTEXT_DATA" => ITF::SL_E_INVALID_CONTEXT_DATA,
            "SL_E_INVALID_HASH" => ITF::SL_E_INVALID_HASH,
            "SL_E_WINDOWS_VERSION_MISMATCH" => ITF::SL_E_WINDOWS_VERSION_MISMATCH,
            "SL_E_ACTIVATION_IN_PROGRESS" => ITF::SL_E_ACTIVATION_IN_PROGRESS,
            "SL_E_STORE_UPGRADE_TOKEN_REQUIRED" => ITF::SL_E_STORE_UPGRADE_TOKEN_REQUIRED,
            "SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION" => ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION,
            "SL_E_STORE_UPGRADE_TOKEN_WRONG_PID" => ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_PID,
            "SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED" => ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED,
            "SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION" => ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION,
            "SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED" => ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED,
            "SL_E_INTERNAL_ERROR" => ITF::SL_E_INTERNAL_ERROR,
            "SL_E_RIGHT_NOT_CONSUMED" => ITF::SL_E_RIGHT_NOT_CONSUMED,
            "SL_E_USE_LICENSE_NOT_INSTALLED" => ITF::SL_E_USE_LICENSE_NOT_INSTALLED,
            "SL_E_MISMATCHED_PKEY_RANGE" => ITF::SL_E_MISMATCHED_PKEY_RANGE,
            "SL_E_MISMATCHED_PID" => ITF::SL_E_MISMATCHED_PID,
            "SL_E_EXTERNAL_SIGNATURE_NOT_FOUND" => ITF::SL_E_EXTERNAL_SIGNATURE_NOT_FOUND,
            "SL_E_RAC_NOT_AVAILABLE" => ITF::SL_E_RAC_NOT_AVAILABLE,
            "SL_E_SPC_NOT_AVAILABLE" => ITF::SL_E_SPC_NOT_AVAILABLE,
            "SL_E_GRACE_TIME_EXPIRED" => ITF::SL_E_GRACE_TIME_EXPIRED,
            "SL_E_MISMATCHED_APPID" => ITF::SL_E_MISMATCHED_APPID,
            "SL_E_NO_PID_CONFIG_DATA" => ITF::SL_E_NO_PID_CONFIG_DATA,
            "SL_E_MISMATCHED_SECURITY_PROCESSOR" => ITF::SL_E_MISMATCHED_SECURITY_PROCESSOR,
            "SL_E_OUT_OF_TOLERANCE" => ITF::SL_E_OUT_OF_TOLERANCE,
            "SL_E_INVALID_PKEY" => ITF::SL_E_INVALID_PKEY,
            "SL_E_LICENSE_FILE_NOT_INSTALLED" => ITF::SL_E_LICENSE_FILE_NOT_INSTALLED,
            "SL_E_VALUE_NOT_FOUND" => ITF::SL_E_VALUE_NOT_FOUND,
            "SL_E_RIGHT_NOT_GRANTED" => ITF::SL_E_RIGHT_NOT_GRANTED,
            "SL_E_PKEY_NOT_INSTALLED" => ITF::SL_E_PKEY_NOT_INSTALLED,
            "SL_E_PRODUCT_SKU_NOT_INSTALLED" => ITF::SL_E_PRODUCT_SKU_NOT_INSTALLED,
            "SL_E_NOT_SUPPORTED" => ITF::SL_E_NOT_SUPPORTED,
            "SL_E_PUBLISHING_LICENSE_NOT_INSTALLED" => ITF::SL_E_PUBLISHING_LICENSE_NOT_INSTALLED,
            "SL_E_LICENSE_SERVER_URL_NOT_FOUND" => ITF::SL_E_LICENSE_SERVER_URL_NOT_FOUND,
            "SL_E_INVALID_EVENT_ID" => ITF::SL_E_INVALID_EVENT_ID,
            "SL_E_EVENT_NOT_REGISTERED" => ITF::SL_E_EVENT_NOT_REGISTERED,
            "SL_E_EVENT_ALREADY_REGISTERED" => ITF::SL_E_EVENT_ALREADY_REGISTERED,
            "SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE" => ITF::SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE,
            "SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED" => ITF::SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED,
            "SL_E_DATATYPE_MISMATCHED" => ITF::SL_E_DATATYPE_MISMATCHED,
            "SL_E_INVALID_LICENSE" => ITF::SL_E_INVALID_LICENSE,
            "SL_E_INVALID_PACKAGE" => ITF::SL_E_INVALID_PACKAGE,
            "SL_E_VALIDITY_TIME_EXPIRED" => ITF::SL_E_VALIDITY_TIME_EXPIRED,
            "SL_E_LICENSE_AUTHORIZATION_FAILED" => ITF::SL_E_LICENSE_AUTHORIZATION_FAILED,
            "SL_E_LICENSE_DECRYPTION_FAILED" => ITF::SL_E_LICENSE_DECRYPTION_FAILED,
            "SL_E_WINDOWS_INVALID_LICENSE_STATE" => ITF::SL_E_WINDOWS_INVALID_LICENSE_STATE,
            "SL_E_LUA_ACCESSDENIED" => ITF::SL_E_LUA_ACCESSDENIED,
            "SL_E_PROXY_KEY_NOT_FOUND" => ITF::SL_E_PROXY_KEY_NOT_FOUND,
            "SL_E_TAMPER_DETECTED" => ITF::SL_E_TAMPER_DETECTED,
            "SL_E_POLICY_CACHE_INVALID" => ITF::SL_E_POLICY_CACHE_INVALID,
            "SL_E_INVALID_RUNNING_MODE" => ITF::SL_E_INVALID_RUNNING_MODE,
            "SL_E_SLP_NOT_SIGNED" => ITF::SL_E_SLP_NOT_SIGNED,
            "SL_E_CIDIID_INVALID_DATA" => ITF::SL_E_CIDIID_INVALID_DATA,
            "SL_E_CIDIID_INVALID_VERSION" => ITF::SL_E_CIDIID_INVALID_VERSION,
            "SL_E_CIDIID_VERSION_NOT_SUPPORTED" => ITF::SL_E_CIDIID_VERSION_NOT_SUPPORTED,
            "SL_E_CIDIID_INVALID_DATA_LENGTH" => ITF::SL_E_CIDIID_INVALID_DATA_LENGTH,
            "SL_E_CIDIID_NOT_DEPOSITED" => ITF::SL_E_CIDIID_NOT_DEPOSITED,
            "SL_E_CIDIID_MISMATCHED" => ITF::SL_E_CIDIID_MISMATCHED,
            "SL_E_INVALID_BINDING_BLOB" => ITF::SL_E_INVALID_BINDING_BLOB,
            "SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED" => ITF::SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED,
            "SL_E_EUL_NOT_AVAILABLE" => ITF::SL_E_EUL_NOT_AVAILABLE,
            "SL_E_VL_NOT_WINDOWS_SLP" => ITF::SL_E_VL_NOT_WINDOWS_SLP,
            "SL_E_VL_NOT_ENOUGH_COUNT" => ITF::SL_E_VL_NOT_ENOUGH_COUNT,
            "SL_E_VL_BINDING_SERVICE_NOT_ENABLED" => ITF::SL_E_VL_BINDING_SERVICE_NOT_ENABLED,
            "SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED" => ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED,
            "SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH" => ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH,
            "SL_E_PROXY_POLICY_NOT_UPDATED" => ITF::SL_E_PROXY_POLICY_NOT_UPDATED,
            "SL_E_CIDIID_INVALID_CHECK_DIGITS" => ITF::SL_E_CIDIID_INVALID_CHECK_DIGITS,
            "SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND" => ITF::SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND,
            "SL_E_INVALID_PRODUCT_KEY" => ITF::SL_E_INVALID_PRODUCT_KEY,
            "SL_E_BLOCKED_PRODUCT_KEY" => ITF::SL_E_BLOCKED_PRODUCT_KEY,
            "SL_E_DUPLICATE_POLICY" => ITF::SL_E_DUPLICATE_POLICY,
            "SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE" => ITF::SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE,
            "SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED" => ITF::SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED,
            "SL_E_BASE_SKU_NOT_AVAILABLE" => ITF::SL_E_BASE_SKU_NOT_AVAILABLE,
            "SL_E_VL_MACHINE_NOT_BOUND" => ITF::SL_E_VL_MACHINE_NOT_BOUND,
            "SL_E_SLP_MISSING_ACPI_SLIC" => ITF::SL_E_SLP_MISSING_ACPI_SLIC,
            "SL_E_SLP_MISSING_SLP_MARKER" => ITF::SL_E_SLP_MISSING_SLP_MARKER,
            "SL_E_SLP_BAD_FORMAT" => ITF::SL_E_SLP_BAD_FORMAT,
            "SL_E_INVALID_PACKAGE_VERSION" => ITF::SL_E_INVALID_PACKAGE_VERSION,
            "SL_E_PKEY_INVALID_UPGRADE" => ITF::SL_E_PKEY_INVALID_UPGRADE,
            "SL_E_ISSUANCE_LICENSE_NOT_INSTALLED" => ITF::SL_E_ISSUANCE_LICENSE_NOT_INSTALLED,
            "SL_E_SLP_OEM_CERT_MISSING" => ITF::SL_E_SLP_OEM_CERT_MISSING,
            "SL_E_NONGENUINE_GRACE_TIME_EXPIRED" => ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED,
            "SL_E_DEPENDENT_PROPERTY_NOT_SET" => ITF::SL_E_DEPENDENT_PROPERTY_NOT_SET,
            "SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2" => ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2,
            "SL_E_MISMATCHED_PRODUCT_SKU" => ITF::SL_E_MISMATCHED_PRODUCT_SKU,
            "SL_E_OPERATION_NOT_ALLOWED" => ITF::SL_E_OPERATION_NOT_ALLOWED,
            "SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED" => ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED,
            "SL_E_VL_INVALID_TIMESTAMP" => ITF::SL_E_VL_INVALID_TIMESTAMP,
            "SL_E_PLUGIN_INVALID_MANIFEST" => ITF::SL_E_PLUGIN_INVALID_MANIFEST,
            "SL_E_APPLICATION_POLICIES_MISSING" => ITF::SL_E_APPLICATION_POLICIES_MISSING,
            "SL_E_APPLICATION_POLICIES_NOT_LOADED" => ITF::SL_E_APPLICATION_POLICIES_NOT_LOADED,
            "SL_E_VL_BINDING_SERVICE_UNAVAILABLE" => ITF::SL_E_VL_BINDING_SERVICE_UNAVAILABLE,
            "SL_E_SERVICE_STOPPING" => ITF::SL_E_SERVICE_STOPPING,
            "SL_E_PLUGIN_NOT_REGISTERED" => ITF::SL_E_PLUGIN_NOT_REGISTERED,
            "SL_E_AUTHN_WRONG_VERSION" => ITF::SL_E_AUTHN_WRONG_VERSION,
            "SL_E_AUTHN_MISMATCHED_KEY" => ITF::SL_E_AUTHN_MISMATCHED_KEY,
            "SL_E_AUTHN_CHALLENGE_NOT_SET" => ITF::SL_E_AUTHN_CHALLENGE_NOT_SET,
            "SL_E_AUTHN_CANT_VERIFY" => ITF::SL_E_AUTHN_CANT_VERIFY,
            "SL_E_SERVICE_RUNNING" => ITF::SL_E_SERVICE_RUNNING,
            "SL_E_SLP_INVALID_MARKER_VERSION" => ITF::SL_E_SLP_INVALID_MARKER_VERSION,
            "SL_E_INVALID_PRODUCT_KEY_TYPE" => ITF::SL_E_INVALID_PRODUCT_KEY_TYPE,
            "SL_E_CIDIID_MISMATCHED_PKEY" => ITF::SL_E_CIDIID_MISMATCHED_PKEY,
            "SL_E_CIDIID_NOT_BOUND" => ITF::SL_E_CIDIID_NOT_BOUND,
            "SL_E_LICENSE_NOT_BOUND" => ITF::SL_E_LICENSE_NOT_BOUND,
            "SL_E_VL_AD_AO_NOT_FOUND" => ITF::SL_E_VL_AD_AO_NOT_FOUND,
            "SL_E_VL_AD_AO_NAME_TOO_LONG" => ITF::SL_E_VL_AD_AO_NAME_TOO_LONG,
            "SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED" => ITF::SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED,
            "SL_E_NOT_GENUINE" => ITF::SL_E_NOT_GENUINE,
            "SL_E_EDITION_MISMATCHED" => ITF::SL_E_EDITION_MISMATCHED,
            "SL_E_TKA_CHALLENGE_EXPIRED" => ITF::SL_E_TKA_CHALLENGE_EXPIRED,
            "SL_E_TKA_SILENT_ACTIVATION_FAILURE" => ITF::SL_E_TKA_SILENT_ACTIVATION_FAILURE,
            "SL_E_TKA_INVALID_CERT_CHAIN" => ITF::SL_E_TKA_INVALID_CERT_CHAIN,
            "SL_E_TKA_GRANT_NOT_FOUND" => ITF::SL_E_TKA_GRANT_NOT_FOUND,
            "SL_E_TKA_CERT_NOT_FOUND" => ITF::SL_E_TKA_CERT_NOT_FOUND,
            "SL_E_TKA_INVALID_SKU_ID" => ITF::SL_E_TKA_INVALID_SKU_ID,
            "SL_E_TKA_INVALID_BLOB" => ITF::SL_E_TKA_INVALID_BLOB,
            "SL_E_TKA_TAMPERED_CERT_CHAIN" => ITF::SL_E_TKA_TAMPERED_CERT_CHAIN,
            "SL_E_TKA_CHALLENGE_MISMATCH" => ITF::SL_E_TKA_CHALLENGE_MISMATCH,
            "SL_E_TKA_INVALID_CERTIFICATE" => ITF::SL_E_TKA_INVALID_CERTIFICATE,
            "SL_E_TKA_INVALID_SMARTCARD" => ITF::SL_E_TKA_INVALID_SMARTCARD,
            "SL_E_TKA_FAILED_GRANT_PARSING" => ITF::SL_E_TKA_FAILED_GRANT_PARSING,
            "SL_E_TKA_INVALID_THUMBPRINT" => ITF::SL_E_TKA_INVALID_THUMBPRINT,
            "SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND" => ITF::SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND,
            "SL_E_TKA_CRITERIA_MISMATCH" => ITF::SL_E_TKA_CRITERIA_MISMATCH,
            "SL_E_TKA_TPID_MISMATCH" => ITF::SL_E_TKA_TPID_MISMATCH,
            "SL_E_TKA_SOFT_CERT_DISALLOWED" => ITF::SL_E_TKA_SOFT_CERT_DISALLOWED,
            "SL_E_TKA_SOFT_CERT_INVALID" => ITF::SL_E_TKA_SOFT_CERT_INVALID,
            "SL_E_TKA_CERT_CNG_NOT_AVAILABLE" => ITF::SL_E_TKA_CERT_CNG_NOT_AVAILABLE,
            "E_RM_UNKNOWN_ERROR" => ITF::E_RM_UNKNOWN_ERROR,
            "SL_E_VALIDITY_PERIOD_EXPIRED" => ITF::SL_E_VALIDITY_PERIOD_EXPIRED,
            "SL_E_IA_THROTTLE_LIMIT_EXCEEDED" => ITF::SL_E_IA_THROTTLE_LIMIT_EXCEEDED,
            "SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM" => ITF::SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM,
            "SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED" => ITF::SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED,
            "SL_E_IA_ID_MISMATCH" => ITF::SL_E_IA_ID_MISMATCH,
            "SL_E_IA_MACHINE_NOT_BOUND" => ITF::SL_E_IA_MACHINE_NOT_BOUND,
            "SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION" => ITF::SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION,
        }
    }
    pub fn from_code(code: u32) -> ITF {
        return match code {
            0x00040000 => ITF::OLE_S_USEREG,
            0x00040001 => ITF::OLE_S_STATIC,
            0x00040001 => ITF::MS_S_PENDING,
            0x00040002 => ITF::OLE_S_MAC_CLIPFORMAT,
            0x00040002 => ITF::MS_S_NOUPDATE,
            0x00040003 => ITF::MS_S_ENDOFSTREAM,
            0x000400FF => ITF::OLE_S_LAST,
            0x00040100 => ITF::DRAGDROP_S_DROP,
            0x00040101 => ITF::DRAGDROP_S_CANCEL,
            0x00040102 => ITF::DRAGDROP_S_USEDEFAULTCURSORS,
            0x00040103 => ITF::VFW_S_NO_MORE_ITEMS,
            0x00040130 => ITF::DATA_S_SAMEFORMATETC,
            0x00040140 => ITF::VIEW_S_ALREADY_FROZEN,
            0x00040170 => ITF::CACHE_S_FORMATETC_NOTSUPPORTED,
            0x00040171 => ITF::CACHE_S_SAMECACHE,
            0x00040172 => ITF::CACHE_S_SOMECACHES_NOTUPDATED,
            0x00040180 => ITF::OLEOBJ_S_INVALIDVERB,
            0x00040181 => ITF::OLEOBJ_S_CANNOT_DOVERB_NOW,
            0x00040182 => ITF::OLEOBJ_S_INVALIDHWND,
            0x000401A0 => ITF::INPLACE_S_TRUNCATED,
            0x000401C0 => ITF::CONVERT10_S_NO_PRESENTATION,
            0x000401E2 => ITF::MK_S_REDUCED_TO_SELF,
            0x000401E4 => ITF::MK_S_ME,
            0x000401E5 => ITF::MK_S_HIM,
            0x000401E6 => ITF::MK_S_US,
            0x000401E7 => ITF::MK_S_MONIKERALREADYREGISTERED,
            0x000401E8 => ITF::MK_S_ASYNCHRONOUS,
            0x00040200 => ITF::EVENT_S_SOME_SUBSCRIBERS_FAILED,
            0x00040200 => ITF::IMAPI_S_PROPERTIESIGNORED,
            0x00040200 => ITF::MPEG2_S_MORE_DATA_AVAILABLE,
            0x00040201 => ITF::IMAPI_S_BUFFER_TO_SMALL,
            0x00040201 => ITF::MPEG2_S_NO_MORE_DATA_AVAILABLE,
            0x00040202 => ITF::EVENT_S_NOSUBSCRIBERS,
            0x00040202 => ITF::MPEG2_S_SG_INFO_FOUND,
            0x00040203 => ITF::_MAPI_W_NO_SERVICE,
            0x00040203 => ITF::MPEG2_S_SG_INFO_NOT_FOUND,
            0x00040204 => ITF::MPEG2_S_MPE_INFO_FOUND,
            0x00040205 => ITF::MPEG2_S_MPE_INFO_NOT_FOUND,
            0x00040206 => ITF::MPEG2_S_NEW_MODULE_VERSION,
            0x0004022D => ITF::VFW_S_DUPLICATE_NAME,
            0x00040237 => ITF::VFW_S_STATE_INTERMEDIATE,
            0x00040242 => ITF::VFW_S_PARTIAL_RENDER,
            0x00040245 => ITF::VFW_S_SOME_DATA_IGNORED,
            0x00040246 => ITF::VFW_S_CONNECTIONS_DEFERRED,
            0x00040250 => ITF::VFW_S_RESOURCE_NOT_NEEDED,
            0x00040252 => ITF::TPC_S_TRUNCATED,
            0x00040253 => ITF::TPC_S_INTERRUPTED,
            0x00040254 => ITF::TPC_S_NO_DATA_TO_PROCESS,
            0x00040254 => ITF::VFW_S_MEDIA_TYPE_IGNORED,
            0x00040257 => ITF::VFW_S_VIDEO_NOT_RENDERED,
            0x00040258 => ITF::VFW_S_AUDIO_NOT_RENDERED,
            0x0004025A => ITF::VFW_S_RPZA,
            0x00040260 => ITF::VFW_S_ESTIMATED,
            0x00040263 => ITF::VFW_S_RESERVED,
            0x00040267 => ITF::VFW_S_STREAM_OFF,
            0x00040268 => ITF::VFW_S_CANT_CUE,
            0x0004027E => ITF::VFW_S_NOPREVIEWPIN,
            0x00040280 => ITF::VFW_S_DVD_NON_ONE_SEQUENTIAL,
            0x0004028C => ITF::VFW_S_DVD_CHANNEL_CONTENTS_NOT_AVAILABLE,
            0x0004028D => ITF::VFW_S_DVD_NOT_ACCURATE,
            0x00040300 => ITF::TF_S_ASYNC,
            0x00040300 => ITF::TS_S_ASYNC,
            0x00040607 => ITF::CM_S_NODATASERVERS,
            0x00040704 => ITF::QRY_S_NOROWSFOUND,
            0x00040712 => ITF::QRY_S_TERMIGNORED,
            0x00040716 => ITF::QRY_S_INEXACTRESULTS,
            0x0004092F => ITF::IDS_MON_DEFAULT_ERROR,
            0x00040930 => ITF::IDS_MON_ILLEGAL_PASSTHROUGH,
            0x00040931 => ITF::IDS_MON_PARSE_ERR_1_PARAM,
            0x00040932 => ITF::IDS_MON_PARSE_ERR_2_PARAM,
            0x00040933 => ITF::IDS_MON_SEMI_COLON,
            0x00040934 => ITF::IDS_MON_ORDINAL_OUT_OF_RANGE,
            0x00040935 => ITF::IDS_MON_VIEW_NOT_DEFINED,
            0x00040936 => ITF::IDS_MON_COLUMN_NOT_DEFINED,
            0x00040937 => ITF::IDS_MON_BUILTIN_VIEW,
            0x00040938 => ITF::IDS_MON_OUT_OF_MEMORY,
            0x00040939 => ITF::IDS_MON_SELECT_STAR,
            0x0004093A => ITF::IDS_MON_OR_NOT,
            0x0004093B => ITF::IDS_MON_CANNOT_CONVERT,
            0x0004093C => ITF::IDS_MON_OUT_OF_RANGE,
            0x0004093D => ITF::IDS_MON_RELATIVE_INTERVAL,
            0x0004093E => ITF::IDS_MON_NOT_COLUMN_OF_VIEW,
            0x0004093F => ITF::IDS_MON_BUILTIN_PROPERTY,
            0x00040940 => ITF::IDS_MON_WEIGHT_OUT_OF_RANGE,
            0x00040941 => ITF::IDS_MON_MATCH_STRING,
            0x00040942 => ITF::IDS_MON_PROPERTY_NAME_IN_VIEW,
            0x00040943 => ITF::IDS_MON_VIEW_ALREADY_DEFINED,
            0x00040944 => ITF::IDS_MON_INVALID_CATALOG,
            0x00040945 => ITF::IDS_MON_INVALIDSELECT_COALESCE,
            0x00040946 => ITF::IDS_MON_CANNOT_CAST,
            0x00040947 => ITF::IDS_MON_DATE_OUT_OF_RANGE,
            0x00040948 => ITF::IDS_MON_INVALID_IN_GROUP_CLAUSE,
            0x00040D1C => ITF::GTHR_S_STATUS_CHANGE_IGNORED,
            0x00040D1D => ITF::GTHR_S_STATUS_END_CRAWL,
            0x00040D1E => ITF::GTHR_S_STATUS_RESET,
            0x00040D1F => ITF::GTHR_S_STATUS_THROTTLE,
            0x00040D20 => ITF::GTHR_S_STATUS_RESUME,
            0x00040D21 => ITF::GTHR_S_STATUS_PAUSE,
            0x00040D24 => ITF::GTHR_S_END_STD_CHUNKS,
            0x00040D2B => ITF::GTHR_S_NO_CRAWL_SEEDS,
            0x00040D30 => ITF::GTHR_S_CANNOT_FILTER,
            0x00040D33 => ITF::GTHR_S_STATUS_STOP,
            0x00040D36 => ITF::GTHR_S_STATUS_START,
            0x00040D56 => ITF::GTHR_S_CONFIG_HAS_ACCOUNTS,
            0x00040D67 => ITF::GTHR_S_PROB_NOT_MODIFIED,
            0x00040D68 => ITF::GTHR_S_CRAWL_SCHEDULED,
            0x00040D69 => ITF::GTHR_S_TRANSACTION_IGNORED,
            0x00040D6A => ITF::GTHR_S_START_FILTER_FROM_PROTOCOL,
            0x00040D6C => ITF::GTHR_S_BAD_FILE_LINK,
            0x00040D6E => ITF::GTHR_S_NOT_ALL_PARTS,
            0x00040D70 => ITF::GTHR_S_END_PROCESS_LOOP_NOTIFY_QUEUE,
            0x00040D71 => ITF::GTHR_S_START_FILTER_FROM_BODY,
            0x00040D78 => ITF::GTHR_S_MODIFIED_PARTS,
            0x00040D83 => ITF::GTHR_S_CRAWL_FULL,
            0x00040D84 => ITF::GTHR_S_CRAWL_INCREMENTAL,
            0x00040D85 => ITF::GTHR_S_CRAWL_ADAPTIVE,
            0x00040D90 => ITF::GTHR_S_NO_INDEX,
            0x00040D92 => ITF::GTHR_S_PAUSE_REASON_EXTERNAL,
            0x00040D93 => ITF::GTHR_S_PAUSE_REASON_UPGRADING,
            0x00040D94 => ITF::GTHR_S_PAUSE_REASON_BACKOFF,
            0x00040D9A => ITF::GTHR_S_OFFICE_CHILD,
            0x00040DA6 => ITF::GTHR_S_CANNOT_WORDBREAK,
            0x00040DA7 => ITF::GTHR_S_USE_MIME_FILTER,
            0x00040DB3 => ITF::GTHR_S_PAUSE_REASON_PROFILE_IMPORT,
            0x00040EC0 => ITF::DB_S_ROWLIMITEXCEEDED,
            0x00040EC1 => ITF::DB_S_COLUMNTYPEMISMATCH,
            0x00040EC2 => ITF::DB_S_TYPEINFOOVERRIDDEN,
            0x00040EC3 => ITF::DB_S_BOOKMARKSKIPPED,
            0x00040EC5 => ITF::DB_S_NONEXTROWSET,
            0x00040EC6 => ITF::DB_S_ENDOFROWSET,
            0x00040EC7 => ITF::DB_S_COMMANDREEXECUTED,
            0x00040EC8 => ITF::DB_S_BUFFERFULL,
            0x00040EC9 => ITF::DB_S_NORESULT,
            0x00040ECA => ITF::DB_S_CANTRELEASE,
            0x00040ECB => ITF::DB_S_GOALCHANGED,
            0x00040ECC => ITF::DB_S_UNWANTEDOPERATION,
            0x00040ECD => ITF::DB_S_DIALECTIGNORED,
            0x00040ECE => ITF::DB_S_UNWANTEDPHASE,
            0x00040ECF => ITF::DB_S_UNWANTEDREASON,
            0x00040ED0 => ITF::DB_S_ASYNCHRONOUS,
            0x00040ED1 => ITF::DB_S_COLUMNSCHANGED,
            0x00040ED2 => ITF::DB_S_ERRORSRETURNED,
            0x00040ED3 => ITF::DB_S_BADROWHANDLE,
            0x00040ED4 => ITF::DB_S_DELETEDROW,
            0x00040ED5 => ITF::DB_S_TOOMANYCHANGES,
            0x00040ED6 => ITF::DB_S_STOPLIMITREACHED,
            0x00040ED7 => ITF::DB_S_NOTSINGLETON,
            0x00040ED8 => ITF::DB_S_LOCKUPGRADED,
            0x00040ED9 => ITF::DB_S_PROPERTIESCHANGED,
            0x00040EDA => ITF::DB_S_ERRORSOCCURRED,
            0x00040EDB => ITF::DB_S_PARAMUNAVAILABLE,
            0x00040EDC => ITF::DB_S_MULTIPLECHANGES,
            0x00040EDD => ITF::DB_S_NOROWSPECIFICCOLUMNS,
            0x00041000 => ITF::REC_S_IDIDTHEUPDATES,
            0x00041001 => ITF::REC_S_NOTCOMPLETE,
            0x00041001 => ITF::SEO_S_MOREDATA,
            0x00041002 => ITF::REC_S_NOTCOMPLETEBUTPROPAGATE,
            0x00041114 => ITF::IDX_S_NO_BUILD_IN_PROGRESS,
            0x00041115 => ITF::IDX_S_SEARCH_SERVER_ALREADY_EXISTS,
            0x00041116 => ITF::IDX_S_SEARCH_SERVER_DOES_NOT_EXIST,
            0x0004111D => ITF::IDX_S_DSS_NOT_AVAILABLE,
            0x00041180 => ITF::JPS_S_DUPLICATE_DOC_DETECTED,
            0x00041203 => ITF::PRTH_S_NOT_MODIFIED,
            0x00041209 => ITF::PRTH_S_MAX_GROWTH,
            0x0004120C => ITF::PRTH_S_MAX_DOWNLOAD,
            0x00041210 => ITF::PRTH_S_ACL_IS_READ_EVERYONE,
            0x00041214 => ITF::PRTH_S_USE_ROSEBUD,
            0x0004121B => ITF::PRTH_S_NOT_ALL_PARTS,
            0x00041225 => ITF::PRTH_S_TRY_IMPERSONATING,
            0x00041300 => ITF::SCHED_S_TASK_READY,
            0x00041301 => ITF::SCHED_S_TASK_RUNNING,
            0x00041302 => ITF::SCHED_S_TASK_DISABLED,
            0x00041303 => ITF::SCHED_S_TASK_HAS_NOT_RUN,
            0x00041304 => ITF::SCHED_S_TASK_NO_MORE_RUNS,
            0x00041305 => ITF::SCHED_S_TASK_NOT_SCHEDULED,
            0x00041306 => ITF::SCHED_S_TASK_TERMINATED,
            0x00041307 => ITF::SCHED_S_TASK_NO_VALID_TRIGGERS,
            0x00041308 => ITF::SCHED_S_EVENT_TRIGGER,
            0x0004131B => ITF::SCHED_S_SOME_TRIGGERS_FAILED,
            0x0004131C => ITF::SCHED_S_BATCH_LOGON_PROBLEM,
            0x00041325 => ITF::SCHED_S_TASK_QUEUED,
            0x00041679 => ITF::QPLIST_S_DUPLICATE,
            0x00041680 => ITF::FDAEMON_W_WORDLISTFULL,
            0x00041685 => ITF::FDAEMON_W_EMPTYWORDLIST,
            0x000416A0 => ITF::SEARCH_S_NOMOREHITS,
            0x00041704 => ITF::FILTER_W_MONIKER_CLIPPED,
            0x00041709 => ITF::FILTER_S_LAST_TEXT,
            0x0004170A => ITF::FILTER_S_LAST_VALUES,
            0x00041731 => ITF::FILTER_S_PARTIAL_CONTENTSCAN_IMMEDIATE,
            0x00041732 => ITF::FILTER_S_FULL_CONTENTSCAN_IMMEDIATE,
            0x00041733 => ITF::FILTER_S_CONTENTSCAN_DELAYED,
            0x00041735 => ITF::FILTER_S_DISK_FULL,
            0x0004173A => ITF::FILTER_S_NO_PROPSETS,
            0x0004173C => ITF::FILTER_S_NO_SECURITY_DESCRIPTOR,
            0x00041781 => ITF::LANGUAGE_S_LARGE_WORD,
            0x00041793 => ITF::PSINK_S_LARGE_WORD,
            0x0004180E => ITF::CI_S_WORKID_DELETED,
            0x00041814 => ITF::CI_S_END_OF_ENUMERATION,
            0x00041825 => ITF::CI_S_NO_DOCSTORE,
            0x00041826 => ITF::CI_S_CAT_STOPPED,
            0x00041829 => ITF::CI_S_NEW_AUXMETADATA,
            0x0004182B => ITF::CI_S_CLIENT_REQUESTED_ABORT,
            0x0004182C => ITF::CI_S_RETRY_DOCUMENT,
            0x00041830 => ITF::CI_S_CATALOG_RESET,
            0x00041902 => ITF::NLADMIN_S_NOT_ALL_BUILD_CATALOGS_INITIALIZED,
            0x00042309 => ITF::VSS_S_ASYNC_PENDING,
            0x0004230A => ITF::VSS_S_ASYNC_FINISHED,
            0x0004230B => ITF::VSS_S_ASYNC_CANCELLED,
            0x00042321 => ITF::VSS_S_SOME_SNAPSHOTS_NOT_IMPORTED,
            0x0004241A => ITF::VDS_S_DISK_PARTIALLY_CLEANED,
            0x00042421 => ITF::VDS_S_PROVIDER_ERROR_LOADING_CACHE,
            0x00042434 => ITF::VDS_S_UPDATE_BOOTFILE_FAILED,
            0x00042436 => ITF::VDS_S_BOOT_PARTITION_NUMBER_CHANGE,
            0x00042443 => ITF::VDS_S_VOLUME_COMPRESS_FAILED,
            0x0004244D => ITF::VDS_S_IN_PROGRESS,
            0x0004245A => ITF::VDS_S_IA64_BOOT_MIRRORED_TO_MBR,
            0x0004245B => ITF::VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES,
            0x00042465 => ITF::VDS_S_EXTEND_FILE_SYSTEM_FAILED,
            0x00042467 => ITF::VDS_S_MBR_BOOT_MIRRORED_TO_GPT,
            0x00042508 => ITF::VDS_S_DISK_IS_MISSING,
            0x0004250A => ITF::VDS_S_NONCONFORMANT_PARTITION_INFO,
            0x0004250E => ITF::VDS_S_SYSTEM_PARTITION,
            0x00042517 => ITF::VDS_S_NO_NOTIFICATION,
            0x00042518 => ITF::VDS_S_DEFAULT_PLEX_MEMBER_IDS,
            0x00042577 => ITF::VDS_S_DISMOUNT_FAILED,
            0x00042578 => ITF::VDS_S_REMOUNT_FAILED,
            0x0004257A => ITF::VDS_S_RESYNC_NOTIFICATION_TASK_FAILED,
            0x00042581 => ITF::VDS_S_VSS_FLUSH_AND_HOLD_WRITES,
            0x00042582 => ITF::VDS_S_VSS_RELEASE_WRITES,
            0x00042583 => ITF::VDS_S_FS_LOCK,
            0x0004258B => ITF::VDS_S_PLEX_NOT_LOADED_TO_CACHE,
            0x0004258E => ITF::VDS_S_WINPE_BOOTENTRY,
            0x00042602 => ITF::NOTESPH_S_IGNORE_ID,
            0x00042610 => ITF::NOTESPH_S_LISTKNOWNFIELDS,
            0x00042700 => ITF::VDS_S_NAME_TRUNCATED,
            0x00042702 => ITF::VDS_S_STATUSES_INCOMPLETELY_SET,
            0x00042714 => ITF::VDS_S_ALREADY_EXISTS,
            0x00042715 => ITF::VDS_S_PROPERTIES_INCOMPLETE,
            0x00042800 => ITF::VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED,
            0x00042801 => ITF::VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED,
            0x00042802 => ITF::VDS_S_ISCSI_LOGIN_ALREAD_EXISTS,
            0x00042808 => ITF::VDS_S_DISK_MOUNT_FAILED,
            0x00042809 => ITF::VDS_S_DISK_DISMOUNT_FAILED,
            0x00043501 => ITF::REXSPH_S_REDIRECTED,
            0x00043619 => ITF::FTE_S_RESOURCES_STARTING_TO_GET_LOW,
            0x00043622 => ITF::FTE_S_BEYOND_QUOTA,
            0x00043625 => ITF::FTE_S_REDUNDANT,
            0x0004362B => ITF::FTE_S_STATUS_CHANGE_REQUEST,
            0x0004362E => ITF::FTE_S_RESUME,
            0x0004363C => ITF::FTE_S_PROPERTY_STORE_END_OF_ENUMERATION,
            0x00043646 => ITF::FTE_S_READONLY_CATALOG,
            0x00043657 => ITF::FTE_S_TRY_TO_FLUSH,
            0x00043658 => ITF::FTE_S_CATALOG_BLOB_MISMATCHED,
            0x00043659 => ITF::FTE_S_PROPERTY_RESET,
            0x00044244 => ITF::VDS_S_ACCESS_PATH_NOT_DELETED,
            0x00045005 => ITF::SP_END_OF_STREAM,
            0x0004500B => ITF::SP_INSUFFICIENTDATA,
            0x00045010 => ITF::SP_AUDIO_PAUSED,
            0x00045015 => ITF::SP_AUDIO_CONVERSION_ENABLED,
            0x00045016 => ITF::SP_NO_HYPOTHESIS_AVAILABLE,
            0x00045018 => ITF::SP_ALREADY_IN_LEX,
            0x0004501A => ITF::SP_LEX_NOTHING_TO_SYNC,
            0x00045026 => ITF::SP_REQUEST_PENDING,
            0x0004502C => ITF::SP_NO_PARSE_FOUND,
            0x00045034 => ITF::SP_UNSUPPORTED_ON_STREAM_INPUT,
            0x00045037 => ITF::SP_WORD_EXISTS_WITHOUT_PRONUNCIATION,
            0x0004504E => ITF::SP_RECOGNIZER_INACTIVE,
            0x00045053 => ITF::SP_PARTIAL_PARSE_FOUND,
            0x00045055 => ITF::SP_NO_RULE_ACTIVE,
            0x00045057 => ITF::SP_STREAM_UNINITIALIZED,
            0x00045065 => ITF::SP_AUDIO_STOPPED,
            0x00045074 => ITF::SP_COMPLETE_BUT_EXTENDABLE,
            0x0004507B => ITF::SP_NO_RULES_TO_ACTIVATE,
            0x0004507C => ITF::SP_NO_WORDENTRY_NOTIFICATION,
            0x0004507F => ITF::S_LIMIT_REACHED,
            0x00045080 => ITF::S_NOTSUPPORTED,
            0x00045304 => ITF::FSRM_S_PARTIAL_BATCH,
            0x00045305 => ITF::FSRM_S_PARTIAL_CLASSIFICATION,
            0x00045306 => ITF::FSRM_S_CLASSIFICATION_SCAN_FAILURES,
            0x0004531B => ITF::FSRM_E_AUTO_QUOTA,
            0x0004A020 => ITF::NETCFG_S_REBOOT,
            0x0004A022 => ITF::NETCFG_S_DISABLE_QUERY,
            0x0004A023 => ITF::NETCFG_S_STILL_REFERENCED,
            0x0004A024 => ITF::NETCFG_S_CAUSED_SETUP_CHANGE,
            0x0004A025 => ITF::NETCFG_S_COMMIT_NOW,
            0x0004D000 => ITF::XACT_S_ASYNC,
            0x0004D001 => ITF::XACT_S_DEFECT,
            0x0004D002 => ITF::XACT_S_READONLY,
            0x0004D003 => ITF::XACT_S_SOMENORETAIN,
            0x0004D004 => ITF::XACT_S_OKINFORM,
            0x0004D005 => ITF::XACT_S_MADECHANGESCONTENT,
            0x0004D006 => ITF::XACT_S_MADECHANGESINFORM,
            0x0004D007 => ITF::XACT_S_ALLNORETAIN,
            0x0004D008 => ITF::XACT_S_ABORTING,
            0x0004D009 => ITF::XACT_S_SINGLEPHASE,
            0x0004D00A => ITF::XACT_S_LOCALLY_OK,
            0x0004D010 => ITF::XACT_S_LASTRESOURCEMANAGER,
            0x0004DC01 => ITF::S_DEVCAP_OUTPUT_FULL_REPLACEMENT,
            0x40040024 => ITF::IO_FILE_QUOTA_THRESHOLD,
            0x40040025 => ITF::IO_FILE_QUOTA_LIMIT,
            0x40040026 => ITF::IO_FILE_QUOTA_STARTED,
            0x40040027 => ITF::IO_FILE_QUOTA_SUCCEEDED,
            0x40040077 => ITF::IO_INFO_THROTTLE_COMPLETE,
            0x40040085 => ITF::IO_CDROM_EXCLUSIVE_LOCK,
            0x40041000 => ITF::MSG_TEST_MESSAGE,
            0x4004D30F => ITF::SL_REMAPPING_SP_PUB_TRUSTED_TIME_OK,
            0x4004D601 => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_IDENTICAL,
            0x4004D602 => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_POLICY_CHANGED,
            0x4004F00C => ITF::SL_I_OOB_GRACE_PERIOD,
            0x4004F00D => ITF::SL_I_OOT_GRACE_PERIOD,
            0x4004F040 => ITF::SL_E_VL_INFO_PRODUCT_USER_RIGHT,
            0x4004F065 => ITF::SL_I_NONGENUINE_GRACE_PERIOD,
            0x4004F068 => ITF::SL_I_NONGENUINE_GRACE_PERIOD_2,
            0x4004FC04 => ITF::SL_I_TIMEBASED_VALIDITY_PERIOD,
            0x4004FC05 => ITF::SL_I_PERPETUAL_OOB_GRACE_PERIOD,
            0x4004FC06 => ITF::SL_I_TIMEBASED_EXTENDED_GRACE_PERIOD,
            0x80040000 => ITF::OLE_E_OLEVERB,
            0x80040001 => ITF::OLE_E_ADVF,
            0x80040001 => ITF::E_NOTVALIDFORANIMATEDIMAGE,
            0x80040002 => ITF::OLE_E_ENUM_NOMORE,
            0x80040003 => ITF::OLE_E_ADVISENOTSUPPORTED,
            0x80040003 => ITF::TAPI_E_NOTSUPPORTED,
            0x80040004 => ITF::OLE_E_NOCONNECTION,
            0x80040004 => ITF::TAPI_E_INVALIDMEDIATYPE,
            0x80040005 => ITF::OLE_E_NOTRUNNING,
            0x80040005 => ITF::TAPI_E_OPERATIONFAILED,
            0x80040006 => ITF::OLE_E_NOCACHE,
            0x80040006 => ITF::TAPI_E_ALLOCATED,
            0x80040007 => ITF::OLE_E_BLANK,
            0x80040007 => ITF::TAPI_E_CALLUNAVAIL,
            0x80040008 => ITF::OLE_E_CLASSDIFF,
            0x80040008 => ITF::TAPI_E_COMPLETIONOVERRUN,
            0x80040009 => ITF::OLE_E_CANT_GETMONIKER,
            0x80040009 => ITF::TAPI_E_CONFERENCEFULL,
            0x8004000A => ITF::OLE_E_CANT_BINDTOSOURCE,
            0x8004000A => ITF::TAPI_E_DIALMODIFIERNOTSUPPORTED,
            0x8004000B => ITF::OLE_E_STATIC,
            0x8004000B => ITF::TAPI_E_INUSE,
            0x8004000C => ITF::OLE_E_PROMPTSAVECANCELLED,
            0x8004000C => ITF::TAPI_E_INVALADDRESS,
            0x8004000D => ITF::OLE_E_INVALIDRECT,
            0x8004000D => ITF::TAPI_E_INVALADDRESSSTATE,
            0x8004000E => ITF::OLE_E_WRONGCOMPOBJ,
            0x8004000E => ITF::TAPI_E_INVALCALLPARAMS,
            0x8004000F => ITF::OLE_E_INVALIDHWND,
            0x8004000F => ITF::TAPI_E_INVALCALLPRIVILEGE,
            0x80040010 => ITF::OLE_E_NOT_INPLACEACTIVE,
            0x80040010 => ITF::TAPI_E_INVALCALLSTATE,
            0x80040011 => ITF::OLE_E_CANTCONVERT,
            0x80040011 => ITF::TAPI_E_INVALCARD,
            0x80040012 => ITF::OLE_E_NOSTORAGE,
            0x80040012 => ITF::TAPI_E_INVALCOMPLETIONID,
            0x80040013 => ITF::TAPI_E_INVALCOUNTRYCODE,
            0x80040014 => ITF::TAPI_E_INVALDEVICECLASS,
            0x80040015 => ITF::TAPI_E_INVALDIALPARAMS,
            0x80040016 => ITF::TAPI_E_INVALDIGITS,
            0x80040017 => ITF::TAPI_E_INVALGROUPID,
            0x80040018 => ITF::TAPI_E_INVALLOCATION,
            0x80040019 => ITF::TAPI_E_INVALMESSAGEID,
            0x8004001A => ITF::TAPI_E_INVALPARKID,
            0x8004001A => ITF::IO_WRN_BAD_FIRMWARE,
            0x8004001B => ITF::TAPI_E_INVALRATE,
            0x8004001C => ITF::TAPI_E_INVALTIMEOUT,
            0x8004001D => ITF::TAPI_E_INVALTONE,
            0x8004001E => ITF::TAPI_E_INVALLIST,
            0x8004001F => ITF::TAPI_E_INVALMODE,
            0x80040020 => ITF::TAPI_E_NOCONFERENCE,
            0x80040020 => ITF::IO_WRITE_CACHE_ENABLED,
            0x80040021 => ITF::TAPI_E_NODEVICE,
            0x80040021 => ITF::IO_RECOVERED_VIA_ECC,
            0x80040022 => ITF::TAPI_E_NOREQUEST,
            0x80040022 => ITF::IO_WRITE_CACHE_DISABLED,
            0x80040023 => ITF::TAPI_E_NOTOWNER,
            0x80040024 => ITF::TAPI_E_NOTREGISTERED,
            0x80040025 => ITF::TAPI_E_REQUESTOVERRUN,
            0x80040026 => ITF::TAPI_E_TARGETNOTFOUND,
            0x80040027 => ITF::TAPI_E_TARGETSELF,
            0x80040028 => ITF::TAPI_E_USERUSERINFOTOOBIG,
            0x80040028 => ITF::IO_FILE_QUOTA_FAILED,
            0x80040029 => ITF::TAPI_E_REINIT,
            0x8004002A => ITF::TAPI_E_ADDRESSBLOCKED,
            0x8004002B => ITF::TAPI_E_BILLINGREJECTED,
            0x8004002C => ITF::TAPI_E_INVALFEATURE,
            0x8004002D => ITF::TAPI_E_INVALBUTTONLAMPID,
            0x8004002E => ITF::TAPI_E_INVALBUTTONSTATE,
            0x8004002F => ITF::TAPI_E_INVALDATAID,
            0x80040030 => ITF::TAPI_E_INVALHOOKSWITCHDEV,
            0x80040031 => ITF::TAPI_E_DROPPED,
            0x80040032 => ITF::TAPI_E_NOREQUESTRECIPIENT,
            0x80040032 => ITF::IO_LOST_DELAYED_WRITE,
            0x80040033 => ITF::TAPI_E_REQUESTQUEUEFULL,
            0x80040033 => ITF::IO_WARNING_PAGING_FAILURE,
            0x80040034 => ITF::TAPI_E_DESTBUSY,
            0x80040034 => ITF::IO_WRN_FAILURE_PREDICTED,
            0x80040035 => ITF::TAPI_E_DESTNOANSWER,
            0x80040035 => ITF::IO_WARNING_INTERRUPT_STILL_PENDING,
            0x80040036 => ITF::TAPI_E_DESTUNAVAIL,
            0x80040036 => ITF::IO_DRIVER_CANCEL_TIMEOUT,
            0x80040037 => ITF::TAPI_E_REQUESTFAILED,
            0x80040038 => ITF::TAPI_E_REQUESTCANCELLED,
            0x80040038 => ITF::IO_WARNING_ALLOCATION_FAILED,
            0x80040039 => ITF::TAPI_E_INVALPRIVILEGE,
            0x80040039 => ITF::IO_WARNING_LOG_FLUSH_FAILED,
            0x8004003A => ITF::TAPI_E_INVALIDDIRECTION,
            0x8004003A => ITF::IO_WARNING_DUPLICATE_SIGNATURE,
            0x8004003B => ITF::TAPI_E_INVALIDTERMINAL,
            0x8004003B => ITF::IO_WARNING_DUPLICATE_PATH,
            0x8004003C => ITF::TAPI_E_INVALIDTERMINALCLASS,
            0x8004003D => ITF::TAPI_E_NODRIVER,
            0x8004003E => ITF::TAPI_E_MAXSTREAMS,
            0x8004003F => ITF::TAPI_E_NOTERMINALSELECTED,
            0x80040040 => ITF::TAPI_E_TERMINALINUSE,
            0x80040041 => ITF::TAPI_E_NOTSTOPPED,
            0x80040042 => ITF::TAPI_E_MAXTERMINALS,
            0x80040043 => ITF::TAPI_E_INVALIDSTREAM,
            0x80040044 => ITF::TAPI_E_TIMEOUT,
            0x80040045 => ITF::TAPI_E_CALLCENTER_GROUP_REMOVED,
            0x80040046 => ITF::TAPI_E_CALLCENTER_QUEUE_REMOVED,
            0x80040047 => ITF::TAPI_E_CALLCENTER_NO_AGENT_ID,
            0x80040048 => ITF::TAPI_E_CALLCENTER_INVALAGENTID,
            0x80040049 => ITF::TAPI_E_CALLCENTER_INVALAGENTGROUP,
            0x8004004A => ITF::TAPI_E_CALLCENTER_INVALPASSWORD,
            0x8004004B => ITF::TAPI_E_CALLCENTER_INVALAGENTSTATE,
            0x8004004C => ITF::TAPI_E_CALLCENTER_INVALAGENTACTIVITY,
            0x8004004D => ITF::TAPI_E_REGISTRY_SETTING_CORRUPT,
            0x8004004E => ITF::TAPI_E_TERMINAL_PEER,
            0x8004004F => ITF::TAPI_E_PEER_NOT_SET,
            0x80040050 => ITF::TAPI_E_NOEVENT,
            0x80040051 => ITF::TAPI_E_INVALADDRESSTYPE,
            0x80040052 => ITF::TAPI_E_RESOURCEUNAVAIL,
            0x80040053 => ITF::TAPI_E_PHONENOTOPEN,
            0x80040054 => ITF::TAPI_E_CALLNOTSELECTED,
            0x80040055 => ITF::TAPI_E_WRONGEVENT,
            0x80040056 => ITF::TAPI_E_NOFORMAT,
            0x80040057 => ITF::TAPI_E_INVALIDSTREAMSTATE,
            0x80040058 => ITF::TAPI_E_WRONG_STATE,
            0x80040059 => ITF::TAPI_E_NOT_INITIALIZED,
            0x8004005A => ITF::TAPI_E_SERVICE_NOT_RUNNING,
            0x80040064 => ITF::DV_E_FORMATETC,
            0x80040065 => ITF::DV_E_DVTARGETDEVICE,
            0x80040066 => ITF::DV_E_STGMEDIUM,
            0x80040067 => ITF::DV_E_STATDATA,
            0x80040068 => ITF::DV_E_LINDEX,
            0x80040069 => ITF::DV_E_TYMED,
            0x8004006A => ITF::DV_E_CLIPFORMAT,
            0x8004006B => ITF::DV_E_DVASPECT,
            0x8004006C => ITF::DV_E_DVTARGETDEVICE_SIZE,
            0x8004006D => ITF::DV_E_NOIVIEWOBJECT,
            0x80040076 => ITF::IO_WARNING_BUS_RESET,
            0x80040081 => ITF::IO_WARNING_RESET,
            0x80040084 => ITF::IO_WARNING_WRITE_FUA_PROBLEM,
            0x8004008B => ITF::IO_LOST_DELAYED_WRITE_NETWORK_DISCONNECTED,
            0x8004008C => ITF::IO_LOST_DELAYED_WRITE_NETWORK_SERVER_ERROR,
            0x8004008D => ITF::IO_LOST_DELAYED_WRITE_NETWORK_LOCAL_DISK_ERROR,
            0x8004008E => ITF::IO_WARNING_VOLUME_LOST_DISK_EXTENT,
            0x8004008F => ITF::IO_WARNING_DEVICE_HAS_INTERNAL_DUMP,
            0x80040090 => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED,
            0x80040091 => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX,
            0x80040092 => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_LUN,
            0x80040093 => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_LUN_POOL,
            0x80040094 => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_LUN,
            0x80040095 => ITF::IO_WARNING_SOFT_THRESHOLD_REACHED_EX_POOL_POOL,
            0x80040097 => ITF::IO_WARNING_DISK_CAPACITY_CHANGED,
            0x80040098 => ITF::IO_WARNING_DISK_PROVISIONING_TYPE_CHANGED,
            0x80040099 => ITF::IO_WARNING_IO_OPERATION_RETRIED,
            0x8004009B => ITF::IO_WARNING_COMPLETION_TIME,
            0x8004009C => ITF::IO_WARNING_DUMP_DISABLED_DEVICE_GONE,
            0x8004009D => ITF::IO_WARNING_DISK_SURPRISE_REMOVED,
            0x8004009E => ITF::IO_WARNING_REPEATED_DISK_GUID,
            0x800400FF => ITF::OLE_E_LAST,
            0x80040100 => ITF::DRAGDROP_E_NOTREGISTERED,
            0x80040101 => ITF::DRAGDROP_E_ALREADYREGISTERED,
            0x80040102 => ITF::DRAGDROP_E_INVALIDHWND,
            0x80040102 => ITF::_MAPI_E_NO_SUPPORT,
            0x80040103 => ITF::DRAGDROP_E_CONCURRENT_DRAG_ATTEMPTED,
            0x80040103 => ITF::_MAPI_E_BAD_CHARWIDTH,
            0x80040105 => ITF::_MAPI_E_STRING_TOO_LONG,
            0x80040106 => ITF::_MAPI_E_UNKNOWN_FLAGS,
            0x80040107 => ITF::_MAPI_E_INVALID_ENTRYID,
            0x80040108 => ITF::_MAPI_E_INVALID_OBJECT,
            0x80040109 => ITF::_MAPI_E_OBJECT_CHANGED,
            0x8004010A => ITF::_MAPI_E_OBJECT_DELETED,
            0x8004010B => ITF::_MAPI_E_BUSY,
            0x8004010D => ITF::_MAPI_E_NOT_ENOUGH_DISK,
            0x8004010E => ITF::_MAPI_E_NOT_ENOUGH_RESOURCES,
            0x8004010F => ITF::_MAPI_E_NOT_FOUND,
            0x80040110 => ITF::CLASS_E_NOAGGREGATION,
            0x80040110 => ITF::_MAPI_E_VERSION,
            0x80040111 => ITF::CLASS_E_CLASSNOTAVAILABLE,
            0x80040111 => ITF::_MAPI_E_LOGON_FAILED,
            0x80040112 => ITF::CLASS_E_NOTLICENSED,
            0x80040112 => ITF::_MAPI_E_SESSION_LIMIT,
            0x80040113 => ITF::_MAPI_E_USER_CANCEL,
            0x80040114 => ITF::_MAPI_E_UNABLE_TO_ABORT,
            0x80040115 => ITF::_MAPI_E_NETWORK_ERROR,
            0x80040116 => ITF::_MAPI_E_DISK_ERROR,
            0x80040117 => ITF::_MAPI_E_TOO_COMPLEX,
            0x80040118 => ITF::_MAPI_E_BAD_COLUMN,
            0x80040119 => ITF::_MAPI_E_EXTENDED_ERROR,
            0x8004011A => ITF::_MAPI_E_COMPUTED,
            0x8004011B => ITF::_MAPI_E_CORRUPT_DATA,
            0x8004011C => ITF::_MAPI_E_UNCONFIGURED,
            0x8004011D => ITF::_MAPI_E_FAILONEPROVIDER,
            0x8004011E => ITF::_MAPI_E_UNKNOWN_CPID,
            0x8004011F => ITF::_MAPI_E_UNKNOWN_LCID,
            0x80040120 => ITF::_MAPI_E_PASSWORD_CHANGE_REQUIRED,
            0x80040121 => ITF::_MAPI_E_PASSWORD_EXPIRED,
            0x80040122 => ITF::_MAPI_E_INVALID_WORKSTATION_ACCOUNT,
            0x80040123 => ITF::_MAPI_E_INVALID_ACCESS_TIME,
            0x80040124 => ITF::_MAPI_E_ACCOUNT_DISABLED,
            0x80040140 => ITF::VIEW_E_DRAW,
            0x80040150 => ITF::REGDB_E_READREGDB,
            0x80040151 => ITF::REGDB_E_WRITEREGDB,
            0x80040152 => ITF::REGDB_E_KEYMISSING,
            0x80040153 => ITF::REGDB_E_INVALIDVALUE,
            0x80040154 => ITF::REGDB_E_CLASSNOTREG,
            0x80040154 => ITF::E_CLASSNOTREG,
            0x80040155 => ITF::REGDB_E_IIDNOTREG,
            0x80040156 => ITF::REGDB_E_BADTHREADINGMODEL,
            0x80040157 => ITF::REGDB_E_PACKAGEPOLICYVIOLATION,
            0x80040160 => ITF::CAT_E_CATIDNOEXIST,
            0x80040161 => ITF::CAT_E_NODESCRIPTION,
            0x80040164 => ITF::CS_E_PACKAGE_NOTFOUND,
            0x80040165 => ITF::CS_E_NOT_DELETABLE,
            0x80040166 => ITF::CS_E_CLASS_NOTFOUND,
            0x80040167 => ITF::CS_E_INVALID_VERSION,
            0x80040168 => ITF::CS_E_NO_CLASSSTORE,
            0x80040169 => ITF::CS_E_OBJECT_NOTFOUND,
            0x8004016A => ITF::CS_E_OBJECT_ALREADY_EXISTS,
            0x8004016B => ITF::CS_E_INVALID_PATH,
            0x8004016C => ITF::CS_E_NETWORK_ERROR,
            0x8004016D => ITF::CS_E_ADMIN_LIMIT_EXCEEDED,
            0x8004016E => ITF::CS_E_SCHEMA_MISMATCH,
            0x8004016F => ITF::CS_E_INTERNAL_ERROR,
            0x80040170 => ITF::CACHE_E_NOCACHE_UPDATED,
            0x80040180 => ITF::OLEOBJ_E_NOVERBS,
            0x80040181 => ITF::OLEOBJ_E_INVALIDVERB,
            0x800401A0 => ITF::INPLACE_E_NOTUNDOABLE,
            0x800401A1 => ITF::INPLACE_E_NOTOOLSPACE,
            0x800401C0 => ITF::CONVERT10_E_OLESTREAM_GET,
            0x800401C1 => ITF::CONVERT10_E_OLESTREAM_PUT,
            0x800401C2 => ITF::CONVERT10_E_OLESTREAM_FMT,
            0x800401C3 => ITF::CONVERT10_E_OLESTREAM_BITMAP_TO_DIB,
            0x800401C4 => ITF::CONVERT10_E_STG_FMT,
            0x800401C5 => ITF::CONVERT10_E_STG_NO_STD_STREAM,
            0x800401C6 => ITF::CONVERT10_E_STG_DIB_TO_BITMAP,
            0x800401D0 => ITF::CLIPBRD_E_CANT_OPEN,
            0x800401D1 => ITF::CLIPBRD_E_CANT_EMPTY,
            0x800401D2 => ITF::CLIPBRD_E_CANT_SET,
            0x800401D3 => ITF::CLIPBRD_E_BAD_DATA,
            0x800401D4 => ITF::CLIPBRD_E_CANT_CLOSE,
            0x800401E0 => ITF::MK_E_CONNECTMANUALLY,
            0x800401E1 => ITF::MK_E_EXCEEDEDDEADLINE,
            0x800401E2 => ITF::MK_E_NEEDGENERIC,
            0x800401E3 => ITF::MK_E_UNAVAILABLE,
            0x800401E4 => ITF::MK_E_SYNTAX,
            0x800401E5 => ITF::MK_E_NOOBJECT,
            0x800401E6 => ITF::MK_E_INVALIDEXTENSION,
            0x800401E7 => ITF::MK_E_INTERMEDIATEINTERFACENOTSUPPORTED,
            0x800401E8 => ITF::MK_E_NOTBINDABLE,
            0x800401E9 => ITF::MK_E_NOTBOUND,
            0x800401EA => ITF::MK_E_CANTOPENFILE,
            0x800401EB => ITF::MK_E_MUSTBOTHERUSER,
            0x800401EC => ITF::MK_E_NOINVERSE,
            0x800401ED => ITF::MK_E_NOSTORAGE,
            0x800401EE => ITF::MK_E_NOPREFIX,
            0x800401EF => ITF::MK_E_ENUMERATION_FAILED,
            0x800401F0 => ITF::CO_E_NOTINITIALIZED,
            0x800401F0 => ITF::DDERR_NOTINITIALIZED,
            0x800401F1 => ITF::CO_E_ALREADYINITIALIZED,
            0x800401F2 => ITF::CO_E_CANTDETERMINECLASS,
            0x800401F3 => ITF::CO_E_CLASSSTRING,
            0x800401F4 => ITF::CO_E_IIDSTRING,
            0x800401F5 => ITF::CO_E_APPNOTFOUND,
            0x800401F6 => ITF::CO_E_APPSINGLEUSE,
            0x800401F7 => ITF::CO_E_ERRORINAPP,
            0x800401F8 => ITF::CO_E_DLLNOTFOUND,
            0x800401F9 => ITF::CO_E_ERRORINDLL,
            0x800401FA => ITF::CO_E_WRONGOSFORAPP,
            0x800401FB => ITF::CO_E_OBJNOTREG,
            0x800401FC => ITF::CO_E_OBJISREG,
            0x800401FD => ITF::CO_E_OBJNOTCONNECTED,
            0x800401FE => ITF::CO_E_APPDIDNTREG,
            0x800401FF => ITF::CO_E_RELEASED,
            0x80040200 => ITF::VFW_E_INVALIDMEDIATYPE,
            0x80040200 => ITF::_MAPI_E_END_OF_SESSION,
            0x80040200 => ITF::MPEG2_E_UNINITIALIZED,
            0x80040200 => ITF::TF_E_INVALIDPOS,
            0x80040200 => ITF::TS_E_INVALIDPOS,
            0x80040200 => ITF::UPNP_E_ROOT_ELEMENT_EXPECTED,
            0x80040200 => ITF::USP_E_SCRIPT_NOT_IN_FONT,
            0x80040201 => ITF::EVENT_E_ALL_SUBSCRIBERS_FAILED,
            0x80040201 => ITF::VFW_E_INVALIDSUBTYPE,
            0x80040201 => ITF::CDO_E_UNCAUGHT_EXCEPTION,
            0x80040201 => ITF::_MAPI_E_UNKNOWN_ENTRYID,
            0x80040201 => ITF::MPEG2_E_ALREADY_INITIALIZED,
            0x80040201 => ITF::TF_E_NOLOCK,
            0x80040201 => ITF::TS_E_NOLOCK,
            0x80040201 => ITF::UPNP_E_DEVICE_ELEMENT_EXPECTED,
            0x80040202 => ITF::VFW_E_NEED_OWNER,
            0x80040202 => ITF::CDO_E_NOT_OPENED,
            0x80040202 => ITF::_MAPI_E_MISSING_REQUIRED_COLUMN,
            0x80040202 => ITF::MPEG2_E_OUT_OF_BOUNDS,
            0x80040202 => ITF::TF_E_NOOBJECT,
            0x80040202 => ITF::TS_E_NOOBJECT,
            0x80040202 => ITF::UPNP_E_SERVICE_ELEMENT_EXPECTED,
            0x80040203 => ITF::EVENT_E_QUERYSYNTAX,
            0x80040203 => ITF::VFW_E_ENUM_OUT_OF_SYNC,
            0x80040203 => ITF::CDO_E_UNSUPPORTED_DATASOURCE,
            0x80040203 => ITF::MPEG2_E_MALFORMED_TABLE,
            0x80040203 => ITF::TF_E_NOSERVICE,
            0x80040203 => ITF::TS_E_NOSERVICE,
            0x80040203 => ITF::UPNP_E_SERVICE_NODE_INCOMPLETE,
            0x80040204 => ITF::EVENT_E_QUERYFIELD,
            0x80040204 => ITF::VFW_E_ALREADY_CONNECTED,
            0x80040204 => ITF::CDO_E_INVALID_PROPERTYNAME,
            0x80040204 => ITF::MPEG2_E_UNDEFINED,
            0x80040204 => ITF::TF_E_NOINTERFACE,
            0x80040204 => ITF::TS_E_NOINTERFACE,
            0x80040204 => ITF::UPNP_E_DEVICE_NODE_INCOMPLETE,
            0x80040205 => ITF::EVENT_E_INTERNALEXCEPTION,
            0x80040205 => ITF::VFW_E_FILTER_ACTIVE,
            0x80040205 => ITF::CDO_E_PROP_UNSUPPORTED,
            0x80040205 => ITF::MPEG2_E_NOT_PRESENT,
            0x80040205 => ITF::TF_E_NOSELECTION,
            0x80040205 => ITF::TS_E_NOSELECTION,
            0x80040205 => ITF::UPNP_E_ICON_ELEMENT_EXPECTED,
            0x80040206 => ITF::EVENT_E_INTERNALERROR,
            0x80040206 => ITF::VFW_E_NO_TYPES,
            0x80040206 => ITF::CDO_E_INACTIVE,
            0x80040206 => ITF::MPEG2_E_SECTION_NOT_FOUND,
            0x80040206 => ITF::TF_E_NOLAYOUT,
            0x80040206 => ITF::TS_E_NOLAYOUT,
            0x80040206 => ITF::UPNP_E_ICON_NODE_INCOMPLETE,
            0x80040207 => ITF::EVENT_E_INVALID_PER_USER_SID,
            0x80040207 => ITF::VFW_E_NO_ACCEPTABLE_TYPES,
            0x80040207 => ITF::CDO_E_NO_SUPPORT_FOR_OBJECTS,
            0x80040207 => ITF::MPEG2_E_TX_STREAM_UNAVAILABLE,
            0x80040207 => ITF::TF_E_INVALIDPOINT,
            0x80040207 => ITF::TS_E_INVALIDPOINT,
            0x80040207 => ITF::UPNP_E_INVALID_ACTION,
            0x80040208 => ITF::EVENT_E_USER_EXCEPTION,
            0x80040208 => ITF::VFW_E_INVALID_DIRECTION,
            0x80040208 => ITF::CDO_E_NOT_AVAILABLE,
            0x80040208 => ITF::MPEG2_E_SERVICE_ID_NOT_FOUND,
            0x80040208 => ITF::TF_E_SYNCHRONOUS,
            0x80040208 => ITF::TS_E_SYNCHRONOUS,
            0x80040208 => ITF::UPNP_E_INVALID_ARGUMENTS,
            0x80040209 => ITF::EVENT_E_TOO_MANY_METHODS,
            0x80040209 => ITF::VFW_E_NOT_CONNECTED,
            0x80040209 => ITF::CDO_E_NO_DEFAULT_DROP_DIR,
            0x80040209 => ITF::MPEG2_E_SERVICE_PMT_NOT_FOUND,
            0x80040209 => ITF::TF_E_READONLY,
            0x80040209 => ITF::TS_E_READONLY,
            0x80040209 => ITF::UPNP_E_OUT_OF_SYNC,
            0x8004020A => ITF::EVENT_E_MISSING_EVENTCLASS,
            0x8004020A => ITF::VFW_E_NO_ALLOCATOR,
            0x8004020A => ITF::CDO_E_SMTP_SERVER_REQUIRED,
            0x8004020A => ITF::MPEG2_E_DSI_NOT_FOUND,
            0x8004020A => ITF::TF_E_FORMAT,
            0x8004020A => ITF::TS_E_FORMAT,
            0x8004020B => ITF::EVENT_E_NOT_ALL_REMOVED,
            0x8004020B => ITF::VFW_E_RUNTIME_ERROR,
            0x8004020B => ITF::CDO_E_NNTP_SERVER_REQUIRED,
            0x8004020B => ITF::IMAPI_E_NOTOPENED,
            0x8004020B => ITF::MPEG2_E_SERVER_UNAVAILABLE,
            0x8004020C => ITF::EVENT_E_COMPLUS_NOT_INSTALLED,
            0x8004020C => ITF::VFW_E_BUFFER_NOTSET,
            0x8004020C => ITF::CDO_E_RECIPIENT_MISSING,
            0x8004020C => ITF::IMAPI_E_NOTINITIALIZED,
            0x8004020C => ITF::MPEG2_E_INVALID_CAROUSEL_ID,
            0x8004020D => ITF::EVENT_E_CANT_MODIFY_OR_DELETE_UNCONFIGURED_OBJECT,
            0x8004020D => ITF::VFW_E_BUFFER_OVERFLOW,
            0x8004020D => ITF::CDO_E_FROM_MISSING,
            0x8004020D => ITF::IMAPI_E_USERABORT,
            0x8004020D => ITF::MPEG2_E_MALFORMED_DSMCC_MESSAGE,
            0x8004020E => ITF::EVENT_E_CANT_MODIFY_OR_DELETE_CONFIGURED_OBJECT,
            0x8004020E => ITF::VFW_E_BADALIGN,
            0x8004020E => ITF::CDO_E_SENDER_REJECTED,
            0x8004020E => ITF::IMAPI_E_GENERIC,
            0x8004020E => ITF::MPEG2_E_INVALID_SG_OBJECT_KIND,
            0x8004020F => ITF::EVENT_E_INVALID_EVENT_CLASS_PARTITION,
            0x8004020F => ITF::VFW_E_ALREADY_COMMITTED,
            0x8004020F => ITF::CDO_E_RECIPIENTS_REJECTED,
            0x8004020F => ITF::IMAPI_E_MEDIUM_NOTPRESENT,
            0x8004020F => ITF::MPEG2_E_OBJECT_NOT_FOUND,
            0x80040210 => ITF::EVENT_E_PER_USER_SID_NOT_LOGGED_ON,
            0x80040210 => ITF::VFW_E_BUFFERS_OUTSTANDING,
            0x80040210 => ITF::CDO_E_NNTP_POST_FAILED,
            0x80040210 => ITF::IMAPI_E_MEDIUM_INVALIDTYPE,
            0x80040210 => ITF::MPEG2_E_OBJECT_KIND_NOT_A_DIRECTORY,
            0x80040210 => ITF::UPNP_E_ACTION_REQUEST_FAILED,
            0x80040211 => ITF::VFW_E_NOT_COMMITTED,
            0x80040211 => ITF::CDO_E_SMTP_SEND_FAILED,
            0x80040211 => ITF::IMAPI_E_DEVICE_NOPROPERTIES,
            0x80040211 => ITF::MPEG2_E_OBJECT_KIND_NOT_A_FILE,
            0x80040211 => ITF::UPNP_E_TRANSPORT_ERROR,
            0x80040212 => ITF::TPC_E_NO_DEFAULT_TABLET,
            0x80040212 => ITF::VFW_E_SIZENOTSET,
            0x80040212 => ITF::CDO_E_CONNECTION_DROPPED,
            0x80040212 => ITF::IMAPI_E_DEVICE_NOTACCESSIBLE,
            0x80040212 => ITF::MPEG2_E_FILE_OFFSET_TOO_BIG,
            0x80040212 => ITF::UPNP_E_VARIABLE_VALUE_UNKNOWN,
            0x80040213 => ITF::VFW_E_NO_CLOCK,
            0x80040213 => ITF::CDO_E_FAILED_TO_CONNECT,
            0x80040213 => ITF::IMAPI_E_DEVICE_NOTPRESENT,
            0x80040213 => ITF::MPEG2_E_STREAM_STOPPED,
            0x80040213 => ITF::UPNP_E_INVALID_VARIABLE,
            0x80040214 => ITF::VFW_E_NO_SINK,
            0x80040214 => ITF::CDO_E_INVALID_POST,
            0x80040214 => ITF::IMAPI_E_DEVICE_INVALIDTYPE,
            0x80040214 => ITF::MPEG2_E_REGISTRY_ACCESS_FAILED,
            0x80040214 => ITF::UPNP_E_DEVICE_ERROR,
            0x80040215 => ITF::VFW_E_NO_INTERFACE,
            0x80040215 => ITF::CDO_E_AUTHENTICATION_FAILURE,
            0x80040215 => ITF::IMAPI_E_INITIALIZE_WRITE,
            0x80040215 => ITF::MPEG2_E_INVALID_UDP_PORT,
            0x80040215 => ITF::UPNP_E_PROTOCOL_ERROR,
            0x80040216 => ITF::VFW_E_NOT_FOUND,
            0x80040216 => ITF::CDO_E_INVALID_CONTENT_TYPE,
            0x80040216 => ITF::IMAPI_E_INITIALIZE_ENDWRITE,
            0x80040216 => ITF::MPEG2_E_DATA_SOURCE_FAILED,
            0x80040216 => ITF::UPNP_E_ERROR_PROCESSING_RESPONSE,
            0x80040217 => ITF::VFW_E_CANNOT_CONNECT,
            0x80040217 => ITF::CDO_E_LOGON_FAILURE,
            0x80040217 => ITF::IMAPI_E_FILESYSTEM,
            0x80040217 => ITF::MPEG2_E_DII_NOT_FOUND,
            0x80040217 => ITF::UPNP_E_DEVICE_TIMEOUT,
            0x80040218 => ITF::VFW_E_CANNOT_RENDER,
            0x80040218 => ITF::CDO_E_HTTP_NOT_FOUND,
            0x80040218 => ITF::IMAPI_E_FILEACCESS,
            0x80040218 => ITF::MPEG2_E_DSHOW_PIN_NOT_FOUND,
            0x80040219 => ITF::TPC_E_INVALID_INPUT_RECT,
            0x80040219 => ITF::VFW_E_CHANGING_FORMAT,
            0x80040219 => ITF::CDO_E_HTTP_FORBIDDEN,
            0x80040219 => ITF::IMAPI_E_DISCINFO,
            0x80040219 => ITF::MPEG2_E_BUFFER_TOO_SMALL,
            0x8004021A => ITF::VFW_E_NO_COLOR_KEY_SET,
            0x8004021A => ITF::CDO_E_HTTP_FAILED,
            0x8004021A => ITF::IMAPI_E_TRACKNOTOPEN,
            0x8004021A => ITF::MPEG2_E_MISSING_SECTIONS,
            0x8004021B => ITF::TPC_E_UNKNOWN_PROPERTY,
            0x8004021B => ITF::VFW_E_NOT_OVERLAY_CONNECTION,
            0x8004021B => ITF::CDO_E_MULTIPART_NO_DATA,
            0x8004021B => ITF::IMAPI_E_TRACKOPEN,
            0x8004021B => ITF::MPEG2_E_TOO_MANY_SECTIONS,
            0x8004021C => ITF::VFW_E_NOT_SAMPLE_CONNECTION,
            0x8004021C => ITF::CDO_E_INVALID_ENCODING_FOR_MULTIPART,
            0x8004021C => ITF::IMAPI_E_DISCFULL,
            0x8004021C => ITF::MPEG2_E_NEXT_TABLE_OPS_NOT_AVAILABLE,
            0x8004021D => ITF::VFW_E_PALETTE_SET,
            0x8004021D => ITF::CDO_E_UNSAFE_OPERATION,
            0x8004021D => ITF::IMAPI_E_BADJOLIETNAME,
            0x8004021D => ITF::MPEG2_E_INCORRECT_DESCRIPTOR_TAG,
            0x8004021E => ITF::VFW_E_COLOR_KEY_SET,
            0x8004021E => ITF::CDO_E_PROP_NOT_FOUND,
            0x8004021E => ITF::IMAPI_E_INVALIDIMAGE,
            0x8004021F => ITF::VFW_E_NO_COLOR_KEY_FOUND,
            0x8004021F => ITF::IMAPI_E_NOACTIVEFORMAT,
            0x80040220 => ITF::VFW_E_NO_PALETTE_AVAILABLE,
            0x80040220 => ITF::CDO_E_INVALID_SEND_OPTION,
            0x80040220 => ITF::IMAPI_E_NOACTIVERECORDER,
            0x80040221 => ITF::VFW_E_NO_DISPLAY_PALETTE,
            0x80040221 => ITF::CDO_E_INVALID_POST_OPTION,
            0x80040221 => ITF::IMAPI_E_WRONGFORMAT,
            0x80040222 => ITF::TPC_E_INVALID_STROKE,
            0x80040222 => ITF::VFW_E_TOO_MANY_COLORS,
            0x80040222 => ITF::CDO_E_NO_PICKUP_DIR,
            0x80040222 => ITF::IMAPI_E_ALREADYOPEN,
            0x80040223 => ITF::TPC_E_INITIALIZE_FAIL,
            0x80040223 => ITF::VFW_E_STATE_CHANGED,
            0x80040223 => ITF::CDO_E_NOT_ALL_DELETED,
            0x80040223 => ITF::IMAPI_E_WRONGDISC,
            0x80040224 => ITF::VFW_E_NOT_STOPPED,
            0x80040224 => ITF::CDO_E_NO_METHOD,
            0x80040224 => ITF::IMAPI_E_FILEEXISTS,
            0x80040225 => ITF::VFW_E_NOT_PAUSED,
            0x80040225 => ITF::IMAPI_E_STASHINUSE,
            0x80040226 => ITF::VFW_E_NOT_RUNNING,
            0x80040226 => ITF::IMAPI_E_DEVICE_STILL_IN_USE,
            0x80040227 => ITF::VFW_E_WRONG_STATE,
            0x80040227 => ITF::CDO_E_PROP_READONLY,
            0x80040227 => ITF::IMAPI_E_LOSS_OF_STREAMING,
            0x80040228 => ITF::VFW_E_START_TIME_AFTER_END,
            0x80040228 => ITF::CDO_E_PROP_CANNOT_DELETE,
            0x80040228 => ITF::IMAPI_E_COMPRESSEDSTASH,
            0x80040229 => ITF::VFW_E_INVALID_RECT,
            0x80040229 => ITF::CDO_E_BAD_DATA,
            0x80040229 => ITF::IMAPI_E_ENCRYPTEDSTASH,
            0x8004022A => ITF::VFW_E_TYPE_NOT_ACCEPTED,
            0x8004022A => ITF::CDO_E_PROP_NONHEADER,
            0x8004022A => ITF::IMAPI_E_NOTENOUGHDISKFORSTASH,
            0x8004022B => ITF::VFW_E_SAMPLE_REJECTED,
            0x8004022B => ITF::CDO_E_INVALID_CHARSET,
            0x8004022B => ITF::IMAPI_E_REMOVABLESTASH,
            0x8004022C => ITF::VFW_E_SAMPLE_REJECTED_EOS,
            0x8004022C => ITF::CDO_E_ADOSTREAM_NOT_BOUND,
            0x8004022C => ITF::IMAPI_E_CANNOT_WRITE_TO_MEDIA,
            0x8004022D => ITF::VFW_E_DUPLICATE_NAME,
            0x8004022D => ITF::CDO_E_CONTENTPROPXML_NOT_FOUND,
            0x8004022D => ITF::IMAPI_E_TRACK_NOT_BIG_ENOUGH,
            0x8004022E => ITF::VFW_E_TIMEOUT,
            0x8004022E => ITF::CDO_E_CONTENTPROPXML_WRONG_CHARSET,
            0x8004022F => ITF::VFW_E_INVALID_FILE_FORMAT,
            0x8004022F => ITF::CDO_E_CONTENTPROPXML_PARSE_FAILED,
            0x80040230 => ITF::VFW_E_ENUM_OUT_OF_RANGE,
            0x80040230 => ITF::CDO_E_CONTENTPROPXML_CONVERT_FAILED,
            0x80040231 => ITF::VFW_E_CIRCULAR_GRAPH,
            0x80040231 => ITF::CDO_E_NO_DIRECTORIES_SPECIFIED,
            0x80040232 => ITF::TPC_E_NOT_RELEVANT,
            0x80040232 => ITF::VFW_E_NOT_ALLOWED_TO_SAVE,
            0x80040232 => ITF::CDO_E_DIRECTORIES_UNREACHABLE,
            0x80040233 => ITF::TPC_E_INVALID_PACKET_DESCRIPTION,
            0x80040233 => ITF::VFW_E_TIME_ALREADY_PASSED,
            0x80040233 => ITF::CDO_E_BAD_SENDER,
            0x80040234 => ITF::VFW_E_ALREADY_CANCELLED,
            0x80040234 => ITF::CDO_E_SELF_BINDING,
            0x80040235 => ITF::TPC_E_RECOGNIZER_NOT_REGISTERED,
            0x80040235 => ITF::VFW_E_CORRUPT_GRAPH_FILE,
            0x80040235 => ITF::CDO_E_BAD_ATTENDEE_DATA,
            0x80040236 => ITF::TPC_E_INVALID_RIGHTS,
            0x80040236 => ITF::VFW_E_ADVISE_ALREADY_SET,
            0x80040236 => ITF::CDO_E_ROLE_NOMORE_AVAILABLE,
            0x80040237 => ITF::TPC_E_OUT_OF_ORDER_CALL,
            0x80040237 => ITF::CDO_E_BAD_TASKTYPE_ONASSIGN,
            0x80040238 => ITF::TPC_E_QUEUE_FULL,
            0x80040238 => ITF::VFW_E_NO_MODEX_AVAILABLE,
            0x80040238 => ITF::CDO_E_NOT_ASSIGNEDTO_USER,
            0x80040239 => ITF::TPC_E_INVALID_CONFIGURATION,
            0x80040239 => ITF::VFW_E_NO_ADVISE_SET,
            0x80040239 => ITF::CDO_E_OUTOFDATE,
            0x8004023A => ITF::TPC_E_INVALID_DATA_FROM_RECOGNIZER,
            0x8004023A => ITF::VFW_E_NO_FULLSCREEN,
            0x8004023B => ITF::VFW_E_IN_FULLSCREEN_MODE,
            0x80040240 => ITF::VFW_E_UNKNOWN_FILE_TYPE,
            0x80040241 => ITF::TPC_E_INVALID_PROPERTY,
            0x80040241 => ITF::VFW_E_CANNOT_LOAD_SOURCE_FILTER,
            0x80040243 => ITF::VFW_E_FILE_TOO_SHORT,
            0x80040244 => ITF::VFW_E_INVALID_FILE_VERSION,
            0x80040247 => ITF::VFW_E_INVALID_CLSID,
            0x80040248 => ITF::VFW_E_INVALID_MEDIA_TYPE,
            0x80040249 => ITF::VFW_E_SAMPLE_TIME_NOT_SET,
            0x80040251 => ITF::VFW_E_MEDIA_TIME_NOT_SET,
            0x80040252 => ITF::VFW_E_NO_TIME_FORMAT_SET,
            0x80040253 => ITF::VFW_E_MONO_AUDIO_HW,
            0x80040255 => ITF::VFW_E_NO_DECOMPRESSOR,
            0x80040256 => ITF::VFW_E_NO_AUDIO_HARDWARE,
            0x80040259 => ITF::VFW_E_RPZA,
            0x8004025B => ITF::VFW_E_PROCESSOR_NOT_SUITABLE,
            0x8004025C => ITF::VFW_E_UNSUPPORTED_AUDIO,
            0x8004025D => ITF::VFW_E_UNSUPPORTED_VIDEO,
            0x8004025E => ITF::VFW_E_MPEG_NOT_CONSTRAINED,
            0x8004025F => ITF::VFW_E_NOT_IN_GRAPH,
            0x80040261 => ITF::VFW_E_NO_TIME_FORMAT,
            0x80040262 => ITF::VFW_E_READ_ONLY,
            0x80040264 => ITF::VFW_E_BUFFER_UNDERFLOW,
            0x80040265 => ITF::VFW_E_UNSUPPORTED_STREAM,
            0x80040266 => ITF::VFW_E_NO_TRANSPORT,
            0x80040269 => ITF::VFW_E_BAD_VIDEOCD,
            0x80040270 => ITF::VFW_S_NO_STOP_TIME,
            0x80040271 => ITF::VFW_E_OUT_OF_VIDEO_MEMORY,
            0x80040272 => ITF::VFW_E_VP_NEGOTIATION_FAILED,
            0x80040273 => ITF::VFW_E_DDRAW_CAPS_NOT_SUITABLE,
            0x80040274 => ITF::VFW_E_NO_VP_HARDWARE,
            0x80040275 => ITF::VFW_E_NO_CAPTURE_HARDWARE,
            0x80040276 => ITF::VFW_E_DVD_OPERATION_INHIBITED,
            0x80040277 => ITF::VFW_E_DVD_INVALIDDOMAIN,
            0x80040278 => ITF::VFW_E_DVD_NO_BUTTON,
            0x80040279 => ITF::VFW_E_DVD_GRAPHNOTREADY,
            0x8004027A => ITF::VFW_E_DVD_RENDERFAIL,
            0x8004027B => ITF::VFW_E_DVD_DECNOTENOUGH,
            0x8004027C => ITF::VFW_E_DDRAW_VERSION_NOT_SUITABLE,
            0x8004027D => ITF::VFW_E_COPYPROT_FAILED,
            0x8004027F => ITF::VFW_E_TIME_EXPIRED,
            0x80040281 => ITF::VFW_E_DVD_WRONG_SPEED,
            0x80040282 => ITF::VFW_E_DVD_MENU_DOES_NOT_EXIST,
            0x80040283 => ITF::VFW_E_DVD_CMD_CANCELLED,
            0x80040284 => ITF::VFW_E_DVD_STATE_WRONG_VERSION,
            0x80040285 => ITF::VFW_E_DVD_STATE_CORRUPT,
            0x80040286 => ITF::VFW_E_DVD_STATE_WRONG_DISC,
            0x80040287 => ITF::VFW_E_DVD_INCOMPATIBLE_REGION,
            0x80040288 => ITF::VFW_E_DVD_NO_ATTRIBUTES,
            0x80040289 => ITF::VFW_E_DVD_NO_GOUP_PGC,
            0x8004028A => ITF::VFW_E_DVD_LOW_PARENTAL_LEVEL,
            0x8004028B => ITF::VFW_E_DVD_NOT_IN_KARAOKE_MODE,
            0x8004028E => ITF::VFW_E_FRAME_STEP_UNSUPPORTED,
            0x8004028F => ITF::VFW_E_DVD_STREAM_DISABLED,
            0x80040290 => ITF::VFW_E_DVD_TITLE_UNKNOWN,
            0x80040291 => ITF::VFW_E_DVD_INVALID_DISC,
            0x80040292 => ITF::VFW_E_DVD_NO_RESUME_INFORMATION,
            0x80040293 => ITF::VFW_E_PIN_ALREADY_BLOCKED_ON_THIS_THREAD,
            0x80040294 => ITF::VFW_E_PIN_ALREADY_BLOCKED,
            0x80040295 => ITF::VFW_E_CERTIFICATION_FAILURE,
            0x80040296 => ITF::VFW_E_VMR_NOT_IN_MIXER_MODE,
            0x80040297 => ITF::VFW_E_VMR_NO_AP_SUPPLIED,
            0x80040298 => ITF::VFW_E_VMR_NO_DEINTERLACE_HW,
            0x80040299 => ITF::VFW_E_VMR_NO_PROCAMP_HW,
            0x8004029A => ITF::VFW_E_DVD_VMR9_INCOMPATIBLEDEC,
            0x8004029B => ITF::VFW_E_NO_COPP_HW,
            0x8004029C => ITF::VFW_E_DVD_NONBLOCKING,
            0x8004029D => ITF::VFW_E_DVD_TOO_MANY_RENDERERS_IN_FILTER_GRAPH,
            0x8004029E => ITF::VFW_E_DVD_NON_EVR_RENDERER_IN_FILTER_GRAPH,
            0x8004029F => ITF::VFW_E_DVD_RESOLUTION_ERROR,
            0x80040300 => ITF::NET_E_GENERAL,
            0x80040300 => ITF::FHCFG_E_CORRUPT_CONFIG_FILE,
            0x80040300 => ITF::UPNP_E_ACTION_SPECIFIC_BASE,
            0x80040301 => ITF::FHCFG_E_CONFIG_FILE_NOT_FOUND,
            0x80040302 => ITF::FHCFG_E_CONFIG_ALREADY_EXISTS,
            0x80040303 => ITF::NET_E_DISCONNECTED,
            0x80040303 => ITF::FHCFG_E_NO_VALID_CONFIGURATION_LOADED,
            0x80040304 => ITF::FHCFG_E_TARGET_NOT_CONNECTED,
            0x80040305 => ITF::FHCFG_E_CONFIGURATION_PREVIOUSLY_LOADED,
            0x80040306 => ITF::FHCFG_E_TARGET_VERIFICATION_FAILED,
            0x80040307 => ITF::FHCFG_E_TARGET_NOT_CONFIGURED,
            0x80040308 => ITF::NET_E_INVALIDPARAMS,
            0x80040308 => ITF::FHCFG_E_TARGET_NOT_ENOUGH_FREE_SPACE,
            0x80040309 => ITF::NET_E_OPERATIONINPROGRESS,
            0x80040309 => ITF::FHCFG_E_TARGET_CANNOT_BE_USED,
            0x80040310 => ITF::VFW_E_CODECAPI_LINEAR_RANGE,
            0x80040310 => ITF::FHCFG_E_RECOMMENDATION_CHANGE_NOT_ALLOWED,
            0x80040311 => ITF::VFW_E_CODECAPI_ENUMERATED,
            0x80040311 => ITF::FHCFG_E_TARGET_REHYDRATED_ELSEWHERE,
            0x80040312 => ITF::FHCFG_E_LEGACY_TARGET_UNSUPPORTED,
            0x80040313 => ITF::VFW_E_CODECAPI_NO_DEFAULT,
            0x80040313 => ITF::FHCFG_E_LEGACY_TARGET_VALIDATION_UNSUPPORTED,
            0x80040314 => ITF::VFW_E_CODECAPI_NO_CURRENT_VALUE,
            0x80040314 => ITF::FHCFG_E_LEGACY_BACKUP_USER_EXCLUDED,
            0x80040315 => ITF::VFW_E_DVD_CHAPTER_DOES_NOT_EXIST,
            0x80040315 => ITF::FHCFG_E_LEGACY_BACKUP_NOT_FOUND,
            0x800403F2 => ITF::VFW_E_BAD_KEY,
            0x80040400 => ITF::DS_E_NOMOREDATA,
            0x80040401 => ITF::DS_E_INVALIDDATASOURCE,
            0x80040401 => ITF::MS_E_SAMPLEALLOC,
            0x80040402 => ITF::DS_E_DATASOURCENOTAVAILABLE,
            0x80040402 => ITF::MS_E_PURPOSEID,
            0x80040403 => ITF::DS_E_QUERYCANCELED,
            0x80040403 => ITF::MS_E_NOSTREAM,
            0x80040404 => ITF::DS_E_UNKNOWNREQUEST,
            0x80040404 => ITF::MS_E_NOSEEKING,
            0x80040405 => ITF::DS_E_BADREQUEST,
            0x80040405 => ITF::MS_E_INCOMPATIBLE,
            0x80040406 => ITF::DS_E_SERVERCAPACITY,
            0x80040406 => ITF::MS_E_BUSY,
            0x80040407 => ITF::DS_E_BADSEQUENCE,
            0x80040407 => ITF::MS_E_NOTINIT,
            0x80040408 => ITF::DS_E_MESSAGETOOLONG,
            0x80040408 => ITF::MS_E_SOURCEALREADYDEFINED,
            0x80040409 => ITF::DS_E_SERVERERROR,
            0x80040409 => ITF::MS_E_INVALIDSTREAMTYPE,
            0x8004040A => ITF::DS_E_CONFIGBAD,
            0x8004040A => ITF::MS_E_NOTRUNNING,
            0x80040410 => ITF::DS_E_DATANOTPRESENT,
            0x80040411 => ITF::DS_E_SETSTATUSINPROGRESS,
            0x80040412 => ITF::DS_E_DUPLICATEID,
            0x80040413 => ITF::DS_E_TOOMANYDATASOURCES,
            0x80040414 => ITF::DS_E_REGISTRY,
            0x80040415 => ITF::DS_E_DATASOURCENOTDISABLED,
            0x80040416 => ITF::DS_E_INVALIDTAGDB,
            0x80040417 => ITF::DS_E_INVALIDCATALOGNAME,
            0x80040418 => ITF::DS_E_CONFIGNOTRIGHTTYPE,
            0x80040419 => ITF::DS_E_PROTOCOLVERSION,
            0x8004041A => ITF::DS_E_ALREADYENABLED,
            0x8004041C => ITF::DS_E_INDEXDIRECTORY,
            0x8004041D => ITF::DS_E_VALUETOOLARGE,
            0x8004041E => ITF::DS_E_UNKNOWNPARAM,
            0x8004041F => ITF::DS_E_BUFFERTOOSMALL,
            0x80040420 => ITF::DS_E_PARAMOUTOFRANGE,
            0x80040421 => ITF::DS_E_ALREADYDISABLED,
            0x80040422 => ITF::DS_E_QUERYHUNG,
            0x80040423 => ITF::DS_E_BADRESULT,
            0x80040424 => ITF::DS_E_CANNOTWRITEREGISTRY,
            0x80040425 => ITF::DS_E_CANNOTREMOVECONCURRENT,
            0x80040426 => ITF::DS_E_SEARCHCATNAMECOLLISION,
            0x80040427 => ITF::DS_E_PROPVERSIONMISMATCH,
            0x80040428 => ITF::DS_E_MISSINGCATALOG,
            0x8004042B => ITF::UPNP_E_ACTION_SPECIFIC_MAX,
            0x80040500 => ITF::TF_E_LOCKED,
            0x80040500 => ITF::UPNP_E_INVALID_DOCUMENT,
            0x80040501 => ITF::COLL_E_BADSEQUENCE,
            0x80040501 => ITF::TF_E_STACKFULL,
            0x80040501 => ITF::UPNP_E_EVENT_SUBSCRIPTION_FAILED,
            0x80040502 => ITF::COLL_E_NOMOREDATA,
            0x80040502 => ITF::TF_E_NOTOWNEDRANGE,
            0x80040503 => ITF::COLL_E_INCOMPATIBLECOLUMNS,
            0x80040503 => ITF::TF_E_NOPROVIDER,
            0x80040504 => ITF::COLL_E_BUFFERTOOSMALL,
            0x80040504 => ITF::TF_E_DISCONNECTED,
            0x80040505 => ITF::TF_E_INVALIDVIEW,
            0x80040506 => ITF::COLL_E_BADRESULT,
            0x80040506 => ITF::TF_E_ALREADY_EXISTS,
            0x80040507 => ITF::COLL_E_NOSORTCOLUMN,
            0x80040507 => ITF::TF_E_RANGE_NOT_COVERED,
            0x80040508 => ITF::COLL_E_DUPLICATEDBID,
            0x80040508 => ITF::TF_E_COMPOSITION_REJECTED,
            0x80040509 => ITF::COLL_E_TOOMANYMERGECOLUMNS,
            0x80040509 => ITF::TF_E_EMPTYCONTEXT,
            0x8004050A => ITF::COLL_E_NODEFAULTCATALOG,
            0x8004050B => ITF::COLL_E_MAXCONNEXCEEDED,
            0x80040600 => ITF::FHSVC_E_BACKUP_BLOCKED,
            0x80040601 => ITF::CM_E_TOOMANYDATASERVERS,
            0x80040601 => ITF::FHSVC_E_NOT_CONFIGURED,
            0x80040602 => ITF::CM_E_TOOMANYDATASOURCES,
            0x80040602 => ITF::FHSVC_E_CONFIG_DISABLED,
            0x80040603 => ITF::CM_E_NOQUERYCONNECTIONS,
            0x80040603 => ITF::FHSVC_E_CONFIG_DISABLED_GP,
            0x80040604 => ITF::CM_E_DATASOURCENOTAVAILABLE,
            0x80040604 => ITF::FHSVC_E_FATAL_CONFIG_ERROR,
            0x80040605 => ITF::CM_E_CONNECTIONTIMEOUT,
            0x80040605 => ITF::FHSVC_E_CONFIG_REHYDRATING,
            0x80040606 => ITF::CM_E_SERVERNOTFOUND,
            0x80040608 => ITF::CM_E_REGISTRY,
            0x80040609 => ITF::CM_E_INVALIDDATASOURCE,
            0x8004060A => ITF::CM_E_TIMEOUT,
            0x8004060B => ITF::CM_E_INSUFFICIENTBUFFER,
            0x80040701 => ITF::QRY_E_QUERYSYNTAX,
            0x80040702 => ITF::QRY_E_TYPEMISMATCH,
            0x80040703 => ITF::QRY_E_UNHANDLEDTYPE,
            0x80040705 => ITF::QRY_E_TOOMANYCOLUMNS,
            0x80040706 => ITF::QRY_E_TOOMANYDATABASES,
            0x80040707 => ITF::QRY_E_STARTHITTOBIG,
            0x80040708 => ITF::QRY_E_TOOMANYQUERYTERMS,
            0x80040709 => ITF::QRY_E_NODATASOURCES,
            0x8004070A => ITF::QRY_E_TIMEOUT,
            0x8004070B => ITF::QRY_E_COLUMNNOTSORTABLE,
            0x8004070C => ITF::QRY_E_COLUMNNOTSEARCHABLE,
            0x8004070D => ITF::QRY_E_INVALIDCOLUMN,
            0x8004070E => ITF::QRY_E_QUERYCORRUPT,
            0x8004070F => ITF::QRY_E_PREFIXWILDCARD,
            0x80040710 => ITF::QRY_E_INFIXWILDCARD,
            0x80040711 => ITF::QRY_E_WILDCARDPREFIXLENGTH,
            0x80040713 => ITF::QRY_E_ENGINEFAILED,
            0x80040714 => ITF::QRY_E_SEARCHTOOBIG,
            0x80040715 => ITF::QRY_E_NULLQUERY,
            0x80040717 => ITF::QRY_E_NOCOLUMNS,
            0x80040718 => ITF::QRY_E_INVALIDSCOPES,
            0x80040719 => ITF::QRY_E_INVALIDCATALOG,
            0x8004071A => ITF::QRY_E_SCOPECARDINALIDY,
            0x8004071B => ITF::QRY_E_UNEXPECTED,
            0x8004071C => ITF::QRY_E_INVALIDPATH,
            0x8004071D => ITF::QRY_E_LMNOTINITIALIZED,
            0x8004071E => ITF::QRY_E_INVALIDINTERVAL,
            0x8004071F => ITF::QRY_E_NOLOGMANAGER,
            0x80040C01 => ITF::SCHEMA_E_LOAD_SPECIAL,
            0x80040C02 => ITF::SCHEMA_E_FILENOTFOUND,
            0x80040C03 => ITF::SCHEMA_E_NESTEDTAG,
            0x80040C04 => ITF::SCHEMA_E_UNEXPECTEDTAG,
            0x80040C05 => ITF::SCHEMA_E_VERSIONMISMATCH,
            0x80040C06 => ITF::SCHEMA_E_CANNOTCREATEFILE,
            0x80040C07 => ITF::SCHEMA_E_CANNOTWRITEFILE,
            0x80040C08 => ITF::SCHEMA_E_EMPTYFILE,
            0x80040C09 => ITF::SCHEMA_E_INVALIDFILETYPE,
            0x80040C0A => ITF::SCHEMA_E_INVALIDDATATYPE,
            0x80040C0B => ITF::SCHEMA_E_CANNOTCREATENOISEWORDFILE,
            0x80040C0C => ITF::SCHEMA_E_ADDSTOPWORDS,
            0x80040C0D => ITF::SCHEMA_E_NAMEEXISTS,
            0x80040C0E => ITF::SCHEMA_E_INVALIDVALUE,
            0x80040C0F => ITF::SCHEMA_E_BADPROPSPEC,
            0x80040C10 => ITF::SCHEMA_E_NOMORECOLUMNS,
            0x80040C11 => ITF::SCHEMA_E_FILECHANGED,
            0x80040C12 => ITF::SCHEMA_E_BADCOLUMNNAME,
            0x80040C13 => ITF::SCHEMA_E_BADPROPPID,
            0x80040C14 => ITF::SCHEMA_E_BADATTRIBUTE,
            0x80040C15 => ITF::SCHEMA_E_BADFILENAME,
            0x80040C16 => ITF::SCHEMA_E_PROPEXISTS,
            0x80040C17 => ITF::SCHEMA_E_DUPLICATENOISE,
            0x80040D02 => ITF::GTHR_E_DUPLICATE_OBJECT,
            0x80040D03 => ITF::GTHR_E_UNABLE_TO_READ_REGISTRY,
            0x80040D04 => ITF::GTHR_E_ERROR_WRITING_REGISTRY,
            0x80040D05 => ITF::GTHR_E_ERROR_INITIALIZING_PERFMON,
            0x80040D06 => ITF::GTHR_E_ERROR_OBJECT_NOT_FOUND,
            0x80040D07 => ITF::GTHR_E_URL_EXCLUDED,
            0x80040D0A => ITF::GTHR_E_CONFIG_DUP_PROJECT,
            0x80040D0B => ITF::GTHR_E_CONFIG_DUP_EXTENSION,
            0x80040D0D => ITF::GTHR_E_DUPLICATE_URL,
            0x80040D0E => ITF::GTHR_E_TOO_MANY_PLUGINS,
            0x80040D0F => ITF::GTHR_E_INVALIDFUNCTION,
            0x80040D10 => ITF::GTHR_E_NOFILTERSINK,
            0x80040D11 => ITF::GTHR_E_FILTER_PROCESS_TERMINATED,
            0x80040D12 => ITF::GTHR_E_FILTER_INVALID_MESSAGE,
            0x80040D13 => ITF::GTHR_E_UNSUPPORTED_PROPERTY_TYPE,
            0x80040D14 => ITF::GTHR_E_NAME_TOO_LONG,
            0x80040D15 => ITF::GTHR_E_NO_IDENTITY,
            0x80040D16 => ITF::GTHR_E_FILTER_NOT_FOUND,
            0x80040D17 => ITF::GTHR_E_FILTER_NO_MORE_THREADS,
            0x80040D18 => ITF::GTHR_E_PRT_HNDLR_PROGID_MISSING,
            0x80040D19 => ITF::GTHR_E_FILTER_PROCESS_TERMINATED_QUOTA,
            0x80040D1A => ITF::GTHR_E_UNKNOWN_PROTOCOL,
            0x80040D1B => ITF::GTHR_E_PROJECT_NOT_INITIALIZED,
            0x80040D22 => ITF::GTHR_E_INVALID_PROJECT_NAME,
            0x80040D23 => ITF::GTHR_E_SHUTTING_DOWN,
            0x80040D25 => ITF::GTHR_E_VALUE_NOT_AVAILABLE,
            0x80040D26 => ITF::GTHR_E_OUT_OF_DOC_ID,
            0x80040D27 => ITF::GTHR_E_NOTIFICATION_START_PAGE,
            0x80040D2A => ITF::GTHR_E_DUP_PROPERTY_MAPPING,
            0x80040D2C => ITF::GTHR_E_INVALID_ACCOUNT,
            0x80040D2E => ITF::GTHR_E_FILTER_INIT,
            0x80040D2F => ITF::GTHR_E_INVALID_ACCOUNT_SYNTAX,
            0x80040D31 => ITF::GTHR_E_PROXY_NAME,
            0x80040D32 => ITF::GTHR_E_SERVER_UNAVAILABLE,
            0x80040D34 => ITF::GTHR_E_INVALID_PATH,
            0x80040D35 => ITF::GTHR_E_FILTER_NO_CODEPAGE,
            0x80040D37 => ITF::GTHR_E_NO_PRTCLHNLR,
            0x80040D38 => ITF::GTHR_E_IE_OFFLINE,
            0x80040D39 => ITF::GTHR_E_BAD_FILTER_DAEMON,
            0x80040D40 => ITF::GTHR_E_INVALID_MAPPING,
            0x80040D41 => ITF::GTHR_E_USER_AGENT_NOT_SPECIFIED,
            0x80040D43 => ITF::GTHR_E_FROM_NOT_SPECIFIED,
            0x80040D44 => ITF::GTHR_E_INVALID_STREAM_LOGS_COUNT,
            0x80040D45 => ITF::GTHR_E_INVALID_EXTENSION,
            0x80040D46 => ITF::GTHR_E_INVALID_GROW_FACTOR,
            0x80040D47 => ITF::GTHR_E_INVALID_TIME_OUT,
            0x80040D48 => ITF::GTHR_E_INVALID_RETRIES,
            0x80040D49 => ITF::GTHR_E_INVALID_LOG_FILE_NAME,
            0x80040D50 => ITF::GTHR_E_INVALID_HOST_NAME,
            0x80040D51 => ITF::GTHR_E_INVALID_START_PAGE,
            0x80040D52 => ITF::GTHR_E_DUPLICATE_PROJECT,
            0x80040D53 => ITF::GTHR_E_INVALID_DIRECTORY,
            0x80040D54 => ITF::GTHR_E_FILTER_INTERRUPTED,
            0x80040D55 => ITF::GTHR_E_INVALID_PROXY_PORT,
            0x80040D57 => ITF::GTHR_E_SECRET_NOT_FOUND,
            0x80040D58 => ITF::GTHR_E_INVALID_PATH_EXPRESSION,
            0x80040D59 => ITF::GTHR_E_INVALID_START_PAGE_HOST,
            0x80040D60 => ITF::GTHR_E_INVALID_START_PAGE_PATH,
            0x80040D61 => ITF::GTHR_E_APPLICATION_NOT_FOUND,
            0x80040D62 => ITF::GTHR_E_CANNOT_REMOVE_PLUGINMGR,
            0x80040D63 => ITF::GTHR_E_INVALID_APPLICATION_NAME,
            0x80040D65 => ITF::GTHR_E_FILTER_FAULT,
            0x80040D66 => ITF::GTHR_E_NON_FIXED_DRIVE,
            0x80040D6B => ITF::GTHR_E_FILTER_SINGLE_THREADED,
            0x80040D6D => ITF::GTHR_E_URL_UNIDENTIFIED,
            0x80040D6F => ITF::GTHR_E_FORCE_NOTIFICATION_RESET,
            0x80040D72 => ITF::GTHR_E_CONTENT_ID_CONFLICT,
            0x80040D73 => ITF::GTHR_E_UNABLE_TO_READ_EXCHANGE_STORE,
            0x80040D74 => ITF::GTHR_E_RECOVERABLE_EXOLEDB_ERROR,
            0x80040D76 => ITF::GTHR_E_INVALID_CALL_FROM_WBREAKER,
            0x80040D77 => ITF::GTHR_E_PROPERTY_LIST_NOT_INITIALIZED,
            0x80040D79 => ITF::GHTR_E_LOCAL_SERVER_UNAVAILABLE,
            0x80040D7A => ITF::GTHR_E_SCHEMA_ERRORS_OCCURRED,
            0x80040D7B => ITF::GTHR_E_TIMEOUT,
            0x80040D86 => ITF::GTHR_E_NOTIFICATION_START_ADDRESS_INVALID,
            0x80040D87 => ITF::GTHR_E_NOTIFICATION_TYPE_NOT_SUPPORTED,
            0x80040D88 => ITF::GTHR_E_NOTIFICATION_FILE_SHARE_INFO_NOT_AVAILABLE,
            0x80040D89 => ITF::GTHR_E_NOTIFICATION_LOCAL_PATH_MUST_USE_FIXED_DRIVE,
            0x80040D8B => ITF::GHTR_E_INSUFFICIENT_DISK_SPACE,
            0x80040D8D => ITF::GTHR_E_INVALID_RESOURCE_ID,
            0x80040D8E => ITF::GTHR_E_NESTED_HIERARCHICAL_START_ADDRESSES,
            0x80040D95 => ITF::GTHR_E_RETRY,
            0x80040D96 => ITF::GTHR_E_JET_BACKUP_ERROR,
            0x80040D97 => ITF::GTHR_E_JET_RESTORE_ERROR,
            0x80040D9B => ITF::GTHR_E_PLUGIN_NOT_REGISTERED,
            0x80040D9C => ITF::GTHR_E_NOTIF_ACCESS_TOKEN_UPDATED,
            0x80040D9D => ITF::GTHR_E_DIRMON_NOT_INITIALZED,
            0x80040D9E => ITF::GTHR_E_NOTIF_BEING_REMOVED,
            0x80040D9F => ITF::GTHR_E_NOTIF_EXCESSIVE_THROUGHPUT,
            0x80040DA0 => ITF::GTHR_E_INVALID_PATH_SPEC,
            0x80040DA1 => ITF::GTHR_E_INSUFFICIENT_FEATURE_TERMS,
            0x80040DA2 => ITF::GTHR_E_INSUFFICIENT_EXAMPLE_CATEGORIES,
            0x80040DA3 => ITF::GTHR_E_INSUFFICIENT_EXAMPLE_DOCUMENTS,
            0x80040DA4 => ITF::GTHR_E_AUTOCAT_UNEXPECTED,
            0x80040DA5 => ITF::GTHR_E_SINGLE_THREADED_EMBEDDING,
            0x80040DA9 => ITF::GTHR_E_FOLDER_CRAWLED_BY_ANOTHER_WORKSPACE,
            0x80040DAA => ITF::GTHR_E_EMPTY_DACL,
            0x80040DAB => ITF::GTHR_E_OBJECT_NOT_VALID,
            0x80040DAE => ITF::GTHR_E_CANNOT_ENABLE_CHECKPOINT,
            0x80040DAF => ITF::GTHR_E_SCOPES_EXCEEDED,
            0x80040DB0 => ITF::GTHR_E_PROPERTIES_EXCEEDED,
            0x80040DB2 => ITF::GTHR_E_INVALID_START_ADDRESS,
            0x80040DB4 => ITF::GTHR_E_PIPE_NOT_CONNECTTED,
            0x80040DB6 => ITF::GTHR_E_BACKUP_VALIDATION_FAIL,
            0x80040DB7 => ITF::GTHR_E_BAD_FILTER_HOST,
            0x80040DBA => ITF::GTHR_E_FILTERPOOL_NOTFOUND,
            0x80040DBB => ITF::GTHR_E_ADDLINKS_FAILED_WILL_RETRY_PARENT,
            0x80040E00 => ITF::DB_E_BADACCESSORHANDLE,
            0x80040E01 => ITF::DB_E_ROWLIMITEXCEEDED,
            0x80040E02 => ITF::DB_E_READONLYACCESSOR,
            0x80040E03 => ITF::DB_E_SCHEMAVIOLATION,
            0x80040E04 => ITF::DB_E_BADROWHANDLE,
            0x80040E05 => ITF::DB_E_OBJECTOPEN,
            0x80040E06 => ITF::DB_E_BADCHAPTER,
            0x80040E07 => ITF::DB_E_CANTCONVERTVALUE,
            0x80040E08 => ITF::DB_E_BADBINDINFO,
            0x80040E09 => ITF::DB_SEC_E_PERMISSIONDENIED,
            0x80040E0A => ITF::DB_E_NOTAREFERENCECOLUMN,
            0x80040E0B => ITF::DB_E_LIMITREJECTED,
            0x80040E0C => ITF::DB_E_NOCOMMAND,
            0x80040E0D => ITF::DB_E_COSTLIMIT,
            0x80040E0E => ITF::DB_E_BADBOOKMARK,
            0x80040E0F => ITF::DB_E_BADLOCKMODE,
            0x80040E10 => ITF::DB_E_PARAMNOTOPTIONAL,
            0x80040E11 => ITF::DB_E_BADCOLUMNID,
            0x80040E12 => ITF::DB_E_BADRATIO,
            0x80040E13 => ITF::DB_E_BADVALUES,
            0x80040E14 => ITF::DB_E_ERRORSINCOMMAND,
            0x80040E15 => ITF::DB_E_CANTCANCEL,
            0x80040E16 => ITF::DB_E_DIALECTNOTSUPPORTED,
            0x80040E17 => ITF::DB_E_DUPLICATEDATASOURCE,
            0x80040E18 => ITF::DB_E_CANNOTRESTART,
            0x80040E19 => ITF::DB_E_NOTFOUND,
            0x80040E1A => ITF::DB_E_CANNOTFREE,
            0x80040E1B => ITF::DB_E_NEWLYINSERTED,
            0x80040E1C => ITF::DB_E_GOALREJECTED,
            0x80040E1D => ITF::DB_E_UNSUPPORTEDCONVERSION,
            0x80040E1E => ITF::DB_E_BADSTARTPOSITION,
            0x80040E1F => ITF::DB_E_NOQUERY,
            0x80040E20 => ITF::DB_E_NOTREENTRANT,
            0x80040E21 => ITF::DB_E_ERRORSOCCURRED,
            0x80040E22 => ITF::DB_E_NOAGGREGATION,
            0x80040E23 => ITF::DB_E_DELETEDROW,
            0x80040E24 => ITF::DB_E_CANTFETCHBACKWARDS,
            0x80040E25 => ITF::DB_E_ROWSNOTRELEASED,
            0x80040E26 => ITF::DB_E_BADSTORAGEFLAG,
            0x80040E27 => ITF::DB_E_BADCOMPAREOP,
            0x80040E28 => ITF::DB_E_BADSTATUSVALUE,
            0x80040E29 => ITF::DB_E_CANTSCROLLBACKWARDS,
            0x80040E2A => ITF::DB_E_BADREGIONHANDLE,
            0x80040E2B => ITF::DB_E_NONCONTIGUOUSRANGE,
            0x80040E2C => ITF::DB_E_INVALIDTRANSITION,
            0x80040E2D => ITF::DB_E_NOTASUBREGION,
            0x80040E2E => ITF::DB_E_MULTIPLESTATEMENTS,
            0x80040E2F => ITF::DB_E_INTEGRITYVIOLATION,
            0x80040E30 => ITF::DB_E_BADTYPENAME,
            0x80040E31 => ITF::DB_E_ABORTLIMITREACHED,
            0x80040E32 => ITF::DB_E_ROWSETINCOMMAND,
            0x80040E33 => ITF::DB_E_CANTTRANSLATE,
            0x80040E34 => ITF::DB_E_DUPLICATEINDEXID,
            0x80040E35 => ITF::DB_E_NOINDEX,
            0x80040E36 => ITF::DB_E_INDEXINUSE,
            0x80040E37 => ITF::DB_E_NOTABLE,
            0x80040E38 => ITF::DB_E_CONCURRENCYVIOLATION,
            0x80040E39 => ITF::DB_E_BADCOPY,
            0x80040E3A => ITF::DB_E_BADPRECISION,
            0x80040E3B => ITF::DB_E_BADSCALE,
            0x80040E3C => ITF::DB_E_BADTABLEID,
            0x80040E3D => ITF::DB_E_BADTYPE,
            0x80040E3E => ITF::DB_E_DUPLICATECOLUMNID,
            0x80040E3F => ITF::DB_E_DUPLICATETABLEID,
            0x80040E40 => ITF::DB_E_TABLEINUSE,
            0x80040E41 => ITF::DB_E_NOLOCALE,
            0x80040E42 => ITF::DB_E_BADRECORDNUM,
            0x80040E43 => ITF::DB_E_BOOKMARKSKIPPED,
            0x80040E44 => ITF::DB_E_BADPROPERTYVALUE,
            0x80040E45 => ITF::DB_E_INVALID,
            0x80040E46 => ITF::DB_E_BADACCESSORFLAGS,
            0x80040E47 => ITF::DB_E_BADSTORAGEFLAGS,
            0x80040E48 => ITF::DB_E_BYREFACCESSORNOTSUPPORTED,
            0x80040E49 => ITF::DB_E_NULLACCESSORNOTSUPPORTED,
            0x80040E4A => ITF::DB_E_NOTPREPARED,
            0x80040E4B => ITF::DB_E_BADACCESSORTYPE,
            0x80040E4C => ITF::DB_E_WRITEONLYACCESSOR,
            0x80040E4D => ITF::DB_SEC_E_AUTH_FAILED,
            0x80040E4E => ITF::DB_E_CANCELED,
            0x80040E4F => ITF::DB_E_CHAPTERNOTRELEASED,
            0x80040E50 => ITF::DB_E_BADSOURCEHANDLE,
            0x80040E51 => ITF::DB_E_PARAMUNAVAILABLE,
            0x80040E52 => ITF::DB_E_ALREADYINITIALIZED,
            0x80040E53 => ITF::DB_E_NOTSUPPORTED,
            0x80040E54 => ITF::DB_E_MAXPENDCHANGESEXCEEDED,
            0x80040E55 => ITF::DB_E_BADORDINAL,
            0x80040E56 => ITF::DB_E_PENDINGCHANGES,
            0x80040E57 => ITF::DB_E_DATAOVERFLOW,
            0x80040E58 => ITF::DB_E_BADHRESULT,
            0x80040E59 => ITF::DB_E_BADLOOKUPID,
            0x80040E5A => ITF::DB_E_BADDYNAMICERRORID,
            0x80040E5B => ITF::DB_E_PENDINGINSERT,
            0x80040E5C => ITF::DB_E_BADCONVERTFLAG,
            0x80040E5D => ITF::DB_E_BADPARAMETERNAME,
            0x80040E5E => ITF::DB_E_MULTIPLESTORAGE,
            0x80040E5F => ITF::DB_E_CANTFILTER,
            0x80040E60 => ITF::DB_E_CANTORDER,
            0x80040E61 => ITF::MD_E_BADTUPLE,
            0x80040E62 => ITF::MD_E_BADCOORDINATE,
            0x80040E63 => ITF::MD_E_INVALIDAXIS,
            0x80040E64 => ITF::MD_E_INVALIDCELLRANGE,
            0x80040E65 => ITF::DB_E_NOCOLUMN,
            0x80040E67 => ITF::DB_E_COMMANDNOTPERSISTED,
            0x80040E68 => ITF::DB_E_DUPLICATEID,
            0x80040E69 => ITF::DB_E_OBJECTCREATIONLIMITREACHED,
            0x80040E6A => ITF::SEC_E_BADTRUSTEEID,
            0x80040E6B => ITF::SEC_E_NOTRUSTEEID,
            0x80040E6C => ITF::SEC_E_NOMEMBERSHIPSUPPORT,
            0x80040E6D => ITF::SEC_E_INVALIDOBJECT,
            0x80040E6E => ITF::SEC_E_NOOWNER,
            0x80040E6F => ITF::SEC_E_INVALIDACCESSENTRYLIST,
            0x80040E70 => ITF::SEC_E_INVALIDOWNER,
            0x80040E71 => ITF::SEC_E_INVALIDACCESSENTRY,
            0x80040E72 => ITF::DB_E_BADINDEXID,
            0x80040E73 => ITF::DB_E_BADINITSTRING,
            0x80040E74 => ITF::DB_E_NOPROVIDERSREGISTERED,
            0x80040E75 => ITF::DB_E_MISMATCHEDPROVIDER,
            0x80040E76 => ITF::DB_E_BADCOMMANDID,
            0x80040E77 => ITF::DB_E_BADCONSTRAINTTYPE,
            0x80040E78 => ITF::DB_E_BADCONSTRAINTFORM,
            0x80040E79 => ITF::DB_E_BADDEFERRABILITY,
            0x80040E80 => ITF::DB_E_BADMATCHTYPE,
            0x80040E8A => ITF::DB_E_BADUPDATEDELETERULE,
            0x80040E8B => ITF::DB_E_BADCONSTRAINTID,
            0x80040E8C => ITF::DB_E_BADCOMMANDFLAGS,
            0x80040E8D => ITF::DB_E_OBJECTMISMATCH,
            0x80040E8E => ITF::DB_E_RESOURCEOUTOFSCOPE,
            0x80040E90 => ITF::DB_E_DROPRESTRICTED,
            0x80040E91 => ITF::DB_E_NOSOURCEOBJECT,
            0x80040E92 => ITF::DB_E_RESOURCELOCKED,
            0x80040E93 => ITF::DB_E_NOTCOLLECTION,
            0x80040E94 => ITF::DB_E_READONLY,
            0x80040E95 => ITF::DB_E_ASYNCNOTSUPPORTED,
            0x80040E96 => ITF::DB_E_CANNOTCONNECT,
            0x80040E97 => ITF::DB_E_TIMEOUT,
            0x80040E98 => ITF::DB_E_RESOURCEEXISTS,
            0x80040E99 => ITF::DB_E_DUPLICATECONSTRAINTID,
            0x80040E9A => ITF::DB_E_OUTOFSPACE,
            0x80040E9B => ITF::DB_SEC_E_SAFEMODE_DENIED,
            0x80040E9C => ITF::DB_E_NOSTATISTIC,
            0x80040E9D => ITF::DB_E_ALTERRESTRICTED,
            0x80040E9E => ITF::DB_E_RESOURCENOTSUPPORTED,
            0x80040E9F => ITF::DB_E_NOCONSTRAINT,
            0x80040EA0 => ITF::DB_E_COLUMNUNAVAILABLE,
            0x80040EFF => ITF::DB_E_BOGUS,
            0x80041000 => ITF::DXVA2_E_NOT_INITIALIZED,
            0x80041000 => ITF::MF_E_DXGI_DEVICE_NOT_INITIALIZED,
            0x80041000 => ITF::SYNC_E_ID_FORMAT_MISMATCH,
            0x80041000 => ITF::REC_E_ABORTED,
            0x80041000 => ITF::ROUTER_E_NOTINTERESTED,
            0x80041001 => ITF::DXVA2_E_NEW_VIDEO_DEVICE,
            0x80041001 => ITF::MF_E_DXGI_NEW_VIDEO_DEVICE,
            0x80041001 => ITF::SYNC_E_INVALID_OPERATION,
            0x80041001 => ITF::REC_E_NOCALLBACK,
            0x80041002 => ITF::DXVA2_E_VIDEO_DEVICE_LOCKED,
            0x80041002 => ITF::MF_E_DXGI_VIDEO_DEVICE_LOCKED,
            0x80041002 => ITF::SYNC_E_REPLICA_NOT_FOUND,
            0x80041002 => ITF::REC_E_NORESIDUES,
            0x80041002 => ITF::SEO_E_NOTPRESENT,
            0x80041003 => ITF::DXVA2_E_NOT_AVAILABLE,
            0x80041003 => ITF::SYNC_E_CHANGE_COUNT_MISMATCH,
            0x80041003 => ITF::REC_E_TOODIFFERENT,
            0x80041003 => ITF::SEO_E_TIMEOUT,
            0x80041004 => ITF::SYNC_E_CHANGE_UNIT_COUNT_MISMATCH,
            0x80041004 => ITF::REC_E_INEEDTODOTHEUPDATES,
            0x80041004 => ITF::SEO_S_DONEPROCESSING,
            0x80041005 => ITF::SYNC_E_KNOWLEDGE_DECREASED,
            0x80041005 => ITF::EVENTS_E_BADDATA,
            0x80041006 => ITF::SYNC_E_CHANGE_NOT_IN_KNOWLEDGE,
            0x80041006 => ITF::EVENTS_E_TIMEOUT,
            0x80041007 => ITF::SYNC_E_ITEM_MUST_EXIST,
            0x80041007 => ITF::EVENTS_E_DISABLED,
            0x80041008 => ITF::SYNC_E_HAS_NO_DATA,
            0x80041009 => ITF::SYNC_E_CHANGE_NEEDS_KNOWLEDGE,
            0x8004100A => ITF::SYNC_E_RANGE_OUT_OF_ORDER,
            0x8004100B => ITF::SYNC_E_NOT_EXPECTED_CHANGE,
            0x8004100C => ITF::SYNC_E_DESERIALIZATION,
            0x8004100D => ITF::SYNC_E_SINGLE_RANGE_ONLY,
            0x8004100E => ITF::SYNC_E_ITEM_HAS_CHANGE_UNITS,
            0x8004100F => ITF::SYNC_E_ITEM_HAS_NO_CHANGE_UNITS,
            0x80041010 => ITF::SYNC_E_ITEM_HAS_NO_VERSION_DATA,
            0x80041011 => ITF::SYNC_E_OBJECT_NEEDS_STATE,
            0x80041012 => ITF::SYNC_E_FEEDSYNC_INVALID_FEED,
            0x80041013 => ITF::SYNC_E_FEEDSYNC_ITEM_NOT_IN_METADATA,
            0x80041014 => ITF::SYNC_E_FEEDSYNC_CALLBACK_EXPECTED,
            0x80041015 => ITF::SYNC_E_INVALID_VERSION,
            0x80041016 => ITF::SYNC_E_DUPLICATE_ITEM,
            0x80041017 => ITF::SYNC_E_INVALID_ORDER_FOR_VECTOR_ELEMENTS,
            0x80041018 => ITF::SYNC_E_INVALID_SYNC_TIME,
            0x80041019 => ITF::SYNC_E_INCOMPLETE_REPLICA_KEY_MAP,
            0x8004101A => ITF::SYNC_E_INVALID_REPLICA_KEY,
            0x8004101B => ITF::SYNC_E_NEGATIVE_RANGE_EXCEPTION,
            0x8004101C => ITF::SYNC_E_BATCH_NEEDS_KNOWLEDGE,
            0x8004101D => ITF::SYNC_E_INTERNAL_ERROR,
            0x8004101E => ITF::SYNC_E_CHANGE_BATCH_IS_READ_ONLY,
            0x8004101F => ITF::SYNC_E_DATA_MODIFIED_CONCURRENTLY,
            0x80041020 => ITF::SYNC_E_ON_CREATE_MUST_FAIL_ENTIRE_ITEM,
            0x80041021 => ITF::SYNC_E_FILTER_NOT_SUPPORTED,
            0x80041022 => ITF::SYNC_E_LOAD_CONFLICT_DATA_FAILED,
            0x80041023 => ITF::SYNC_E_INVALID_SERIALIZATION_VERSION,
            0x80041024 => ITF::SYNC_E_MARKER_MISMATCH,
            0x80041025 => ITF::SYNC_E_FORGOTTEN_KNOWLEDGE_NOT_CONTAINED,
            0x80041026 => ITF::SYNC_E_ACTIVE_CHANGE_APPLICATION_CONTEXT,
            0x80041027 => ITF::SYNC_E_ITEM_LIST_FILTERED_FULL_ENUMERATION_NOT_SUPPORTED,
            0x80041028 => ITF::SYNC_E_FULL_ENUMERATION_MUST_BE_USED,
            0x80041029 => ITF::SYNC_E_BATCH_NEEDS_FILTER_FORGOTTEN_KNOWLEDGE,
            0x8004102A => ITF::SYNC_E_CONSTRAINT_CONFLICT_NOT_ALLOWED,
            0x8004102B => ITF::SYNC_E_SOURCE_DOES_NOT_TRACK_FILTER,
            0x80041101 => ITF::IDX_E_INVALIDTAG,
            0x80041102 => ITF::IDX_E_METAFILE_CORRUPT,
            0x80041103 => ITF::IDX_E_TOO_MANY_SEARCH_SERVERS,
            0x80041104 => ITF::IDX_E_SEARCH_SERVER_ALREADY_EXISTS,
            0x80041105 => ITF::IDX_E_BUILD_IN_PROGRESS,
            0x80041106 => ITF::IDX_E_IDXLSTFILE_CORRUPT,
            0x80041107 => ITF::IDX_E_REGISTRY_ENTRY,
            0x80041108 => ITF::IDX_E_OBJECT_NOT_FOUND,
            0x80041109 => ITF::IDX_E_SEARCH_SERVER_NOT_FOUND,
            0x8004110A => ITF::IDX_E_WB_NOTFOUND,
            0x8004110B => ITF::IDX_E_NOISELIST_NOTFOUND,
            0x8004110C => ITF::IDX_E_STEMMER_NOTFOUND,
            0x8004110D => ITF::IDX_E_PROP_STOPPED,
            0x8004110E => ITF::IDX_E_DISKFULL,
            0x8004110F => ITF::IDX_E_INVALID_INDEX,
            0x80041110 => ITF::IDX_E_CORRUPT_INDEX,
            0x80041112 => ITF::IDX_E_PROPSTORE_INIT_FAILED,
            0x80041113 => ITF::IDX_E_PROP_STATE_CORRUPT,
            0x80041117 => ITF::IDX_E_NOT_LOADED,
            0x80041118 => ITF::IDX_E_PROP_MAJOR_VERSION_MISMATCH,
            0x80041119 => ITF::IDX_E_PROP_MINOR_VERSION_MISMATCH,
            0x8004111A => ITF::IDX_E_DSS_NOT_CONNECTED,
            0x8004111B => ITF::IDX_E_DOCUMENT_ABORTED,
            0x8004111C => ITF::IDX_E_CATALOG_DISMOUNTED,
            0x8004111F => ITF::IDX_E_USE_DEFAULT_CONTENTCLASS,
            0x80041120 => ITF::IDX_E_USE_APPGLOBAL_PROPTABLE,
            0x8004117F => ITF::JPS_E_JET_ERR,
            0x80041181 => ITF::JPS_E_CATALOG_DECSRIPTION_MISSING,
            0x80041182 => ITF::JPS_E_MISSING_INFORMATION,
            0x80041183 => ITF::JPS_E_INSUFFICIENT_VERSION_STORAGE,
            0x80041184 => ITF::JPS_E_INSUFFICIENT_DATABASE_SESSIONS,
            0x80041185 => ITF::JPS_E_INSUFFICIENT_DATABASE_RESOURCES,
            0x80041186 => ITF::JPS_E_SCHEMA_ERROR,
            0x80041187 => ITF::JPS_E_PROPAGATION_FILE,
            0x80041188 => ITF::JPS_E_PROPAGATION_CORRUPTION,
            0x80041189 => ITF::JPS_E_PROPAGATION_VERSION_MISMATCH,
            0x8004118A => ITF::JPS_E_SHARING_VIOLATION,
            0x800411A0 => ITF::EXCI_E_NO_CONFIG,
            0x800411A1 => ITF::EXCI_E_INVALID_SERVER_CONFIG,
            0x800411A2 => ITF::EXCI_E_ACCESS_DENIED,
            0x800411A3 => ITF::EXCI_E_INVALID_EXCHANGE_SERVER,
            0x800411A4 => ITF::EXCI_E_BADCONFIG_OR_ACCESSDENIED,
            0x800411A5 => ITF::EXCI_E_WRONG_SERVER_OR_ACCT,
            0x800411A6 => ITF::EXCI_E_NOT_ADMIN_OR_WRONG_SITE,
            0x800411A7 => ITF::EXCI_E_NO_MAPI,
            0x800411A8 => ITF::EXCI_E_INVALID_ACCOUNT_INFO,
            0x80041200 => ITF::PRTH_E_COMM_ERROR,
            0x80041201 => ITF::PRTH_E_OBJ_NOT_FOUND,
            0x80041202 => ITF::PRTH_E_REQUEST_ERROR,
            0x80041204 => ITF::PRTH_E_INTERNAL_ERROR,
            0x80041205 => ITF::PRTH_E_ACCESS_DENIED,
            0x80041206 => ITF::PRTH_E_SERVER_ERROR,
            0x80041207 => ITF::PRTH_E_NOT_REDIRECTED,
            0x80041208 => ITF::PRTH_E_BAD_REQUEST,
            0x80041209 => ITF::PRTH_E_HTTP_CANNOT_CONNECT,
            0x8004120A => ITF::PRTH_E_WININET,
            0x8004120B => ITF::PRTH_E_RETRY,
            0x8004120D => ITF::PRTH_E_MIME_EXCLUDED,
            0x8004120E => ITF::PRTH_E_CANT_TRANSFORM_EXTERNAL_ACL,
            0x8004120F => ITF::PRTH_E_CANT_TRANSFORM_DENIED_ACE,
            0x80041211 => ITF::PRTH_E_ACL_IS_READ_NONE,
            0x80041212 => ITF::PRTH_E_ACL_TOO_BIG,
            0x80041213 => ITF::PRTH_E_NO_PROPERTY,
            0x80041215 => ITF::PRTH_E_DATABASE_OPEN_ERROR,
            0x80041216 => ITF::PRTH_E_OPLOCK_BROKEN,
            0x80041217 => ITF::PRTH_E_LOAD_FAILED,
            0x80041218 => ITF::PRTH_E_INIT_FAILED,
            0x80041219 => ITF::PRTH_E_VOLUME_MOUNT_POINT,
            0x8004121A => ITF::PRTH_E_TRUNCATED,
            0x8004121D => ITF::GTHR_E_LOCAL_GROUPS_EXPANSION_INTERNAL_ERROR,
            0x80041223 => ITF::PRTH_E_HTTPS_CERTIFICATE_ERROR,
            0x80041224 => ITF::PRTH_E_HTTPS_REQUIRE_CERTIFICATE,
            0x80041309 => ITF::SCHED_E_TRIGGER_NOT_FOUND,
            0x8004130A => ITF::SCHED_E_TASK_NOT_READY,
            0x8004130B => ITF::SCHED_E_TASK_NOT_RUNNING,
            0x8004130C => ITF::SCHED_E_SERVICE_NOT_INSTALLED,
            0x8004130D => ITF::SCHED_E_CANNOT_OPEN_TASK,
            0x8004130E => ITF::SCHED_E_INVALID_TASK,
            0x8004130F => ITF::SCHED_E_ACCOUNT_INFORMATION_NOT_SET,
            0x80041310 => ITF::SCHED_E_ACCOUNT_NAME_NOT_FOUND,
            0x80041311 => ITF::SCHED_E_ACCOUNT_DBASE_CORRUPT,
            0x80041312 => ITF::SCHED_E_NO_SECURITY_SERVICES,
            0x80041313 => ITF::SCHED_E_UNKNOWN_OBJECT_VERSION,
            0x80041314 => ITF::SCHED_E_UNSUPPORTED_ACCOUNT_OPTION,
            0x80041315 => ITF::SCHED_E_SERVICE_NOT_RUNNING,
            0x80041316 => ITF::SCHED_E_UNEXPECTEDNODE,
            0x80041317 => ITF::SCHED_E_NAMESPACE,
            0x80041318 => ITF::SCHED_E_INVALIDVALUE,
            0x80041319 => ITF::SCHED_E_MISSINGNODE,
            0x8004131A => ITF::SCHED_E_MALFORMEDXML,
            0x8004131D => ITF::SCHED_E_TOO_MANY_NODES,
            0x8004131E => ITF::SCHED_E_PAST_END_BOUNDARY,
            0x8004131F => ITF::SCHED_E_ALREADY_RUNNING,
            0x80041320 => ITF::SCHED_E_USER_NOT_LOGGED_ON,
            0x80041321 => ITF::SCHED_E_INVALID_TASK_HASH,
            0x80041322 => ITF::SCHED_E_SERVICE_NOT_AVAILABLE,
            0x80041323 => ITF::SCHED_E_SERVICE_TOO_BUSY,
            0x80041324 => ITF::SCHED_E_TASK_ATTEMPTED,
            0x80041326 => ITF::SCHED_E_TASK_DISABLED,
            0x80041327 => ITF::SCHED_E_TASK_NOT_V1_COMPAT,
            0x80041328 => ITF::SCHED_E_START_ON_DEMAND,
            0x80041329 => ITF::SCHED_E_TASK_NOT_UBPM_COMPAT,
            0x80041330 => ITF::SCHED_E_DEPRECATED_FEATURE_USED,
            0x80041401 => ITF::SEC_E_INITFAILED,
            0x80041402 => ITF::SEC_E_NOTINITIALIZED,
            0x80041403 => ITF::SEC_E_INVALIDCONTEXT,
            0x800414FF => ITF::SEC_E_ACCESSDENIED,
            0x80041501 => ITF::CMDLINE_E_UNEXPECTED,
            0x80041502 => ITF::CMDLINE_E_PAREN,
            0x80041503 => ITF::CMDLINE_E_PARAM_SIZE,
            0x80041504 => ITF::CMDLINE_E_NOT_INIT,
            0x80041505 => ITF::CMDLINE_E_ALREADY_INIT,
            0x80041506 => ITF::CMDLINE_E_NUM_PARAMS,
            0x80041600 => ITF::QUERY_E_FAILED,
            0x80041600 => ITF::SYNC_E_REGISTRATION_INTERNAL_ERROR,
            0x80041601 => ITF::QUERY_E_INVALIDQUERY,
            0x80041601 => ITF::SYNC_E_REGISTRATION_ALREADY_REGISTERED,
            0x80041602 => ITF::QUERY_E_INVALIDRESTRICTION,
            0x80041602 => ITF::SYNC_E_REGISTRATION_NOT_REGISTERED,
            0x80041603 => ITF::QUERY_E_INVALIDSORT,
            0x80041603 => ITF::SYNC_E_REGISTRATION_CORRUPT_DATA,
            0x80041604 => ITF::QUERY_E_INVALIDCATEGORIZE,
            0x80041604 => ITF::SYNC_E_REGISTRATION_ALREADY_COMMITTED,
            0x80041605 => ITF::QUERY_E_ALLNOISE,
            0x80041606 => ITF::QUERY_E_TOOCOMPLEX,
            0x80041607 => ITF::QUERY_E_TIMEDOUT,
            0x80041608 => ITF::QUERY_E_DUPLICATE_OUTPUT_COLUMN,
            0x80041609 => ITF::QUERY_E_INVALID_OUTPUT_COLUMN,
            0x8004160A => ITF::QUERY_E_INVALID_DIRECTORY,
            0x8004160B => ITF::QUERY_E_DIR_ON_REMOVABLE_DRIVE,
            0x8004160C => ITF::QUERY_S_NO_QUERY,
            0x8004160D => ITF::QUERY_E_ALLNOISE_AND_NO_RELDOC,
            0x8004160E => ITF::QUERY_E_NO_RELDOC,
            0x8004160F => ITF::QUERY_E_ALLNOISE_AND_NO_RELPROP,
            0x80041610 => ITF::QUERY_E_NO_RELPROP,
            0x80041611 => ITF::QUERY_E_REPEATED_RELDOC,
            0x80041612 => ITF::QUERY_E_RELDOC_SYNTAX_NOT_SUPPORTED,
            0x80041613 => ITF::QUERY_E_INVALID_DOCUMENT_IDENTIFIER,
            0x80041614 => ITF::QUERY_E_INCORRECT_VERSION,
            0x80041615 => ITF::QUERY_E_INVALIDSCOPE_COALESCE,
            0x80041616 => ITF::QUERY_E_INVALIDSORT_COALESCE,
            0x80041617 => ITF::QUERY_E_INVALIDCOALESCE,
            0x80041618 => ITF::QUERY_E_UPGRADEINPROGRESS,
            0x80041619 => ITF::QUERY_E_AGGREGATE_NOT_SUPPORTED,
            0x8004161A => ITF::QUERY_E_TOP_LEVEL_IN_GROUP,
            0x8004161B => ITF::QUERY_E_DUPLICATE_RANGE_NAME,
            0x80041651 => ITF::QPLIST_E_CANT_OPEN_FILE,
            0x80041652 => ITF::QPLIST_E_READ_ERROR,
            0x80041653 => ITF::QPLIST_E_EXPECTING_NAME,
            0x80041654 => ITF::QPLIST_E_EXPECTING_TYPE,
            0x80041655 => ITF::QPLIST_E_UNRECOGNIZED_TYPE,
            0x80041656 => ITF::QPLIST_E_EXPECTING_INTEGER,
            0x80041657 => ITF::QPLIST_E_EXPECTING_CLOSE_PAREN,
            0x80041658 => ITF::QPLIST_E_EXPECTING_GUID,
            0x80041659 => ITF::QPLIST_E_BAD_GUID,
            0x8004165A => ITF::QPLIST_E_EXPECTING_PROP_SPEC,
            0x8004165B => ITF::QPLIST_E_CANT_SET_PROPERTY,
            0x8004165C => ITF::QPLIST_E_DUPLICATE,
            0x8004165D => ITF::QPLIST_E_VECTORBYREF_USED_ALONE,
            0x8004165E => ITF::QPLIST_E_BYREF_USED_WITHOUT_PTRTYPE,
            0x80041660 => ITF::QPARSE_E_UNEXPECTED_NOT,
            0x80041661 => ITF::QPARSE_E_EXPECTING_INTEGER,
            0x80041662 => ITF::QPARSE_E_EXPECTING_REAL,
            0x80041663 => ITF::QPARSE_E_EXPECTING_DATE,
            0x80041664 => ITF::QPARSE_E_EXPECTING_CURRENCY,
            0x80041665 => ITF::QPARSE_E_EXPECTING_GUID,
            0x80041666 => ITF::QPARSE_E_EXPECTING_BRACE,
            0x80041667 => ITF::QPARSE_E_EXPECTING_PAREN,
            0x80041668 => ITF::QPARSE_E_EXPECTING_PROPERTY,
            0x80041669 => ITF::QPARSE_E_NOT_YET_IMPLEMENTED,
            0x8004166A => ITF::QPARSE_E_EXPECTING_PHRASE,
            0x8004166B => ITF::QPARSE_E_UNSUPPORTED_PROPERTY_TYPE,
            0x8004166C => ITF::QPARSE_E_EXPECTING_REGEX,
            0x8004166D => ITF::QPARSE_E_EXPECTING_REGEX_PROPERTY,
            0x8004166E => ITF::QPARSE_E_INVALID_LITERAL,
            0x8004166F => ITF::QPARSE_E_NO_SUCH_PROPERTY,
            0x80041670 => ITF::QPARSE_E_EXPECTING_EOS,
            0x80041671 => ITF::QPARSE_E_EXPECTING_COMMA,
            0x80041672 => ITF::QPARSE_E_UNEXPECTED_EOS,
            0x80041673 => ITF::QPARSE_E_WEIGHT_OUT_OF_RANGE,
            0x80041674 => ITF::QPARSE_E_NO_SUCH_SORT_PROPERTY,
            0x80041675 => ITF::QPARSE_E_INVALID_SORT_ORDER,
            0x80041676 => ITF::QUTIL_E_CANT_CONVERT_VROOT,
            0x80041677 => ITF::QPARSE_E_INVALID_GROUPING,
            0x8004167A => ITF::QPARSE_E_INVALID_QUERY,
            0x8004167B => ITF::QPARSE_E_INVALID_RANKMETHOD,
            0x80041681 => ITF::FDAEMON_E_LOWRESOURCE,
            0x80041682 => ITF::FDAEMON_E_FATALERROR,
            0x80041683 => ITF::FDAEMON_E_PARTITIONDELETED,
            0x80041684 => ITF::FDAEMON_E_CHANGEUPDATEFAILED,
            0x80041686 => ITF::FDAEMON_E_WORDLISTCOMMITFAILED,
            0x80041687 => ITF::FDAEMON_E_NOWORDLIST,
            0x80041688 => ITF::FDAEMON_E_TOOMANYFILTEREDBLOCKS,
            0x800416A1 => ITF::SEARCH_E_NOMONIKER,
            0x800416A2 => ITF::SEARCH_E_NOREGION,
            0x80041700 => ITF::FILTER_E_END_OF_CHUNKS,
            0x80041701 => ITF::FILTER_E_NO_MORE_TEXT,
            0x80041702 => ITF::FILTER_E_NO_MORE_VALUES,
            0x80041703 => ITF::FILTER_E_ACCESS,
            0x80041705 => ITF::FILTER_E_NO_TEXT,
            0x80041706 => ITF::FILTER_E_NO_VALUES,
            0x80041707 => ITF::FILTER_E_EMBEDDING_UNAVAILABLE,
            0x80041708 => ITF::FILTER_E_LINK_UNAVAILABLE,
            0x8004170B => ITF::FILTER_E_PASSWORD,
            0x8004170C => ITF::FILTER_E_UNKNOWNFORMAT,
            0x80041730 => ITF::FILTER_E_TOO_BIG,
            0x80041736 => ITF::FILTER_E_ALREADY_OPEN,
            0x80041737 => ITF::FILTER_E_UNREACHABLE,
            0x80041738 => ITF::FILTER_E_IN_USE,
            0x80041739 => ITF::FILTER_E_NOT_OPEN,
            0x8004173B => ITF::FILTER_E_NO_SUCH_PROPERTY,
            0x8004173D => ITF::FILTER_E_OFFLINE,
            0x8004173E => ITF::FILTER_E_PARTIALLY_FILTERED,
            0x80041780 => ITF::WBREAK_E_END_OF_TEXT,
            0x80041782 => ITF::WBREAK_E_QUERY_ONLY,
            0x80041783 => ITF::WBREAK_E_BUFFER_TOO_SMALL,
            0x80041784 => ITF::LANGUAGE_E_DATABASE_NOT_FOUND,
            0x80041785 => ITF::WBREAK_E_INIT_FAILED,
            0x80041790 => ITF::PSINK_E_QUERY_ONLY,
            0x80041791 => ITF::PSINK_E_INDEX_ONLY,
            0x80041792 => ITF::PSINK_E_LARGE_ATTACHMENT,
            0x8004180A => ITF::CI_E_ALREADY_INITIALIZED,
            0x8004180B => ITF::CI_E_NOT_INITIALIZED,
            0x8004180C => ITF::CI_E_BUFFERTOOSMALL,
            0x8004180D => ITF::CI_E_PROPERTY_NOT_CACHED,
            0x8004180F => ITF::CI_E_INVALID_STATE,
            0x80041810 => ITF::CI_E_FILTERING_DISABLED,
            0x80041811 => ITF::CI_E_DISK_FULL,
            0x80041812 => ITF::CI_E_SHUTDOWN,
            0x80041813 => ITF::CI_E_WORKID_NOTVALID,
            0x80041815 => ITF::CI_E_NOT_FOUND,
            0x80041816 => ITF::CI_E_USE_DEFAULT_PID,
            0x80041817 => ITF::CI_E_DUPLICATE_NOTIFICATION,
            0x80041818 => ITF::CI_E_UPDATES_DISABLED,
            0x80041819 => ITF::CI_E_INVALID_FLAGS_COMBINATION,
            0x8004181A => ITF::CI_E_OUTOFSEQ_INCREMENT_DATA,
            0x8004181B => ITF::CI_E_SHARING_VIOLATION,
            0x8004181C => ITF::CI_E_LOGON_FAILURE,
            0x8004181D => ITF::CI_E_NO_CATALOG,
            0x8004181E => ITF::CI_E_STRANGE_PAGEORSECTOR_SIZE,
            0x8004181F => ITF::CI_E_TIMEOUT,
            0x80041820 => ITF::CI_E_NOT_RUNNING,
            0x80041827 => ITF::CI_E_CARDINALITY_MISMATCH,
            0x80041828 => ITF::CI_E_CONFIG_DISK_FULL,
            0x80041829 => ITF::CI_E_DISTRIBUTED_GROUPBY_UNSUPPORTED,
            0x8004182A => ITF::CI_E_NO_AUXMETADATA,
            0x8004182F => ITF::CI_E_INVALID_CATALOG_LIST_VERSION,
            0x80041901 => ITF::NLADMIN_E_DUPLICATE_CATALOG,
            0x80041903 => ITF::NLADMIN_E_FAILED_TO_GIVE_ACCOUNT_PRIVILEGE,
            0x80041904 => ITF::NLADMIN_E_BUILD_CATALOG_NOT_INITIALIZED,
            0x80041B59 => ITF::FAX_E_SRV_OUTOFMEMORY,
            0x80041B5A => ITF::FAX_E_GROUP_NOT_FOUND,
            0x80041B5B => ITF::FAX_E_BAD_GROUP_CONFIGURATION,
            0x80041B5C => ITF::FAX_E_GROUP_IN_USE,
            0x80041B5D => ITF::FAX_E_RULE_NOT_FOUND,
            0x80041B5E => ITF::FAX_E_NOT_NTFS,
            0x80041B5F => ITF::FAX_E_DIRECTORY_IN_USE,
            0x80041B60 => ITF::FAX_E_FILE_ACCESS_DENIED,
            0x80041B61 => ITF::FAX_E_MESSAGE_NOT_FOUND,
            0x80041B62 => ITF::FAX_E_DEVICE_NUM_LIMIT_EXCEEDED,
            0x80041B63 => ITF::FAX_E_NOT_SUPPORTED_ON_THIS_SKU,
            0x80041B64 => ITF::FAX_E_VERSION_MISMATCH,
            0x80041B65 => ITF::FAX_E_RECIPIENTS_LIMIT,
            0x80042000 => ITF::SCRIPTPI_E_CHUNK_NOT_TEXT,
            0x80042001 => ITF::SCRIPTPI_E_PID_NOT_NAME,
            0x80042002 => ITF::SCRIPTPI_E_PID_NOT_NUMERIC,
            0x80042003 => ITF::SCRIPTPI_E_CHUNK_NOT_VALUE,
            0x80042004 => ITF::SCRIPTPI_E_CANNOT_ALTER_CHUNK,
            0x80042005 => ITF::SCRIPTPI_E_ALREADY_COMPLETED,
            0x80042100 => ITF::MSS_E_INVALIDAPPNAME,
            0x80042101 => ITF::MSS_E_APPNOTFOUND,
            0x80042102 => ITF::MSS_E_APPALREADYEXISTS,
            0x80042103 => ITF::MSS_E_CATALOGNOTFOUND,
            0x80042104 => ITF::MSS_E_CATALOGSTOPPING,
            0x80042105 => ITF::MSS_E_UNICODEFILEHEADERMISSING,
            0x80042106 => ITF::MSS_E_CATALOGALREADYEXISTS,
            0x80042200 => ITF::XML_E_NODEFAULTNS,
            0x80042201 => ITF::XML_E_BADSXQL,
            0x80042301 => ITF::VSS_E_BAD_STATE,
            0x80042302 => ITF::VSS_E_UNEXPECTED,
            0x80042303 => ITF::VSS_E_PROVIDER_ALREADY_REGISTERED,
            0x80042304 => ITF::VSS_E_PROVIDER_NOT_REGISTERED,
            0x80042306 => ITF::VSS_E_PROVIDER_VETO,
            0x80042307 => ITF::VSS_E_PROVIDER_IN_USE,
            0x80042308 => ITF::VSS_E_OBJECT_NOT_FOUND,
            0x8004230C => ITF::VSS_E_VOLUME_NOT_SUPPORTED,
            0x8004230D => ITF::VSS_E_OBJECT_ALREADY_EXISTS,
            0x8004230E => ITF::VSS_E_VOLUME_NOT_SUPPORTED_BY_PROVIDER,
            0x8004230F => ITF::VSS_E_UNEXPECTED_PROVIDER_ERROR,
            0x80042310 => ITF::VSS_E_CORRUPT_XML_DOCUMENT,
            0x80042311 => ITF::VSS_E_INVALID_XML_DOCUMENT,
            0x80042312 => ITF::VSS_E_MAXIMUM_NUMBER_OF_VOLUMES_REACHED,
            0x80042313 => ITF::VSS_E_FLUSH_WRITES_TIMEOUT,
            0x80042314 => ITF::VSS_E_HOLD_WRITES_TIMEOUT,
            0x80042315 => ITF::VSS_E_UNEXPECTED_WRITER_ERROR,
            0x80042316 => ITF::VSS_E_SNAPSHOT_SET_IN_PROGRESS,
            0x80042317 => ITF::VSS_E_MAXIMUM_NUMBER_OF_SNAPSHOTS_REACHED,
            0x80042318 => ITF::VSS_E_WRITER_INFRASTRUCTURE,
            0x80042319 => ITF::VSS_E_WRITER_NOT_RESPONDING,
            0x8004231A => ITF::VSS_E_WRITER_ALREADY_SUBSCRIBED,
            0x8004231B => ITF::VSS_E_UNSUPPORTED_CONTEXT,
            0x8004231D => ITF::VSS_E_VOLUME_IN_USE,
            0x8004231E => ITF::VSS_E_MAXIMUM_DIFFAREA_ASSOCIATIONS_REACHED,
            0x8004231F => ITF::VSS_E_INSUFFICIENT_STORAGE,
            0x80042320 => ITF::VSS_E_NO_SNAPSHOTS_IMPORTED,
            0x80042321 => ITF::VSS_E_SOME_SNAPSHOTS_NOT_IMPORTED,
            0x80042322 => ITF::VSS_E_MAXIMUM_NUMBER_OF_REMOTE_MACHINES_REACHED,
            0x80042323 => ITF::VSS_E_REMOTE_SERVER_UNAVAILABLE,
            0x80042324 => ITF::VSS_E_REMOTE_SERVER_UNSUPPORTED,
            0x80042325 => ITF::VSS_E_REVERT_IN_PROGRESS,
            0x80042326 => ITF::VSS_E_REVERT_VOLUME_LOST,
            0x80042327 => ITF::VSS_E_REBOOT_REQUIRED,
            0x80042328 => ITF::VSS_E_TRANSACTION_FREEZE_TIMEOUT,
            0x80042329 => ITF::VSS_E_TRANSACTION_THAW_TIMEOUT,
            0x8004232A => ITF::VSS_E_UNSELECTED_VOLUME,
            0x8004232B => ITF::VSS_E_SNAPSHOT_NOT_IN_SET,
            0x8004232C => ITF::VSS_E_NESTED_VOLUME_LIMIT,
            0x8004232D => ITF::VSS_E_VOLUME_NOT_LOCAL,
            0x8004232E => ITF::VSS_E_CLUSTER_TIMEOUT,
            0x8004232F => ITF::VSS_E_NOT_SUPPORTED,
            0x80042336 => ITF::VSS_E_WRITERERROR_PARTIAL_FAILURE,
            0x800423F0 => ITF::VSS_E_WRITERERROR_INCONSISTENTSNAPSHOT,
            0x800423F1 => ITF::VSS_E_WRITERERROR_OUTOFRESOURCES,
            0x800423F2 => ITF::VSS_E_WRITERERROR_TIMEOUT,
            0x800423F3 => ITF::VSS_E_WRITERERROR_RETRYABLE,
            0x800423F4 => ITF::VSS_E_WRITERERROR_NONRETRYABLE,
            0x800423F5 => ITF::VSS_E_WRITERERROR_RECOVERY_FAILED,
            0x800423F6 => ITF::VSS_E_BREAK_REVERT_ID_FAILED,
            0x800423F7 => ITF::VSS_E_LEGACY_PROVIDER,
            0x800423F8 => ITF::VSS_E_MISSING_DISK,
            0x800423F9 => ITF::VSS_E_MISSING_HIDDEN_VOLUME,
            0x800423FA => ITF::VSS_E_MISSING_VOLUME,
            0x800423FB => ITF::VSS_E_AUTORECOVERY_FAILED,
            0x800423FC => ITF::VSS_E_DYNAMIC_DISK_ERROR,
            0x800423FD => ITF::VSS_E_NONTRANSPORTABLE_BCD,
            0x800423FE => ITF::VSS_E_CANNOT_REVERT_DISKID,
            0x800423FF => ITF::VSS_E_RESYNC_IN_PROGRESS,
            0x80042400 => ITF::VDS_E_NOT_SUPPORTED,
            0x80042400 => ITF::VSS_E_CLUSTER_ERROR,
            0x80042401 => ITF::FLTRDMN_E_UNEXPECTED,
            0x80042401 => ITF::VDS_E_INITIALIZED_FAILED,
            0x80042401 => ITF::VSS_E_ASRERROR_DISK_ASSIGNMENT_FAILED,
            0x80042402 => ITF::FLTRDMN_E_QI_FILTER_FAILED,
            0x80042402 => ITF::VDS_E_INITIALIZE_NOT_CALLED,
            0x80042402 => ITF::VSS_E_ASRERROR_DISK_RECREATION_FAILED,
            0x80042403 => ITF::VDS_E_ALREADY_REGISTERED,
            0x80042403 => ITF::VSS_E_ASRERROR_NO_ARCPATH,
            0x80042404 => ITF::FLTRDMN_E_FILTER_INIT_FAILED,
            0x80042404 => ITF::VDS_E_ANOTHER_CALL_IN_PROGRESS,
            0x80042404 => ITF::VSS_E_ASRERROR_MISSING_DYNDISK,
            0x80042405 => ITF::FLTRDMN_E_ENCRYPTED_DOCUMENT,
            0x80042405 => ITF::VDS_E_OBJECT_NOT_FOUND,
            0x80042405 => ITF::VSS_E_ASRERROR_SHARED_CRIDISK,
            0x80042406 => ITF::FLTRDMN_E_CANNOT_DECRYPT_PASSWORD,
            0x80042406 => ITF::VDS_E_INVALID_SPACE,
            0x80042406 => ITF::VSS_E_ASRERROR_DATADISK_RDISK0,
            0x80042407 => ITF::VDS_E_PARTITION_LIMIT_REACHED,
            0x80042407 => ITF::VSS_E_ASRERROR_RDISK0_TOOSMALL,
            0x80042408 => ITF::VDS_E_PARTITION_NOT_EMPTY,
            0x80042408 => ITF::VSS_E_ASRERROR_CRITICAL_DISKS_TOO_SMALL,
            0x80042409 => ITF::VDS_E_OPERATION_PENDING,
            0x80042409 => ITF::VSS_E_WRITER_STATUS_NOT_AVAILABLE,
            0x8004240A => ITF::VDS_E_OPERATION_DENIED,
            0x8004240A => ITF::VSS_E_ASRERROR_DYNAMIC_VHD_NOT_SUPPORTED,
            0x8004240B => ITF::VDS_E_OBJECT_DELETED,
            0x8004240C => ITF::VDS_E_CANCEL_TOO_LATE,
            0x8004240D => ITF::VDS_E_OPERATION_CANCELED,
            0x8004240E => ITF::VDS_E_CANNOT_EXTEND,
            0x8004240F => ITF::VDS_E_NOT_ENOUGH_SPACE,
            0x80042410 => ITF::VDS_E_NOT_ENOUGH_DRIVE,
            0x80042411 => ITF::VDS_E_BAD_COOKIE,
            0x80042411 => ITF::VSS_E_CRITICAL_VOLUME_ON_INVALID_DISK,
            0x80042412 => ITF::VDS_E_NO_MEDIA,
            0x80042412 => ITF::VSS_E_ASRERROR_RDISK_FOR_SYSTEM_DISK_NOT_FOUND,
            0x80042413 => ITF::VDS_E_DEVICE_IN_USE,
            0x80042413 => ITF::VSS_E_ASRERROR_NO_PHYSICAL_DISK_AVAILABLE,
            0x80042414 => ITF::VDS_E_DISK_NOT_EMPTY,
            0x80042414 => ITF::VSS_E_ASRERROR_FIXED_PHYSICAL_DISK_AVAILABLE_AFTER_DISK_EXCLUSION,
            0x80042415 => ITF::VDS_E_INVALID_OPERATION,
            0x80042415 => ITF::VSS_E_ASRERROR_CRITICAL_DISK_CANNOT_BE_EXCLUDED,
            0x80042416 => ITF::VDS_E_PATH_NOT_FOUND,
            0x80042416 => ITF::VSS_E_ASRERROR_SYSTEM_PARTITION_HIDDEN,
            0x80042417 => ITF::VDS_E_DISK_NOT_INITIALIZED,
            0x80042417 => ITF::VSS_E_FSS_TIMEOUT,
            0x80042418 => ITF::VDS_E_NOT_AN_UNALLOCATED_DISK,
            0x80042419 => ITF::VDS_E_UNRECOVERABLE_ERROR,
            0x8004241B => ITF::VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED,
            0x8004241C => ITF::VDS_E_PROVIDER_INITIALIZATION_FAILED,
            0x8004241D => ITF::VDS_E_OBJECT_EXISTS,
            0x8004241E => ITF::VDS_E_NO_DISKS_FOUND,
            0x8004241F => ITF::VDS_E_PROVIDER_CACHE_CORRUPT,
            0x80042420 => ITF::VDS_E_DMADMIN_METHOD_CALL_FAILED,
            0x80042422 => ITF::VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND,
            0x80042423 => ITF::VDS_E_PROVIDER_VOL_OPEN,
            0x80042424 => ITF::VDS_E_DMADMIN_CORRUPT_NOTIFICATION,
            0x80042425 => ITF::VDS_E_INCOMPATIBLE_FILE_SYSTEM,
            0x80042426 => ITF::VDS_E_INCOMPATIBLE_MEDIA,
            0x80042427 => ITF::VDS_E_ACCESS_DENIED,
            0x80042428 => ITF::VDS_E_MEDIA_WRITE_PROTECTED,
            0x80042429 => ITF::VDS_E_BAD_LABEL,
            0x8004242A => ITF::VDS_E_CANT_QUICK_FORMAT,
            0x8004242B => ITF::VDS_E_IO_ERROR,
            0x8004242C => ITF::VDS_E_VOLUME_TOO_SMALL,
            0x8004242D => ITF::VDS_E_VOLUME_TOO_BIG,
            0x8004242E => ITF::VDS_E_CLUSTER_SIZE_TOO_SMALL,
            0x8004242F => ITF::VDS_E_CLUSTER_SIZE_TOO_BIG,
            0x80042430 => ITF::VDS_E_CLUSTER_COUNT_BEYOND_32BITS,
            0x80042431 => ITF::VDS_E_OBJECT_STATUS_FAILED,
            0x80042432 => ITF::VDS_E_VOLUME_INCOMPLETE,
            0x80042433 => ITF::VDS_E_EXTENT_SIZE_LESS_THAN_MIN,
            0x80042436 => ITF::VDS_E_BOOT_PARTITION_NUMBER_CHANGE,
            0x80042437 => ITF::VDS_E_NO_FREE_SPACE,
            0x80042438 => ITF::VDS_E_ACTIVE_PARTITION,
            0x80042439 => ITF::VDS_E_PARTITION_OF_UNKNOWN_TYPE,
            0x8004243A => ITF::VDS_E_LEGACY_VOLUME_FORMAT,
            0x8004243B => ITF::VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS,
            0x8004243C => ITF::VDS_E_MIGRATE_OPEN_VOLUME,
            0x8004243D => ITF::VDS_E_VOLUME_NOT_ONLINE,
            0x8004243E => ITF::VDS_E_VOLUME_NOT_HEALTHY,
            0x8004243F => ITF::VDS_E_VOLUME_SPANS_DISKS,
            0x80042440 => ITF::VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE,
            0x80042441 => ITF::VDS_E_BAD_PROVIDER_DATA,
            0x80042442 => ITF::VDS_E_PROVIDER_FAILURE,
            0x80042444 => ITF::VDS_E_PACK_OFFLINE,
            0x80042445 => ITF::VDS_E_VOLUME_NOT_A_MIRROR,
            0x80042446 => ITF::VDS_E_NO_EXTENTS_FOR_VOLUME,
            0x80042447 => ITF::VDS_E_DISK_NOT_LOADED_TO_CACHE,
            0x80042448 => ITF::VDS_E_INTERNAL_ERROR,
            0x8004244A => ITF::VDS_E_PROVIDER_TYPE_NOT_SUPPORTED,
            0x8004244B => ITF::VDS_E_DISK_NOT_ONLINE,
            0x8004244C => ITF::VDS_E_DISK_IN_USE_BY_VOLUME,
            0x8004244E => ITF::VDS_E_ASYNC_OBJECT_FAILURE,
            0x8004244F => ITF::VDS_E_VOLUME_NOT_MOUNTED,
            0x80042450 => ITF::VDS_E_PACK_NOT_FOUND,
            0x80042451 => ITF::VDS_E_IMPORT_SET_INCOMPLETE,
            0x80042452 => ITF::VDS_E_DISK_NOT_IMPORTED,
            0x80042453 => ITF::VDS_E_OBJECT_OUT_OF_SYNC,
            0x80042454 => ITF::VDS_E_MISSING_DISK,
            0x80042455 => ITF::VDS_E_DISK_PNP_REG_CORRUPT,
            0x80042456 => ITF::VDS_E_LBN_REMAP_ENABLED_FLAG,
            0x80042457 => ITF::VDS_E_NO_DRIVELETTER_FLAG,
            0x80042458 => ITF::VDS_E_REVERT_ON_CLOSE,
            0x80042459 => ITF::VDS_E_REVERT_ON_CLOSE_SET,
            0x8004245A => ITF::VDS_E_IA64_BOOT_MIRRORED_TO_MBR,
            0x8004245C => ITF::VDS_E_VOLUME_TEMPORARILY_DISMOUNTED,
            0x8004245D => ITF::VDS_E_VOLUME_PERMANENTLY_DISMOUNTED,
            0x8004245E => ITF::VDS_E_VOLUME_HAS_PATH,
            0x8004245F => ITF::VDS_E_TIMEOUT,
            0x80042460 => ITF::VDS_E_REPAIR_VOLUMESTATE,
            0x80042461 => ITF::VDS_E_LDM_TIMEOUT,
            0x80042462 => ITF::VDS_E_REVERT_ON_CLOSE_MISMATCH,
            0x80042463 => ITF::VDS_E_RETRY,
            0x80042464 => ITF::VDS_E_ONLINE_PACK_EXISTS,
            0x80042466 => ITF::VDS_E_EXTEND_FILE_SYSTEM_FAILED,
            0x80042468 => ITF::VDS_E_MAX_USABLE_MBR,
            0x80042469 => ITF::VDS_S_GPT_BOOT_MIRRORED_TO_MBR,
            0x80042500 => ITF::OLEDB_BINDER_CUSTOM_ERROR,
            0x80042500 => ITF::VDS_E_NO_SOFTWARE_PROVIDERS_LOADED,
            0x80042501 => ITF::VDS_E_DISK_NOT_MISSING,
            0x80042502 => ITF::VDS_E_NO_VOLUME_LAYOUT,
            0x80042503 => ITF::VDS_E_CORRUPT_VOLUME_INFO,
            0x80042504 => ITF::VDS_E_INVALID_ENUMERATOR,
            0x80042505 => ITF::VDS_E_DRIVER_INTERNAL_ERROR,
            0x80042507 => ITF::VDS_E_VOLUME_INVALID_NAME,
            0x80042509 => ITF::VDS_E_CORRUPT_PARTITION_INFO,
            0x8004250B => ITF::VDS_E_CORRUPT_EXTENT_INFO,
            0x8004250C => ITF::VDS_E_DUP_EMPTY_PACK_GUID,
            0x8004250D => ITF::VDS_E_DRIVER_NO_PACK_NAME,
            0x8004250F => ITF::VDS_E_BAD_PNP_MESSAGE,
            0x80042510 => ITF::VDS_E_NO_PNP_DISK_ARRIVE,
            0x80042511 => ITF::VDS_E_NO_PNP_VOLUME_ARRIVE,
            0x80042512 => ITF::VDS_E_NO_PNP_DISK_REMOVE,
            0x80042513 => ITF::VDS_E_NO_PNP_VOLUME_REMOVE,
            0x80042514 => ITF::VDS_E_PROVIDER_EXITING,
            0x80042515 => ITF::VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE,
            0x80042516 => ITF::VDS_E_MEMBER_SIZE_INVALID,
            0x80042519 => ITF::VDS_E_INVALID_DISK,
            0x8004251A => ITF::VDS_E_INVALID_PACK,
            0x8004251B => ITF::VDS_E_VOLUME_ON_DISK,
            0x8004251C => ITF::VDS_E_DRIVER_INVALID_PARAM,
            0x8004251D => ITF::VDS_E_TARGET_PACK_NOT_EMPTY,
            0x8004251E => ITF::VDS_E_CANNOT_SHRINK,
            0x8004251F => ITF::VDS_E_MULTIPLE_PACKS,
            0x80042520 => ITF::VDS_E_PACK_ONLINE,
            0x80042521 => ITF::VDS_E_INVALID_PLEX_COUNT,
            0x80042522 => ITF::VDS_E_INVALID_MEMBER_COUNT,
            0x80042523 => ITF::VDS_E_INVALID_PLEX_ORDER,
            0x80042524 => ITF::VDS_E_INVALID_MEMBER_ORDER,
            0x80042525 => ITF::VDS_E_INVALID_STRIPE_SIZE,
            0x80042526 => ITF::VDS_E_INVALID_DISK_COUNT,
            0x80042527 => ITF::VDS_E_INVALID_EXTENT_COUNT,
            0x80042528 => ITF::VDS_E_SOURCE_IS_TARGET_PACK,
            0x80042529 => ITF::VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED,
            0x8004252A => ITF::VDS_E_CORRUPT_NOTIFICATION_INFO,
            0x8004252C => ITF::VDS_E_INVALID_PLEX_GUID,
            0x8004252D => ITF::VDS_E_DISK_NOT_FOUND_IN_PACK,
            0x8004252E => ITF::VDS_E_DUPLICATE_DISK,
            0x8004252F => ITF::VDS_E_LAST_VALID_DISK,
            0x80042530 => ITF::VDS_E_INVALID_SECTOR_SIZE,
            0x80042531 => ITF::VDS_E_ONE_EXTENT_PER_DISK,
            0x80042532 => ITF::VDS_E_INVALID_BLOCK_SIZE,
            0x80042533 => ITF::VDS_E_PLEX_SIZE_INVALID,
            0x80042534 => ITF::VDS_E_NO_EXTENTS_FOR_PLEX,
            0x80042535 => ITF::VDS_E_INVALID_PLEX_TYPE,
            0x80042536 => ITF::VDS_E_INVALID_PLEX_BLOCK_SIZE,
            0x80042537 => ITF::VDS_E_NO_HEALTHY_DISKS,
            0x80042538 => ITF::VDS_E_CONFIG_LIMIT,
            0x80042539 => ITF::VDS_E_DISK_CONFIGURATION_CORRUPTED,
            0x8004253A => ITF::VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC,
            0x8004253B => ITF::VDS_E_DISK_CONFIGURATION_UPDATE_FAILED,
            0x8004253C => ITF::VDS_E_DISK_DYNAMIC,
            0x8004253D => ITF::VDS_E_DRIVER_OBJECT_NOT_FOUND,
            0x8004253E => ITF::VDS_E_PARTITION_NOT_CYLINDER_ALIGNED,
            0x8004253F => ITF::VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL,
            0x80042540 => ITF::VDS_E_DISK_IO_FAILING,
            0x80042541 => ITF::VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED,
            0x80042542 => ITF::VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED,
            0x80042543 => ITF::VDS_E_GPT_ATTRIBUTES_INVALID,
            0x80042544 => ITF::VDS_E_MEMBER_IS_HEALTHY,
            0x80042545 => ITF::VDS_E_MEMBER_REGENERATING,
            0x80042546 => ITF::VDS_E_PACK_NAME_INVALID,
            0x80042547 => ITF::VDS_E_PLEX_IS_HEALTHY,
            0x80042548 => ITF::VDS_E_PLEX_LAST_ACTIVE,
            0x80042549 => ITF::VDS_E_PLEX_MISSING,
            0x8004254A => ITF::VDS_E_MEMBER_MISSING,
            0x8004254B => ITF::VDS_E_PLEX_REGENERATING,
            0x8004254D => ITF::VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE,
            0x8004254E => ITF::VDS_E_INVALID_VOLUME_LENGTH,
            0x8004254F => ITF::VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE,
            0x80042550 => ITF::VDS_E_VOLUME_NOT_RETAINED,
            0x80042551 => ITF::VDS_E_VOLUME_RETAINED,
            0x80042553 => ITF::VDS_E_ALIGN_BEYOND_FIRST_CYLINDER,
            0x80042554 => ITF::VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE,
            0x80042555 => ITF::VDS_E_ALIGN_NOT_ZERO,
            0x80042556 => ITF::VDS_E_CACHE_CORRUPT,
            0x80042557 => ITF::VDS_E_CANNOT_CLEAR_VOLUME_FLAG,
            0x80042558 => ITF::VDS_E_DISK_BEING_CLEANED,
            0x80042559 => ITF::VDS_E_DISK_NOT_CONVERTIBLE,
            0x8004255A => ITF::VDS_E_DISK_REMOVEABLE,
            0x8004255B => ITF::VDS_E_DISK_REMOVEABLE_NOT_EMPTY,
            0x8004255C => ITF::VDS_E_DRIVE_LETTER_NOT_FREE,
            0x8004255D => ITF::VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED,
            0x8004255E => ITF::VDS_E_INVALID_DRIVE_LETTER,
            0x8004255F => ITF::VDS_E_INVALID_DRIVE_LETTER_COUNT,
            0x80042560 => ITF::VDS_E_INVALID_FS_FLAG,
            0x80042561 => ITF::VDS_E_INVALID_FS_TYPE,
            0x80042562 => ITF::VDS_E_INVALID_OBJECT_TYPE,
            0x80042563 => ITF::VDS_E_INVALID_PARTITION_LAYOUT,
            0x80042564 => ITF::VDS_E_INVALID_PARTITION_STYLE,
            0x80042565 => ITF::VDS_E_INVALID_PARTITION_TYPE,
            0x80042566 => ITF::VDS_E_INVALID_PROVIDER_CLSID,
            0x80042567 => ITF::VDS_E_INVALID_PROVIDER_ID,
            0x80042568 => ITF::VDS_E_INVALID_PROVIDER_NAME,
            0x80042569 => ITF::VDS_E_INVALID_PROVIDER_TYPE,
            0x8004256A => ITF::VDS_E_INVALID_PROVIDER_VERSION_GUID,
            0x8004256B => ITF::VDS_E_INVALID_PROVIDER_VERSION_STRING,
            0x8004256C => ITF::VDS_E_INVALID_QUERY_PROVIDER_FLAG,
            0x8004256D => ITF::VDS_E_INVALID_SERVICE_FLAG,
            0x8004256E => ITF::VDS_E_INVALID_VOLUME_FLAG,
            0x8004256F => ITF::VDS_E_PARTITION_NOT_OEM,
            0x80042570 => ITF::VDS_E_PARTITION_PROTECTED,
            0x80042571 => ITF::VDS_E_PARTITION_STYLE_MISMATCH,
            0x80042572 => ITF::VDS_E_PROVIDER_INTERNAL_ERROR,
            0x80042573 => ITF::VDS_E_SHRINK_SIZE_LESS_THAN_MIN,
            0x80042574 => ITF::VDS_E_SHRINK_SIZE_TOO_BIG,
            0x80042575 => ITF::VDS_E_UNRECOVERABLE_PROVIDER_ERROR,
            0x80042576 => ITF::VDS_E_VOLUME_HIDDEN,
            0x80042579 => ITF::VDS_E_FLAG_ALREADY_SET,
            0x8004257B => ITF::VDS_E_DISTINCT_VOLUME,
            0x8004257C => ITF::VDS_E_VOLUME_NOT_FOUND_IN_PACK,
            0x8004257D => ITF::VDS_E_PARTITION_NON_DATA,
            0x8004257E => ITF::VDS_E_CRITICAL_PLEX,
            0x8004257F => ITF::VDS_E_VOLUME_SYNCHRONIZING,
            0x80042580 => ITF::VDS_E_VOLUME_REGENERATING,
            0x80042584 => ITF::VDS_E_READONLY,
            0x80042585 => ITF::VDS_E_INVALID_VOLUME_TYPE,
            0x80042586 => ITF::VDS_E_BAD_BOOT_DISK,
            0x80042587 => ITF::VDS_E_LOG_UPDATE,
            0x80042588 => ITF::VDS_E_VOLUME_MIRRORED,
            0x80042589 => ITF::VDS_E_VOLUME_SIMPLE_SPANNED,
            0x8004258A => ITF::VDS_E_NO_VALID_LOG_COPIES,
            0x8004258B => ITF::VDS_E_PLEX_NOT_LOADED_TO_CACHE,
            0x8004258C => ITF::VDS_E_PARTITION_MSR,
            0x8004258D => ITF::VDS_E_PARTITION_LDM,
            0x8004258F => ITF::VDS_E_ALIGN_NOT_A_POWER_OF_TWO,
            0x80042590 => ITF::VDS_E_ALIGN_IS_ZERO,
            0x80042591 => ITF::VDS_E_SHRINK_IN_PROGRESS,
            0x80042592 => ITF::VDS_E_CANT_INVALIDATE_FVE,
            0x80042593 => ITF::VDS_E_FS_NOT_DETERMINED,
            0x80042595 => ITF::VDS_E_DISK_NOT_OFFLINE,
            0x80042596 => ITF::VDS_E_FAILED_TO_ONLINE_DISK,
            0x80042597 => ITF::VDS_E_FAILED_TO_OFFLINE_DISK,
            0x80042598 => ITF::VDS_E_BAD_REVISION_NUMBER,
            0x80042599 => ITF::VDS_E_SHRINK_USER_CANCELLED,
            0x8004259A => ITF::VDS_E_SHRINK_DIRTY_VOLUME,
            0x80042601 => ITF::NOTESPH_E_UNEXPECTED_STATE,
            0x80042603 => ITF::NOTESPH_E_UNSUPPORTED_CONTENT_FIELD_TYPE,
            0x80042604 => ITF::NOTESPH_E_ITEM_NOT_FOUND,
            0x80042605 => ITF::NOTESPH_E_SERVER_CONFIG,
            0x80042606 => ITF::NOTESPH_E_ATTACHMENTS,
            0x80042607 => ITF::NOTESPH_E_NO_NTID,
            0x80042608 => ITF::NOTESPH_E_DB_ACCESS_DENIED,
            0x80042609 => ITF::NOTESPH_E_NOTESSETUP_ID_MAPPING_ERROR,
            0x80042611 => ITF::NOTESPH_E_FAIL,
            0x80042614 => ITF::STS_ABORTXMLPARSE,
            0x80042616 => ITF::STS_WS_ERROR,
            0x80042617 => ITF::SPS_WS_ERROR,
            0x80042701 => ITF::EXSTOREPH_E_UNEXPECTED,
            0x80042701 => ITF::VDS_E_NAME_NOT_UNIQUE,
            0x80042703 => ITF::VDS_E_ADDRESSES_INCOMPLETELY_SET,
            0x80042705 => ITF::VDS_E_SECURITY_INCOMPLETELY_SET,
            0x80042706 => ITF::VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED,
            0x80042707 => ITF::VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED,
            0x80042708 => ITF::VDS_E_ISCSI_LOGIN_FAILED,
            0x80042709 => ITF::VDS_E_ISCSI_LOGOUT_FAILED,
            0x8004270A => ITF::VDS_E_ISCSI_SESSION_NOT_FOUND,
            0x8004270B => ITF::VDS_E_ASSOCIATED_LUNS_EXIST,
            0x8004270C => ITF::VDS_E_ASSOCIATED_PORTALS_EXIST,
            0x8004270D => ITF::VDS_E_NO_DISCOVERY_DOMAIN,
            0x8004270E => ITF::VDS_E_MULTIPLE_DISCOVERY_DOMAINS,
            0x8004270F => ITF::VDS_E_NO_DISK_PATHNAME,
            0x80042710 => ITF::VDS_E_ISCSI_LOGOUT_INCOMPLETE,
            0x80042711 => ITF::VDS_E_NO_VOLUME_PATHNAME,
            0x80042712 => ITF::VDS_E_PROVIDER_CACHE_OUTOFSYNC,
            0x80042713 => ITF::VDS_E_NO_IMPORT_TARGET,
            0x80042801 => ITF::CERT_E_NOT_FOUND_OR_NO_PERMISSSION,
            0x80042803 => ITF::VDS_E_UNABLE_TO_FIND_BOOT_DISK,
            0x80042804 => ITF::VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO,
            0x80042805 => ITF::VDS_E_GET_SAN_POLICY,
            0x80042806 => ITF::VDS_E_SET_SAN_POLICY,
            0x80042807 => ITF::VDS_E_BOOT_DISK,
            0x8004280A => ITF::VDS_E_DISK_IS_OFFLINE,
            0x8004280B => ITF::VDS_E_DISK_IS_READ_ONLY,
            0x8004280C => ITF::VDS_E_PAGEFILE_DISK,
            0x8004280D => ITF::VDS_E_HIBERNATION_FILE_DISK,
            0x8004280E => ITF::VDS_E_CRASHDUMP_DISK,
            0x8004280F => ITF::VDS_E_UNABLE_TO_FIND_SYSTEM_DISK,
            0x80042810 => ITF::VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO,
            0x80042811 => ITF::VDS_E_SYSTEM_DISK,
            0x80042812 => ITF::VDS_E_VOLUME_SHRINK_FVE_LOCKED,
            0x80042813 => ITF::VDS_E_VOLUME_SHRINK_FVE_CORRUPT,
            0x80042814 => ITF::VDS_E_VOLUME_SHRINK_FVE_RECOVERY,
            0x80042815 => ITF::VDS_E_VOLUME_SHRINK_FVE,
            0x80042816 => ITF::VDS_E_SHRINK_OVER_DATA,
            0x80042817 => ITF::VDS_E_INVALID_SHRINK_SIZE,
            0x80042818 => ITF::VDS_E_LUN_DISK_MISSING,
            0x80042819 => ITF::VDS_E_LUN_DISK_FAILED,
            0x8004281A => ITF::VDS_E_LUN_DISK_NOT_READY,
            0x8004281B => ITF::VDS_E_LUN_DISK_NO_MEDIA,
            0x8004281C => ITF::VDS_E_LUN_NOT_READY,
            0x8004281D => ITF::VDS_E_LUN_OFFLINE,
            0x8004281E => ITF::VDS_E_LUN_FAILED,
            0x8004281F => ITF::VDS_E_VOLUME_EXTEND_FVE_LOCKED,
            0x80042820 => ITF::VDS_E_VOLUME_EXTEND_FVE_CORRUPT,
            0x80042821 => ITF::VDS_E_VOLUME_EXTEND_FVE_RECOVERY,
            0x80042822 => ITF::VDS_E_VOLUME_EXTEND_FVE,
            0x80042823 => ITF::VDS_E_SECTOR_SIZE_ERROR,
            0x80042900 => ITF::VDS_E_INITIATOR_ADAPTER_NOT_FOUND,
            0x80042901 => ITF::VDS_E_TARGET_PORTAL_NOT_FOUND,
            0x80042902 => ITF::VDS_E_INVALID_PORT_PATH,
            0x80042903 => ITF::VDS_E_INVALID_ISCSI_TARGET_NAME,
            0x80042904 => ITF::VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS,
            0x80042905 => ITF::VDS_E_ISCSI_GET_IKE_INFO,
            0x80042906 => ITF::VDS_E_ISCSI_SET_IKE_INFO,
            0x80042907 => ITF::VDS_E_SUBSYSTEM_ID_IS_NULL,
            0x80042908 => ITF::VDS_E_ISCSI_INITIATOR_NODE_NAME,
            0x80042909 => ITF::VDS_E_ISCSI_GROUP_PRESHARE_KEY,
            0x8004290A => ITF::VDS_E_ISCSI_CHAP_SECRET,
            0x8004290B => ITF::VDS_E_INVALID_IP_ADDRESS,
            0x8004290C => ITF::VDS_E_REBOOT_REQUIRED,
            0x8004290D => ITF::VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED,
            0x8004290E => ITF::VDS_E_BOOT_PAGEFILE_DRIVE_LETTER,
            0x8004290F => ITF::VDS_E_DELETE_WITH_CRITICAL,
            0x80042910 => ITF::VDS_E_CLEAN_WITH_DATA,
            0x80042911 => ITF::VDS_E_CLEAN_WITH_OEM,
            0x80042912 => ITF::VDS_E_CLEAN_WITH_CRITICAL,
            0x80042913 => ITF::VDS_E_FORMAT_CRITICAL,
            0x80042914 => ITF::VDS_E_NTFS_FORMAT_NOT_SUPPORTED,
            0x80042915 => ITF::VDS_E_FAT32_FORMAT_NOT_SUPPORTED,
            0x80042916 => ITF::VDS_E_FAT_FORMAT_NOT_SUPPORTED,
            0x80042917 => ITF::VDS_E_FORMAT_NOT_SUPPORTED,
            0x80042918 => ITF::VDS_E_COMPRESSION_NOT_SUPPORTED,
            0x80042919 => ITF::VDS_E_VDISK_NOT_OPEN,
            0x8004291A => ITF::VDS_E_VDISK_INVALID_OP_STATE,
            0x8004291B => ITF::VDS_E_INVALID_PATH,
            0x8004291C => ITF::VDS_E_INVALID_ISCSI_PATH,
            0x8004291D => ITF::VDS_E_SHRINK_LUN_NOT_UNMASKED,
            0x8004291E => ITF::VDS_E_LUN_DISK_READ_ONLY,
            0x8004291F => ITF::VDS_E_LUN_UPDATE_DISK,
            0x80042920 => ITF::VDS_E_LUN_DYNAMIC,
            0x80042921 => ITF::VDS_E_LUN_DYNAMIC_OFFLINE,
            0x80042922 => ITF::VDS_E_LUN_SHRINK_GPT_HEADER,
            0x80042923 => ITF::VDS_E_MIRROR_NOT_SUPPORTED,
            0x80042924 => ITF::VDS_E_RAID5_NOT_SUPPORTED,
            0x80042925 => ITF::VDS_E_DISK_NOT_CONVERTIBLE_SIZE,
            0x80042926 => ITF::VDS_E_OFFLINE_NOT_SUPPORTED,
            0x80042927 => ITF::VDS_E_VDISK_PATHNAME_INVALID,
            0x80042928 => ITF::VDS_E_EXTEND_TOO_MANY_CLUSTERS,
            0x80042929 => ITF::VDS_E_EXTEND_UNKNOWN_FILESYSTEM,
            0x8004292A => ITF::VDS_E_SHRINK_UNKNOWN_FILESYSTEM,
            0x8004292B => ITF::VDS_E_VD_DISK_NOT_OPEN,
            0x8004292C => ITF::VDS_E_VD_DISK_IS_EXPANDING,
            0x8004292D => ITF::VDS_E_VD_DISK_IS_COMPACTING,
            0x8004292E => ITF::VDS_E_VD_DISK_IS_MERGING,
            0x8004292F => ITF::VDS_E_VD_IS_ATTACHED,
            0x80042930 => ITF::VDS_E_VD_DISK_ALREADY_OPEN,
            0x80042931 => ITF::VDS_E_VD_DISK_ALREADY_EXPANDING,
            0x80042932 => ITF::VDS_E_VD_ALREADY_COMPACTING,
            0x80042933 => ITF::VDS_E_VD_ALREADY_MERGING,
            0x80042934 => ITF::VDS_E_VD_ALREADY_ATTACHED,
            0x80042935 => ITF::VDS_E_VD_ALREADY_DETACHED,
            0x80042936 => ITF::VDS_E_VD_NOT_ATTACHED_READONLY,
            0x80042937 => ITF::VDS_E_VD_IS_BEING_ATTACHED,
            0x80042938 => ITF::VDS_E_VD_IS_BEING_DETACHED,
            0x80042A00 => ITF::VDS_E_NO_POOL,
            0x80042A01 => ITF::VDS_E_NO_POOL_CREATED,
            0x80042A02 => ITF::VDS_E_NO_MAINTENANCE_MODE,
            0x80042A03 => ITF::VDS_E_BLOCK_CLUSTERED,
            0x80042A04 => ITF::VDS_E_DISK_HAS_BANDS,
            0x80042A05 => ITF::VDS_E_INVALID_STATE,
            0x80042A06 => ITF::VDS_E_REFS_FORMAT_NOT_SUPPORTED,
            0x80042A07 => ITF::VDS_E_DELETE_WITH_BOOTBACKING,
            0x80042A08 => ITF::VDS_E_FORMAT_WITH_BOOTBACKING,
            0x80042A09 => ITF::VDS_E_CLEAN_WITH_BOOTBACKING,
            0x80043301 => ITF::SRCH_SCHEMA_CACHE_E_UNEXPECTED,
            0x80043401 => ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_READ,
            0x80043402 => ITF::CONTENT_SOURCE_E_UNEXPECTED_NULL_POINTER,
            0x80043403 => ITF::CONTENT_SOURCE_E_PROPERTY_MAPPING_BAD_VECTOR_SIZE,
            0x80043404 => ITF::CONTENT_SOURCE_E_CONTENT_CLASS_READ,
            0x80043405 => ITF::CONTENT_SOURCE_E_UNEXPECTED_EXCEPTION,
            0x80043406 => ITF::CONTENT_SOURCE_E_NULL_CONTENT_CLASS_BSTR,
            0x80043407 => ITF::CONTENT_SOURCE_E_CONTENT_SOURCE_COLUMN_TYPE,
            0x80043408 => ITF::CONTENT_SOURCE_E_OUT_OF_RANGE,
            0x80043409 => ITF::CONTENT_SOURCE_E_NULL_URI,
            0x80043500 => ITF::REXSPH_E_INVALID_CALL,
            0x80043502 => ITF::REXSPH_E_REDIRECT_ON_SECURITY_UPDATE,
            0x80043503 => ITF::REXSPH_E_MULTIPLE_REDIRECT,
            0x80043504 => ITF::REXSPH_E_NO_PROPERTY_ON_ROW,
            0x80043505 => ITF::REXSPH_E_TYPE_MISMATCH_ON_READ,
            0x80043506 => ITF::REXSPH_E_UNEXPECTED_DATA_STATUS,
            0x80043507 => ITF::REXSPH_E_UNKNOWN_DATA_TYPE,
            0x80043508 => ITF::REXSPH_E_UNEXPECTED_FILTER_STATE,
            0x80043509 => ITF::REXSPH_E_DUPLICATE_PROPERTY,
            0x80043602 => ITF::FTE_E_SECRET_NOT_FOUND,
            0x80043603 => ITF::FTE_E_PIPE_NOT_CONNECTED,
            0x80043604 => ITF::FTE_E_ADMIN_BLOB_CORRUPT,
            0x80043605 => ITF::FTE_E_FILTER_SINGLE_THREADED,
            0x80043606 => ITF::FTE_E_ERROR_WRITING_REGISTRY,
            0x80043607 => ITF::FTE_E_PROJECT_SHUTDOWN,
            0x80043608 => ITF::FTE_E_PROJECT_NOT_INITALIZED,
            0x80043609 => ITF::FTE_E_PIPE_DATA_CORRUPTED,
            0x80043610 => ITF::FTE_E_URB_TOO_BIG,
            0x80043611 => ITF::FTE_E_INVALID_DOCID,
            0x80043612 => ITF::FTE_E_PAUSE_EXTERNAL,
            0x80043613 => ITF::FTE_E_REJECTED_DUE_TO_PROJECT_STATUS,
            0x80043614 => ITF::FTE_E_FD_DID_NOT_CONNECT,
            0x80043616 => ITF::FTE_E_PROGID_REQUIRED,
            0x80043617 => ITF::FTE_E_STATIC_THREAD_INVALID_ARGUMENTS,
            0x80043618 => ITF::FTE_E_CATALOG_ALREADY_EXISTS,
            0x8004361A => ITF::FTE_E_PATH_TOO_LONG,
            0x8004361B => ITF::FTE_INVALID_ADMIN_CLIENT,
            0x8004361C => ITF::FTE_E_COM_SIGNATURE_VALIDATION,
            0x8004361D => ITF::FTE_E_AFFINITY_MASK,
            0x8004361E => ITF::FTE_E_FD_OWNERSHIP_OBSOLETE,
            0x80043621 => ITF::FTE_E_EXCEEDED_MAX_PLUGINS,
            0x80043624 => ITF::FTE_E_DUPLICATE_OBJECT,
            0x80043626 => ITF::FTE_E_REDUNDANT_TRAN_FAILURE,
            0x80043627 => ITF::FTE_E_DEPENDENT_TRAN_FAILED_TO_PERSIST,
            0x80043628 => ITF::FTE_E_FD_SHUTDOWN,
            0x80043629 => ITF::FTE_E_CATALOG_DOES_NOT_EXIST,
            0x8004362A => ITF::FTE_E_NO_PLUGINS,
            0x8004362C => ITF::FTE_E_BATCH_ABORTED,
            0x8004362D => ITF::FTE_E_ANOTHER_STATUS_CHANGE_IS_ALREADY_ACTIVE,
            0x8004362F => ITF::FTE_E_NOT_PROCESSED_DUE_TO_PREVIOUS_ERRORS,
            0x80043630 => ITF::FTE_E_FD_TIMEOUT,
            0x80043631 => ITF::FTE_E_RESOURCE_SHUTDOWN,
            0x80043632 => ITF::FTE_E_INVALID_PROPERTY,
            0x80043633 => ITF::FTE_E_NO_MORE_PROPERTIES,
            0x80043634 => ITF::FTE_E_UNKNOWN_PLUGIN,
            0x80043635 => ITF::FTE_E_LIBRARY_NOT_LOADED,
            0x80043636 => ITF::FTE_E_PERFMON_FULL,
            0x80043637 => ITF::FTE_E_FAILED_TO_CREATE_ACCESSOR,
            0x80043638 => ITF::FTE_E_INVALID_TYPE,
            0x80043639 => ITF::FTE_E_OUT_OF_RANGE,
            0x8004363A => ITF::FTE_E_CORRUPT_PROPERTY_STORE,
            0x8004363B => ITF::FTE_E_PROPERTY_STORE_WORKID_NOTVALID,
            0x8004363D => ITF::FTE_E_CORRUPT_GATHERER_HASH_MAP,
            0x8004363E => ITF::FTE_E_KEY_NOT_CACHED,
            0x8004363F => ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_SHUTDOWN,
            0x80043640 => ITF::FTE_E_UPGRADE_INTERFACE_ALREADY_INSTANTIATED,
            0x80043641 => ITF::FTE_E_STACK_CORRUPTED,
            0x80043642 => ITF::FTE_E_INVALID_PROG_ID,
            0x80043643 => ITF::FTE_E_SERIAL_STREAM_CORRUPT,
            0x80043644 => ITF::FTE_E_READONLY_CATALOG,
            0x80043645 => ITF::FTE_E_PERF_NOT_LOADED,
            0x80043648 => ITF::FTE_E_RETRY_HUGE_DOC,
            0x80043649 => ITF::FTE_E_UNKNOWN_FD_TYPE,
            0x8004364A => ITF::FTE_E_DOC_TOO_HUGE,
            0x8004364B => ITF::FTE_E_DATATYPE_MISALIGNMENT,
            0x8004364C => ITF::FTE_E_ALREADY_INITIALIZED,
            0x8004364D => ITF::FTE_E_FD_USED_TOO_MUCH_MEMORY,
            0x8004364E => ITF::FTE_E_UNEXPECTED_EXIT,
            0x8004364F => ITF::FTE_E_HIGH_MEMORY_PRESSURE,
            0x80043650 => ITF::FTE_E_INVALID_ISOLATE_ERROR_BATCH,
            0x80043651 => ITF::FTE_E_RETRY_SINGLE_DOC_PER_BATCH,
            0x80043652 => ITF::FTE_E_INVALID_PROJECT_ID,
            0x80043653 => ITF::FTE_E_FAILURE_TO_POST_SETCOMPLETION_STATUS,
            0x80043654 => ITF::FTE_E_INVALID_CODEPAGE,
            0x80043655 => ITF::FTE_E_FD_IDLE,
            0x80043656 => ITF::FTE_E_FD_UNRESPONSIVE,
            0x80043C01 => ITF::WCN_E_PEER_NOT_FOUND,
            0x80043C02 => ITF::WCN_E_AUTHENTICATION_FAILED,
            0x80043C03 => ITF::WCN_E_CONNECTION_REJECTED,
            0x80043C04 => ITF::WCN_E_SESSION_TIMEDOUT,
            0x80043C05 => ITF::WCN_E_PROTOCOL_ERROR,
            0x80044000 => ITF::CDO_E_ARGUMENT1,
            0x80044000 => ITF::PEOPLE_IMPORT_E_DBCONNFAIL,
            0x80044001 => ITF::CDO_E_ARGUMENT2,
            0x80044001 => ITF::PEOPLE_IMPORT_NODSDEFINED,
            0x80044002 => ITF::CDO_E_ARGUMENT3,
            0x80044002 => ITF::PEOPLE_IMPORT_E_FAILTOGETDSDEF,
            0x80044003 => ITF::CDO_E_ARGUMENT4,
            0x80044003 => ITF::PEOPLE_IMPORT_NOMAPPINGDEFINED,
            0x80044004 => ITF::CDO_E_ARGUMENT5,
            0x80044004 => ITF::PEOPLE_IMPORT_E_FAILTOGETDSMAPPING,
            0x80044005 => ITF::PEOPLE_IMPORT_E_DATATYPENOTSUPPORTED,
            0x80044006 => ITF::PEOPLE_IMPORT_E_NOCASTINGSUPPORTED,
            0x80044007 => ITF::PEOPLE_IMPORT_E_UPDATE_DIRSYNC_COOKIE,
            0x80044008 => ITF::PEOPLE_IMPORT_E_DIRSYNC_ZERO_COOKIE,
            0x80044009 => ITF::PEOPLE_IMPORT_E_LDAPPATH_TOOLONG,
            0x8004400A => ITF::PEOPLE_IMPORT_E_CANONICALURL_TOOLONG,
            0x8004400B => ITF::PEOPLE_IMPORT_E_USERNAME_NOTRESOLVED,
            0x8004400C => ITF::PEOPLE_IMPORT_E_DC_NOT_AVAILABLE,
            0x8004400D => ITF::PEOPLE_IMPORT_E_DOMAIN_DISCOVER_FAILED,
            0x8004400E => ITF::PEOPLE_IMPORT_E_FAILTOGETLCID,
            0x8004400F => ITF::PEOPLE_IMPORT_E_DOMAIN_REMOVED,
            0x80044010 => ITF::PEOPLE_IMPORT_E_ENUM_ACCESSDENIED,
            0x80044011 => ITF::PEOPLE_IMPORT_E_DIRSYNC_NOTREFRESHED,
            0x80045001 => ITF::SPERR_UNINITIALIZED,
            0x80045002 => ITF::SPERR_ALREADY_INITIALIZED,
            0x80045003 => ITF::SPERR_UNSUPPORTED_FORMAT,
            0x80045004 => ITF::SPERR_INVALID_FLAGS,
            0x80045006 => ITF::SPERR_DEVICE_BUSY,
            0x80045007 => ITF::SPERR_DEVICE_NOT_SUPPORTED,
            0x80045008 => ITF::SPERR_DEVICE_NOT_ENABLED,
            0x80045009 => ITF::SPERR_NO_DRIVER,
            0x8004500A => ITF::SPERR_FILEMUSTBEUNICODE,
            0x8004500C => ITF::SPERR_INVALID_PHRASE_ID,
            0x8004500D => ITF::SPERR_BUFFER_TOO_SMALL,
            0x8004500E => ITF::SPERR_FORMAT_NOT_SPECIFIED,
            0x8004500F => ITF::SPERR_AUDIO_STOPPED,
            0x80045011 => ITF::SPERR_RULE_NOT_FOUND,
            0x80045012 => ITF::SPERR_TTS_ENGINE_EXCEPTION,
            0x80045013 => ITF::SPERR_TTS_NLP_EXCEPTION,
            0x80045014 => ITF::SPERR_ENGINE_BUSY,
            0x80045017 => ITF::SPERR_CANT_CREATE,
            0x80045019 => ITF::SPERR_NOT_IN_LEX,
            0x8004501B => ITF::SPERR_LEX_VERY_OUT_OF_SYNC,
            0x8004501C => ITF::SPERR_UNDEFINED_FORWARD_RULE_REF,
            0x8004501D => ITF::SPERR_EMPTY_RULE,
            0x8004501E => ITF::SPERR_GRAMMAR_COMPILER_INTERNAL_ERROR,
            0x8004501F => ITF::SPERR_RULE_NOT_DYNAMIC,
            0x80045020 => ITF::SPERR_DUPLICATE_RULE_NAME,
            0x80045021 => ITF::SPERR_DUPLICATE_RESOURCE_NAME,
            0x80045022 => ITF::SPERR_TOO_MANY_GRAMMARS,
            0x80045023 => ITF::SPERR_CIRCULAR_REFERENCE,
            0x80045024 => ITF::SPERR_INVALID_IMPORT,
            0x80045025 => ITF::SPERR_INVALID_WAV_FILE,
            0x80045027 => ITF::SPERR_ALL_WORDS_OPTIONAL,
            0x80045028 => ITF::SPERR_INSTANCE_CHANGE_INVALID,
            0x80045029 => ITF::SPERR_RULE_NAME_ID_CONFLICT,
            0x8004502A => ITF::SPERR_NO_RULES,
            0x8004502B => ITF::SPERR_CIRCULAR_RULE_REF,
            0x8004502D => ITF::SPERR_NO_PARSE_FOUND,
            0x8004502E => ITF::SPERR_REMOTE_CALL_TIMED_OUT,
            0x8004502F => ITF::SPERR_AUDIO_BUFFER_OVERFLOW,
            0x80045030 => ITF::SPERR_NO_AUDIO_DATA,
            0x80045031 => ITF::SPERR_DEAD_ALTERNATE,
            0x80045032 => ITF::SPERR_HIGH_LOW_CONFIDENCE,
            0x80045033 => ITF::SPERR_INVALID_FORMAT_STRING,
            0x80045035 => ITF::SPERR_APPLEX_READ_ONLY,
            0x80045036 => ITF::SPERR_NO_TERMINATING_RULE_PATH,
            0x80045038 => ITF::SPERR_STREAM_CLOSED,
            0x80045039 => ITF::SPERR_NO_MORE_ITEMS,
            0x8004503A => ITF::SPERR_NOT_FOUND,
            0x8004503B => ITF::SPERR_INVALID_AUDIO_STATE,
            0x8004503C => ITF::SPERR_GENERIC_MMSYS_ERROR,
            0x8004503D => ITF::SPERR_MARSHALER_EXCEPTION,
            0x8004503E => ITF::SPERR_NOT_DYNAMIC_GRAMMAR,
            0x8004503F => ITF::SPERR_AMBIGUOUS_PROPERTY,
            0x80045040 => ITF::SPERR_INVALID_REGISTRY_KEY,
            0x80045041 => ITF::SPERR_INVALID_TOKEN_ID,
            0x80045042 => ITF::SPERR_XML_BAD_SYNTAX,
            0x80045043 => ITF::SPERR_XML_RESOURCE_NOT_FOUND,
            0x80045044 => ITF::SPERR_TOKEN_IN_USE,
            0x80045045 => ITF::SPERR_TOKEN_DELETED,
            0x80045046 => ITF::SPERR_MULTI_LINGUAL_NOT_SUPPORTED,
            0x80045047 => ITF::SPERR_EXPORT_DYNAMIC_RULE,
            0x80045048 => ITF::SPERR_STGF_ERROR,
            0x80045049 => ITF::SPERR_WORDFORMAT_ERROR,
            0x8004504A => ITF::SPERR_STREAM_NOT_ACTIVE,
            0x8004504B => ITF::SPERR_ENGINE_RESPONSE_INVALID,
            0x8004504C => ITF::SPERR_SR_ENGINE_EXCEPTION,
            0x8004504D => ITF::SPERR_STREAM_POS_INVALID,
            0x8004504F => ITF::SPERR_REMOTE_CALL_ON_WRONG_THREAD,
            0x80045050 => ITF::SPERR_REMOTE_PROCESS_TERMINATED,
            0x80045051 => ITF::SPERR_REMOTE_PROCESS_ALREADY_RUNNING,
            0x80045052 => ITF::SPERR_LANGID_MISMATCH,
            0x80045054 => ITF::SPERR_NOT_TOPLEVEL_RULE,
            0x80045056 => ITF::SPERR_LEX_REQUIRES_COOKIE,
            0x80045059 => ITF::SPERR_UNSUPPORTED_LANG,
            0x8004505A => ITF::SPERR_VOICE_PAUSED,
            0x8004505B => ITF::SPERR_AUDIO_BUFFER_UNDERFLOW,
            0x8004505C => ITF::SPERR_AUDIO_STOPPED_UNEXPECTEDLY,
            0x8004505D => ITF::SPERR_NO_WORD_PRONUNCIATION,
            0x8004505E => ITF::SPERR_ALTERNATES_WOULD_BE_INCONSISTENT,
            0x8004505F => ITF::SPERR_NOT_SUPPORTED_FOR_SHARED_RECOGNIZER,
            0x80045060 => ITF::SPERR_TIMEOUT,
            0x80045061 => ITF::SPERR_REENTER_SYNCHRONIZE,
            0x80045062 => ITF::SPERR_STATE_WITH_NO_ARCS,
            0x80045063 => ITF::SPERR_NOT_ACTIVE_SESSION,
            0x80045064 => ITF::SPERR_ALREADY_DELETED,
            0x80045066 => ITF::SPERR_RECOXML_GENERATION_FAIL,
            0x80045067 => ITF::SPERR_SML_GENERATION_FAIL,
            0x80045068 => ITF::SPERR_NOT_PROMPT_VOICE,
            0x80045069 => ITF::SPERR_ROOTRULE_ALREADY_DEFINED,
            0x80045070 => ITF::SPERR_SCRIPT_DISALLOWED,
            0x80045071 => ITF::SPERR_REMOTE_CALL_TIMED_OUT_START,
            0x80045072 => ITF::SPERR_REMOTE_CALL_TIMED_OUT_CONNECT,
            0x80045073 => ITF::SPERR_SECMGR_CHANGE_NOT_ALLOWED,
            0x80045075 => ITF::SPERR_FAILED_TO_DELETE_FILE,
            0x80045076 => ITF::SPERR_SHARED_ENGINE_DISABLED,
            0x80045077 => ITF::SPERR_RECOGNIZER_NOT_FOUND,
            0x80045078 => ITF::SPERR_AUDIO_NOT_FOUND,
            0x80045079 => ITF::SPERR_NO_VOWEL,
            0x8004507A => ITF::SPERR_UNSUPPORTED_PHONEME,
            0x8004507D => ITF::SPERR_WORD_NEEDS_NORMALIZATION,
            0x8004507E => ITF::SPERR_CANNOT_NORMALIZE,
            0x80045081 => ITF::SPERR_TOPIC_NOT_ADAPTABLE,
            0x80045082 => ITF::SPERR_PHONEME_CONVERSION,
            0x80045083 => ITF::SPERR_NOT_SUPPORTED_FOR_INPROC_RECOGNIZER,
            0x80045084 => ITF::SPERR_OVERLOAD,
            0x80045085 => ITF::SPERR_LEX_INVALID_DATA,
            0x80045086 => ITF::SPERR_CFG_INVALID_DATA,
            0x80045087 => ITF::SPERR_LEX_UNEXPECTED_FORMAT,
            0x80045088 => ITF::SPERR_STRING_TOO_LONG,
            0x80045089 => ITF::SPERR_STRING_EMPTY,
            0x80045090 => ITF::SPERR_NON_WORD_TRANSITION,
            0x80045091 => ITF::SPERR_SISR_ATTRIBUTES_NOT_ALLOWED,
            0x80045092 => ITF::SPERR_SISR_MIXED_NOT_ALLOWED,
            0x80045093 => ITF::SPERR_VOICE_NOT_FOUND,
            0x80045301 => ITF::FSRM_E_NOT_FOUND,
            0x80045302 => ITF::FSRM_E_INVALID_SCHEDULER_ARGUMENT,
            0x80045303 => ITF::FSRM_E_ALREADY_EXISTS,
            0x80045304 => ITF::FSRM_E_PATH_NOT_FOUND,
            0x80045305 => ITF::FSRM_E_INVALID_USER,
            0x80045306 => ITF::FSRM_E_INVALID_PATH,
            0x80045307 => ITF::FSRM_E_INVALID_LIMIT,
            0x80045308 => ITF::FSRM_E_INVALID_NAME,
            0x80045309 => ITF::FSRM_E_FAIL_BATCH,
            0x8004530A => ITF::FSRM_E_INVALID_TEXT,
            0x8004530B => ITF::FSRM_E_INVALID_IMPORT_VERSION,
            0x8004530D => ITF::FSRM_E_OUT_OF_RANGE,
            0x8004530E => ITF::FSRM_E_REQD_PARAM_MISSING,
            0x8004530F => ITF::FSRM_E_INVALID_COMBINATION,
            0x80045310 => ITF::FSRM_E_DUPLICATE_NAME,
            0x80045311 => ITF::FSRM_E_NOT_SUPPORTED,
            0x80045313 => ITF::FSRM_E_DRIVER_NOT_READY,
            0x80045314 => ITF::FSRM_E_INSUFFICIENT_DISK,
            0x80045315 => ITF::FSRM_E_VOLUME_UNSUPPORTED,
            0x80045316 => ITF::FSRM_E_UNEXPECTED,
            0x80045317 => ITF::FSRM_E_INSECURE_PATH,
            0x80045318 => ITF::FSRM_E_INVALID_SMTP_SERVER,
            0x8004531C => ITF::FSRM_E_EMAIL_NOT_SENT,
            0x8004531E => ITF::FSRM_E_INVALID_EMAIL_ADDRESS,
            0x8004531F => ITF::FSRM_E_FILE_SYSTEM_CORRUPT,
            0x80045320 => ITF::FSRM_E_LONG_CMDLINE,
            0x80045321 => ITF::FSRM_E_INVALID_FILEGROUP_DEFINITION,
            0x80045324 => ITF::FSRM_E_INVALID_DATASCREEN_DEFINITION,
            0x80045328 => ITF::FSRM_E_INVALID_REPORT_FORMAT,
            0x80045329 => ITF::FSRM_E_INVALID_REPORT_DESC,
            0x8004532A => ITF::FSRM_E_INVALID_FILENAME,
            0x8004532C => ITF::FSRM_E_SHADOW_COPY,
            0x8004532D => ITF::FSRM_E_XML_CORRUPTED,
            0x8004532E => ITF::FSRM_E_CLUSTER_NOT_RUNNING,
            0x8004532F => ITF::FSRM_E_STORE_NOT_INSTALLED,
            0x80045330 => ITF::FSRM_E_NOT_CLUSTER_VOLUME,
            0x80045331 => ITF::FSRM_E_DIFFERENT_CLUSTER_GROUP,
            0x80045332 => ITF::FSRM_E_REPORT_TYPE_ALREADY_EXISTS,
            0x80045333 => ITF::FSRM_E_REPORT_JOB_ALREADY_RUNNING,
            0x80045334 => ITF::FSRM_E_REPORT_GENERATION_ERR,
            0x80045335 => ITF::FSRM_E_REPORT_TASK_TRIGGER,
            0x80045336 => ITF::FSRM_E_LOADING_DISABLED_MODULE,
            0x80045337 => ITF::FSRM_E_CANNOT_AGGREGATE,
            0x80045338 => ITF::FSRM_E_MESSAGE_LIMIT_EXCEEDED,
            0x80045339 => ITF::FSRM_E_OBJECT_IN_USE,
            0x8004533A => ITF::FSRM_E_CANNOT_RENAME_PROPERTY,
            0x8004533B => ITF::FSRM_E_CANNOT_CHANGE_PROPERTY_TYPE,
            0x8004533C => ITF::FSRM_E_MAX_PROPERTY_DEFINITIONS,
            0x8004533D => ITF::FSRM_E_CLASSIFICATION_ALREADY_RUNNING,
            0x8004533E => ITF::FSRM_E_CLASSIFICATION_NOT_RUNNING,
            0x8004533F => ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_RUNNING,
            0x80045340 => ITF::FSRM_E_FILE_MANAGEMENT_JOB_EXPIRATION,
            0x80045341 => ITF::FSRM_E_FILE_MANAGEMENT_JOB_CUSTOM,
            0x80045342 => ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOTIFICATION,
            0x80045343 => ITF::FSRM_E_FILE_OPEN_ERROR,
            0x80045344 => ITF::FSRM_E_UNSECURE_LINK_TO_HOSTED_MODULE,
            0x80045345 => ITF::FSRM_E_CACHE_INVALID,
            0x80045346 => ITF::FSRM_E_CACHE_MODULE_ALREADY_EXISTS,
            0x80045347 => ITF::FSRM_E_FILE_MANAGEMENT_EXPIRATION_DIR_IN_SCOPE,
            0x80045348 => ITF::FSRM_E_FILE_MANAGEMENT_JOB_ALREADY_EXISTS,
            0x80045349 => ITF::FSRM_E_PROPERTY_DELETED,
            0x80045350 => ITF::FSRM_E_LAST_ACCESS_UPDATE_DISABLED,
            0x80045351 => ITF::FSRM_E_NO_PROPERTY_VALUE,
            0x80045352 => ITF::FSRM_E_INPROC_MODULE_BLOCKED,
            0x80045353 => ITF::FSRM_E_ENUM_PROPERTIES_FAILED,
            0x80045354 => ITF::FSRM_E_SET_PROPERTY_FAILED,
            0x80045355 => ITF::FSRM_E_CANNOT_STORE_PROPERTIES,
            0x80045356 => ITF::FSRM_E_CANNOT_ALLOW_REPARSE_POINT_TAG,
            0x80045357 => ITF::FSRM_E_PARTIAL_CLASSIFICATION_PROPERTY_NOT_FOUND,
            0x80045358 => ITF::FSRM_E_TEXTREADER_NOT_INITIALIZED,
            0x80045359 => ITF::FSRM_E_TEXTREADER_IFILTER_NOT_FOUND,
            0x8004535A => ITF::FSRM_E_PERSIST_PROPERTIES_FAILED_ENCRYPTED,
            0x80045360 => ITF::FSRM_E_TEXTREADER_IFILTER_CLSID_MALFORMED,
            0x80045361 => ITF::FSRM_E_TEXTREADER_STREAM_ERROR,
            0x80045362 => ITF::FSRM_E_TEXTREADER_FILENAME_TOO_LONG,
            0x80045363 => ITF::FSRM_E_INCOMPATIBLE_FORMAT,
            0x80045364 => ITF::FSRM_E_FILE_ENCRYPTED,
            0x80045365 => ITF::FSRM_E_PERSIST_PROPERTIES_FAILED,
            0x80045366 => ITF::FSRM_E_VOLUME_OFFLINE,
            0x80045367 => ITF::FSRM_E_FILE_MANAGEMENT_ACTION_TIMEOUT,
            0x80045368 => ITF::FSRM_E_FILE_MANAGEMENT_ACTION_GET_EXITCODE_FAILED,
            0x80045369 => ITF::FSRM_E_MODULE_INVALID_PARAM,
            0x8004536A => ITF::FSRM_E_MODULE_INITIALIZATION,
            0x8004536B => ITF::FSRM_E_MODULE_SESSION_INITIALIZATION,
            0x8004536C => ITF::FSRM_E_CLASSIFICATION_SCAN_FAIL,
            0x8004536D => ITF::FSRM_E_FILE_MANAGEMENT_JOB_NOT_LEGACY_ACCESSIBLE,
            0x8004536E => ITF::FSRM_E_FILE_MANAGEMENT_JOB_MAX_FILE_CONDITIONS,
            0x8004536F => ITF::FSRM_E_CANNOT_USE_DEPRECATED_PROPERTY,
            0x80045370 => ITF::FSRM_E_SYNC_TASK_TIMEOUT,
            0x80045371 => ITF::FSRM_E_CANNOT_USE_DELETED_PROPERTY,
            0x80045372 => ITF::FSRM_E_INVALID_AD_CLAIM,
            0x80045373 => ITF::FSRM_E_CLASSIFICATION_CANCELED,
            0x80045374 => ITF::FSRM_E_INVALID_FOLDER_PROPERTY_STORE,
            0x80045375 => ITF::FSRM_E_REBUILDING_FODLER_TYPE_INDEX,
            0x80045376 => ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FILES,
            0x80045377 => ITF::FSRM_E_CLASSIFICATION_TIMEOUT,
            0x80045378 => ITF::FSRM_E_CLASSIFICATION_PARTIAL_BATCH,
            0x80045379 => ITF::FSRM_E_CANNOT_DELETE_SYSTEM_PROPERTY,
            0x8004537A => ITF::FSRM_E_FILE_IN_USE,
            0x8004537B => ITF::FSRM_E_ERROR_NOT_ENABLED,
            0x8004537C => ITF::FSRM_E_CANNOT_CREATE_TEMP_COPY,
            0x8004537D => ITF::FSRM_E_NO_EMAIL_ADDRESS,
            0x8004537E => ITF::FSRM_E_ADR_MAX_EMAILS_SENT,
            0x8004537F => ITF::FSRM_E_PATH_NOT_IN_NAMESPACE,
            0x80045380 => ITF::FSRM_E_RMS_TEMPLATE_NOT_FOUND,
            0x80045381 => ITF::FSRM_E_SECURE_PROPERTIES_NOT_SUPPORTED,
            0x80045382 => ITF::FSRM_E_RMS_NO_PROTECTORS_INSTALLED,
            0x80045383 => ITF::FSRM_E_RMS_NO_PROTECTOR_INSTALLED_FOR_FILE,
            0x80045384 => ITF::FSRM_E_PROPERTY_MUST_APPLY_TO_FOLDERS,
            0x80045385 => ITF::FSRM_E_PROPERTY_MUST_BE_SECURE,
            0x80045386 => ITF::FSRM_E_PROPERTY_MUST_BE_GLOBAL,
            0x80045387 => ITF::FSRM_E_WMI_FAILURE,
            0x80045388 => ITF::FSRM_E_FILE_MANAGEMENT_JOB_RMS,
            0x80045389 => ITF::FSRM_E_SYNC_TASK_HAD_ERRORS,
            0x80045390 => ITF::FSRM_E_ADR_SRV_NOT_SUPPORTED,
            0x80045391 => ITF::FSRM_E_ADR_PATH_IS_LOCAL,
            0x80045392 => ITF::FSRM_E_ADR_NOT_DOMAIN_JOINED,
            0x80045393 => ITF::FSRM_E_CANNOT_REMOVE_READONLY,
            0x80045394 => ITF::FSRM_E_FILE_MANAGEMENT_JOB_INVALID_CONTINUOUS_CONFIG,
            0x80045395 => ITF::FSRM_E_LEGACY_SCHEDULE,
            0x80045396 => ITF::FSRM_E_CSC_PATH_NOT_SUPPORTED,
            0x80045397 => ITF::FSRM_E_EXPIRATION_PATH_NOT_WRITEABLE,
            0x80045398 => ITF::FSRM_E_EXPIRATION_PATH_TOO_LONG,
            0x80045399 => ITF::FSRM_E_EXPIRATION_VOLUME_NOT_NTFS,
            0x8004539A => ITF::FSRM_E_FILE_MANAGEMENT_JOB_DEPRECATED,
            0x8004539B => ITF::FSRM_E_MODULE_TIMEOUT,
            0x80047200 => ITF::IFED_S_MORE_ENTRIES,
            0x80047201 => ITF::IFED_S_EMPTY_DICTIONARY,
            0x80047202 => ITF::IFED_S_WORD_EXISTS,
            0x80047203 => ITF::IFED_S_COMMENT_CHANGED,
            0x80047300 => ITF::IFED_E_NOT_FOUND,
            0x80047301 => ITF::IFED_E_INVALID_FORMAT,
            0x80047302 => ITF::IFED_E_OPEN_FAILED,
            0x80047303 => ITF::IFED_E_WRITE_FAILED,
            0x80047304 => ITF::IFED_E_NO_ENTRY,
            0x80047305 => ITF::IFED_E_REGISTER_FAILED,
            0x80047306 => ITF::IFED_E_NOT_USER_DIC,
            0x80047307 => ITF::IFED_E_NOT_SUPPORTED,
            0x80047308 => ITF::IFED_E_USER_COMMENT,
            0x80047309 => ITF::IFED_E_REGISTER_ILLEGAL_POS,
            0x8004730A => ITF::IFED_E_REGISTER_IMPROPER_WORD,
            0x8004730B => ITF::IFED_E_REGISTER_DISCONNECTED,
            0x8004A020 => ITF::NETCFG_E_ALREADY_INITIALIZED,
            0x8004A020 => ITF::UPNP_E_REQUIRED_ELEMENT_ERROR,
            0x8004A021 => ITF::NETCFG_E_NOT_INITIALIZED,
            0x8004A021 => ITF::UPNP_E_DUPLICATE_NOT_ALLOWED,
            0x8004A022 => ITF::NETCFG_E_IN_USE,
            0x8004A022 => ITF::UPNP_E_DUPLICATE_SERVICE_ID,
            0x8004A023 => ITF::UPNP_E_INVALID_DESCRIPTION,
            0x8004A024 => ITF::NETCFG_E_NO_WRITE_LOCK,
            0x8004A024 => ITF::UPNP_E_INVALID_SERVICE,
            0x8004A025 => ITF::NETCFG_E_NEED_REBOOT,
            0x8004A025 => ITF::UPNP_E_INVALID_ICON,
            0x8004A026 => ITF::NETCFG_E_ACTIVE_RAS_CONNECTIONS,
            0x8004A026 => ITF::UPNP_E_INVALID_XML,
            0x8004A027 => ITF::NETCFG_E_ADAPTER_NOT_FOUND,
            0x8004A027 => ITF::UPNP_E_INVALID_ROOT_NAMESPACE,
            0x8004A028 => ITF::NETCFG_E_COMPONENT_REMOVED_PENDING_REBOOT,
            0x8004A028 => ITF::UPNP_E_SUFFIX_TOO_LONG,
            0x8004A029 => ITF::NETCFG_E_MAX_FILTER_LIMIT,
            0x8004A029 => ITF::UPNP_E_URLBASE_PRESENT,
            0x8004A02A => ITF::NETCFG_E_VMSWITCH_ACTIVE_OVER_ADAPTER,
            0x8004A02B => ITF::NETCFG_E_DUPLICATE_INSTANCEID,
            0x8004A030 => ITF::UPNP_E_VALUE_TOO_LONG,
            0x8004A031 => ITF::UPNP_E_DEVICE_RUNNING,
            0x8004A032 => ITF::UPNP_E_DEVICE_NOTREGISTERED,
            0x8004B200 => ITF::WTS_E_FAILEDEXTRACTION,
            0x8004B201 => ITF::WTS_E_EXTRACTIONTIMEDOUT,
            0x8004B202 => ITF::WTS_E_SURROGATEUNAVAILABLE,
            0x8004B203 => ITF::WTS_E_FASTEXTRACTIONNOTSUPPORTED,
            0x8004B204 => ITF::WTS_E_DATAFILEUNAVAILABLE,
            0x8004CB00 => ITF::FTE_E_CB_OUT_OF_MEMORY,
            0x8004CB01 => ITF::FTE_E_CB_CBID_OUT_OF_BOUND,
            0x8004CB02 => ITF::FTE_E_CB_NOT_ENOUGH_AVAIL_PHY_MEM,
            0x8004CB03 => ITF::FTE_E_CB_NOT_ENOUGH_OCC_BUFFER,
            0x8004CB04 => ITF::FTE_E_CORRUPT_WORDLIST,
            0x8004D000 => ITF::XACT_E_ALREADYOTHERSINGLEPHASE,
            0x8004D001 => ITF::XACT_E_CANTRETAIN,
            0x8004D002 => ITF::XACT_E_COMMITFAILED,
            0x8004D003 => ITF::XACT_E_COMMITPREVENTED,
            0x8004D004 => ITF::XACT_E_HEURISTICABORT,
            0x8004D005 => ITF::XACT_E_HEURISTICCOMMIT,
            0x8004D006 => ITF::XACT_E_HEURISTICDAMAGE,
            0x8004D007 => ITF::XACT_E_HEURISTICDANGER,
            0x8004D008 => ITF::XACT_E_ISOLATIONLEVEL,
            0x8004D009 => ITF::XACT_E_NOASYNC,
            0x8004D00A => ITF::XACT_E_NOENLIST,
            0x8004D00B => ITF::XACT_E_NOISORETAIN,
            0x8004D00C => ITF::XACT_E_NORESOURCE,
            0x8004D00D => ITF::XACT_E_NOTCURRENT,
            0x8004D00E => ITF::XACT_E_NOTRANSACTION,
            0x8004D00F => ITF::XACT_E_NOTSUPPORTED,
            0x8004D010 => ITF::XACT_E_UNKNOWNRMGRID,
            0x8004D011 => ITF::XACT_E_WRONGSTATE,
            0x8004D012 => ITF::XACT_E_WRONGUOW,
            0x8004D013 => ITF::XACT_E_XTIONEXISTS,
            0x8004D014 => ITF::XACT_E_NOIMPORTOBJECT,
            0x8004D015 => ITF::XACT_E_INVALIDCOOKIE,
            0x8004D016 => ITF::XACT_E_INDOUBT,
            0x8004D017 => ITF::XACT_E_NOTIMEOUT,
            0x8004D018 => ITF::XACT_E_ALREADYINPROGRESS,
            0x8004D019 => ITF::XACT_E_ABORTED,
            0x8004D01A => ITF::XACT_E_LOGFULL,
            0x8004D01B => ITF::XACT_E_TMNOTAVAILABLE,
            0x8004D01C => ITF::XACT_E_CONNECTION_DOWN,
            0x8004D01D => ITF::XACT_E_CONNECTION_DENIED,
            0x8004D01E => ITF::XACT_E_REENLISTTIMEOUT,
            0x8004D01F => ITF::XACT_E_TIP_CONNECT_FAILED,
            0x8004D020 => ITF::XACT_E_TIP_PROTOCOL_ERROR,
            0x8004D021 => ITF::XACT_E_TIP_PULL_FAILED,
            0x8004D022 => ITF::XACT_E_DEST_TMNOTAVAILABLE,
            0x8004D023 => ITF::XACT_E_TIP_DISABLED,
            0x8004D024 => ITF::XACT_E_NETWORK_TX_DISABLED,
            0x8004D025 => ITF::XACT_E_PARTNER_NETWORK_TX_DISABLED,
            0x8004D026 => ITF::XACT_E_XA_TX_DISABLED,
            0x8004D027 => ITF::XACT_E_UNABLE_TO_READ_DTC_CONFIG,
            0x8004D028 => ITF::XACT_E_UNABLE_TO_LOAD_DTC_PROXY,
            0x8004D029 => ITF::XACT_E_ABORTING,
            0x8004D02A => ITF::XACT_E_PUSH_COMM_FAILURE,
            0x8004D02B => ITF::XACT_E_PULL_COMM_FAILURE,
            0x8004D02C => ITF::XACT_E_LU_TX_DISABLED,
            0x8004D080 => ITF::XACT_E_CLERKNOTFOUND,
            0x8004D081 => ITF::XACT_E_CLERKEXISTS,
            0x8004D082 => ITF::XACT_E_RECOVERYINPROGRESS,
            0x8004D083 => ITF::XACT_E_TRANSACTIONCLOSED,
            0x8004D084 => ITF::XACT_E_INVALIDLSN,
            0x8004D085 => ITF::XACT_E_REPLAYREQUEST,
            0x8004D100 => ITF::XACT_E_CONNECTION_REQUEST_DENIED,
            0x8004D101 => ITF::XACT_E_TOOMANY_ENLISTMENTS,
            0x8004D102 => ITF::XACT_E_DUPLICATE_GUID,
            0x8004D102 => ITF::SL_REMAPPING_SP_STATUS_SYSTEM_TIME_SKEWED,
            0x8004D103 => ITF::XACT_E_NOTSINGLEPHASE,
            0x8004D104 => ITF::XACT_E_RECOVERYALREADYDONE,
            0x8004D105 => ITF::XACT_E_PROTOCOL,
            0x8004D106 => ITF::XACT_E_RM_FAILURE,
            0x8004D107 => ITF::XACT_E_RECOVERY_FAILED,
            0x8004D108 => ITF::XACT_E_LU_NOT_FOUND,
            0x8004D109 => ITF::XACT_E_DUPLICATE_LU,
            0x8004D10A => ITF::XACT_E_LU_NOT_CONNECTED,
            0x8004D10B => ITF::XACT_E_DUPLICATE_TRANSID,
            0x8004D10B => ITF::SL_REMAPPING_SP_STATUS_DEBUGGER_DETECTED,
            0x8004D10C => ITF::XACT_E_LU_BUSY,
            0x8004D10D => ITF::XACT_E_LU_NO_RECOVERY_PROCESS,
            0x8004D10E => ITF::XACT_E_LU_DOWN,
            0x8004D10F => ITF::XACT_E_LU_RECOVERING,
            0x8004D110 => ITF::XACT_E_LU_RECOVERY_MISMATCH,
            0x8004D111 => ITF::XACT_E_RM_UNAVAILABLE,
            0x8004E002 => ITF::CONTEXT_E_ABORTED,
            0x8004E003 => ITF::CONTEXT_E_ABORTING,
            0x8004E004 => ITF::CONTEXT_E_NOCONTEXT,
            0x8004E005 => ITF::CONTEXT_E_WOULD_DEADLOCK,
            0x8004E006 => ITF::CONTEXT_E_SYNCH_TIMEOUT,
            0x8004E007 => ITF::CONTEXT_E_OLDREF,
            0x8004E00C => ITF::CONTEXT_E_ROLENOTFOUND,
            0x8004E00F => ITF::CONTEXT_E_TMNOTAVAILABLE,
            0x8004E021 => ITF::CO_E_ACTIVATIONFAILED,
            0x8004E022 => ITF::CO_E_ACTIVATIONFAILED_EVENTLOGGED,
            0x8004E023 => ITF::CO_E_ACTIVATIONFAILED_CATALOGERROR,
            0x8004E024 => ITF::CO_E_ACTIVATIONFAILED_TIMEOUT,
            0x8004E025 => ITF::CO_E_INITIALIZATIONFAILED,
            0x8004E026 => ITF::CONTEXT_E_NOJIT,
            0x8004E026 => ITF::SL_E_INVALID_USE_OF_ADD_ON_PKEY,
            0x8004E027 => ITF::CONTEXT_E_NOTRANSACTION,
            0x8004E028 => ITF::CO_E_THREADINGMODEL_CHANGED,
            0x8004E029 => ITF::CO_E_NOIISINTRINSICS,
            0x8004E02A => ITF::CO_E_NOCOOKIES,
            0x8004E02B => ITF::CO_E_DBERROR,
            0x8004E02C => ITF::CO_E_NOTPOOLED,
            0x8004E02D => ITF::CO_E_NOTCONSTRUCTED,
            0x8004E02E => ITF::CO_E_NOSYNCHRONIZATION,
            0x8004E02F => ITF::CO_E_ISOLEVELMISMATCH,
            0x8004E030 => ITF::CO_E_CALL_OUT_OF_TX_SCOPE_NOT_ALLOWED,
            0x8004E031 => ITF::CO_E_EXIT_TRANSACTION_SCOPE_NOT_CALLED,
            0x8004E101 => ITF::SL_E_SFS_INVALID_FS_VERSION,
            0x8004E102 => ITF::SL_E_SFS_INVALID_FD_TABLE,
            0x8004E103 => ITF::SL_E_SFS_INVALID_SYNC,
            0x8004E104 => ITF::SL_E_SFS_BAD_TOKEN_NAME,
            0x8004E105 => ITF::SL_E_SFS_BAD_TOKEN_EXT,
            0x8004E106 => ITF::SL_E_SFS_DUPLICATE_TOKEN_NAME,
            0x8004E107 => ITF::SL_E_SFS_TOKEN_SIZE_MISMATCH,
            0x8004E108 => ITF::SL_E_SFS_INVALID_TOKEN_DATA_HASH,
            0x8004E109 => ITF::SL_E_SFS_FILE_READ_ERROR,
            0x8004E10A => ITF::SL_E_SFS_FILE_WRITE_ERROR,
            0x8004E10B => ITF::SL_E_SFS_INVALID_FILE_POSITION,
            0x8004E10C => ITF::SL_E_SFS_NO_ACTIVE_TRANSACTION,
            0x8004E10D => ITF::SL_E_SFS_INVALID_FS_HEADER,
            0x8004E10E => ITF::SL_E_SFS_INVALID_TOKEN_DESCRIPTOR,
            0x8004FD00 => ITF::FTE_E_FD_NO_IPERSIST_INTERFACE,
            0x8004FD01 => ITF::FTE_E_FD_IFILTER_INIT_FAILED,
            0x8004FD02 => ITF::FTE_E_FD_FAILED_TO_LOAD_IFILTER,
            0x8004FD03 => ITF::FTE_E_FD_DOC_TIMEOUT,
            0x8004FD04 => ITF::FTE_E_FD_UNEXPECTED_EXIT,
            0x8004FD05 => ITF::FTE_E_FD_DOC_UNEXPECTED_EXIT,
            0x8004FD06 => ITF::FTE_E_FD_NOISE_NO_TEXT_FILTER,
            0x8004FD07 => ITF::FTE_E_FD_NOISE_NO_IPERSISTSTREAM_ON_TEXT_FILTER,
            0x8004FD08 => ITF::FTE_E_FD_NOISE_TEXT_FILTER_LOAD_FAILED,
            0x8004FD09 => ITF::FTE_E_FD_NOISE_TEXT_FILTER_INIT_FAILED,
            0x8004FD0A => ITF::FTE_E_FD_OCCURRENCE_OVERFLOW,
            0x8004FD0B => ITF::FTE_E_FD_FILTER_CAUSED_SHARING_VIOLATION,
            0xC0040003 => ITF::IO_ERR_CONFIGURATION_ERROR,
            0xC0040004 => ITF::IO_ERR_DRIVER_ERROR,
            0xC0040005 => ITF::IO_ERR_PARITY,
            0xC0040006 => ITF::IO_ERR_SEEK_ERROR,
            0xC0040007 => ITF::IO_ERR_BAD_BLOCK,
            0xC0040008 => ITF::IO_ERR_OVERRUN_ERROR,
            0xC0040009 => ITF::IO_ERR_TIMEOUT,
            0xC004000A => ITF::IO_ERR_SEQUENCE,
            0xC004000B => ITF::IO_ERR_CONTROLLER_ERROR,
            0xC004000C => ITF::IO_ERR_INTERNAL_ERROR,
            0xC004000D => ITF::IO_ERR_INCORRECT_IRQL,
            0xC004000E => ITF::IO_ERR_INVALID_IOBASE,
            0xC004000F => ITF::IO_ERR_NOT_READY,
            0xC0040010 => ITF::IO_ERR_INVALID_REQUEST,
            0xC0040011 => ITF::IO_ERR_VERSION,
            0xC0040012 => ITF::IO_ERR_LAYERED_FAILURE,
            0xC0040013 => ITF::IO_ERR_RESET,
            0xC0040014 => ITF::IO_ERR_PROTOCOL,
            0xC0040015 => ITF::IO_ERR_MEMORY_CONFLICT_DETECTED,
            0xC0040016 => ITF::IO_ERR_PORT_CONFLICT_DETECTED,
            0xC0040017 => ITF::IO_ERR_DMA_CONFLICT_DETECTED,
            0xC0040018 => ITF::IO_ERR_IRQ_CONFLICT_DETECTED,
            0xC0040019 => ITF::IO_ERR_BAD_FIRMWARE,
            0xC004001B => ITF::IO_ERR_DMA_RESOURCE_CONFLICT,
            0xC004001C => ITF::IO_ERR_INTERRUPT_RESOURCE_CONFLICT,
            0xC004001D => ITF::IO_ERR_MEMORY_RESOURCE_CONFLICT,
            0xC004001E => ITF::IO_ERR_PORT_RESOURCE_CONFLICT,
            0xC004001F => ITF::IO_BAD_BLOCK_WITH_NAME,
            0xC0040029 => ITF::IO_FILE_SYSTEM_CORRUPT,
            0xC004002A => ITF::IO_FILE_QUOTA_CORRUPT,
            0xC004002B => ITF::IO_SYSTEM_SLEEP_FAILED,
            0xC004002C => ITF::IO_DUMP_POINTER_FAILURE,
            0xC004002D => ITF::IO_DUMP_DRIVER_LOAD_FAILURE,
            0xC004002E => ITF::IO_DUMP_INITIALIZATION_FAILURE,
            0xC004002F => ITF::IO_DUMP_DUMPFILE_CONFLICT,
            0xC0040030 => ITF::IO_DUMP_DIRECT_CONFIG_FAILED,
            0xC0040031 => ITF::IO_DUMP_PAGE_CONFIG_FAILED,
            0xC0040037 => ITF::IO_FILE_SYSTEM_CORRUPT_WITH_NAME,
            0xC004006C => ITF::IO_ERR_THREAD_STUCK_IN_DEVICE_DRIVER,
            0xC0040075 => ITF::IO_ERR_PORT_TIMEOUT,
            0xC0040096 => ITF::IO_ERROR_DISK_RESOURCES_EXHAUSTED,
            0xC004009A => ITF::IO_ERROR_IO_HARDWARE_ERROR,
            0xC0040200 => ITF::ES_E_INVALID_RESPONSE,
            0xC0040204 => ITF::ES_E_UNPROVISIONED_HARDWARE,
            0xC0040205 => ITF::ES_E_UNSUPPORTED_HARDWARE,
            0xC0040206 => ITF::ES_E_INCOMPLETE_COMMAND,
            0xC0040207 => ITF::ES_E_BAD_SEQUENCE,
            0xC0040208 => ITF::ES_E_NO_PROBE,
            0xC0040209 => ITF::ES_E_INVALID_SILO,
            0xC004020A => ITF::ES_E_INVALID_CAPABILITY,
            0xC004020B => ITF::ES_E_GROUP_POLICY_FORBIDDEN_USE,
            0xC004020C => ITF::ES_E_GROUP_POLICY_FORBIDDEN_OPERATION,
            0xC004020D => ITF::ES_E_INVALID_PARAM_COMBINATION,
            0xC004020E => ITF::ES_E_INVALID_PARAM_LENGTH,
            0xC004020F => ITF::ES_E_INCONSISTENT_PARAM_LENGTH,
            0xC0040400 => ITF::ES_E_NO_AUTHENTICATION_REQUIRED,
            0xC0040DB9 => ITF::GTHR_E_NTF_CLIENT_NOT_SUBSCRIBED,
            0xC0041100 => ITF::ES_E_INVALID_FIELD_IDENTIFIER,
            0xC0041101 => ITF::ES_E_CHALLENGE_MISMATCH,
            0xC0041102 => ITF::ES_E_CHALLENGE_SIZE_MISMATCH,
            0xC0041103 => ITF::ES_E_FRIENDLY_NAME_TOO_LONG,
            0xC0041104 => ITF::ES_E_SILO_NAME_TOO_LONG,
            0xC0041105 => ITF::ES_E_PASSWORD_TOO_LONG,
            0xC0041106 => ITF::ES_E_PASSWORD_HINT_TOO_LONG,
            0xC0041107 => ITF::ES_E_OTHER_SECURITY_PROTOCOL_ACTIVE,
            0xC0041108 => ITF::ES_E_DEVICE_DIGEST_MISSING,
            0xC0041109 => ITF::ES_E_NOT_AUTHORIZED_UNEXPECTED,
            0xC004110A => ITF::ES_E_AUTHORIZED_UNEXPECTED,
            0xC004110B => ITF::ES_E_PROVISIONED_UNEXPECTED,
            0xC004110C => ITF::ES_E_UNKNOWN_DIGEST_ALGORITHM,
            0xC0041678 => ITF::QUTIL_E_INVALID_CODEPAGE,
            0xC0041734 => ITF::FILTER_E_CONTENTINDEXCORRUPT,
            0xC0041800 => ITF::CI_CORRUPT_DATABASE,
            0xC0041801 => ITF::CI_CORRUPT_CATALOG,
            0xC0041802 => ITF::CI_INVALID_PARTITION,
            0xC0041803 => ITF::CI_INVALID_PRIORITY,
            0xC0041804 => ITF::CI_NO_STARTING_KEY,
            0xC0041805 => ITF::CI_OUT_OF_INDEX_IDS,
            0xC0041806 => ITF::CI_NO_CATALOG,
            0xC0041807 => ITF::CI_CORRUPT_FILTER_BUFFER,
            0xC0041808 => ITF::CI_INVALID_INDEX,
            0xC0041809 => ITF::CI_PROPSTORE_INCONSISTENCY,
            0xC0041821 => ITF::CI_INCORRECT_VERSION,
            0xC0041822 => ITF::CI_E_ENUMERATION_STARTED,
            0xC0041823 => ITF::CI_E_PROPERTY_TOOLARGE,
            0xC0041824 => ITF::CI_E_CLIENT_FILTER_ABORT,
            0xC004182D => ITF::CI_E_CORRUPT_FWIDX,
            0xC004182E => ITF::CI_E_DIACRITIC_SETTINGS_DIFFER,
            0xC0041831 => ITF::CI_E_NO_CATALOG_MANAGER,
            0xC004365A => ITF::FTE_E_NO_PROPERTY_STORE,
            0xC004B001 => ITF::SL_E_SRV_INVALID_PUBLISH_LICENSE,
            0xC004B002 => ITF::SL_E_SRV_INVALID_PRODUCT_KEY_LICENSE,
            0xC004B003 => ITF::SL_E_SRV_INVALID_RIGHTS_ACCOUNT_LICENSE,
            0xC004B004 => ITF::SL_E_SRV_INVALID_LICENSE_STRUCTURE,
            0xC004B005 => ITF::SL_E_SRV_AUTHORIZATION_FAILED,
            0xC004B006 => ITF::SL_E_SRV_INVALID_BINDING,
            0xC004B007 => ITF::SL_E_SRV_SERVER_PONG,
            0xC004B008 => ITF::SL_E_SRV_INVALID_PAYLOAD,
            0xC004B009 => ITF::SL_E_SRV_INVALID_SECURITY_PROCESSOR_LICENSE,
            0xC004B010 => ITF::SL_E_SRV_BUSINESS_TOKEN_ENTRY_NOT_FOUND,
            0xC004B011 => ITF::SL_E_SRV_CLIENT_CLOCK_OUT_OF_SYNC,
            0xC004B100 => ITF::SL_E_SRV_GENERAL_ERROR,
            0xC004C001 => ITF::SL_E_CHPA_PRODUCT_KEY_OUT_OF_RANGE,
            0xC004C002 => ITF::SL_E_CHPA_INVALID_BINDING,
            0xC004C003 => ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED,
            0xC004C004 => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY,
            0xC004C005 => ITF::SL_E_CHPA_BINDING_NOT_FOUND,
            0xC004C006 => ITF::SL_E_CHPA_BINDING_MAPPING_NOT_FOUND,
            0xC004C007 => ITF::SL_E_CHPA_UNSUPPORTED_PRODUCT_KEY,
            0xC004C008 => ITF::SL_E_CHPA_MAXIMUM_UNLOCK_EXCEEDED,
            0xC004C009 => ITF::SL_E_CHPA_ACTCONFIG_ID_NOT_FOUND,
            0xC004C00A => ITF::SL_E_CHPA_INVALID_PRODUCT_DATA_ID,
            0xC004C00B => ITF::SL_E_CHPA_INVALID_PRODUCT_DATA,
            0xC004C00C => ITF::SL_E_CHPA_SYSTEM_ERROR,
            0xC004C00D => ITF::SL_E_CHPA_INVALID_ACTCONFIG_ID,
            0xC004C00E => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_LENGTH,
            0xC004C00F => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_FORMAT,
            0xC004C010 => ITF::SL_E_CHPA_INVALID_PRODUCT_KEY_CHAR,
            0xC004C011 => ITF::SL_E_CHPA_INVALID_BINDING_URI,
            0xC004C012 => ITF::SL_E_CHPA_NETWORK_ERROR,
            0xC004C013 => ITF::SL_E_CHPA_DATABASE_ERROR,
            0xC004C014 => ITF::SL_E_CHPA_INVALID_ARGUMENT,
            0xC004C015 => ITF::SL_E_CHPA_RESPONSE_NOT_AVAILABLE,
            0xC004C016 => ITF::SL_E_CHPA_OEM_SLP_COA0,
            0xC004C017 => ITF::SL_E_CHPA_PRODUCT_KEY_BLOCKED_IPLOCATION,
            0xC004C020 => ITF::SL_E_CHPA_DMAK_LIMIT_EXCEEDED,
            0xC004C021 => ITF::SL_E_CHPA_DMAK_EXTENSION_LIMIT_EXCEEDED,
            0xC004C022 => ITF::SL_E_CHPA_REISSUANCE_LIMIT_NOT_FOUND,
            0xC004C023 => ITF::SL_E_CHPA_OVERRIDE_REQUEST_NOT_FOUND,
            0xC004C030 => ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_BEFORE_START_DATE,
            0xC004C031 => ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_AFTER_END_DATE,
            0xC004C032 => ITF::SL_E_CHPA_TIMEBASED_ACTIVATION_NOT_AVAILABLE,
            0xC004C033 => ITF::SL_E_CHPA_TIMEBASED_PRODUCT_KEY_NOT_CONFIGURED,
            0xC004C04F => ITF::SL_E_CHPA_NO_RULES_TO_ACTIVATE,
            0xC004C050 => ITF::SL_E_CHPA_GENERAL_ERROR,
            0xC004C051 => ITF::SL_E_CHPA_DIGITALMARKER_INVALID_BINDING,
            0xC004C052 => ITF::SL_E_CHPA_DIGITALMARKER_BINDING_NOT_CONFIGURED,
            0xC004C060 => ITF::SL_E_CHPA_DYNAMICALLY_BLOCKED_PRODUCT_KEY,
            0xC004C291 => ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE,
            0xC004C292 => ITF::SL_E_INVALID_LICENSE_STATE_BREACH_GRACE_EXPIRED,
            0xC004C2F6 => ITF::SL_E_INVALID_TEMPLATE_ID,
            0xC004C2FA => ITF::SL_E_INVALID_XML_BLOB,
            0xC004C327 => ITF::SL_E_VALIDATION_BLOB_PARAM_NOT_FOUND,
            0xC004C328 => ITF::SL_E_INVALID_CLIENT_TOKEN,
            0xC004C329 => ITF::SL_E_INVALID_OFFLINE_BLOB,
            0xC004C32A => ITF::SL_E_OFFLINE_VALIDATION_BLOB_PARAM_NOT_FOUND,
            0xC004C32B => ITF::SL_E_INVALID_OSVERSION_TEMPLATEID,
            0xC004C32C => ITF::SL_E_OFFLINE_GENUINE_BLOB_REVOKED,
            0xC004C32D => ITF::SL_E_OFFLINE_GENUINE_BLOB_NOT_FOUND,
            0xC004C3FF => ITF::SL_E_CHPA_MSCH_RESPONSE_NOT_AVAILABLE_VGA,
            0xC004C401 => ITF::SL_E_INVALID_OS_FOR_PRODUCT_KEY,
            0xC004C4A1 => ITF::SL_E_INVALID_FILE_HASH,
            0xC004C4A2 => ITF::SL_E_VALIDATION_BLOCKED_PRODUCT_KEY,
            0xC004C4A4 => ITF::SL_E_MISMATCHED_KEY_TYPES,
            0xC004C4A5 => ITF::SL_E_VALIDATION_INVALID_PRODUCT_KEY,
            0xC004C4A7 => ITF::SL_E_INVALID_OEM_OR_VOLUME_BINDING_DATA,
            0xC004C4A8 => ITF::SL_E_INVALID_LICENSE_STATE,
            0xC004C4A9 => ITF::SL_E_IP_LOCATION_FALIED,
            0xC004C4AB => ITF::SL_E_SOFTMOD_EXPLOIT_DETECTED,
            0xC004C4AC => ITF::SL_E_INVALID_TOKEN_DATA,
            0xC004C4AD => ITF::SL_E_HEALTH_CHECK_FAILED_NEUTRAL_FILES,
            0xC004C4AE => ITF::SL_E_HEALTH_CHECK_FAILED_MUI_FILES,
            0xC004C4AF => ITF::SL_E_INVALID_AD_DATA,
            0xC004C4B0 => ITF::SL_E_INVALID_RSDP_COUNT,
            0xC004C4B1 => ITF::SL_E_ENGINE_DETECTED_EXPLOIT,
            0xC004C531 => ITF::SL_E_NOTIFICATION_BREACH_DETECTED,
            0xC004C532 => ITF::SL_E_NOTIFICATION_GRACE_EXPIRED,
            0xC004C533 => ITF::SL_E_NOTIFICATION_OTHER_REASONS,
            0xC004C600 => ITF::SL_E_NON_GENUINE_STATUS_LAST,
            0xC004C700 => ITF::SL_E_CHPA_BUSINESS_RULE_INPUT_NOT_FOUND,
            0xC004C750 => ITF::SL_E_CHPA_NULL_VALUE_FOR_PROPERTY_NAME_OR_ID,
            0xC004C751 => ITF::SL_E_CHPA_UNKNOWN_PROPERTY_NAME,
            0xC004C752 => ITF::SL_E_CHPA_UNKNOWN_PROPERTY_ID,
            0xC004C755 => ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCTKEY_BINDING,
            0xC004C756 => ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCTKEY_BINDING,
            0xC004C757 => ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCTKEY_BINDING,
            0xC004C758 => ITF::SL_E_CHPA_FAILED_TO_PROCESS_PRODUCT_KEY_BINDINGS_XML,
            0xC004C75A => ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_PROPERTY,
            0xC004C75B => ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_PROPERTY,
            0xC004C75C => ITF::SL_E_CHPA_FAILED_TO_DELETE_PRODUCT_KEY_PROPERTY,
            0xC004C764 => ITF::SL_E_CHPA_UNKNOWN_PRODUCT_KEY_TYPE,
            0xC004C770 => ITF::SL_E_CHPA_PRODUCT_KEY_BEING_USED,
            0xC004C780 => ITF::SL_E_CHPA_FAILED_TO_INSERT_PRODUCT_KEY_RECORD,
            0xC004C781 => ITF::SL_E_CHPA_FAILED_TO_UPDATE_PRODUCT_KEY_RECORD,
            0xC004D000 => ITF::SL_REMAPPING_SP_PUB_API_INVALID_LICENSE,
            0xC004D009 => ITF::SL_REMAPPING_SP_PUB_API_INVALID_ALGORITHM_TYPE,
            0xC004D00C => ITF::SL_REMAPPING_SP_PUB_API_TOO_MANY_LOADED_ENVIRONMENTS,
            0xC004D012 => ITF::SL_REMAPPING_SP_PUB_API_BAD_GET_INFO_QUERY,
            0xC004D02C => ITF::SL_REMAPPING_SP_PUB_API_INVALID_HANDLE,
            0xC004D055 => ITF::SL_REMAPPING_SP_PUB_API_INVALID_KEY_LENGTH,
            0xC004D073 => ITF::SL_REMAPPING_SP_PUB_API_NO_AES_PROVIDER,
            0xC004D081 => ITF::SL_REMAPPING_SP_PUB_API_HANDLE_NOT_COMMITED,
            0xC004D101 => ITF::SL_REMAPPING_SP_PUB_GENERAL_NOT_INITIALIZED,
            0xC004D103 => ITF::SL_REMAPPING_SP_STATUS_GENERIC_FAILURE,
            0xC004D104 => ITF::SL_REMAPPING_SP_STATUS_INVALIDARG,
            0xC004D105 => ITF::SL_REMAPPING_SP_STATUS_ALREADY_EXISTS,
            0xC004D107 => ITF::SL_REMAPPING_SP_STATUS_INSUFFICIENT_BUFFER,
            0xC004D108 => ITF::SL_REMAPPING_SP_STATUS_INVALIDDATA,
            0xC004D109 => ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_CALL,
            0xC004D10A => ITF::SL_REMAPPING_SP_STATUS_INVALID_SPAPI_VERSION,
            0xC004D10C => ITF::SL_REMAPPING_SP_STATUS_NO_MORE_DATA,
            0xC004D201 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_KEYLENGTH,
            0xC004D202 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCKLENGTH,
            0xC004D203 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHER,
            0xC004D204 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_CIPHERMODE,
            0xC004D205 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_PROVIDERID,
            0xC004D206 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_KEYID,
            0xC004D207 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_HASHID,
            0xC004D208 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_UNKNOWN_ATTRIBUTEID,
            0xC004D209 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_HASH_FINALIZED,
            0xC004D20A => ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_AVAILABLE,
            0xC004D20B => ITF::SL_REMAPPING_SP_PUB_CRYPTO_KEY_NOT_FOUND,
            0xC004D20C => ITF::SL_REMAPPING_SP_PUB_CRYPTO_NOT_BLOCK_ALIGNED,
            0xC004D20D => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURELENGTH,
            0xC004D20E => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_SIGNATURE,
            0xC004D20F => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_BLOCK,
            0xC004D210 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_FORMAT,
            0xC004D211 => ITF::SL_REMAPPING_SP_PUB_CRYPTO_INVALID_PADDING,
            0xC004D301 => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED,
            0xC004D302 => ITF::SL_REMAPPING_SP_PUB_TS_REARMED,
            0xC004D303 => ITF::SL_REMAPPING_SP_PUB_TS_RECREATED,
            0xC004D304 => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_NOT_FOUND,
            0xC004D305 => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_ALREADY_EXISTS,
            0xC004D306 => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_KEY_SIZE_TOO_BIG,
            0xC004D307 => ITF::SL_REMAPPING_SP_PUB_TS_MAX_REARM_REACHED,
            0xC004D308 => ITF::SL_REMAPPING_SP_PUB_TS_DATA_SIZE_TOO_BIG,
            0xC004D309 => ITF::SL_REMAPPING_SP_PUB_TS_INVALID_HW_BINDING,
            0xC004D30A => ITF::SL_REMAPPING_SP_PUB_TIMER_ALREADY_EXISTS,
            0xC004D30B => ITF::SL_REMAPPING_SP_PUB_TIMER_NOT_FOUND,
            0xC004D30C => ITF::SL_REMAPPING_SP_PUB_TIMER_EXPIRED,
            0xC004D30D => ITF::SL_REMAPPING_SP_PUB_TIMER_NAME_SIZE_TOO_BIG,
            0xC004D30E => ITF::SL_REMAPPING_SP_PUB_TS_FULL,
            0xC004D310 => ITF::SL_REMAPPING_SP_PUB_TS_ENTRY_READ_ONLY,
            0xC004D311 => ITF::SL_REMAPPING_SP_PUB_TIMER_READ_ONLY,
            0xC004D312 => ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_READ_ONLY,
            0xC004D313 => ITF::SL_REMAPPING_SP_PUB_TS_ATTRIBUTE_NOT_FOUND,
            0xC004D314 => ITF::SL_REMAPPING_SP_PUB_TS_ACCESS_DENIED,
            0xC004D315 => ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_NOT_FOUND,
            0xC004D316 => ITF::SL_REMAPPING_SP_PUB_TS_NAMESPACE_IN_USE,
            0xC004D317 => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_LOAD_INVALID,
            0xC004D318 => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_BREADCRUMB_GENERATION,
            0xC004D319 => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_INVALID_DATA,
            0xC004D31A => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_NO_DATA,
            0xC004D31B => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_BREADCRUMB_MISMATCH,
            0xC004D31C => ITF::SL_REMAPPING_SP_PUB_TS_TAMPERED_DATA_VERSION_MISMATCH,
            0xC004D401 => ITF::SL_REMAPPING_SP_PUB_TAMPER_MODULE_AUTHENTICATION,
            0xC004D402 => ITF::SL_REMAPPING_SP_PUB_TAMPER_SECURITY_PROCESSOR_PATCHED,
            0xC004D501 => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER,
            0xC004D502 => ITF::SL_REMAPPING_SP_PUB_KM_CACHE_TAMPER_RESTORE_FAILED,
            0xC004D701 => ITF::SL_REMAPPING_SP_STATUS_PUSHKEY_CONFLICT,
            0xC004D702 => ITF::SL_REMAPPING_SP_PUB_PROXY_SOFT_TAMPER,
            0xC004E001 => ITF::SL_E_INVALID_CONTEXT,
            0xC004E002 => ITF::SL_E_TOKEN_STORE_INVALID_STATE,
            0xC004E003 => ITF::SL_E_EVALUATION_FAILED,
            0xC004E004 => ITF::SL_E_NOT_EVALUATED,
            0xC004E005 => ITF::SL_E_NOT_ACTIVATED,
            0xC004E006 => ITF::SL_E_INVALID_GUID,
            0xC004E007 => ITF::SL_E_TOKSTO_TOKEN_NOT_FOUND,
            0xC004E008 => ITF::SL_E_TOKSTO_NO_PROPERTIES,
            0xC004E009 => ITF::SL_E_TOKSTO_NOT_INITIALIZED,
            0xC004E00A => ITF::SL_E_TOKSTO_ALREADY_INITIALIZED,
            0xC004E00B => ITF::SL_E_TOKSTO_NO_ID_SET,
            0xC004E00C => ITF::SL_E_TOKSTO_CANT_CREATE_FILE,
            0xC004E00D => ITF::SL_E_TOKSTO_CANT_WRITE_TO_FILE,
            0xC004E00E => ITF::SL_E_TOKSTO_CANT_READ_FILE,
            0xC004E00F => ITF::SL_E_TOKSTO_CANT_PARSE_PROPERTIES,
            0xC004E010 => ITF::SL_E_TOKSTO_PROPERTY_NOT_FOUND,
            0xC004E011 => ITF::SL_E_TOKSTO_INVALID_FILE,
            0xC004E012 => ITF::SL_E_TOKSTO_CANT_CREATE_MUTEX,
            0xC004E013 => ITF::SL_E_TOKSTO_CANT_ACQUIRE_MUTEX,
            0xC004E014 => ITF::SL_E_TOKSTO_NO_TOKEN_DATA,
            0xC004E015 => ITF::SL_E_EUL_CONSUMPTION_FAILED,
            0xC004E016 => ITF::SL_E_PKEY_INVALID_CONFIG,
            0xC004E017 => ITF::SL_E_PKEY_INVALID_UNIQUEID,
            0xC004E018 => ITF::SL_E_PKEY_INVALID_ALGORITHM,
            0xC004E019 => ITF::SL_E_PKEY_INTERNAL_ERROR,
            0xC004E01A => ITF::SL_E_LICENSE_INVALID_ADDON_INFO,
            0xC004E01B => ITF::SL_E_HWID_ERROR,
            0xC004E01C => ITF::SL_E_PKEY_INVALID_KEYCHANGE1,
            0xC004E01D => ITF::SL_E_PKEY_INVALID_KEYCHANGE2,
            0xC004E01E => ITF::SL_E_PKEY_INVALID_KEYCHANGE3,
            0xC004E020 => ITF::SL_E_POLICY_OTHERINFO_MISMATCH,
            0xC004E021 => ITF::SL_E_PRODUCT_UNIQUENESS_GROUP_ID_INVALID,
            0xC004E022 => ITF::SL_E_SECURE_STORE_ID_MISMATCH,
            0xC004E023 => ITF::SL_E_INVALID_RULESET_RULE,
            0xC004E024 => ITF::SL_E_INVALID_CONTEXT_DATA,
            0xC004E025 => ITF::SL_E_INVALID_HASH,
            0xC004E027 => ITF::SL_E_WINDOWS_VERSION_MISMATCH,
            0xC004E028 => ITF::SL_E_ACTIVATION_IN_PROGRESS,
            0xC004E029 => ITF::SL_E_STORE_UPGRADE_TOKEN_REQUIRED,
            0xC004E02A => ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_EDITION,
            0xC004E02B => ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_PID,
            0xC004E02C => ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_PRS_SIGNED,
            0xC004E02D => ITF::SL_E_STORE_UPGRADE_TOKEN_WRONG_VERSION,
            0xC004E02E => ITF::SL_E_STORE_UPGRADE_TOKEN_NOT_AUTHORIZED,
            0xC004F001 => ITF::SL_E_INTERNAL_ERROR,
            0xC004F002 => ITF::SL_E_RIGHT_NOT_CONSUMED,
            0xC004F003 => ITF::SL_E_USE_LICENSE_NOT_INSTALLED,
            0xC004F004 => ITF::SL_E_MISMATCHED_PKEY_RANGE,
            0xC004F005 => ITF::SL_E_MISMATCHED_PID,
            0xC004F006 => ITF::SL_E_EXTERNAL_SIGNATURE_NOT_FOUND,
            0xC004F007 => ITF::SL_E_RAC_NOT_AVAILABLE,
            0xC004F008 => ITF::SL_E_SPC_NOT_AVAILABLE,
            0xC004F009 => ITF::SL_E_GRACE_TIME_EXPIRED,
            0xC004F00A => ITF::SL_E_MISMATCHED_APPID,
            0xC004F00B => ITF::SL_E_NO_PID_CONFIG_DATA,
            0xC004F00E => ITF::SL_E_MISMATCHED_SECURITY_PROCESSOR,
            0xC004F00F => ITF::SL_E_OUT_OF_TOLERANCE,
            0xC004F010 => ITF::SL_E_INVALID_PKEY,
            0xC004F011 => ITF::SL_E_LICENSE_FILE_NOT_INSTALLED,
            0xC004F012 => ITF::SL_E_VALUE_NOT_FOUND,
            0xC004F013 => ITF::SL_E_RIGHT_NOT_GRANTED,
            0xC004F014 => ITF::SL_E_PKEY_NOT_INSTALLED,
            0xC004F015 => ITF::SL_E_PRODUCT_SKU_NOT_INSTALLED,
            0xC004F016 => ITF::SL_E_NOT_SUPPORTED,
            0xC004F017 => ITF::SL_E_PUBLISHING_LICENSE_NOT_INSTALLED,
            0xC004F018 => ITF::SL_E_LICENSE_SERVER_URL_NOT_FOUND,
            0xC004F019 => ITF::SL_E_INVALID_EVENT_ID,
            0xC004F01A => ITF::SL_E_EVENT_NOT_REGISTERED,
            0xC004F01B => ITF::SL_E_EVENT_ALREADY_REGISTERED,
            0xC004F01C => ITF::SL_E_DECRYPTION_LICENSES_NOT_AVAILABLE,
            0xC004F01D => ITF::SL_E_LICENSE_SIGNATURE_VERIFICATION_FAILED,
            0xC004F01E => ITF::SL_E_DATATYPE_MISMATCHED,
            0xC004F01F => ITF::SL_E_INVALID_LICENSE,
            0xC004F020 => ITF::SL_E_INVALID_PACKAGE,
            0xC004F021 => ITF::SL_E_VALIDITY_TIME_EXPIRED,
            0xC004F022 => ITF::SL_E_LICENSE_AUTHORIZATION_FAILED,
            0xC004F023 => ITF::SL_E_LICENSE_DECRYPTION_FAILED,
            0xC004F024 => ITF::SL_E_WINDOWS_INVALID_LICENSE_STATE,
            0xC004F025 => ITF::SL_E_LUA_ACCESSDENIED,
            0xC004F026 => ITF::SL_E_PROXY_KEY_NOT_FOUND,
            0xC004F027 => ITF::SL_E_TAMPER_DETECTED,
            0xC004F028 => ITF::SL_E_POLICY_CACHE_INVALID,
            0xC004F029 => ITF::SL_E_INVALID_RUNNING_MODE,
            0xC004F02A => ITF::SL_E_SLP_NOT_SIGNED,
            0xC004F02C => ITF::SL_E_CIDIID_INVALID_DATA,
            0xC004F02D => ITF::SL_E_CIDIID_INVALID_VERSION,
            0xC004F02E => ITF::SL_E_CIDIID_VERSION_NOT_SUPPORTED,
            0xC004F02F => ITF::SL_E_CIDIID_INVALID_DATA_LENGTH,
            0xC004F030 => ITF::SL_E_CIDIID_NOT_DEPOSITED,
            0xC004F031 => ITF::SL_E_CIDIID_MISMATCHED,
            0xC004F032 => ITF::SL_E_INVALID_BINDING_BLOB,
            0xC004F033 => ITF::SL_E_PRODUCT_KEY_INSTALLATION_NOT_ALLOWED,
            0xC004F034 => ITF::SL_E_EUL_NOT_AVAILABLE,
            0xC004F035 => ITF::SL_E_VL_NOT_WINDOWS_SLP,
            0xC004F038 => ITF::SL_E_VL_NOT_ENOUGH_COUNT,
            0xC004F039 => ITF::SL_E_VL_BINDING_SERVICE_NOT_ENABLED,
            0xC004F041 => ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_NOT_ACTIVATED,
            0xC004F042 => ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_ID_MISMATCH,
            0xC004F047 => ITF::SL_E_PROXY_POLICY_NOT_UPDATED,
            0xC004F04D => ITF::SL_E_CIDIID_INVALID_CHECK_DIGITS,
            0xC004F04F => ITF::SL_E_LICENSE_MANAGEMENT_DATA_NOT_FOUND,
            0xC004F050 => ITF::SL_E_INVALID_PRODUCT_KEY,
            0xC004F051 => ITF::SL_E_BLOCKED_PRODUCT_KEY,
            0xC004F052 => ITF::SL_E_DUPLICATE_POLICY,
            0xC004F053 => ITF::SL_E_MISSING_OVERRIDE_ONLY_ATTRIBUTE,
            0xC004F054 => ITF::SL_E_LICENSE_MANAGEMENT_DATA_DUPLICATED,
            0xC004F055 => ITF::SL_E_BASE_SKU_NOT_AVAILABLE,
            0xC004F056 => ITF::SL_E_VL_MACHINE_NOT_BOUND,
            0xC004F057 => ITF::SL_E_SLP_MISSING_ACPI_SLIC,
            0xC004F058 => ITF::SL_E_SLP_MISSING_SLP_MARKER,
            0xC004F059 => ITF::SL_E_SLP_BAD_FORMAT,
            0xC004F060 => ITF::SL_E_INVALID_PACKAGE_VERSION,
            0xC004F061 => ITF::SL_E_PKEY_INVALID_UPGRADE,
            0xC004F062 => ITF::SL_E_ISSUANCE_LICENSE_NOT_INSTALLED,
            0xC004F063 => ITF::SL_E_SLP_OEM_CERT_MISSING,
            0xC004F064 => ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED,
            0xC004F066 => ITF::SL_E_DEPENDENT_PROPERTY_NOT_SET,
            0xC004F067 => ITF::SL_E_NONGENUINE_GRACE_TIME_EXPIRED_2,
            0xC004F069 => ITF::SL_E_MISMATCHED_PRODUCT_SKU,
            0xC004F06A => ITF::SL_E_OPERATION_NOT_ALLOWED,
            0xC004F06B => ITF::SL_E_VL_KEY_MANAGEMENT_SERVICE_VM_NOT_SUPPORTED,
            0xC004F06C => ITF::SL_E_VL_INVALID_TIMESTAMP,
            0xC004F071 => ITF::SL_E_PLUGIN_INVALID_MANIFEST,
            0xC004F072 => ITF::SL_E_APPLICATION_POLICIES_MISSING,
            0xC004F073 => ITF::SL_E_APPLICATION_POLICIES_NOT_LOADED,
            0xC004F074 => ITF::SL_E_VL_BINDING_SERVICE_UNAVAILABLE,
            0xC004F075 => ITF::SL_E_SERVICE_STOPPING,
            0xC004F076 => ITF::SL_E_PLUGIN_NOT_REGISTERED,
            0xC004F077 => ITF::SL_E_AUTHN_WRONG_VERSION,
            0xC004F078 => ITF::SL_E_AUTHN_MISMATCHED_KEY,
            0xC004F079 => ITF::SL_E_AUTHN_CHALLENGE_NOT_SET,
            0xC004F07A => ITF::SL_E_AUTHN_CANT_VERIFY,
            0xC004F07B => ITF::SL_E_SERVICE_RUNNING,
            0xC004F07C => ITF::SL_E_SLP_INVALID_MARKER_VERSION,
            0xC004F07D => ITF::SL_E_INVALID_PRODUCT_KEY_TYPE,
            0xC004F07E => ITF::SL_E_CIDIID_MISMATCHED_PKEY,
            0xC004F07F => ITF::SL_E_CIDIID_NOT_BOUND,
            0xC004F080 => ITF::SL_E_LICENSE_NOT_BOUND,
            0xC004F081 => ITF::SL_E_VL_AD_AO_NOT_FOUND,
            0xC004F082 => ITF::SL_E_VL_AD_AO_NAME_TOO_LONG,
            0xC004F083 => ITF::SL_E_VL_AD_SCHEMA_VERSION_NOT_SUPPORTED,
            0xC004F200 => ITF::SL_E_NOT_GENUINE,
            0xC004F210 => ITF::SL_E_EDITION_MISMATCHED,
            0xC004F301 => ITF::SL_E_TKA_CHALLENGE_EXPIRED,
            0xC004F302 => ITF::SL_E_TKA_SILENT_ACTIVATION_FAILURE,
            0xC004F303 => ITF::SL_E_TKA_INVALID_CERT_CHAIN,
            0xC004F304 => ITF::SL_E_TKA_GRANT_NOT_FOUND,
            0xC004F305 => ITF::SL_E_TKA_CERT_NOT_FOUND,
            0xC004F306 => ITF::SL_E_TKA_INVALID_SKU_ID,
            0xC004F307 => ITF::SL_E_TKA_INVALID_BLOB,
            0xC004F308 => ITF::SL_E_TKA_TAMPERED_CERT_CHAIN,
            0xC004F309 => ITF::SL_E_TKA_CHALLENGE_MISMATCH,
            0xC004F30A => ITF::SL_E_TKA_INVALID_CERTIFICATE,
            0xC004F30B => ITF::SL_E_TKA_INVALID_SMARTCARD,
            0xC004F30C => ITF::SL_E_TKA_FAILED_GRANT_PARSING,
            0xC004F30D => ITF::SL_E_TKA_INVALID_THUMBPRINT,
            0xC004F30E => ITF::SL_E_TKA_THUMBPRINT_CERT_NOT_FOUND,
            0xC004F30F => ITF::SL_E_TKA_CRITERIA_MISMATCH,
            0xC004F310 => ITF::SL_E_TKA_TPID_MISMATCH,
            0xC004F311 => ITF::SL_E_TKA_SOFT_CERT_DISALLOWED,
            0xC004F312 => ITF::SL_E_TKA_SOFT_CERT_INVALID,
            0xC004F313 => ITF::SL_E_TKA_CERT_CNG_NOT_AVAILABLE,
            0xC004FC03 => ITF::E_RM_UNKNOWN_ERROR,
            0xC004FC07 => ITF::SL_E_VALIDITY_PERIOD_EXPIRED,
            0xC004FD00 => ITF::SL_E_IA_THROTTLE_LIMIT_EXCEEDED,
            0xC004FD01 => ITF::SL_E_IA_INVALID_VIRTUALIZATION_PLATFORM,
            0xC004FD02 => ITF::SL_E_IA_PARENT_PARTITION_NOT_ACTIVATED,
            0xC004FD03 => ITF::SL_E_IA_ID_MISMATCH,
            0xC004FD04 => ITF::SL_E_IA_MACHINE_NOT_BOUND,
            0xC004FE00 => ITF::SL_E_TAMPER_RECOVERY_REQUIRES_ACTIVATION,
        }
    }
}
