/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum MEDIASERVER {
    NS_S_CALLPENDING,
    NS_S_CALLABORTED,
    NS_S_STREAM_TRUNCATED,
    NS_S_REBUFFERING,
    NS_S_DEGRADING_QUALITY,
    NS_S_TRANSCRYPTOR_EOF,
    NS_S_WMP_UI_VERSIONMISMATCH,
    NS_S_WMP_EXCEPTION,
    NS_S_WMP_LOADED_GIF_IMAGE,
    NS_S_WMP_LOADED_PNG_IMAGE,
    NS_S_WMP_LOADED_BMP_IMAGE,
    NS_S_WMP_LOADED_JPG_IMAGE,
    NS_S_WMG_FORCE_DROP_FRAME,
    NS_S_WMR_ALREADYRENDERED,
    NS_S_WMR_PINTYPEPARTIALMATCH,
    NS_S_WMR_PINTYPEFULLMATCH,
    NS_S_WMG_ADVISE_DROP_FRAME,
    NS_S_WMG_ADVISE_DROP_TO_KEYFRAME,
    NS_S_NEED_TO_BUY_BURN_RIGHTS,
    NS_S_WMPCORE_PLAYLISTCLEARABORT,
    NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT,
    NS_S_WMPCORE_PLAYLIST_CREATION_PENDING,
    NS_S_WMPCORE_MEDIA_VALIDATION_PENDING,
    NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED,
    NS_S_WMPCORE_COMMAND_NOT_AVAILABLE,
    NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED,
    NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS,
    NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA,
    NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING,
    NS_S_WMPCORE_MORE_NODES_AVAIABLE,
    NS_S_WMPBR_SUCCESS,
    NS_S_WMPBR_PARTIALSUCCESS,
    NS_S_WMPEFFECT_TRANSPARENT,
    NS_S_WMPEFFECT_OPAQUE,
    NS_S_OPERATION_PENDING,
    NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE,
    NS_S_NAVIGATION_COMPLETE_WITH_ERRORS,
    NS_S_TRACK_ALREADY_DOWNLOADED,
    NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS,
    NS_S_DRM_LICENSE_ACQUIRED,
    NS_S_DRM_INDIVIDUALIZED,
    NS_S_DRM_MONITOR_CANCELLED,
    NS_S_DRM_ACQUIRE_CANCELLED,
    NS_S_DRM_BURNABLE_TRACK,
    NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION,
    NS_S_DRM_NEEDS_INDIVIDUALIZATION,
    NS_S_REBOOT_RECOMMENDED,
    NS_S_REBOOT_REQUIRED,
    NS_S_EOSRECEDING,
    NS_S_CHANGENOTICE,
    MF_S_MULTIPLE_BEGIN,
    MF_S_ACTIVATE_REPLACED,
    MF_S_SINK_NOT_FINALIZED,
    MF_S_SEQUENCER_CONTEXT_CANCELED,
    MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM,
    MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT,
    MF_S_PROTECTION_NOT_REQUIRED,
    MF_S_WAIT_FOR_POLICY_SET,
    MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT,
    MF_S_PE_TRUSTED,
    MF_S_CLOCK_STOPPED,
    NS_I_TIGER_START,
    NS_I_CUB_START,
    NS_I_CUB_RUNNING,
    NS_I_DISK_START,
    NS_I_DISK_REBUILD_STARTED,
    NS_I_DISK_REBUILD_FINISHED,
    NS_I_DISK_REBUILD_ABORTED,
    NS_I_LIMIT_FUNNELS,
    NS_I_START_DISK,
    NS_I_STOP_DISK,
    NS_I_STOP_CUB,
    NS_I_KILL_USERSESSION,
    NS_I_KILL_CONNECTION,
    NS_I_REBUILD_DISK,
    MCMADM_I_NO_EVENTS,
    NS_I_LOGGING_FAILED,
    NS_I_LIMIT_BANDWIDTH,
    NS_I_CUB_UNFAIL_LINK,
    NS_I_RESTRIPE_START,
    NS_I_RESTRIPE_DONE,
    NS_I_RESTRIPE_DISK_OUT,
    NS_I_RESTRIPE_CUB_OUT,
    NS_I_DISK_STOP,
    NS_I_PLAYLIST_CHANGE_RECEDING,
    NS_I_RECONNECTED,
    NS_I_NOLOG_STOP,
    NS_I_EXISTING_PACKETIZER,
    NS_I_MANUAL_PROXY,
    MF_S_ASF_PARSEINPROGRESS,
    MF_I_MANUAL_PROXY,
    NS_W_SERVER_BANDWIDTH_LIMIT,
    NS_W_FILE_BANDWIDTH_LIMIT,
    NS_W_UNKNOWN_EVENT,
    NS_I_CATATONIC_FAILURE,
    NS_I_CATATONIC_AUTO_UNFAIL,
    NS_E_NOCONNECTION,
    NS_E_CANNOTCONNECT,
    NS_E_CANNOTDESTROYTITLE,
    NS_E_CANNOTRENAMETITLE,
    NS_E_CANNOTOFFLINEDISK,
    NS_E_CANNOTONLINEDISK,
    NS_E_NOREGISTEREDWALKER,
    NS_E_NOFUNNEL,
    NS_E_NO_LOCALPLAY,
    NS_E_NETWORK_BUSY,
    NS_E_TOO_MANY_SESS,
    NS_E_ALREADY_CONNECTED,
    NS_E_INVALID_INDEX,
    NS_E_PROTOCOL_MISMATCH,
    NS_E_TIMEOUT,
    NS_E_NET_WRITE,
    NS_E_NET_READ,
    NS_E_DISK_WRITE,
    NS_E_DISK_READ,
    NS_E_FILE_WRITE,
    NS_E_FILE_READ,
    NS_E_FILE_NOT_FOUND,
    NS_E_FILE_EXISTS,
    NS_E_INVALID_NAME,
    NS_E_FILE_OPEN_FAILED,
    NS_E_FILE_ALLOCATION_FAILED,
    NS_E_FILE_INIT_FAILED,
    NS_E_FILE_PLAY_FAILED,
    NS_E_SET_DISK_UID_FAILED,
    NS_E_INDUCED,
    NS_E_CCLINK_DOWN,
    NS_E_INTERNAL,
    NS_E_BUSY,
    NS_E_UNRECOGNIZED_STREAM_TYPE,
    NS_E_NETWORK_SERVICE_FAILURE,
    NS_E_NETWORK_RESOURCE_FAILURE,
    NS_E_CONNECTION_FAILURE,
    NS_E_SHUTDOWN,
    NS_E_INVALID_REQUEST,
    NS_E_INSUFFICIENT_BANDWIDTH,
    NS_E_NOT_REBUILDING,
    NS_E_LATE_OPERATION,
    NS_E_INVALID_DATA,
    NS_E_FILE_BANDWIDTH_LIMIT,
    NS_E_OPEN_FILE_LIMIT,
    NS_E_BAD_CONTROL_DATA,
    NS_E_NO_STREAM,
    NS_E_STREAM_END,
    NS_E_SERVER_NOT_FOUND,
    NS_E_DUPLICATE_NAME,
    NS_E_DUPLICATE_ADDRESS,
    NS_E_BAD_MULTICAST_ADDRESS,
    NS_E_BAD_ADAPTER_ADDRESS,
    NS_E_BAD_DELIVERY_MODE,
    NS_E_INVALID_CHANNEL,
    NS_E_INVALID_STREAM,
    NS_E_INVALID_ARCHIVE,
    NS_E_NOTITLES,
    NS_E_INVALID_CLIENT,
    NS_E_INVALID_BLACKHOLE_ADDRESS,
    NS_E_INCOMPATIBLE_FORMAT,
    NS_E_INVALID_KEY,
    NS_E_INVALID_PORT,
    NS_E_INVALID_TTL,
    NS_E_STRIDE_REFUSED,
    NS_E_MMSAUTOSERVER_CANTFINDWALKER,
    NS_E_MAX_BITRATE,
    NS_E_LOGFILEPERIOD,
    NS_E_MAX_CLIENTS,
    NS_E_LOG_FILE_SIZE,
    NS_E_MAX_FILERATE,
    NS_E_WALKER_UNKNOWN,
    NS_E_WALKER_SERVER,
    NS_E_WALKER_USAGE,
    NS_E_TIGER_FAIL,
    NS_E_CUB_FAIL,
    NS_E_DISK_FAIL,
    NS_E_MAX_FUNNELS_ALERT,
    NS_E_ALLOCATE_FILE_FAIL,
    NS_E_PAGING_ERROR,
    NS_E_BAD_BLOCK0_VERSION,
    NS_E_BAD_DISK_UID,
    NS_E_BAD_FSMAJOR_VERSION,
    NS_E_BAD_STAMPNUMBER,
    NS_E_PARTIALLY_REBUILT_DISK,
    NS_E_ENACTPLAN_GIVEUP,
    MCMADM_E_REGKEY_NOT_FOUND,
    NS_E_NO_FORMATS,
    NS_E_NO_REFERENCES,
    NS_E_WAVE_OPEN,
    NS_E_CANNOTCONNECTEVENTS,
    NS_E_NO_DEVICE,
    NS_E_NO_SPECIFIED_DEVICE,
    NS_E_MONITOR_GIVEUP,
    NS_E_REMIRRORED_DISK,
    NS_E_INSUFFICIENT_DATA,
    NS_E_ASSERT,
    NS_E_BAD_ADAPTER_NAME,
    NS_E_NOT_LICENSED,
    NS_E_NO_SERVER_CONTACT,
    NS_E_TOO_MANY_TITLES,
    NS_E_TITLE_SIZE_EXCEEDED,
    NS_E_UDP_DISABLED,
    NS_E_TCP_DISABLED,
    NS_E_HTTP_DISABLED,
    NS_E_LICENSE_EXPIRED,
    NS_E_TITLE_BITRATE,
    NS_E_EMPTY_PROGRAM_NAME,
    NS_E_MISSING_CHANNEL,
    NS_E_NO_CHANNELS,
    NS_E_INVALID_INDEX2,
    NS_E_CUB_FAIL_LINK,
    NS_E_BAD_CUB_UID,
    NS_E_GLITCH_MODE,
    NS_E_NO_MEDIA_PROTOCOL,
    ASF_E_BUFFEROVERRUN,
    ASF_E_BUFFERTOOSMALL,
    ASF_E_BADLANGUAGEID,
    ASF_E_NOPAYLOADLENGTH,
    ASF_E_TOOMANYPAYLOADS,
    ASF_E_PACKETCONTENTTOOLARGE,
    ASF_E_UNKNOWNPACKETSIZE,
    ASF_E_INVALIDHEADER,
    ASF_E_NOCLOCKOBJECT,
    ASF_E_UNKNOWNCLOCKTYPE,
    ASF_E_OPAQUEPACKET,
    ASF_E_WRONGVERSION,
    ASF_E_OVERFLOW,
    ASF_E_NOTFOUND,
    NS_E_NOTHING_TO_DO,
    NS_E_NO_MULTICAST,
    ASF_E_OBJECTTOOBIG,
    ASF_E_UNEXPECTEDVALUE,
    ASF_E_INVALIDSTATE,
    ASF_E_NOLIBRARY,
    ASF_E_ALREADYINITIALIZED,
    ASF_E_INVALIDINIT,
    ASF_E_NOHEADEROBJECT,
    ASF_E_NODATAOBJECT,
    ASF_E_NOINDEXOBJECT,
    ASF_E_NOSTREAMPROPS,
    ASF_E_NOFILEPROPS,
    ASF_E_INVALIDFLAGS,
    ASF_E_BADDATADESCRIPTOR,
    ASF_E_BADINDEXINTERVAL,
    ASF_E_INVALIDTIME,
    ASF_E_INVALIDINDEX,
    ASF_E_STREAMNUMBERINUSE,
    ASF_E_BADMEDIATYPE,
    ASF_E_WRITEFAILED,
    ASF_E_NOTENOUGHDESCRIPTORS,
    ASF_E_INDEXBLOCKUNLOADED,
    ASF_E_NOTENOUGHBANDWIDTH,
    ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE,
    ASF_E_BADDATAUNIT,
    ASF_E_HEADERSIZE,
    NS_E_INVALID_INPUT_FORMAT,
    NS_E_MSAUDIO_NOT_INSTALLED,
    NS_E_UNEXPECTED_MSAUDIO_ERROR,
    NS_E_INVALID_OUTPUT_FORMAT,
    NS_E_NOT_CONFIGURED,
    NS_E_PROTECTED_CONTENT,
    NS_E_LICENSE_REQUIRED,
    NS_E_TAMPERED_CONTENT,
    NS_E_LICENSE_OUTOFDATE,
    NS_E_LICENSE_INCORRECT_RIGHTS,
    NS_E_AUDIO_CODEC_NOT_INSTALLED,
    NS_E_AUDIO_CODEC_ERROR,
    NS_E_VIDEO_CODEC_NOT_INSTALLED,
    NS_E_VIDEO_CODEC_ERROR,
    NS_E_INVALIDPROFILE,
    NS_E_INCOMPATIBLE_VERSION,
    NS_E_OFFLINE_MODE,
    NS_E_NOT_CONNECTED,
    NS_E_TOO_MUCH_DATA,
    NS_E_UNSUPPORTED_PROPERTY,
    NS_E_8BIT_WAVE_UNSUPPORTED,
    NS_E_NO_MORE_SAMPLES,
    NS_E_INVALID_SAMPLING_RATE,
    NS_E_MAX_PACKET_SIZE_TOO_SMALL,
    NS_E_LATE_PACKET,
    NS_E_DUPLICATE_PACKET,
    NS_E_SDK_BUFFERTOOSMALL,
    NS_E_INVALID_NUM_PASSES,
    NS_E_ATTRIBUTE_READ_ONLY,
    NS_E_ATTRIBUTE_NOT_ALLOWED,
    NS_E_INVALID_EDL,
    NS_E_DATA_UNIT_EXTENSION_TOO_LARGE,
    NS_E_CODEC_DMO_ERROR,
    NS_E_FEATURE_DISABLED_BY_GROUP_POLICY,
    NS_E_FEATURE_DISABLED_IN_SKU,
    NS_E_NO_CD,
    NS_E_CANT_READ_DIGITAL,
    NS_E_DEVICE_DISCONNECTED,
    NS_E_DEVICE_NOT_SUPPORT_FORMAT,
    NS_E_SLOW_READ_DIGITAL,
    NS_E_MIXER_INVALID_LINE,
    NS_E_MIXER_INVALID_CONTROL,
    NS_E_MIXER_INVALID_VALUE,
    NS_E_MIXER_UNKNOWN_MMRESULT,
    NS_E_USER_STOP,
    NS_E_MP3_FORMAT_NOT_FOUND,
    NS_E_CD_READ_ERROR_NO_CORRECTION,
    NS_E_CD_READ_ERROR,
    NS_E_CD_SLOW_COPY,
    NS_E_CD_COPYTO_CD,
    NS_E_MIXER_NODRIVER,
    NS_E_REDBOOK_ENABLED_WHILE_COPYING,
    NS_E_CD_REFRESH,
    NS_E_CD_DRIVER_PROBLEM,
    NS_E_WONT_DO_DIGITAL,
    NS_E_WMPXML_NOERROR,
    NS_E_WMPXML_ENDOFDATA,
    NS_E_WMPXML_PARSEERROR,
    NS_E_WMPXML_ATTRIBUTENOTFOUND,
    NS_E_WMPXML_PINOTFOUND,
    NS_E_WMPXML_EMPTYDOC,
    NS_E_WMP_PATH_ALREADY_IN_LIBRARY,
    NS_E_WMP_FILESCANALREADYSTARTED,
    NS_E_WMP_HME_INVALIDOBJECTID,
    NS_E_WMP_MF_CODE_EXPIRED,
    NS_E_WMP_HME_NOTSEARCHABLEFORITEMS,
    NS_E_WMP_ADDTOLIBRARY_FAILED,
    NS_E_WMP_WINDOWSAPIFAILURE,
    NS_E_WMP_RECORDING_NOT_ALLOWED,
    NS_E_DEVICE_NOT_READY,
    NS_E_DAMAGED_FILE,
    NS_E_MPDB_GENERIC,
    NS_E_FILE_FAILED_CHECKS,
    NS_E_MEDIA_LIBRARY_FAILED,
    NS_E_SHARING_VIOLATION,
    NS_E_NO_ERROR_STRING_FOUND,
    NS_E_WMPOCX_NO_REMOTE_CORE,
    NS_E_WMPOCX_NO_ACTIVE_CORE,
    NS_E_WMPOCX_NOT_RUNNING_REMOTELY,
    NS_E_WMPOCX_NO_REMOTE_WINDOW,
    NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE,
    NS_E_PLUGIN_NOTSHUTDOWN,
    NS_E_WMP_CANNOT_FIND_FOLDER,
    NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED,
    NS_E_WMP_PLUGINDLL_NOTFOUND,
    NS_E_NEED_TO_ASK_USER,
    NS_E_WMPOCX_PLAYER_NOT_DOCKED,
    NS_E_WMP_EXTERNAL_NOTREADY,
    NS_E_WMP_MLS_STALE_DATA,
    NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED,
    NS_E_WMP_UI_VERSIONMISMATCH,
    NS_E_WMP_UI_NOTATHEMEFILE,
    NS_E_WMP_UI_SUBELEMENTNOTFOUND,
    NS_E_WMP_UI_VERSIONPARSE,
    NS_E_WMP_UI_VIEWIDNOTFOUND,
    NS_E_WMP_UI_PASSTHROUGH,
    NS_E_WMP_UI_OBJECTNOTFOUND,
    NS_E_WMP_UI_SECONDHANDLER,
    NS_E_WMP_UI_NOSKININZIP,
    NS_E_WMP_URLDOWNLOADFAILED,
    NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN,
    NS_E_WMP_INVALID_SKIN,
    NS_E_WMP_SENDMAILFAILED,
    NS_E_WMP_LOCKEDINSKINMODE,
    NS_E_WMP_FAILED_TO_SAVE_FILE,
    NS_E_WMP_SAVEAS_READONLY,
    NS_E_WMP_FAILED_TO_SAVE_PLAYLIST,
    NS_E_WMP_FAILED_TO_OPEN_WMD,
    NS_E_WMP_CANT_PLAY_PROTECTED,
    NS_E_SHARING_STATE_OUT_OF_SYNC,
    NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING,
    NS_E_WMP_RBC_JPGMAPPINGIMAGE,
    NS_E_WMP_JPGTRANSPARENCY,
    NS_E_WMP_INVALID_MAX_VAL,
    NS_E_WMP_INVALID_MIN_VAL,
    NS_E_WMP_CS_JPGPOSITIONIMAGE,
    NS_E_WMP_CS_NOTEVENLYDIVISIBLE,
    NS_E_WMPZIP_NOTAZIPFILE,
    NS_E_WMPZIP_CORRUPT,
    NS_E_WMPZIP_FILENOTFOUND,
    NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED,
    NS_E_WMP_IMAGE_INVALID_FORMAT,
    NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE,
    NS_E_WMP_GIF_INVALID_FORMAT,
    NS_E_WMP_GIF_BAD_VERSION_NUMBER,
    NS_E_WMP_GIF_NO_IMAGE_IN_FILE,
    NS_E_WMP_PNG_INVALIDFORMAT,
    NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH,
    NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION,
    NS_E_WMP_PNG_UNSUPPORTED_FILTER,
    NS_E_WMP_PNG_UNSUPPORTED_INTERLACE,
    NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC,
    NS_E_WMP_BMP_INVALID_BITMASK,
    NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED,
    NS_E_WMP_BMP_BITMAP_NOT_CREATED,
    NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED,
    NS_E_WMP_BMP_INVALID_FORMAT,
    NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL,
    NS_E_WMP_JPG_INVALID_FORMAT,
    NS_E_WMP_JPG_BAD_DCTSIZE,
    NS_E_WMP_JPG_BAD_VERSION_NUMBER,
    NS_E_WMP_JPG_BAD_PRECISION,
    NS_E_WMP_JPG_CCIR601_NOTIMPL,
    NS_E_WMP_JPG_NO_IMAGE_IN_FILE,
    NS_E_WMP_JPG_READ_ERROR,
    NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL,
    NS_E_WMP_JPG_IMAGE_TOO_BIG,
    NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE,
    NS_E_WMP_JPG_SOF_UNSUPPORTED,
    NS_E_WMP_JPG_UNKNOWN_MARKER,
    NS_E_WMP_FAILED_TO_OPEN_IMAGE,
    NS_E_WMP_DAI_SONGTOOSHORT,
    NS_E_WMG_RATEUNAVAILABLE,
    NS_E_WMG_PLUGINUNAVAILABLE,
    NS_E_WMG_CANNOTQUEUE,
    NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED,
    NS_E_WMG_UNEXPECTEDPREROLLSTATUS,
    NS_E_WMG_INVALID_COPP_CERTIFICATE,
    NS_E_WMG_COPP_SECURITY_INVALID,
    NS_E_WMG_COPP_UNSUPPORTED,
    NS_E_WMG_INVALIDSTATE,
    NS_E_WMG_SINKALREADYEXISTS,
    NS_E_WMG_NOSDKINTERFACE,
    NS_E_WMG_NOTALLOUTPUTSRENDERED,
    NS_E_WMG_FILETRANSFERNOTALLOWED,
    NS_E_WMR_UNSUPPORTEDSTREAM,
    NS_E_WMR_PINNOTFOUND,
    NS_E_WMR_WAITINGONFORMATSWITCH,
    NS_E_WMR_NOSOURCEFILTER,
    NS_E_WMR_PINTYPENOMATCH,
    NS_E_WMR_NOCALLBACKAVAILABLE,
    NS_E_WMR_SAMPLEPROPERTYNOTSET,
    NS_E_WMR_CANNOT_RENDER_BINARY_STREAM,
    NS_E_WMG_LICENSE_TAMPERED,
    NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM,
    NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT,
    NS_E_ASX_INVALIDFORMAT,
    NS_E_ASX_INVALIDVERSION,
    NS_E_ASX_INVALID_REPEAT_BLOCK,
    NS_E_ASX_NOTHING_TO_WRITE,
    NS_E_URLLIST_INVALIDFORMAT,
    NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST,
    NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS,
    NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE,
    NS_E_WMX_ITEM_DOES_NOT_EXIST,
    NS_E_WMX_ITEM_TYPE_ILLEGAL,
    NS_E_WMX_ITEM_UNSETTABLE,
    NS_E_WMX_PLAYLIST_EMPTY,
    NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED,
    NS_E_WMX_INVALID_FORMAT_OVER_NESTING,
    NS_E_WMPCORE_NOSOURCEURLSTRING,
    NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT,
    NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE,
    NS_E_WMPCORE_BUFFERTOOSMALL,
    NS_E_WMPCORE_UNAVAILABLE,
    NS_E_WMPCORE_INVALIDPLAYLISTMODE,
    NS_E_WMPCORE_ITEMNOTINPLAYLIST,
    NS_E_WMPCORE_PLAYLISTEMPTY,
    NS_E_WMPCORE_NOBROWSER,
    NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL,
    NS_E_WMPCORE_GRAPH_NOT_IN_LIST,
    NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA,
    NS_E_WMPCORE_ERRORSINKNOTREGISTERED,
    NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE,
    NS_E_WMPCORE_WEBHELPFAILED,
    NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED,
    NS_E_WMPCORE_NO_REF_IN_ENTRY,
    NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY,
    NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL,
    NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY,
    NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL,
    NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY,
    NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL,
    NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY,
    NS_E_WMPCORE_LIST_ENTRY_NO_REF,
    NS_E_WMPCORE_MISNAMED_FILE,
    NS_E_WMPCORE_CODEC_NOT_TRUSTED,
    NS_E_WMPCORE_CODEC_NOT_FOUND,
    NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED,
    NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST,
    NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST,
    NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE,
    NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED,
    NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND,
    NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED,
    NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED,
    NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY,
    NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME,
    NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT,
    NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY,
    NS_E_WMPCORE_PLAYLIST_STACK_EMPTY,
    NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE,
    NS_E_WMPCORE_USER_CANCEL,
    NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY,
    NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE,
    NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE,
    NS_E_WMPCORE_INVALID_PLAYLIST_URL,
    NS_E_WMPCORE_MISMATCHED_RUNTIME,
    NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS,
    NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION,
    NS_E_WMPCORE_MEDIA_UNAVAILABLE,
    NS_E_WMPCORE_WMX_ENTRYREF_NO_REF,
    NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST,
    NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS,
    NS_E_WMPCORE_BUSY,
    NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE,
    NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST,
    NS_E_WMPCORE_FILE_NOT_FOUND,
    NS_E_WMPCORE_TEMP_FILE_NOT_FOUND,
    NS_E_WMDM_REVOKED,
    NS_E_DDRAW_GENERIC,
    NS_E_DISPLAY_MODE_CHANGE_FAILED,
    NS_E_PLAYLIST_CONTAINS_ERRORS,
    NS_E_CHANGING_PROXY_NAME,
    NS_E_CHANGING_PROXY_PORT,
    NS_E_CHANGING_PROXY_EXCEPTIONLIST,
    NS_E_CHANGING_PROXYBYPASS,
    NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND,
    NS_E_GRAPH_NOAUDIOLANGUAGE,
    NS_E_GRAPH_NOAUDIOLANGUAGESELECTED,
    NS_E_CORECD_NOTAMEDIACD,
    NS_E_WMPCORE_MEDIA_URL_TOO_LONG,
    NS_E_WMPFLASH_CANT_FIND_COM_SERVER,
    NS_E_WMPFLASH_INCOMPATIBLEVERSION,
    NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS,
    NS_E_NEED_CORE_REFERENCE,
    NS_E_MEDIACD_READ_ERROR,
    NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS,
    NS_E_FLASH_PLAYBACK_NOT_ALLOWED,
    NS_E_UNABLE_TO_CREATE_RIP_LOCATION,
    NS_E_WMPCORE_SOME_CODECS_MISSING,
    NS_E_WMP_RIP_FAILED,
    NS_E_WMP_FAILED_TO_RIP_TRACK,
    NS_E_WMP_ERASE_FAILED,
    NS_E_WMP_FORMAT_FAILED,
    NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE,
    NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD,
    NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD,
    NS_E_WMP_FILE_NO_DURATION,
    NS_E_PDA_FAILED_TO_BURN,
    NS_E_FAILED_DOWNLOAD_ABORT_BURN,
    NS_E_WMPCORE_DEVICE_DRIVERS_MISSING,
    NS_E_WMPIM_USEROFFLINE,
    NS_E_WMPIM_USERCANCELED,
    NS_E_WMPIM_DIALUPFAILED,
    NS_E_WINSOCK_ERROR_STRING,
    NS_E_WMPBR_NOLISTENER,
    NS_E_WMPBR_BACKUPCANCEL,
    NS_E_WMPBR_RESTORECANCEL,
    NS_E_WMPBR_ERRORWITHURL,
    NS_E_WMPBR_NAMECOLLISION,
    NS_E_WMPBR_DRIVE_INVALID,
    NS_E_WMPBR_BACKUPRESTOREFAILED,
    NS_E_WMP_CONVERT_FILE_FAILED,
    NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL,
    NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL,
    NS_E_WMP_CONVERT_FILE_CORRUPT,
    NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL,
    NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL,
    NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER,
    NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS,
    NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED,
    NS_E_DVD_NO_SUBPICTURE_STREAM,
    NS_E_DVD_COPY_PROTECT,
    NS_E_DVD_AUTHORING_PROBLEM,
    NS_E_DVD_INVALID_DISC_REGION,
    NS_E_DVD_COMPATIBLE_VIDEO_CARD,
    NS_E_DVD_MACROVISION,
    NS_E_DVD_SYSTEM_DECODER_REGION,
    NS_E_DVD_DISC_DECODER_REGION,
    NS_E_DVD_NO_VIDEO_STREAM,
    NS_E_DVD_NO_AUDIO_STREAM,
    NS_E_DVD_GRAPH_BUILDING,
    NS_E_DVD_NO_DECODER,
    NS_E_DVD_PARENTAL,
    NS_E_DVD_CANNOT_JUMP,
    NS_E_DVD_DEVICE_CONTENTION,
    NS_E_DVD_NO_VIDEO_MEMORY,
    NS_E_DVD_CANNOT_COPY_PROTECTED,
    NS_E_DVD_REQUIRED_PROPERTY_NOT_SET,
    NS_E_DVD_INVALID_TITLE_CHAPTER,
    NS_E_NO_CD_BURNER,
    NS_E_DEVICE_IS_NOT_READY,
    NS_E_PDA_UNSUPPORTED_FORMAT,
    NS_E_NO_PDA,
    NS_E_PDA_UNSPECIFIED_ERROR,
    NS_E_MEMSTORAGE_BAD_DATA,
    NS_E_PDA_FAIL_SELECT_DEVICE,
    NS_E_PDA_FAIL_READ_WAVE_FILE,
    NS_E_IMAPI_LOSSOFSTREAMING,
    NS_E_PDA_DEVICE_FULL,
    NS_E_FAIL_LAUNCH_ROXIO_PLUGIN,
    NS_E_PDA_DEVICE_FULL_IN_SESSION,
    NS_E_IMAPI_MEDIUM_INVALIDTYPE,
    NS_E_PDA_MANUALDEVICE,
    NS_E_PDA_PARTNERSHIPNOTEXIST,
    NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP,
    NS_E_PDA_NO_TRANSCODE_OF_DRM,
    NS_E_PDA_TRANSCODECACHEFULL,
    NS_E_PDA_TOO_MANY_FILE_COLLISIONS,
    NS_E_PDA_CANNOT_TRANSCODE,
    NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY,
    NS_E_PROCESSINGSHOWSYNCWIZARD,
    NS_E_PDA_TRANSCODE_NOT_PERMITTED,
    NS_E_PDA_INITIALIZINGDEVICES,
    NS_E_PDA_OBSOLETE_SP,
    NS_E_PDA_TITLE_COLLISION,
    NS_E_PDA_DEVICESUPPORTDISABLED,
    NS_E_PDA_NO_LONGER_AVAILABLE,
    NS_E_PDA_ENCODER_NOT_RESPONDING,
    NS_E_PDA_CANNOT_SYNC_FROM_LOCATION,
    NS_E_WMP_PROTOCOL_PROBLEM,
    NS_E_WMP_NO_DISK_SPACE,
    NS_E_WMP_LOGON_FAILURE,
    NS_E_WMP_CANNOT_FIND_FILE,
    NS_E_WMP_SERVER_INACCESSIBLE,
    NS_E_WMP_UNSUPPORTED_FORMAT,
    NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT,
    NS_E_WMP_PLAYLIST_EXISTS,
    NS_E_WMP_NONMEDIA_FILES,
    NS_E_WMP_INVALID_ASX,
    NS_E_WMP_ALREADY_IN_USE,
    NS_E_WMP_IMAPI_FAILURE,
    NS_E_WMP_WMDM_FAILURE,
    NS_E_WMP_CODEC_NEEDED_WITH_4CC,
    NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG,
    NS_E_WMP_MSSAP_NOT_AVAILABLE,
    NS_E_WMP_WMDM_INTERFACEDEAD,
    NS_E_WMP_WMDM_NOTCERTIFIED,
    NS_E_WMP_WMDM_LICENSE_NOTEXIST,
    NS_E_WMP_WMDM_LICENSE_EXPIRED,
    NS_E_WMP_WMDM_BUSY,
    NS_E_WMP_WMDM_NORIGHTS,
    NS_E_WMP_WMDM_INCORRECT_RIGHTS,
    NS_E_WMP_IMAPI_GENERIC,
    NS_E_WMP_IMAPI_DEVICE_NOTPRESENT,
    NS_E_WMP_IMAPI_DEVICE_BUSY,
    NS_E_WMP_IMAPI_LOSS_OF_STREAMING,
    NS_E_WMP_SERVER_UNAVAILABLE,
    NS_E_WMP_FILE_OPEN_FAILED,
    NS_E_WMP_VERIFY_ONLINE,
    NS_E_WMP_SERVER_NOT_RESPONDING,
    NS_E_WMP_DRM_CORRUPT_BACKUP,
    NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE,
    NS_E_WMP_NETWORK_FIREWALL,
    NS_E_WMP_NO_REMOVABLE_MEDIA,
    NS_E_WMP_PROXY_CONNECT_TIMEOUT,
    NS_E_WMP_NEED_UPGRADE,
    NS_E_WMP_AUDIO_HW_PROBLEM,
    NS_E_WMP_INVALID_PROTOCOL,
    NS_E_WMP_INVALID_LIBRARY_ADD,
    NS_E_WMP_MMS_NOT_SUPPORTED,
    NS_E_WMP_NO_PROTOCOLS_SELECTED,
    NS_E_WMP_GOFULLSCREEN_FAILED,
    NS_E_WMP_NETWORK_ERROR,
    NS_E_WMP_CONNECT_TIMEOUT,
    NS_E_WMP_MULTICAST_DISABLED,
    NS_E_WMP_SERVER_DNS_TIMEOUT,
    NS_E_WMP_PROXY_NOT_FOUND,
    NS_E_WMP_TAMPERED_CONTENT,
    NS_E_WMP_OUTOFMEMORY,
    NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED,
    NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED,
    NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE,
    NS_E_WMP_DRM_DRIVER_AUTH_FAILURE,
    NS_E_WMP_NETWORK_RESOURCE_FAILURE,
    NS_E_WMP_UPGRADE_APPLICATION,
    NS_E_WMP_UNKNOWN_ERROR,
    NS_E_WMP_INVALID_KEY,
    NS_E_WMP_CD_ANOTHER_USER,
    NS_E_WMP_DRM_NEEDS_AUTHORIZATION,
    NS_E_WMP_BAD_DRIVER,
    NS_E_WMP_ACCESS_DENIED,
    NS_E_WMP_LICENSE_RESTRICTS,
    NS_E_WMP_INVALID_REQUEST,
    NS_E_WMP_CD_STASH_NO_SPACE,
    NS_E_WMP_DRM_NEW_HARDWARE,
    NS_E_WMP_DRM_INVALID_SIG,
    NS_E_WMP_DRM_CANNOT_RESTORE,
    NS_E_WMP_BURN_DISC_OVERFLOW,
    NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE,
    NS_E_WMP_DRM_NO_SECURE_CLOCK,
    NS_E_WMP_DRM_NO_RIGHTS,
    NS_E_WMP_DRM_INDIV_FAILED,
    NS_E_WMP_SERVER_NONEWCONNECTIONS,
    NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST,
    NS_E_WMP_IMAPI2_ERASE_FAIL,
    NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY,
    NS_E_WMP_DRM_COMPONENT_FAILURE,
    NS_E_WMP_DRM_NO_DEVICE_CERT,
    NS_E_WMP_SERVER_SECURITY_ERROR,
    NS_E_WMP_AUDIO_DEVICE_LOST,
    NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE,
    NS_E_SYNCWIZ_DEVICE_FULL,
    NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS,
    NS_E_TRANSCODE_DELETECACHEERROR,
    NS_E_CD_NO_BUFFERS_READ,
    NS_E_CD_EMPTY_TRACK_QUEUE,
    NS_E_CD_NO_READER,
    NS_E_CD_ISRC_INVALID,
    NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID,
    NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION,
    NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS,
    NS_E_CD_QUEUEING_DISABLED,
    NS_E_WMP_DRM_ACQUIRING_LICENSE,
    NS_E_WMP_DRM_LICENSE_EXPIRED,
    NS_E_WMP_DRM_LICENSE_NOTACQUIRED,
    NS_E_WMP_DRM_LICENSE_NOTENABLED,
    NS_E_WMP_DRM_LICENSE_UNUSABLE,
    NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED,
    NS_E_WMP_DRM_LICENSE_NOSAP,
    NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE,
    NS_E_WMP_LICENSE_REQUIRED,
    NS_E_WMP_PROTECTED_CONTENT,
    NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED,
    NS_E_PDA_CANNOT_SYNC_FROM_INTERNET,
    NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST,
    NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE,
    NS_E_PDA_SYNC_FAILED,
    NS_E_PDA_DELETE_FAILED,
    NS_E_PDA_FAILED_TO_RETRIEVE_FILE,
    NS_E_PDA_DEVICE_NOT_RESPONDING,
    NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO,
    NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE,
    NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO,
    NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO,
    NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE,
    NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG,
    NS_E_PDA_CEWMDM_DRM_ERROR,
    NS_E_INCOMPLETE_PLAYLIST,
    NS_E_PDA_SYNC_RUNNING,
    NS_E_PDA_SYNC_LOGIN_ERROR,
    NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND,
    NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE,
    NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING,
    NS_E_WMP_HWND_NOTFOUND,
    NS_E_BKGDOWNLOAD_WRONG_NO_FILES,
    NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB,
    NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB,
    NS_E_BKGDOWNLOAD_NOJOBPOINTER,
    NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE,
    NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE,
    NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE,
    NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE,
    NS_E_BKGDOWNLOAD_CALLFUNCFAILED,
    NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT,
    NS_E_BKGDOWNLOAD_CALLFUNCENDED,
    NS_E_BKGDOWNLOAD_WMDUNPACKFAILED,
    NS_E_BKGDOWNLOAD_FAILEDINITIALIZE,
    NS_E_INTERFACE_NOT_REGISTERED_IN_GIT,
    NS_E_BKGDOWNLOAD_INVALID_FILE_NAME,
    NS_E_IMAGE_DOWNLOAD_FAILED,
    NS_E_WMP_UDRM_NOUSERLIST,
    NS_E_WMP_DRM_NOT_ACQUIRING,
    NS_E_WMP_BSTR_TOO_LONG,
    NS_E_WMP_AUTOPLAY_INVALID_STATE,
    NS_E_WMP_COMPONENT_REVOKED,
    NS_E_CURL_NOTSAFE,
    NS_E_CURL_INVALIDCHAR,
    NS_E_CURL_INVALIDHOSTNAME,
    NS_E_CURL_INVALIDPATH,
    NS_E_CURL_INVALIDSCHEME,
    NS_E_CURL_INVALIDURL,
    NS_E_CURL_CANTWALK,
    NS_E_CURL_INVALIDPORT,
    NS_E_CURLHELPER_NOTADIRECTORY,
    NS_E_CURLHELPER_NOTAFILE,
    NS_E_CURL_CANTDECODE,
    NS_E_CURLHELPER_NOTRELATIVE,
    NS_E_CURL_INVALIDBUFFERSIZE,
    NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED,
    NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES,
    NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT,
    NS_E_NOT_CONTENT_PARTNER_TRACK,
    NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE,
    NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE,
    NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED,
    NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED,
    NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT,
    NS_E_CONTENT_PARTNER_STILL_INITIALIZING,
    NS_E_OPEN_CONTAINING_FOLDER_FAILED,
    NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES,
    NS_E_REDIRECT,
    NS_E_STALE_PRESENTATION,
    NS_E_NAMESPACE_WRONG_PERSIST,
    NS_E_NAMESPACE_WRONG_TYPE,
    NS_E_NAMESPACE_NODE_CONFLICT,
    NS_E_NAMESPACE_NODE_NOT_FOUND,
    NS_E_NAMESPACE_BUFFER_TOO_SMALL,
    NS_E_NAMESPACE_TOO_MANY_CALLBACKS,
    NS_E_NAMESPACE_DUPLICATE_CALLBACK,
    NS_E_NAMESPACE_CALLBACK_NOT_FOUND,
    NS_E_NAMESPACE_NAME_TOO_LONG,
    NS_E_NAMESPACE_DUPLICATE_NAME,
    NS_E_NAMESPACE_EMPTY_NAME,
    NS_E_NAMESPACE_INDEX_TOO_LARGE,
    NS_E_NAMESPACE_BAD_NAME,
    NS_E_NAMESPACE_WRONG_SECURITY,
    NS_E_CACHE_ARCHIVE_CONFLICT,
    NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND,
    NS_E_CACHE_ORIGIN_SERVER_TIMEOUT,
    NS_E_CACHE_NOT_BROADCAST,
    NS_E_CACHE_CANNOT_BE_CACHED,
    NS_E_CACHE_NOT_MODIFIED,
    NS_E_CANNOT_REMOVE_PUBLISHING_POINT,
    NS_E_CANNOT_REMOVE_PLUGIN,
    NS_E_WRONG_PUBLISHING_POINT_TYPE,
    NS_E_UNSUPPORTED_LOAD_TYPE,
    NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION,
    NS_E_INVALID_PUBLISHING_POINT_NAME,
    NS_E_TOO_MANY_MULTICAST_SINKS,
    NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED,
    NS_E_MULTICAST_PLUGIN_NOT_ENABLED,
    NS_E_INVALID_OPERATING_SYSTEM_VERSION,
    NS_E_PUBLISHING_POINT_REMOVED,
    NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST,
    NS_E_UNSUPPORTED_LANGUAGE,
    NS_E_WRONG_OS_VERSION,
    NS_E_PUBLISHING_POINT_STOPPED,
    NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING,
    NS_E_EMPTY_PLAYLIST,
    NS_E_PLAYLIST_PARSE_FAILURE,
    NS_E_PLAYLIST_UNSUPPORTED_ENTRY,
    NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST,
    NS_E_PLAYLIST_ENTRY_SEEK,
    NS_E_PLAYLIST_RECURSIVE_PLAYLISTS,
    NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS,
    NS_E_PLAYLIST_SHUTDOWN,
    NS_E_PLAYLIST_END_RECEDING,
    NS_E_DATAPATH_NO_SINK,
    NS_E_INVALID_PUSH_TEMPLATE,
    NS_E_INVALID_PUSH_PUBLISHING_POINT,
    NS_E_CRITICAL_ERROR,
    NS_E_NO_NEW_CONNECTIONS,
    NS_E_WSX_INVALID_VERSION,
    NS_E_HEADER_MISMATCH,
    NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME,
    NS_E_NO_SCRIPT_ENGINE,
    NS_E_PLUGIN_ERROR_REPORTED,
    NS_E_SOURCE_PLUGIN_NOT_FOUND,
    NS_E_PLAYLIST_PLUGIN_NOT_FOUND,
    NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED,
    NS_E_MEDIA_PARSER_INVALID_FORMAT,
    NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED,
    NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER,
    NS_E_WIZARD_RUNNING,
    NS_E_INVALID_LOG_URL,
    NS_E_INVALID_MTU_RANGE,
    NS_E_INVALID_PLAY_STATISTICS,
    NS_E_LOG_NEED_TO_BE_SKIPPED,
    NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED,
    NS_E_PORT_IN_USE,
    NS_E_PORT_IN_USE_HTTP,
    NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE,
    NS_E_ARCHIVE_REACH_QUOTA,
    NS_E_ARCHIVE_ABORT_DUE_TO_BCAST,
    NS_E_ARCHIVE_GAP_DETECTED,
    NS_E_AUTHORIZATION_FILE_NOT_FOUND,
    NS_E_BAD_MARKIN,
    NS_E_BAD_MARKOUT,
    NS_E_NOMATCHING_MEDIASOURCE,
    NS_E_UNSUPPORTED_SOURCETYPE,
    NS_E_TOO_MANY_AUDIO,
    NS_E_TOO_MANY_VIDEO,
    NS_E_NOMATCHING_ELEMENT,
    NS_E_MISMATCHED_MEDIACONTENT,
    NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP,
    NS_E_AUDIODEVICE_BUSY,
    NS_E_AUDIODEVICE_UNEXPECTED,
    NS_E_AUDIODEVICE_BADFORMAT,
    NS_E_VIDEODEVICE_BUSY,
    NS_E_VIDEODEVICE_UNEXPECTED,
    NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING,
    NS_E_NO_PROFILE_IN_SOURCEGROUP,
    NS_E_VIDEODRIVER_UNSTABLE,
    NS_E_VIDCAPSTARTFAILED,
    NS_E_VIDSOURCECOMPRESSION,
    NS_E_VIDSOURCESIZE,
    NS_E_ICMQUERYFORMAT,
    NS_E_VIDCAPCREATEWINDOW,
    NS_E_VIDCAPDRVINUSE,
    NS_E_NO_MEDIAFORMAT_IN_SOURCE,
    NS_E_NO_VALID_OUTPUT_STREAM,
    NS_E_NO_VALID_SOURCE_PLUGIN,
    NS_E_NO_ACTIVE_SOURCEGROUP,
    NS_E_NO_SCRIPT_STREAM,
    NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING,
    NS_E_INVALIDPACKETSIZE,
    NS_E_PLUGIN_CLSID_INVALID,
    NS_E_UNSUPPORTED_ARCHIVETYPE,
    NS_E_UNSUPPORTED_ARCHIVEOPERATION,
    NS_E_ARCHIVE_FILENAME_NOTSET,
    NS_E_SOURCEGROUP_NOTPREPARED,
    NS_E_PROFILE_MISMATCH,
    NS_E_INCORRECTCLIPSETTINGS,
    NS_E_NOSTATSAVAILABLE,
    NS_E_NOTARCHIVING,
    NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED,
    NS_E_NOSOURCEGROUPS,
    NS_E_INVALIDINPUTFPS,
    NS_E_NO_DATAVIEW_SUPPORT,
    NS_E_CODEC_UNAVAILABLE,
    NS_E_ARCHIVE_SAME_AS_INPUT,
    NS_E_SOURCE_NOTSPECIFIED,
    NS_E_NO_REALTIME_TIMECOMPRESSION,
    NS_E_UNSUPPORTED_ENCODER_DEVICE,
    NS_E_UNEXPECTED_DISPLAY_SETTINGS,
    NS_E_NO_AUDIODATA,
    NS_E_INPUTSOURCE_PROBLEM,
    NS_E_WME_VERSION_MISMATCH,
    NS_E_NO_REALTIME_PREPROCESS,
    NS_E_NO_REPEAT_PREPROCESS,
    NS_E_CANNOT_PAUSE_LIVEBROADCAST,
    NS_E_DRM_PROFILE_NOT_SET,
    NS_E_DUPLICATE_DRMPROFILE,
    NS_E_INVALID_DEVICE,
    NS_E_SPEECHEDL_ON_NON_MIXEDMODE,
    NS_E_DRM_PASSWORD_TOO_LONG,
    NS_E_DEVCONTROL_FAILED_SEEK,
    NS_E_INTERLACE_REQUIRE_SAMESIZE,
    NS_E_TOO_MANY_DEVICECONTROL,
    NS_E_NO_MULTIPASS_FOR_LIVEDEVICE,
    NS_E_MISSING_AUDIENCE,
    NS_E_AUDIENCE_CONTENTTYPE_MISMATCH,
    NS_E_MISSING_SOURCE_INDEX,
    NS_E_NUM_LANGUAGE_MISMATCH,
    NS_E_LANGUAGE_MISMATCH,
    NS_E_VBRMODE_MISMATCH,
    NS_E_INVALID_INPUT_AUDIENCE_INDEX,
    NS_E_INVALID_INPUT_LANGUAGE,
    NS_E_INVALID_INPUT_STREAM,
    NS_E_EXPECT_MONO_WAV_INPUT,
    NS_E_INPUT_WAVFORMAT_MISMATCH,
    NS_E_RECORDQ_DISK_FULL,
    NS_E_NO_PAL_INVERSE_TELECINE,
    NS_E_ACTIVE_SG_DEVICE_DISCONNECTED,
    NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED,
    NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER,
    NS_E_INPUT_DOESNOT_SUPPORT_SMPTE,
    NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS,
    NS_E_BAD_CONTENTEDL,
    NS_E_INTERLACEMODE_MISMATCH,
    NS_E_NONSQUAREPIXELMODE_MISMATCH,
    NS_E_SMPTEMODE_MISMATCH,
    NS_E_END_OF_TAPE,
    NS_E_NO_MEDIA_IN_AUDIENCE,
    NS_E_NO_AUDIENCES,
    NS_E_NO_AUDIO_COMPAT,
    NS_E_INVALID_VBR_COMPAT,
    NS_E_NO_PROFILE_NAME,
    NS_E_INVALID_VBR_WITH_UNCOMP,
    NS_E_MULTIPLE_VBR_AUDIENCES,
    NS_E_UNCOMP_COMP_COMBINATION,
    NS_E_MULTIPLE_AUDIO_CODECS,
    NS_E_MULTIPLE_AUDIO_FORMATS,
    NS_E_AUDIO_BITRATE_STEPDOWN,
    NS_E_INVALID_AUDIO_PEAKRATE,
    NS_E_INVALID_AUDIO_PEAKRATE_2,
    NS_E_INVALID_AUDIO_BUFFERMAX,
    NS_E_MULTIPLE_VIDEO_CODECS,
    NS_E_MULTIPLE_VIDEO_SIZES,
    NS_E_INVALID_VIDEO_BITRATE,
    NS_E_VIDEO_BITRATE_STEPDOWN,
    NS_E_INVALID_VIDEO_PEAKRATE,
    NS_E_INVALID_VIDEO_PEAKRATE_2,
    NS_E_INVALID_VIDEO_WIDTH,
    NS_E_INVALID_VIDEO_HEIGHT,
    NS_E_INVALID_VIDEO_FPS,
    NS_E_INVALID_VIDEO_KEYFRAME,
    NS_E_INVALID_VIDEO_IQUALITY,
    NS_E_INVALID_VIDEO_CQUALITY,
    NS_E_INVALID_VIDEO_BUFFER,
    NS_E_INVALID_VIDEO_BUFFERMAX,
    NS_E_INVALID_VIDEO_BUFFERMAX_2,
    NS_E_INVALID_VIDEO_WIDTH_ALIGN,
    NS_E_INVALID_VIDEO_HEIGHT_ALIGN,
    NS_E_MULTIPLE_SCRIPT_BITRATES,
    NS_E_INVALID_SCRIPT_BITRATE,
    NS_E_MULTIPLE_FILE_BITRATES,
    NS_E_INVALID_FILE_BITRATE,
    NS_E_SAME_AS_INPUT_COMBINATION,
    NS_E_SOURCE_CANNOT_LOOP,
    NS_E_INVALID_FOLDDOWN_COEFFICIENTS,
    NS_E_DRMPROFILE_NOTFOUND,
    NS_E_INVALID_TIMECODE,
    NS_E_NO_AUDIO_TIMECOMPRESSION,
    NS_E_NO_TWOPASS_TIMECOMPRESSION,
    NS_E_TIMECODE_REQUIRES_VIDEOSTREAM,
    NS_E_NO_MBR_WITH_TIMECODE,
    NS_E_INVALID_INTERLACEMODE,
    NS_E_INVALID_INTERLACE_COMPAT,
    NS_E_INVALID_NONSQUAREPIXEL_COMPAT,
    NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL,
    NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR,
    NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT,
    NS_E_DEVICECONTROL_UNSTABLE,
    NS_E_INVALID_PIXEL_ASPECT_RATIO,
    NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH,
    NS_E_INVALID_PROFILE_CONTENTTYPE,
    NS_E_TRANSFORM_PLUGIN_NOT_FOUND,
    NS_E_TRANSFORM_PLUGIN_INVALID,
    NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS,
    NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING,
    NS_E_MARKIN_UNSUPPORTED,
    NS_E_DRM_INVALID_APPLICATION,
    NS_E_DRM_LICENSE_STORE_ERROR,
    NS_E_DRM_SECURE_STORE_ERROR,
    NS_E_DRM_LICENSE_STORE_SAVE_ERROR,
    NS_E_DRM_SECURE_STORE_UNLOCK_ERROR,
    NS_E_DRM_INVALID_CONTENT,
    NS_E_DRM_UNABLE_TO_OPEN_LICENSE,
    NS_E_DRM_INVALID_LICENSE,
    NS_E_DRM_INVALID_MACHINE,
    NS_E_DRM_ENUM_LICENSE_FAILED,
    NS_E_DRM_INVALID_LICENSE_REQUEST,
    NS_E_DRM_UNABLE_TO_INITIALIZE,
    NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE,
    NS_E_DRM_INVALID_LICENSE_ACQUIRED,
    NS_E_DRM_NO_RIGHTS,
    NS_E_DRM_KEY_ERROR,
    NS_E_DRM_ENCRYPT_ERROR,
    NS_E_DRM_DECRYPT_ERROR,
    NS_E_DRM_LICENSE_INVALID_XML,
    NS_E_DRM_NEEDS_INDIVIDUALIZATION,
    NS_E_DRM_ALREADY_INDIVIDUALIZED,
    NS_E_DRM_ACTION_NOT_QUERIED,
    NS_E_DRM_ACQUIRING_LICENSE,
    NS_E_DRM_INDIVIDUALIZING,
    NS_E_BACKUP_RESTORE_FAILURE,
    NS_E_BACKUP_RESTORE_BAD_REQUEST_ID,
    NS_E_DRM_PARAMETERS_MISMATCHED,
    NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT,
    NS_E_DRM_INDIVIDUALIZE_ERROR,
    NS_E_DRM_LICENSE_OPEN_ERROR,
    NS_E_DRM_LICENSE_CLOSE_ERROR,
    NS_E_DRM_GET_LICENSE_ERROR,
    NS_E_DRM_QUERY_ERROR,
    NS_E_DRM_REPORT_ERROR,
    NS_E_DRM_GET_LICENSESTRING_ERROR,
    NS_E_DRM_GET_CONTENTSTRING_ERROR,
    NS_E_DRM_MONITOR_ERROR,
    NS_E_DRM_UNABLE_TO_SET_PARAMETER,
    NS_E_DRM_INVALID_APPDATA,
    NS_E_DRM_INVALID_APPDATA_VERSION,
    NS_E_DRM_BACKUP_EXISTS,
    NS_E_DRM_BACKUP_CORRUPT,
    NS_E_DRM_BACKUPRESTORE_BUSY,
    NS_E_BACKUP_RESTORE_BAD_DATA,
    NS_E_DRM_LICENSE_UNUSABLE,
    NS_E_DRM_INVALID_PROPERTY,
    NS_E_DRM_SECURE_STORE_NOT_FOUND,
    NS_E_DRM_CACHED_CONTENT_ERROR,
    NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE,
    NS_E_DRM_DRIVER_AUTH_FAILURE,
    NS_E_DRM_NEED_UPGRADE_MSSAP,
    NS_E_DRM_REOPEN_CONTENT,
    NS_E_DRM_DRIVER_DIGIOUT_FAILURE,
    NS_E_DRM_INVALID_SECURESTORE_PASSWORD,
    NS_E_DRM_APPCERT_REVOKED,
    NS_E_DRM_RESTORE_FRAUD,
    NS_E_DRM_HARDWARE_INCONSISTENT,
    NS_E_DRM_SDMI_TRIGGER,
    NS_E_DRM_SDMI_NOMORECOPIES,
    NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT,
    NS_E_DRM_LICENSE_NOTACQUIRED,
    NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT,
    NS_E_DRM_BUFFER_TOO_SMALL,
    NS_E_DRM_UNSUPPORTED_PROPERTY,
    NS_E_DRM_ERROR_BAD_NET_RESP,
    NS_E_DRM_STORE_NOTALLSTORED,
    NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID,
    NS_E_DRM_INVALID_DATA,
    NS_E_DRM_POLICY_DISABLE_ONLINE,
    NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT,
    NS_E_DRM_NOT_CONFIGURED,
    NS_E_DRM_DEVICE_ACTIVATION_CANCELED,
    NS_E_BACKUP_RESTORE_TOO_MANY_RESETS,
    NS_E_DRM_DEBUGGING_NOT_ALLOWED,
    NS_E_DRM_OPERATION_CANCELED,
    NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED,
    NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT,
    NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT,
    NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION,
    NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION,
    NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT,
    NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK,
    NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK,
    NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER,
    NS_E_DRM_POLICY_METERING_DISABLED,
    NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED,
    NS_E_DRM_SDK_VERSIONMISMATCH,
    NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET,
    NS_E_LICENSE_HEADER_MISSING_URL,
    NS_E_DEVICE_NOT_WMDRM_DEVICE,
    NS_E_DRM_INVALID_APPCERT,
    NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION,
    NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE,
    NS_E_DRM_CHECKPOINT_FAILED,
    NS_E_DRM_BB_UNABLE_TO_INITIALIZE,
    NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID,
    NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE,
    NS_E_DRM_DATASTORE_CORRUPT,
    NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT,
    NS_E_DRM_STUBLIB_REQUIRED,
    NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT,
    NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE,
    NS_E_DRM_INVALID_MIGRATION_IMAGE,
    NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED,
    NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE,
    NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID,
    NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE,
    NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH,
    NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS,
    NS_E_DRM_HARDWAREID_MISMATCH,
    NS_E_INVALID_DRMV2CLT_STUBLIB,
    NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA,
    NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS,
    NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD,
    NS_E_DRM_MIGRATION_NOT_SUPPORTED,
    NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT,
    NS_E_DRM_CHECKPOINT_MISMATCH,
    NS_E_DRM_CHECKPOINT_CORRUPT,
    NS_E_REG_FLUSH_FAILURE,
    NS_E_HDS_KEY_MISMATCH,
    NS_E_DRM_MIGRATION_OPERATION_CANCELLED,
    NS_E_DRM_MIGRATION_OBJECT_IN_USE,
    NS_E_DRM_MALFORMED_CONTENT_HEADER,
    NS_E_DRM_LICENSE_EXPIRED,
    NS_E_DRM_LICENSE_NOTENABLED,
    NS_E_DRM_LICENSE_APPSECLOW,
    NS_E_DRM_STORE_NEEDINDI,
    NS_E_DRM_STORE_NOTALLOWED,
    NS_E_DRM_LICENSE_APP_NOTALLOWED,
    NS_E_DRM_LICENSE_CERT_EXPIRED,
    NS_E_DRM_LICENSE_SECLOW,
    NS_E_DRM_LICENSE_CONTENT_REVOKED,
    NS_E_DRM_DEVICE_NOT_REGISTERED,
    NS_E_DRM_LICENSE_NOSAP,
    NS_E_DRM_LICENSE_NOSVP,
    NS_E_DRM_LICENSE_NOWDM,
    NS_E_DRM_LICENSE_NOTRUSTEDCODEC,
    NS_E_DRM_SOURCEID_NOT_SUPPORTED,
    NS_E_DRM_NEEDS_UPGRADE_TEMPFILE,
    NS_E_DRM_NEED_UPGRADE_PD,
    NS_E_DRM_SIGNATURE_FAILURE,
    NS_E_DRM_LICENSE_SERVER_INFO_MISSING,
    NS_E_DRM_BUSY,
    NS_E_DRM_PD_TOO_MANY_DEVICES,
    NS_E_DRM_INDIV_FRAUD,
    NS_E_DRM_INDIV_NO_CABS,
    NS_E_DRM_INDIV_SERVICE_UNAVAILABLE,
    NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE,
    NS_E_DRM_CLIENT_CODE_EXPIRED,
    NS_E_DRM_NO_UPLINK_LICENSE,
    NS_E_DRM_INVALID_KID,
    NS_E_DRM_LICENSE_INITIALIZATION_ERROR,
    NS_E_DRM_CHAIN_TOO_LONG,
    NS_E_DRM_UNSUPPORTED_ALGORITHM,
    NS_E_DRM_LICENSE_DELETION_ERROR,
    NS_E_DRM_INVALID_CERTIFICATE,
    NS_E_DRM_CERTIFICATE_REVOKED,
    NS_E_DRM_LICENSE_UNAVAILABLE,
    NS_E_DRM_DEVICE_LIMIT_REACHED,
    NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY,
    NS_E_DRM_MUST_REGISTER,
    NS_E_DRM_MUST_APPROVE,
    NS_E_DRM_MUST_REVALIDATE,
    NS_E_DRM_INVALID_PROXIMITY_RESPONSE,
    NS_E_DRM_INVALID_SESSION,
    NS_E_DRM_DEVICE_NOT_OPEN,
    NS_E_DRM_DEVICE_ALREADY_REGISTERED,
    NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION,
    NS_E_DRM_UNSUPPORTED_ACTION,
    NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE,
    NS_E_DRM_UNABLE_TO_OPEN_PORT,
    NS_E_DRM_BAD_REQUEST,
    NS_E_DRM_INVALID_CRL,
    NS_E_DRM_ATTRIBUTE_TOO_LONG,
    NS_E_DRM_EXPIRED_LICENSEBLOB,
    NS_E_DRM_INVALID_LICENSEBLOB,
    NS_E_DRM_INCLUSION_LIST_REQUIRED,
    NS_E_DRM_DRMV2CLT_REVOKED,
    NS_E_DRM_RIV_TOO_SMALL,
    NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED,
    NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
    NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
    NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
    NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED,
    NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED,
    NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED,
    NS_E_REBOOT_RECOMMENDED,
    NS_E_REBOOT_REQUIRED,
    NS_E_SETUP_INCOMPLETE,
    NS_E_SETUP_DRM_MIGRATION_FAILED,
    NS_E_SETUP_IGNORABLE_FAILURE,
    NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE,
    NS_E_SETUP_BLOCKED,
    NS_E_UNKNOWN_PROTOCOL,
    NS_E_REDIRECT_TO_PROXY,
    NS_E_INTERNAL_SERVER_ERROR,
    NS_E_BAD_REQUEST,
    NS_E_ERROR_FROM_PROXY,
    NS_E_PROXY_TIMEOUT,
    NS_E_SERVER_UNAVAILABLE,
    NS_E_REFUSED_BY_SERVER,
    NS_E_INCOMPATIBLE_SERVER,
    NS_E_MULTICAST_DISABLED,
    NS_E_INVALID_REDIRECT,
    NS_E_ALL_PROTOCOLS_DISABLED,
    NS_E_MSBD_NO_LONGER_SUPPORTED,
    NS_E_PROXY_NOT_FOUND,
    NS_E_CANNOT_CONNECT_TO_PROXY,
    NS_E_SERVER_DNS_TIMEOUT,
    NS_E_PROXY_DNS_TIMEOUT,
    NS_E_CLOSED_ON_SUSPEND,
    NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER,
    NS_E_SESSION_NOT_FOUND,
    NS_E_REQUIRE_STREAMING_CLIENT,
    NS_E_PLAYLIST_ENTRY_HAS_CHANGED,
    NS_E_PROXY_ACCESSDENIED,
    NS_E_PROXY_SOURCE_ACCESSDENIED,
    NS_E_NETWORK_SINK_WRITE,
    NS_E_FIREWALL,
    NS_E_MMS_NOT_SUPPORTED,
    NS_E_SERVER_ACCESSDENIED,
    NS_E_RESOURCE_GONE,
    NS_E_NO_EXISTING_PACKETIZER,
    NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE,
    NS_E_RESET_SOCKET_CONNECTION,
    NS_E_TOO_MANY_HOPS,
    NS_E_TOO_MUCH_DATA_FROM_SERVER,
    NS_E_CONNECT_TIMEOUT,
    NS_E_PROXY_CONNECT_TIMEOUT,
    NS_E_SESSION_INVALID,
    NS_E_PACKETSINK_UNKNOWN_FEC_STREAM,
    NS_E_PUSH_CANNOTCONNECT,
    NS_E_INCOMPATIBLE_PUSH_SERVER,
    NS_E_END_OF_PLAYLIST,
    NS_E_USE_FILE_SOURCE,
    NS_E_PROPERTY_NOT_FOUND,
    NS_E_PROPERTY_READ_ONLY,
    NS_E_TABLE_KEY_NOT_FOUND,
    NS_E_INVALID_QUERY_OPERATOR,
    NS_E_INVALID_QUERY_PROPERTY,
    NS_E_PROPERTY_NOT_SUPPORTED,
    NS_E_SCHEMA_CLASSIFY_FAILURE,
    NS_E_METADATA_FORMAT_NOT_SUPPORTED,
    NS_E_METADATA_NO_EDITING_CAPABILITY,
    NS_E_METADATA_CANNOT_SET_LOCALE,
    NS_E_METADATA_LANGUAGE_NOT_SUPORTED,
    NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE,
    NS_E_METADATA_NOT_AVAILABLE,
    NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE,
    NS_E_METADATA_INVALID_DOCUMENT_TYPE,
    NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE,
    NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE,
    MF_E_PLATFORM_NOT_INITIALIZED,
    MF_E_BUFFERTOOSMALL,
    MF_E_INVALIDREQUEST,
    MF_E_INVALIDSTREAMNUMBER,
    MF_E_INVALIDMEDIATYPE,
    MF_E_NOTACCEPTING,
    MF_E_NOT_INITIALIZED,
    MF_E_UNSUPPORTED_REPRESENTATION,
    MF_E_NO_MORE_TYPES,
    MF_E_UNSUPPORTED_SERVICE,
    MF_E_UNEXPECTED,
    MF_E_INVALIDNAME,
    MF_E_INVALIDTYPE,
    MF_E_INVALID_FILE_FORMAT,
    MF_E_INVALIDINDEX,
    MF_E_INVALID_TIMESTAMP,
    MF_E_UNSUPPORTED_SCHEME,
    MF_E_UNSUPPORTED_BYTESTREAM_TYPE,
    MF_E_UNSUPPORTED_TIME_FORMAT,
    MF_E_NO_SAMPLE_TIMESTAMP,
    MF_E_NO_SAMPLE_DURATION,
    MF_E_INVALID_STREAM_DATA,
    MF_E_RT_UNAVAILABLE,
    MF_E_UNSUPPORTED_RATE,
    MF_E_THINNING_UNSUPPORTED,
    MF_E_REVERSE_UNSUPPORTED,
    MF_E_UNSUPPORTED_RATE_TRANSITION,
    MF_E_RATE_CHANGE_PREEMPTED,
    MF_E_NOT_FOUND,
    MF_E_NOT_AVAILABLE,
    MF_E_NO_CLOCK,
    MF_E_MULTIPLE_BEGIN,
    MF_E_MULTIPLE_SUBSCRIBERS,
    MF_E_TIMER_ORPHANED,
    MF_E_STATE_TRANSITION_PENDING,
    MF_E_UNSUPPORTED_STATE_TRANSITION,
    MF_E_UNRECOVERABLE_ERROR_OCCURRED,
    MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS,
    MF_E_SAMPLE_NOT_WRITABLE,
    MF_E_INVALID_KEY,
    MF_E_BAD_STARTUP_VERSION,
    MF_E_UNSUPPORTED_CAPTION,
    MF_E_INVALID_POSITION,
    MF_E_ATTRIBUTENOTFOUND,
    MF_E_PROPERTY_TYPE_NOT_ALLOWED,
    MF_E_PROPERTY_TYPE_NOT_SUPPORTED,
    MF_E_PROPERTY_EMPTY,
    MF_E_PROPERTY_NOT_EMPTY,
    MF_E_PROPERTY_VECTOR_NOT_ALLOWED,
    MF_E_PROPERTY_VECTOR_REQUIRED,
    MF_E_OPERATION_CANCELLED,
    MF_E_BYTESTREAM_NOT_SEEKABLE,
    MF_E_DISABLED_IN_SAFEMODE,
    MF_E_CANNOT_PARSE_BYTESTREAM,
    MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS,
    MF_E_MEDIAPROC_WRONGSTATE,
    MF_E_RT_THROUGHPUT_NOT_AVAILABLE,
    MF_E_RT_TOO_MANY_CLASSES,
    MF_E_RT_WOULDBLOCK,
    MF_E_NO_BITPUMP,
    MF_E_RT_OUTOFMEMORY,
    MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED,
    MF_E_CANNOT_CREATE_SINK,
    MF_E_BYTESTREAM_UNKNOWN_LENGTH,
    MF_E_SESSION_PAUSEWHILESTOPPED,
    MF_E_FORMAT_CHANGE_NOT_SUPPORTED,
    MF_E_INVALID_WORKQUEUE,
    MF_E_DRM_UNSUPPORTED,
    MF_E_UNAUTHORIZED,
    MF_E_OUT_OF_RANGE,
    MF_E_INVALID_CODEC_MERIT,
    MF_E_HW_MFT_FAILED_START_STREAMING,
    MF_E_ASF_PARSINGINCOMPLETE,
    MF_E_ASF_MISSINGDATA,
    MF_E_ASF_INVALIDDATA,
    MF_E_ASF_OPAQUEPACKET,
    MF_E_ASF_NOINDEX,
    MF_E_ASF_OUTOFRANGE,
    MF_E_ASF_INDEXNOTLOADED,
    MF_E_ASF_TOO_MANY_PAYLOADS,
    MF_E_ASF_UNSUPPORTED_STREAM_TYPE,
    MF_E_ASF_DROPPED_PACKET,
    MF_E_NO_EVENTS_AVAILABLE,
    MF_E_INVALID_STATE_TRANSITION,
    MF_E_END_OF_STREAM,
    MF_E_SHUTDOWN,
    MF_E_MP3_NOTFOUND,
    MF_E_MP3_OUTOFDATA,
    MF_E_MP3_NOTMP3,
    MF_E_MP3_NOTSUPPORTED,
    MF_E_NO_DURATION,
    MF_E_INVALID_FORMAT,
    MF_E_PROPERTY_NOT_FOUND,
    MF_E_PROPERTY_READ_ONLY,
    MF_E_PROPERTY_NOT_ALLOWED,
    MF_E_MEDIA_SOURCE_NOT_STARTED,
    MF_E_UNSUPPORTED_FORMAT,
    MF_E_MP3_BAD_CRC,
    MF_E_NOT_PROTECTED,
    MF_E_MEDIA_SOURCE_WRONGSTATE,
    MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED,
    MF_E_CANNOT_FIND_KEYFRAME_SAMPLE,
    MF_E_NETWORK_RESOURCE_FAILURE,
    MF_E_NET_WRITE,
    MF_E_NET_READ,
    MF_E_NET_REQUIRE_NETWORK,
    MF_E_NET_REQUIRE_ASYNC,
    MF_E_NET_BWLEVEL_NOT_SUPPORTED,
    MF_E_NET_STREAMGROUPS_NOT_SUPPORTED,
    MF_E_NET_MANUALSS_NOT_SUPPORTED,
    MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR,
    MF_E_NET_CACHESTREAM_NOT_FOUND,
    MF_E_NET_REQUIRE_INPUT,
    MF_E_NET_REDIRECT,
    MF_E_NET_REDIRECT_TO_PROXY,
    MF_E_NET_TOO_MANY_REDIRECTS,
    MF_E_NET_TIMEOUT,
    MF_E_NET_CLIENT_CLOSE,
    MF_E_NET_BAD_CONTROL_DATA,
    MF_E_NET_INCOMPATIBLE_SERVER,
    MF_E_NET_UNSAFE_URL,
    MF_E_NET_CACHE_NO_DATA,
    MF_E_NET_EOL,
    MF_E_NET_BAD_REQUEST,
    MF_E_NET_INTERNAL_SERVER_ERROR,
    MF_E_NET_SESSION_NOT_FOUND,
    MF_E_NET_NOCONNECTION,
    MF_E_NET_CONNECTION_FAILURE,
    MF_E_NET_INCOMPATIBLE_PUSHSERVER,
    MF_E_NET_SERVER_ACCESSDENIED,
    MF_E_NET_PROXY_ACCESSDENIED,
    MF_E_NET_CANNOTCONNECT,
    MF_E_NET_INVALID_PUSH_TEMPLATE,
    MF_E_NET_INVALID_PUSH_PUBLISHING_POINT,
    MF_E_NET_BUSY,
    MF_E_NET_RESOURCE_GONE,
    MF_E_NET_ERROR_FROM_PROXY,
    MF_E_NET_PROXY_TIMEOUT,
    MF_E_NET_SERVER_UNAVAILABLE,
    MF_E_NET_TOO_MUCH_DATA,
    MF_E_NET_SESSION_INVALID,
    MF_E_OFFLINE_MODE,
    MF_E_NET_UDP_BLOCKED,
    MF_E_NET_UNSUPPORTED_CONFIGURATION,
    MF_E_NET_PROTOCOL_DISABLED,
    MF_E_ALREADY_INITIALIZED,
    MF_E_BANDWIDTH_OVERRUN,
    MF_E_LATE_SAMPLE,
    MF_E_FLUSH_NEEDED,
    MF_E_INVALID_PROFILE,
    MF_E_INDEX_NOT_COMMITTED,
    MF_E_NO_INDEX,
    MF_E_CANNOT_INDEX_IN_PLACE,
    MF_E_MISSING_ASF_LEAKYBUCKET,
    MF_E_INVALID_ASF_STREAMID,
    MF_E_STREAMSINK_REMOVED,
    MF_E_STREAMSINKS_OUT_OF_SYNC,
    MF_E_STREAMSINKS_FIXED,
    MF_E_STREAMSINK_EXISTS,
    MF_E_SAMPLEALLOCATOR_CANCELED,
    MF_E_SAMPLEALLOCATOR_EMPTY,
    MF_E_SINK_ALREADYSTOPPED,
    MF_E_ASF_FILESINK_BITRATE_UNKNOWN,
    MF_E_SINK_NO_STREAMS,
    MF_E_METADATA_TOO_LONG,
    MF_E_SINK_NO_SAMPLES_PROCESSED,
    MF_E_VIDEO_REN_NO_PROCAMP_HW,
    MF_E_VIDEO_REN_NO_DEINTERLACE_HW,
    MF_E_VIDEO_REN_COPYPROT_FAILED,
    MF_E_VIDEO_REN_SURFACE_NOT_SHARED,
    MF_E_VIDEO_DEVICE_LOCKED,
    MF_E_NEW_VIDEO_DEVICE,
    MF_E_NO_VIDEO_SAMPLE_AVAILABLE,
    MF_E_NO_AUDIO_PLAYBACK_DEVICE,
    MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE,
    MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED,
    MF_E_AUDIO_SERVICE_NOT_RUNNING,
    MF_E_TOPO_INVALID_OPTIONAL_NODE,
    MF_E_TOPO_CANNOT_FIND_DECRYPTOR,
    MF_E_TOPO_CODEC_NOT_FOUND,
    MF_E_TOPO_CANNOT_CONNECT,
    MF_E_TOPO_UNSUPPORTED,
    MF_E_TOPO_INVALID_TIME_ATTRIBUTES,
    MF_E_TOPO_LOOPS_IN_TOPOLOGY,
    MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR,
    MF_E_TOPO_MISSING_STREAM_DESCRIPTOR,
    MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED,
    MF_E_TOPO_MISSING_SOURCE,
    MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED,
    MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID,
    MF_E_NO_SOURCE_IN_CACHE,
    MF_E_TRANSFORM_TYPE_NOT_SET,
    MF_E_TRANSFORM_STREAM_CHANGE,
    MF_E_TRANSFORM_INPUT_REMAINING,
    MF_E_TRANSFORM_PROFILE_MISSING,
    MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT,
    MF_E_TRANSFORM_PROFILE_TRUNCATED,
    MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED,
    MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG,
    MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE,
    MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM,
    MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG,
    MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE,
    MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE,
    MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE,
    MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE,
    MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION,
    MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES,
    MF_E_TRANSFORM_NEED_MORE_INPUT,
    MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG,
    MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING,
    MF_E_UNSUPPORTED_D3D_TYPE,
    MF_E_TRANSFORM_ASYNC_LOCKED,
    MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER,
    MF_E_LICENSE_INCORRECT_RIGHTS,
    MF_E_LICENSE_OUTOFDATE,
    MF_E_LICENSE_REQUIRED,
    MF_E_DRM_HARDWARE_INCONSISTENT,
    MF_E_NO_CONTENT_PROTECTION_MANAGER,
    MF_E_LICENSE_RESTORE_NO_RIGHTS,
    MF_E_BACKUP_RESTRICTED_LICENSE,
    MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION,
    MF_E_COMPONENT_REVOKED,
    MF_E_TRUST_DISABLED,
    MF_E_WMDRMOTA_NO_ACTION,
    MF_E_WMDRMOTA_ACTION_ALREADY_SET,
    MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE,
    MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED,
    MF_E_WMDRMOTA_ACTION_MISMATCH,
    MF_E_WMDRMOTA_INVALID_POLICY,
    MF_E_POLICY_UNSUPPORTED,
    MF_E_OPL_NOT_SUPPORTED,
    MF_E_TOPOLOGY_VERIFICATION_FAILED,
    MF_E_SIGNATURE_VERIFICATION_FAILED,
    MF_E_DEBUGGING_NOT_ALLOWED,
    MF_E_CODE_EXPIRED,
    MF_E_GRL_VERSION_TOO_LOW,
    MF_E_GRL_RENEWAL_NOT_FOUND,
    MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND,
    MF_E_KERNEL_UNTRUSTED,
    MF_E_PEAUTH_UNTRUSTED,
    MF_E_NON_PE_PROCESS,
    MF_E_REBOOT_REQUIRED,
    MF_E_GRL_INVALID_FORMAT,
    MF_E_GRL_UNRECOGNIZED_FORMAT,
    MF_E_ALL_PROCESS_RESTART_REQUIRED,
    MF_E_PROCESS_RESTART_REQUIRED,
    MF_E_USERMODE_UNTRUSTED,
    MF_E_PEAUTH_SESSION_NOT_STARTED,
    MF_E_INSUFFICIENT_BUFFER,
    MF_E_PEAUTH_PUBLICKEY_REVOKED,
    MF_E_GRL_ABSENT,
    MF_E_PE_UNTRUSTED,
    MF_E_PEAUTH_NOT_STARTED,
    MF_E_INCOMPATIBLE_SAMPLE_PROTECTION,
    MF_E_PE_SESSIONS_MAXED,
    MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED,
    MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED,
    MF_E_ITA_UNSUPPORTED_ACTION,
    MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS,
    MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS,
    MF_E_BAD_OPL_STRUCTURE_FORMAT,
    MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID,
    MF_E_NO_PMP_HOST,
    MF_E_ITA_OPL_DATA_NOT_INITIALIZED,
    MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT,
    MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT,
    MF_E_CLOCK_INVALID_CONTINUITY_KEY,
    MF_E_CLOCK_NO_TIME_SOURCE,
    MF_E_CLOCK_STATE_ALREADY_SET,
    MF_E_CLOCK_NOT_SIMPLE,
    MF_E_NO_MORE_DROP_MODES,
    MF_E_NO_MORE_QUALITY_LEVELS,
    MF_E_DROPTIME_NOT_SUPPORTED,
    MF_E_QUALITYKNOB_WAIT_LONGER,
    MF_E_QM_INVALIDSTATE,
    MF_E_TRANSCODE_NO_CONTAINERTYPE,
    MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS,
    MF_E_TRANSCODE_NO_MATCHING_ENCODER,
    MF_E_ALLOCATOR_NOT_INITIALIZED,
    MF_E_ALLOCATOR_NOT_COMMITED,
    MF_E_ALLOCATOR_ALREADY_COMMITED,
    MF_E_STREAM_ERROR,
    MF_E_INVALID_STREAM_STATE,
    MF_E_HW_STREAM_NOT_CONNECTED,
}

impl MEDIASERVER {
    pub fn code(&self) -> u32 {
        return match self {
            MEDIASERVER::NS_S_CALLPENDING => 0x000D0000 as u32,
            MEDIASERVER::NS_S_CALLABORTED => 0x000D0001 as u32,
            MEDIASERVER::NS_S_STREAM_TRUNCATED => 0x000D0002 as u32,
            MEDIASERVER::NS_S_REBUFFERING => 0x000D0BC8 as u32,
            MEDIASERVER::NS_S_DEGRADING_QUALITY => 0x000D0BC9 as u32,
            MEDIASERVER::NS_S_TRANSCRYPTOR_EOF => 0x000D0BDB as u32,
            MEDIASERVER::NS_S_WMP_UI_VERSIONMISMATCH => 0x000D0FE8 as u32,
            MEDIASERVER::NS_S_WMP_EXCEPTION => 0x000D0FE9 as u32,
            MEDIASERVER::NS_S_WMP_LOADED_GIF_IMAGE => 0x000D1040 as u32,
            MEDIASERVER::NS_S_WMP_LOADED_PNG_IMAGE => 0x000D1041 as u32,
            MEDIASERVER::NS_S_WMP_LOADED_BMP_IMAGE => 0x000D1042 as u32,
            MEDIASERVER::NS_S_WMP_LOADED_JPG_IMAGE => 0x000D1043 as u32,
            MEDIASERVER::NS_S_WMG_FORCE_DROP_FRAME => 0x000D104F as u32,
            MEDIASERVER::NS_S_WMR_ALREADYRENDERED => 0x000D105F as u32,
            MEDIASERVER::NS_S_WMR_PINTYPEPARTIALMATCH => 0x000D1060 as u32,
            MEDIASERVER::NS_S_WMR_PINTYPEFULLMATCH => 0x000D1061 as u32,
            MEDIASERVER::NS_S_WMG_ADVISE_DROP_FRAME => 0x000D1066 as u32,
            MEDIASERVER::NS_S_WMG_ADVISE_DROP_TO_KEYFRAME => 0x000D1067 as u32,
            MEDIASERVER::NS_S_NEED_TO_BUY_BURN_RIGHTS => 0x000D10DB as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLISTCLEARABORT => 0x000D10FE as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT => 0x000D10FF as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_CREATION_PENDING => 0x000D1102 as u32,
            MEDIASERVER::NS_S_WMPCORE_MEDIA_VALIDATION_PENDING => 0x000D1103 as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED => 0x000D1104 as u32,
            MEDIASERVER::NS_S_WMPCORE_COMMAND_NOT_AVAILABLE => 0x000D1105 as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED => 0x000D1106 as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS => 0x000D1107 as u32,
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA => 0x000D1108 as u32,
            MEDIASERVER::NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING => 0x000D1109 as u32,
            MEDIASERVER::NS_S_WMPCORE_MORE_NODES_AVAIABLE => 0x000D110A as u32,
            MEDIASERVER::NS_S_WMPBR_SUCCESS => 0x000D1135 as u32,
            MEDIASERVER::NS_S_WMPBR_PARTIALSUCCESS => 0x000D1136 as u32,
            MEDIASERVER::NS_S_WMPEFFECT_TRANSPARENT => 0x000D1144 as u32,
            MEDIASERVER::NS_S_WMPEFFECT_OPAQUE => 0x000D1145 as u32,
            MEDIASERVER::NS_S_OPERATION_PENDING => 0x000D114E as u32,
            MEDIASERVER::NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE => 0x000D1359 as u32,
            MEDIASERVER::NS_S_NAVIGATION_COMPLETE_WITH_ERRORS => 0x000D135E as u32,
            MEDIASERVER::NS_S_TRACK_ALREADY_DOWNLOADED => 0x000D1361 as u32,
            MEDIASERVER::NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS => 0x000D1519 as u32,
            MEDIASERVER::NS_S_DRM_LICENSE_ACQUIRED => 0x000D2726 as u32,
            MEDIASERVER::NS_S_DRM_INDIVIDUALIZED => 0x000D2727 as u32,
            MEDIASERVER::NS_S_DRM_MONITOR_CANCELLED => 0x000D2746 as u32,
            MEDIASERVER::NS_S_DRM_ACQUIRE_CANCELLED => 0x000D2747 as u32,
            MEDIASERVER::NS_S_DRM_BURNABLE_TRACK => 0x000D276E as u32,
            MEDIASERVER::NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION => 0x000D276F as u32,
            MEDIASERVER::NS_S_DRM_NEEDS_INDIVIDUALIZATION => 0x000D27DE as u32,
            MEDIASERVER::NS_S_REBOOT_RECOMMENDED => 0x000D2AF8 as u32,
            MEDIASERVER::NS_S_REBOOT_REQUIRED => 0x000D2AF9 as u32,
            MEDIASERVER::NS_S_EOSRECEDING => 0x000D2F09 as u32,
            MEDIASERVER::NS_S_CHANGENOTICE => 0x000D2F0D as u32,
            MEDIASERVER::MF_S_MULTIPLE_BEGIN => 0x000D36D8 as u32,
            MEDIASERVER::MF_S_ACTIVATE_REPLACED => 0x000D36FD as u32,
            MEDIASERVER::MF_S_SINK_NOT_FINALIZED => 0x000D4A42 as u32,
            MEDIASERVER::MF_S_SEQUENCER_CONTEXT_CANCELED => 0x000D61AD as u32,
            MEDIASERVER::MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM => 0x000D61AF as u32,
            MEDIASERVER::MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT => 0x000D6D75 as u32,
            MEDIASERVER::MF_S_PROTECTION_NOT_REQUIRED => 0x000D7150 as u32,
            MEDIASERVER::MF_S_WAIT_FOR_POLICY_SET => 0x000D7168 as u32,
            MEDIASERVER::MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT => 0x000D7169 as u32,
            MEDIASERVER::MF_S_PE_TRUSTED => 0x000D7173 as u32,
            MEDIASERVER::MF_S_CLOCK_STOPPED => 0x000D9C44 as u32,
            MEDIASERVER::NS_I_TIGER_START => 0x400D004F as u32,
            MEDIASERVER::NS_I_CUB_START => 0x400D0051 as u32,
            MEDIASERVER::NS_I_CUB_RUNNING => 0x400D0052 as u32,
            MEDIASERVER::NS_I_DISK_START => 0x400D0054 as u32,
            MEDIASERVER::NS_I_DISK_REBUILD_STARTED => 0x400D0056 as u32,
            MEDIASERVER::NS_I_DISK_REBUILD_FINISHED => 0x400D0057 as u32,
            MEDIASERVER::NS_I_DISK_REBUILD_ABORTED => 0x400D0058 as u32,
            MEDIASERVER::NS_I_LIMIT_FUNNELS => 0x400D0059 as u32,
            MEDIASERVER::NS_I_START_DISK => 0x400D005A as u32,
            MEDIASERVER::NS_I_STOP_DISK => 0x400D005B as u32,
            MEDIASERVER::NS_I_STOP_CUB => 0x400D005C as u32,
            MEDIASERVER::NS_I_KILL_USERSESSION => 0x400D005D as u32,
            MEDIASERVER::NS_I_KILL_CONNECTION => 0x400D005E as u32,
            MEDIASERVER::NS_I_REBUILD_DISK => 0x400D005F as u32,
            MEDIASERVER::MCMADM_I_NO_EVENTS => 0x400D0069 as u32,
            MEDIASERVER::NS_I_LOGGING_FAILED => 0x400D006E as u32,
            MEDIASERVER::NS_I_LIMIT_BANDWIDTH => 0x400D0070 as u32,
            MEDIASERVER::NS_I_CUB_UNFAIL_LINK => 0x400D0191 as u32,
            MEDIASERVER::NS_I_RESTRIPE_START => 0x400D0193 as u32,
            MEDIASERVER::NS_I_RESTRIPE_DONE => 0x400D0194 as u32,
            MEDIASERVER::NS_I_RESTRIPE_DISK_OUT => 0x400D0196 as u32,
            MEDIASERVER::NS_I_RESTRIPE_CUB_OUT => 0x400D0197 as u32,
            MEDIASERVER::NS_I_DISK_STOP => 0x400D0198 as u32,
            MEDIASERVER::NS_I_PLAYLIST_CHANGE_RECEDING => 0x400D14BE as u32,
            MEDIASERVER::NS_I_RECONNECTED => 0x400D2EFF as u32,
            MEDIASERVER::NS_I_NOLOG_STOP => 0x400D2F01 as u32,
            MEDIASERVER::NS_I_EXISTING_PACKETIZER => 0x400D2F03 as u32,
            MEDIASERVER::NS_I_MANUAL_PROXY => 0x400D2F04 as u32,
            MEDIASERVER::MF_S_ASF_PARSEINPROGRESS => 0x400D3A98 as u32,
            MEDIASERVER::MF_I_MANUAL_PROXY => 0x400D4272 as u32,
            MEDIASERVER::NS_W_SERVER_BANDWIDTH_LIMIT => 0x800D0003 as u32,
            MEDIASERVER::NS_W_FILE_BANDWIDTH_LIMIT => 0x800D0004 as u32,
            MEDIASERVER::NS_W_UNKNOWN_EVENT => 0x800D0060 as u32,
            MEDIASERVER::NS_I_CATATONIC_FAILURE => 0x800D0199 as u32,
            MEDIASERVER::NS_I_CATATONIC_AUTO_UNFAIL => 0x800D019A as u32,
            MEDIASERVER::NS_E_NOCONNECTION => 0xC00D0005 as u32,
            MEDIASERVER::NS_E_CANNOTCONNECT => 0xC00D0006 as u32,
            MEDIASERVER::NS_E_CANNOTDESTROYTITLE => 0xC00D0007 as u32,
            MEDIASERVER::NS_E_CANNOTRENAMETITLE => 0xC00D0008 as u32,
            MEDIASERVER::NS_E_CANNOTOFFLINEDISK => 0xC00D0009 as u32,
            MEDIASERVER::NS_E_CANNOTONLINEDISK => 0xC00D000A as u32,
            MEDIASERVER::NS_E_NOREGISTEREDWALKER => 0xC00D000B as u32,
            MEDIASERVER::NS_E_NOFUNNEL => 0xC00D000C as u32,
            MEDIASERVER::NS_E_NO_LOCALPLAY => 0xC00D000D as u32,
            MEDIASERVER::NS_E_NETWORK_BUSY => 0xC00D000E as u32,
            MEDIASERVER::NS_E_TOO_MANY_SESS => 0xC00D000F as u32,
            MEDIASERVER::NS_E_ALREADY_CONNECTED => 0xC00D0010 as u32,
            MEDIASERVER::NS_E_INVALID_INDEX => 0xC00D0011 as u32,
            MEDIASERVER::NS_E_PROTOCOL_MISMATCH => 0xC00D0012 as u32,
            MEDIASERVER::NS_E_TIMEOUT => 0xC00D0013 as u32,
            MEDIASERVER::NS_E_NET_WRITE => 0xC00D0014 as u32,
            MEDIASERVER::NS_E_NET_READ => 0xC00D0015 as u32,
            MEDIASERVER::NS_E_DISK_WRITE => 0xC00D0016 as u32,
            MEDIASERVER::NS_E_DISK_READ => 0xC00D0017 as u32,
            MEDIASERVER::NS_E_FILE_WRITE => 0xC00D0018 as u32,
            MEDIASERVER::NS_E_FILE_READ => 0xC00D0019 as u32,
            MEDIASERVER::NS_E_FILE_NOT_FOUND => 0xC00D001A as u32,
            MEDIASERVER::NS_E_FILE_EXISTS => 0xC00D001B as u32,
            MEDIASERVER::NS_E_INVALID_NAME => 0xC00D001C as u32,
            MEDIASERVER::NS_E_FILE_OPEN_FAILED => 0xC00D001D as u32,
            MEDIASERVER::NS_E_FILE_ALLOCATION_FAILED => 0xC00D001E as u32,
            MEDIASERVER::NS_E_FILE_INIT_FAILED => 0xC00D001F as u32,
            MEDIASERVER::NS_E_FILE_PLAY_FAILED => 0xC00D0020 as u32,
            MEDIASERVER::NS_E_SET_DISK_UID_FAILED => 0xC00D0021 as u32,
            MEDIASERVER::NS_E_INDUCED => 0xC00D0022 as u32,
            MEDIASERVER::NS_E_CCLINK_DOWN => 0xC00D0023 as u32,
            MEDIASERVER::NS_E_INTERNAL => 0xC00D0024 as u32,
            MEDIASERVER::NS_E_BUSY => 0xC00D0025 as u32,
            MEDIASERVER::NS_E_UNRECOGNIZED_STREAM_TYPE => 0xC00D0026 as u32,
            MEDIASERVER::NS_E_NETWORK_SERVICE_FAILURE => 0xC00D0027 as u32,
            MEDIASERVER::NS_E_NETWORK_RESOURCE_FAILURE => 0xC00D0028 as u32,
            MEDIASERVER::NS_E_CONNECTION_FAILURE => 0xC00D0029 as u32,
            MEDIASERVER::NS_E_SHUTDOWN => 0xC00D002A as u32,
            MEDIASERVER::NS_E_INVALID_REQUEST => 0xC00D002B as u32,
            MEDIASERVER::NS_E_INSUFFICIENT_BANDWIDTH => 0xC00D002C as u32,
            MEDIASERVER::NS_E_NOT_REBUILDING => 0xC00D002D as u32,
            MEDIASERVER::NS_E_LATE_OPERATION => 0xC00D002E as u32,
            MEDIASERVER::NS_E_INVALID_DATA => 0xC00D002F as u32,
            MEDIASERVER::NS_E_FILE_BANDWIDTH_LIMIT => 0xC00D0030 as u32,
            MEDIASERVER::NS_E_OPEN_FILE_LIMIT => 0xC00D0031 as u32,
            MEDIASERVER::NS_E_BAD_CONTROL_DATA => 0xC00D0032 as u32,
            MEDIASERVER::NS_E_NO_STREAM => 0xC00D0033 as u32,
            MEDIASERVER::NS_E_STREAM_END => 0xC00D0034 as u32,
            MEDIASERVER::NS_E_SERVER_NOT_FOUND => 0xC00D0035 as u32,
            MEDIASERVER::NS_E_DUPLICATE_NAME => 0xC00D0036 as u32,
            MEDIASERVER::NS_E_DUPLICATE_ADDRESS => 0xC00D0037 as u32,
            MEDIASERVER::NS_E_BAD_MULTICAST_ADDRESS => 0xC00D0038 as u32,
            MEDIASERVER::NS_E_BAD_ADAPTER_ADDRESS => 0xC00D0039 as u32,
            MEDIASERVER::NS_E_BAD_DELIVERY_MODE => 0xC00D003A as u32,
            MEDIASERVER::NS_E_INVALID_CHANNEL => 0xC00D003B as u32,
            MEDIASERVER::NS_E_INVALID_STREAM => 0xC00D003C as u32,
            MEDIASERVER::NS_E_INVALID_ARCHIVE => 0xC00D003D as u32,
            MEDIASERVER::NS_E_NOTITLES => 0xC00D003E as u32,
            MEDIASERVER::NS_E_INVALID_CLIENT => 0xC00D003F as u32,
            MEDIASERVER::NS_E_INVALID_BLACKHOLE_ADDRESS => 0xC00D0040 as u32,
            MEDIASERVER::NS_E_INCOMPATIBLE_FORMAT => 0xC00D0041 as u32,
            MEDIASERVER::NS_E_INVALID_KEY => 0xC00D0042 as u32,
            MEDIASERVER::NS_E_INVALID_PORT => 0xC00D0043 as u32,
            MEDIASERVER::NS_E_INVALID_TTL => 0xC00D0044 as u32,
            MEDIASERVER::NS_E_STRIDE_REFUSED => 0xC00D0045 as u32,
            MEDIASERVER::NS_E_MMSAUTOSERVER_CANTFINDWALKER => 0xC00D0046 as u32,
            MEDIASERVER::NS_E_MAX_BITRATE => 0xC00D0047 as u32,
            MEDIASERVER::NS_E_LOGFILEPERIOD => 0xC00D0048 as u32,
            MEDIASERVER::NS_E_MAX_CLIENTS => 0xC00D0049 as u32,
            MEDIASERVER::NS_E_LOG_FILE_SIZE => 0xC00D004A as u32,
            MEDIASERVER::NS_E_MAX_FILERATE => 0xC00D004B as u32,
            MEDIASERVER::NS_E_WALKER_UNKNOWN => 0xC00D004C as u32,
            MEDIASERVER::NS_E_WALKER_SERVER => 0xC00D004D as u32,
            MEDIASERVER::NS_E_WALKER_USAGE => 0xC00D004E as u32,
            MEDIASERVER::NS_E_TIGER_FAIL => 0xC00D0050 as u32,
            MEDIASERVER::NS_E_CUB_FAIL => 0xC00D0053 as u32,
            MEDIASERVER::NS_E_DISK_FAIL => 0xC00D0055 as u32,
            MEDIASERVER::NS_E_MAX_FUNNELS_ALERT => 0xC00D0060 as u32,
            MEDIASERVER::NS_E_ALLOCATE_FILE_FAIL => 0xC00D0061 as u32,
            MEDIASERVER::NS_E_PAGING_ERROR => 0xC00D0062 as u32,
            MEDIASERVER::NS_E_BAD_BLOCK0_VERSION => 0xC00D0063 as u32,
            MEDIASERVER::NS_E_BAD_DISK_UID => 0xC00D0064 as u32,
            MEDIASERVER::NS_E_BAD_FSMAJOR_VERSION => 0xC00D0065 as u32,
            MEDIASERVER::NS_E_BAD_STAMPNUMBER => 0xC00D0066 as u32,
            MEDIASERVER::NS_E_PARTIALLY_REBUILT_DISK => 0xC00D0067 as u32,
            MEDIASERVER::NS_E_ENACTPLAN_GIVEUP => 0xC00D0068 as u32,
            MEDIASERVER::MCMADM_E_REGKEY_NOT_FOUND => 0xC00D006A as u32,
            MEDIASERVER::NS_E_NO_FORMATS => 0xC00D006B as u32,
            MEDIASERVER::NS_E_NO_REFERENCES => 0xC00D006C as u32,
            MEDIASERVER::NS_E_WAVE_OPEN => 0xC00D006D as u32,
            MEDIASERVER::NS_E_CANNOTCONNECTEVENTS => 0xC00D006F as u32,
            MEDIASERVER::NS_E_NO_DEVICE => 0xC00D0071 as u32,
            MEDIASERVER::NS_E_NO_SPECIFIED_DEVICE => 0xC00D0072 as u32,
            MEDIASERVER::NS_E_MONITOR_GIVEUP => 0xC00D00C8 as u32,
            MEDIASERVER::NS_E_REMIRRORED_DISK => 0xC00D00C9 as u32,
            MEDIASERVER::NS_E_INSUFFICIENT_DATA => 0xC00D00CA as u32,
            MEDIASERVER::NS_E_ASSERT => 0xC00D00CB as u32,
            MEDIASERVER::NS_E_BAD_ADAPTER_NAME => 0xC00D00CC as u32,
            MEDIASERVER::NS_E_NOT_LICENSED => 0xC00D00CD as u32,
            MEDIASERVER::NS_E_NO_SERVER_CONTACT => 0xC00D00CE as u32,
            MEDIASERVER::NS_E_TOO_MANY_TITLES => 0xC00D00CF as u32,
            MEDIASERVER::NS_E_TITLE_SIZE_EXCEEDED => 0xC00D00D0 as u32,
            MEDIASERVER::NS_E_UDP_DISABLED => 0xC00D00D1 as u32,
            MEDIASERVER::NS_E_TCP_DISABLED => 0xC00D00D2 as u32,
            MEDIASERVER::NS_E_HTTP_DISABLED => 0xC00D00D3 as u32,
            MEDIASERVER::NS_E_LICENSE_EXPIRED => 0xC00D00D4 as u32,
            MEDIASERVER::NS_E_TITLE_BITRATE => 0xC00D00D5 as u32,
            MEDIASERVER::NS_E_EMPTY_PROGRAM_NAME => 0xC00D00D6 as u32,
            MEDIASERVER::NS_E_MISSING_CHANNEL => 0xC00D00D7 as u32,
            MEDIASERVER::NS_E_NO_CHANNELS => 0xC00D00D8 as u32,
            MEDIASERVER::NS_E_INVALID_INDEX2 => 0xC00D00D9 as u32,
            MEDIASERVER::NS_E_CUB_FAIL_LINK => 0xC00D0190 as u32,
            MEDIASERVER::NS_E_BAD_CUB_UID => 0xC00D0192 as u32,
            MEDIASERVER::NS_E_GLITCH_MODE => 0xC00D0195 as u32,
            MEDIASERVER::NS_E_NO_MEDIA_PROTOCOL => 0xC00D019B as u32,
            MEDIASERVER::ASF_E_BUFFEROVERRUN => 0xC00D07D0 as u32,
            MEDIASERVER::ASF_E_BUFFERTOOSMALL => 0xC00D07D1 as u32,
            MEDIASERVER::ASF_E_BADLANGUAGEID => 0xC00D07D2 as u32,
            MEDIASERVER::ASF_E_NOPAYLOADLENGTH => 0xC00D07DB as u32,
            MEDIASERVER::ASF_E_TOOMANYPAYLOADS => 0xC00D07DC as u32,
            MEDIASERVER::ASF_E_PACKETCONTENTTOOLARGE => 0xC00D07DE as u32,
            MEDIASERVER::ASF_E_UNKNOWNPACKETSIZE => 0xC00D07E0 as u32,
            MEDIASERVER::ASF_E_INVALIDHEADER => 0xC00D07E2 as u32,
            MEDIASERVER::ASF_E_NOCLOCKOBJECT => 0xC00D07E6 as u32,
            MEDIASERVER::ASF_E_UNKNOWNCLOCKTYPE => 0xC00D07EB as u32,
            MEDIASERVER::ASF_E_OPAQUEPACKET => 0xC00D07ED as u32,
            MEDIASERVER::ASF_E_WRONGVERSION => 0xC00D07EE as u32,
            MEDIASERVER::ASF_E_OVERFLOW => 0xC00D07EF as u32,
            MEDIASERVER::ASF_E_NOTFOUND => 0xC00D07F0 as u32,
            MEDIASERVER::NS_E_NOTHING_TO_DO => 0xC00D07F1 as u32,
            MEDIASERVER::NS_E_NO_MULTICAST => 0xC00D07F2 as u32,
            MEDIASERVER::ASF_E_OBJECTTOOBIG => 0xC00D07F3 as u32,
            MEDIASERVER::ASF_E_UNEXPECTEDVALUE => 0xC00D07F4 as u32,
            MEDIASERVER::ASF_E_INVALIDSTATE => 0xC00D07F5 as u32,
            MEDIASERVER::ASF_E_NOLIBRARY => 0xC00D07F6 as u32,
            MEDIASERVER::ASF_E_ALREADYINITIALIZED => 0xC00D07F7 as u32,
            MEDIASERVER::ASF_E_INVALIDINIT => 0xC00D07F8 as u32,
            MEDIASERVER::ASF_E_NOHEADEROBJECT => 0xC00D07F9 as u32,
            MEDIASERVER::ASF_E_NODATAOBJECT => 0xC00D07FA as u32,
            MEDIASERVER::ASF_E_NOINDEXOBJECT => 0xC00D07FB as u32,
            MEDIASERVER::ASF_E_NOSTREAMPROPS => 0xC00D07FC as u32,
            MEDIASERVER::ASF_E_NOFILEPROPS => 0xC00D07FD as u32,
            MEDIASERVER::ASF_E_INVALIDFLAGS => 0xC00D0801 as u32,
            MEDIASERVER::ASF_E_BADDATADESCRIPTOR => 0xC00D0802 as u32,
            MEDIASERVER::ASF_E_BADINDEXINTERVAL => 0xC00D0803 as u32,
            MEDIASERVER::ASF_E_INVALIDTIME => 0xC00D0804 as u32,
            MEDIASERVER::ASF_E_INVALIDINDEX => 0xC00D0805 as u32,
            MEDIASERVER::ASF_E_STREAMNUMBERINUSE => 0xC00D0806 as u32,
            MEDIASERVER::ASF_E_BADMEDIATYPE => 0xC00D0807 as u32,
            MEDIASERVER::ASF_E_WRITEFAILED => 0xC00D0808 as u32,
            MEDIASERVER::ASF_E_NOTENOUGHDESCRIPTORS => 0xC00D0809 as u32,
            MEDIASERVER::ASF_E_INDEXBLOCKUNLOADED => 0xC00D080A as u32,
            MEDIASERVER::ASF_E_NOTENOUGHBANDWIDTH => 0xC00D080B as u32,
            MEDIASERVER::ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE => 0xC00D080C as u32,
            MEDIASERVER::ASF_E_BADDATAUNIT => 0xC00D080D as u32,
            MEDIASERVER::ASF_E_HEADERSIZE => 0xC00D080E as u32,
            MEDIASERVER::NS_E_INVALID_INPUT_FORMAT => 0xC00D0BB8 as u32,
            MEDIASERVER::NS_E_MSAUDIO_NOT_INSTALLED => 0xC00D0BB9 as u32,
            MEDIASERVER::NS_E_UNEXPECTED_MSAUDIO_ERROR => 0xC00D0BBA as u32,
            MEDIASERVER::NS_E_INVALID_OUTPUT_FORMAT => 0xC00D0BBB as u32,
            MEDIASERVER::NS_E_NOT_CONFIGURED => 0xC00D0BBC as u32,
            MEDIASERVER::NS_E_PROTECTED_CONTENT => 0xC00D0BBD as u32,
            MEDIASERVER::NS_E_LICENSE_REQUIRED => 0xC00D0BBE as u32,
            MEDIASERVER::NS_E_TAMPERED_CONTENT => 0xC00D0BBF as u32,
            MEDIASERVER::NS_E_LICENSE_OUTOFDATE => 0xC00D0BC0 as u32,
            MEDIASERVER::NS_E_LICENSE_INCORRECT_RIGHTS => 0xC00D0BC1 as u32,
            MEDIASERVER::NS_E_AUDIO_CODEC_NOT_INSTALLED => 0xC00D0BC2 as u32,
            MEDIASERVER::NS_E_AUDIO_CODEC_ERROR => 0xC00D0BC3 as u32,
            MEDIASERVER::NS_E_VIDEO_CODEC_NOT_INSTALLED => 0xC00D0BC4 as u32,
            MEDIASERVER::NS_E_VIDEO_CODEC_ERROR => 0xC00D0BC5 as u32,
            MEDIASERVER::NS_E_INVALIDPROFILE => 0xC00D0BC6 as u32,
            MEDIASERVER::NS_E_INCOMPATIBLE_VERSION => 0xC00D0BC7 as u32,
            MEDIASERVER::NS_E_OFFLINE_MODE => 0xC00D0BCA as u32,
            MEDIASERVER::NS_E_NOT_CONNECTED => 0xC00D0BCB as u32,
            MEDIASERVER::NS_E_TOO_MUCH_DATA => 0xC00D0BCC as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_PROPERTY => 0xC00D0BCD as u32,
            MEDIASERVER::NS_E_8BIT_WAVE_UNSUPPORTED => 0xC00D0BCE as u32,
            MEDIASERVER::NS_E_NO_MORE_SAMPLES => 0xC00D0BCF as u32,
            MEDIASERVER::NS_E_INVALID_SAMPLING_RATE => 0xC00D0BD0 as u32,
            MEDIASERVER::NS_E_MAX_PACKET_SIZE_TOO_SMALL => 0xC00D0BD1 as u32,
            MEDIASERVER::NS_E_LATE_PACKET => 0xC00D0BD2 as u32,
            MEDIASERVER::NS_E_DUPLICATE_PACKET => 0xC00D0BD3 as u32,
            MEDIASERVER::NS_E_SDK_BUFFERTOOSMALL => 0xC00D0BD4 as u32,
            MEDIASERVER::NS_E_INVALID_NUM_PASSES => 0xC00D0BD5 as u32,
            MEDIASERVER::NS_E_ATTRIBUTE_READ_ONLY => 0xC00D0BD6 as u32,
            MEDIASERVER::NS_E_ATTRIBUTE_NOT_ALLOWED => 0xC00D0BD7 as u32,
            MEDIASERVER::NS_E_INVALID_EDL => 0xC00D0BD8 as u32,
            MEDIASERVER::NS_E_DATA_UNIT_EXTENSION_TOO_LARGE => 0xC00D0BD9 as u32,
            MEDIASERVER::NS_E_CODEC_DMO_ERROR => 0xC00D0BDA as u32,
            MEDIASERVER::NS_E_FEATURE_DISABLED_BY_GROUP_POLICY => 0xC00D0BDC as u32,
            MEDIASERVER::NS_E_FEATURE_DISABLED_IN_SKU => 0xC00D0BDD as u32,
            MEDIASERVER::NS_E_NO_CD => 0xC00D0FA0 as u32,
            MEDIASERVER::NS_E_CANT_READ_DIGITAL => 0xC00D0FA1 as u32,
            MEDIASERVER::NS_E_DEVICE_DISCONNECTED => 0xC00D0FA2 as u32,
            MEDIASERVER::NS_E_DEVICE_NOT_SUPPORT_FORMAT => 0xC00D0FA3 as u32,
            MEDIASERVER::NS_E_SLOW_READ_DIGITAL => 0xC00D0FA4 as u32,
            MEDIASERVER::NS_E_MIXER_INVALID_LINE => 0xC00D0FA5 as u32,
            MEDIASERVER::NS_E_MIXER_INVALID_CONTROL => 0xC00D0FA6 as u32,
            MEDIASERVER::NS_E_MIXER_INVALID_VALUE => 0xC00D0FA7 as u32,
            MEDIASERVER::NS_E_MIXER_UNKNOWN_MMRESULT => 0xC00D0FA8 as u32,
            MEDIASERVER::NS_E_USER_STOP => 0xC00D0FA9 as u32,
            MEDIASERVER::NS_E_MP3_FORMAT_NOT_FOUND => 0xC00D0FAA as u32,
            MEDIASERVER::NS_E_CD_READ_ERROR_NO_CORRECTION => 0xC00D0FAB as u32,
            MEDIASERVER::NS_E_CD_READ_ERROR => 0xC00D0FAC as u32,
            MEDIASERVER::NS_E_CD_SLOW_COPY => 0xC00D0FAD as u32,
            MEDIASERVER::NS_E_CD_COPYTO_CD => 0xC00D0FAE as u32,
            MEDIASERVER::NS_E_MIXER_NODRIVER => 0xC00D0FAF as u32,
            MEDIASERVER::NS_E_REDBOOK_ENABLED_WHILE_COPYING => 0xC00D0FB0 as u32,
            MEDIASERVER::NS_E_CD_REFRESH => 0xC00D0FB1 as u32,
            MEDIASERVER::NS_E_CD_DRIVER_PROBLEM => 0xC00D0FB2 as u32,
            MEDIASERVER::NS_E_WONT_DO_DIGITAL => 0xC00D0FB3 as u32,
            MEDIASERVER::NS_E_WMPXML_NOERROR => 0xC00D0FB4 as u32,
            MEDIASERVER::NS_E_WMPXML_ENDOFDATA => 0xC00D0FB5 as u32,
            MEDIASERVER::NS_E_WMPXML_PARSEERROR => 0xC00D0FB6 as u32,
            MEDIASERVER::NS_E_WMPXML_ATTRIBUTENOTFOUND => 0xC00D0FB7 as u32,
            MEDIASERVER::NS_E_WMPXML_PINOTFOUND => 0xC00D0FB8 as u32,
            MEDIASERVER::NS_E_WMPXML_EMPTYDOC => 0xC00D0FB9 as u32,
            MEDIASERVER::NS_E_WMP_PATH_ALREADY_IN_LIBRARY => 0xC00D0FBA as u32,
            MEDIASERVER::NS_E_WMP_FILESCANALREADYSTARTED => 0xC00D0FBE as u32,
            MEDIASERVER::NS_E_WMP_HME_INVALIDOBJECTID => 0xC00D0FBF as u32,
            MEDIASERVER::NS_E_WMP_MF_CODE_EXPIRED => 0xC00D0FC0 as u32,
            MEDIASERVER::NS_E_WMP_HME_NOTSEARCHABLEFORITEMS => 0xC00D0FC1 as u32,
            MEDIASERVER::NS_E_WMP_ADDTOLIBRARY_FAILED => 0xC00D0FC7 as u32,
            MEDIASERVER::NS_E_WMP_WINDOWSAPIFAILURE => 0xC00D0FC8 as u32,
            MEDIASERVER::NS_E_WMP_RECORDING_NOT_ALLOWED => 0xC00D0FC9 as u32,
            MEDIASERVER::NS_E_DEVICE_NOT_READY => 0xC00D0FCA as u32,
            MEDIASERVER::NS_E_DAMAGED_FILE => 0xC00D0FCB as u32,
            MEDIASERVER::NS_E_MPDB_GENERIC => 0xC00D0FCC as u32,
            MEDIASERVER::NS_E_FILE_FAILED_CHECKS => 0xC00D0FCD as u32,
            MEDIASERVER::NS_E_MEDIA_LIBRARY_FAILED => 0xC00D0FCE as u32,
            MEDIASERVER::NS_E_SHARING_VIOLATION => 0xC00D0FCF as u32,
            MEDIASERVER::NS_E_NO_ERROR_STRING_FOUND => 0xC00D0FD0 as u32,
            MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_CORE => 0xC00D0FD1 as u32,
            MEDIASERVER::NS_E_WMPOCX_NO_ACTIVE_CORE => 0xC00D0FD2 as u32,
            MEDIASERVER::NS_E_WMPOCX_NOT_RUNNING_REMOTELY => 0xC00D0FD3 as u32,
            MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_WINDOW => 0xC00D0FD4 as u32,
            MEDIASERVER::NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE => 0xC00D0FD5 as u32,
            MEDIASERVER::NS_E_PLUGIN_NOTSHUTDOWN => 0xC00D0FD6 as u32,
            MEDIASERVER::NS_E_WMP_CANNOT_FIND_FOLDER => 0xC00D0FD7 as u32,
            MEDIASERVER::NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED => 0xC00D0FD8 as u32,
            MEDIASERVER::NS_E_WMP_PLUGINDLL_NOTFOUND => 0xC00D0FD9 as u32,
            MEDIASERVER::NS_E_NEED_TO_ASK_USER => 0xC00D0FDA as u32,
            MEDIASERVER::NS_E_WMPOCX_PLAYER_NOT_DOCKED => 0xC00D0FDB as u32,
            MEDIASERVER::NS_E_WMP_EXTERNAL_NOTREADY => 0xC00D0FDC as u32,
            MEDIASERVER::NS_E_WMP_MLS_STALE_DATA => 0xC00D0FDD as u32,
            MEDIASERVER::NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED => 0xC00D0FDE as u32,
            MEDIASERVER::NS_E_WMP_UI_VERSIONMISMATCH => 0xC00D0FDF as u32,
            MEDIASERVER::NS_E_WMP_UI_NOTATHEMEFILE => 0xC00D0FE0 as u32,
            MEDIASERVER::NS_E_WMP_UI_SUBELEMENTNOTFOUND => 0xC00D0FE1 as u32,
            MEDIASERVER::NS_E_WMP_UI_VERSIONPARSE => 0xC00D0FE2 as u32,
            MEDIASERVER::NS_E_WMP_UI_VIEWIDNOTFOUND => 0xC00D0FE3 as u32,
            MEDIASERVER::NS_E_WMP_UI_PASSTHROUGH => 0xC00D0FE4 as u32,
            MEDIASERVER::NS_E_WMP_UI_OBJECTNOTFOUND => 0xC00D0FE5 as u32,
            MEDIASERVER::NS_E_WMP_UI_SECONDHANDLER => 0xC00D0FE6 as u32,
            MEDIASERVER::NS_E_WMP_UI_NOSKININZIP => 0xC00D0FE7 as u32,
            MEDIASERVER::NS_E_WMP_URLDOWNLOADFAILED => 0xC00D0FEA as u32,
            MEDIASERVER::NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN => 0xC00D0FEB as u32,
            MEDIASERVER::NS_E_WMP_INVALID_SKIN => 0xC00D0FEC as u32,
            MEDIASERVER::NS_E_WMP_SENDMAILFAILED => 0xC00D0FED as u32,
            MEDIASERVER::NS_E_WMP_LOCKEDINSKINMODE => 0xC00D0FEE as u32,
            MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_FILE => 0xC00D0FEF as u32,
            MEDIASERVER::NS_E_WMP_SAVEAS_READONLY => 0xC00D0FF0 as u32,
            MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_PLAYLIST => 0xC00D0FF1 as u32,
            MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_WMD => 0xC00D0FF2 as u32,
            MEDIASERVER::NS_E_WMP_CANT_PLAY_PROTECTED => 0xC00D0FF3 as u32,
            MEDIASERVER::NS_E_SHARING_STATE_OUT_OF_SYNC => 0xC00D0FF4 as u32,
            MEDIASERVER::NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING => 0xC00D0FFA as u32,
            MEDIASERVER::NS_E_WMP_RBC_JPGMAPPINGIMAGE => 0xC00D1004 as u32,
            MEDIASERVER::NS_E_WMP_JPGTRANSPARENCY => 0xC00D1005 as u32,
            MEDIASERVER::NS_E_WMP_INVALID_MAX_VAL => 0xC00D1009 as u32,
            MEDIASERVER::NS_E_WMP_INVALID_MIN_VAL => 0xC00D100A as u32,
            MEDIASERVER::NS_E_WMP_CS_JPGPOSITIONIMAGE => 0xC00D100E as u32,
            MEDIASERVER::NS_E_WMP_CS_NOTEVENLYDIVISIBLE => 0xC00D100F as u32,
            MEDIASERVER::NS_E_WMPZIP_NOTAZIPFILE => 0xC00D1018 as u32,
            MEDIASERVER::NS_E_WMPZIP_CORRUPT => 0xC00D1019 as u32,
            MEDIASERVER::NS_E_WMPZIP_FILENOTFOUND => 0xC00D101A as u32,
            MEDIASERVER::NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED => 0xC00D1022 as u32,
            MEDIASERVER::NS_E_WMP_IMAGE_INVALID_FORMAT => 0xC00D1023 as u32,
            MEDIASERVER::NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE => 0xC00D1024 as u32,
            MEDIASERVER::NS_E_WMP_GIF_INVALID_FORMAT => 0xC00D1025 as u32,
            MEDIASERVER::NS_E_WMP_GIF_BAD_VERSION_NUMBER => 0xC00D1026 as u32,
            MEDIASERVER::NS_E_WMP_GIF_NO_IMAGE_IN_FILE => 0xC00D1027 as u32,
            MEDIASERVER::NS_E_WMP_PNG_INVALIDFORMAT => 0xC00D1028 as u32,
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH => 0xC00D1029 as u32,
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION => 0xC00D102A as u32,
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_FILTER => 0xC00D102B as u32,
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_INTERLACE => 0xC00D102C as u32,
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC => 0xC00D102D as u32,
            MEDIASERVER::NS_E_WMP_BMP_INVALID_BITMASK => 0xC00D102E as u32,
            MEDIASERVER::NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED => 0xC00D102F as u32,
            MEDIASERVER::NS_E_WMP_BMP_BITMAP_NOT_CREATED => 0xC00D1030 as u32,
            MEDIASERVER::NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED => 0xC00D1031 as u32,
            MEDIASERVER::NS_E_WMP_BMP_INVALID_FORMAT => 0xC00D1032 as u32,
            MEDIASERVER::NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL => 0xC00D1033 as u32,
            MEDIASERVER::NS_E_WMP_JPG_INVALID_FORMAT => 0xC00D1034 as u32,
            MEDIASERVER::NS_E_WMP_JPG_BAD_DCTSIZE => 0xC00D1035 as u32,
            MEDIASERVER::NS_E_WMP_JPG_BAD_VERSION_NUMBER => 0xC00D1036 as u32,
            MEDIASERVER::NS_E_WMP_JPG_BAD_PRECISION => 0xC00D1037 as u32,
            MEDIASERVER::NS_E_WMP_JPG_CCIR601_NOTIMPL => 0xC00D1038 as u32,
            MEDIASERVER::NS_E_WMP_JPG_NO_IMAGE_IN_FILE => 0xC00D1039 as u32,
            MEDIASERVER::NS_E_WMP_JPG_READ_ERROR => 0xC00D103A as u32,
            MEDIASERVER::NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL => 0xC00D103B as u32,
            MEDIASERVER::NS_E_WMP_JPG_IMAGE_TOO_BIG => 0xC00D103C as u32,
            MEDIASERVER::NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE => 0xC00D103D as u32,
            MEDIASERVER::NS_E_WMP_JPG_SOF_UNSUPPORTED => 0xC00D103E as u32,
            MEDIASERVER::NS_E_WMP_JPG_UNKNOWN_MARKER => 0xC00D103F as u32,
            MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_IMAGE => 0xC00D1044 as u32,
            MEDIASERVER::NS_E_WMP_DAI_SONGTOOSHORT => 0xC00D1049 as u32,
            MEDIASERVER::NS_E_WMG_RATEUNAVAILABLE => 0xC00D104A as u32,
            MEDIASERVER::NS_E_WMG_PLUGINUNAVAILABLE => 0xC00D104B as u32,
            MEDIASERVER::NS_E_WMG_CANNOTQUEUE => 0xC00D104C as u32,
            MEDIASERVER::NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED => 0xC00D104D as u32,
            MEDIASERVER::NS_E_WMG_UNEXPECTEDPREROLLSTATUS => 0xC00D104E as u32,
            MEDIASERVER::NS_E_WMG_INVALID_COPP_CERTIFICATE => 0xC00D1051 as u32,
            MEDIASERVER::NS_E_WMG_COPP_SECURITY_INVALID => 0xC00D1052 as u32,
            MEDIASERVER::NS_E_WMG_COPP_UNSUPPORTED => 0xC00D1053 as u32,
            MEDIASERVER::NS_E_WMG_INVALIDSTATE => 0xC00D1054 as u32,
            MEDIASERVER::NS_E_WMG_SINKALREADYEXISTS => 0xC00D1055 as u32,
            MEDIASERVER::NS_E_WMG_NOSDKINTERFACE => 0xC00D1056 as u32,
            MEDIASERVER::NS_E_WMG_NOTALLOUTPUTSRENDERED => 0xC00D1057 as u32,
            MEDIASERVER::NS_E_WMG_FILETRANSFERNOTALLOWED => 0xC00D1058 as u32,
            MEDIASERVER::NS_E_WMR_UNSUPPORTEDSTREAM => 0xC00D1059 as u32,
            MEDIASERVER::NS_E_WMR_PINNOTFOUND => 0xC00D105A as u32,
            MEDIASERVER::NS_E_WMR_WAITINGONFORMATSWITCH => 0xC00D105B as u32,
            MEDIASERVER::NS_E_WMR_NOSOURCEFILTER => 0xC00D105C as u32,
            MEDIASERVER::NS_E_WMR_PINTYPENOMATCH => 0xC00D105D as u32,
            MEDIASERVER::NS_E_WMR_NOCALLBACKAVAILABLE => 0xC00D105E as u32,
            MEDIASERVER::NS_E_WMR_SAMPLEPROPERTYNOTSET => 0xC00D1062 as u32,
            MEDIASERVER::NS_E_WMR_CANNOT_RENDER_BINARY_STREAM => 0xC00D1063 as u32,
            MEDIASERVER::NS_E_WMG_LICENSE_TAMPERED => 0xC00D1064 as u32,
            MEDIASERVER::NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM => 0xC00D1065 as u32,
            MEDIASERVER::NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT => 0xC00D1068 as u32,
            MEDIASERVER::NS_E_ASX_INVALIDFORMAT => 0xC00D1069 as u32,
            MEDIASERVER::NS_E_ASX_INVALIDVERSION => 0xC00D106A as u32,
            MEDIASERVER::NS_E_ASX_INVALID_REPEAT_BLOCK => 0xC00D106B as u32,
            MEDIASERVER::NS_E_ASX_NOTHING_TO_WRITE => 0xC00D106C as u32,
            MEDIASERVER::NS_E_URLLIST_INVALIDFORMAT => 0xC00D106D as u32,
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST => 0xC00D106E as u32,
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS => 0xC00D106F as u32,
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE => 0xC00D1070 as u32,
            MEDIASERVER::NS_E_WMX_ITEM_DOES_NOT_EXIST => 0xC00D1071 as u32,
            MEDIASERVER::NS_E_WMX_ITEM_TYPE_ILLEGAL => 0xC00D1072 as u32,
            MEDIASERVER::NS_E_WMX_ITEM_UNSETTABLE => 0xC00D1073 as u32,
            MEDIASERVER::NS_E_WMX_PLAYLIST_EMPTY => 0xC00D1074 as u32,
            MEDIASERVER::NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED => 0xC00D1075 as u32,
            MEDIASERVER::NS_E_WMX_INVALID_FORMAT_OVER_NESTING => 0xC00D1076 as u32,
            MEDIASERVER::NS_E_WMPCORE_NOSOURCEURLSTRING => 0xC00D107C as u32,
            MEDIASERVER::NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT => 0xC00D107D as u32,
            MEDIASERVER::NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE => 0xC00D107E as u32,
            MEDIASERVER::NS_E_WMPCORE_BUFFERTOOSMALL => 0xC00D107F as u32,
            MEDIASERVER::NS_E_WMPCORE_UNAVAILABLE => 0xC00D1080 as u32,
            MEDIASERVER::NS_E_WMPCORE_INVALIDPLAYLISTMODE => 0xC00D1081 as u32,
            MEDIASERVER::NS_E_WMPCORE_ITEMNOTINPLAYLIST => 0xC00D1086 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLISTEMPTY => 0xC00D1087 as u32,
            MEDIASERVER::NS_E_WMPCORE_NOBROWSER => 0xC00D1088 as u32,
            MEDIASERVER::NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL => 0xC00D1089 as u32,
            MEDIASERVER::NS_E_WMPCORE_GRAPH_NOT_IN_LIST => 0xC00D108A as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA => 0xC00D108B as u32,
            MEDIASERVER::NS_E_WMPCORE_ERRORSINKNOTREGISTERED => 0xC00D108C as u32,
            MEDIASERVER::NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE => 0xC00D108D as u32,
            MEDIASERVER::NS_E_WMPCORE_WEBHELPFAILED => 0xC00D108E as u32,
            MEDIASERVER::NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED => 0xC00D108F as u32,
            MEDIASERVER::NS_E_WMPCORE_NO_REF_IN_ENTRY => 0xC00D1090 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY => 0xC00D1091 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL => 0xC00D1092 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY => 0xC00D1093 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL => 0xC00D1094 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY => 0xC00D1095 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL => 0xC00D1096 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY => 0xC00D1097 as u32,
            MEDIASERVER::NS_E_WMPCORE_LIST_ENTRY_NO_REF => 0xC00D1098 as u32,
            MEDIASERVER::NS_E_WMPCORE_MISNAMED_FILE => 0xC00D1099 as u32,
            MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_TRUSTED => 0xC00D109A as u32,
            MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_FOUND => 0xC00D109B as u32,
            MEDIASERVER::NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED => 0xC00D109C as u32,
            MEDIASERVER::NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST => 0xC00D109D as u32,
            MEDIASERVER::NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST => 0xC00D109E as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE => 0xC00D109F as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED => 0xC00D10A0 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND => 0xC00D10A1 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED => 0xC00D10A2 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED => 0xC00D10A3 as u32,
            MEDIASERVER::NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY => 0xC00D10A4 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME => 0xC00D10A5 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT => 0xC00D10A6 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY => 0xC00D10A7 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_STACK_EMPTY => 0xC00D10A8 as u32,
            MEDIASERVER::NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE => 0xC00D10A9 as u32,
            MEDIASERVER::NS_E_WMPCORE_USER_CANCEL => 0xC00D10AB as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY => 0xC00D10AC as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE => 0xC00D10AD as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE => 0xC00D10AE as u32,
            MEDIASERVER::NS_E_WMPCORE_INVALID_PLAYLIST_URL => 0xC00D10AF as u32,
            MEDIASERVER::NS_E_WMPCORE_MISMATCHED_RUNTIME => 0xC00D10B0 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS => 0xC00D10B1 as u32,
            MEDIASERVER::NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION => 0xC00D10B2 as u32,
            MEDIASERVER::NS_E_WMPCORE_MEDIA_UNAVAILABLE => 0xC00D10B3 as u32,
            MEDIASERVER::NS_E_WMPCORE_WMX_ENTRYREF_NO_REF => 0xC00D10B4 as u32,
            MEDIASERVER::NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST => 0xC00D10B5 as u32,
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS => 0xC00D10B6 as u32,
            MEDIASERVER::NS_E_WMPCORE_BUSY => 0xC00D10B7 as u32,
            MEDIASERVER::NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE => 0xC00D10B8 as u32,
            MEDIASERVER::NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST => 0xC00D10B9 as u32,
            MEDIASERVER::NS_E_WMPCORE_FILE_NOT_FOUND => 0xC00D10BA as u32,
            MEDIASERVER::NS_E_WMPCORE_TEMP_FILE_NOT_FOUND => 0xC00D10BB as u32,
            MEDIASERVER::NS_E_WMDM_REVOKED => 0xC00D10BC as u32,
            MEDIASERVER::NS_E_DDRAW_GENERIC => 0xC00D10BD as u32,
            MEDIASERVER::NS_E_DISPLAY_MODE_CHANGE_FAILED => 0xC00D10BE as u32,
            MEDIASERVER::NS_E_PLAYLIST_CONTAINS_ERRORS => 0xC00D10BF as u32,
            MEDIASERVER::NS_E_CHANGING_PROXY_NAME => 0xC00D10C0 as u32,
            MEDIASERVER::NS_E_CHANGING_PROXY_PORT => 0xC00D10C1 as u32,
            MEDIASERVER::NS_E_CHANGING_PROXY_EXCEPTIONLIST => 0xC00D10C2 as u32,
            MEDIASERVER::NS_E_CHANGING_PROXYBYPASS => 0xC00D10C3 as u32,
            MEDIASERVER::NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND => 0xC00D10C4 as u32,
            MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGE => 0xC00D10C5 as u32,
            MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGESELECTED => 0xC00D10C6 as u32,
            MEDIASERVER::NS_E_CORECD_NOTAMEDIACD => 0xC00D10C7 as u32,
            MEDIASERVER::NS_E_WMPCORE_MEDIA_URL_TOO_LONG => 0xC00D10C8 as u32,
            MEDIASERVER::NS_E_WMPFLASH_CANT_FIND_COM_SERVER => 0xC00D10C9 as u32,
            MEDIASERVER::NS_E_WMPFLASH_INCOMPATIBLEVERSION => 0xC00D10CA as u32,
            MEDIASERVER::NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS => 0xC00D10CB as u32,
            MEDIASERVER::NS_E_NEED_CORE_REFERENCE => 0xC00D10CC as u32,
            MEDIASERVER::NS_E_MEDIACD_READ_ERROR => 0xC00D10CD as u32,
            MEDIASERVER::NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS => 0xC00D10CE as u32,
            MEDIASERVER::NS_E_FLASH_PLAYBACK_NOT_ALLOWED => 0xC00D10CF as u32,
            MEDIASERVER::NS_E_UNABLE_TO_CREATE_RIP_LOCATION => 0xC00D10D0 as u32,
            MEDIASERVER::NS_E_WMPCORE_SOME_CODECS_MISSING => 0xC00D10D1 as u32,
            MEDIASERVER::NS_E_WMP_RIP_FAILED => 0xC00D10D2 as u32,
            MEDIASERVER::NS_E_WMP_FAILED_TO_RIP_TRACK => 0xC00D10D3 as u32,
            MEDIASERVER::NS_E_WMP_ERASE_FAILED => 0xC00D10D4 as u32,
            MEDIASERVER::NS_E_WMP_FORMAT_FAILED => 0xC00D10D5 as u32,
            MEDIASERVER::NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE => 0xC00D10D6 as u32,
            MEDIASERVER::NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD => 0xC00D10D7 as u32,
            MEDIASERVER::NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD => 0xC00D10D8 as u32,
            MEDIASERVER::NS_E_WMP_FILE_NO_DURATION => 0xC00D10D9 as u32,
            MEDIASERVER::NS_E_PDA_FAILED_TO_BURN => 0xC00D10DA as u32,
            MEDIASERVER::NS_E_FAILED_DOWNLOAD_ABORT_BURN => 0xC00D10DC as u32,
            MEDIASERVER::NS_E_WMPCORE_DEVICE_DRIVERS_MISSING => 0xC00D10DD as u32,
            MEDIASERVER::NS_E_WMPIM_USEROFFLINE => 0xC00D1126 as u32,
            MEDIASERVER::NS_E_WMPIM_USERCANCELED => 0xC00D1127 as u32,
            MEDIASERVER::NS_E_WMPIM_DIALUPFAILED => 0xC00D1128 as u32,
            MEDIASERVER::NS_E_WINSOCK_ERROR_STRING => 0xC00D1129 as u32,
            MEDIASERVER::NS_E_WMPBR_NOLISTENER => 0xC00D1130 as u32,
            MEDIASERVER::NS_E_WMPBR_BACKUPCANCEL => 0xC00D1131 as u32,
            MEDIASERVER::NS_E_WMPBR_RESTORECANCEL => 0xC00D1132 as u32,
            MEDIASERVER::NS_E_WMPBR_ERRORWITHURL => 0xC00D1133 as u32,
            MEDIASERVER::NS_E_WMPBR_NAMECOLLISION => 0xC00D1134 as u32,
            MEDIASERVER::NS_E_WMPBR_DRIVE_INVALID => 0xC00D1137 as u32,
            MEDIASERVER::NS_E_WMPBR_BACKUPRESTOREFAILED => 0xC00D1138 as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_FILE_FAILED => 0xC00D1158 as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL => 0xC00D1159 as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL => 0xC00D115A as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_FILE_CORRUPT => 0xC00D115B as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL => 0xC00D115C as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL => 0xC00D115D as u32,
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER => 0xC00D115E as u32,
            MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS => 0xC00D1160 as u32,
            MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED => 0xC00D1161 as u32,
            MEDIASERVER::NS_E_DVD_NO_SUBPICTURE_STREAM => 0xC00D1162 as u32,
            MEDIASERVER::NS_E_DVD_COPY_PROTECT => 0xC00D1163 as u32,
            MEDIASERVER::NS_E_DVD_AUTHORING_PROBLEM => 0xC00D1164 as u32,
            MEDIASERVER::NS_E_DVD_INVALID_DISC_REGION => 0xC00D1165 as u32,
            MEDIASERVER::NS_E_DVD_COMPATIBLE_VIDEO_CARD => 0xC00D1166 as u32,
            MEDIASERVER::NS_E_DVD_MACROVISION => 0xC00D1167 as u32,
            MEDIASERVER::NS_E_DVD_SYSTEM_DECODER_REGION => 0xC00D1168 as u32,
            MEDIASERVER::NS_E_DVD_DISC_DECODER_REGION => 0xC00D1169 as u32,
            MEDIASERVER::NS_E_DVD_NO_VIDEO_STREAM => 0xC00D116A as u32,
            MEDIASERVER::NS_E_DVD_NO_AUDIO_STREAM => 0xC00D116B as u32,
            MEDIASERVER::NS_E_DVD_GRAPH_BUILDING => 0xC00D116C as u32,
            MEDIASERVER::NS_E_DVD_NO_DECODER => 0xC00D116D as u32,
            MEDIASERVER::NS_E_DVD_PARENTAL => 0xC00D116E as u32,
            MEDIASERVER::NS_E_DVD_CANNOT_JUMP => 0xC00D116F as u32,
            MEDIASERVER::NS_E_DVD_DEVICE_CONTENTION => 0xC00D1170 as u32,
            MEDIASERVER::NS_E_DVD_NO_VIDEO_MEMORY => 0xC00D1171 as u32,
            MEDIASERVER::NS_E_DVD_CANNOT_COPY_PROTECTED => 0xC00D1172 as u32,
            MEDIASERVER::NS_E_DVD_REQUIRED_PROPERTY_NOT_SET => 0xC00D1173 as u32,
            MEDIASERVER::NS_E_DVD_INVALID_TITLE_CHAPTER => 0xC00D1174 as u32,
            MEDIASERVER::NS_E_NO_CD_BURNER => 0xC00D1176 as u32,
            MEDIASERVER::NS_E_DEVICE_IS_NOT_READY => 0xC00D1177 as u32,
            MEDIASERVER::NS_E_PDA_UNSUPPORTED_FORMAT => 0xC00D1178 as u32,
            MEDIASERVER::NS_E_NO_PDA => 0xC00D1179 as u32,
            MEDIASERVER::NS_E_PDA_UNSPECIFIED_ERROR => 0xC00D117A as u32,
            MEDIASERVER::NS_E_MEMSTORAGE_BAD_DATA => 0xC00D117B as u32,
            MEDIASERVER::NS_E_PDA_FAIL_SELECT_DEVICE => 0xC00D117C as u32,
            MEDIASERVER::NS_E_PDA_FAIL_READ_WAVE_FILE => 0xC00D117D as u32,
            MEDIASERVER::NS_E_IMAPI_LOSSOFSTREAMING => 0xC00D117E as u32,
            MEDIASERVER::NS_E_PDA_DEVICE_FULL => 0xC00D117F as u32,
            MEDIASERVER::NS_E_FAIL_LAUNCH_ROXIO_PLUGIN => 0xC00D1180 as u32,
            MEDIASERVER::NS_E_PDA_DEVICE_FULL_IN_SESSION => 0xC00D1181 as u32,
            MEDIASERVER::NS_E_IMAPI_MEDIUM_INVALIDTYPE => 0xC00D1182 as u32,
            MEDIASERVER::NS_E_PDA_MANUALDEVICE => 0xC00D1183 as u32,
            MEDIASERVER::NS_E_PDA_PARTNERSHIPNOTEXIST => 0xC00D1184 as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP => 0xC00D1185 as u32,
            MEDIASERVER::NS_E_PDA_NO_TRANSCODE_OF_DRM => 0xC00D1186 as u32,
            MEDIASERVER::NS_E_PDA_TRANSCODECACHEFULL => 0xC00D1187 as u32,
            MEDIASERVER::NS_E_PDA_TOO_MANY_FILE_COLLISIONS => 0xC00D1188 as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE => 0xC00D1189 as u32,
            MEDIASERVER::NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY => 0xC00D118A as u32,
            MEDIASERVER::NS_E_PROCESSINGSHOWSYNCWIZARD => 0xC00D118B as u32,
            MEDIASERVER::NS_E_PDA_TRANSCODE_NOT_PERMITTED => 0xC00D118C as u32,
            MEDIASERVER::NS_E_PDA_INITIALIZINGDEVICES => 0xC00D118D as u32,
            MEDIASERVER::NS_E_PDA_OBSOLETE_SP => 0xC00D118E as u32,
            MEDIASERVER::NS_E_PDA_TITLE_COLLISION => 0xC00D118F as u32,
            MEDIASERVER::NS_E_PDA_DEVICESUPPORTDISABLED => 0xC00D1190 as u32,
            MEDIASERVER::NS_E_PDA_NO_LONGER_AVAILABLE => 0xC00D1191 as u32,
            MEDIASERVER::NS_E_PDA_ENCODER_NOT_RESPONDING => 0xC00D1192 as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_LOCATION => 0xC00D1193 as u32,
            MEDIASERVER::NS_E_WMP_PROTOCOL_PROBLEM => 0xC00D1194 as u32,
            MEDIASERVER::NS_E_WMP_NO_DISK_SPACE => 0xC00D1195 as u32,
            MEDIASERVER::NS_E_WMP_LOGON_FAILURE => 0xC00D1196 as u32,
            MEDIASERVER::NS_E_WMP_CANNOT_FIND_FILE => 0xC00D1197 as u32,
            MEDIASERVER::NS_E_WMP_SERVER_INACCESSIBLE => 0xC00D1198 as u32,
            MEDIASERVER::NS_E_WMP_UNSUPPORTED_FORMAT => 0xC00D1199 as u32,
            MEDIASERVER::NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT => 0xC00D119A as u32,
            MEDIASERVER::NS_E_WMP_PLAYLIST_EXISTS => 0xC00D119B as u32,
            MEDIASERVER::NS_E_WMP_NONMEDIA_FILES => 0xC00D119C as u32,
            MEDIASERVER::NS_E_WMP_INVALID_ASX => 0xC00D119D as u32,
            MEDIASERVER::NS_E_WMP_ALREADY_IN_USE => 0xC00D119E as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_FAILURE => 0xC00D119F as u32,
            MEDIASERVER::NS_E_WMP_WMDM_FAILURE => 0xC00D11A0 as u32,
            MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_4CC => 0xC00D11A1 as u32,
            MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG => 0xC00D11A2 as u32,
            MEDIASERVER::NS_E_WMP_MSSAP_NOT_AVAILABLE => 0xC00D11A3 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_INTERFACEDEAD => 0xC00D11A4 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_NOTCERTIFIED => 0xC00D11A5 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_LICENSE_NOTEXIST => 0xC00D11A6 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_LICENSE_EXPIRED => 0xC00D11A7 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_BUSY => 0xC00D11A8 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_NORIGHTS => 0xC00D11A9 as u32,
            MEDIASERVER::NS_E_WMP_WMDM_INCORRECT_RIGHTS => 0xC00D11AA as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_GENERIC => 0xC00D11AB as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_NOTPRESENT => 0xC00D11AD as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_BUSY => 0xC00D11AE as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_LOSS_OF_STREAMING => 0xC00D11AF as u32,
            MEDIASERVER::NS_E_WMP_SERVER_UNAVAILABLE => 0xC00D11B0 as u32,
            MEDIASERVER::NS_E_WMP_FILE_OPEN_FAILED => 0xC00D11B1 as u32,
            MEDIASERVER::NS_E_WMP_VERIFY_ONLINE => 0xC00D11B2 as u32,
            MEDIASERVER::NS_E_WMP_SERVER_NOT_RESPONDING => 0xC00D11B3 as u32,
            MEDIASERVER::NS_E_WMP_DRM_CORRUPT_BACKUP => 0xC00D11B4 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE => 0xC00D11B5 as u32,
            MEDIASERVER::NS_E_WMP_NETWORK_FIREWALL => 0xC00D11B6 as u32,
            MEDIASERVER::NS_E_WMP_NO_REMOVABLE_MEDIA => 0xC00D11B7 as u32,
            MEDIASERVER::NS_E_WMP_PROXY_CONNECT_TIMEOUT => 0xC00D11B8 as u32,
            MEDIASERVER::NS_E_WMP_NEED_UPGRADE => 0xC00D11B9 as u32,
            MEDIASERVER::NS_E_WMP_AUDIO_HW_PROBLEM => 0xC00D11BA as u32,
            MEDIASERVER::NS_E_WMP_INVALID_PROTOCOL => 0xC00D11BB as u32,
            MEDIASERVER::NS_E_WMP_INVALID_LIBRARY_ADD => 0xC00D11BC as u32,
            MEDIASERVER::NS_E_WMP_MMS_NOT_SUPPORTED => 0xC00D11BD as u32,
            MEDIASERVER::NS_E_WMP_NO_PROTOCOLS_SELECTED => 0xC00D11BE as u32,
            MEDIASERVER::NS_E_WMP_GOFULLSCREEN_FAILED => 0xC00D11BF as u32,
            MEDIASERVER::NS_E_WMP_NETWORK_ERROR => 0xC00D11C0 as u32,
            MEDIASERVER::NS_E_WMP_CONNECT_TIMEOUT => 0xC00D11C1 as u32,
            MEDIASERVER::NS_E_WMP_MULTICAST_DISABLED => 0xC00D11C2 as u32,
            MEDIASERVER::NS_E_WMP_SERVER_DNS_TIMEOUT => 0xC00D11C3 as u32,
            MEDIASERVER::NS_E_WMP_PROXY_NOT_FOUND => 0xC00D11C4 as u32,
            MEDIASERVER::NS_E_WMP_TAMPERED_CONTENT => 0xC00D11C5 as u32,
            MEDIASERVER::NS_E_WMP_OUTOFMEMORY => 0xC00D11C6 as u32,
            MEDIASERVER::NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED => 0xC00D11C7 as u32,
            MEDIASERVER::NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED => 0xC00D11C8 as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE => 0xC00D11C9 as u32,
            MEDIASERVER::NS_E_WMP_DRM_DRIVER_AUTH_FAILURE => 0xC00D11CA as u32,
            MEDIASERVER::NS_E_WMP_NETWORK_RESOURCE_FAILURE => 0xC00D11CB as u32,
            MEDIASERVER::NS_E_WMP_UPGRADE_APPLICATION => 0xC00D11CC as u32,
            MEDIASERVER::NS_E_WMP_UNKNOWN_ERROR => 0xC00D11CD as u32,
            MEDIASERVER::NS_E_WMP_INVALID_KEY => 0xC00D11CE as u32,
            MEDIASERVER::NS_E_WMP_CD_ANOTHER_USER => 0xC00D11CF as u32,
            MEDIASERVER::NS_E_WMP_DRM_NEEDS_AUTHORIZATION => 0xC00D11D0 as u32,
            MEDIASERVER::NS_E_WMP_BAD_DRIVER => 0xC00D11D1 as u32,
            MEDIASERVER::NS_E_WMP_ACCESS_DENIED => 0xC00D11D2 as u32,
            MEDIASERVER::NS_E_WMP_LICENSE_RESTRICTS => 0xC00D11D3 as u32,
            MEDIASERVER::NS_E_WMP_INVALID_REQUEST => 0xC00D11D4 as u32,
            MEDIASERVER::NS_E_WMP_CD_STASH_NO_SPACE => 0xC00D11D5 as u32,
            MEDIASERVER::NS_E_WMP_DRM_NEW_HARDWARE => 0xC00D11D6 as u32,
            MEDIASERVER::NS_E_WMP_DRM_INVALID_SIG => 0xC00D11D7 as u32,
            MEDIASERVER::NS_E_WMP_DRM_CANNOT_RESTORE => 0xC00D11D8 as u32,
            MEDIASERVER::NS_E_WMP_BURN_DISC_OVERFLOW => 0xC00D11D9 as u32,
            MEDIASERVER::NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE => 0xC00D11DA as u32,
            MEDIASERVER::NS_E_WMP_DRM_NO_SECURE_CLOCK => 0xC00D11DB as u32,
            MEDIASERVER::NS_E_WMP_DRM_NO_RIGHTS => 0xC00D11DC as u32,
            MEDIASERVER::NS_E_WMP_DRM_INDIV_FAILED => 0xC00D11DD as u32,
            MEDIASERVER::NS_E_WMP_SERVER_NONEWCONNECTIONS => 0xC00D11DE as u32,
            MEDIASERVER::NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST => 0xC00D11DF as u32,
            MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_FAIL => 0xC00D11E0 as u32,
            MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY => 0xC00D11E1 as u32,
            MEDIASERVER::NS_E_WMP_DRM_COMPONENT_FAILURE => 0xC00D11E2 as u32,
            MEDIASERVER::NS_E_WMP_DRM_NO_DEVICE_CERT => 0xC00D11E3 as u32,
            MEDIASERVER::NS_E_WMP_SERVER_SECURITY_ERROR => 0xC00D11E4 as u32,
            MEDIASERVER::NS_E_WMP_AUDIO_DEVICE_LOST => 0xC00D11E5 as u32,
            MEDIASERVER::NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE => 0xC00D11E6 as u32,
            MEDIASERVER::NS_E_SYNCWIZ_DEVICE_FULL => 0xC00D11EE as u32,
            MEDIASERVER::NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS => 0xC00D11EF as u32,
            MEDIASERVER::NS_E_TRANSCODE_DELETECACHEERROR => 0xC00D11F0 as u32,
            MEDIASERVER::NS_E_CD_NO_BUFFERS_READ => 0xC00D11F8 as u32,
            MEDIASERVER::NS_E_CD_EMPTY_TRACK_QUEUE => 0xC00D11F9 as u32,
            MEDIASERVER::NS_E_CD_NO_READER => 0xC00D11FA as u32,
            MEDIASERVER::NS_E_CD_ISRC_INVALID => 0xC00D11FB as u32,
            MEDIASERVER::NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID => 0xC00D11FC as u32,
            MEDIASERVER::NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION => 0xC00D11FD as u32,
            MEDIASERVER::NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS => 0xC00D11FE as u32,
            MEDIASERVER::NS_E_CD_QUEUEING_DISABLED => 0xC00D11FF as u32,
            MEDIASERVER::NS_E_WMP_DRM_ACQUIRING_LICENSE => 0xC00D1202 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_EXPIRED => 0xC00D1203 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTACQUIRED => 0xC00D1204 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTENABLED => 0xC00D1205 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_UNUSABLE => 0xC00D1206 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED => 0xC00D1207 as u32,
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOSAP => 0xC00D1208 as u32,
            MEDIASERVER::NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE => 0xC00D1209 as u32,
            MEDIASERVER::NS_E_WMP_LICENSE_REQUIRED => 0xC00D120A as u32,
            MEDIASERVER::NS_E_WMP_PROTECTED_CONTENT => 0xC00D120B as u32,
            MEDIASERVER::NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED => 0xC00D122A as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_INTERNET => 0xC00D1234 as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST => 0xC00D1235 as u32,
            MEDIASERVER::NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE => 0xC00D1236 as u32,
            MEDIASERVER::NS_E_PDA_SYNC_FAILED => 0xC00D1237 as u32,
            MEDIASERVER::NS_E_PDA_DELETE_FAILED => 0xC00D1238 as u32,
            MEDIASERVER::NS_E_PDA_FAILED_TO_RETRIEVE_FILE => 0xC00D1239 as u32,
            MEDIASERVER::NS_E_PDA_DEVICE_NOT_RESPONDING => 0xC00D123A as u32,
            MEDIASERVER::NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO => 0xC00D123B as u32,
            MEDIASERVER::NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE => 0xC00D123C as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO => 0xC00D123D as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO => 0xC00D123E as u32,
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE => 0xC00D123F as u32,
            MEDIASERVER::NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG => 0xC00D1240 as u32,
            MEDIASERVER::NS_E_PDA_CEWMDM_DRM_ERROR => 0xC00D1241 as u32,
            MEDIASERVER::NS_E_INCOMPLETE_PLAYLIST => 0xC00D1242 as u32,
            MEDIASERVER::NS_E_PDA_SYNC_RUNNING => 0xC00D1243 as u32,
            MEDIASERVER::NS_E_PDA_SYNC_LOGIN_ERROR => 0xC00D1244 as u32,
            MEDIASERVER::NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND => 0xC00D1245 as u32,
            MEDIASERVER::NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE => 0xC00D1246 as u32,
            MEDIASERVER::NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING => 0xC00D1247 as u32,
            MEDIASERVER::NS_E_WMP_HWND_NOTFOUND => 0xC00D125C as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_WRONG_NO_FILES => 0xC00D125D as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB => 0xC00D125E as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB => 0xC00D125F as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_NOJOBPOINTER => 0xC00D1260 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE => 0xC00D1261 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE => 0xC00D1262 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE => 0xC00D1263 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE => 0xC00D1264 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCFAILED => 0xC00D1265 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT => 0xC00D1266 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCENDED => 0xC00D1267 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_WMDUNPACKFAILED => 0xC00D1268 as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_FAILEDINITIALIZE => 0xC00D1269 as u32,
            MEDIASERVER::NS_E_INTERFACE_NOT_REGISTERED_IN_GIT => 0xC00D126A as u32,
            MEDIASERVER::NS_E_BKGDOWNLOAD_INVALID_FILE_NAME => 0xC00D126B as u32,
            MEDIASERVER::NS_E_IMAGE_DOWNLOAD_FAILED => 0xC00D128E as u32,
            MEDIASERVER::NS_E_WMP_UDRM_NOUSERLIST => 0xC00D12C0 as u32,
            MEDIASERVER::NS_E_WMP_DRM_NOT_ACQUIRING => 0xC00D12C1 as u32,
            MEDIASERVER::NS_E_WMP_BSTR_TOO_LONG => 0xC00D12F2 as u32,
            MEDIASERVER::NS_E_WMP_AUTOPLAY_INVALID_STATE => 0xC00D12FC as u32,
            MEDIASERVER::NS_E_WMP_COMPONENT_REVOKED => 0xC00D1306 as u32,
            MEDIASERVER::NS_E_CURL_NOTSAFE => 0xC00D1324 as u32,
            MEDIASERVER::NS_E_CURL_INVALIDCHAR => 0xC00D1325 as u32,
            MEDIASERVER::NS_E_CURL_INVALIDHOSTNAME => 0xC00D1326 as u32,
            MEDIASERVER::NS_E_CURL_INVALIDPATH => 0xC00D1327 as u32,
            MEDIASERVER::NS_E_CURL_INVALIDSCHEME => 0xC00D1328 as u32,
            MEDIASERVER::NS_E_CURL_INVALIDURL => 0xC00D1329 as u32,
            MEDIASERVER::NS_E_CURL_CANTWALK => 0xC00D132B as u32,
            MEDIASERVER::NS_E_CURL_INVALIDPORT => 0xC00D132C as u32,
            MEDIASERVER::NS_E_CURLHELPER_NOTADIRECTORY => 0xC00D132D as u32,
            MEDIASERVER::NS_E_CURLHELPER_NOTAFILE => 0xC00D132E as u32,
            MEDIASERVER::NS_E_CURL_CANTDECODE => 0xC00D132F as u32,
            MEDIASERVER::NS_E_CURLHELPER_NOTRELATIVE => 0xC00D1330 as u32,
            MEDIASERVER::NS_E_CURL_INVALIDBUFFERSIZE => 0xC00D1331 as u32,
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED => 0xC00D1356 as u32,
            MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES => 0xC00D1357 as u32,
            MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT => 0xC00D1358 as u32,
            MEDIASERVER::NS_E_NOT_CONTENT_PARTNER_TRACK => 0xC00D135A as u32,
            MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE => 0xC00D135B as u32,
            MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE => 0xC00D135C as u32,
            MEDIASERVER::NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED => 0xC00D135D as u32,
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED => 0xC00D135F as u32,
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT => 0xC00D1360 as u32,
            MEDIASERVER::NS_E_CONTENT_PARTNER_STILL_INITIALIZING => 0xC00D1362 as u32,
            MEDIASERVER::NS_E_OPEN_CONTAINING_FOLDER_FAILED => 0xC00D1363 as u32,
            MEDIASERVER::NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES => 0xC00D136A as u32,
            MEDIASERVER::NS_E_REDIRECT => 0xC00D1388 as u32,
            MEDIASERVER::NS_E_STALE_PRESENTATION => 0xC00D1389 as u32,
            MEDIASERVER::NS_E_NAMESPACE_WRONG_PERSIST => 0xC00D138A as u32,
            MEDIASERVER::NS_E_NAMESPACE_WRONG_TYPE => 0xC00D138B as u32,
            MEDIASERVER::NS_E_NAMESPACE_NODE_CONFLICT => 0xC00D138C as u32,
            MEDIASERVER::NS_E_NAMESPACE_NODE_NOT_FOUND => 0xC00D138D as u32,
            MEDIASERVER::NS_E_NAMESPACE_BUFFER_TOO_SMALL => 0xC00D138E as u32,
            MEDIASERVER::NS_E_NAMESPACE_TOO_MANY_CALLBACKS => 0xC00D138F as u32,
            MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_CALLBACK => 0xC00D1390 as u32,
            MEDIASERVER::NS_E_NAMESPACE_CALLBACK_NOT_FOUND => 0xC00D1391 as u32,
            MEDIASERVER::NS_E_NAMESPACE_NAME_TOO_LONG => 0xC00D1392 as u32,
            MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_NAME => 0xC00D1393 as u32,
            MEDIASERVER::NS_E_NAMESPACE_EMPTY_NAME => 0xC00D1394 as u32,
            MEDIASERVER::NS_E_NAMESPACE_INDEX_TOO_LARGE => 0xC00D1395 as u32,
            MEDIASERVER::NS_E_NAMESPACE_BAD_NAME => 0xC00D1396 as u32,
            MEDIASERVER::NS_E_NAMESPACE_WRONG_SECURITY => 0xC00D1397 as u32,
            MEDIASERVER::NS_E_CACHE_ARCHIVE_CONFLICT => 0xC00D13EC as u32,
            MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND => 0xC00D13ED as u32,
            MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_TIMEOUT => 0xC00D13EE as u32,
            MEDIASERVER::NS_E_CACHE_NOT_BROADCAST => 0xC00D13EF as u32,
            MEDIASERVER::NS_E_CACHE_CANNOT_BE_CACHED => 0xC00D13F0 as u32,
            MEDIASERVER::NS_E_CACHE_NOT_MODIFIED => 0xC00D13F1 as u32,
            MEDIASERVER::NS_E_CANNOT_REMOVE_PUBLISHING_POINT => 0xC00D1450 as u32,
            MEDIASERVER::NS_E_CANNOT_REMOVE_PLUGIN => 0xC00D1451 as u32,
            MEDIASERVER::NS_E_WRONG_PUBLISHING_POINT_TYPE => 0xC00D1452 as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_LOAD_TYPE => 0xC00D1453 as u32,
            MEDIASERVER::NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION => 0xC00D1454 as u32,
            MEDIASERVER::NS_E_INVALID_PUBLISHING_POINT_NAME => 0xC00D1455 as u32,
            MEDIASERVER::NS_E_TOO_MANY_MULTICAST_SINKS => 0xC00D1456 as u32,
            MEDIASERVER::NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED => 0xC00D1457 as u32,
            MEDIASERVER::NS_E_MULTICAST_PLUGIN_NOT_ENABLED => 0xC00D1458 as u32,
            MEDIASERVER::NS_E_INVALID_OPERATING_SYSTEM_VERSION => 0xC00D1459 as u32,
            MEDIASERVER::NS_E_PUBLISHING_POINT_REMOVED => 0xC00D145A as u32,
            MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST => 0xC00D145B as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_LANGUAGE => 0xC00D145C as u32,
            MEDIASERVER::NS_E_WRONG_OS_VERSION => 0xC00D145D as u32,
            MEDIASERVER::NS_E_PUBLISHING_POINT_STOPPED => 0xC00D145E as u32,
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING => 0xC00D14B4 as u32,
            MEDIASERVER::NS_E_EMPTY_PLAYLIST => 0xC00D14B5 as u32,
            MEDIASERVER::NS_E_PLAYLIST_PARSE_FAILURE => 0xC00D14B6 as u32,
            MEDIASERVER::NS_E_PLAYLIST_UNSUPPORTED_ENTRY => 0xC00D14B7 as u32,
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST => 0xC00D14B8 as u32,
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_SEEK => 0xC00D14B9 as u32,
            MEDIASERVER::NS_E_PLAYLIST_RECURSIVE_PLAYLISTS => 0xC00D14BA as u32,
            MEDIASERVER::NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS => 0xC00D14BB as u32,
            MEDIASERVER::NS_E_PLAYLIST_SHUTDOWN => 0xC00D14BC as u32,
            MEDIASERVER::NS_E_PLAYLIST_END_RECEDING => 0xC00D14BD as u32,
            MEDIASERVER::NS_E_DATAPATH_NO_SINK => 0xC00D1518 as u32,
            MEDIASERVER::NS_E_INVALID_PUSH_TEMPLATE => 0xC00D151A as u32,
            MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT => 0xC00D151B as u32,
            MEDIASERVER::NS_E_CRITICAL_ERROR => 0xC00D151C as u32,
            MEDIASERVER::NS_E_NO_NEW_CONNECTIONS => 0xC00D151D as u32,
            MEDIASERVER::NS_E_WSX_INVALID_VERSION => 0xC00D151E as u32,
            MEDIASERVER::NS_E_HEADER_MISMATCH => 0xC00D151F as u32,
            MEDIASERVER::NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME => 0xC00D1520 as u32,
            MEDIASERVER::NS_E_NO_SCRIPT_ENGINE => 0xC00D157C as u32,
            MEDIASERVER::NS_E_PLUGIN_ERROR_REPORTED => 0xC00D157D as u32,
            MEDIASERVER::NS_E_SOURCE_PLUGIN_NOT_FOUND => 0xC00D157E as u32,
            MEDIASERVER::NS_E_PLAYLIST_PLUGIN_NOT_FOUND => 0xC00D157F as u32,
            MEDIASERVER::NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED => 0xC00D1580 as u32,
            MEDIASERVER::NS_E_MEDIA_PARSER_INVALID_FORMAT => 0xC00D1581 as u32,
            MEDIASERVER::NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED => 0xC00D1582 as u32,
            MEDIASERVER::NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER => 0xC00D1583 as u32,
            MEDIASERVER::NS_E_WIZARD_RUNNING => 0xC00D1584 as u32,
            MEDIASERVER::NS_E_INVALID_LOG_URL => 0xC00D1585 as u32,
            MEDIASERVER::NS_E_INVALID_MTU_RANGE => 0xC00D1586 as u32,
            MEDIASERVER::NS_E_INVALID_PLAY_STATISTICS => 0xC00D1587 as u32,
            MEDIASERVER::NS_E_LOG_NEED_TO_BE_SKIPPED => 0xC00D1588 as u32,
            MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED => 0xC00D1589 as u32,
            MEDIASERVER::NS_E_PORT_IN_USE => 0xC00D158A as u32,
            MEDIASERVER::NS_E_PORT_IN_USE_HTTP => 0xC00D158B as u32,
            MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE => 0xC00D158C as u32,
            MEDIASERVER::NS_E_ARCHIVE_REACH_QUOTA => 0xC00D158D as u32,
            MEDIASERVER::NS_E_ARCHIVE_ABORT_DUE_TO_BCAST => 0xC00D158E as u32,
            MEDIASERVER::NS_E_ARCHIVE_GAP_DETECTED => 0xC00D158F as u32,
            MEDIASERVER::NS_E_AUTHORIZATION_FILE_NOT_FOUND => 0xC00D1590 as u32,
            MEDIASERVER::NS_E_BAD_MARKIN => 0xC00D1B58 as u32,
            MEDIASERVER::NS_E_BAD_MARKOUT => 0xC00D1B59 as u32,
            MEDIASERVER::NS_E_NOMATCHING_MEDIASOURCE => 0xC00D1B5A as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_SOURCETYPE => 0xC00D1B5B as u32,
            MEDIASERVER::NS_E_TOO_MANY_AUDIO => 0xC00D1B5C as u32,
            MEDIASERVER::NS_E_TOO_MANY_VIDEO => 0xC00D1B5D as u32,
            MEDIASERVER::NS_E_NOMATCHING_ELEMENT => 0xC00D1B5E as u32,
            MEDIASERVER::NS_E_MISMATCHED_MEDIACONTENT => 0xC00D1B5F as u32,
            MEDIASERVER::NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP => 0xC00D1B60 as u32,
            MEDIASERVER::NS_E_AUDIODEVICE_BUSY => 0xC00D1B61 as u32,
            MEDIASERVER::NS_E_AUDIODEVICE_UNEXPECTED => 0xC00D1B62 as u32,
            MEDIASERVER::NS_E_AUDIODEVICE_BADFORMAT => 0xC00D1B63 as u32,
            MEDIASERVER::NS_E_VIDEODEVICE_BUSY => 0xC00D1B64 as u32,
            MEDIASERVER::NS_E_VIDEODEVICE_UNEXPECTED => 0xC00D1B65 as u32,
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING => 0xC00D1B66 as u32,
            MEDIASERVER::NS_E_NO_PROFILE_IN_SOURCEGROUP => 0xC00D1B67 as u32,
            MEDIASERVER::NS_E_VIDEODRIVER_UNSTABLE => 0xC00D1B68 as u32,
            MEDIASERVER::NS_E_VIDCAPSTARTFAILED => 0xC00D1B69 as u32,
            MEDIASERVER::NS_E_VIDSOURCECOMPRESSION => 0xC00D1B6A as u32,
            MEDIASERVER::NS_E_VIDSOURCESIZE => 0xC00D1B6B as u32,
            MEDIASERVER::NS_E_ICMQUERYFORMAT => 0xC00D1B6C as u32,
            MEDIASERVER::NS_E_VIDCAPCREATEWINDOW => 0xC00D1B6D as u32,
            MEDIASERVER::NS_E_VIDCAPDRVINUSE => 0xC00D1B6E as u32,
            MEDIASERVER::NS_E_NO_MEDIAFORMAT_IN_SOURCE => 0xC00D1B6F as u32,
            MEDIASERVER::NS_E_NO_VALID_OUTPUT_STREAM => 0xC00D1B70 as u32,
            MEDIASERVER::NS_E_NO_VALID_SOURCE_PLUGIN => 0xC00D1B71 as u32,
            MEDIASERVER::NS_E_NO_ACTIVE_SOURCEGROUP => 0xC00D1B72 as u32,
            MEDIASERVER::NS_E_NO_SCRIPT_STREAM => 0xC00D1B73 as u32,
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING => 0xC00D1B74 as u32,
            MEDIASERVER::NS_E_INVALIDPACKETSIZE => 0xC00D1B75 as u32,
            MEDIASERVER::NS_E_PLUGIN_CLSID_INVALID => 0xC00D1B76 as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVETYPE => 0xC00D1B77 as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVEOPERATION => 0xC00D1B78 as u32,
            MEDIASERVER::NS_E_ARCHIVE_FILENAME_NOTSET => 0xC00D1B79 as u32,
            MEDIASERVER::NS_E_SOURCEGROUP_NOTPREPARED => 0xC00D1B7A as u32,
            MEDIASERVER::NS_E_PROFILE_MISMATCH => 0xC00D1B7B as u32,
            MEDIASERVER::NS_E_INCORRECTCLIPSETTINGS => 0xC00D1B7C as u32,
            MEDIASERVER::NS_E_NOSTATSAVAILABLE => 0xC00D1B7D as u32,
            MEDIASERVER::NS_E_NOTARCHIVING => 0xC00D1B7E as u32,
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED => 0xC00D1B7F as u32,
            MEDIASERVER::NS_E_NOSOURCEGROUPS => 0xC00D1B80 as u32,
            MEDIASERVER::NS_E_INVALIDINPUTFPS => 0xC00D1B81 as u32,
            MEDIASERVER::NS_E_NO_DATAVIEW_SUPPORT => 0xC00D1B82 as u32,
            MEDIASERVER::NS_E_CODEC_UNAVAILABLE => 0xC00D1B83 as u32,
            MEDIASERVER::NS_E_ARCHIVE_SAME_AS_INPUT => 0xC00D1B84 as u32,
            MEDIASERVER::NS_E_SOURCE_NOTSPECIFIED => 0xC00D1B85 as u32,
            MEDIASERVER::NS_E_NO_REALTIME_TIMECOMPRESSION => 0xC00D1B86 as u32,
            MEDIASERVER::NS_E_UNSUPPORTED_ENCODER_DEVICE => 0xC00D1B87 as u32,
            MEDIASERVER::NS_E_UNEXPECTED_DISPLAY_SETTINGS => 0xC00D1B88 as u32,
            MEDIASERVER::NS_E_NO_AUDIODATA => 0xC00D1B89 as u32,
            MEDIASERVER::NS_E_INPUTSOURCE_PROBLEM => 0xC00D1B8A as u32,
            MEDIASERVER::NS_E_WME_VERSION_MISMATCH => 0xC00D1B8B as u32,
            MEDIASERVER::NS_E_NO_REALTIME_PREPROCESS => 0xC00D1B8C as u32,
            MEDIASERVER::NS_E_NO_REPEAT_PREPROCESS => 0xC00D1B8D as u32,
            MEDIASERVER::NS_E_CANNOT_PAUSE_LIVEBROADCAST => 0xC00D1B8E as u32,
            MEDIASERVER::NS_E_DRM_PROFILE_NOT_SET => 0xC00D1B8F as u32,
            MEDIASERVER::NS_E_DUPLICATE_DRMPROFILE => 0xC00D1B90 as u32,
            MEDIASERVER::NS_E_INVALID_DEVICE => 0xC00D1B91 as u32,
            MEDIASERVER::NS_E_SPEECHEDL_ON_NON_MIXEDMODE => 0xC00D1B92 as u32,
            MEDIASERVER::NS_E_DRM_PASSWORD_TOO_LONG => 0xC00D1B93 as u32,
            MEDIASERVER::NS_E_DEVCONTROL_FAILED_SEEK => 0xC00D1B94 as u32,
            MEDIASERVER::NS_E_INTERLACE_REQUIRE_SAMESIZE => 0xC00D1B95 as u32,
            MEDIASERVER::NS_E_TOO_MANY_DEVICECONTROL => 0xC00D1B96 as u32,
            MEDIASERVER::NS_E_NO_MULTIPASS_FOR_LIVEDEVICE => 0xC00D1B97 as u32,
            MEDIASERVER::NS_E_MISSING_AUDIENCE => 0xC00D1B98 as u32,
            MEDIASERVER::NS_E_AUDIENCE_CONTENTTYPE_MISMATCH => 0xC00D1B99 as u32,
            MEDIASERVER::NS_E_MISSING_SOURCE_INDEX => 0xC00D1B9A as u32,
            MEDIASERVER::NS_E_NUM_LANGUAGE_MISMATCH => 0xC00D1B9B as u32,
            MEDIASERVER::NS_E_LANGUAGE_MISMATCH => 0xC00D1B9C as u32,
            MEDIASERVER::NS_E_VBRMODE_MISMATCH => 0xC00D1B9D as u32,
            MEDIASERVER::NS_E_INVALID_INPUT_AUDIENCE_INDEX => 0xC00D1B9E as u32,
            MEDIASERVER::NS_E_INVALID_INPUT_LANGUAGE => 0xC00D1B9F as u32,
            MEDIASERVER::NS_E_INVALID_INPUT_STREAM => 0xC00D1BA0 as u32,
            MEDIASERVER::NS_E_EXPECT_MONO_WAV_INPUT => 0xC00D1BA1 as u32,
            MEDIASERVER::NS_E_INPUT_WAVFORMAT_MISMATCH => 0xC00D1BA2 as u32,
            MEDIASERVER::NS_E_RECORDQ_DISK_FULL => 0xC00D1BA3 as u32,
            MEDIASERVER::NS_E_NO_PAL_INVERSE_TELECINE => 0xC00D1BA4 as u32,
            MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_DISCONNECTED => 0xC00D1BA5 as u32,
            MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED => 0xC00D1BA6 as u32,
            MEDIASERVER::NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER => 0xC00D1BA7 as u32,
            MEDIASERVER::NS_E_INPUT_DOESNOT_SUPPORT_SMPTE => 0xC00D1BA8 as u32,
            MEDIASERVER::NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS => 0xC00D1BA9 as u32,
            MEDIASERVER::NS_E_BAD_CONTENTEDL => 0xC00D1BAA as u32,
            MEDIASERVER::NS_E_INTERLACEMODE_MISMATCH => 0xC00D1BAB as u32,
            MEDIASERVER::NS_E_NONSQUAREPIXELMODE_MISMATCH => 0xC00D1BAC as u32,
            MEDIASERVER::NS_E_SMPTEMODE_MISMATCH => 0xC00D1BAD as u32,
            MEDIASERVER::NS_E_END_OF_TAPE => 0xC00D1BAE as u32,
            MEDIASERVER::NS_E_NO_MEDIA_IN_AUDIENCE => 0xC00D1BAF as u32,
            MEDIASERVER::NS_E_NO_AUDIENCES => 0xC00D1BB0 as u32,
            MEDIASERVER::NS_E_NO_AUDIO_COMPAT => 0xC00D1BB1 as u32,
            MEDIASERVER::NS_E_INVALID_VBR_COMPAT => 0xC00D1BB2 as u32,
            MEDIASERVER::NS_E_NO_PROFILE_NAME => 0xC00D1BB3 as u32,
            MEDIASERVER::NS_E_INVALID_VBR_WITH_UNCOMP => 0xC00D1BB4 as u32,
            MEDIASERVER::NS_E_MULTIPLE_VBR_AUDIENCES => 0xC00D1BB5 as u32,
            MEDIASERVER::NS_E_UNCOMP_COMP_COMBINATION => 0xC00D1BB6 as u32,
            MEDIASERVER::NS_E_MULTIPLE_AUDIO_CODECS => 0xC00D1BB7 as u32,
            MEDIASERVER::NS_E_MULTIPLE_AUDIO_FORMATS => 0xC00D1BB8 as u32,
            MEDIASERVER::NS_E_AUDIO_BITRATE_STEPDOWN => 0xC00D1BB9 as u32,
            MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE => 0xC00D1BBA as u32,
            MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE_2 => 0xC00D1BBB as u32,
            MEDIASERVER::NS_E_INVALID_AUDIO_BUFFERMAX => 0xC00D1BBC as u32,
            MEDIASERVER::NS_E_MULTIPLE_VIDEO_CODECS => 0xC00D1BBD as u32,
            MEDIASERVER::NS_E_MULTIPLE_VIDEO_SIZES => 0xC00D1BBE as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_BITRATE => 0xC00D1BBF as u32,
            MEDIASERVER::NS_E_VIDEO_BITRATE_STEPDOWN => 0xC00D1BC0 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE => 0xC00D1BC1 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE_2 => 0xC00D1BC2 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH => 0xC00D1BC3 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT => 0xC00D1BC4 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_FPS => 0xC00D1BC5 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_KEYFRAME => 0xC00D1BC6 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_IQUALITY => 0xC00D1BC7 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_CQUALITY => 0xC00D1BC8 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFER => 0xC00D1BC9 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX => 0xC00D1BCA as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX_2 => 0xC00D1BCB as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_ALIGN => 0xC00D1BCC as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT_ALIGN => 0xC00D1BCD as u32,
            MEDIASERVER::NS_E_MULTIPLE_SCRIPT_BITRATES => 0xC00D1BCE as u32,
            MEDIASERVER::NS_E_INVALID_SCRIPT_BITRATE => 0xC00D1BCF as u32,
            MEDIASERVER::NS_E_MULTIPLE_FILE_BITRATES => 0xC00D1BD0 as u32,
            MEDIASERVER::NS_E_INVALID_FILE_BITRATE => 0xC00D1BD1 as u32,
            MEDIASERVER::NS_E_SAME_AS_INPUT_COMBINATION => 0xC00D1BD2 as u32,
            MEDIASERVER::NS_E_SOURCE_CANNOT_LOOP => 0xC00D1BD3 as u32,
            MEDIASERVER::NS_E_INVALID_FOLDDOWN_COEFFICIENTS => 0xC00D1BD4 as u32,
            MEDIASERVER::NS_E_DRMPROFILE_NOTFOUND => 0xC00D1BD5 as u32,
            MEDIASERVER::NS_E_INVALID_TIMECODE => 0xC00D1BD6 as u32,
            MEDIASERVER::NS_E_NO_AUDIO_TIMECOMPRESSION => 0xC00D1BD7 as u32,
            MEDIASERVER::NS_E_NO_TWOPASS_TIMECOMPRESSION => 0xC00D1BD8 as u32,
            MEDIASERVER::NS_E_TIMECODE_REQUIRES_VIDEOSTREAM => 0xC00D1BD9 as u32,
            MEDIASERVER::NS_E_NO_MBR_WITH_TIMECODE => 0xC00D1BDA as u32,
            MEDIASERVER::NS_E_INVALID_INTERLACEMODE => 0xC00D1BDB as u32,
            MEDIASERVER::NS_E_INVALID_INTERLACE_COMPAT => 0xC00D1BDC as u32,
            MEDIASERVER::NS_E_INVALID_NONSQUAREPIXEL_COMPAT => 0xC00D1BDD as u32,
            MEDIASERVER::NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL => 0xC00D1BDE as u32,
            MEDIASERVER::NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR => 0xC00D1BDF as u32,
            MEDIASERVER::NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT => 0xC00D1BE0 as u32,
            MEDIASERVER::NS_E_DEVICECONTROL_UNSTABLE => 0xC00D1BE1 as u32,
            MEDIASERVER::NS_E_INVALID_PIXEL_ASPECT_RATIO => 0xC00D1BE2 as u32,
            MEDIASERVER::NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH => 0xC00D1BE3 as u32,
            MEDIASERVER::NS_E_INVALID_PROFILE_CONTENTTYPE => 0xC00D1BE4 as u32,
            MEDIASERVER::NS_E_TRANSFORM_PLUGIN_NOT_FOUND => 0xC00D1BE5 as u32,
            MEDIASERVER::NS_E_TRANSFORM_PLUGIN_INVALID => 0xC00D1BE6 as u32,
            MEDIASERVER::NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS => 0xC00D1BE7 as u32,
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING => 0xC00D1BE8 as u32,
            MEDIASERVER::NS_E_MARKIN_UNSUPPORTED => 0xC00D1BE9 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_APPLICATION => 0xC00D2711 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_STORE_ERROR => 0xC00D2712 as u32,
            MEDIASERVER::NS_E_DRM_SECURE_STORE_ERROR => 0xC00D2713 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_STORE_SAVE_ERROR => 0xC00D2714 as u32,
            MEDIASERVER::NS_E_DRM_SECURE_STORE_UNLOCK_ERROR => 0xC00D2715 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_CONTENT => 0xC00D2716 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_LICENSE => 0xC00D2717 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE => 0xC00D2718 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_MACHINE => 0xC00D2719 as u32,
            MEDIASERVER::NS_E_DRM_ENUM_LICENSE_FAILED => 0xC00D271B as u32,
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE_REQUEST => 0xC00D271C as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_INITIALIZE => 0xC00D271D as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE => 0xC00D271E as u32,
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE_ACQUIRED => 0xC00D271F as u32,
            MEDIASERVER::NS_E_DRM_NO_RIGHTS => 0xC00D2720 as u32,
            MEDIASERVER::NS_E_DRM_KEY_ERROR => 0xC00D2721 as u32,
            MEDIASERVER::NS_E_DRM_ENCRYPT_ERROR => 0xC00D2722 as u32,
            MEDIASERVER::NS_E_DRM_DECRYPT_ERROR => 0xC00D2723 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_INVALID_XML => 0xC00D2725 as u32,
            MEDIASERVER::NS_E_DRM_NEEDS_INDIVIDUALIZATION => 0xC00D2728 as u32,
            MEDIASERVER::NS_E_DRM_ALREADY_INDIVIDUALIZED => 0xC00D2729 as u32,
            MEDIASERVER::NS_E_DRM_ACTION_NOT_QUERIED => 0xC00D272A as u32,
            MEDIASERVER::NS_E_DRM_ACQUIRING_LICENSE => 0xC00D272B as u32,
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZING => 0xC00D272C as u32,
            MEDIASERVER::NS_E_BACKUP_RESTORE_FAILURE => 0xC00D272D as u32,
            MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_REQUEST_ID => 0xC00D272E as u32,
            MEDIASERVER::NS_E_DRM_PARAMETERS_MISMATCHED => 0xC00D272F as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT => 0xC00D2730 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT => 0xC00D2731 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT => 0xC00D2732 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT => 0xC00D2733 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT => 0xC00D2734 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT => 0xC00D2735 as u32,
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZE_ERROR => 0xC00D2736 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_OPEN_ERROR => 0xC00D2737 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_CLOSE_ERROR => 0xC00D2738 as u32,
            MEDIASERVER::NS_E_DRM_GET_LICENSE_ERROR => 0xC00D2739 as u32,
            MEDIASERVER::NS_E_DRM_QUERY_ERROR => 0xC00D273A as u32,
            MEDIASERVER::NS_E_DRM_REPORT_ERROR => 0xC00D273B as u32,
            MEDIASERVER::NS_E_DRM_GET_LICENSESTRING_ERROR => 0xC00D273C as u32,
            MEDIASERVER::NS_E_DRM_GET_CONTENTSTRING_ERROR => 0xC00D273D as u32,
            MEDIASERVER::NS_E_DRM_MONITOR_ERROR => 0xC00D273E as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_PARAMETER => 0xC00D273F as u32,
            MEDIASERVER::NS_E_DRM_INVALID_APPDATA => 0xC00D2740 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_APPDATA_VERSION => 0xC00D2741 as u32,
            MEDIASERVER::NS_E_DRM_BACKUP_EXISTS => 0xC00D2742 as u32,
            MEDIASERVER::NS_E_DRM_BACKUP_CORRUPT => 0xC00D2743 as u32,
            MEDIASERVER::NS_E_DRM_BACKUPRESTORE_BUSY => 0xC00D2744 as u32,
            MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_DATA => 0xC00D2745 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_UNUSABLE => 0xC00D2748 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_PROPERTY => 0xC00D2749 as u32,
            MEDIASERVER::NS_E_DRM_SECURE_STORE_NOT_FOUND => 0xC00D274A as u32,
            MEDIASERVER::NS_E_DRM_CACHED_CONTENT_ERROR => 0xC00D274B as u32,
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE => 0xC00D274C as u32,
            MEDIASERVER::NS_E_DRM_DRIVER_AUTH_FAILURE => 0xC00D274D as u32,
            MEDIASERVER::NS_E_DRM_NEED_UPGRADE_MSSAP => 0xC00D274E as u32,
            MEDIASERVER::NS_E_DRM_REOPEN_CONTENT => 0xC00D274F as u32,
            MEDIASERVER::NS_E_DRM_DRIVER_DIGIOUT_FAILURE => 0xC00D2750 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_SECURESTORE_PASSWORD => 0xC00D2751 as u32,
            MEDIASERVER::NS_E_DRM_APPCERT_REVOKED => 0xC00D2752 as u32,
            MEDIASERVER::NS_E_DRM_RESTORE_FRAUD => 0xC00D2753 as u32,
            MEDIASERVER::NS_E_DRM_HARDWARE_INCONSISTENT => 0xC00D2754 as u32,
            MEDIASERVER::NS_E_DRM_SDMI_TRIGGER => 0xC00D2755 as u32,
            MEDIASERVER::NS_E_DRM_SDMI_NOMORECOPIES => 0xC00D2756 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT => 0xC00D2757 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT => 0xC00D2758 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_NOTACQUIRED => 0xC00D2759 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT => 0xC00D275A as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT => 0xC00D275B as u32,
            MEDIASERVER::NS_E_DRM_BUFFER_TOO_SMALL => 0xC00D275C as u32,
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROPERTY => 0xC00D275D as u32,
            MEDIASERVER::NS_E_DRM_ERROR_BAD_NET_RESP => 0xC00D275E as u32,
            MEDIASERVER::NS_E_DRM_STORE_NOTALLSTORED => 0xC00D275F as u32,
            MEDIASERVER::NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID => 0xC00D2760 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_DATA => 0xC00D2761 as u32,
            MEDIASERVER::NS_E_DRM_POLICY_DISABLE_ONLINE => 0xC00D2762 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT => 0xC00D2763 as u32,
            MEDIASERVER::NS_E_DRM_NOT_CONFIGURED => 0xC00D2764 as u32,
            MEDIASERVER::NS_E_DRM_DEVICE_ACTIVATION_CANCELED => 0xC00D2765 as u32,
            MEDIASERVER::NS_E_BACKUP_RESTORE_TOO_MANY_RESETS => 0xC00D2766 as u32,
            MEDIASERVER::NS_E_DRM_DEBUGGING_NOT_ALLOWED => 0xC00D2767 as u32,
            MEDIASERVER::NS_E_DRM_OPERATION_CANCELED => 0xC00D2768 as u32,
            MEDIASERVER::NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED => 0xC00D2769 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT => 0xC00D276A as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT => 0xC00D276B as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT => 0xC00D276C as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT => 0xC00D276D as u32,
            MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION => 0xC00D2770 as u32,
            MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION => 0xC00D2771 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT => 0xC00D2772 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK => 0xC00D2773 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK => 0xC00D2774 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER => 0xC00D2775 as u32,
            MEDIASERVER::NS_E_DRM_POLICY_METERING_DISABLED => 0xC00D2776 as u32,
            MEDIASERVER::NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED => 0xC00D2777 as u32,
            MEDIASERVER::NS_E_DRM_SDK_VERSIONMISMATCH => 0xC00D2778 as u32,
            MEDIASERVER::NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET => 0xC00D2779 as u32,
            MEDIASERVER::NS_E_LICENSE_HEADER_MISSING_URL => 0xC00D277A as u32,
            MEDIASERVER::NS_E_DEVICE_NOT_WMDRM_DEVICE => 0xC00D277B as u32,
            MEDIASERVER::NS_E_DRM_INVALID_APPCERT => 0xC00D277C as u32,
            MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION => 0xC00D277D as u32,
            MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE => 0xC00D277E as u32,
            MEDIASERVER::NS_E_DRM_CHECKPOINT_FAILED => 0xC00D277F as u32,
            MEDIASERVER::NS_E_DRM_BB_UNABLE_TO_INITIALIZE => 0xC00D2780 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID => 0xC00D2781 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE => 0xC00D2782 as u32,
            MEDIASERVER::NS_E_DRM_DATASTORE_CORRUPT => 0xC00D2783 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT => 0xC00D2784 as u32,
            MEDIASERVER::NS_E_DRM_STUBLIB_REQUIRED => 0xC00D2785 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT => 0xC00D2786 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE => 0xC00D2787 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_MIGRATION_IMAGE => 0xC00D2788 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED => 0xC00D2789 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE => 0xC00D278A as u32,
            MEDIASERVER::NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID => 0xC00D278B as u32,
            MEDIASERVER::NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE => 0xC00D278C as u32,
            MEDIASERVER::NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH => 0xC00D278D as u32,
            MEDIASERVER::NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS => 0xC00D278E as u32,
            MEDIASERVER::NS_E_DRM_HARDWAREID_MISMATCH => 0xC00D278F as u32,
            MEDIASERVER::NS_E_INVALID_DRMV2CLT_STUBLIB => 0xC00D2790 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA => 0xC00D2791 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS => 0xC00D2792 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD => 0xC00D2793 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_NOT_SUPPORTED => 0xC00D2794 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT => 0xC00D2795 as u32,
            MEDIASERVER::NS_E_DRM_CHECKPOINT_MISMATCH => 0xC00D2796 as u32,
            MEDIASERVER::NS_E_DRM_CHECKPOINT_CORRUPT => 0xC00D2797 as u32,
            MEDIASERVER::NS_E_REG_FLUSH_FAILURE => 0xC00D2798 as u32,
            MEDIASERVER::NS_E_HDS_KEY_MISMATCH => 0xC00D2799 as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_OPERATION_CANCELLED => 0xC00D279A as u32,
            MEDIASERVER::NS_E_DRM_MIGRATION_OBJECT_IN_USE => 0xC00D279B as u32,
            MEDIASERVER::NS_E_DRM_MALFORMED_CONTENT_HEADER => 0xC00D279C as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_EXPIRED => 0xC00D27D8 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_NOTENABLED => 0xC00D27D9 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_APPSECLOW => 0xC00D27DA as u32,
            MEDIASERVER::NS_E_DRM_STORE_NEEDINDI => 0xC00D27DB as u32,
            MEDIASERVER::NS_E_DRM_STORE_NOTALLOWED => 0xC00D27DC as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_APP_NOTALLOWED => 0xC00D27DD as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_CERT_EXPIRED => 0xC00D27DF as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_SECLOW => 0xC00D27E0 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_CONTENT_REVOKED => 0xC00D27E1 as u32,
            MEDIASERVER::NS_E_DRM_DEVICE_NOT_REGISTERED => 0xC00D27E2 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_NOSAP => 0xC00D280A as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_NOSVP => 0xC00D280B as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_NOWDM => 0xC00D280C as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_NOTRUSTEDCODEC => 0xC00D280D as u32,
            MEDIASERVER::NS_E_DRM_SOURCEID_NOT_SUPPORTED => 0xC00D280E as u32,
            MEDIASERVER::NS_E_DRM_NEEDS_UPGRADE_TEMPFILE => 0xC00D283D as u32,
            MEDIASERVER::NS_E_DRM_NEED_UPGRADE_PD => 0xC00D283E as u32,
            MEDIASERVER::NS_E_DRM_SIGNATURE_FAILURE => 0xC00D283F as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_SERVER_INFO_MISSING => 0xC00D2840 as u32,
            MEDIASERVER::NS_E_DRM_BUSY => 0xC00D2841 as u32,
            MEDIASERVER::NS_E_DRM_PD_TOO_MANY_DEVICES => 0xC00D2842 as u32,
            MEDIASERVER::NS_E_DRM_INDIV_FRAUD => 0xC00D2843 as u32,
            MEDIASERVER::NS_E_DRM_INDIV_NO_CABS => 0xC00D2844 as u32,
            MEDIASERVER::NS_E_DRM_INDIV_SERVICE_UNAVAILABLE => 0xC00D2845 as u32,
            MEDIASERVER::NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE => 0xC00D2846 as u32,
            MEDIASERVER::NS_E_DRM_CLIENT_CODE_EXPIRED => 0xC00D2847 as u32,
            MEDIASERVER::NS_E_DRM_NO_UPLINK_LICENSE => 0xC00D2848 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_KID => 0xC00D2849 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_INITIALIZATION_ERROR => 0xC00D284A as u32,
            MEDIASERVER::NS_E_DRM_CHAIN_TOO_LONG => 0xC00D284C as u32,
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_ALGORITHM => 0xC00D284D as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_DELETION_ERROR => 0xC00D284E as u32,
            MEDIASERVER::NS_E_DRM_INVALID_CERTIFICATE => 0xC00D28A0 as u32,
            MEDIASERVER::NS_E_DRM_CERTIFICATE_REVOKED => 0xC00D28A1 as u32,
            MEDIASERVER::NS_E_DRM_LICENSE_UNAVAILABLE => 0xC00D28A2 as u32,
            MEDIASERVER::NS_E_DRM_DEVICE_LIMIT_REACHED => 0xC00D28A3 as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY => 0xC00D28A4 as u32,
            MEDIASERVER::NS_E_DRM_MUST_REGISTER => 0xC00D28A5 as u32,
            MEDIASERVER::NS_E_DRM_MUST_APPROVE => 0xC00D28A6 as u32,
            MEDIASERVER::NS_E_DRM_MUST_REVALIDATE => 0xC00D28A7 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_PROXIMITY_RESPONSE => 0xC00D28A8 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_SESSION => 0xC00D28A9 as u32,
            MEDIASERVER::NS_E_DRM_DEVICE_NOT_OPEN => 0xC00D28AA as u32,
            MEDIASERVER::NS_E_DRM_DEVICE_ALREADY_REGISTERED => 0xC00D28AB as u32,
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION => 0xC00D28AC as u32,
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_ACTION => 0xC00D28AD as u32,
            MEDIASERVER::NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE => 0xC00D28AE as u32,
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_PORT => 0xC00D28AF as u32,
            MEDIASERVER::NS_E_DRM_BAD_REQUEST => 0xC00D28B0 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_CRL => 0xC00D28B1 as u32,
            MEDIASERVER::NS_E_DRM_ATTRIBUTE_TOO_LONG => 0xC00D28B2 as u32,
            MEDIASERVER::NS_E_DRM_EXPIRED_LICENSEBLOB => 0xC00D28B3 as u32,
            MEDIASERVER::NS_E_DRM_INVALID_LICENSEBLOB => 0xC00D28B4 as u32,
            MEDIASERVER::NS_E_DRM_INCLUSION_LIST_REQUIRED => 0xC00D28B5 as u32,
            MEDIASERVER::NS_E_DRM_DRMV2CLT_REVOKED => 0xC00D28B6 as u32,
            MEDIASERVER::NS_E_DRM_RIV_TOO_SMALL => 0xC00D28B7 as u32,
            MEDIASERVER::NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED => 0xC00D2904 as u32,
            MEDIASERVER::NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => 0xC00D2905 as u32,
            MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => 0xC00D2906 as u32,
            MEDIASERVER::NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => 0xC00D2907 as u32,
            MEDIASERVER::NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED => 0xC00D2908 as u32,
            MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED => 0xC00D2909 as u32,
            MEDIASERVER::NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED => 0xC00D290A as u32,
            MEDIASERVER::NS_E_REBOOT_RECOMMENDED => 0xC00D2AFA as u32,
            MEDIASERVER::NS_E_REBOOT_REQUIRED => 0xC00D2AFB as u32,
            MEDIASERVER::NS_E_SETUP_INCOMPLETE => 0xC00D2AFC as u32,
            MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED => 0xC00D2AFD as u32,
            MEDIASERVER::NS_E_SETUP_IGNORABLE_FAILURE => 0xC00D2AFE as u32,
            MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE => 0xC00D2AFF as u32,
            MEDIASERVER::NS_E_SETUP_BLOCKED => 0xC00D2B00 as u32,
            MEDIASERVER::NS_E_UNKNOWN_PROTOCOL => 0xC00D2EE0 as u32,
            MEDIASERVER::NS_E_REDIRECT_TO_PROXY => 0xC00D2EE1 as u32,
            MEDIASERVER::NS_E_INTERNAL_SERVER_ERROR => 0xC00D2EE2 as u32,
            MEDIASERVER::NS_E_BAD_REQUEST => 0xC00D2EE3 as u32,
            MEDIASERVER::NS_E_ERROR_FROM_PROXY => 0xC00D2EE4 as u32,
            MEDIASERVER::NS_E_PROXY_TIMEOUT => 0xC00D2EE5 as u32,
            MEDIASERVER::NS_E_SERVER_UNAVAILABLE => 0xC00D2EE6 as u32,
            MEDIASERVER::NS_E_REFUSED_BY_SERVER => 0xC00D2EE7 as u32,
            MEDIASERVER::NS_E_INCOMPATIBLE_SERVER => 0xC00D2EE8 as u32,
            MEDIASERVER::NS_E_MULTICAST_DISABLED => 0xC00D2EE9 as u32,
            MEDIASERVER::NS_E_INVALID_REDIRECT => 0xC00D2EEA as u32,
            MEDIASERVER::NS_E_ALL_PROTOCOLS_DISABLED => 0xC00D2EEB as u32,
            MEDIASERVER::NS_E_MSBD_NO_LONGER_SUPPORTED => 0xC00D2EEC as u32,
            MEDIASERVER::NS_E_PROXY_NOT_FOUND => 0xC00D2EED as u32,
            MEDIASERVER::NS_E_CANNOT_CONNECT_TO_PROXY => 0xC00D2EEE as u32,
            MEDIASERVER::NS_E_SERVER_DNS_TIMEOUT => 0xC00D2EEF as u32,
            MEDIASERVER::NS_E_PROXY_DNS_TIMEOUT => 0xC00D2EF0 as u32,
            MEDIASERVER::NS_E_CLOSED_ON_SUSPEND => 0xC00D2EF1 as u32,
            MEDIASERVER::NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER => 0xC00D2EF2 as u32,
            MEDIASERVER::NS_E_SESSION_NOT_FOUND => 0xC00D2EF3 as u32,
            MEDIASERVER::NS_E_REQUIRE_STREAMING_CLIENT => 0xC00D2EF4 as u32,
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_HAS_CHANGED => 0xC00D2EF5 as u32,
            MEDIASERVER::NS_E_PROXY_ACCESSDENIED => 0xC00D2EF6 as u32,
            MEDIASERVER::NS_E_PROXY_SOURCE_ACCESSDENIED => 0xC00D2EF7 as u32,
            MEDIASERVER::NS_E_NETWORK_SINK_WRITE => 0xC00D2EF8 as u32,
            MEDIASERVER::NS_E_FIREWALL => 0xC00D2EF9 as u32,
            MEDIASERVER::NS_E_MMS_NOT_SUPPORTED => 0xC00D2EFA as u32,
            MEDIASERVER::NS_E_SERVER_ACCESSDENIED => 0xC00D2EFB as u32,
            MEDIASERVER::NS_E_RESOURCE_GONE => 0xC00D2EFC as u32,
            MEDIASERVER::NS_E_NO_EXISTING_PACKETIZER => 0xC00D2EFD as u32,
            MEDIASERVER::NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE => 0xC00D2EFE as u32,
            MEDIASERVER::NS_E_RESET_SOCKET_CONNECTION => 0xC00D2F00 as u32,
            MEDIASERVER::NS_E_TOO_MANY_HOPS => 0xC00D2F02 as u32,
            MEDIASERVER::NS_E_TOO_MUCH_DATA_FROM_SERVER => 0xC00D2F05 as u32,
            MEDIASERVER::NS_E_CONNECT_TIMEOUT => 0xC00D2F06 as u32,
            MEDIASERVER::NS_E_PROXY_CONNECT_TIMEOUT => 0xC00D2F07 as u32,
            MEDIASERVER::NS_E_SESSION_INVALID => 0xC00D2F08 as u32,
            MEDIASERVER::NS_E_PACKETSINK_UNKNOWN_FEC_STREAM => 0xC00D2F0A as u32,
            MEDIASERVER::NS_E_PUSH_CANNOTCONNECT => 0xC00D2F0B as u32,
            MEDIASERVER::NS_E_INCOMPATIBLE_PUSH_SERVER => 0xC00D2F0C as u32,
            MEDIASERVER::NS_E_END_OF_PLAYLIST => 0xC00D32C8 as u32,
            MEDIASERVER::NS_E_USE_FILE_SOURCE => 0xC00D32C9 as u32,
            MEDIASERVER::NS_E_PROPERTY_NOT_FOUND => 0xC00D32CA as u32,
            MEDIASERVER::NS_E_PROPERTY_READ_ONLY => 0xC00D32CC as u32,
            MEDIASERVER::NS_E_TABLE_KEY_NOT_FOUND => 0xC00D32CD as u32,
            MEDIASERVER::NS_E_INVALID_QUERY_OPERATOR => 0xC00D32CF as u32,
            MEDIASERVER::NS_E_INVALID_QUERY_PROPERTY => 0xC00D32D0 as u32,
            MEDIASERVER::NS_E_PROPERTY_NOT_SUPPORTED => 0xC00D32D2 as u32,
            MEDIASERVER::NS_E_SCHEMA_CLASSIFY_FAILURE => 0xC00D32D4 as u32,
            MEDIASERVER::NS_E_METADATA_FORMAT_NOT_SUPPORTED => 0xC00D32D5 as u32,
            MEDIASERVER::NS_E_METADATA_NO_EDITING_CAPABILITY => 0xC00D32D6 as u32,
            MEDIASERVER::NS_E_METADATA_CANNOT_SET_LOCALE => 0xC00D32D7 as u32,
            MEDIASERVER::NS_E_METADATA_LANGUAGE_NOT_SUPORTED => 0xC00D32D8 as u32,
            MEDIASERVER::NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE => 0xC00D32D9 as u32,
            MEDIASERVER::NS_E_METADATA_NOT_AVAILABLE => 0xC00D32DA as u32,
            MEDIASERVER::NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE => 0xC00D32DB as u32,
            MEDIASERVER::NS_E_METADATA_INVALID_DOCUMENT_TYPE => 0xC00D32DC as u32,
            MEDIASERVER::NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE => 0xC00D32DD as u32,
            MEDIASERVER::NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE => 0xC00D32DE as u32,
            MEDIASERVER::MF_E_PLATFORM_NOT_INITIALIZED => 0xC00D36B0 as u32,
            MEDIASERVER::MF_E_BUFFERTOOSMALL => 0xC00D36B1 as u32,
            MEDIASERVER::MF_E_INVALIDREQUEST => 0xC00D36B2 as u32,
            MEDIASERVER::MF_E_INVALIDSTREAMNUMBER => 0xC00D36B3 as u32,
            MEDIASERVER::MF_E_INVALIDMEDIATYPE => 0xC00D36B4 as u32,
            MEDIASERVER::MF_E_NOTACCEPTING => 0xC00D36B5 as u32,
            MEDIASERVER::MF_E_NOT_INITIALIZED => 0xC00D36B6 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_REPRESENTATION => 0xC00D36B7 as u32,
            MEDIASERVER::MF_E_NO_MORE_TYPES => 0xC00D36B9 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_SERVICE => 0xC00D36BA as u32,
            MEDIASERVER::MF_E_UNEXPECTED => 0xC00D36BB as u32,
            MEDIASERVER::MF_E_INVALIDNAME => 0xC00D36BC as u32,
            MEDIASERVER::MF_E_INVALIDTYPE => 0xC00D36BD as u32,
            MEDIASERVER::MF_E_INVALID_FILE_FORMAT => 0xC00D36BE as u32,
            MEDIASERVER::MF_E_INVALIDINDEX => 0xC00D36BF as u32,
            MEDIASERVER::MF_E_INVALID_TIMESTAMP => 0xC00D36C0 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_SCHEME => 0xC00D36C3 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_BYTESTREAM_TYPE => 0xC00D36C4 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_TIME_FORMAT => 0xC00D36C5 as u32,
            MEDIASERVER::MF_E_NO_SAMPLE_TIMESTAMP => 0xC00D36C8 as u32,
            MEDIASERVER::MF_E_NO_SAMPLE_DURATION => 0xC00D36C9 as u32,
            MEDIASERVER::MF_E_INVALID_STREAM_DATA => 0xC00D36CB as u32,
            MEDIASERVER::MF_E_RT_UNAVAILABLE => 0xC00D36CF as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_RATE => 0xC00D36D0 as u32,
            MEDIASERVER::MF_E_THINNING_UNSUPPORTED => 0xC00D36D1 as u32,
            MEDIASERVER::MF_E_REVERSE_UNSUPPORTED => 0xC00D36D2 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_RATE_TRANSITION => 0xC00D36D3 as u32,
            MEDIASERVER::MF_E_RATE_CHANGE_PREEMPTED => 0xC00D36D4 as u32,
            MEDIASERVER::MF_E_NOT_FOUND => 0xC00D36D5 as u32,
            MEDIASERVER::MF_E_NOT_AVAILABLE => 0xC00D36D6 as u32,
            MEDIASERVER::MF_E_NO_CLOCK => 0xC00D36D7 as u32,
            MEDIASERVER::MF_E_MULTIPLE_BEGIN => 0xC00D36D9 as u32,
            MEDIASERVER::MF_E_MULTIPLE_SUBSCRIBERS => 0xC00D36DA as u32,
            MEDIASERVER::MF_E_TIMER_ORPHANED => 0xC00D36DB as u32,
            MEDIASERVER::MF_E_STATE_TRANSITION_PENDING => 0xC00D36DC as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_STATE_TRANSITION => 0xC00D36DD as u32,
            MEDIASERVER::MF_E_UNRECOVERABLE_ERROR_OCCURRED => 0xC00D36DE as u32,
            MEDIASERVER::MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS => 0xC00D36DF as u32,
            MEDIASERVER::MF_E_SAMPLE_NOT_WRITABLE => 0xC00D36E0 as u32,
            MEDIASERVER::MF_E_INVALID_KEY => 0xC00D36E2 as u32,
            MEDIASERVER::MF_E_BAD_STARTUP_VERSION => 0xC00D36E3 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_CAPTION => 0xC00D36E4 as u32,
            MEDIASERVER::MF_E_INVALID_POSITION => 0xC00D36E5 as u32,
            MEDIASERVER::MF_E_ATTRIBUTENOTFOUND => 0xC00D36E6 as u32,
            MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_ALLOWED => 0xC00D36E7 as u32,
            MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_SUPPORTED => 0xC00D36E8 as u32,
            MEDIASERVER::MF_E_PROPERTY_EMPTY => 0xC00D36E9 as u32,
            MEDIASERVER::MF_E_PROPERTY_NOT_EMPTY => 0xC00D36EA as u32,
            MEDIASERVER::MF_E_PROPERTY_VECTOR_NOT_ALLOWED => 0xC00D36EB as u32,
            MEDIASERVER::MF_E_PROPERTY_VECTOR_REQUIRED => 0xC00D36EC as u32,
            MEDIASERVER::MF_E_OPERATION_CANCELLED => 0xC00D36ED as u32,
            MEDIASERVER::MF_E_BYTESTREAM_NOT_SEEKABLE => 0xC00D36EE as u32,
            MEDIASERVER::MF_E_DISABLED_IN_SAFEMODE => 0xC00D36EF as u32,
            MEDIASERVER::MF_E_CANNOT_PARSE_BYTESTREAM => 0xC00D36F0 as u32,
            MEDIASERVER::MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS => 0xC00D36F1 as u32,
            MEDIASERVER::MF_E_MEDIAPROC_WRONGSTATE => 0xC00D36F2 as u32,
            MEDIASERVER::MF_E_RT_THROUGHPUT_NOT_AVAILABLE => 0xC00D36F3 as u32,
            MEDIASERVER::MF_E_RT_TOO_MANY_CLASSES => 0xC00D36F4 as u32,
            MEDIASERVER::MF_E_RT_WOULDBLOCK => 0xC00D36F5 as u32,
            MEDIASERVER::MF_E_NO_BITPUMP => 0xC00D36F6 as u32,
            MEDIASERVER::MF_E_RT_OUTOFMEMORY => 0xC00D36F7 as u32,
            MEDIASERVER::MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED => 0xC00D36F8 as u32,
            MEDIASERVER::MF_E_CANNOT_CREATE_SINK => 0xC00D36FA as u32,
            MEDIASERVER::MF_E_BYTESTREAM_UNKNOWN_LENGTH => 0xC00D36FB as u32,
            MEDIASERVER::MF_E_SESSION_PAUSEWHILESTOPPED => 0xC00D36FC as u32,
            MEDIASERVER::MF_E_FORMAT_CHANGE_NOT_SUPPORTED => 0xC00D36FE as u32,
            MEDIASERVER::MF_E_INVALID_WORKQUEUE => 0xC00D36FF as u32,
            MEDIASERVER::MF_E_DRM_UNSUPPORTED => 0xC00D3700 as u32,
            MEDIASERVER::MF_E_UNAUTHORIZED => 0xC00D3701 as u32,
            MEDIASERVER::MF_E_OUT_OF_RANGE => 0xC00D3702 as u32,
            MEDIASERVER::MF_E_INVALID_CODEC_MERIT => 0xC00D3703 as u32,
            MEDIASERVER::MF_E_HW_MFT_FAILED_START_STREAMING => 0xC00D3704 as u32,
            MEDIASERVER::MF_E_ASF_PARSINGINCOMPLETE => 0xC00D3A98 as u32,
            MEDIASERVER::MF_E_ASF_MISSINGDATA => 0xC00D3A99 as u32,
            MEDIASERVER::MF_E_ASF_INVALIDDATA => 0xC00D3A9A as u32,
            MEDIASERVER::MF_E_ASF_OPAQUEPACKET => 0xC00D3A9B as u32,
            MEDIASERVER::MF_E_ASF_NOINDEX => 0xC00D3A9C as u32,
            MEDIASERVER::MF_E_ASF_OUTOFRANGE => 0xC00D3A9D as u32,
            MEDIASERVER::MF_E_ASF_INDEXNOTLOADED => 0xC00D3A9E as u32,
            MEDIASERVER::MF_E_ASF_TOO_MANY_PAYLOADS => 0xC00D3A9F as u32,
            MEDIASERVER::MF_E_ASF_UNSUPPORTED_STREAM_TYPE => 0xC00D3AA0 as u32,
            MEDIASERVER::MF_E_ASF_DROPPED_PACKET => 0xC00D3AA1 as u32,
            MEDIASERVER::MF_E_NO_EVENTS_AVAILABLE => 0xC00D3E80 as u32,
            MEDIASERVER::MF_E_INVALID_STATE_TRANSITION => 0xC00D3E82 as u32,
            MEDIASERVER::MF_E_END_OF_STREAM => 0xC00D3E84 as u32,
            MEDIASERVER::MF_E_SHUTDOWN => 0xC00D3E85 as u32,
            MEDIASERVER::MF_E_MP3_NOTFOUND => 0xC00D3E86 as u32,
            MEDIASERVER::MF_E_MP3_OUTOFDATA => 0xC00D3E87 as u32,
            MEDIASERVER::MF_E_MP3_NOTMP3 => 0xC00D3E88 as u32,
            MEDIASERVER::MF_E_MP3_NOTSUPPORTED => 0xC00D3E89 as u32,
            MEDIASERVER::MF_E_NO_DURATION => 0xC00D3E8A as u32,
            MEDIASERVER::MF_E_INVALID_FORMAT => 0xC00D3E8C as u32,
            MEDIASERVER::MF_E_PROPERTY_NOT_FOUND => 0xC00D3E8D as u32,
            MEDIASERVER::MF_E_PROPERTY_READ_ONLY => 0xC00D3E8E as u32,
            MEDIASERVER::MF_E_PROPERTY_NOT_ALLOWED => 0xC00D3E8F as u32,
            MEDIASERVER::MF_E_MEDIA_SOURCE_NOT_STARTED => 0xC00D3E91 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_FORMAT => 0xC00D3E98 as u32,
            MEDIASERVER::MF_E_MP3_BAD_CRC => 0xC00D3E99 as u32,
            MEDIASERVER::MF_E_NOT_PROTECTED => 0xC00D3E9A as u32,
            MEDIASERVER::MF_E_MEDIA_SOURCE_WRONGSTATE => 0xC00D3E9B as u32,
            MEDIASERVER::MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED => 0xC00D3E9C as u32,
            MEDIASERVER::MF_E_CANNOT_FIND_KEYFRAME_SAMPLE => 0xC00D3E9D as u32,
            MEDIASERVER::MF_E_NETWORK_RESOURCE_FAILURE => 0xC00D4268 as u32,
            MEDIASERVER::MF_E_NET_WRITE => 0xC00D4269 as u32,
            MEDIASERVER::MF_E_NET_READ => 0xC00D426A as u32,
            MEDIASERVER::MF_E_NET_REQUIRE_NETWORK => 0xC00D426B as u32,
            MEDIASERVER::MF_E_NET_REQUIRE_ASYNC => 0xC00D426C as u32,
            MEDIASERVER::MF_E_NET_BWLEVEL_NOT_SUPPORTED => 0xC00D426D as u32,
            MEDIASERVER::MF_E_NET_STREAMGROUPS_NOT_SUPPORTED => 0xC00D426E as u32,
            MEDIASERVER::MF_E_NET_MANUALSS_NOT_SUPPORTED => 0xC00D426F as u32,
            MEDIASERVER::MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR => 0xC00D4270 as u32,
            MEDIASERVER::MF_E_NET_CACHESTREAM_NOT_FOUND => 0xC00D4271 as u32,
            MEDIASERVER::MF_E_NET_REQUIRE_INPUT => 0xC00D4274 as u32,
            MEDIASERVER::MF_E_NET_REDIRECT => 0xC00D4275 as u32,
            MEDIASERVER::MF_E_NET_REDIRECT_TO_PROXY => 0xC00D4276 as u32,
            MEDIASERVER::MF_E_NET_TOO_MANY_REDIRECTS => 0xC00D4277 as u32,
            MEDIASERVER::MF_E_NET_TIMEOUT => 0xC00D4278 as u32,
            MEDIASERVER::MF_E_NET_CLIENT_CLOSE => 0xC00D4279 as u32,
            MEDIASERVER::MF_E_NET_BAD_CONTROL_DATA => 0xC00D427A as u32,
            MEDIASERVER::MF_E_NET_INCOMPATIBLE_SERVER => 0xC00D427B as u32,
            MEDIASERVER::MF_E_NET_UNSAFE_URL => 0xC00D427C as u32,
            MEDIASERVER::MF_E_NET_CACHE_NO_DATA => 0xC00D427D as u32,
            MEDIASERVER::MF_E_NET_EOL => 0xC00D427E as u32,
            MEDIASERVER::MF_E_NET_BAD_REQUEST => 0xC00D427F as u32,
            MEDIASERVER::MF_E_NET_INTERNAL_SERVER_ERROR => 0xC00D4280 as u32,
            MEDIASERVER::MF_E_NET_SESSION_NOT_FOUND => 0xC00D4281 as u32,
            MEDIASERVER::MF_E_NET_NOCONNECTION => 0xC00D4282 as u32,
            MEDIASERVER::MF_E_NET_CONNECTION_FAILURE => 0xC00D4283 as u32,
            MEDIASERVER::MF_E_NET_INCOMPATIBLE_PUSHSERVER => 0xC00D4284 as u32,
            MEDIASERVER::MF_E_NET_SERVER_ACCESSDENIED => 0xC00D4285 as u32,
            MEDIASERVER::MF_E_NET_PROXY_ACCESSDENIED => 0xC00D4286 as u32,
            MEDIASERVER::MF_E_NET_CANNOTCONNECT => 0xC00D4287 as u32,
            MEDIASERVER::MF_E_NET_INVALID_PUSH_TEMPLATE => 0xC00D4288 as u32,
            MEDIASERVER::MF_E_NET_INVALID_PUSH_PUBLISHING_POINT => 0xC00D4289 as u32,
            MEDIASERVER::MF_E_NET_BUSY => 0xC00D428A as u32,
            MEDIASERVER::MF_E_NET_RESOURCE_GONE => 0xC00D428B as u32,
            MEDIASERVER::MF_E_NET_ERROR_FROM_PROXY => 0xC00D428C as u32,
            MEDIASERVER::MF_E_NET_PROXY_TIMEOUT => 0xC00D428D as u32,
            MEDIASERVER::MF_E_NET_SERVER_UNAVAILABLE => 0xC00D428E as u32,
            MEDIASERVER::MF_E_NET_TOO_MUCH_DATA => 0xC00D428F as u32,
            MEDIASERVER::MF_E_NET_SESSION_INVALID => 0xC00D4290 as u32,
            MEDIASERVER::MF_E_OFFLINE_MODE => 0xC00D4291 as u32,
            MEDIASERVER::MF_E_NET_UDP_BLOCKED => 0xC00D4292 as u32,
            MEDIASERVER::MF_E_NET_UNSUPPORTED_CONFIGURATION => 0xC00D4293 as u32,
            MEDIASERVER::MF_E_NET_PROTOCOL_DISABLED => 0xC00D4294 as u32,
            MEDIASERVER::MF_E_ALREADY_INITIALIZED => 0xC00D4650 as u32,
            MEDIASERVER::MF_E_BANDWIDTH_OVERRUN => 0xC00D4651 as u32,
            MEDIASERVER::MF_E_LATE_SAMPLE => 0xC00D4652 as u32,
            MEDIASERVER::MF_E_FLUSH_NEEDED => 0xC00D4653 as u32,
            MEDIASERVER::MF_E_INVALID_PROFILE => 0xC00D4654 as u32,
            MEDIASERVER::MF_E_INDEX_NOT_COMMITTED => 0xC00D4655 as u32,
            MEDIASERVER::MF_E_NO_INDEX => 0xC00D4656 as u32,
            MEDIASERVER::MF_E_CANNOT_INDEX_IN_PLACE => 0xC00D4657 as u32,
            MEDIASERVER::MF_E_MISSING_ASF_LEAKYBUCKET => 0xC00D4658 as u32,
            MEDIASERVER::MF_E_INVALID_ASF_STREAMID => 0xC00D4659 as u32,
            MEDIASERVER::MF_E_STREAMSINK_REMOVED => 0xC00D4A38 as u32,
            MEDIASERVER::MF_E_STREAMSINKS_OUT_OF_SYNC => 0xC00D4A3A as u32,
            MEDIASERVER::MF_E_STREAMSINKS_FIXED => 0xC00D4A3B as u32,
            MEDIASERVER::MF_E_STREAMSINK_EXISTS => 0xC00D4A3C as u32,
            MEDIASERVER::MF_E_SAMPLEALLOCATOR_CANCELED => 0xC00D4A3D as u32,
            MEDIASERVER::MF_E_SAMPLEALLOCATOR_EMPTY => 0xC00D4A3E as u32,
            MEDIASERVER::MF_E_SINK_ALREADYSTOPPED => 0xC00D4A3F as u32,
            MEDIASERVER::MF_E_ASF_FILESINK_BITRATE_UNKNOWN => 0xC00D4A40 as u32,
            MEDIASERVER::MF_E_SINK_NO_STREAMS => 0xC00D4A41 as u32,
            MEDIASERVER::MF_E_METADATA_TOO_LONG => 0xC00D4A43 as u32,
            MEDIASERVER::MF_E_SINK_NO_SAMPLES_PROCESSED => 0xC00D4A44 as u32,
            MEDIASERVER::MF_E_VIDEO_REN_NO_PROCAMP_HW => 0xC00D4E20 as u32,
            MEDIASERVER::MF_E_VIDEO_REN_NO_DEINTERLACE_HW => 0xC00D4E21 as u32,
            MEDIASERVER::MF_E_VIDEO_REN_COPYPROT_FAILED => 0xC00D4E22 as u32,
            MEDIASERVER::MF_E_VIDEO_REN_SURFACE_NOT_SHARED => 0xC00D4E23 as u32,
            MEDIASERVER::MF_E_VIDEO_DEVICE_LOCKED => 0xC00D4E24 as u32,
            MEDIASERVER::MF_E_NEW_VIDEO_DEVICE => 0xC00D4E25 as u32,
            MEDIASERVER::MF_E_NO_VIDEO_SAMPLE_AVAILABLE => 0xC00D4E26 as u32,
            MEDIASERVER::MF_E_NO_AUDIO_PLAYBACK_DEVICE => 0xC00D4E84 as u32,
            MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE => 0xC00D4E85 as u32,
            MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED => 0xC00D4E86 as u32,
            MEDIASERVER::MF_E_AUDIO_SERVICE_NOT_RUNNING => 0xC00D4E87 as u32,
            MEDIASERVER::MF_E_TOPO_INVALID_OPTIONAL_NODE => 0xC00D520E as u32,
            MEDIASERVER::MF_E_TOPO_CANNOT_FIND_DECRYPTOR => 0xC00D5211 as u32,
            MEDIASERVER::MF_E_TOPO_CODEC_NOT_FOUND => 0xC00D5212 as u32,
            MEDIASERVER::MF_E_TOPO_CANNOT_CONNECT => 0xC00D5213 as u32,
            MEDIASERVER::MF_E_TOPO_UNSUPPORTED => 0xC00D5214 as u32,
            MEDIASERVER::MF_E_TOPO_INVALID_TIME_ATTRIBUTES => 0xC00D5215 as u32,
            MEDIASERVER::MF_E_TOPO_LOOPS_IN_TOPOLOGY => 0xC00D5216 as u32,
            MEDIASERVER::MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR => 0xC00D5217 as u32,
            MEDIASERVER::MF_E_TOPO_MISSING_STREAM_DESCRIPTOR => 0xC00D5218 as u32,
            MEDIASERVER::MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED => 0xC00D5219 as u32,
            MEDIASERVER::MF_E_TOPO_MISSING_SOURCE => 0xC00D521A as u32,
            MEDIASERVER::MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED => 0xC00D521B as u32,
            MEDIASERVER::MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID => 0xC00D61AC as u32,
            MEDIASERVER::MF_E_NO_SOURCE_IN_CACHE => 0xC00D61AE as u32,
            MEDIASERVER::MF_E_TRANSFORM_TYPE_NOT_SET => 0xC00D6D60 as u32,
            MEDIASERVER::MF_E_TRANSFORM_STREAM_CHANGE => 0xC00D6D61 as u32,
            MEDIASERVER::MF_E_TRANSFORM_INPUT_REMAINING => 0xC00D6D62 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_MISSING => 0xC00D6D63 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT => 0xC00D6D64 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_TRUNCATED => 0xC00D6D65 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED => 0xC00D6D66 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG => 0xC00D6D67 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE => 0xC00D6D68 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM => 0xC00D6D69 as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG => 0xC00D6D6A as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE => 0xC00D6D6B as u32,
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE => 0xC00D6D6C as u32,
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE => 0xC00D6D6D as u32,
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE => 0xC00D6D6E as u32,
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION => 0xC00D6D6F as u32,
            MEDIASERVER::MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES => 0xC00D6D70 as u32,
            MEDIASERVER::MF_E_TRANSFORM_NEED_MORE_INPUT => 0xC00D6D72 as u32,
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG => 0xC00D6D73 as u32,
            MEDIASERVER::MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING => 0xC00D6D74 as u32,
            MEDIASERVER::MF_E_UNSUPPORTED_D3D_TYPE => 0xC00D6D76 as u32,
            MEDIASERVER::MF_E_TRANSFORM_ASYNC_LOCKED => 0xC00D6D77 as u32,
            MEDIASERVER::MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER => 0xC00D6D78 as u32,
            MEDIASERVER::MF_E_LICENSE_INCORRECT_RIGHTS => 0xC00D7148 as u32,
            MEDIASERVER::MF_E_LICENSE_OUTOFDATE => 0xC00D7149 as u32,
            MEDIASERVER::MF_E_LICENSE_REQUIRED => 0xC00D714A as u32,
            MEDIASERVER::MF_E_DRM_HARDWARE_INCONSISTENT => 0xC00D714B as u32,
            MEDIASERVER::MF_E_NO_CONTENT_PROTECTION_MANAGER => 0xC00D714C as u32,
            MEDIASERVER::MF_E_LICENSE_RESTORE_NO_RIGHTS => 0xC00D714D as u32,
            MEDIASERVER::MF_E_BACKUP_RESTRICTED_LICENSE => 0xC00D714E as u32,
            MEDIASERVER::MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION => 0xC00D714F as u32,
            MEDIASERVER::MF_E_COMPONENT_REVOKED => 0xC00D7151 as u32,
            MEDIASERVER::MF_E_TRUST_DISABLED => 0xC00D7152 as u32,
            MEDIASERVER::MF_E_WMDRMOTA_NO_ACTION => 0xC00D7153 as u32,
            MEDIASERVER::MF_E_WMDRMOTA_ACTION_ALREADY_SET => 0xC00D7154 as u32,
            MEDIASERVER::MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE => 0xC00D7155 as u32,
            MEDIASERVER::MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED => 0xC00D7156 as u32,
            MEDIASERVER::MF_E_WMDRMOTA_ACTION_MISMATCH => 0xC00D7157 as u32,
            MEDIASERVER::MF_E_WMDRMOTA_INVALID_POLICY => 0xC00D7158 as u32,
            MEDIASERVER::MF_E_POLICY_UNSUPPORTED => 0xC00D7159 as u32,
            MEDIASERVER::MF_E_OPL_NOT_SUPPORTED => 0xC00D715A as u32,
            MEDIASERVER::MF_E_TOPOLOGY_VERIFICATION_FAILED => 0xC00D715B as u32,
            MEDIASERVER::MF_E_SIGNATURE_VERIFICATION_FAILED => 0xC00D715C as u32,
            MEDIASERVER::MF_E_DEBUGGING_NOT_ALLOWED => 0xC00D715D as u32,
            MEDIASERVER::MF_E_CODE_EXPIRED => 0xC00D715E as u32,
            MEDIASERVER::MF_E_GRL_VERSION_TOO_LOW => 0xC00D715F as u32,
            MEDIASERVER::MF_E_GRL_RENEWAL_NOT_FOUND => 0xC00D7160 as u32,
            MEDIASERVER::MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND => 0xC00D7161 as u32,
            MEDIASERVER::MF_E_KERNEL_UNTRUSTED => 0xC00D7162 as u32,
            MEDIASERVER::MF_E_PEAUTH_UNTRUSTED => 0xC00D7163 as u32,
            MEDIASERVER::MF_E_NON_PE_PROCESS => 0xC00D7165 as u32,
            MEDIASERVER::MF_E_REBOOT_REQUIRED => 0xC00D7167 as u32,
            MEDIASERVER::MF_E_GRL_INVALID_FORMAT => 0xC00D716A as u32,
            MEDIASERVER::MF_E_GRL_UNRECOGNIZED_FORMAT => 0xC00D716B as u32,
            MEDIASERVER::MF_E_ALL_PROCESS_RESTART_REQUIRED => 0xC00D716C as u32,
            MEDIASERVER::MF_E_PROCESS_RESTART_REQUIRED => 0xC00D716D as u32,
            MEDIASERVER::MF_E_USERMODE_UNTRUSTED => 0xC00D716E as u32,
            MEDIASERVER::MF_E_PEAUTH_SESSION_NOT_STARTED => 0xC00D716F as u32,
            MEDIASERVER::MF_E_INSUFFICIENT_BUFFER => 0xC00D7170 as u32,
            MEDIASERVER::MF_E_PEAUTH_PUBLICKEY_REVOKED => 0xC00D7171 as u32,
            MEDIASERVER::MF_E_GRL_ABSENT => 0xC00D7172 as u32,
            MEDIASERVER::MF_E_PE_UNTRUSTED => 0xC00D7174 as u32,
            MEDIASERVER::MF_E_PEAUTH_NOT_STARTED => 0xC00D7175 as u32,
            MEDIASERVER::MF_E_INCOMPATIBLE_SAMPLE_PROTECTION => 0xC00D7176 as u32,
            MEDIASERVER::MF_E_PE_SESSIONS_MAXED => 0xC00D7177 as u32,
            MEDIASERVER::MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED => 0xC00D7178 as u32,
            MEDIASERVER::MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED => 0xC00D7179 as u32,
            MEDIASERVER::MF_E_ITA_UNSUPPORTED_ACTION => 0xC00D717A as u32,
            MEDIASERVER::MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS => 0xC00D717B as u32,
            MEDIASERVER::MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS => 0xC00D717C as u32,
            MEDIASERVER::MF_E_BAD_OPL_STRUCTURE_FORMAT => 0xC00D717D as u32,
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID => 0xC00D717E as u32,
            MEDIASERVER::MF_E_NO_PMP_HOST => 0xC00D717F as u32,
            MEDIASERVER::MF_E_ITA_OPL_DATA_NOT_INITIALIZED => 0xC00D7180 as u32,
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT => 0xC00D7181 as u32,
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT => 0xC00D7182 as u32,
            MEDIASERVER::MF_E_CLOCK_INVALID_CONTINUITY_KEY => 0xC00D9C40 as u32,
            MEDIASERVER::MF_E_CLOCK_NO_TIME_SOURCE => 0xC00D9C41 as u32,
            MEDIASERVER::MF_E_CLOCK_STATE_ALREADY_SET => 0xC00D9C42 as u32,
            MEDIASERVER::MF_E_CLOCK_NOT_SIMPLE => 0xC00D9C43 as u32,
            MEDIASERVER::MF_E_NO_MORE_DROP_MODES => 0xC00DA028 as u32,
            MEDIASERVER::MF_E_NO_MORE_QUALITY_LEVELS => 0xC00DA029 as u32,
            MEDIASERVER::MF_E_DROPTIME_NOT_SUPPORTED => 0xC00DA02A as u32,
            MEDIASERVER::MF_E_QUALITYKNOB_WAIT_LONGER => 0xC00DA02B as u32,
            MEDIASERVER::MF_E_QM_INVALIDSTATE => 0xC00DA02C as u32,
            MEDIASERVER::MF_E_TRANSCODE_NO_CONTAINERTYPE => 0xC00DA410 as u32,
            MEDIASERVER::MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS => 0xC00DA411 as u32,
            MEDIASERVER::MF_E_TRANSCODE_NO_MATCHING_ENCODER => 0xC00DA412 as u32,
            MEDIASERVER::MF_E_ALLOCATOR_NOT_INITIALIZED => 0xC00DA7F8 as u32,
            MEDIASERVER::MF_E_ALLOCATOR_NOT_COMMITED => 0xC00DA7F9 as u32,
            MEDIASERVER::MF_E_ALLOCATOR_ALREADY_COMMITED => 0xC00DA7FA as u32,
            MEDIASERVER::MF_E_STREAM_ERROR => 0xC00DA7FB as u32,
            MEDIASERVER::MF_E_INVALID_STREAM_STATE => 0xC00DA7FC as u32,
            MEDIASERVER::MF_E_HW_STREAM_NOT_CONNECTED => 0xC00DA7FD as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            MEDIASERVER::NS_S_CALLPENDING => RawError::Kind(MEDIASERVER::NS_S_CALLPENDING),
            MEDIASERVER::NS_S_CALLABORTED => RawError::Kind(MEDIASERVER::NS_S_CALLABORTED),
            MEDIASERVER::NS_S_STREAM_TRUNCATED => RawError::Kind(MEDIASERVER::NS_S_STREAM_TRUNCATED),
            MEDIASERVER::NS_S_REBUFFERING => RawError::Kind(MEDIASERVER::NS_S_REBUFFERING),
            MEDIASERVER::NS_S_DEGRADING_QUALITY => RawError::Kind(MEDIASERVER::NS_S_DEGRADING_QUALITY),
            MEDIASERVER::NS_S_TRANSCRYPTOR_EOF => RawError::Kind(MEDIASERVER::NS_S_TRANSCRYPTOR_EOF),
            MEDIASERVER::NS_S_WMP_UI_VERSIONMISMATCH => RawError::Kind(MEDIASERVER::NS_S_WMP_UI_VERSIONMISMATCH),
            MEDIASERVER::NS_S_WMP_EXCEPTION => RawError::Kind(MEDIASERVER::NS_S_WMP_EXCEPTION),
            MEDIASERVER::NS_S_WMP_LOADED_GIF_IMAGE => RawError::Kind(MEDIASERVER::NS_S_WMP_LOADED_GIF_IMAGE),
            MEDIASERVER::NS_S_WMP_LOADED_PNG_IMAGE => RawError::Kind(MEDIASERVER::NS_S_WMP_LOADED_PNG_IMAGE),
            MEDIASERVER::NS_S_WMP_LOADED_BMP_IMAGE => RawError::Kind(MEDIASERVER::NS_S_WMP_LOADED_BMP_IMAGE),
            MEDIASERVER::NS_S_WMP_LOADED_JPG_IMAGE => RawError::Kind(MEDIASERVER::NS_S_WMP_LOADED_JPG_IMAGE),
            MEDIASERVER::NS_S_WMG_FORCE_DROP_FRAME => RawError::Kind(MEDIASERVER::NS_S_WMG_FORCE_DROP_FRAME),
            MEDIASERVER::NS_S_WMR_ALREADYRENDERED => RawError::Kind(MEDIASERVER::NS_S_WMR_ALREADYRENDERED),
            MEDIASERVER::NS_S_WMR_PINTYPEPARTIALMATCH => RawError::Kind(MEDIASERVER::NS_S_WMR_PINTYPEPARTIALMATCH),
            MEDIASERVER::NS_S_WMR_PINTYPEFULLMATCH => RawError::Kind(MEDIASERVER::NS_S_WMR_PINTYPEFULLMATCH),
            MEDIASERVER::NS_S_WMG_ADVISE_DROP_FRAME => RawError::Kind(MEDIASERVER::NS_S_WMG_ADVISE_DROP_FRAME),
            MEDIASERVER::NS_S_WMG_ADVISE_DROP_TO_KEYFRAME => RawError::Kind(MEDIASERVER::NS_S_WMG_ADVISE_DROP_TO_KEYFRAME),
            MEDIASERVER::NS_S_NEED_TO_BUY_BURN_RIGHTS => RawError::Kind(MEDIASERVER::NS_S_NEED_TO_BUY_BURN_RIGHTS),
            MEDIASERVER::NS_S_WMPCORE_PLAYLISTCLEARABORT => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLISTCLEARABORT),
            MEDIASERVER::NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT),
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_CREATION_PENDING => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLIST_CREATION_PENDING),
            MEDIASERVER::NS_S_WMPCORE_MEDIA_VALIDATION_PENDING => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_MEDIA_VALIDATION_PENDING),
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED),
            MEDIASERVER::NS_S_WMPCORE_COMMAND_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_COMMAND_NOT_AVAILABLE),
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED),
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS),
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA),
            MEDIASERVER::NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING),
            MEDIASERVER::NS_S_WMPCORE_MORE_NODES_AVAIABLE => RawError::Kind(MEDIASERVER::NS_S_WMPCORE_MORE_NODES_AVAIABLE),
            MEDIASERVER::NS_S_WMPBR_SUCCESS => RawError::Kind(MEDIASERVER::NS_S_WMPBR_SUCCESS),
            MEDIASERVER::NS_S_WMPBR_PARTIALSUCCESS => RawError::Kind(MEDIASERVER::NS_S_WMPBR_PARTIALSUCCESS),
            MEDIASERVER::NS_S_WMPEFFECT_TRANSPARENT => RawError::Kind(MEDIASERVER::NS_S_WMPEFFECT_TRANSPARENT),
            MEDIASERVER::NS_S_WMPEFFECT_OPAQUE => RawError::Kind(MEDIASERVER::NS_S_WMPEFFECT_OPAQUE),
            MEDIASERVER::NS_S_OPERATION_PENDING => RawError::Kind(MEDIASERVER::NS_S_OPERATION_PENDING),
            MEDIASERVER::NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE => RawError::Kind(MEDIASERVER::NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE),
            MEDIASERVER::NS_S_NAVIGATION_COMPLETE_WITH_ERRORS => RawError::Kind(MEDIASERVER::NS_S_NAVIGATION_COMPLETE_WITH_ERRORS),
            MEDIASERVER::NS_S_TRACK_ALREADY_DOWNLOADED => RawError::Kind(MEDIASERVER::NS_S_TRACK_ALREADY_DOWNLOADED),
            MEDIASERVER::NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS => RawError::Kind(MEDIASERVER::NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS),
            MEDIASERVER::NS_S_DRM_LICENSE_ACQUIRED => RawError::Kind(MEDIASERVER::NS_S_DRM_LICENSE_ACQUIRED),
            MEDIASERVER::NS_S_DRM_INDIVIDUALIZED => RawError::Kind(MEDIASERVER::NS_S_DRM_INDIVIDUALIZED),
            MEDIASERVER::NS_S_DRM_MONITOR_CANCELLED => RawError::Kind(MEDIASERVER::NS_S_DRM_MONITOR_CANCELLED),
            MEDIASERVER::NS_S_DRM_ACQUIRE_CANCELLED => RawError::Kind(MEDIASERVER::NS_S_DRM_ACQUIRE_CANCELLED),
            MEDIASERVER::NS_S_DRM_BURNABLE_TRACK => RawError::Kind(MEDIASERVER::NS_S_DRM_BURNABLE_TRACK),
            MEDIASERVER::NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION => RawError::Kind(MEDIASERVER::NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION),
            MEDIASERVER::NS_S_DRM_NEEDS_INDIVIDUALIZATION => RawError::Kind(MEDIASERVER::NS_S_DRM_NEEDS_INDIVIDUALIZATION),
            MEDIASERVER::NS_S_REBOOT_RECOMMENDED => RawError::Kind(MEDIASERVER::NS_S_REBOOT_RECOMMENDED),
            MEDIASERVER::NS_S_REBOOT_REQUIRED => RawError::Kind(MEDIASERVER::NS_S_REBOOT_REQUIRED),
            MEDIASERVER::NS_S_EOSRECEDING => RawError::Kind(MEDIASERVER::NS_S_EOSRECEDING),
            MEDIASERVER::NS_S_CHANGENOTICE => RawError::Kind(MEDIASERVER::NS_S_CHANGENOTICE),
            MEDIASERVER::MF_S_MULTIPLE_BEGIN => RawError::Kind(MEDIASERVER::MF_S_MULTIPLE_BEGIN),
            MEDIASERVER::MF_S_ACTIVATE_REPLACED => RawError::Kind(MEDIASERVER::MF_S_ACTIVATE_REPLACED),
            MEDIASERVER::MF_S_SINK_NOT_FINALIZED => RawError::Kind(MEDIASERVER::MF_S_SINK_NOT_FINALIZED),
            MEDIASERVER::MF_S_SEQUENCER_CONTEXT_CANCELED => RawError::Kind(MEDIASERVER::MF_S_SEQUENCER_CONTEXT_CANCELED),
            MEDIASERVER::MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM => RawError::Kind(MEDIASERVER::MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM),
            MEDIASERVER::MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT => RawError::Kind(MEDIASERVER::MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT),
            MEDIASERVER::MF_S_PROTECTION_NOT_REQUIRED => RawError::Kind(MEDIASERVER::MF_S_PROTECTION_NOT_REQUIRED),
            MEDIASERVER::MF_S_WAIT_FOR_POLICY_SET => RawError::Kind(MEDIASERVER::MF_S_WAIT_FOR_POLICY_SET),
            MEDIASERVER::MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT => RawError::Kind(MEDIASERVER::MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT),
            MEDIASERVER::MF_S_PE_TRUSTED => RawError::Kind(MEDIASERVER::MF_S_PE_TRUSTED),
            MEDIASERVER::MF_S_CLOCK_STOPPED => RawError::Kind(MEDIASERVER::MF_S_CLOCK_STOPPED),
            MEDIASERVER::NS_I_TIGER_START => RawError::Kind(MEDIASERVER::NS_I_TIGER_START),
            MEDIASERVER::NS_I_CUB_START => RawError::Kind(MEDIASERVER::NS_I_CUB_START),
            MEDIASERVER::NS_I_CUB_RUNNING => RawError::Kind(MEDIASERVER::NS_I_CUB_RUNNING),
            MEDIASERVER::NS_I_DISK_START => RawError::Kind(MEDIASERVER::NS_I_DISK_START),
            MEDIASERVER::NS_I_DISK_REBUILD_STARTED => RawError::Kind(MEDIASERVER::NS_I_DISK_REBUILD_STARTED),
            MEDIASERVER::NS_I_DISK_REBUILD_FINISHED => RawError::Kind(MEDIASERVER::NS_I_DISK_REBUILD_FINISHED),
            MEDIASERVER::NS_I_DISK_REBUILD_ABORTED => RawError::Kind(MEDIASERVER::NS_I_DISK_REBUILD_ABORTED),
            MEDIASERVER::NS_I_LIMIT_FUNNELS => RawError::Kind(MEDIASERVER::NS_I_LIMIT_FUNNELS),
            MEDIASERVER::NS_I_START_DISK => RawError::Kind(MEDIASERVER::NS_I_START_DISK),
            MEDIASERVER::NS_I_STOP_DISK => RawError::Kind(MEDIASERVER::NS_I_STOP_DISK),
            MEDIASERVER::NS_I_STOP_CUB => RawError::Kind(MEDIASERVER::NS_I_STOP_CUB),
            MEDIASERVER::NS_I_KILL_USERSESSION => RawError::Kind(MEDIASERVER::NS_I_KILL_USERSESSION),
            MEDIASERVER::NS_I_KILL_CONNECTION => RawError::Kind(MEDIASERVER::NS_I_KILL_CONNECTION),
            MEDIASERVER::NS_I_REBUILD_DISK => RawError::Kind(MEDIASERVER::NS_I_REBUILD_DISK),
            MEDIASERVER::MCMADM_I_NO_EVENTS => RawError::Kind(MEDIASERVER::MCMADM_I_NO_EVENTS),
            MEDIASERVER::NS_I_LOGGING_FAILED => RawError::Kind(MEDIASERVER::NS_I_LOGGING_FAILED),
            MEDIASERVER::NS_I_LIMIT_BANDWIDTH => RawError::Kind(MEDIASERVER::NS_I_LIMIT_BANDWIDTH),
            MEDIASERVER::NS_I_CUB_UNFAIL_LINK => RawError::Kind(MEDIASERVER::NS_I_CUB_UNFAIL_LINK),
            MEDIASERVER::NS_I_RESTRIPE_START => RawError::Kind(MEDIASERVER::NS_I_RESTRIPE_START),
            MEDIASERVER::NS_I_RESTRIPE_DONE => RawError::Kind(MEDIASERVER::NS_I_RESTRIPE_DONE),
            MEDIASERVER::NS_I_RESTRIPE_DISK_OUT => RawError::Kind(MEDIASERVER::NS_I_RESTRIPE_DISK_OUT),
            MEDIASERVER::NS_I_RESTRIPE_CUB_OUT => RawError::Kind(MEDIASERVER::NS_I_RESTRIPE_CUB_OUT),
            MEDIASERVER::NS_I_DISK_STOP => RawError::Kind(MEDIASERVER::NS_I_DISK_STOP),
            MEDIASERVER::NS_I_PLAYLIST_CHANGE_RECEDING => RawError::Kind(MEDIASERVER::NS_I_PLAYLIST_CHANGE_RECEDING),
            MEDIASERVER::NS_I_RECONNECTED => RawError::Kind(MEDIASERVER::NS_I_RECONNECTED),
            MEDIASERVER::NS_I_NOLOG_STOP => RawError::Kind(MEDIASERVER::NS_I_NOLOG_STOP),
            MEDIASERVER::NS_I_EXISTING_PACKETIZER => RawError::Kind(MEDIASERVER::NS_I_EXISTING_PACKETIZER),
            MEDIASERVER::NS_I_MANUAL_PROXY => RawError::Kind(MEDIASERVER::NS_I_MANUAL_PROXY),
            MEDIASERVER::MF_S_ASF_PARSEINPROGRESS => RawError::Kind(MEDIASERVER::MF_S_ASF_PARSEINPROGRESS),
            MEDIASERVER::MF_I_MANUAL_PROXY => RawError::Kind(MEDIASERVER::MF_I_MANUAL_PROXY),
            MEDIASERVER::NS_W_SERVER_BANDWIDTH_LIMIT => RawError::Kind(MEDIASERVER::NS_W_SERVER_BANDWIDTH_LIMIT),
            MEDIASERVER::NS_W_FILE_BANDWIDTH_LIMIT => RawError::Kind(MEDIASERVER::NS_W_FILE_BANDWIDTH_LIMIT),
            MEDIASERVER::NS_W_UNKNOWN_EVENT => RawError::Kind(MEDIASERVER::NS_W_UNKNOWN_EVENT),
            MEDIASERVER::NS_I_CATATONIC_FAILURE => RawError::Kind(MEDIASERVER::NS_I_CATATONIC_FAILURE),
            MEDIASERVER::NS_I_CATATONIC_AUTO_UNFAIL => RawError::Kind(MEDIASERVER::NS_I_CATATONIC_AUTO_UNFAIL),
            MEDIASERVER::NS_E_NOCONNECTION => RawError::Kind(MEDIASERVER::NS_E_NOCONNECTION),
            MEDIASERVER::NS_E_CANNOTCONNECT => RawError::Kind(MEDIASERVER::NS_E_CANNOTCONNECT),
            MEDIASERVER::NS_E_CANNOTDESTROYTITLE => RawError::Kind(MEDIASERVER::NS_E_CANNOTDESTROYTITLE),
            MEDIASERVER::NS_E_CANNOTRENAMETITLE => RawError::Kind(MEDIASERVER::NS_E_CANNOTRENAMETITLE),
            MEDIASERVER::NS_E_CANNOTOFFLINEDISK => RawError::Kind(MEDIASERVER::NS_E_CANNOTOFFLINEDISK),
            MEDIASERVER::NS_E_CANNOTONLINEDISK => RawError::Kind(MEDIASERVER::NS_E_CANNOTONLINEDISK),
            MEDIASERVER::NS_E_NOREGISTEREDWALKER => RawError::Kind(MEDIASERVER::NS_E_NOREGISTEREDWALKER),
            MEDIASERVER::NS_E_NOFUNNEL => RawError::Kind(MEDIASERVER::NS_E_NOFUNNEL),
            MEDIASERVER::NS_E_NO_LOCALPLAY => RawError::Kind(MEDIASERVER::NS_E_NO_LOCALPLAY),
            MEDIASERVER::NS_E_NETWORK_BUSY => RawError::Kind(MEDIASERVER::NS_E_NETWORK_BUSY),
            MEDIASERVER::NS_E_TOO_MANY_SESS => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_SESS),
            MEDIASERVER::NS_E_ALREADY_CONNECTED => RawError::Kind(MEDIASERVER::NS_E_ALREADY_CONNECTED),
            MEDIASERVER::NS_E_INVALID_INDEX => RawError::Kind(MEDIASERVER::NS_E_INVALID_INDEX),
            MEDIASERVER::NS_E_PROTOCOL_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_PROTOCOL_MISMATCH),
            MEDIASERVER::NS_E_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_TIMEOUT),
            MEDIASERVER::NS_E_NET_WRITE => RawError::Kind(MEDIASERVER::NS_E_NET_WRITE),
            MEDIASERVER::NS_E_NET_READ => RawError::Kind(MEDIASERVER::NS_E_NET_READ),
            MEDIASERVER::NS_E_DISK_WRITE => RawError::Kind(MEDIASERVER::NS_E_DISK_WRITE),
            MEDIASERVER::NS_E_DISK_READ => RawError::Kind(MEDIASERVER::NS_E_DISK_READ),
            MEDIASERVER::NS_E_FILE_WRITE => RawError::Kind(MEDIASERVER::NS_E_FILE_WRITE),
            MEDIASERVER::NS_E_FILE_READ => RawError::Kind(MEDIASERVER::NS_E_FILE_READ),
            MEDIASERVER::NS_E_FILE_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_FILE_NOT_FOUND),
            MEDIASERVER::NS_E_FILE_EXISTS => RawError::Kind(MEDIASERVER::NS_E_FILE_EXISTS),
            MEDIASERVER::NS_E_INVALID_NAME => RawError::Kind(MEDIASERVER::NS_E_INVALID_NAME),
            MEDIASERVER::NS_E_FILE_OPEN_FAILED => RawError::Kind(MEDIASERVER::NS_E_FILE_OPEN_FAILED),
            MEDIASERVER::NS_E_FILE_ALLOCATION_FAILED => RawError::Kind(MEDIASERVER::NS_E_FILE_ALLOCATION_FAILED),
            MEDIASERVER::NS_E_FILE_INIT_FAILED => RawError::Kind(MEDIASERVER::NS_E_FILE_INIT_FAILED),
            MEDIASERVER::NS_E_FILE_PLAY_FAILED => RawError::Kind(MEDIASERVER::NS_E_FILE_PLAY_FAILED),
            MEDIASERVER::NS_E_SET_DISK_UID_FAILED => RawError::Kind(MEDIASERVER::NS_E_SET_DISK_UID_FAILED),
            MEDIASERVER::NS_E_INDUCED => RawError::Kind(MEDIASERVER::NS_E_INDUCED),
            MEDIASERVER::NS_E_CCLINK_DOWN => RawError::Kind(MEDIASERVER::NS_E_CCLINK_DOWN),
            MEDIASERVER::NS_E_INTERNAL => RawError::Kind(MEDIASERVER::NS_E_INTERNAL),
            MEDIASERVER::NS_E_BUSY => RawError::Kind(MEDIASERVER::NS_E_BUSY),
            MEDIASERVER::NS_E_UNRECOGNIZED_STREAM_TYPE => RawError::Kind(MEDIASERVER::NS_E_UNRECOGNIZED_STREAM_TYPE),
            MEDIASERVER::NS_E_NETWORK_SERVICE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_NETWORK_SERVICE_FAILURE),
            MEDIASERVER::NS_E_NETWORK_RESOURCE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_NETWORK_RESOURCE_FAILURE),
            MEDIASERVER::NS_E_CONNECTION_FAILURE => RawError::Kind(MEDIASERVER::NS_E_CONNECTION_FAILURE),
            MEDIASERVER::NS_E_SHUTDOWN => RawError::Kind(MEDIASERVER::NS_E_SHUTDOWN),
            MEDIASERVER::NS_E_INVALID_REQUEST => RawError::Kind(MEDIASERVER::NS_E_INVALID_REQUEST),
            MEDIASERVER::NS_E_INSUFFICIENT_BANDWIDTH => RawError::Kind(MEDIASERVER::NS_E_INSUFFICIENT_BANDWIDTH),
            MEDIASERVER::NS_E_NOT_REBUILDING => RawError::Kind(MEDIASERVER::NS_E_NOT_REBUILDING),
            MEDIASERVER::NS_E_LATE_OPERATION => RawError::Kind(MEDIASERVER::NS_E_LATE_OPERATION),
            MEDIASERVER::NS_E_INVALID_DATA => RawError::Kind(MEDIASERVER::NS_E_INVALID_DATA),
            MEDIASERVER::NS_E_FILE_BANDWIDTH_LIMIT => RawError::Kind(MEDIASERVER::NS_E_FILE_BANDWIDTH_LIMIT),
            MEDIASERVER::NS_E_OPEN_FILE_LIMIT => RawError::Kind(MEDIASERVER::NS_E_OPEN_FILE_LIMIT),
            MEDIASERVER::NS_E_BAD_CONTROL_DATA => RawError::Kind(MEDIASERVER::NS_E_BAD_CONTROL_DATA),
            MEDIASERVER::NS_E_NO_STREAM => RawError::Kind(MEDIASERVER::NS_E_NO_STREAM),
            MEDIASERVER::NS_E_STREAM_END => RawError::Kind(MEDIASERVER::NS_E_STREAM_END),
            MEDIASERVER::NS_E_SERVER_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_SERVER_NOT_FOUND),
            MEDIASERVER::NS_E_DUPLICATE_NAME => RawError::Kind(MEDIASERVER::NS_E_DUPLICATE_NAME),
            MEDIASERVER::NS_E_DUPLICATE_ADDRESS => RawError::Kind(MEDIASERVER::NS_E_DUPLICATE_ADDRESS),
            MEDIASERVER::NS_E_BAD_MULTICAST_ADDRESS => RawError::Kind(MEDIASERVER::NS_E_BAD_MULTICAST_ADDRESS),
            MEDIASERVER::NS_E_BAD_ADAPTER_ADDRESS => RawError::Kind(MEDIASERVER::NS_E_BAD_ADAPTER_ADDRESS),
            MEDIASERVER::NS_E_BAD_DELIVERY_MODE => RawError::Kind(MEDIASERVER::NS_E_BAD_DELIVERY_MODE),
            MEDIASERVER::NS_E_INVALID_CHANNEL => RawError::Kind(MEDIASERVER::NS_E_INVALID_CHANNEL),
            MEDIASERVER::NS_E_INVALID_STREAM => RawError::Kind(MEDIASERVER::NS_E_INVALID_STREAM),
            MEDIASERVER::NS_E_INVALID_ARCHIVE => RawError::Kind(MEDIASERVER::NS_E_INVALID_ARCHIVE),
            MEDIASERVER::NS_E_NOTITLES => RawError::Kind(MEDIASERVER::NS_E_NOTITLES),
            MEDIASERVER::NS_E_INVALID_CLIENT => RawError::Kind(MEDIASERVER::NS_E_INVALID_CLIENT),
            MEDIASERVER::NS_E_INVALID_BLACKHOLE_ADDRESS => RawError::Kind(MEDIASERVER::NS_E_INVALID_BLACKHOLE_ADDRESS),
            MEDIASERVER::NS_E_INCOMPATIBLE_FORMAT => RawError::Kind(MEDIASERVER::NS_E_INCOMPATIBLE_FORMAT),
            MEDIASERVER::NS_E_INVALID_KEY => RawError::Kind(MEDIASERVER::NS_E_INVALID_KEY),
            MEDIASERVER::NS_E_INVALID_PORT => RawError::Kind(MEDIASERVER::NS_E_INVALID_PORT),
            MEDIASERVER::NS_E_INVALID_TTL => RawError::Kind(MEDIASERVER::NS_E_INVALID_TTL),
            MEDIASERVER::NS_E_STRIDE_REFUSED => RawError::Kind(MEDIASERVER::NS_E_STRIDE_REFUSED),
            MEDIASERVER::NS_E_MMSAUTOSERVER_CANTFINDWALKER => RawError::Kind(MEDIASERVER::NS_E_MMSAUTOSERVER_CANTFINDWALKER),
            MEDIASERVER::NS_E_MAX_BITRATE => RawError::Kind(MEDIASERVER::NS_E_MAX_BITRATE),
            MEDIASERVER::NS_E_LOGFILEPERIOD => RawError::Kind(MEDIASERVER::NS_E_LOGFILEPERIOD),
            MEDIASERVER::NS_E_MAX_CLIENTS => RawError::Kind(MEDIASERVER::NS_E_MAX_CLIENTS),
            MEDIASERVER::NS_E_LOG_FILE_SIZE => RawError::Kind(MEDIASERVER::NS_E_LOG_FILE_SIZE),
            MEDIASERVER::NS_E_MAX_FILERATE => RawError::Kind(MEDIASERVER::NS_E_MAX_FILERATE),
            MEDIASERVER::NS_E_WALKER_UNKNOWN => RawError::Kind(MEDIASERVER::NS_E_WALKER_UNKNOWN),
            MEDIASERVER::NS_E_WALKER_SERVER => RawError::Kind(MEDIASERVER::NS_E_WALKER_SERVER),
            MEDIASERVER::NS_E_WALKER_USAGE => RawError::Kind(MEDIASERVER::NS_E_WALKER_USAGE),
            MEDIASERVER::NS_E_TIGER_FAIL => RawError::Kind(MEDIASERVER::NS_E_TIGER_FAIL),
            MEDIASERVER::NS_E_CUB_FAIL => RawError::Kind(MEDIASERVER::NS_E_CUB_FAIL),
            MEDIASERVER::NS_E_DISK_FAIL => RawError::Kind(MEDIASERVER::NS_E_DISK_FAIL),
            MEDIASERVER::NS_E_MAX_FUNNELS_ALERT => RawError::Kind(MEDIASERVER::NS_E_MAX_FUNNELS_ALERT),
            MEDIASERVER::NS_E_ALLOCATE_FILE_FAIL => RawError::Kind(MEDIASERVER::NS_E_ALLOCATE_FILE_FAIL),
            MEDIASERVER::NS_E_PAGING_ERROR => RawError::Kind(MEDIASERVER::NS_E_PAGING_ERROR),
            MEDIASERVER::NS_E_BAD_BLOCK0_VERSION => RawError::Kind(MEDIASERVER::NS_E_BAD_BLOCK0_VERSION),
            MEDIASERVER::NS_E_BAD_DISK_UID => RawError::Kind(MEDIASERVER::NS_E_BAD_DISK_UID),
            MEDIASERVER::NS_E_BAD_FSMAJOR_VERSION => RawError::Kind(MEDIASERVER::NS_E_BAD_FSMAJOR_VERSION),
            MEDIASERVER::NS_E_BAD_STAMPNUMBER => RawError::Kind(MEDIASERVER::NS_E_BAD_STAMPNUMBER),
            MEDIASERVER::NS_E_PARTIALLY_REBUILT_DISK => RawError::Kind(MEDIASERVER::NS_E_PARTIALLY_REBUILT_DISK),
            MEDIASERVER::NS_E_ENACTPLAN_GIVEUP => RawError::Kind(MEDIASERVER::NS_E_ENACTPLAN_GIVEUP),
            MEDIASERVER::MCMADM_E_REGKEY_NOT_FOUND => RawError::Kind(MEDIASERVER::MCMADM_E_REGKEY_NOT_FOUND),
            MEDIASERVER::NS_E_NO_FORMATS => RawError::Kind(MEDIASERVER::NS_E_NO_FORMATS),
            MEDIASERVER::NS_E_NO_REFERENCES => RawError::Kind(MEDIASERVER::NS_E_NO_REFERENCES),
            MEDIASERVER::NS_E_WAVE_OPEN => RawError::Kind(MEDIASERVER::NS_E_WAVE_OPEN),
            MEDIASERVER::NS_E_CANNOTCONNECTEVENTS => RawError::Kind(MEDIASERVER::NS_E_CANNOTCONNECTEVENTS),
            MEDIASERVER::NS_E_NO_DEVICE => RawError::Kind(MEDIASERVER::NS_E_NO_DEVICE),
            MEDIASERVER::NS_E_NO_SPECIFIED_DEVICE => RawError::Kind(MEDIASERVER::NS_E_NO_SPECIFIED_DEVICE),
            MEDIASERVER::NS_E_MONITOR_GIVEUP => RawError::Kind(MEDIASERVER::NS_E_MONITOR_GIVEUP),
            MEDIASERVER::NS_E_REMIRRORED_DISK => RawError::Kind(MEDIASERVER::NS_E_REMIRRORED_DISK),
            MEDIASERVER::NS_E_INSUFFICIENT_DATA => RawError::Kind(MEDIASERVER::NS_E_INSUFFICIENT_DATA),
            MEDIASERVER::NS_E_ASSERT => RawError::Kind(MEDIASERVER::NS_E_ASSERT),
            MEDIASERVER::NS_E_BAD_ADAPTER_NAME => RawError::Kind(MEDIASERVER::NS_E_BAD_ADAPTER_NAME),
            MEDIASERVER::NS_E_NOT_LICENSED => RawError::Kind(MEDIASERVER::NS_E_NOT_LICENSED),
            MEDIASERVER::NS_E_NO_SERVER_CONTACT => RawError::Kind(MEDIASERVER::NS_E_NO_SERVER_CONTACT),
            MEDIASERVER::NS_E_TOO_MANY_TITLES => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_TITLES),
            MEDIASERVER::NS_E_TITLE_SIZE_EXCEEDED => RawError::Kind(MEDIASERVER::NS_E_TITLE_SIZE_EXCEEDED),
            MEDIASERVER::NS_E_UDP_DISABLED => RawError::Kind(MEDIASERVER::NS_E_UDP_DISABLED),
            MEDIASERVER::NS_E_TCP_DISABLED => RawError::Kind(MEDIASERVER::NS_E_TCP_DISABLED),
            MEDIASERVER::NS_E_HTTP_DISABLED => RawError::Kind(MEDIASERVER::NS_E_HTTP_DISABLED),
            MEDIASERVER::NS_E_LICENSE_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_LICENSE_EXPIRED),
            MEDIASERVER::NS_E_TITLE_BITRATE => RawError::Kind(MEDIASERVER::NS_E_TITLE_BITRATE),
            MEDIASERVER::NS_E_EMPTY_PROGRAM_NAME => RawError::Kind(MEDIASERVER::NS_E_EMPTY_PROGRAM_NAME),
            MEDIASERVER::NS_E_MISSING_CHANNEL => RawError::Kind(MEDIASERVER::NS_E_MISSING_CHANNEL),
            MEDIASERVER::NS_E_NO_CHANNELS => RawError::Kind(MEDIASERVER::NS_E_NO_CHANNELS),
            MEDIASERVER::NS_E_INVALID_INDEX2 => RawError::Kind(MEDIASERVER::NS_E_INVALID_INDEX2),
            MEDIASERVER::NS_E_CUB_FAIL_LINK => RawError::Kind(MEDIASERVER::NS_E_CUB_FAIL_LINK),
            MEDIASERVER::NS_E_BAD_CUB_UID => RawError::Kind(MEDIASERVER::NS_E_BAD_CUB_UID),
            MEDIASERVER::NS_E_GLITCH_MODE => RawError::Kind(MEDIASERVER::NS_E_GLITCH_MODE),
            MEDIASERVER::NS_E_NO_MEDIA_PROTOCOL => RawError::Kind(MEDIASERVER::NS_E_NO_MEDIA_PROTOCOL),
            MEDIASERVER::ASF_E_BUFFEROVERRUN => RawError::Kind(MEDIASERVER::ASF_E_BUFFEROVERRUN),
            MEDIASERVER::ASF_E_BUFFERTOOSMALL => RawError::Kind(MEDIASERVER::ASF_E_BUFFERTOOSMALL),
            MEDIASERVER::ASF_E_BADLANGUAGEID => RawError::Kind(MEDIASERVER::ASF_E_BADLANGUAGEID),
            MEDIASERVER::ASF_E_NOPAYLOADLENGTH => RawError::Kind(MEDIASERVER::ASF_E_NOPAYLOADLENGTH),
            MEDIASERVER::ASF_E_TOOMANYPAYLOADS => RawError::Kind(MEDIASERVER::ASF_E_TOOMANYPAYLOADS),
            MEDIASERVER::ASF_E_PACKETCONTENTTOOLARGE => RawError::Kind(MEDIASERVER::ASF_E_PACKETCONTENTTOOLARGE),
            MEDIASERVER::ASF_E_UNKNOWNPACKETSIZE => RawError::Kind(MEDIASERVER::ASF_E_UNKNOWNPACKETSIZE),
            MEDIASERVER::ASF_E_INVALIDHEADER => RawError::Kind(MEDIASERVER::ASF_E_INVALIDHEADER),
            MEDIASERVER::ASF_E_NOCLOCKOBJECT => RawError::Kind(MEDIASERVER::ASF_E_NOCLOCKOBJECT),
            MEDIASERVER::ASF_E_UNKNOWNCLOCKTYPE => RawError::Kind(MEDIASERVER::ASF_E_UNKNOWNCLOCKTYPE),
            MEDIASERVER::ASF_E_OPAQUEPACKET => RawError::Kind(MEDIASERVER::ASF_E_OPAQUEPACKET),
            MEDIASERVER::ASF_E_WRONGVERSION => RawError::Kind(MEDIASERVER::ASF_E_WRONGVERSION),
            MEDIASERVER::ASF_E_OVERFLOW => RawError::Kind(MEDIASERVER::ASF_E_OVERFLOW),
            MEDIASERVER::ASF_E_NOTFOUND => RawError::Kind(MEDIASERVER::ASF_E_NOTFOUND),
            MEDIASERVER::NS_E_NOTHING_TO_DO => RawError::Kind(MEDIASERVER::NS_E_NOTHING_TO_DO),
            MEDIASERVER::NS_E_NO_MULTICAST => RawError::Kind(MEDIASERVER::NS_E_NO_MULTICAST),
            MEDIASERVER::ASF_E_OBJECTTOOBIG => RawError::Kind(MEDIASERVER::ASF_E_OBJECTTOOBIG),
            MEDIASERVER::ASF_E_UNEXPECTEDVALUE => RawError::Kind(MEDIASERVER::ASF_E_UNEXPECTEDVALUE),
            MEDIASERVER::ASF_E_INVALIDSTATE => RawError::Kind(MEDIASERVER::ASF_E_INVALIDSTATE),
            MEDIASERVER::ASF_E_NOLIBRARY => RawError::Kind(MEDIASERVER::ASF_E_NOLIBRARY),
            MEDIASERVER::ASF_E_ALREADYINITIALIZED => RawError::Kind(MEDIASERVER::ASF_E_ALREADYINITIALIZED),
            MEDIASERVER::ASF_E_INVALIDINIT => RawError::Kind(MEDIASERVER::ASF_E_INVALIDINIT),
            MEDIASERVER::ASF_E_NOHEADEROBJECT => RawError::Kind(MEDIASERVER::ASF_E_NOHEADEROBJECT),
            MEDIASERVER::ASF_E_NODATAOBJECT => RawError::Kind(MEDIASERVER::ASF_E_NODATAOBJECT),
            MEDIASERVER::ASF_E_NOINDEXOBJECT => RawError::Kind(MEDIASERVER::ASF_E_NOINDEXOBJECT),
            MEDIASERVER::ASF_E_NOSTREAMPROPS => RawError::Kind(MEDIASERVER::ASF_E_NOSTREAMPROPS),
            MEDIASERVER::ASF_E_NOFILEPROPS => RawError::Kind(MEDIASERVER::ASF_E_NOFILEPROPS),
            MEDIASERVER::ASF_E_INVALIDFLAGS => RawError::Kind(MEDIASERVER::ASF_E_INVALIDFLAGS),
            MEDIASERVER::ASF_E_BADDATADESCRIPTOR => RawError::Kind(MEDIASERVER::ASF_E_BADDATADESCRIPTOR),
            MEDIASERVER::ASF_E_BADINDEXINTERVAL => RawError::Kind(MEDIASERVER::ASF_E_BADINDEXINTERVAL),
            MEDIASERVER::ASF_E_INVALIDTIME => RawError::Kind(MEDIASERVER::ASF_E_INVALIDTIME),
            MEDIASERVER::ASF_E_INVALIDINDEX => RawError::Kind(MEDIASERVER::ASF_E_INVALIDINDEX),
            MEDIASERVER::ASF_E_STREAMNUMBERINUSE => RawError::Kind(MEDIASERVER::ASF_E_STREAMNUMBERINUSE),
            MEDIASERVER::ASF_E_BADMEDIATYPE => RawError::Kind(MEDIASERVER::ASF_E_BADMEDIATYPE),
            MEDIASERVER::ASF_E_WRITEFAILED => RawError::Kind(MEDIASERVER::ASF_E_WRITEFAILED),
            MEDIASERVER::ASF_E_NOTENOUGHDESCRIPTORS => RawError::Kind(MEDIASERVER::ASF_E_NOTENOUGHDESCRIPTORS),
            MEDIASERVER::ASF_E_INDEXBLOCKUNLOADED => RawError::Kind(MEDIASERVER::ASF_E_INDEXBLOCKUNLOADED),
            MEDIASERVER::ASF_E_NOTENOUGHBANDWIDTH => RawError::Kind(MEDIASERVER::ASF_E_NOTENOUGHBANDWIDTH),
            MEDIASERVER::ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE => RawError::Kind(MEDIASERVER::ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE),
            MEDIASERVER::ASF_E_BADDATAUNIT => RawError::Kind(MEDIASERVER::ASF_E_BADDATAUNIT),
            MEDIASERVER::ASF_E_HEADERSIZE => RawError::Kind(MEDIASERVER::ASF_E_HEADERSIZE),
            MEDIASERVER::NS_E_INVALID_INPUT_FORMAT => RawError::Kind(MEDIASERVER::NS_E_INVALID_INPUT_FORMAT),
            MEDIASERVER::NS_E_MSAUDIO_NOT_INSTALLED => RawError::Kind(MEDIASERVER::NS_E_MSAUDIO_NOT_INSTALLED),
            MEDIASERVER::NS_E_UNEXPECTED_MSAUDIO_ERROR => RawError::Kind(MEDIASERVER::NS_E_UNEXPECTED_MSAUDIO_ERROR),
            MEDIASERVER::NS_E_INVALID_OUTPUT_FORMAT => RawError::Kind(MEDIASERVER::NS_E_INVALID_OUTPUT_FORMAT),
            MEDIASERVER::NS_E_NOT_CONFIGURED => RawError::Kind(MEDIASERVER::NS_E_NOT_CONFIGURED),
            MEDIASERVER::NS_E_PROTECTED_CONTENT => RawError::Kind(MEDIASERVER::NS_E_PROTECTED_CONTENT),
            MEDIASERVER::NS_E_LICENSE_REQUIRED => RawError::Kind(MEDIASERVER::NS_E_LICENSE_REQUIRED),
            MEDIASERVER::NS_E_TAMPERED_CONTENT => RawError::Kind(MEDIASERVER::NS_E_TAMPERED_CONTENT),
            MEDIASERVER::NS_E_LICENSE_OUTOFDATE => RawError::Kind(MEDIASERVER::NS_E_LICENSE_OUTOFDATE),
            MEDIASERVER::NS_E_LICENSE_INCORRECT_RIGHTS => RawError::Kind(MEDIASERVER::NS_E_LICENSE_INCORRECT_RIGHTS),
            MEDIASERVER::NS_E_AUDIO_CODEC_NOT_INSTALLED => RawError::Kind(MEDIASERVER::NS_E_AUDIO_CODEC_NOT_INSTALLED),
            MEDIASERVER::NS_E_AUDIO_CODEC_ERROR => RawError::Kind(MEDIASERVER::NS_E_AUDIO_CODEC_ERROR),
            MEDIASERVER::NS_E_VIDEO_CODEC_NOT_INSTALLED => RawError::Kind(MEDIASERVER::NS_E_VIDEO_CODEC_NOT_INSTALLED),
            MEDIASERVER::NS_E_VIDEO_CODEC_ERROR => RawError::Kind(MEDIASERVER::NS_E_VIDEO_CODEC_ERROR),
            MEDIASERVER::NS_E_INVALIDPROFILE => RawError::Kind(MEDIASERVER::NS_E_INVALIDPROFILE),
            MEDIASERVER::NS_E_INCOMPATIBLE_VERSION => RawError::Kind(MEDIASERVER::NS_E_INCOMPATIBLE_VERSION),
            MEDIASERVER::NS_E_OFFLINE_MODE => RawError::Kind(MEDIASERVER::NS_E_OFFLINE_MODE),
            MEDIASERVER::NS_E_NOT_CONNECTED => RawError::Kind(MEDIASERVER::NS_E_NOT_CONNECTED),
            MEDIASERVER::NS_E_TOO_MUCH_DATA => RawError::Kind(MEDIASERVER::NS_E_TOO_MUCH_DATA),
            MEDIASERVER::NS_E_UNSUPPORTED_PROPERTY => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_PROPERTY),
            MEDIASERVER::NS_E_8BIT_WAVE_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_8BIT_WAVE_UNSUPPORTED),
            MEDIASERVER::NS_E_NO_MORE_SAMPLES => RawError::Kind(MEDIASERVER::NS_E_NO_MORE_SAMPLES),
            MEDIASERVER::NS_E_INVALID_SAMPLING_RATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_SAMPLING_RATE),
            MEDIASERVER::NS_E_MAX_PACKET_SIZE_TOO_SMALL => RawError::Kind(MEDIASERVER::NS_E_MAX_PACKET_SIZE_TOO_SMALL),
            MEDIASERVER::NS_E_LATE_PACKET => RawError::Kind(MEDIASERVER::NS_E_LATE_PACKET),
            MEDIASERVER::NS_E_DUPLICATE_PACKET => RawError::Kind(MEDIASERVER::NS_E_DUPLICATE_PACKET),
            MEDIASERVER::NS_E_SDK_BUFFERTOOSMALL => RawError::Kind(MEDIASERVER::NS_E_SDK_BUFFERTOOSMALL),
            MEDIASERVER::NS_E_INVALID_NUM_PASSES => RawError::Kind(MEDIASERVER::NS_E_INVALID_NUM_PASSES),
            MEDIASERVER::NS_E_ATTRIBUTE_READ_ONLY => RawError::Kind(MEDIASERVER::NS_E_ATTRIBUTE_READ_ONLY),
            MEDIASERVER::NS_E_ATTRIBUTE_NOT_ALLOWED => RawError::Kind(MEDIASERVER::NS_E_ATTRIBUTE_NOT_ALLOWED),
            MEDIASERVER::NS_E_INVALID_EDL => RawError::Kind(MEDIASERVER::NS_E_INVALID_EDL),
            MEDIASERVER::NS_E_DATA_UNIT_EXTENSION_TOO_LARGE => RawError::Kind(MEDIASERVER::NS_E_DATA_UNIT_EXTENSION_TOO_LARGE),
            MEDIASERVER::NS_E_CODEC_DMO_ERROR => RawError::Kind(MEDIASERVER::NS_E_CODEC_DMO_ERROR),
            MEDIASERVER::NS_E_FEATURE_DISABLED_BY_GROUP_POLICY => RawError::Kind(MEDIASERVER::NS_E_FEATURE_DISABLED_BY_GROUP_POLICY),
            MEDIASERVER::NS_E_FEATURE_DISABLED_IN_SKU => RawError::Kind(MEDIASERVER::NS_E_FEATURE_DISABLED_IN_SKU),
            MEDIASERVER::NS_E_NO_CD => RawError::Kind(MEDIASERVER::NS_E_NO_CD),
            MEDIASERVER::NS_E_CANT_READ_DIGITAL => RawError::Kind(MEDIASERVER::NS_E_CANT_READ_DIGITAL),
            MEDIASERVER::NS_E_DEVICE_DISCONNECTED => RawError::Kind(MEDIASERVER::NS_E_DEVICE_DISCONNECTED),
            MEDIASERVER::NS_E_DEVICE_NOT_SUPPORT_FORMAT => RawError::Kind(MEDIASERVER::NS_E_DEVICE_NOT_SUPPORT_FORMAT),
            MEDIASERVER::NS_E_SLOW_READ_DIGITAL => RawError::Kind(MEDIASERVER::NS_E_SLOW_READ_DIGITAL),
            MEDIASERVER::NS_E_MIXER_INVALID_LINE => RawError::Kind(MEDIASERVER::NS_E_MIXER_INVALID_LINE),
            MEDIASERVER::NS_E_MIXER_INVALID_CONTROL => RawError::Kind(MEDIASERVER::NS_E_MIXER_INVALID_CONTROL),
            MEDIASERVER::NS_E_MIXER_INVALID_VALUE => RawError::Kind(MEDIASERVER::NS_E_MIXER_INVALID_VALUE),
            MEDIASERVER::NS_E_MIXER_UNKNOWN_MMRESULT => RawError::Kind(MEDIASERVER::NS_E_MIXER_UNKNOWN_MMRESULT),
            MEDIASERVER::NS_E_USER_STOP => RawError::Kind(MEDIASERVER::NS_E_USER_STOP),
            MEDIASERVER::NS_E_MP3_FORMAT_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_MP3_FORMAT_NOT_FOUND),
            MEDIASERVER::NS_E_CD_READ_ERROR_NO_CORRECTION => RawError::Kind(MEDIASERVER::NS_E_CD_READ_ERROR_NO_CORRECTION),
            MEDIASERVER::NS_E_CD_READ_ERROR => RawError::Kind(MEDIASERVER::NS_E_CD_READ_ERROR),
            MEDIASERVER::NS_E_CD_SLOW_COPY => RawError::Kind(MEDIASERVER::NS_E_CD_SLOW_COPY),
            MEDIASERVER::NS_E_CD_COPYTO_CD => RawError::Kind(MEDIASERVER::NS_E_CD_COPYTO_CD),
            MEDIASERVER::NS_E_MIXER_NODRIVER => RawError::Kind(MEDIASERVER::NS_E_MIXER_NODRIVER),
            MEDIASERVER::NS_E_REDBOOK_ENABLED_WHILE_COPYING => RawError::Kind(MEDIASERVER::NS_E_REDBOOK_ENABLED_WHILE_COPYING),
            MEDIASERVER::NS_E_CD_REFRESH => RawError::Kind(MEDIASERVER::NS_E_CD_REFRESH),
            MEDIASERVER::NS_E_CD_DRIVER_PROBLEM => RawError::Kind(MEDIASERVER::NS_E_CD_DRIVER_PROBLEM),
            MEDIASERVER::NS_E_WONT_DO_DIGITAL => RawError::Kind(MEDIASERVER::NS_E_WONT_DO_DIGITAL),
            MEDIASERVER::NS_E_WMPXML_NOERROR => RawError::Kind(MEDIASERVER::NS_E_WMPXML_NOERROR),
            MEDIASERVER::NS_E_WMPXML_ENDOFDATA => RawError::Kind(MEDIASERVER::NS_E_WMPXML_ENDOFDATA),
            MEDIASERVER::NS_E_WMPXML_PARSEERROR => RawError::Kind(MEDIASERVER::NS_E_WMPXML_PARSEERROR),
            MEDIASERVER::NS_E_WMPXML_ATTRIBUTENOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMPXML_ATTRIBUTENOTFOUND),
            MEDIASERVER::NS_E_WMPXML_PINOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMPXML_PINOTFOUND),
            MEDIASERVER::NS_E_WMPXML_EMPTYDOC => RawError::Kind(MEDIASERVER::NS_E_WMPXML_EMPTYDOC),
            MEDIASERVER::NS_E_WMP_PATH_ALREADY_IN_LIBRARY => RawError::Kind(MEDIASERVER::NS_E_WMP_PATH_ALREADY_IN_LIBRARY),
            MEDIASERVER::NS_E_WMP_FILESCANALREADYSTARTED => RawError::Kind(MEDIASERVER::NS_E_WMP_FILESCANALREADYSTARTED),
            MEDIASERVER::NS_E_WMP_HME_INVALIDOBJECTID => RawError::Kind(MEDIASERVER::NS_E_WMP_HME_INVALIDOBJECTID),
            MEDIASERVER::NS_E_WMP_MF_CODE_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_WMP_MF_CODE_EXPIRED),
            MEDIASERVER::NS_E_WMP_HME_NOTSEARCHABLEFORITEMS => RawError::Kind(MEDIASERVER::NS_E_WMP_HME_NOTSEARCHABLEFORITEMS),
            MEDIASERVER::NS_E_WMP_ADDTOLIBRARY_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_ADDTOLIBRARY_FAILED),
            MEDIASERVER::NS_E_WMP_WINDOWSAPIFAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_WINDOWSAPIFAILURE),
            MEDIASERVER::NS_E_WMP_RECORDING_NOT_ALLOWED => RawError::Kind(MEDIASERVER::NS_E_WMP_RECORDING_NOT_ALLOWED),
            MEDIASERVER::NS_E_DEVICE_NOT_READY => RawError::Kind(MEDIASERVER::NS_E_DEVICE_NOT_READY),
            MEDIASERVER::NS_E_DAMAGED_FILE => RawError::Kind(MEDIASERVER::NS_E_DAMAGED_FILE),
            MEDIASERVER::NS_E_MPDB_GENERIC => RawError::Kind(MEDIASERVER::NS_E_MPDB_GENERIC),
            MEDIASERVER::NS_E_FILE_FAILED_CHECKS => RawError::Kind(MEDIASERVER::NS_E_FILE_FAILED_CHECKS),
            MEDIASERVER::NS_E_MEDIA_LIBRARY_FAILED => RawError::Kind(MEDIASERVER::NS_E_MEDIA_LIBRARY_FAILED),
            MEDIASERVER::NS_E_SHARING_VIOLATION => RawError::Kind(MEDIASERVER::NS_E_SHARING_VIOLATION),
            MEDIASERVER::NS_E_NO_ERROR_STRING_FOUND => RawError::Kind(MEDIASERVER::NS_E_NO_ERROR_STRING_FOUND),
            MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_CORE => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_CORE),
            MEDIASERVER::NS_E_WMPOCX_NO_ACTIVE_CORE => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_NO_ACTIVE_CORE),
            MEDIASERVER::NS_E_WMPOCX_NOT_RUNNING_REMOTELY => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_NOT_RUNNING_REMOTELY),
            MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_WINDOW => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_WINDOW),
            MEDIASERVER::NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE),
            MEDIASERVER::NS_E_PLUGIN_NOTSHUTDOWN => RawError::Kind(MEDIASERVER::NS_E_PLUGIN_NOTSHUTDOWN),
            MEDIASERVER::NS_E_WMP_CANNOT_FIND_FOLDER => RawError::Kind(MEDIASERVER::NS_E_WMP_CANNOT_FIND_FOLDER),
            MEDIASERVER::NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED => RawError::Kind(MEDIASERVER::NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED),
            MEDIASERVER::NS_E_WMP_PLUGINDLL_NOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMP_PLUGINDLL_NOTFOUND),
            MEDIASERVER::NS_E_NEED_TO_ASK_USER => RawError::Kind(MEDIASERVER::NS_E_NEED_TO_ASK_USER),
            MEDIASERVER::NS_E_WMPOCX_PLAYER_NOT_DOCKED => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_PLAYER_NOT_DOCKED),
            MEDIASERVER::NS_E_WMP_EXTERNAL_NOTREADY => RawError::Kind(MEDIASERVER::NS_E_WMP_EXTERNAL_NOTREADY),
            MEDIASERVER::NS_E_WMP_MLS_STALE_DATA => RawError::Kind(MEDIASERVER::NS_E_WMP_MLS_STALE_DATA),
            MEDIASERVER::NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED),
            MEDIASERVER::NS_E_WMP_UI_VERSIONMISMATCH => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_VERSIONMISMATCH),
            MEDIASERVER::NS_E_WMP_UI_NOTATHEMEFILE => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_NOTATHEMEFILE),
            MEDIASERVER::NS_E_WMP_UI_SUBELEMENTNOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_SUBELEMENTNOTFOUND),
            MEDIASERVER::NS_E_WMP_UI_VERSIONPARSE => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_VERSIONPARSE),
            MEDIASERVER::NS_E_WMP_UI_VIEWIDNOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_VIEWIDNOTFOUND),
            MEDIASERVER::NS_E_WMP_UI_PASSTHROUGH => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_PASSTHROUGH),
            MEDIASERVER::NS_E_WMP_UI_OBJECTNOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_OBJECTNOTFOUND),
            MEDIASERVER::NS_E_WMP_UI_SECONDHANDLER => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_SECONDHANDLER),
            MEDIASERVER::NS_E_WMP_UI_NOSKININZIP => RawError::Kind(MEDIASERVER::NS_E_WMP_UI_NOSKININZIP),
            MEDIASERVER::NS_E_WMP_URLDOWNLOADFAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_URLDOWNLOADFAILED),
            MEDIASERVER::NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN),
            MEDIASERVER::NS_E_WMP_INVALID_SKIN => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_SKIN),
            MEDIASERVER::NS_E_WMP_SENDMAILFAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_SENDMAILFAILED),
            MEDIASERVER::NS_E_WMP_LOCKEDINSKINMODE => RawError::Kind(MEDIASERVER::NS_E_WMP_LOCKEDINSKINMODE),
            MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_FILE => RawError::Kind(MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_FILE),
            MEDIASERVER::NS_E_WMP_SAVEAS_READONLY => RawError::Kind(MEDIASERVER::NS_E_WMP_SAVEAS_READONLY),
            MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_PLAYLIST),
            MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_WMD => RawError::Kind(MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_WMD),
            MEDIASERVER::NS_E_WMP_CANT_PLAY_PROTECTED => RawError::Kind(MEDIASERVER::NS_E_WMP_CANT_PLAY_PROTECTED),
            MEDIASERVER::NS_E_SHARING_STATE_OUT_OF_SYNC => RawError::Kind(MEDIASERVER::NS_E_SHARING_STATE_OUT_OF_SYNC),
            MEDIASERVER::NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING => RawError::Kind(MEDIASERVER::NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING),
            MEDIASERVER::NS_E_WMP_RBC_JPGMAPPINGIMAGE => RawError::Kind(MEDIASERVER::NS_E_WMP_RBC_JPGMAPPINGIMAGE),
            MEDIASERVER::NS_E_WMP_JPGTRANSPARENCY => RawError::Kind(MEDIASERVER::NS_E_WMP_JPGTRANSPARENCY),
            MEDIASERVER::NS_E_WMP_INVALID_MAX_VAL => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_MAX_VAL),
            MEDIASERVER::NS_E_WMP_INVALID_MIN_VAL => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_MIN_VAL),
            MEDIASERVER::NS_E_WMP_CS_JPGPOSITIONIMAGE => RawError::Kind(MEDIASERVER::NS_E_WMP_CS_JPGPOSITIONIMAGE),
            MEDIASERVER::NS_E_WMP_CS_NOTEVENLYDIVISIBLE => RawError::Kind(MEDIASERVER::NS_E_WMP_CS_NOTEVENLYDIVISIBLE),
            MEDIASERVER::NS_E_WMPZIP_NOTAZIPFILE => RawError::Kind(MEDIASERVER::NS_E_WMPZIP_NOTAZIPFILE),
            MEDIASERVER::NS_E_WMPZIP_CORRUPT => RawError::Kind(MEDIASERVER::NS_E_WMPZIP_CORRUPT),
            MEDIASERVER::NS_E_WMPZIP_FILENOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMPZIP_FILENOTFOUND),
            MEDIASERVER::NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED),
            MEDIASERVER::NS_E_WMP_IMAGE_INVALID_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAGE_INVALID_FORMAT),
            MEDIASERVER::NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE => RawError::Kind(MEDIASERVER::NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE),
            MEDIASERVER::NS_E_WMP_GIF_INVALID_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_GIF_INVALID_FORMAT),
            MEDIASERVER::NS_E_WMP_GIF_BAD_VERSION_NUMBER => RawError::Kind(MEDIASERVER::NS_E_WMP_GIF_BAD_VERSION_NUMBER),
            MEDIASERVER::NS_E_WMP_GIF_NO_IMAGE_IN_FILE => RawError::Kind(MEDIASERVER::NS_E_WMP_GIF_NO_IMAGE_IN_FILE),
            MEDIASERVER::NS_E_WMP_PNG_INVALIDFORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_PNG_INVALIDFORMAT),
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH => RawError::Kind(MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH),
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION => RawError::Kind(MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION),
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_FILTER => RawError::Kind(MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_FILTER),
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_INTERLACE => RawError::Kind(MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_INTERLACE),
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC => RawError::Kind(MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC),
            MEDIASERVER::NS_E_WMP_BMP_INVALID_BITMASK => RawError::Kind(MEDIASERVER::NS_E_WMP_BMP_INVALID_BITMASK),
            MEDIASERVER::NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED),
            MEDIASERVER::NS_E_WMP_BMP_BITMAP_NOT_CREATED => RawError::Kind(MEDIASERVER::NS_E_WMP_BMP_BITMAP_NOT_CREATED),
            MEDIASERVER::NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED),
            MEDIASERVER::NS_E_WMP_BMP_INVALID_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_BMP_INVALID_FORMAT),
            MEDIASERVER::NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL),
            MEDIASERVER::NS_E_WMP_JPG_INVALID_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_INVALID_FORMAT),
            MEDIASERVER::NS_E_WMP_JPG_BAD_DCTSIZE => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_BAD_DCTSIZE),
            MEDIASERVER::NS_E_WMP_JPG_BAD_VERSION_NUMBER => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_BAD_VERSION_NUMBER),
            MEDIASERVER::NS_E_WMP_JPG_BAD_PRECISION => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_BAD_PRECISION),
            MEDIASERVER::NS_E_WMP_JPG_CCIR601_NOTIMPL => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_CCIR601_NOTIMPL),
            MEDIASERVER::NS_E_WMP_JPG_NO_IMAGE_IN_FILE => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_NO_IMAGE_IN_FILE),
            MEDIASERVER::NS_E_WMP_JPG_READ_ERROR => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_READ_ERROR),
            MEDIASERVER::NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL),
            MEDIASERVER::NS_E_WMP_JPG_IMAGE_TOO_BIG => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_IMAGE_TOO_BIG),
            MEDIASERVER::NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE),
            MEDIASERVER::NS_E_WMP_JPG_SOF_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_SOF_UNSUPPORTED),
            MEDIASERVER::NS_E_WMP_JPG_UNKNOWN_MARKER => RawError::Kind(MEDIASERVER::NS_E_WMP_JPG_UNKNOWN_MARKER),
            MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_IMAGE => RawError::Kind(MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_IMAGE),
            MEDIASERVER::NS_E_WMP_DAI_SONGTOOSHORT => RawError::Kind(MEDIASERVER::NS_E_WMP_DAI_SONGTOOSHORT),
            MEDIASERVER::NS_E_WMG_RATEUNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMG_RATEUNAVAILABLE),
            MEDIASERVER::NS_E_WMG_PLUGINUNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMG_PLUGINUNAVAILABLE),
            MEDIASERVER::NS_E_WMG_CANNOTQUEUE => RawError::Kind(MEDIASERVER::NS_E_WMG_CANNOTQUEUE),
            MEDIASERVER::NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED => RawError::Kind(MEDIASERVER::NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED),
            MEDIASERVER::NS_E_WMG_UNEXPECTEDPREROLLSTATUS => RawError::Kind(MEDIASERVER::NS_E_WMG_UNEXPECTEDPREROLLSTATUS),
            MEDIASERVER::NS_E_WMG_INVALID_COPP_CERTIFICATE => RawError::Kind(MEDIASERVER::NS_E_WMG_INVALID_COPP_CERTIFICATE),
            MEDIASERVER::NS_E_WMG_COPP_SECURITY_INVALID => RawError::Kind(MEDIASERVER::NS_E_WMG_COPP_SECURITY_INVALID),
            MEDIASERVER::NS_E_WMG_COPP_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMG_COPP_UNSUPPORTED),
            MEDIASERVER::NS_E_WMG_INVALIDSTATE => RawError::Kind(MEDIASERVER::NS_E_WMG_INVALIDSTATE),
            MEDIASERVER::NS_E_WMG_SINKALREADYEXISTS => RawError::Kind(MEDIASERVER::NS_E_WMG_SINKALREADYEXISTS),
            MEDIASERVER::NS_E_WMG_NOSDKINTERFACE => RawError::Kind(MEDIASERVER::NS_E_WMG_NOSDKINTERFACE),
            MEDIASERVER::NS_E_WMG_NOTALLOUTPUTSRENDERED => RawError::Kind(MEDIASERVER::NS_E_WMG_NOTALLOUTPUTSRENDERED),
            MEDIASERVER::NS_E_WMG_FILETRANSFERNOTALLOWED => RawError::Kind(MEDIASERVER::NS_E_WMG_FILETRANSFERNOTALLOWED),
            MEDIASERVER::NS_E_WMR_UNSUPPORTEDSTREAM => RawError::Kind(MEDIASERVER::NS_E_WMR_UNSUPPORTEDSTREAM),
            MEDIASERVER::NS_E_WMR_PINNOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMR_PINNOTFOUND),
            MEDIASERVER::NS_E_WMR_WAITINGONFORMATSWITCH => RawError::Kind(MEDIASERVER::NS_E_WMR_WAITINGONFORMATSWITCH),
            MEDIASERVER::NS_E_WMR_NOSOURCEFILTER => RawError::Kind(MEDIASERVER::NS_E_WMR_NOSOURCEFILTER),
            MEDIASERVER::NS_E_WMR_PINTYPENOMATCH => RawError::Kind(MEDIASERVER::NS_E_WMR_PINTYPENOMATCH),
            MEDIASERVER::NS_E_WMR_NOCALLBACKAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMR_NOCALLBACKAVAILABLE),
            MEDIASERVER::NS_E_WMR_SAMPLEPROPERTYNOTSET => RawError::Kind(MEDIASERVER::NS_E_WMR_SAMPLEPROPERTYNOTSET),
            MEDIASERVER::NS_E_WMR_CANNOT_RENDER_BINARY_STREAM => RawError::Kind(MEDIASERVER::NS_E_WMR_CANNOT_RENDER_BINARY_STREAM),
            MEDIASERVER::NS_E_WMG_LICENSE_TAMPERED => RawError::Kind(MEDIASERVER::NS_E_WMG_LICENSE_TAMPERED),
            MEDIASERVER::NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM => RawError::Kind(MEDIASERVER::NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM),
            MEDIASERVER::NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT),
            MEDIASERVER::NS_E_ASX_INVALIDFORMAT => RawError::Kind(MEDIASERVER::NS_E_ASX_INVALIDFORMAT),
            MEDIASERVER::NS_E_ASX_INVALIDVERSION => RawError::Kind(MEDIASERVER::NS_E_ASX_INVALIDVERSION),
            MEDIASERVER::NS_E_ASX_INVALID_REPEAT_BLOCK => RawError::Kind(MEDIASERVER::NS_E_ASX_INVALID_REPEAT_BLOCK),
            MEDIASERVER::NS_E_ASX_NOTHING_TO_WRITE => RawError::Kind(MEDIASERVER::NS_E_ASX_NOTHING_TO_WRITE),
            MEDIASERVER::NS_E_URLLIST_INVALIDFORMAT => RawError::Kind(MEDIASERVER::NS_E_URLLIST_INVALIDFORMAT),
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST => RawError::Kind(MEDIASERVER::NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST),
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS => RawError::Kind(MEDIASERVER::NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS),
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE => RawError::Kind(MEDIASERVER::NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE),
            MEDIASERVER::NS_E_WMX_ITEM_DOES_NOT_EXIST => RawError::Kind(MEDIASERVER::NS_E_WMX_ITEM_DOES_NOT_EXIST),
            MEDIASERVER::NS_E_WMX_ITEM_TYPE_ILLEGAL => RawError::Kind(MEDIASERVER::NS_E_WMX_ITEM_TYPE_ILLEGAL),
            MEDIASERVER::NS_E_WMX_ITEM_UNSETTABLE => RawError::Kind(MEDIASERVER::NS_E_WMX_ITEM_UNSETTABLE),
            MEDIASERVER::NS_E_WMX_PLAYLIST_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMX_PLAYLIST_EMPTY),
            MEDIASERVER::NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED => RawError::Kind(MEDIASERVER::NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED),
            MEDIASERVER::NS_E_WMX_INVALID_FORMAT_OVER_NESTING => RawError::Kind(MEDIASERVER::NS_E_WMX_INVALID_FORMAT_OVER_NESTING),
            MEDIASERVER::NS_E_WMPCORE_NOSOURCEURLSTRING => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_NOSOURCEURLSTRING),
            MEDIASERVER::NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT),
            MEDIASERVER::NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE),
            MEDIASERVER::NS_E_WMPCORE_BUFFERTOOSMALL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_BUFFERTOOSMALL),
            MEDIASERVER::NS_E_WMPCORE_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_UNAVAILABLE),
            MEDIASERVER::NS_E_WMPCORE_INVALIDPLAYLISTMODE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_INVALIDPLAYLISTMODE),
            MEDIASERVER::NS_E_WMPCORE_ITEMNOTINPLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_ITEMNOTINPLAYLIST),
            MEDIASERVER::NS_E_WMPCORE_PLAYLISTEMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLISTEMPTY),
            MEDIASERVER::NS_E_WMPCORE_NOBROWSER => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_NOBROWSER),
            MEDIASERVER::NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL),
            MEDIASERVER::NS_E_WMPCORE_GRAPH_NOT_IN_LIST => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_GRAPH_NOT_IN_LIST),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA),
            MEDIASERVER::NS_E_WMPCORE_ERRORSINKNOTREGISTERED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_ERRORSINKNOTREGISTERED),
            MEDIASERVER::NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE),
            MEDIASERVER::NS_E_WMPCORE_WEBHELPFAILED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WEBHELPFAILED),
            MEDIASERVER::NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED),
            MEDIASERVER::NS_E_WMPCORE_NO_REF_IN_ENTRY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_NO_REF_IN_ENTRY),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL),
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_LIST_ENTRY_NO_REF => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_LIST_ENTRY_NO_REF),
            MEDIASERVER::NS_E_WMPCORE_MISNAMED_FILE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MISNAMED_FILE),
            MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_TRUSTED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_TRUSTED),
            MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_FOUND),
            MEDIASERVER::NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED),
            MEDIASERVER::NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST),
            MEDIASERVER::NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED),
            MEDIASERVER::NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_STACK_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_STACK_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE),
            MEDIASERVER::NS_E_WMPCORE_USER_CANCEL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_USER_CANCEL),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE),
            MEDIASERVER::NS_E_WMPCORE_INVALID_PLAYLIST_URL => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_INVALID_PLAYLIST_URL),
            MEDIASERVER::NS_E_WMPCORE_MISMATCHED_RUNTIME => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MISMATCHED_RUNTIME),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS),
            MEDIASERVER::NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION),
            MEDIASERVER::NS_E_WMPCORE_MEDIA_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MEDIA_UNAVAILABLE),
            MEDIASERVER::NS_E_WMPCORE_WMX_ENTRYREF_NO_REF => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_WMX_ENTRYREF_NO_REF),
            MEDIASERVER::NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST),
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS),
            MEDIASERVER::NS_E_WMPCORE_BUSY => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_BUSY),
            MEDIASERVER::NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE),
            MEDIASERVER::NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST),
            MEDIASERVER::NS_E_WMPCORE_FILE_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_FILE_NOT_FOUND),
            MEDIASERVER::NS_E_WMPCORE_TEMP_FILE_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_TEMP_FILE_NOT_FOUND),
            MEDIASERVER::NS_E_WMDM_REVOKED => RawError::Kind(MEDIASERVER::NS_E_WMDM_REVOKED),
            MEDIASERVER::NS_E_DDRAW_GENERIC => RawError::Kind(MEDIASERVER::NS_E_DDRAW_GENERIC),
            MEDIASERVER::NS_E_DISPLAY_MODE_CHANGE_FAILED => RawError::Kind(MEDIASERVER::NS_E_DISPLAY_MODE_CHANGE_FAILED),
            MEDIASERVER::NS_E_PLAYLIST_CONTAINS_ERRORS => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_CONTAINS_ERRORS),
            MEDIASERVER::NS_E_CHANGING_PROXY_NAME => RawError::Kind(MEDIASERVER::NS_E_CHANGING_PROXY_NAME),
            MEDIASERVER::NS_E_CHANGING_PROXY_PORT => RawError::Kind(MEDIASERVER::NS_E_CHANGING_PROXY_PORT),
            MEDIASERVER::NS_E_CHANGING_PROXY_EXCEPTIONLIST => RawError::Kind(MEDIASERVER::NS_E_CHANGING_PROXY_EXCEPTIONLIST),
            MEDIASERVER::NS_E_CHANGING_PROXYBYPASS => RawError::Kind(MEDIASERVER::NS_E_CHANGING_PROXYBYPASS),
            MEDIASERVER::NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND),
            MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGE => RawError::Kind(MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGE),
            MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGESELECTED => RawError::Kind(MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGESELECTED),
            MEDIASERVER::NS_E_CORECD_NOTAMEDIACD => RawError::Kind(MEDIASERVER::NS_E_CORECD_NOTAMEDIACD),
            MEDIASERVER::NS_E_WMPCORE_MEDIA_URL_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_MEDIA_URL_TOO_LONG),
            MEDIASERVER::NS_E_WMPFLASH_CANT_FIND_COM_SERVER => RawError::Kind(MEDIASERVER::NS_E_WMPFLASH_CANT_FIND_COM_SERVER),
            MEDIASERVER::NS_E_WMPFLASH_INCOMPATIBLEVERSION => RawError::Kind(MEDIASERVER::NS_E_WMPFLASH_INCOMPATIBLEVERSION),
            MEDIASERVER::NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS => RawError::Kind(MEDIASERVER::NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS),
            MEDIASERVER::NS_E_NEED_CORE_REFERENCE => RawError::Kind(MEDIASERVER::NS_E_NEED_CORE_REFERENCE),
            MEDIASERVER::NS_E_MEDIACD_READ_ERROR => RawError::Kind(MEDIASERVER::NS_E_MEDIACD_READ_ERROR),
            MEDIASERVER::NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS => RawError::Kind(MEDIASERVER::NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS),
            MEDIASERVER::NS_E_FLASH_PLAYBACK_NOT_ALLOWED => RawError::Kind(MEDIASERVER::NS_E_FLASH_PLAYBACK_NOT_ALLOWED),
            MEDIASERVER::NS_E_UNABLE_TO_CREATE_RIP_LOCATION => RawError::Kind(MEDIASERVER::NS_E_UNABLE_TO_CREATE_RIP_LOCATION),
            MEDIASERVER::NS_E_WMPCORE_SOME_CODECS_MISSING => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_SOME_CODECS_MISSING),
            MEDIASERVER::NS_E_WMP_RIP_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_RIP_FAILED),
            MEDIASERVER::NS_E_WMP_FAILED_TO_RIP_TRACK => RawError::Kind(MEDIASERVER::NS_E_WMP_FAILED_TO_RIP_TRACK),
            MEDIASERVER::NS_E_WMP_ERASE_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_ERASE_FAILED),
            MEDIASERVER::NS_E_WMP_FORMAT_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_FORMAT_FAILED),
            MEDIASERVER::NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE => RawError::Kind(MEDIASERVER::NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE),
            MEDIASERVER::NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD => RawError::Kind(MEDIASERVER::NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD),
            MEDIASERVER::NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD => RawError::Kind(MEDIASERVER::NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD),
            MEDIASERVER::NS_E_WMP_FILE_NO_DURATION => RawError::Kind(MEDIASERVER::NS_E_WMP_FILE_NO_DURATION),
            MEDIASERVER::NS_E_PDA_FAILED_TO_BURN => RawError::Kind(MEDIASERVER::NS_E_PDA_FAILED_TO_BURN),
            MEDIASERVER::NS_E_FAILED_DOWNLOAD_ABORT_BURN => RawError::Kind(MEDIASERVER::NS_E_FAILED_DOWNLOAD_ABORT_BURN),
            MEDIASERVER::NS_E_WMPCORE_DEVICE_DRIVERS_MISSING => RawError::Kind(MEDIASERVER::NS_E_WMPCORE_DEVICE_DRIVERS_MISSING),
            MEDIASERVER::NS_E_WMPIM_USEROFFLINE => RawError::Kind(MEDIASERVER::NS_E_WMPIM_USEROFFLINE),
            MEDIASERVER::NS_E_WMPIM_USERCANCELED => RawError::Kind(MEDIASERVER::NS_E_WMPIM_USERCANCELED),
            MEDIASERVER::NS_E_WMPIM_DIALUPFAILED => RawError::Kind(MEDIASERVER::NS_E_WMPIM_DIALUPFAILED),
            MEDIASERVER::NS_E_WINSOCK_ERROR_STRING => RawError::Kind(MEDIASERVER::NS_E_WINSOCK_ERROR_STRING),
            MEDIASERVER::NS_E_WMPBR_NOLISTENER => RawError::Kind(MEDIASERVER::NS_E_WMPBR_NOLISTENER),
            MEDIASERVER::NS_E_WMPBR_BACKUPCANCEL => RawError::Kind(MEDIASERVER::NS_E_WMPBR_BACKUPCANCEL),
            MEDIASERVER::NS_E_WMPBR_RESTORECANCEL => RawError::Kind(MEDIASERVER::NS_E_WMPBR_RESTORECANCEL),
            MEDIASERVER::NS_E_WMPBR_ERRORWITHURL => RawError::Kind(MEDIASERVER::NS_E_WMPBR_ERRORWITHURL),
            MEDIASERVER::NS_E_WMPBR_NAMECOLLISION => RawError::Kind(MEDIASERVER::NS_E_WMPBR_NAMECOLLISION),
            MEDIASERVER::NS_E_WMPBR_DRIVE_INVALID => RawError::Kind(MEDIASERVER::NS_E_WMPBR_DRIVE_INVALID),
            MEDIASERVER::NS_E_WMPBR_BACKUPRESTOREFAILED => RawError::Kind(MEDIASERVER::NS_E_WMPBR_BACKUPRESTOREFAILED),
            MEDIASERVER::NS_E_WMP_CONVERT_FILE_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_FILE_FAILED),
            MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL),
            MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL),
            MEDIASERVER::NS_E_WMP_CONVERT_FILE_CORRUPT => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_FILE_CORRUPT),
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL),
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL),
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER => RawError::Kind(MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER),
            MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS => RawError::Kind(MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS),
            MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED => RawError::Kind(MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED),
            MEDIASERVER::NS_E_DVD_NO_SUBPICTURE_STREAM => RawError::Kind(MEDIASERVER::NS_E_DVD_NO_SUBPICTURE_STREAM),
            MEDIASERVER::NS_E_DVD_COPY_PROTECT => RawError::Kind(MEDIASERVER::NS_E_DVD_COPY_PROTECT),
            MEDIASERVER::NS_E_DVD_AUTHORING_PROBLEM => RawError::Kind(MEDIASERVER::NS_E_DVD_AUTHORING_PROBLEM),
            MEDIASERVER::NS_E_DVD_INVALID_DISC_REGION => RawError::Kind(MEDIASERVER::NS_E_DVD_INVALID_DISC_REGION),
            MEDIASERVER::NS_E_DVD_COMPATIBLE_VIDEO_CARD => RawError::Kind(MEDIASERVER::NS_E_DVD_COMPATIBLE_VIDEO_CARD),
            MEDIASERVER::NS_E_DVD_MACROVISION => RawError::Kind(MEDIASERVER::NS_E_DVD_MACROVISION),
            MEDIASERVER::NS_E_DVD_SYSTEM_DECODER_REGION => RawError::Kind(MEDIASERVER::NS_E_DVD_SYSTEM_DECODER_REGION),
            MEDIASERVER::NS_E_DVD_DISC_DECODER_REGION => RawError::Kind(MEDIASERVER::NS_E_DVD_DISC_DECODER_REGION),
            MEDIASERVER::NS_E_DVD_NO_VIDEO_STREAM => RawError::Kind(MEDIASERVER::NS_E_DVD_NO_VIDEO_STREAM),
            MEDIASERVER::NS_E_DVD_NO_AUDIO_STREAM => RawError::Kind(MEDIASERVER::NS_E_DVD_NO_AUDIO_STREAM),
            MEDIASERVER::NS_E_DVD_GRAPH_BUILDING => RawError::Kind(MEDIASERVER::NS_E_DVD_GRAPH_BUILDING),
            MEDIASERVER::NS_E_DVD_NO_DECODER => RawError::Kind(MEDIASERVER::NS_E_DVD_NO_DECODER),
            MEDIASERVER::NS_E_DVD_PARENTAL => RawError::Kind(MEDIASERVER::NS_E_DVD_PARENTAL),
            MEDIASERVER::NS_E_DVD_CANNOT_JUMP => RawError::Kind(MEDIASERVER::NS_E_DVD_CANNOT_JUMP),
            MEDIASERVER::NS_E_DVD_DEVICE_CONTENTION => RawError::Kind(MEDIASERVER::NS_E_DVD_DEVICE_CONTENTION),
            MEDIASERVER::NS_E_DVD_NO_VIDEO_MEMORY => RawError::Kind(MEDIASERVER::NS_E_DVD_NO_VIDEO_MEMORY),
            MEDIASERVER::NS_E_DVD_CANNOT_COPY_PROTECTED => RawError::Kind(MEDIASERVER::NS_E_DVD_CANNOT_COPY_PROTECTED),
            MEDIASERVER::NS_E_DVD_REQUIRED_PROPERTY_NOT_SET => RawError::Kind(MEDIASERVER::NS_E_DVD_REQUIRED_PROPERTY_NOT_SET),
            MEDIASERVER::NS_E_DVD_INVALID_TITLE_CHAPTER => RawError::Kind(MEDIASERVER::NS_E_DVD_INVALID_TITLE_CHAPTER),
            MEDIASERVER::NS_E_NO_CD_BURNER => RawError::Kind(MEDIASERVER::NS_E_NO_CD_BURNER),
            MEDIASERVER::NS_E_DEVICE_IS_NOT_READY => RawError::Kind(MEDIASERVER::NS_E_DEVICE_IS_NOT_READY),
            MEDIASERVER::NS_E_PDA_UNSUPPORTED_FORMAT => RawError::Kind(MEDIASERVER::NS_E_PDA_UNSUPPORTED_FORMAT),
            MEDIASERVER::NS_E_NO_PDA => RawError::Kind(MEDIASERVER::NS_E_NO_PDA),
            MEDIASERVER::NS_E_PDA_UNSPECIFIED_ERROR => RawError::Kind(MEDIASERVER::NS_E_PDA_UNSPECIFIED_ERROR),
            MEDIASERVER::NS_E_MEMSTORAGE_BAD_DATA => RawError::Kind(MEDIASERVER::NS_E_MEMSTORAGE_BAD_DATA),
            MEDIASERVER::NS_E_PDA_FAIL_SELECT_DEVICE => RawError::Kind(MEDIASERVER::NS_E_PDA_FAIL_SELECT_DEVICE),
            MEDIASERVER::NS_E_PDA_FAIL_READ_WAVE_FILE => RawError::Kind(MEDIASERVER::NS_E_PDA_FAIL_READ_WAVE_FILE),
            MEDIASERVER::NS_E_IMAPI_LOSSOFSTREAMING => RawError::Kind(MEDIASERVER::NS_E_IMAPI_LOSSOFSTREAMING),
            MEDIASERVER::NS_E_PDA_DEVICE_FULL => RawError::Kind(MEDIASERVER::NS_E_PDA_DEVICE_FULL),
            MEDIASERVER::NS_E_FAIL_LAUNCH_ROXIO_PLUGIN => RawError::Kind(MEDIASERVER::NS_E_FAIL_LAUNCH_ROXIO_PLUGIN),
            MEDIASERVER::NS_E_PDA_DEVICE_FULL_IN_SESSION => RawError::Kind(MEDIASERVER::NS_E_PDA_DEVICE_FULL_IN_SESSION),
            MEDIASERVER::NS_E_IMAPI_MEDIUM_INVALIDTYPE => RawError::Kind(MEDIASERVER::NS_E_IMAPI_MEDIUM_INVALIDTYPE),
            MEDIASERVER::NS_E_PDA_MANUALDEVICE => RawError::Kind(MEDIASERVER::NS_E_PDA_MANUALDEVICE),
            MEDIASERVER::NS_E_PDA_PARTNERSHIPNOTEXIST => RawError::Kind(MEDIASERVER::NS_E_PDA_PARTNERSHIPNOTEXIST),
            MEDIASERVER::NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP),
            MEDIASERVER::NS_E_PDA_NO_TRANSCODE_OF_DRM => RawError::Kind(MEDIASERVER::NS_E_PDA_NO_TRANSCODE_OF_DRM),
            MEDIASERVER::NS_E_PDA_TRANSCODECACHEFULL => RawError::Kind(MEDIASERVER::NS_E_PDA_TRANSCODECACHEFULL),
            MEDIASERVER::NS_E_PDA_TOO_MANY_FILE_COLLISIONS => RawError::Kind(MEDIASERVER::NS_E_PDA_TOO_MANY_FILE_COLLISIONS),
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE),
            MEDIASERVER::NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY => RawError::Kind(MEDIASERVER::NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY),
            MEDIASERVER::NS_E_PROCESSINGSHOWSYNCWIZARD => RawError::Kind(MEDIASERVER::NS_E_PROCESSINGSHOWSYNCWIZARD),
            MEDIASERVER::NS_E_PDA_TRANSCODE_NOT_PERMITTED => RawError::Kind(MEDIASERVER::NS_E_PDA_TRANSCODE_NOT_PERMITTED),
            MEDIASERVER::NS_E_PDA_INITIALIZINGDEVICES => RawError::Kind(MEDIASERVER::NS_E_PDA_INITIALIZINGDEVICES),
            MEDIASERVER::NS_E_PDA_OBSOLETE_SP => RawError::Kind(MEDIASERVER::NS_E_PDA_OBSOLETE_SP),
            MEDIASERVER::NS_E_PDA_TITLE_COLLISION => RawError::Kind(MEDIASERVER::NS_E_PDA_TITLE_COLLISION),
            MEDIASERVER::NS_E_PDA_DEVICESUPPORTDISABLED => RawError::Kind(MEDIASERVER::NS_E_PDA_DEVICESUPPORTDISABLED),
            MEDIASERVER::NS_E_PDA_NO_LONGER_AVAILABLE => RawError::Kind(MEDIASERVER::NS_E_PDA_NO_LONGER_AVAILABLE),
            MEDIASERVER::NS_E_PDA_ENCODER_NOT_RESPONDING => RawError::Kind(MEDIASERVER::NS_E_PDA_ENCODER_NOT_RESPONDING),
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_LOCATION => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_LOCATION),
            MEDIASERVER::NS_E_WMP_PROTOCOL_PROBLEM => RawError::Kind(MEDIASERVER::NS_E_WMP_PROTOCOL_PROBLEM),
            MEDIASERVER::NS_E_WMP_NO_DISK_SPACE => RawError::Kind(MEDIASERVER::NS_E_WMP_NO_DISK_SPACE),
            MEDIASERVER::NS_E_WMP_LOGON_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_LOGON_FAILURE),
            MEDIASERVER::NS_E_WMP_CANNOT_FIND_FILE => RawError::Kind(MEDIASERVER::NS_E_WMP_CANNOT_FIND_FILE),
            MEDIASERVER::NS_E_WMP_SERVER_INACCESSIBLE => RawError::Kind(MEDIASERVER::NS_E_WMP_SERVER_INACCESSIBLE),
            MEDIASERVER::NS_E_WMP_UNSUPPORTED_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_UNSUPPORTED_FORMAT),
            MEDIASERVER::NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT => RawError::Kind(MEDIASERVER::NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT),
            MEDIASERVER::NS_E_WMP_PLAYLIST_EXISTS => RawError::Kind(MEDIASERVER::NS_E_WMP_PLAYLIST_EXISTS),
            MEDIASERVER::NS_E_WMP_NONMEDIA_FILES => RawError::Kind(MEDIASERVER::NS_E_WMP_NONMEDIA_FILES),
            MEDIASERVER::NS_E_WMP_INVALID_ASX => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_ASX),
            MEDIASERVER::NS_E_WMP_ALREADY_IN_USE => RawError::Kind(MEDIASERVER::NS_E_WMP_ALREADY_IN_USE),
            MEDIASERVER::NS_E_WMP_IMAPI_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_FAILURE),
            MEDIASERVER::NS_E_WMP_WMDM_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_FAILURE),
            MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_4CC => RawError::Kind(MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_4CC),
            MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG => RawError::Kind(MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG),
            MEDIASERVER::NS_E_WMP_MSSAP_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMP_MSSAP_NOT_AVAILABLE),
            MEDIASERVER::NS_E_WMP_WMDM_INTERFACEDEAD => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_INTERFACEDEAD),
            MEDIASERVER::NS_E_WMP_WMDM_NOTCERTIFIED => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_NOTCERTIFIED),
            MEDIASERVER::NS_E_WMP_WMDM_LICENSE_NOTEXIST => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_LICENSE_NOTEXIST),
            MEDIASERVER::NS_E_WMP_WMDM_LICENSE_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_LICENSE_EXPIRED),
            MEDIASERVER::NS_E_WMP_WMDM_BUSY => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_BUSY),
            MEDIASERVER::NS_E_WMP_WMDM_NORIGHTS => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_NORIGHTS),
            MEDIASERVER::NS_E_WMP_WMDM_INCORRECT_RIGHTS => RawError::Kind(MEDIASERVER::NS_E_WMP_WMDM_INCORRECT_RIGHTS),
            MEDIASERVER::NS_E_WMP_IMAPI_GENERIC => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_GENERIC),
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_NOTPRESENT => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_NOTPRESENT),
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_BUSY => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_BUSY),
            MEDIASERVER::NS_E_WMP_IMAPI_LOSS_OF_STREAMING => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_LOSS_OF_STREAMING),
            MEDIASERVER::NS_E_WMP_SERVER_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMP_SERVER_UNAVAILABLE),
            MEDIASERVER::NS_E_WMP_FILE_OPEN_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_FILE_OPEN_FAILED),
            MEDIASERVER::NS_E_WMP_VERIFY_ONLINE => RawError::Kind(MEDIASERVER::NS_E_WMP_VERIFY_ONLINE),
            MEDIASERVER::NS_E_WMP_SERVER_NOT_RESPONDING => RawError::Kind(MEDIASERVER::NS_E_WMP_SERVER_NOT_RESPONDING),
            MEDIASERVER::NS_E_WMP_DRM_CORRUPT_BACKUP => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_CORRUPT_BACKUP),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE),
            MEDIASERVER::NS_E_WMP_NETWORK_FIREWALL => RawError::Kind(MEDIASERVER::NS_E_WMP_NETWORK_FIREWALL),
            MEDIASERVER::NS_E_WMP_NO_REMOVABLE_MEDIA => RawError::Kind(MEDIASERVER::NS_E_WMP_NO_REMOVABLE_MEDIA),
            MEDIASERVER::NS_E_WMP_PROXY_CONNECT_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_WMP_PROXY_CONNECT_TIMEOUT),
            MEDIASERVER::NS_E_WMP_NEED_UPGRADE => RawError::Kind(MEDIASERVER::NS_E_WMP_NEED_UPGRADE),
            MEDIASERVER::NS_E_WMP_AUDIO_HW_PROBLEM => RawError::Kind(MEDIASERVER::NS_E_WMP_AUDIO_HW_PROBLEM),
            MEDIASERVER::NS_E_WMP_INVALID_PROTOCOL => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_PROTOCOL),
            MEDIASERVER::NS_E_WMP_INVALID_LIBRARY_ADD => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_LIBRARY_ADD),
            MEDIASERVER::NS_E_WMP_MMS_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_WMP_MMS_NOT_SUPPORTED),
            MEDIASERVER::NS_E_WMP_NO_PROTOCOLS_SELECTED => RawError::Kind(MEDIASERVER::NS_E_WMP_NO_PROTOCOLS_SELECTED),
            MEDIASERVER::NS_E_WMP_GOFULLSCREEN_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_GOFULLSCREEN_FAILED),
            MEDIASERVER::NS_E_WMP_NETWORK_ERROR => RawError::Kind(MEDIASERVER::NS_E_WMP_NETWORK_ERROR),
            MEDIASERVER::NS_E_WMP_CONNECT_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_WMP_CONNECT_TIMEOUT),
            MEDIASERVER::NS_E_WMP_MULTICAST_DISABLED => RawError::Kind(MEDIASERVER::NS_E_WMP_MULTICAST_DISABLED),
            MEDIASERVER::NS_E_WMP_SERVER_DNS_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_WMP_SERVER_DNS_TIMEOUT),
            MEDIASERVER::NS_E_WMP_PROXY_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_WMP_PROXY_NOT_FOUND),
            MEDIASERVER::NS_E_WMP_TAMPERED_CONTENT => RawError::Kind(MEDIASERVER::NS_E_WMP_TAMPERED_CONTENT),
            MEDIASERVER::NS_E_WMP_OUTOFMEMORY => RawError::Kind(MEDIASERVER::NS_E_WMP_OUTOFMEMORY),
            MEDIASERVER::NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED => RawError::Kind(MEDIASERVER::NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED),
            MEDIASERVER::NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED => RawError::Kind(MEDIASERVER::NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED),
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE),
            MEDIASERVER::NS_E_WMP_DRM_DRIVER_AUTH_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_DRIVER_AUTH_FAILURE),
            MEDIASERVER::NS_E_WMP_NETWORK_RESOURCE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_NETWORK_RESOURCE_FAILURE),
            MEDIASERVER::NS_E_WMP_UPGRADE_APPLICATION => RawError::Kind(MEDIASERVER::NS_E_WMP_UPGRADE_APPLICATION),
            MEDIASERVER::NS_E_WMP_UNKNOWN_ERROR => RawError::Kind(MEDIASERVER::NS_E_WMP_UNKNOWN_ERROR),
            MEDIASERVER::NS_E_WMP_INVALID_KEY => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_KEY),
            MEDIASERVER::NS_E_WMP_CD_ANOTHER_USER => RawError::Kind(MEDIASERVER::NS_E_WMP_CD_ANOTHER_USER),
            MEDIASERVER::NS_E_WMP_DRM_NEEDS_AUTHORIZATION => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_NEEDS_AUTHORIZATION),
            MEDIASERVER::NS_E_WMP_BAD_DRIVER => RawError::Kind(MEDIASERVER::NS_E_WMP_BAD_DRIVER),
            MEDIASERVER::NS_E_WMP_ACCESS_DENIED => RawError::Kind(MEDIASERVER::NS_E_WMP_ACCESS_DENIED),
            MEDIASERVER::NS_E_WMP_LICENSE_RESTRICTS => RawError::Kind(MEDIASERVER::NS_E_WMP_LICENSE_RESTRICTS),
            MEDIASERVER::NS_E_WMP_INVALID_REQUEST => RawError::Kind(MEDIASERVER::NS_E_WMP_INVALID_REQUEST),
            MEDIASERVER::NS_E_WMP_CD_STASH_NO_SPACE => RawError::Kind(MEDIASERVER::NS_E_WMP_CD_STASH_NO_SPACE),
            MEDIASERVER::NS_E_WMP_DRM_NEW_HARDWARE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_NEW_HARDWARE),
            MEDIASERVER::NS_E_WMP_DRM_INVALID_SIG => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_INVALID_SIG),
            MEDIASERVER::NS_E_WMP_DRM_CANNOT_RESTORE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_CANNOT_RESTORE),
            MEDIASERVER::NS_E_WMP_BURN_DISC_OVERFLOW => RawError::Kind(MEDIASERVER::NS_E_WMP_BURN_DISC_OVERFLOW),
            MEDIASERVER::NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE),
            MEDIASERVER::NS_E_WMP_DRM_NO_SECURE_CLOCK => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_NO_SECURE_CLOCK),
            MEDIASERVER::NS_E_WMP_DRM_NO_RIGHTS => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_NO_RIGHTS),
            MEDIASERVER::NS_E_WMP_DRM_INDIV_FAILED => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_INDIV_FAILED),
            MEDIASERVER::NS_E_WMP_SERVER_NONEWCONNECTIONS => RawError::Kind(MEDIASERVER::NS_E_WMP_SERVER_NONEWCONNECTIONS),
            MEDIASERVER::NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST),
            MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_FAIL => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_FAIL),
            MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY),
            MEDIASERVER::NS_E_WMP_DRM_COMPONENT_FAILURE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_COMPONENT_FAILURE),
            MEDIASERVER::NS_E_WMP_DRM_NO_DEVICE_CERT => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_NO_DEVICE_CERT),
            MEDIASERVER::NS_E_WMP_SERVER_SECURITY_ERROR => RawError::Kind(MEDIASERVER::NS_E_WMP_SERVER_SECURITY_ERROR),
            MEDIASERVER::NS_E_WMP_AUDIO_DEVICE_LOST => RawError::Kind(MEDIASERVER::NS_E_WMP_AUDIO_DEVICE_LOST),
            MEDIASERVER::NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE => RawError::Kind(MEDIASERVER::NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE),
            MEDIASERVER::NS_E_SYNCWIZ_DEVICE_FULL => RawError::Kind(MEDIASERVER::NS_E_SYNCWIZ_DEVICE_FULL),
            MEDIASERVER::NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS => RawError::Kind(MEDIASERVER::NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS),
            MEDIASERVER::NS_E_TRANSCODE_DELETECACHEERROR => RawError::Kind(MEDIASERVER::NS_E_TRANSCODE_DELETECACHEERROR),
            MEDIASERVER::NS_E_CD_NO_BUFFERS_READ => RawError::Kind(MEDIASERVER::NS_E_CD_NO_BUFFERS_READ),
            MEDIASERVER::NS_E_CD_EMPTY_TRACK_QUEUE => RawError::Kind(MEDIASERVER::NS_E_CD_EMPTY_TRACK_QUEUE),
            MEDIASERVER::NS_E_CD_NO_READER => RawError::Kind(MEDIASERVER::NS_E_CD_NO_READER),
            MEDIASERVER::NS_E_CD_ISRC_INVALID => RawError::Kind(MEDIASERVER::NS_E_CD_ISRC_INVALID),
            MEDIASERVER::NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID => RawError::Kind(MEDIASERVER::NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID),
            MEDIASERVER::NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION => RawError::Kind(MEDIASERVER::NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION),
            MEDIASERVER::NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS => RawError::Kind(MEDIASERVER::NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS),
            MEDIASERVER::NS_E_CD_QUEUEING_DISABLED => RawError::Kind(MEDIASERVER::NS_E_CD_QUEUEING_DISABLED),
            MEDIASERVER::NS_E_WMP_DRM_ACQUIRING_LICENSE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_ACQUIRING_LICENSE),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_EXPIRED),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTACQUIRED => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTACQUIRED),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTENABLED => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTENABLED),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_UNUSABLE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_UNUSABLE),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED),
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOSAP => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOSAP),
            MEDIASERVER::NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE),
            MEDIASERVER::NS_E_WMP_LICENSE_REQUIRED => RawError::Kind(MEDIASERVER::NS_E_WMP_LICENSE_REQUIRED),
            MEDIASERVER::NS_E_WMP_PROTECTED_CONTENT => RawError::Kind(MEDIASERVER::NS_E_WMP_PROTECTED_CONTENT),
            MEDIASERVER::NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED => RawError::Kind(MEDIASERVER::NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED),
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_INTERNET => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_INTERNET),
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST),
            MEDIASERVER::NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE => RawError::Kind(MEDIASERVER::NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE),
            MEDIASERVER::NS_E_PDA_SYNC_FAILED => RawError::Kind(MEDIASERVER::NS_E_PDA_SYNC_FAILED),
            MEDIASERVER::NS_E_PDA_DELETE_FAILED => RawError::Kind(MEDIASERVER::NS_E_PDA_DELETE_FAILED),
            MEDIASERVER::NS_E_PDA_FAILED_TO_RETRIEVE_FILE => RawError::Kind(MEDIASERVER::NS_E_PDA_FAILED_TO_RETRIEVE_FILE),
            MEDIASERVER::NS_E_PDA_DEVICE_NOT_RESPONDING => RawError::Kind(MEDIASERVER::NS_E_PDA_DEVICE_NOT_RESPONDING),
            MEDIASERVER::NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO => RawError::Kind(MEDIASERVER::NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO),
            MEDIASERVER::NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE => RawError::Kind(MEDIASERVER::NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE),
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO),
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO),
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE => RawError::Kind(MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE),
            MEDIASERVER::NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG),
            MEDIASERVER::NS_E_PDA_CEWMDM_DRM_ERROR => RawError::Kind(MEDIASERVER::NS_E_PDA_CEWMDM_DRM_ERROR),
            MEDIASERVER::NS_E_INCOMPLETE_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_INCOMPLETE_PLAYLIST),
            MEDIASERVER::NS_E_PDA_SYNC_RUNNING => RawError::Kind(MEDIASERVER::NS_E_PDA_SYNC_RUNNING),
            MEDIASERVER::NS_E_PDA_SYNC_LOGIN_ERROR => RawError::Kind(MEDIASERVER::NS_E_PDA_SYNC_LOGIN_ERROR),
            MEDIASERVER::NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND),
            MEDIASERVER::NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE => RawError::Kind(MEDIASERVER::NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE),
            MEDIASERVER::NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING => RawError::Kind(MEDIASERVER::NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING),
            MEDIASERVER::NS_E_WMP_HWND_NOTFOUND => RawError::Kind(MEDIASERVER::NS_E_WMP_HWND_NOTFOUND),
            MEDIASERVER::NS_E_BKGDOWNLOAD_WRONG_NO_FILES => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_WRONG_NO_FILES),
            MEDIASERVER::NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB),
            MEDIASERVER::NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB),
            MEDIASERVER::NS_E_BKGDOWNLOAD_NOJOBPOINTER => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_NOJOBPOINTER),
            MEDIASERVER::NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE),
            MEDIASERVER::NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE),
            MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE),
            MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE),
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCFAILED => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCFAILED),
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT),
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCENDED => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCENDED),
            MEDIASERVER::NS_E_BKGDOWNLOAD_WMDUNPACKFAILED => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_WMDUNPACKFAILED),
            MEDIASERVER::NS_E_BKGDOWNLOAD_FAILEDINITIALIZE => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_FAILEDINITIALIZE),
            MEDIASERVER::NS_E_INTERFACE_NOT_REGISTERED_IN_GIT => RawError::Kind(MEDIASERVER::NS_E_INTERFACE_NOT_REGISTERED_IN_GIT),
            MEDIASERVER::NS_E_BKGDOWNLOAD_INVALID_FILE_NAME => RawError::Kind(MEDIASERVER::NS_E_BKGDOWNLOAD_INVALID_FILE_NAME),
            MEDIASERVER::NS_E_IMAGE_DOWNLOAD_FAILED => RawError::Kind(MEDIASERVER::NS_E_IMAGE_DOWNLOAD_FAILED),
            MEDIASERVER::NS_E_WMP_UDRM_NOUSERLIST => RawError::Kind(MEDIASERVER::NS_E_WMP_UDRM_NOUSERLIST),
            MEDIASERVER::NS_E_WMP_DRM_NOT_ACQUIRING => RawError::Kind(MEDIASERVER::NS_E_WMP_DRM_NOT_ACQUIRING),
            MEDIASERVER::NS_E_WMP_BSTR_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_WMP_BSTR_TOO_LONG),
            MEDIASERVER::NS_E_WMP_AUTOPLAY_INVALID_STATE => RawError::Kind(MEDIASERVER::NS_E_WMP_AUTOPLAY_INVALID_STATE),
            MEDIASERVER::NS_E_WMP_COMPONENT_REVOKED => RawError::Kind(MEDIASERVER::NS_E_WMP_COMPONENT_REVOKED),
            MEDIASERVER::NS_E_CURL_NOTSAFE => RawError::Kind(MEDIASERVER::NS_E_CURL_NOTSAFE),
            MEDIASERVER::NS_E_CURL_INVALIDCHAR => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDCHAR),
            MEDIASERVER::NS_E_CURL_INVALIDHOSTNAME => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDHOSTNAME),
            MEDIASERVER::NS_E_CURL_INVALIDPATH => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDPATH),
            MEDIASERVER::NS_E_CURL_INVALIDSCHEME => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDSCHEME),
            MEDIASERVER::NS_E_CURL_INVALIDURL => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDURL),
            MEDIASERVER::NS_E_CURL_CANTWALK => RawError::Kind(MEDIASERVER::NS_E_CURL_CANTWALK),
            MEDIASERVER::NS_E_CURL_INVALIDPORT => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDPORT),
            MEDIASERVER::NS_E_CURLHELPER_NOTADIRECTORY => RawError::Kind(MEDIASERVER::NS_E_CURLHELPER_NOTADIRECTORY),
            MEDIASERVER::NS_E_CURLHELPER_NOTAFILE => RawError::Kind(MEDIASERVER::NS_E_CURLHELPER_NOTAFILE),
            MEDIASERVER::NS_E_CURL_CANTDECODE => RawError::Kind(MEDIASERVER::NS_E_CURL_CANTDECODE),
            MEDIASERVER::NS_E_CURLHELPER_NOTRELATIVE => RawError::Kind(MEDIASERVER::NS_E_CURLHELPER_NOTRELATIVE),
            MEDIASERVER::NS_E_CURL_INVALIDBUFFERSIZE => RawError::Kind(MEDIASERVER::NS_E_CURL_INVALIDBUFFERSIZE),
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED => RawError::Kind(MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED),
            MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES => RawError::Kind(MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES),
            MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT => RawError::Kind(MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT),
            MEDIASERVER::NS_E_NOT_CONTENT_PARTNER_TRACK => RawError::Kind(MEDIASERVER::NS_E_NOT_CONTENT_PARTNER_TRACK),
            MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE => RawError::Kind(MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE),
            MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE => RawError::Kind(MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE),
            MEDIASERVER::NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED => RawError::Kind(MEDIASERVER::NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED),
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED => RawError::Kind(MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED),
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT),
            MEDIASERVER::NS_E_CONTENT_PARTNER_STILL_INITIALIZING => RawError::Kind(MEDIASERVER::NS_E_CONTENT_PARTNER_STILL_INITIALIZING),
            MEDIASERVER::NS_E_OPEN_CONTAINING_FOLDER_FAILED => RawError::Kind(MEDIASERVER::NS_E_OPEN_CONTAINING_FOLDER_FAILED),
            MEDIASERVER::NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES => RawError::Kind(MEDIASERVER::NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES),
            MEDIASERVER::NS_E_REDIRECT => RawError::Kind(MEDIASERVER::NS_E_REDIRECT),
            MEDIASERVER::NS_E_STALE_PRESENTATION => RawError::Kind(MEDIASERVER::NS_E_STALE_PRESENTATION),
            MEDIASERVER::NS_E_NAMESPACE_WRONG_PERSIST => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_WRONG_PERSIST),
            MEDIASERVER::NS_E_NAMESPACE_WRONG_TYPE => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_WRONG_TYPE),
            MEDIASERVER::NS_E_NAMESPACE_NODE_CONFLICT => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_NODE_CONFLICT),
            MEDIASERVER::NS_E_NAMESPACE_NODE_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_NODE_NOT_FOUND),
            MEDIASERVER::NS_E_NAMESPACE_BUFFER_TOO_SMALL => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_BUFFER_TOO_SMALL),
            MEDIASERVER::NS_E_NAMESPACE_TOO_MANY_CALLBACKS => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_TOO_MANY_CALLBACKS),
            MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_CALLBACK => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_CALLBACK),
            MEDIASERVER::NS_E_NAMESPACE_CALLBACK_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_CALLBACK_NOT_FOUND),
            MEDIASERVER::NS_E_NAMESPACE_NAME_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_NAME_TOO_LONG),
            MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_NAME => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_NAME),
            MEDIASERVER::NS_E_NAMESPACE_EMPTY_NAME => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_EMPTY_NAME),
            MEDIASERVER::NS_E_NAMESPACE_INDEX_TOO_LARGE => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_INDEX_TOO_LARGE),
            MEDIASERVER::NS_E_NAMESPACE_BAD_NAME => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_BAD_NAME),
            MEDIASERVER::NS_E_NAMESPACE_WRONG_SECURITY => RawError::Kind(MEDIASERVER::NS_E_NAMESPACE_WRONG_SECURITY),
            MEDIASERVER::NS_E_CACHE_ARCHIVE_CONFLICT => RawError::Kind(MEDIASERVER::NS_E_CACHE_ARCHIVE_CONFLICT),
            MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND),
            MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_TIMEOUT),
            MEDIASERVER::NS_E_CACHE_NOT_BROADCAST => RawError::Kind(MEDIASERVER::NS_E_CACHE_NOT_BROADCAST),
            MEDIASERVER::NS_E_CACHE_CANNOT_BE_CACHED => RawError::Kind(MEDIASERVER::NS_E_CACHE_CANNOT_BE_CACHED),
            MEDIASERVER::NS_E_CACHE_NOT_MODIFIED => RawError::Kind(MEDIASERVER::NS_E_CACHE_NOT_MODIFIED),
            MEDIASERVER::NS_E_CANNOT_REMOVE_PUBLISHING_POINT => RawError::Kind(MEDIASERVER::NS_E_CANNOT_REMOVE_PUBLISHING_POINT),
            MEDIASERVER::NS_E_CANNOT_REMOVE_PLUGIN => RawError::Kind(MEDIASERVER::NS_E_CANNOT_REMOVE_PLUGIN),
            MEDIASERVER::NS_E_WRONG_PUBLISHING_POINT_TYPE => RawError::Kind(MEDIASERVER::NS_E_WRONG_PUBLISHING_POINT_TYPE),
            MEDIASERVER::NS_E_UNSUPPORTED_LOAD_TYPE => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_LOAD_TYPE),
            MEDIASERVER::NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION => RawError::Kind(MEDIASERVER::NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION),
            MEDIASERVER::NS_E_INVALID_PUBLISHING_POINT_NAME => RawError::Kind(MEDIASERVER::NS_E_INVALID_PUBLISHING_POINT_NAME),
            MEDIASERVER::NS_E_TOO_MANY_MULTICAST_SINKS => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_MULTICAST_SINKS),
            MEDIASERVER::NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED => RawError::Kind(MEDIASERVER::NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED),
            MEDIASERVER::NS_E_MULTICAST_PLUGIN_NOT_ENABLED => RawError::Kind(MEDIASERVER::NS_E_MULTICAST_PLUGIN_NOT_ENABLED),
            MEDIASERVER::NS_E_INVALID_OPERATING_SYSTEM_VERSION => RawError::Kind(MEDIASERVER::NS_E_INVALID_OPERATING_SYSTEM_VERSION),
            MEDIASERVER::NS_E_PUBLISHING_POINT_REMOVED => RawError::Kind(MEDIASERVER::NS_E_PUBLISHING_POINT_REMOVED),
            MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST => RawError::Kind(MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST),
            MEDIASERVER::NS_E_UNSUPPORTED_LANGUAGE => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_LANGUAGE),
            MEDIASERVER::NS_E_WRONG_OS_VERSION => RawError::Kind(MEDIASERVER::NS_E_WRONG_OS_VERSION),
            MEDIASERVER::NS_E_PUBLISHING_POINT_STOPPED => RawError::Kind(MEDIASERVER::NS_E_PUBLISHING_POINT_STOPPED),
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING),
            MEDIASERVER::NS_E_EMPTY_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_EMPTY_PLAYLIST),
            MEDIASERVER::NS_E_PLAYLIST_PARSE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_PARSE_FAILURE),
            MEDIASERVER::NS_E_PLAYLIST_UNSUPPORTED_ENTRY => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_UNSUPPORTED_ENTRY),
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST),
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_SEEK => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_ENTRY_SEEK),
            MEDIASERVER::NS_E_PLAYLIST_RECURSIVE_PLAYLISTS => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_RECURSIVE_PLAYLISTS),
            MEDIASERVER::NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS),
            MEDIASERVER::NS_E_PLAYLIST_SHUTDOWN => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_SHUTDOWN),
            MEDIASERVER::NS_E_PLAYLIST_END_RECEDING => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_END_RECEDING),
            MEDIASERVER::NS_E_DATAPATH_NO_SINK => RawError::Kind(MEDIASERVER::NS_E_DATAPATH_NO_SINK),
            MEDIASERVER::NS_E_INVALID_PUSH_TEMPLATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_PUSH_TEMPLATE),
            MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT => RawError::Kind(MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT),
            MEDIASERVER::NS_E_CRITICAL_ERROR => RawError::Kind(MEDIASERVER::NS_E_CRITICAL_ERROR),
            MEDIASERVER::NS_E_NO_NEW_CONNECTIONS => RawError::Kind(MEDIASERVER::NS_E_NO_NEW_CONNECTIONS),
            MEDIASERVER::NS_E_WSX_INVALID_VERSION => RawError::Kind(MEDIASERVER::NS_E_WSX_INVALID_VERSION),
            MEDIASERVER::NS_E_HEADER_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_HEADER_MISMATCH),
            MEDIASERVER::NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME => RawError::Kind(MEDIASERVER::NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME),
            MEDIASERVER::NS_E_NO_SCRIPT_ENGINE => RawError::Kind(MEDIASERVER::NS_E_NO_SCRIPT_ENGINE),
            MEDIASERVER::NS_E_PLUGIN_ERROR_REPORTED => RawError::Kind(MEDIASERVER::NS_E_PLUGIN_ERROR_REPORTED),
            MEDIASERVER::NS_E_SOURCE_PLUGIN_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_SOURCE_PLUGIN_NOT_FOUND),
            MEDIASERVER::NS_E_PLAYLIST_PLUGIN_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_PLUGIN_NOT_FOUND),
            MEDIASERVER::NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED),
            MEDIASERVER::NS_E_MEDIA_PARSER_INVALID_FORMAT => RawError::Kind(MEDIASERVER::NS_E_MEDIA_PARSER_INVALID_FORMAT),
            MEDIASERVER::NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED => RawError::Kind(MEDIASERVER::NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED),
            MEDIASERVER::NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER => RawError::Kind(MEDIASERVER::NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER),
            MEDIASERVER::NS_E_WIZARD_RUNNING => RawError::Kind(MEDIASERVER::NS_E_WIZARD_RUNNING),
            MEDIASERVER::NS_E_INVALID_LOG_URL => RawError::Kind(MEDIASERVER::NS_E_INVALID_LOG_URL),
            MEDIASERVER::NS_E_INVALID_MTU_RANGE => RawError::Kind(MEDIASERVER::NS_E_INVALID_MTU_RANGE),
            MEDIASERVER::NS_E_INVALID_PLAY_STATISTICS => RawError::Kind(MEDIASERVER::NS_E_INVALID_PLAY_STATISTICS),
            MEDIASERVER::NS_E_LOG_NEED_TO_BE_SKIPPED => RawError::Kind(MEDIASERVER::NS_E_LOG_NEED_TO_BE_SKIPPED),
            MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED => RawError::Kind(MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED),
            MEDIASERVER::NS_E_PORT_IN_USE => RawError::Kind(MEDIASERVER::NS_E_PORT_IN_USE),
            MEDIASERVER::NS_E_PORT_IN_USE_HTTP => RawError::Kind(MEDIASERVER::NS_E_PORT_IN_USE_HTTP),
            MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE => RawError::Kind(MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE),
            MEDIASERVER::NS_E_ARCHIVE_REACH_QUOTA => RawError::Kind(MEDIASERVER::NS_E_ARCHIVE_REACH_QUOTA),
            MEDIASERVER::NS_E_ARCHIVE_ABORT_DUE_TO_BCAST => RawError::Kind(MEDIASERVER::NS_E_ARCHIVE_ABORT_DUE_TO_BCAST),
            MEDIASERVER::NS_E_ARCHIVE_GAP_DETECTED => RawError::Kind(MEDIASERVER::NS_E_ARCHIVE_GAP_DETECTED),
            MEDIASERVER::NS_E_AUTHORIZATION_FILE_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_AUTHORIZATION_FILE_NOT_FOUND),
            MEDIASERVER::NS_E_BAD_MARKIN => RawError::Kind(MEDIASERVER::NS_E_BAD_MARKIN),
            MEDIASERVER::NS_E_BAD_MARKOUT => RawError::Kind(MEDIASERVER::NS_E_BAD_MARKOUT),
            MEDIASERVER::NS_E_NOMATCHING_MEDIASOURCE => RawError::Kind(MEDIASERVER::NS_E_NOMATCHING_MEDIASOURCE),
            MEDIASERVER::NS_E_UNSUPPORTED_SOURCETYPE => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_SOURCETYPE),
            MEDIASERVER::NS_E_TOO_MANY_AUDIO => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_AUDIO),
            MEDIASERVER::NS_E_TOO_MANY_VIDEO => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_VIDEO),
            MEDIASERVER::NS_E_NOMATCHING_ELEMENT => RawError::Kind(MEDIASERVER::NS_E_NOMATCHING_ELEMENT),
            MEDIASERVER::NS_E_MISMATCHED_MEDIACONTENT => RawError::Kind(MEDIASERVER::NS_E_MISMATCHED_MEDIACONTENT),
            MEDIASERVER::NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP => RawError::Kind(MEDIASERVER::NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP),
            MEDIASERVER::NS_E_AUDIODEVICE_BUSY => RawError::Kind(MEDIASERVER::NS_E_AUDIODEVICE_BUSY),
            MEDIASERVER::NS_E_AUDIODEVICE_UNEXPECTED => RawError::Kind(MEDIASERVER::NS_E_AUDIODEVICE_UNEXPECTED),
            MEDIASERVER::NS_E_AUDIODEVICE_BADFORMAT => RawError::Kind(MEDIASERVER::NS_E_AUDIODEVICE_BADFORMAT),
            MEDIASERVER::NS_E_VIDEODEVICE_BUSY => RawError::Kind(MEDIASERVER::NS_E_VIDEODEVICE_BUSY),
            MEDIASERVER::NS_E_VIDEODEVICE_UNEXPECTED => RawError::Kind(MEDIASERVER::NS_E_VIDEODEVICE_UNEXPECTED),
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING => RawError::Kind(MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING),
            MEDIASERVER::NS_E_NO_PROFILE_IN_SOURCEGROUP => RawError::Kind(MEDIASERVER::NS_E_NO_PROFILE_IN_SOURCEGROUP),
            MEDIASERVER::NS_E_VIDEODRIVER_UNSTABLE => RawError::Kind(MEDIASERVER::NS_E_VIDEODRIVER_UNSTABLE),
            MEDIASERVER::NS_E_VIDCAPSTARTFAILED => RawError::Kind(MEDIASERVER::NS_E_VIDCAPSTARTFAILED),
            MEDIASERVER::NS_E_VIDSOURCECOMPRESSION => RawError::Kind(MEDIASERVER::NS_E_VIDSOURCECOMPRESSION),
            MEDIASERVER::NS_E_VIDSOURCESIZE => RawError::Kind(MEDIASERVER::NS_E_VIDSOURCESIZE),
            MEDIASERVER::NS_E_ICMQUERYFORMAT => RawError::Kind(MEDIASERVER::NS_E_ICMQUERYFORMAT),
            MEDIASERVER::NS_E_VIDCAPCREATEWINDOW => RawError::Kind(MEDIASERVER::NS_E_VIDCAPCREATEWINDOW),
            MEDIASERVER::NS_E_VIDCAPDRVINUSE => RawError::Kind(MEDIASERVER::NS_E_VIDCAPDRVINUSE),
            MEDIASERVER::NS_E_NO_MEDIAFORMAT_IN_SOURCE => RawError::Kind(MEDIASERVER::NS_E_NO_MEDIAFORMAT_IN_SOURCE),
            MEDIASERVER::NS_E_NO_VALID_OUTPUT_STREAM => RawError::Kind(MEDIASERVER::NS_E_NO_VALID_OUTPUT_STREAM),
            MEDIASERVER::NS_E_NO_VALID_SOURCE_PLUGIN => RawError::Kind(MEDIASERVER::NS_E_NO_VALID_SOURCE_PLUGIN),
            MEDIASERVER::NS_E_NO_ACTIVE_SOURCEGROUP => RawError::Kind(MEDIASERVER::NS_E_NO_ACTIVE_SOURCEGROUP),
            MEDIASERVER::NS_E_NO_SCRIPT_STREAM => RawError::Kind(MEDIASERVER::NS_E_NO_SCRIPT_STREAM),
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING => RawError::Kind(MEDIASERVER::NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING),
            MEDIASERVER::NS_E_INVALIDPACKETSIZE => RawError::Kind(MEDIASERVER::NS_E_INVALIDPACKETSIZE),
            MEDIASERVER::NS_E_PLUGIN_CLSID_INVALID => RawError::Kind(MEDIASERVER::NS_E_PLUGIN_CLSID_INVALID),
            MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVETYPE => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVETYPE),
            MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVEOPERATION => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVEOPERATION),
            MEDIASERVER::NS_E_ARCHIVE_FILENAME_NOTSET => RawError::Kind(MEDIASERVER::NS_E_ARCHIVE_FILENAME_NOTSET),
            MEDIASERVER::NS_E_SOURCEGROUP_NOTPREPARED => RawError::Kind(MEDIASERVER::NS_E_SOURCEGROUP_NOTPREPARED),
            MEDIASERVER::NS_E_PROFILE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_PROFILE_MISMATCH),
            MEDIASERVER::NS_E_INCORRECTCLIPSETTINGS => RawError::Kind(MEDIASERVER::NS_E_INCORRECTCLIPSETTINGS),
            MEDIASERVER::NS_E_NOSTATSAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_NOSTATSAVAILABLE),
            MEDIASERVER::NS_E_NOTARCHIVING => RawError::Kind(MEDIASERVER::NS_E_NOTARCHIVING),
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED => RawError::Kind(MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED),
            MEDIASERVER::NS_E_NOSOURCEGROUPS => RawError::Kind(MEDIASERVER::NS_E_NOSOURCEGROUPS),
            MEDIASERVER::NS_E_INVALIDINPUTFPS => RawError::Kind(MEDIASERVER::NS_E_INVALIDINPUTFPS),
            MEDIASERVER::NS_E_NO_DATAVIEW_SUPPORT => RawError::Kind(MEDIASERVER::NS_E_NO_DATAVIEW_SUPPORT),
            MEDIASERVER::NS_E_CODEC_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_CODEC_UNAVAILABLE),
            MEDIASERVER::NS_E_ARCHIVE_SAME_AS_INPUT => RawError::Kind(MEDIASERVER::NS_E_ARCHIVE_SAME_AS_INPUT),
            MEDIASERVER::NS_E_SOURCE_NOTSPECIFIED => RawError::Kind(MEDIASERVER::NS_E_SOURCE_NOTSPECIFIED),
            MEDIASERVER::NS_E_NO_REALTIME_TIMECOMPRESSION => RawError::Kind(MEDIASERVER::NS_E_NO_REALTIME_TIMECOMPRESSION),
            MEDIASERVER::NS_E_UNSUPPORTED_ENCODER_DEVICE => RawError::Kind(MEDIASERVER::NS_E_UNSUPPORTED_ENCODER_DEVICE),
            MEDIASERVER::NS_E_UNEXPECTED_DISPLAY_SETTINGS => RawError::Kind(MEDIASERVER::NS_E_UNEXPECTED_DISPLAY_SETTINGS),
            MEDIASERVER::NS_E_NO_AUDIODATA => RawError::Kind(MEDIASERVER::NS_E_NO_AUDIODATA),
            MEDIASERVER::NS_E_INPUTSOURCE_PROBLEM => RawError::Kind(MEDIASERVER::NS_E_INPUTSOURCE_PROBLEM),
            MEDIASERVER::NS_E_WME_VERSION_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_WME_VERSION_MISMATCH),
            MEDIASERVER::NS_E_NO_REALTIME_PREPROCESS => RawError::Kind(MEDIASERVER::NS_E_NO_REALTIME_PREPROCESS),
            MEDIASERVER::NS_E_NO_REPEAT_PREPROCESS => RawError::Kind(MEDIASERVER::NS_E_NO_REPEAT_PREPROCESS),
            MEDIASERVER::NS_E_CANNOT_PAUSE_LIVEBROADCAST => RawError::Kind(MEDIASERVER::NS_E_CANNOT_PAUSE_LIVEBROADCAST),
            MEDIASERVER::NS_E_DRM_PROFILE_NOT_SET => RawError::Kind(MEDIASERVER::NS_E_DRM_PROFILE_NOT_SET),
            MEDIASERVER::NS_E_DUPLICATE_DRMPROFILE => RawError::Kind(MEDIASERVER::NS_E_DUPLICATE_DRMPROFILE),
            MEDIASERVER::NS_E_INVALID_DEVICE => RawError::Kind(MEDIASERVER::NS_E_INVALID_DEVICE),
            MEDIASERVER::NS_E_SPEECHEDL_ON_NON_MIXEDMODE => RawError::Kind(MEDIASERVER::NS_E_SPEECHEDL_ON_NON_MIXEDMODE),
            MEDIASERVER::NS_E_DRM_PASSWORD_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_DRM_PASSWORD_TOO_LONG),
            MEDIASERVER::NS_E_DEVCONTROL_FAILED_SEEK => RawError::Kind(MEDIASERVER::NS_E_DEVCONTROL_FAILED_SEEK),
            MEDIASERVER::NS_E_INTERLACE_REQUIRE_SAMESIZE => RawError::Kind(MEDIASERVER::NS_E_INTERLACE_REQUIRE_SAMESIZE),
            MEDIASERVER::NS_E_TOO_MANY_DEVICECONTROL => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_DEVICECONTROL),
            MEDIASERVER::NS_E_NO_MULTIPASS_FOR_LIVEDEVICE => RawError::Kind(MEDIASERVER::NS_E_NO_MULTIPASS_FOR_LIVEDEVICE),
            MEDIASERVER::NS_E_MISSING_AUDIENCE => RawError::Kind(MEDIASERVER::NS_E_MISSING_AUDIENCE),
            MEDIASERVER::NS_E_AUDIENCE_CONTENTTYPE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_AUDIENCE_CONTENTTYPE_MISMATCH),
            MEDIASERVER::NS_E_MISSING_SOURCE_INDEX => RawError::Kind(MEDIASERVER::NS_E_MISSING_SOURCE_INDEX),
            MEDIASERVER::NS_E_NUM_LANGUAGE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_NUM_LANGUAGE_MISMATCH),
            MEDIASERVER::NS_E_LANGUAGE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_LANGUAGE_MISMATCH),
            MEDIASERVER::NS_E_VBRMODE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_VBRMODE_MISMATCH),
            MEDIASERVER::NS_E_INVALID_INPUT_AUDIENCE_INDEX => RawError::Kind(MEDIASERVER::NS_E_INVALID_INPUT_AUDIENCE_INDEX),
            MEDIASERVER::NS_E_INVALID_INPUT_LANGUAGE => RawError::Kind(MEDIASERVER::NS_E_INVALID_INPUT_LANGUAGE),
            MEDIASERVER::NS_E_INVALID_INPUT_STREAM => RawError::Kind(MEDIASERVER::NS_E_INVALID_INPUT_STREAM),
            MEDIASERVER::NS_E_EXPECT_MONO_WAV_INPUT => RawError::Kind(MEDIASERVER::NS_E_EXPECT_MONO_WAV_INPUT),
            MEDIASERVER::NS_E_INPUT_WAVFORMAT_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_INPUT_WAVFORMAT_MISMATCH),
            MEDIASERVER::NS_E_RECORDQ_DISK_FULL => RawError::Kind(MEDIASERVER::NS_E_RECORDQ_DISK_FULL),
            MEDIASERVER::NS_E_NO_PAL_INVERSE_TELECINE => RawError::Kind(MEDIASERVER::NS_E_NO_PAL_INVERSE_TELECINE),
            MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_DISCONNECTED => RawError::Kind(MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_DISCONNECTED),
            MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED => RawError::Kind(MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED),
            MEDIASERVER::NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER => RawError::Kind(MEDIASERVER::NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER),
            MEDIASERVER::NS_E_INPUT_DOESNOT_SUPPORT_SMPTE => RawError::Kind(MEDIASERVER::NS_E_INPUT_DOESNOT_SUPPORT_SMPTE),
            MEDIASERVER::NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS => RawError::Kind(MEDIASERVER::NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS),
            MEDIASERVER::NS_E_BAD_CONTENTEDL => RawError::Kind(MEDIASERVER::NS_E_BAD_CONTENTEDL),
            MEDIASERVER::NS_E_INTERLACEMODE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_INTERLACEMODE_MISMATCH),
            MEDIASERVER::NS_E_NONSQUAREPIXELMODE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_NONSQUAREPIXELMODE_MISMATCH),
            MEDIASERVER::NS_E_SMPTEMODE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_SMPTEMODE_MISMATCH),
            MEDIASERVER::NS_E_END_OF_TAPE => RawError::Kind(MEDIASERVER::NS_E_END_OF_TAPE),
            MEDIASERVER::NS_E_NO_MEDIA_IN_AUDIENCE => RawError::Kind(MEDIASERVER::NS_E_NO_MEDIA_IN_AUDIENCE),
            MEDIASERVER::NS_E_NO_AUDIENCES => RawError::Kind(MEDIASERVER::NS_E_NO_AUDIENCES),
            MEDIASERVER::NS_E_NO_AUDIO_COMPAT => RawError::Kind(MEDIASERVER::NS_E_NO_AUDIO_COMPAT),
            MEDIASERVER::NS_E_INVALID_VBR_COMPAT => RawError::Kind(MEDIASERVER::NS_E_INVALID_VBR_COMPAT),
            MEDIASERVER::NS_E_NO_PROFILE_NAME => RawError::Kind(MEDIASERVER::NS_E_NO_PROFILE_NAME),
            MEDIASERVER::NS_E_INVALID_VBR_WITH_UNCOMP => RawError::Kind(MEDIASERVER::NS_E_INVALID_VBR_WITH_UNCOMP),
            MEDIASERVER::NS_E_MULTIPLE_VBR_AUDIENCES => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_VBR_AUDIENCES),
            MEDIASERVER::NS_E_UNCOMP_COMP_COMBINATION => RawError::Kind(MEDIASERVER::NS_E_UNCOMP_COMP_COMBINATION),
            MEDIASERVER::NS_E_MULTIPLE_AUDIO_CODECS => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_AUDIO_CODECS),
            MEDIASERVER::NS_E_MULTIPLE_AUDIO_FORMATS => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_AUDIO_FORMATS),
            MEDIASERVER::NS_E_AUDIO_BITRATE_STEPDOWN => RawError::Kind(MEDIASERVER::NS_E_AUDIO_BITRATE_STEPDOWN),
            MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE),
            MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE_2 => RawError::Kind(MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE_2),
            MEDIASERVER::NS_E_INVALID_AUDIO_BUFFERMAX => RawError::Kind(MEDIASERVER::NS_E_INVALID_AUDIO_BUFFERMAX),
            MEDIASERVER::NS_E_MULTIPLE_VIDEO_CODECS => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_VIDEO_CODECS),
            MEDIASERVER::NS_E_MULTIPLE_VIDEO_SIZES => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_VIDEO_SIZES),
            MEDIASERVER::NS_E_INVALID_VIDEO_BITRATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_BITRATE),
            MEDIASERVER::NS_E_VIDEO_BITRATE_STEPDOWN => RawError::Kind(MEDIASERVER::NS_E_VIDEO_BITRATE_STEPDOWN),
            MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE),
            MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE_2 => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE_2),
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH),
            MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT),
            MEDIASERVER::NS_E_INVALID_VIDEO_FPS => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_FPS),
            MEDIASERVER::NS_E_INVALID_VIDEO_KEYFRAME => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_KEYFRAME),
            MEDIASERVER::NS_E_INVALID_VIDEO_IQUALITY => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_IQUALITY),
            MEDIASERVER::NS_E_INVALID_VIDEO_CQUALITY => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_CQUALITY),
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFER => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_BUFFER),
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX),
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX_2 => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX_2),
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_ALIGN => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_ALIGN),
            MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT_ALIGN => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT_ALIGN),
            MEDIASERVER::NS_E_MULTIPLE_SCRIPT_BITRATES => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_SCRIPT_BITRATES),
            MEDIASERVER::NS_E_INVALID_SCRIPT_BITRATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_SCRIPT_BITRATE),
            MEDIASERVER::NS_E_MULTIPLE_FILE_BITRATES => RawError::Kind(MEDIASERVER::NS_E_MULTIPLE_FILE_BITRATES),
            MEDIASERVER::NS_E_INVALID_FILE_BITRATE => RawError::Kind(MEDIASERVER::NS_E_INVALID_FILE_BITRATE),
            MEDIASERVER::NS_E_SAME_AS_INPUT_COMBINATION => RawError::Kind(MEDIASERVER::NS_E_SAME_AS_INPUT_COMBINATION),
            MEDIASERVER::NS_E_SOURCE_CANNOT_LOOP => RawError::Kind(MEDIASERVER::NS_E_SOURCE_CANNOT_LOOP),
            MEDIASERVER::NS_E_INVALID_FOLDDOWN_COEFFICIENTS => RawError::Kind(MEDIASERVER::NS_E_INVALID_FOLDDOWN_COEFFICIENTS),
            MEDIASERVER::NS_E_DRMPROFILE_NOTFOUND => RawError::Kind(MEDIASERVER::NS_E_DRMPROFILE_NOTFOUND),
            MEDIASERVER::NS_E_INVALID_TIMECODE => RawError::Kind(MEDIASERVER::NS_E_INVALID_TIMECODE),
            MEDIASERVER::NS_E_NO_AUDIO_TIMECOMPRESSION => RawError::Kind(MEDIASERVER::NS_E_NO_AUDIO_TIMECOMPRESSION),
            MEDIASERVER::NS_E_NO_TWOPASS_TIMECOMPRESSION => RawError::Kind(MEDIASERVER::NS_E_NO_TWOPASS_TIMECOMPRESSION),
            MEDIASERVER::NS_E_TIMECODE_REQUIRES_VIDEOSTREAM => RawError::Kind(MEDIASERVER::NS_E_TIMECODE_REQUIRES_VIDEOSTREAM),
            MEDIASERVER::NS_E_NO_MBR_WITH_TIMECODE => RawError::Kind(MEDIASERVER::NS_E_NO_MBR_WITH_TIMECODE),
            MEDIASERVER::NS_E_INVALID_INTERLACEMODE => RawError::Kind(MEDIASERVER::NS_E_INVALID_INTERLACEMODE),
            MEDIASERVER::NS_E_INVALID_INTERLACE_COMPAT => RawError::Kind(MEDIASERVER::NS_E_INVALID_INTERLACE_COMPAT),
            MEDIASERVER::NS_E_INVALID_NONSQUAREPIXEL_COMPAT => RawError::Kind(MEDIASERVER::NS_E_INVALID_NONSQUAREPIXEL_COMPAT),
            MEDIASERVER::NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL => RawError::Kind(MEDIASERVER::NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL),
            MEDIASERVER::NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR => RawError::Kind(MEDIASERVER::NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR),
            MEDIASERVER::NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT => RawError::Kind(MEDIASERVER::NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT),
            MEDIASERVER::NS_E_DEVICECONTROL_UNSTABLE => RawError::Kind(MEDIASERVER::NS_E_DEVICECONTROL_UNSTABLE),
            MEDIASERVER::NS_E_INVALID_PIXEL_ASPECT_RATIO => RawError::Kind(MEDIASERVER::NS_E_INVALID_PIXEL_ASPECT_RATIO),
            MEDIASERVER::NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH),
            MEDIASERVER::NS_E_INVALID_PROFILE_CONTENTTYPE => RawError::Kind(MEDIASERVER::NS_E_INVALID_PROFILE_CONTENTTYPE),
            MEDIASERVER::NS_E_TRANSFORM_PLUGIN_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_TRANSFORM_PLUGIN_NOT_FOUND),
            MEDIASERVER::NS_E_TRANSFORM_PLUGIN_INVALID => RawError::Kind(MEDIASERVER::NS_E_TRANSFORM_PLUGIN_INVALID),
            MEDIASERVER::NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS => RawError::Kind(MEDIASERVER::NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS),
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING => RawError::Kind(MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING),
            MEDIASERVER::NS_E_MARKIN_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_MARKIN_UNSUPPORTED),
            MEDIASERVER::NS_E_DRM_INVALID_APPLICATION => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_APPLICATION),
            MEDIASERVER::NS_E_DRM_LICENSE_STORE_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_STORE_ERROR),
            MEDIASERVER::NS_E_DRM_SECURE_STORE_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_SECURE_STORE_ERROR),
            MEDIASERVER::NS_E_DRM_LICENSE_STORE_SAVE_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_STORE_SAVE_ERROR),
            MEDIASERVER::NS_E_DRM_SECURE_STORE_UNLOCK_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_SECURE_STORE_UNLOCK_ERROR),
            MEDIASERVER::NS_E_DRM_INVALID_CONTENT => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_CONTENT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_LICENSE => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_LICENSE),
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_LICENSE),
            MEDIASERVER::NS_E_DRM_INVALID_MACHINE => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_MACHINE),
            MEDIASERVER::NS_E_DRM_ENUM_LICENSE_FAILED => RawError::Kind(MEDIASERVER::NS_E_DRM_ENUM_LICENSE_FAILED),
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE_REQUEST => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_LICENSE_REQUEST),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_INITIALIZE => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_INITIALIZE),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE),
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE_ACQUIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_LICENSE_ACQUIRED),
            MEDIASERVER::NS_E_DRM_NO_RIGHTS => RawError::Kind(MEDIASERVER::NS_E_DRM_NO_RIGHTS),
            MEDIASERVER::NS_E_DRM_KEY_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_KEY_ERROR),
            MEDIASERVER::NS_E_DRM_ENCRYPT_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_ENCRYPT_ERROR),
            MEDIASERVER::NS_E_DRM_DECRYPT_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_DECRYPT_ERROR),
            MEDIASERVER::NS_E_DRM_LICENSE_INVALID_XML => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_INVALID_XML),
            MEDIASERVER::NS_E_DRM_NEEDS_INDIVIDUALIZATION => RawError::Kind(MEDIASERVER::NS_E_DRM_NEEDS_INDIVIDUALIZATION),
            MEDIASERVER::NS_E_DRM_ALREADY_INDIVIDUALIZED => RawError::Kind(MEDIASERVER::NS_E_DRM_ALREADY_INDIVIDUALIZED),
            MEDIASERVER::NS_E_DRM_ACTION_NOT_QUERIED => RawError::Kind(MEDIASERVER::NS_E_DRM_ACTION_NOT_QUERIED),
            MEDIASERVER::NS_E_DRM_ACQUIRING_LICENSE => RawError::Kind(MEDIASERVER::NS_E_DRM_ACQUIRING_LICENSE),
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZING => RawError::Kind(MEDIASERVER::NS_E_DRM_INDIVIDUALIZING),
            MEDIASERVER::NS_E_BACKUP_RESTORE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_BACKUP_RESTORE_FAILURE),
            MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_REQUEST_ID => RawError::Kind(MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_REQUEST_ID),
            MEDIASERVER::NS_E_DRM_PARAMETERS_MISMATCHED => RawError::Kind(MEDIASERVER::NS_E_DRM_PARAMETERS_MISMATCHED),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT),
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZE_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_INDIVIDUALIZE_ERROR),
            MEDIASERVER::NS_E_DRM_LICENSE_OPEN_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_OPEN_ERROR),
            MEDIASERVER::NS_E_DRM_LICENSE_CLOSE_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_CLOSE_ERROR),
            MEDIASERVER::NS_E_DRM_GET_LICENSE_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_GET_LICENSE_ERROR),
            MEDIASERVER::NS_E_DRM_QUERY_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_QUERY_ERROR),
            MEDIASERVER::NS_E_DRM_REPORT_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_REPORT_ERROR),
            MEDIASERVER::NS_E_DRM_GET_LICENSESTRING_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_GET_LICENSESTRING_ERROR),
            MEDIASERVER::NS_E_DRM_GET_CONTENTSTRING_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_GET_CONTENTSTRING_ERROR),
            MEDIASERVER::NS_E_DRM_MONITOR_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_MONITOR_ERROR),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_PARAMETER => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_PARAMETER),
            MEDIASERVER::NS_E_DRM_INVALID_APPDATA => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_APPDATA),
            MEDIASERVER::NS_E_DRM_INVALID_APPDATA_VERSION => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_APPDATA_VERSION),
            MEDIASERVER::NS_E_DRM_BACKUP_EXISTS => RawError::Kind(MEDIASERVER::NS_E_DRM_BACKUP_EXISTS),
            MEDIASERVER::NS_E_DRM_BACKUP_CORRUPT => RawError::Kind(MEDIASERVER::NS_E_DRM_BACKUP_CORRUPT),
            MEDIASERVER::NS_E_DRM_BACKUPRESTORE_BUSY => RawError::Kind(MEDIASERVER::NS_E_DRM_BACKUPRESTORE_BUSY),
            MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_DATA => RawError::Kind(MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_DATA),
            MEDIASERVER::NS_E_DRM_LICENSE_UNUSABLE => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_UNUSABLE),
            MEDIASERVER::NS_E_DRM_INVALID_PROPERTY => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_PROPERTY),
            MEDIASERVER::NS_E_DRM_SECURE_STORE_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_DRM_SECURE_STORE_NOT_FOUND),
            MEDIASERVER::NS_E_DRM_CACHED_CONTENT_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_CACHED_CONTENT_ERROR),
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE => RawError::Kind(MEDIASERVER::NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE),
            MEDIASERVER::NS_E_DRM_DRIVER_AUTH_FAILURE => RawError::Kind(MEDIASERVER::NS_E_DRM_DRIVER_AUTH_FAILURE),
            MEDIASERVER::NS_E_DRM_NEED_UPGRADE_MSSAP => RawError::Kind(MEDIASERVER::NS_E_DRM_NEED_UPGRADE_MSSAP),
            MEDIASERVER::NS_E_DRM_REOPEN_CONTENT => RawError::Kind(MEDIASERVER::NS_E_DRM_REOPEN_CONTENT),
            MEDIASERVER::NS_E_DRM_DRIVER_DIGIOUT_FAILURE => RawError::Kind(MEDIASERVER::NS_E_DRM_DRIVER_DIGIOUT_FAILURE),
            MEDIASERVER::NS_E_DRM_INVALID_SECURESTORE_PASSWORD => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_SECURESTORE_PASSWORD),
            MEDIASERVER::NS_E_DRM_APPCERT_REVOKED => RawError::Kind(MEDIASERVER::NS_E_DRM_APPCERT_REVOKED),
            MEDIASERVER::NS_E_DRM_RESTORE_FRAUD => RawError::Kind(MEDIASERVER::NS_E_DRM_RESTORE_FRAUD),
            MEDIASERVER::NS_E_DRM_HARDWARE_INCONSISTENT => RawError::Kind(MEDIASERVER::NS_E_DRM_HARDWARE_INCONSISTENT),
            MEDIASERVER::NS_E_DRM_SDMI_TRIGGER => RawError::Kind(MEDIASERVER::NS_E_DRM_SDMI_TRIGGER),
            MEDIASERVER::NS_E_DRM_SDMI_NOMORECOPIES => RawError::Kind(MEDIASERVER::NS_E_DRM_SDMI_NOMORECOPIES),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT),
            MEDIASERVER::NS_E_DRM_LICENSE_NOTACQUIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_NOTACQUIRED),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT),
            MEDIASERVER::NS_E_DRM_BUFFER_TOO_SMALL => RawError::Kind(MEDIASERVER::NS_E_DRM_BUFFER_TOO_SMALL),
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROPERTY => RawError::Kind(MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROPERTY),
            MEDIASERVER::NS_E_DRM_ERROR_BAD_NET_RESP => RawError::Kind(MEDIASERVER::NS_E_DRM_ERROR_BAD_NET_RESP),
            MEDIASERVER::NS_E_DRM_STORE_NOTALLSTORED => RawError::Kind(MEDIASERVER::NS_E_DRM_STORE_NOTALLSTORED),
            MEDIASERVER::NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID => RawError::Kind(MEDIASERVER::NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID),
            MEDIASERVER::NS_E_DRM_INVALID_DATA => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_DATA),
            MEDIASERVER::NS_E_DRM_POLICY_DISABLE_ONLINE => RawError::Kind(MEDIASERVER::NS_E_DRM_POLICY_DISABLE_ONLINE),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT),
            MEDIASERVER::NS_E_DRM_NOT_CONFIGURED => RawError::Kind(MEDIASERVER::NS_E_DRM_NOT_CONFIGURED),
            MEDIASERVER::NS_E_DRM_DEVICE_ACTIVATION_CANCELED => RawError::Kind(MEDIASERVER::NS_E_DRM_DEVICE_ACTIVATION_CANCELED),
            MEDIASERVER::NS_E_BACKUP_RESTORE_TOO_MANY_RESETS => RawError::Kind(MEDIASERVER::NS_E_BACKUP_RESTORE_TOO_MANY_RESETS),
            MEDIASERVER::NS_E_DRM_DEBUGGING_NOT_ALLOWED => RawError::Kind(MEDIASERVER::NS_E_DRM_DEBUGGING_NOT_ALLOWED),
            MEDIASERVER::NS_E_DRM_OPERATION_CANCELED => RawError::Kind(MEDIASERVER::NS_E_DRM_OPERATION_CANCELED),
            MEDIASERVER::NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED => RawError::Kind(MEDIASERVER::NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT),
            MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION => RawError::Kind(MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION),
            MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION => RawError::Kind(MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER),
            MEDIASERVER::NS_E_DRM_POLICY_METERING_DISABLED => RawError::Kind(MEDIASERVER::NS_E_DRM_POLICY_METERING_DISABLED),
            MEDIASERVER::NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED),
            MEDIASERVER::NS_E_DRM_SDK_VERSIONMISMATCH => RawError::Kind(MEDIASERVER::NS_E_DRM_SDK_VERSIONMISMATCH),
            MEDIASERVER::NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET => RawError::Kind(MEDIASERVER::NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET),
            MEDIASERVER::NS_E_LICENSE_HEADER_MISSING_URL => RawError::Kind(MEDIASERVER::NS_E_LICENSE_HEADER_MISSING_URL),
            MEDIASERVER::NS_E_DEVICE_NOT_WMDRM_DEVICE => RawError::Kind(MEDIASERVER::NS_E_DEVICE_NOT_WMDRM_DEVICE),
            MEDIASERVER::NS_E_DRM_INVALID_APPCERT => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_APPCERT),
            MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION => RawError::Kind(MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION),
            MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE => RawError::Kind(MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE),
            MEDIASERVER::NS_E_DRM_CHECKPOINT_FAILED => RawError::Kind(MEDIASERVER::NS_E_DRM_CHECKPOINT_FAILED),
            MEDIASERVER::NS_E_DRM_BB_UNABLE_TO_INITIALIZE => RawError::Kind(MEDIASERVER::NS_E_DRM_BB_UNABLE_TO_INITIALIZE),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE),
            MEDIASERVER::NS_E_DRM_DATASTORE_CORRUPT => RawError::Kind(MEDIASERVER::NS_E_DRM_DATASTORE_CORRUPT),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT),
            MEDIASERVER::NS_E_DRM_STUBLIB_REQUIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_STUBLIB_REQUIRED),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT),
            MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE),
            MEDIASERVER::NS_E_DRM_INVALID_MIGRATION_IMAGE => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_MIGRATION_IMAGE),
            MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED),
            MEDIASERVER::NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE),
            MEDIASERVER::NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID => RawError::Kind(MEDIASERVER::NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID),
            MEDIASERVER::NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE => RawError::Kind(MEDIASERVER::NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE),
            MEDIASERVER::NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH => RawError::Kind(MEDIASERVER::NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH),
            MEDIASERVER::NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS => RawError::Kind(MEDIASERVER::NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS),
            MEDIASERVER::NS_E_DRM_HARDWAREID_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_DRM_HARDWAREID_MISMATCH),
            MEDIASERVER::NS_E_INVALID_DRMV2CLT_STUBLIB => RawError::Kind(MEDIASERVER::NS_E_INVALID_DRMV2CLT_STUBLIB),
            MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA),
            MEDIASERVER::NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS),
            MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD),
            MEDIASERVER::NS_E_DRM_MIGRATION_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_NOT_SUPPORTED),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT),
            MEDIASERVER::NS_E_DRM_CHECKPOINT_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_DRM_CHECKPOINT_MISMATCH),
            MEDIASERVER::NS_E_DRM_CHECKPOINT_CORRUPT => RawError::Kind(MEDIASERVER::NS_E_DRM_CHECKPOINT_CORRUPT),
            MEDIASERVER::NS_E_REG_FLUSH_FAILURE => RawError::Kind(MEDIASERVER::NS_E_REG_FLUSH_FAILURE),
            MEDIASERVER::NS_E_HDS_KEY_MISMATCH => RawError::Kind(MEDIASERVER::NS_E_HDS_KEY_MISMATCH),
            MEDIASERVER::NS_E_DRM_MIGRATION_OPERATION_CANCELLED => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_OPERATION_CANCELLED),
            MEDIASERVER::NS_E_DRM_MIGRATION_OBJECT_IN_USE => RawError::Kind(MEDIASERVER::NS_E_DRM_MIGRATION_OBJECT_IN_USE),
            MEDIASERVER::NS_E_DRM_MALFORMED_CONTENT_HEADER => RawError::Kind(MEDIASERVER::NS_E_DRM_MALFORMED_CONTENT_HEADER),
            MEDIASERVER::NS_E_DRM_LICENSE_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_EXPIRED),
            MEDIASERVER::NS_E_DRM_LICENSE_NOTENABLED => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_NOTENABLED),
            MEDIASERVER::NS_E_DRM_LICENSE_APPSECLOW => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_APPSECLOW),
            MEDIASERVER::NS_E_DRM_STORE_NEEDINDI => RawError::Kind(MEDIASERVER::NS_E_DRM_STORE_NEEDINDI),
            MEDIASERVER::NS_E_DRM_STORE_NOTALLOWED => RawError::Kind(MEDIASERVER::NS_E_DRM_STORE_NOTALLOWED),
            MEDIASERVER::NS_E_DRM_LICENSE_APP_NOTALLOWED => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_APP_NOTALLOWED),
            MEDIASERVER::NS_E_DRM_LICENSE_CERT_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_CERT_EXPIRED),
            MEDIASERVER::NS_E_DRM_LICENSE_SECLOW => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_SECLOW),
            MEDIASERVER::NS_E_DRM_LICENSE_CONTENT_REVOKED => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_CONTENT_REVOKED),
            MEDIASERVER::NS_E_DRM_DEVICE_NOT_REGISTERED => RawError::Kind(MEDIASERVER::NS_E_DRM_DEVICE_NOT_REGISTERED),
            MEDIASERVER::NS_E_DRM_LICENSE_NOSAP => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_NOSAP),
            MEDIASERVER::NS_E_DRM_LICENSE_NOSVP => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_NOSVP),
            MEDIASERVER::NS_E_DRM_LICENSE_NOWDM => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_NOWDM),
            MEDIASERVER::NS_E_DRM_LICENSE_NOTRUSTEDCODEC => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_NOTRUSTEDCODEC),
            MEDIASERVER::NS_E_DRM_SOURCEID_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_DRM_SOURCEID_NOT_SUPPORTED),
            MEDIASERVER::NS_E_DRM_NEEDS_UPGRADE_TEMPFILE => RawError::Kind(MEDIASERVER::NS_E_DRM_NEEDS_UPGRADE_TEMPFILE),
            MEDIASERVER::NS_E_DRM_NEED_UPGRADE_PD => RawError::Kind(MEDIASERVER::NS_E_DRM_NEED_UPGRADE_PD),
            MEDIASERVER::NS_E_DRM_SIGNATURE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_DRM_SIGNATURE_FAILURE),
            MEDIASERVER::NS_E_DRM_LICENSE_SERVER_INFO_MISSING => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_SERVER_INFO_MISSING),
            MEDIASERVER::NS_E_DRM_BUSY => RawError::Kind(MEDIASERVER::NS_E_DRM_BUSY),
            MEDIASERVER::NS_E_DRM_PD_TOO_MANY_DEVICES => RawError::Kind(MEDIASERVER::NS_E_DRM_PD_TOO_MANY_DEVICES),
            MEDIASERVER::NS_E_DRM_INDIV_FRAUD => RawError::Kind(MEDIASERVER::NS_E_DRM_INDIV_FRAUD),
            MEDIASERVER::NS_E_DRM_INDIV_NO_CABS => RawError::Kind(MEDIASERVER::NS_E_DRM_INDIV_NO_CABS),
            MEDIASERVER::NS_E_DRM_INDIV_SERVICE_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_DRM_INDIV_SERVICE_UNAVAILABLE),
            MEDIASERVER::NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE),
            MEDIASERVER::NS_E_DRM_CLIENT_CODE_EXPIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_CLIENT_CODE_EXPIRED),
            MEDIASERVER::NS_E_DRM_NO_UPLINK_LICENSE => RawError::Kind(MEDIASERVER::NS_E_DRM_NO_UPLINK_LICENSE),
            MEDIASERVER::NS_E_DRM_INVALID_KID => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_KID),
            MEDIASERVER::NS_E_DRM_LICENSE_INITIALIZATION_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_INITIALIZATION_ERROR),
            MEDIASERVER::NS_E_DRM_CHAIN_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_DRM_CHAIN_TOO_LONG),
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_ALGORITHM => RawError::Kind(MEDIASERVER::NS_E_DRM_UNSUPPORTED_ALGORITHM),
            MEDIASERVER::NS_E_DRM_LICENSE_DELETION_ERROR => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_DELETION_ERROR),
            MEDIASERVER::NS_E_DRM_INVALID_CERTIFICATE => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_CERTIFICATE),
            MEDIASERVER::NS_E_DRM_CERTIFICATE_REVOKED => RawError::Kind(MEDIASERVER::NS_E_DRM_CERTIFICATE_REVOKED),
            MEDIASERVER::NS_E_DRM_LICENSE_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_DRM_LICENSE_UNAVAILABLE),
            MEDIASERVER::NS_E_DRM_DEVICE_LIMIT_REACHED => RawError::Kind(MEDIASERVER::NS_E_DRM_DEVICE_LIMIT_REACHED),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY),
            MEDIASERVER::NS_E_DRM_MUST_REGISTER => RawError::Kind(MEDIASERVER::NS_E_DRM_MUST_REGISTER),
            MEDIASERVER::NS_E_DRM_MUST_APPROVE => RawError::Kind(MEDIASERVER::NS_E_DRM_MUST_APPROVE),
            MEDIASERVER::NS_E_DRM_MUST_REVALIDATE => RawError::Kind(MEDIASERVER::NS_E_DRM_MUST_REVALIDATE),
            MEDIASERVER::NS_E_DRM_INVALID_PROXIMITY_RESPONSE => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_PROXIMITY_RESPONSE),
            MEDIASERVER::NS_E_DRM_INVALID_SESSION => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_SESSION),
            MEDIASERVER::NS_E_DRM_DEVICE_NOT_OPEN => RawError::Kind(MEDIASERVER::NS_E_DRM_DEVICE_NOT_OPEN),
            MEDIASERVER::NS_E_DRM_DEVICE_ALREADY_REGISTERED => RawError::Kind(MEDIASERVER::NS_E_DRM_DEVICE_ALREADY_REGISTERED),
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION => RawError::Kind(MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION),
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_ACTION => RawError::Kind(MEDIASERVER::NS_E_DRM_UNSUPPORTED_ACTION),
            MEDIASERVER::NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE => RawError::Kind(MEDIASERVER::NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE),
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_PORT => RawError::Kind(MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_PORT),
            MEDIASERVER::NS_E_DRM_BAD_REQUEST => RawError::Kind(MEDIASERVER::NS_E_DRM_BAD_REQUEST),
            MEDIASERVER::NS_E_DRM_INVALID_CRL => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_CRL),
            MEDIASERVER::NS_E_DRM_ATTRIBUTE_TOO_LONG => RawError::Kind(MEDIASERVER::NS_E_DRM_ATTRIBUTE_TOO_LONG),
            MEDIASERVER::NS_E_DRM_EXPIRED_LICENSEBLOB => RawError::Kind(MEDIASERVER::NS_E_DRM_EXPIRED_LICENSEBLOB),
            MEDIASERVER::NS_E_DRM_INVALID_LICENSEBLOB => RawError::Kind(MEDIASERVER::NS_E_DRM_INVALID_LICENSEBLOB),
            MEDIASERVER::NS_E_DRM_INCLUSION_LIST_REQUIRED => RawError::Kind(MEDIASERVER::NS_E_DRM_INCLUSION_LIST_REQUIRED),
            MEDIASERVER::NS_E_DRM_DRMV2CLT_REVOKED => RawError::Kind(MEDIASERVER::NS_E_DRM_DRMV2CLT_REVOKED),
            MEDIASERVER::NS_E_DRM_RIV_TOO_SMALL => RawError::Kind(MEDIASERVER::NS_E_DRM_RIV_TOO_SMALL),
            MEDIASERVER::NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED),
            MEDIASERVER::NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED),
            MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED),
            MEDIASERVER::NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED),
            MEDIASERVER::NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED),
            MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED),
            MEDIASERVER::NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED => RawError::Kind(MEDIASERVER::NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED),
            MEDIASERVER::NS_E_REBOOT_RECOMMENDED => RawError::Kind(MEDIASERVER::NS_E_REBOOT_RECOMMENDED),
            MEDIASERVER::NS_E_REBOOT_REQUIRED => RawError::Kind(MEDIASERVER::NS_E_REBOOT_REQUIRED),
            MEDIASERVER::NS_E_SETUP_INCOMPLETE => RawError::Kind(MEDIASERVER::NS_E_SETUP_INCOMPLETE),
            MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED => RawError::Kind(MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED),
            MEDIASERVER::NS_E_SETUP_IGNORABLE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_SETUP_IGNORABLE_FAILURE),
            MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE => RawError::Kind(MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE),
            MEDIASERVER::NS_E_SETUP_BLOCKED => RawError::Kind(MEDIASERVER::NS_E_SETUP_BLOCKED),
            MEDIASERVER::NS_E_UNKNOWN_PROTOCOL => RawError::Kind(MEDIASERVER::NS_E_UNKNOWN_PROTOCOL),
            MEDIASERVER::NS_E_REDIRECT_TO_PROXY => RawError::Kind(MEDIASERVER::NS_E_REDIRECT_TO_PROXY),
            MEDIASERVER::NS_E_INTERNAL_SERVER_ERROR => RawError::Kind(MEDIASERVER::NS_E_INTERNAL_SERVER_ERROR),
            MEDIASERVER::NS_E_BAD_REQUEST => RawError::Kind(MEDIASERVER::NS_E_BAD_REQUEST),
            MEDIASERVER::NS_E_ERROR_FROM_PROXY => RawError::Kind(MEDIASERVER::NS_E_ERROR_FROM_PROXY),
            MEDIASERVER::NS_E_PROXY_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_PROXY_TIMEOUT),
            MEDIASERVER::NS_E_SERVER_UNAVAILABLE => RawError::Kind(MEDIASERVER::NS_E_SERVER_UNAVAILABLE),
            MEDIASERVER::NS_E_REFUSED_BY_SERVER => RawError::Kind(MEDIASERVER::NS_E_REFUSED_BY_SERVER),
            MEDIASERVER::NS_E_INCOMPATIBLE_SERVER => RawError::Kind(MEDIASERVER::NS_E_INCOMPATIBLE_SERVER),
            MEDIASERVER::NS_E_MULTICAST_DISABLED => RawError::Kind(MEDIASERVER::NS_E_MULTICAST_DISABLED),
            MEDIASERVER::NS_E_INVALID_REDIRECT => RawError::Kind(MEDIASERVER::NS_E_INVALID_REDIRECT),
            MEDIASERVER::NS_E_ALL_PROTOCOLS_DISABLED => RawError::Kind(MEDIASERVER::NS_E_ALL_PROTOCOLS_DISABLED),
            MEDIASERVER::NS_E_MSBD_NO_LONGER_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_MSBD_NO_LONGER_SUPPORTED),
            MEDIASERVER::NS_E_PROXY_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_PROXY_NOT_FOUND),
            MEDIASERVER::NS_E_CANNOT_CONNECT_TO_PROXY => RawError::Kind(MEDIASERVER::NS_E_CANNOT_CONNECT_TO_PROXY),
            MEDIASERVER::NS_E_SERVER_DNS_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_SERVER_DNS_TIMEOUT),
            MEDIASERVER::NS_E_PROXY_DNS_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_PROXY_DNS_TIMEOUT),
            MEDIASERVER::NS_E_CLOSED_ON_SUSPEND => RawError::Kind(MEDIASERVER::NS_E_CLOSED_ON_SUSPEND),
            MEDIASERVER::NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER => RawError::Kind(MEDIASERVER::NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER),
            MEDIASERVER::NS_E_SESSION_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_SESSION_NOT_FOUND),
            MEDIASERVER::NS_E_REQUIRE_STREAMING_CLIENT => RawError::Kind(MEDIASERVER::NS_E_REQUIRE_STREAMING_CLIENT),
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_HAS_CHANGED => RawError::Kind(MEDIASERVER::NS_E_PLAYLIST_ENTRY_HAS_CHANGED),
            MEDIASERVER::NS_E_PROXY_ACCESSDENIED => RawError::Kind(MEDIASERVER::NS_E_PROXY_ACCESSDENIED),
            MEDIASERVER::NS_E_PROXY_SOURCE_ACCESSDENIED => RawError::Kind(MEDIASERVER::NS_E_PROXY_SOURCE_ACCESSDENIED),
            MEDIASERVER::NS_E_NETWORK_SINK_WRITE => RawError::Kind(MEDIASERVER::NS_E_NETWORK_SINK_WRITE),
            MEDIASERVER::NS_E_FIREWALL => RawError::Kind(MEDIASERVER::NS_E_FIREWALL),
            MEDIASERVER::NS_E_MMS_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_MMS_NOT_SUPPORTED),
            MEDIASERVER::NS_E_SERVER_ACCESSDENIED => RawError::Kind(MEDIASERVER::NS_E_SERVER_ACCESSDENIED),
            MEDIASERVER::NS_E_RESOURCE_GONE => RawError::Kind(MEDIASERVER::NS_E_RESOURCE_GONE),
            MEDIASERVER::NS_E_NO_EXISTING_PACKETIZER => RawError::Kind(MEDIASERVER::NS_E_NO_EXISTING_PACKETIZER),
            MEDIASERVER::NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE => RawError::Kind(MEDIASERVER::NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE),
            MEDIASERVER::NS_E_RESET_SOCKET_CONNECTION => RawError::Kind(MEDIASERVER::NS_E_RESET_SOCKET_CONNECTION),
            MEDIASERVER::NS_E_TOO_MANY_HOPS => RawError::Kind(MEDIASERVER::NS_E_TOO_MANY_HOPS),
            MEDIASERVER::NS_E_TOO_MUCH_DATA_FROM_SERVER => RawError::Kind(MEDIASERVER::NS_E_TOO_MUCH_DATA_FROM_SERVER),
            MEDIASERVER::NS_E_CONNECT_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_CONNECT_TIMEOUT),
            MEDIASERVER::NS_E_PROXY_CONNECT_TIMEOUT => RawError::Kind(MEDIASERVER::NS_E_PROXY_CONNECT_TIMEOUT),
            MEDIASERVER::NS_E_SESSION_INVALID => RawError::Kind(MEDIASERVER::NS_E_SESSION_INVALID),
            MEDIASERVER::NS_E_PACKETSINK_UNKNOWN_FEC_STREAM => RawError::Kind(MEDIASERVER::NS_E_PACKETSINK_UNKNOWN_FEC_STREAM),
            MEDIASERVER::NS_E_PUSH_CANNOTCONNECT => RawError::Kind(MEDIASERVER::NS_E_PUSH_CANNOTCONNECT),
            MEDIASERVER::NS_E_INCOMPATIBLE_PUSH_SERVER => RawError::Kind(MEDIASERVER::NS_E_INCOMPATIBLE_PUSH_SERVER),
            MEDIASERVER::NS_E_END_OF_PLAYLIST => RawError::Kind(MEDIASERVER::NS_E_END_OF_PLAYLIST),
            MEDIASERVER::NS_E_USE_FILE_SOURCE => RawError::Kind(MEDIASERVER::NS_E_USE_FILE_SOURCE),
            MEDIASERVER::NS_E_PROPERTY_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_PROPERTY_NOT_FOUND),
            MEDIASERVER::NS_E_PROPERTY_READ_ONLY => RawError::Kind(MEDIASERVER::NS_E_PROPERTY_READ_ONLY),
            MEDIASERVER::NS_E_TABLE_KEY_NOT_FOUND => RawError::Kind(MEDIASERVER::NS_E_TABLE_KEY_NOT_FOUND),
            MEDIASERVER::NS_E_INVALID_QUERY_OPERATOR => RawError::Kind(MEDIASERVER::NS_E_INVALID_QUERY_OPERATOR),
            MEDIASERVER::NS_E_INVALID_QUERY_PROPERTY => RawError::Kind(MEDIASERVER::NS_E_INVALID_QUERY_PROPERTY),
            MEDIASERVER::NS_E_PROPERTY_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_PROPERTY_NOT_SUPPORTED),
            MEDIASERVER::NS_E_SCHEMA_CLASSIFY_FAILURE => RawError::Kind(MEDIASERVER::NS_E_SCHEMA_CLASSIFY_FAILURE),
            MEDIASERVER::NS_E_METADATA_FORMAT_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::NS_E_METADATA_FORMAT_NOT_SUPPORTED),
            MEDIASERVER::NS_E_METADATA_NO_EDITING_CAPABILITY => RawError::Kind(MEDIASERVER::NS_E_METADATA_NO_EDITING_CAPABILITY),
            MEDIASERVER::NS_E_METADATA_CANNOT_SET_LOCALE => RawError::Kind(MEDIASERVER::NS_E_METADATA_CANNOT_SET_LOCALE),
            MEDIASERVER::NS_E_METADATA_LANGUAGE_NOT_SUPORTED => RawError::Kind(MEDIASERVER::NS_E_METADATA_LANGUAGE_NOT_SUPORTED),
            MEDIASERVER::NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE => RawError::Kind(MEDIASERVER::NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE),
            MEDIASERVER::NS_E_METADATA_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::NS_E_METADATA_NOT_AVAILABLE),
            MEDIASERVER::NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE),
            MEDIASERVER::NS_E_METADATA_INVALID_DOCUMENT_TYPE => RawError::Kind(MEDIASERVER::NS_E_METADATA_INVALID_DOCUMENT_TYPE),
            MEDIASERVER::NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE),
            MEDIASERVER::NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE => RawError::Kind(MEDIASERVER::NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE),
            MEDIASERVER::MF_E_PLATFORM_NOT_INITIALIZED => RawError::Kind(MEDIASERVER::MF_E_PLATFORM_NOT_INITIALIZED),
            MEDIASERVER::MF_E_BUFFERTOOSMALL => RawError::Kind(MEDIASERVER::MF_E_BUFFERTOOSMALL),
            MEDIASERVER::MF_E_INVALIDREQUEST => RawError::Kind(MEDIASERVER::MF_E_INVALIDREQUEST),
            MEDIASERVER::MF_E_INVALIDSTREAMNUMBER => RawError::Kind(MEDIASERVER::MF_E_INVALIDSTREAMNUMBER),
            MEDIASERVER::MF_E_INVALIDMEDIATYPE => RawError::Kind(MEDIASERVER::MF_E_INVALIDMEDIATYPE),
            MEDIASERVER::MF_E_NOTACCEPTING => RawError::Kind(MEDIASERVER::MF_E_NOTACCEPTING),
            MEDIASERVER::MF_E_NOT_INITIALIZED => RawError::Kind(MEDIASERVER::MF_E_NOT_INITIALIZED),
            MEDIASERVER::MF_E_UNSUPPORTED_REPRESENTATION => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_REPRESENTATION),
            MEDIASERVER::MF_E_NO_MORE_TYPES => RawError::Kind(MEDIASERVER::MF_E_NO_MORE_TYPES),
            MEDIASERVER::MF_E_UNSUPPORTED_SERVICE => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_SERVICE),
            MEDIASERVER::MF_E_UNEXPECTED => RawError::Kind(MEDIASERVER::MF_E_UNEXPECTED),
            MEDIASERVER::MF_E_INVALIDNAME => RawError::Kind(MEDIASERVER::MF_E_INVALIDNAME),
            MEDIASERVER::MF_E_INVALIDTYPE => RawError::Kind(MEDIASERVER::MF_E_INVALIDTYPE),
            MEDIASERVER::MF_E_INVALID_FILE_FORMAT => RawError::Kind(MEDIASERVER::MF_E_INVALID_FILE_FORMAT),
            MEDIASERVER::MF_E_INVALIDINDEX => RawError::Kind(MEDIASERVER::MF_E_INVALIDINDEX),
            MEDIASERVER::MF_E_INVALID_TIMESTAMP => RawError::Kind(MEDIASERVER::MF_E_INVALID_TIMESTAMP),
            MEDIASERVER::MF_E_UNSUPPORTED_SCHEME => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_SCHEME),
            MEDIASERVER::MF_E_UNSUPPORTED_BYTESTREAM_TYPE => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_BYTESTREAM_TYPE),
            MEDIASERVER::MF_E_UNSUPPORTED_TIME_FORMAT => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_TIME_FORMAT),
            MEDIASERVER::MF_E_NO_SAMPLE_TIMESTAMP => RawError::Kind(MEDIASERVER::MF_E_NO_SAMPLE_TIMESTAMP),
            MEDIASERVER::MF_E_NO_SAMPLE_DURATION => RawError::Kind(MEDIASERVER::MF_E_NO_SAMPLE_DURATION),
            MEDIASERVER::MF_E_INVALID_STREAM_DATA => RawError::Kind(MEDIASERVER::MF_E_INVALID_STREAM_DATA),
            MEDIASERVER::MF_E_RT_UNAVAILABLE => RawError::Kind(MEDIASERVER::MF_E_RT_UNAVAILABLE),
            MEDIASERVER::MF_E_UNSUPPORTED_RATE => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_RATE),
            MEDIASERVER::MF_E_THINNING_UNSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_THINNING_UNSUPPORTED),
            MEDIASERVER::MF_E_REVERSE_UNSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_REVERSE_UNSUPPORTED),
            MEDIASERVER::MF_E_UNSUPPORTED_RATE_TRANSITION => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_RATE_TRANSITION),
            MEDIASERVER::MF_E_RATE_CHANGE_PREEMPTED => RawError::Kind(MEDIASERVER::MF_E_RATE_CHANGE_PREEMPTED),
            MEDIASERVER::MF_E_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_NOT_FOUND),
            MEDIASERVER::MF_E_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::MF_E_NOT_AVAILABLE),
            MEDIASERVER::MF_E_NO_CLOCK => RawError::Kind(MEDIASERVER::MF_E_NO_CLOCK),
            MEDIASERVER::MF_E_MULTIPLE_BEGIN => RawError::Kind(MEDIASERVER::MF_E_MULTIPLE_BEGIN),
            MEDIASERVER::MF_E_MULTIPLE_SUBSCRIBERS => RawError::Kind(MEDIASERVER::MF_E_MULTIPLE_SUBSCRIBERS),
            MEDIASERVER::MF_E_TIMER_ORPHANED => RawError::Kind(MEDIASERVER::MF_E_TIMER_ORPHANED),
            MEDIASERVER::MF_E_STATE_TRANSITION_PENDING => RawError::Kind(MEDIASERVER::MF_E_STATE_TRANSITION_PENDING),
            MEDIASERVER::MF_E_UNSUPPORTED_STATE_TRANSITION => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_STATE_TRANSITION),
            MEDIASERVER::MF_E_UNRECOVERABLE_ERROR_OCCURRED => RawError::Kind(MEDIASERVER::MF_E_UNRECOVERABLE_ERROR_OCCURRED),
            MEDIASERVER::MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS => RawError::Kind(MEDIASERVER::MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS),
            MEDIASERVER::MF_E_SAMPLE_NOT_WRITABLE => RawError::Kind(MEDIASERVER::MF_E_SAMPLE_NOT_WRITABLE),
            MEDIASERVER::MF_E_INVALID_KEY => RawError::Kind(MEDIASERVER::MF_E_INVALID_KEY),
            MEDIASERVER::MF_E_BAD_STARTUP_VERSION => RawError::Kind(MEDIASERVER::MF_E_BAD_STARTUP_VERSION),
            MEDIASERVER::MF_E_UNSUPPORTED_CAPTION => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_CAPTION),
            MEDIASERVER::MF_E_INVALID_POSITION => RawError::Kind(MEDIASERVER::MF_E_INVALID_POSITION),
            MEDIASERVER::MF_E_ATTRIBUTENOTFOUND => RawError::Kind(MEDIASERVER::MF_E_ATTRIBUTENOTFOUND),
            MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_ALLOWED => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_ALLOWED),
            MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_SUPPORTED),
            MEDIASERVER::MF_E_PROPERTY_EMPTY => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_EMPTY),
            MEDIASERVER::MF_E_PROPERTY_NOT_EMPTY => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_NOT_EMPTY),
            MEDIASERVER::MF_E_PROPERTY_VECTOR_NOT_ALLOWED => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_VECTOR_NOT_ALLOWED),
            MEDIASERVER::MF_E_PROPERTY_VECTOR_REQUIRED => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_VECTOR_REQUIRED),
            MEDIASERVER::MF_E_OPERATION_CANCELLED => RawError::Kind(MEDIASERVER::MF_E_OPERATION_CANCELLED),
            MEDIASERVER::MF_E_BYTESTREAM_NOT_SEEKABLE => RawError::Kind(MEDIASERVER::MF_E_BYTESTREAM_NOT_SEEKABLE),
            MEDIASERVER::MF_E_DISABLED_IN_SAFEMODE => RawError::Kind(MEDIASERVER::MF_E_DISABLED_IN_SAFEMODE),
            MEDIASERVER::MF_E_CANNOT_PARSE_BYTESTREAM => RawError::Kind(MEDIASERVER::MF_E_CANNOT_PARSE_BYTESTREAM),
            MEDIASERVER::MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS => RawError::Kind(MEDIASERVER::MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS),
            MEDIASERVER::MF_E_MEDIAPROC_WRONGSTATE => RawError::Kind(MEDIASERVER::MF_E_MEDIAPROC_WRONGSTATE),
            MEDIASERVER::MF_E_RT_THROUGHPUT_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::MF_E_RT_THROUGHPUT_NOT_AVAILABLE),
            MEDIASERVER::MF_E_RT_TOO_MANY_CLASSES => RawError::Kind(MEDIASERVER::MF_E_RT_TOO_MANY_CLASSES),
            MEDIASERVER::MF_E_RT_WOULDBLOCK => RawError::Kind(MEDIASERVER::MF_E_RT_WOULDBLOCK),
            MEDIASERVER::MF_E_NO_BITPUMP => RawError::Kind(MEDIASERVER::MF_E_NO_BITPUMP),
            MEDIASERVER::MF_E_RT_OUTOFMEMORY => RawError::Kind(MEDIASERVER::MF_E_RT_OUTOFMEMORY),
            MEDIASERVER::MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED => RawError::Kind(MEDIASERVER::MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED),
            MEDIASERVER::MF_E_CANNOT_CREATE_SINK => RawError::Kind(MEDIASERVER::MF_E_CANNOT_CREATE_SINK),
            MEDIASERVER::MF_E_BYTESTREAM_UNKNOWN_LENGTH => RawError::Kind(MEDIASERVER::MF_E_BYTESTREAM_UNKNOWN_LENGTH),
            MEDIASERVER::MF_E_SESSION_PAUSEWHILESTOPPED => RawError::Kind(MEDIASERVER::MF_E_SESSION_PAUSEWHILESTOPPED),
            MEDIASERVER::MF_E_FORMAT_CHANGE_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_FORMAT_CHANGE_NOT_SUPPORTED),
            MEDIASERVER::MF_E_INVALID_WORKQUEUE => RawError::Kind(MEDIASERVER::MF_E_INVALID_WORKQUEUE),
            MEDIASERVER::MF_E_DRM_UNSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_DRM_UNSUPPORTED),
            MEDIASERVER::MF_E_UNAUTHORIZED => RawError::Kind(MEDIASERVER::MF_E_UNAUTHORIZED),
            MEDIASERVER::MF_E_OUT_OF_RANGE => RawError::Kind(MEDIASERVER::MF_E_OUT_OF_RANGE),
            MEDIASERVER::MF_E_INVALID_CODEC_MERIT => RawError::Kind(MEDIASERVER::MF_E_INVALID_CODEC_MERIT),
            MEDIASERVER::MF_E_HW_MFT_FAILED_START_STREAMING => RawError::Kind(MEDIASERVER::MF_E_HW_MFT_FAILED_START_STREAMING),
            MEDIASERVER::MF_E_ASF_PARSINGINCOMPLETE => RawError::Kind(MEDIASERVER::MF_E_ASF_PARSINGINCOMPLETE),
            MEDIASERVER::MF_E_ASF_MISSINGDATA => RawError::Kind(MEDIASERVER::MF_E_ASF_MISSINGDATA),
            MEDIASERVER::MF_E_ASF_INVALIDDATA => RawError::Kind(MEDIASERVER::MF_E_ASF_INVALIDDATA),
            MEDIASERVER::MF_E_ASF_OPAQUEPACKET => RawError::Kind(MEDIASERVER::MF_E_ASF_OPAQUEPACKET),
            MEDIASERVER::MF_E_ASF_NOINDEX => RawError::Kind(MEDIASERVER::MF_E_ASF_NOINDEX),
            MEDIASERVER::MF_E_ASF_OUTOFRANGE => RawError::Kind(MEDIASERVER::MF_E_ASF_OUTOFRANGE),
            MEDIASERVER::MF_E_ASF_INDEXNOTLOADED => RawError::Kind(MEDIASERVER::MF_E_ASF_INDEXNOTLOADED),
            MEDIASERVER::MF_E_ASF_TOO_MANY_PAYLOADS => RawError::Kind(MEDIASERVER::MF_E_ASF_TOO_MANY_PAYLOADS),
            MEDIASERVER::MF_E_ASF_UNSUPPORTED_STREAM_TYPE => RawError::Kind(MEDIASERVER::MF_E_ASF_UNSUPPORTED_STREAM_TYPE),
            MEDIASERVER::MF_E_ASF_DROPPED_PACKET => RawError::Kind(MEDIASERVER::MF_E_ASF_DROPPED_PACKET),
            MEDIASERVER::MF_E_NO_EVENTS_AVAILABLE => RawError::Kind(MEDIASERVER::MF_E_NO_EVENTS_AVAILABLE),
            MEDIASERVER::MF_E_INVALID_STATE_TRANSITION => RawError::Kind(MEDIASERVER::MF_E_INVALID_STATE_TRANSITION),
            MEDIASERVER::MF_E_END_OF_STREAM => RawError::Kind(MEDIASERVER::MF_E_END_OF_STREAM),
            MEDIASERVER::MF_E_SHUTDOWN => RawError::Kind(MEDIASERVER::MF_E_SHUTDOWN),
            MEDIASERVER::MF_E_MP3_NOTFOUND => RawError::Kind(MEDIASERVER::MF_E_MP3_NOTFOUND),
            MEDIASERVER::MF_E_MP3_OUTOFDATA => RawError::Kind(MEDIASERVER::MF_E_MP3_OUTOFDATA),
            MEDIASERVER::MF_E_MP3_NOTMP3 => RawError::Kind(MEDIASERVER::MF_E_MP3_NOTMP3),
            MEDIASERVER::MF_E_MP3_NOTSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_MP3_NOTSUPPORTED),
            MEDIASERVER::MF_E_NO_DURATION => RawError::Kind(MEDIASERVER::MF_E_NO_DURATION),
            MEDIASERVER::MF_E_INVALID_FORMAT => RawError::Kind(MEDIASERVER::MF_E_INVALID_FORMAT),
            MEDIASERVER::MF_E_PROPERTY_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_NOT_FOUND),
            MEDIASERVER::MF_E_PROPERTY_READ_ONLY => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_READ_ONLY),
            MEDIASERVER::MF_E_PROPERTY_NOT_ALLOWED => RawError::Kind(MEDIASERVER::MF_E_PROPERTY_NOT_ALLOWED),
            MEDIASERVER::MF_E_MEDIA_SOURCE_NOT_STARTED => RawError::Kind(MEDIASERVER::MF_E_MEDIA_SOURCE_NOT_STARTED),
            MEDIASERVER::MF_E_UNSUPPORTED_FORMAT => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_FORMAT),
            MEDIASERVER::MF_E_MP3_BAD_CRC => RawError::Kind(MEDIASERVER::MF_E_MP3_BAD_CRC),
            MEDIASERVER::MF_E_NOT_PROTECTED => RawError::Kind(MEDIASERVER::MF_E_NOT_PROTECTED),
            MEDIASERVER::MF_E_MEDIA_SOURCE_WRONGSTATE => RawError::Kind(MEDIASERVER::MF_E_MEDIA_SOURCE_WRONGSTATE),
            MEDIASERVER::MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED => RawError::Kind(MEDIASERVER::MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED),
            MEDIASERVER::MF_E_CANNOT_FIND_KEYFRAME_SAMPLE => RawError::Kind(MEDIASERVER::MF_E_CANNOT_FIND_KEYFRAME_SAMPLE),
            MEDIASERVER::MF_E_NETWORK_RESOURCE_FAILURE => RawError::Kind(MEDIASERVER::MF_E_NETWORK_RESOURCE_FAILURE),
            MEDIASERVER::MF_E_NET_WRITE => RawError::Kind(MEDIASERVER::MF_E_NET_WRITE),
            MEDIASERVER::MF_E_NET_READ => RawError::Kind(MEDIASERVER::MF_E_NET_READ),
            MEDIASERVER::MF_E_NET_REQUIRE_NETWORK => RawError::Kind(MEDIASERVER::MF_E_NET_REQUIRE_NETWORK),
            MEDIASERVER::MF_E_NET_REQUIRE_ASYNC => RawError::Kind(MEDIASERVER::MF_E_NET_REQUIRE_ASYNC),
            MEDIASERVER::MF_E_NET_BWLEVEL_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_NET_BWLEVEL_NOT_SUPPORTED),
            MEDIASERVER::MF_E_NET_STREAMGROUPS_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_NET_STREAMGROUPS_NOT_SUPPORTED),
            MEDIASERVER::MF_E_NET_MANUALSS_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_NET_MANUALSS_NOT_SUPPORTED),
            MEDIASERVER::MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR => RawError::Kind(MEDIASERVER::MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR),
            MEDIASERVER::MF_E_NET_CACHESTREAM_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_NET_CACHESTREAM_NOT_FOUND),
            MEDIASERVER::MF_E_NET_REQUIRE_INPUT => RawError::Kind(MEDIASERVER::MF_E_NET_REQUIRE_INPUT),
            MEDIASERVER::MF_E_NET_REDIRECT => RawError::Kind(MEDIASERVER::MF_E_NET_REDIRECT),
            MEDIASERVER::MF_E_NET_REDIRECT_TO_PROXY => RawError::Kind(MEDIASERVER::MF_E_NET_REDIRECT_TO_PROXY),
            MEDIASERVER::MF_E_NET_TOO_MANY_REDIRECTS => RawError::Kind(MEDIASERVER::MF_E_NET_TOO_MANY_REDIRECTS),
            MEDIASERVER::MF_E_NET_TIMEOUT => RawError::Kind(MEDIASERVER::MF_E_NET_TIMEOUT),
            MEDIASERVER::MF_E_NET_CLIENT_CLOSE => RawError::Kind(MEDIASERVER::MF_E_NET_CLIENT_CLOSE),
            MEDIASERVER::MF_E_NET_BAD_CONTROL_DATA => RawError::Kind(MEDIASERVER::MF_E_NET_BAD_CONTROL_DATA),
            MEDIASERVER::MF_E_NET_INCOMPATIBLE_SERVER => RawError::Kind(MEDIASERVER::MF_E_NET_INCOMPATIBLE_SERVER),
            MEDIASERVER::MF_E_NET_UNSAFE_URL => RawError::Kind(MEDIASERVER::MF_E_NET_UNSAFE_URL),
            MEDIASERVER::MF_E_NET_CACHE_NO_DATA => RawError::Kind(MEDIASERVER::MF_E_NET_CACHE_NO_DATA),
            MEDIASERVER::MF_E_NET_EOL => RawError::Kind(MEDIASERVER::MF_E_NET_EOL),
            MEDIASERVER::MF_E_NET_BAD_REQUEST => RawError::Kind(MEDIASERVER::MF_E_NET_BAD_REQUEST),
            MEDIASERVER::MF_E_NET_INTERNAL_SERVER_ERROR => RawError::Kind(MEDIASERVER::MF_E_NET_INTERNAL_SERVER_ERROR),
            MEDIASERVER::MF_E_NET_SESSION_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_NET_SESSION_NOT_FOUND),
            MEDIASERVER::MF_E_NET_NOCONNECTION => RawError::Kind(MEDIASERVER::MF_E_NET_NOCONNECTION),
            MEDIASERVER::MF_E_NET_CONNECTION_FAILURE => RawError::Kind(MEDIASERVER::MF_E_NET_CONNECTION_FAILURE),
            MEDIASERVER::MF_E_NET_INCOMPATIBLE_PUSHSERVER => RawError::Kind(MEDIASERVER::MF_E_NET_INCOMPATIBLE_PUSHSERVER),
            MEDIASERVER::MF_E_NET_SERVER_ACCESSDENIED => RawError::Kind(MEDIASERVER::MF_E_NET_SERVER_ACCESSDENIED),
            MEDIASERVER::MF_E_NET_PROXY_ACCESSDENIED => RawError::Kind(MEDIASERVER::MF_E_NET_PROXY_ACCESSDENIED),
            MEDIASERVER::MF_E_NET_CANNOTCONNECT => RawError::Kind(MEDIASERVER::MF_E_NET_CANNOTCONNECT),
            MEDIASERVER::MF_E_NET_INVALID_PUSH_TEMPLATE => RawError::Kind(MEDIASERVER::MF_E_NET_INVALID_PUSH_TEMPLATE),
            MEDIASERVER::MF_E_NET_INVALID_PUSH_PUBLISHING_POINT => RawError::Kind(MEDIASERVER::MF_E_NET_INVALID_PUSH_PUBLISHING_POINT),
            MEDIASERVER::MF_E_NET_BUSY => RawError::Kind(MEDIASERVER::MF_E_NET_BUSY),
            MEDIASERVER::MF_E_NET_RESOURCE_GONE => RawError::Kind(MEDIASERVER::MF_E_NET_RESOURCE_GONE),
            MEDIASERVER::MF_E_NET_ERROR_FROM_PROXY => RawError::Kind(MEDIASERVER::MF_E_NET_ERROR_FROM_PROXY),
            MEDIASERVER::MF_E_NET_PROXY_TIMEOUT => RawError::Kind(MEDIASERVER::MF_E_NET_PROXY_TIMEOUT),
            MEDIASERVER::MF_E_NET_SERVER_UNAVAILABLE => RawError::Kind(MEDIASERVER::MF_E_NET_SERVER_UNAVAILABLE),
            MEDIASERVER::MF_E_NET_TOO_MUCH_DATA => RawError::Kind(MEDIASERVER::MF_E_NET_TOO_MUCH_DATA),
            MEDIASERVER::MF_E_NET_SESSION_INVALID => RawError::Kind(MEDIASERVER::MF_E_NET_SESSION_INVALID),
            MEDIASERVER::MF_E_OFFLINE_MODE => RawError::Kind(MEDIASERVER::MF_E_OFFLINE_MODE),
            MEDIASERVER::MF_E_NET_UDP_BLOCKED => RawError::Kind(MEDIASERVER::MF_E_NET_UDP_BLOCKED),
            MEDIASERVER::MF_E_NET_UNSUPPORTED_CONFIGURATION => RawError::Kind(MEDIASERVER::MF_E_NET_UNSUPPORTED_CONFIGURATION),
            MEDIASERVER::MF_E_NET_PROTOCOL_DISABLED => RawError::Kind(MEDIASERVER::MF_E_NET_PROTOCOL_DISABLED),
            MEDIASERVER::MF_E_ALREADY_INITIALIZED => RawError::Kind(MEDIASERVER::MF_E_ALREADY_INITIALIZED),
            MEDIASERVER::MF_E_BANDWIDTH_OVERRUN => RawError::Kind(MEDIASERVER::MF_E_BANDWIDTH_OVERRUN),
            MEDIASERVER::MF_E_LATE_SAMPLE => RawError::Kind(MEDIASERVER::MF_E_LATE_SAMPLE),
            MEDIASERVER::MF_E_FLUSH_NEEDED => RawError::Kind(MEDIASERVER::MF_E_FLUSH_NEEDED),
            MEDIASERVER::MF_E_INVALID_PROFILE => RawError::Kind(MEDIASERVER::MF_E_INVALID_PROFILE),
            MEDIASERVER::MF_E_INDEX_NOT_COMMITTED => RawError::Kind(MEDIASERVER::MF_E_INDEX_NOT_COMMITTED),
            MEDIASERVER::MF_E_NO_INDEX => RawError::Kind(MEDIASERVER::MF_E_NO_INDEX),
            MEDIASERVER::MF_E_CANNOT_INDEX_IN_PLACE => RawError::Kind(MEDIASERVER::MF_E_CANNOT_INDEX_IN_PLACE),
            MEDIASERVER::MF_E_MISSING_ASF_LEAKYBUCKET => RawError::Kind(MEDIASERVER::MF_E_MISSING_ASF_LEAKYBUCKET),
            MEDIASERVER::MF_E_INVALID_ASF_STREAMID => RawError::Kind(MEDIASERVER::MF_E_INVALID_ASF_STREAMID),
            MEDIASERVER::MF_E_STREAMSINK_REMOVED => RawError::Kind(MEDIASERVER::MF_E_STREAMSINK_REMOVED),
            MEDIASERVER::MF_E_STREAMSINKS_OUT_OF_SYNC => RawError::Kind(MEDIASERVER::MF_E_STREAMSINKS_OUT_OF_SYNC),
            MEDIASERVER::MF_E_STREAMSINKS_FIXED => RawError::Kind(MEDIASERVER::MF_E_STREAMSINKS_FIXED),
            MEDIASERVER::MF_E_STREAMSINK_EXISTS => RawError::Kind(MEDIASERVER::MF_E_STREAMSINK_EXISTS),
            MEDIASERVER::MF_E_SAMPLEALLOCATOR_CANCELED => RawError::Kind(MEDIASERVER::MF_E_SAMPLEALLOCATOR_CANCELED),
            MEDIASERVER::MF_E_SAMPLEALLOCATOR_EMPTY => RawError::Kind(MEDIASERVER::MF_E_SAMPLEALLOCATOR_EMPTY),
            MEDIASERVER::MF_E_SINK_ALREADYSTOPPED => RawError::Kind(MEDIASERVER::MF_E_SINK_ALREADYSTOPPED),
            MEDIASERVER::MF_E_ASF_FILESINK_BITRATE_UNKNOWN => RawError::Kind(MEDIASERVER::MF_E_ASF_FILESINK_BITRATE_UNKNOWN),
            MEDIASERVER::MF_E_SINK_NO_STREAMS => RawError::Kind(MEDIASERVER::MF_E_SINK_NO_STREAMS),
            MEDIASERVER::MF_E_METADATA_TOO_LONG => RawError::Kind(MEDIASERVER::MF_E_METADATA_TOO_LONG),
            MEDIASERVER::MF_E_SINK_NO_SAMPLES_PROCESSED => RawError::Kind(MEDIASERVER::MF_E_SINK_NO_SAMPLES_PROCESSED),
            MEDIASERVER::MF_E_VIDEO_REN_NO_PROCAMP_HW => RawError::Kind(MEDIASERVER::MF_E_VIDEO_REN_NO_PROCAMP_HW),
            MEDIASERVER::MF_E_VIDEO_REN_NO_DEINTERLACE_HW => RawError::Kind(MEDIASERVER::MF_E_VIDEO_REN_NO_DEINTERLACE_HW),
            MEDIASERVER::MF_E_VIDEO_REN_COPYPROT_FAILED => RawError::Kind(MEDIASERVER::MF_E_VIDEO_REN_COPYPROT_FAILED),
            MEDIASERVER::MF_E_VIDEO_REN_SURFACE_NOT_SHARED => RawError::Kind(MEDIASERVER::MF_E_VIDEO_REN_SURFACE_NOT_SHARED),
            MEDIASERVER::MF_E_VIDEO_DEVICE_LOCKED => RawError::Kind(MEDIASERVER::MF_E_VIDEO_DEVICE_LOCKED),
            MEDIASERVER::MF_E_NEW_VIDEO_DEVICE => RawError::Kind(MEDIASERVER::MF_E_NEW_VIDEO_DEVICE),
            MEDIASERVER::MF_E_NO_VIDEO_SAMPLE_AVAILABLE => RawError::Kind(MEDIASERVER::MF_E_NO_VIDEO_SAMPLE_AVAILABLE),
            MEDIASERVER::MF_E_NO_AUDIO_PLAYBACK_DEVICE => RawError::Kind(MEDIASERVER::MF_E_NO_AUDIO_PLAYBACK_DEVICE),
            MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE => RawError::Kind(MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE),
            MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED => RawError::Kind(MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED),
            MEDIASERVER::MF_E_AUDIO_SERVICE_NOT_RUNNING => RawError::Kind(MEDIASERVER::MF_E_AUDIO_SERVICE_NOT_RUNNING),
            MEDIASERVER::MF_E_TOPO_INVALID_OPTIONAL_NODE => RawError::Kind(MEDIASERVER::MF_E_TOPO_INVALID_OPTIONAL_NODE),
            MEDIASERVER::MF_E_TOPO_CANNOT_FIND_DECRYPTOR => RawError::Kind(MEDIASERVER::MF_E_TOPO_CANNOT_FIND_DECRYPTOR),
            MEDIASERVER::MF_E_TOPO_CODEC_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_TOPO_CODEC_NOT_FOUND),
            MEDIASERVER::MF_E_TOPO_CANNOT_CONNECT => RawError::Kind(MEDIASERVER::MF_E_TOPO_CANNOT_CONNECT),
            MEDIASERVER::MF_E_TOPO_UNSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_TOPO_UNSUPPORTED),
            MEDIASERVER::MF_E_TOPO_INVALID_TIME_ATTRIBUTES => RawError::Kind(MEDIASERVER::MF_E_TOPO_INVALID_TIME_ATTRIBUTES),
            MEDIASERVER::MF_E_TOPO_LOOPS_IN_TOPOLOGY => RawError::Kind(MEDIASERVER::MF_E_TOPO_LOOPS_IN_TOPOLOGY),
            MEDIASERVER::MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR => RawError::Kind(MEDIASERVER::MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR),
            MEDIASERVER::MF_E_TOPO_MISSING_STREAM_DESCRIPTOR => RawError::Kind(MEDIASERVER::MF_E_TOPO_MISSING_STREAM_DESCRIPTOR),
            MEDIASERVER::MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED => RawError::Kind(MEDIASERVER::MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED),
            MEDIASERVER::MF_E_TOPO_MISSING_SOURCE => RawError::Kind(MEDIASERVER::MF_E_TOPO_MISSING_SOURCE),
            MEDIASERVER::MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED),
            MEDIASERVER::MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID => RawError::Kind(MEDIASERVER::MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID),
            MEDIASERVER::MF_E_NO_SOURCE_IN_CACHE => RawError::Kind(MEDIASERVER::MF_E_NO_SOURCE_IN_CACHE),
            MEDIASERVER::MF_E_TRANSFORM_TYPE_NOT_SET => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_TYPE_NOT_SET),
            MEDIASERVER::MF_E_TRANSFORM_STREAM_CHANGE => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_STREAM_CHANGE),
            MEDIASERVER::MF_E_TRANSFORM_INPUT_REMAINING => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_INPUT_REMAINING),
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_MISSING => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROFILE_MISSING),
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT),
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_TRUNCATED => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROFILE_TRUNCATED),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE),
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE),
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE),
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE),
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION),
            MEDIASERVER::MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES),
            MEDIASERVER::MF_E_TRANSFORM_NEED_MORE_INPUT => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_NEED_MORE_INPUT),
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG),
            MEDIASERVER::MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING),
            MEDIASERVER::MF_E_UNSUPPORTED_D3D_TYPE => RawError::Kind(MEDIASERVER::MF_E_UNSUPPORTED_D3D_TYPE),
            MEDIASERVER::MF_E_TRANSFORM_ASYNC_LOCKED => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_ASYNC_LOCKED),
            MEDIASERVER::MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER => RawError::Kind(MEDIASERVER::MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER),
            MEDIASERVER::MF_E_LICENSE_INCORRECT_RIGHTS => RawError::Kind(MEDIASERVER::MF_E_LICENSE_INCORRECT_RIGHTS),
            MEDIASERVER::MF_E_LICENSE_OUTOFDATE => RawError::Kind(MEDIASERVER::MF_E_LICENSE_OUTOFDATE),
            MEDIASERVER::MF_E_LICENSE_REQUIRED => RawError::Kind(MEDIASERVER::MF_E_LICENSE_REQUIRED),
            MEDIASERVER::MF_E_DRM_HARDWARE_INCONSISTENT => RawError::Kind(MEDIASERVER::MF_E_DRM_HARDWARE_INCONSISTENT),
            MEDIASERVER::MF_E_NO_CONTENT_PROTECTION_MANAGER => RawError::Kind(MEDIASERVER::MF_E_NO_CONTENT_PROTECTION_MANAGER),
            MEDIASERVER::MF_E_LICENSE_RESTORE_NO_RIGHTS => RawError::Kind(MEDIASERVER::MF_E_LICENSE_RESTORE_NO_RIGHTS),
            MEDIASERVER::MF_E_BACKUP_RESTRICTED_LICENSE => RawError::Kind(MEDIASERVER::MF_E_BACKUP_RESTRICTED_LICENSE),
            MEDIASERVER::MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION => RawError::Kind(MEDIASERVER::MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION),
            MEDIASERVER::MF_E_COMPONENT_REVOKED => RawError::Kind(MEDIASERVER::MF_E_COMPONENT_REVOKED),
            MEDIASERVER::MF_E_TRUST_DISABLED => RawError::Kind(MEDIASERVER::MF_E_TRUST_DISABLED),
            MEDIASERVER::MF_E_WMDRMOTA_NO_ACTION => RawError::Kind(MEDIASERVER::MF_E_WMDRMOTA_NO_ACTION),
            MEDIASERVER::MF_E_WMDRMOTA_ACTION_ALREADY_SET => RawError::Kind(MEDIASERVER::MF_E_WMDRMOTA_ACTION_ALREADY_SET),
            MEDIASERVER::MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE => RawError::Kind(MEDIASERVER::MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE),
            MEDIASERVER::MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED),
            MEDIASERVER::MF_E_WMDRMOTA_ACTION_MISMATCH => RawError::Kind(MEDIASERVER::MF_E_WMDRMOTA_ACTION_MISMATCH),
            MEDIASERVER::MF_E_WMDRMOTA_INVALID_POLICY => RawError::Kind(MEDIASERVER::MF_E_WMDRMOTA_INVALID_POLICY),
            MEDIASERVER::MF_E_POLICY_UNSUPPORTED => RawError::Kind(MEDIASERVER::MF_E_POLICY_UNSUPPORTED),
            MEDIASERVER::MF_E_OPL_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_OPL_NOT_SUPPORTED),
            MEDIASERVER::MF_E_TOPOLOGY_VERIFICATION_FAILED => RawError::Kind(MEDIASERVER::MF_E_TOPOLOGY_VERIFICATION_FAILED),
            MEDIASERVER::MF_E_SIGNATURE_VERIFICATION_FAILED => RawError::Kind(MEDIASERVER::MF_E_SIGNATURE_VERIFICATION_FAILED),
            MEDIASERVER::MF_E_DEBUGGING_NOT_ALLOWED => RawError::Kind(MEDIASERVER::MF_E_DEBUGGING_NOT_ALLOWED),
            MEDIASERVER::MF_E_CODE_EXPIRED => RawError::Kind(MEDIASERVER::MF_E_CODE_EXPIRED),
            MEDIASERVER::MF_E_GRL_VERSION_TOO_LOW => RawError::Kind(MEDIASERVER::MF_E_GRL_VERSION_TOO_LOW),
            MEDIASERVER::MF_E_GRL_RENEWAL_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_GRL_RENEWAL_NOT_FOUND),
            MEDIASERVER::MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND => RawError::Kind(MEDIASERVER::MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND),
            MEDIASERVER::MF_E_KERNEL_UNTRUSTED => RawError::Kind(MEDIASERVER::MF_E_KERNEL_UNTRUSTED),
            MEDIASERVER::MF_E_PEAUTH_UNTRUSTED => RawError::Kind(MEDIASERVER::MF_E_PEAUTH_UNTRUSTED),
            MEDIASERVER::MF_E_NON_PE_PROCESS => RawError::Kind(MEDIASERVER::MF_E_NON_PE_PROCESS),
            MEDIASERVER::MF_E_REBOOT_REQUIRED => RawError::Kind(MEDIASERVER::MF_E_REBOOT_REQUIRED),
            MEDIASERVER::MF_E_GRL_INVALID_FORMAT => RawError::Kind(MEDIASERVER::MF_E_GRL_INVALID_FORMAT),
            MEDIASERVER::MF_E_GRL_UNRECOGNIZED_FORMAT => RawError::Kind(MEDIASERVER::MF_E_GRL_UNRECOGNIZED_FORMAT),
            MEDIASERVER::MF_E_ALL_PROCESS_RESTART_REQUIRED => RawError::Kind(MEDIASERVER::MF_E_ALL_PROCESS_RESTART_REQUIRED),
            MEDIASERVER::MF_E_PROCESS_RESTART_REQUIRED => RawError::Kind(MEDIASERVER::MF_E_PROCESS_RESTART_REQUIRED),
            MEDIASERVER::MF_E_USERMODE_UNTRUSTED => RawError::Kind(MEDIASERVER::MF_E_USERMODE_UNTRUSTED),
            MEDIASERVER::MF_E_PEAUTH_SESSION_NOT_STARTED => RawError::Kind(MEDIASERVER::MF_E_PEAUTH_SESSION_NOT_STARTED),
            MEDIASERVER::MF_E_INSUFFICIENT_BUFFER => RawError::Kind(MEDIASERVER::MF_E_INSUFFICIENT_BUFFER),
            MEDIASERVER::MF_E_PEAUTH_PUBLICKEY_REVOKED => RawError::Kind(MEDIASERVER::MF_E_PEAUTH_PUBLICKEY_REVOKED),
            MEDIASERVER::MF_E_GRL_ABSENT => RawError::Kind(MEDIASERVER::MF_E_GRL_ABSENT),
            MEDIASERVER::MF_E_PE_UNTRUSTED => RawError::Kind(MEDIASERVER::MF_E_PE_UNTRUSTED),
            MEDIASERVER::MF_E_PEAUTH_NOT_STARTED => RawError::Kind(MEDIASERVER::MF_E_PEAUTH_NOT_STARTED),
            MEDIASERVER::MF_E_INCOMPATIBLE_SAMPLE_PROTECTION => RawError::Kind(MEDIASERVER::MF_E_INCOMPATIBLE_SAMPLE_PROTECTION),
            MEDIASERVER::MF_E_PE_SESSIONS_MAXED => RawError::Kind(MEDIASERVER::MF_E_PE_SESSIONS_MAXED),
            MEDIASERVER::MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED => RawError::Kind(MEDIASERVER::MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED),
            MEDIASERVER::MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED => RawError::Kind(MEDIASERVER::MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED),
            MEDIASERVER::MF_E_ITA_UNSUPPORTED_ACTION => RawError::Kind(MEDIASERVER::MF_E_ITA_UNSUPPORTED_ACTION),
            MEDIASERVER::MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS => RawError::Kind(MEDIASERVER::MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS),
            MEDIASERVER::MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS => RawError::Kind(MEDIASERVER::MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS),
            MEDIASERVER::MF_E_BAD_OPL_STRUCTURE_FORMAT => RawError::Kind(MEDIASERVER::MF_E_BAD_OPL_STRUCTURE_FORMAT),
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID => RawError::Kind(MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID),
            MEDIASERVER::MF_E_NO_PMP_HOST => RawError::Kind(MEDIASERVER::MF_E_NO_PMP_HOST),
            MEDIASERVER::MF_E_ITA_OPL_DATA_NOT_INITIALIZED => RawError::Kind(MEDIASERVER::MF_E_ITA_OPL_DATA_NOT_INITIALIZED),
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT => RawError::Kind(MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT),
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT => RawError::Kind(MEDIASERVER::MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT),
            MEDIASERVER::MF_E_CLOCK_INVALID_CONTINUITY_KEY => RawError::Kind(MEDIASERVER::MF_E_CLOCK_INVALID_CONTINUITY_KEY),
            MEDIASERVER::MF_E_CLOCK_NO_TIME_SOURCE => RawError::Kind(MEDIASERVER::MF_E_CLOCK_NO_TIME_SOURCE),
            MEDIASERVER::MF_E_CLOCK_STATE_ALREADY_SET => RawError::Kind(MEDIASERVER::MF_E_CLOCK_STATE_ALREADY_SET),
            MEDIASERVER::MF_E_CLOCK_NOT_SIMPLE => RawError::Kind(MEDIASERVER::MF_E_CLOCK_NOT_SIMPLE),
            MEDIASERVER::MF_E_NO_MORE_DROP_MODES => RawError::Kind(MEDIASERVER::MF_E_NO_MORE_DROP_MODES),
            MEDIASERVER::MF_E_NO_MORE_QUALITY_LEVELS => RawError::Kind(MEDIASERVER::MF_E_NO_MORE_QUALITY_LEVELS),
            MEDIASERVER::MF_E_DROPTIME_NOT_SUPPORTED => RawError::Kind(MEDIASERVER::MF_E_DROPTIME_NOT_SUPPORTED),
            MEDIASERVER::MF_E_QUALITYKNOB_WAIT_LONGER => RawError::Kind(MEDIASERVER::MF_E_QUALITYKNOB_WAIT_LONGER),
            MEDIASERVER::MF_E_QM_INVALIDSTATE => RawError::Kind(MEDIASERVER::MF_E_QM_INVALIDSTATE),
            MEDIASERVER::MF_E_TRANSCODE_NO_CONTAINERTYPE => RawError::Kind(MEDIASERVER::MF_E_TRANSCODE_NO_CONTAINERTYPE),
            MEDIASERVER::MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS => RawError::Kind(MEDIASERVER::MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS),
            MEDIASERVER::MF_E_TRANSCODE_NO_MATCHING_ENCODER => RawError::Kind(MEDIASERVER::MF_E_TRANSCODE_NO_MATCHING_ENCODER),
            MEDIASERVER::MF_E_ALLOCATOR_NOT_INITIALIZED => RawError::Kind(MEDIASERVER::MF_E_ALLOCATOR_NOT_INITIALIZED),
            MEDIASERVER::MF_E_ALLOCATOR_NOT_COMMITED => RawError::Kind(MEDIASERVER::MF_E_ALLOCATOR_NOT_COMMITED),
            MEDIASERVER::MF_E_ALLOCATOR_ALREADY_COMMITED => RawError::Kind(MEDIASERVER::MF_E_ALLOCATOR_ALREADY_COMMITED),
            MEDIASERVER::MF_E_STREAM_ERROR => RawError::Kind(MEDIASERVER::MF_E_STREAM_ERROR),
            MEDIASERVER::MF_E_INVALID_STREAM_STATE => RawError::Kind(MEDIASERVER::MF_E_INVALID_STREAM_STATE),
            MEDIASERVER::MF_E_HW_STREAM_NOT_CONNECTED => RawError::Kind(MEDIASERVER::MF_E_HW_STREAM_NOT_CONNECTED),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            MEDIASERVER::NS_S_CALLPENDING => "The requested operation is pending completion.",
            MEDIASERVER::NS_S_CALLABORTED => "The requested operation was aborted by the client.",
            MEDIASERVER::NS_S_STREAM_TRUNCATED => "The stream was purposefully stopped before completion.",
            MEDIASERVER::NS_S_REBUFFERING => "The requested operation has caused the source to rebuffer.",
            MEDIASERVER::NS_S_DEGRADING_QUALITY => "The requested operation has caused the source to degrade codec quality.",
            MEDIASERVER::NS_S_TRANSCRYPTOR_EOF => "The transcryptor object has reached end of file.",
            MEDIASERVER::NS_S_WMP_UI_VERSIONMISMATCH => "An upgrade is needed for the theme manager to correctly show this skin. Skin reports version: %.1f.",
            MEDIASERVER::NS_S_WMP_EXCEPTION => "An error occurred in one of the UI components.",
            MEDIASERVER::NS_S_WMP_LOADED_GIF_IMAGE => "Successfully loaded a GIF file.",
            MEDIASERVER::NS_S_WMP_LOADED_PNG_IMAGE => "Successfully loaded a PNG file.",
            MEDIASERVER::NS_S_WMP_LOADED_BMP_IMAGE => "Successfully loaded a BMP file.",
            MEDIASERVER::NS_S_WMP_LOADED_JPG_IMAGE => "Successfully loaded a JPG file.",
            MEDIASERVER::NS_S_WMG_FORCE_DROP_FRAME => "Drop this frame.",
            MEDIASERVER::NS_S_WMR_ALREADYRENDERED => "The specified stream has already been rendered.",
            MEDIASERVER::NS_S_WMR_PINTYPEPARTIALMATCH => "The specified type partially matches this pin type.",
            MEDIASERVER::NS_S_WMR_PINTYPEFULLMATCH => "The specified type fully matches this pin type.",
            MEDIASERVER::NS_S_WMG_ADVISE_DROP_FRAME => "The timestamp is late compared to the current render position. Advise dropping this frame.",
            MEDIASERVER::NS_S_WMG_ADVISE_DROP_TO_KEYFRAME => "The timestamp is severely late compared to the current render position. Advise dropping everything up to the next key frame.",
            MEDIASERVER::NS_S_NEED_TO_BUY_BURN_RIGHTS => "No burn rights. You will be prompted to buy burn rights when you try to burn this file to an audio CD.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLISTCLEARABORT => "Failed to clear playlist because it was aborted by user.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT => "Failed to remove item in the playlist since it was aborted by user.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_CREATION_PENDING => "Playlist is being generated asynchronously.",
            MEDIASERVER::NS_S_WMPCORE_MEDIA_VALIDATION_PENDING => "Validation of the media is pending.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED => "Encountered more than one Repeat block during ASX processing.",
            MEDIASERVER::NS_S_WMPCORE_COMMAND_NOT_AVAILABLE => "Current state of WMP disallows calling this method or property.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED => "Name for the playlist has been auto generated.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS => "The imported playlist does not contain all items from the original.",
            MEDIASERVER::NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA => "The M3U playlist has been ignored because it only contains one item.",
            MEDIASERVER::NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING => "The open for the child playlist associated with this media is pending.",
            MEDIASERVER::NS_S_WMPCORE_MORE_NODES_AVAIABLE => "More nodes support the interface requested, but the array for returning them is full.",
            MEDIASERVER::NS_S_WMPBR_SUCCESS => "Backup or Restore successful!.",
            MEDIASERVER::NS_S_WMPBR_PARTIALSUCCESS => "Transfer complete with limitations.",
            MEDIASERVER::NS_S_WMPEFFECT_TRANSPARENT => "Request to the effects control to change transparency status to transparent.",
            MEDIASERVER::NS_S_WMPEFFECT_OPAQUE => "Request to the effects control to change transparency status to opaque.",
            MEDIASERVER::NS_S_OPERATION_PENDING => "The requested application pane is performing an operation and will not be released.",
            MEDIASERVER::NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE => "The file is only available for purchase when you buy the entire album.",
            MEDIASERVER::NS_S_NAVIGATION_COMPLETE_WITH_ERRORS => "There were problems completing the requested navigation. There are identifiers missing in the catalog.",
            MEDIASERVER::NS_S_TRACK_ALREADY_DOWNLOADED => "Track already downloaded.",
            MEDIASERVER::NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS => "The publishing point successfully started, but one or more of the requested data writer plug-ins failed.",
            MEDIASERVER::NS_S_DRM_LICENSE_ACQUIRED => "Status message: The license was acquired.",
            MEDIASERVER::NS_S_DRM_INDIVIDUALIZED => "Status message: The security upgrade has been completed.",
            MEDIASERVER::NS_S_DRM_MONITOR_CANCELLED => "Status message: License monitoring has been canceled.",
            MEDIASERVER::NS_S_DRM_ACQUIRE_CANCELLED => "Status message: License acquisition has been canceled.",
            MEDIASERVER::NS_S_DRM_BURNABLE_TRACK => "The track is burnable and had no playlist burn limit.",
            MEDIASERVER::NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION => "The track is burnable but has a playlist burn limit.",
            MEDIASERVER::NS_S_DRM_NEEDS_INDIVIDUALIZATION => "A security upgrade is required to perform the operation on this media file.",
            MEDIASERVER::NS_S_REBOOT_RECOMMENDED => "Installation was successful; however, some file cleanup is not complete. For best results, restart your computer.",
            MEDIASERVER::NS_S_REBOOT_REQUIRED => "Installation was successful; however, some file cleanup is not complete. To continue, you must restart your computer.",
            MEDIASERVER::NS_S_EOSRECEDING => "EOS hit during rewinding.",
            MEDIASERVER::NS_S_CHANGENOTICE => "Internal.",
            MEDIASERVER::MF_S_MULTIPLE_BEGIN => "This callback and state had already been passed in to this event generator earlier.",
            MEDIASERVER::MF_S_ACTIVATE_REPLACED => "The activate could not be created in the remote process for some reason: it was replaced with empty one.",
            MEDIASERVER::MF_S_SINK_NOT_FINALIZED => "The sink has not been finalized before shut down. This can cause the sink to generate corrupted content.",
            MEDIASERVER::MF_S_SEQUENCER_CONTEXT_CANCELED => "The context was canceled.",
            MEDIASERVER::MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM => "Cannot update topology flags.",
            MEDIASERVER::MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT => "The caller should not propagate this event to downstream components.",
            MEDIASERVER::MF_S_PROTECTION_NOT_REQUIRED => "Protection for stream is not required.",
            MEDIASERVER::MF_S_WAIT_FOR_POLICY_SET => "Protection for this stream is not guaranteed to be enforced until the MEPolicySet event is fired.",
            MEDIASERVER::MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT => "This video stream is disabled because it is being sent to an unknown software output.",
            MEDIASERVER::MF_S_PE_TRUSTED => "The Protected Environment is trusted.",
            MEDIASERVER::MF_S_CLOCK_STOPPED => "Timer::SetTimer returns this success code if call happened while timer is stopped. Timer is not going to be dispatched until clock is running.",
            MEDIASERVER::NS_I_TIGER_START => "The Title Server %1 is running.",
            MEDIASERVER::NS_I_CUB_START => "Content Server %1 (%2) is starting.",
            MEDIASERVER::NS_I_CUB_RUNNING => "Content Server %1 (%2) is running.",
            MEDIASERVER::NS_I_DISK_START => "Disk %1 ( %2 ) on Content Server %3, is running.",
            MEDIASERVER::NS_I_DISK_REBUILD_STARTED => "Started rebuilding disk %1 ( %2 ) on Content Server %3.",
            MEDIASERVER::NS_I_DISK_REBUILD_FINISHED => "Finished rebuilding disk %1 ( %2 ) on Content Server %3.",
            MEDIASERVER::NS_I_DISK_REBUILD_ABORTED => "Aborted rebuilding disk %1 ( %2 ) on Content Server %3.",
            MEDIASERVER::NS_I_LIMIT_FUNNELS => "A NetShow administrator at network location %1 set the data stream limit to %2 streams.",
            MEDIASERVER::NS_I_START_DISK => "A NetShow administrator at network location %1 started disk %2.",
            MEDIASERVER::NS_I_STOP_DISK => "A NetShow administrator at network location %1 stopped disk %2.",
            MEDIASERVER::NS_I_STOP_CUB => "A NetShow administrator at network location %1 stopped Content Server %2.",
            MEDIASERVER::NS_I_KILL_USERSESSION => "A NetShow administrator at network location %1 aborted user session %2 from the system.",
            MEDIASERVER::NS_I_KILL_CONNECTION => "A NetShow administrator at network location %1 aborted obsolete connection %2 from the system.",
            MEDIASERVER::NS_I_REBUILD_DISK => "A NetShow administrator at network location %1 started rebuilding disk %2.",
            MEDIASERVER::MCMADM_I_NO_EVENTS => "Event initialization failed, there will be no MCM events.",
            MEDIASERVER::NS_I_LOGGING_FAILED => "The logging operation failed.",
            MEDIASERVER::NS_I_LIMIT_BANDWIDTH => "A NetShow administrator at network location %1 set the maximum bandwidth limit to %2 bps.",
            MEDIASERVER::NS_I_CUB_UNFAIL_LINK => "Content Server %1 (%2) has established its link to Content Server %3.",
            MEDIASERVER::NS_I_RESTRIPE_START => "Restripe operation has started.",
            MEDIASERVER::NS_I_RESTRIPE_DONE => "Restripe operation has completed.",
            MEDIASERVER::NS_I_RESTRIPE_DISK_OUT => "Content disk %1 (%2) on Content Server %3 has been restriped out.",
            MEDIASERVER::NS_I_RESTRIPE_CUB_OUT => "Content server %1 (%2) has been restriped out.",
            MEDIASERVER::NS_I_DISK_STOP => "Disk %1 ( %2 ) on Content Server %3, has been offlined.",
            MEDIASERVER::NS_I_PLAYLIST_CHANGE_RECEDING => "The playlist change occurred while receding.",
            MEDIASERVER::NS_I_RECONNECTED => "The client is reconnected.",
            MEDIASERVER::NS_I_NOLOG_STOP => "Forcing a switch to a pending header on start.",
            MEDIASERVER::NS_I_EXISTING_PACKETIZER => "There is already an existing packetizer plugin for the stream.",
            MEDIASERVER::NS_I_MANUAL_PROXY => "The proxy setting is manual.",
            MEDIASERVER::MF_S_ASF_PARSEINPROGRESS => "Parsing is still in progress and is not yet complete.",
            MEDIASERVER::MF_I_MANUAL_PROXY => "The proxy setting is manual.",
            MEDIASERVER::NS_W_SERVER_BANDWIDTH_LIMIT => "The maximum filebitrate value specified is greater than the server's configured maximum bandwidth.",
            MEDIASERVER::NS_W_FILE_BANDWIDTH_LIMIT => "The maximum bandwidth value specified is less than the maximum filebitrate.",
            MEDIASERVER::NS_W_UNKNOWN_EVENT => "Unknown %1 event encountered.",
            MEDIASERVER::NS_I_CATATONIC_FAILURE => "Disk %1 ( %2 ) on Content Server %3, will be failed because it is catatonic.",
            MEDIASERVER::NS_I_CATATONIC_AUTO_UNFAIL => "Disk %1 ( %2 ) on Content Server %3, auto online from catatonic state.",
            MEDIASERVER::NS_E_NOCONNECTION => "There is no connection established with the Windows Media server. The operation failed.",
            MEDIASERVER::NS_E_CANNOTCONNECT => "Unable to establish a connection to the server.",
            MEDIASERVER::NS_E_CANNOTDESTROYTITLE => "Unable to destroy the title.",
            MEDIASERVER::NS_E_CANNOTRENAMETITLE => "Unable to rename the title.",
            MEDIASERVER::NS_E_CANNOTOFFLINEDISK => "Unable to offline disk.",
            MEDIASERVER::NS_E_CANNOTONLINEDISK => "Unable to online disk.",
            MEDIASERVER::NS_E_NOREGISTEREDWALKER => "There is no file parser registered for this type of file.",
            MEDIASERVER::NS_E_NOFUNNEL => "There is no data connection established.",
            MEDIASERVER::NS_E_NO_LOCALPLAY => "Failed to load the local play DLL.",
            MEDIASERVER::NS_E_NETWORK_BUSY => "The network is busy.",
            MEDIASERVER::NS_E_TOO_MANY_SESS => "The server session limit was exceeded.",
            MEDIASERVER::NS_E_ALREADY_CONNECTED => "The network connection already exists.",
            MEDIASERVER::NS_E_INVALID_INDEX => "Index %1 is invalid.",
            MEDIASERVER::NS_E_PROTOCOL_MISMATCH => "There is no protocol or protocol version supported by both the client and the server.",
            MEDIASERVER::NS_E_TIMEOUT => "The server, a computer set up to offer multimedia content to other computers, could not handle your request for multimedia content in a timely manner. Please try again later.",
            MEDIASERVER::NS_E_NET_WRITE => "Error writing to the network.",
            MEDIASERVER::NS_E_NET_READ => "Error reading from the network.",
            MEDIASERVER::NS_E_DISK_WRITE => "Error writing to a disk.",
            MEDIASERVER::NS_E_DISK_READ => "Error reading from a disk.",
            MEDIASERVER::NS_E_FILE_WRITE => "Error writing to a file.",
            MEDIASERVER::NS_E_FILE_READ => "Error reading from a file.",
            MEDIASERVER::NS_E_FILE_NOT_FOUND => "The system cannot find the file specified.",
            MEDIASERVER::NS_E_FILE_EXISTS => "The file already exists.",
            MEDIASERVER::NS_E_INVALID_NAME => "The file name, directory name, or volume label syntax is incorrect.",
            MEDIASERVER::NS_E_FILE_OPEN_FAILED => "Failed to open a file.",
            MEDIASERVER::NS_E_FILE_ALLOCATION_FAILED => "Unable to allocate a file.",
            MEDIASERVER::NS_E_FILE_INIT_FAILED => "Unable to initialize a file.",
            MEDIASERVER::NS_E_FILE_PLAY_FAILED => "Unable to play a file.",
            MEDIASERVER::NS_E_SET_DISK_UID_FAILED => "Could not set the disk UID.",
            MEDIASERVER::NS_E_INDUCED => "An error was induced for testing purposes.",
            MEDIASERVER::NS_E_CCLINK_DOWN => "Two Content Servers failed to communicate.",
            MEDIASERVER::NS_E_INTERNAL => "An unknown error occurred.",
            MEDIASERVER::NS_E_BUSY => "The requested resource is in use.",
            MEDIASERVER::NS_E_UNRECOGNIZED_STREAM_TYPE => "The specified protocol is not recognized. Be sure that the file name and syntax, such as slashes, are correct for the protocol.",
            MEDIASERVER::NS_E_NETWORK_SERVICE_FAILURE => "The network service provider failed.",
            MEDIASERVER::NS_E_NETWORK_RESOURCE_FAILURE => "An attempt to acquire a network resource failed.",
            MEDIASERVER::NS_E_CONNECTION_FAILURE => "The network connection has failed.",
            MEDIASERVER::NS_E_SHUTDOWN => "The session is being terminated locally.",
            MEDIASERVER::NS_E_INVALID_REQUEST => "The request is invalid in the current state.",
            MEDIASERVER::NS_E_INSUFFICIENT_BANDWIDTH => "There is insufficient bandwidth available to fulfill the request.",
            MEDIASERVER::NS_E_NOT_REBUILDING => "The disk is not rebuilding.",
            MEDIASERVER::NS_E_LATE_OPERATION => "An operation requested for a particular time could not be carried out on schedule.",
            MEDIASERVER::NS_E_INVALID_DATA => "Invalid or corrupt data was encountered.",
            MEDIASERVER::NS_E_FILE_BANDWIDTH_LIMIT => "The bandwidth required to stream a file is higher than the maximum file bandwidth allowed on the server.",
            MEDIASERVER::NS_E_OPEN_FILE_LIMIT => "The client cannot have any more files open simultaneously.",
            MEDIASERVER::NS_E_BAD_CONTROL_DATA => "The server received invalid data from the client on the control connection.",
            MEDIASERVER::NS_E_NO_STREAM => "There is no stream available.",
            MEDIASERVER::NS_E_STREAM_END => "There is no more data in the stream.",
            MEDIASERVER::NS_E_SERVER_NOT_FOUND => "The specified server could not be found.",
            MEDIASERVER::NS_E_DUPLICATE_NAME => "The specified name is already in use.",
            MEDIASERVER::NS_E_DUPLICATE_ADDRESS => "The specified address is already in use.",
            MEDIASERVER::NS_E_BAD_MULTICAST_ADDRESS => "The specified address is not a valid multicast address.",
            MEDIASERVER::NS_E_BAD_ADAPTER_ADDRESS => "The specified adapter address is invalid.",
            MEDIASERVER::NS_E_BAD_DELIVERY_MODE => "The specified delivery mode is invalid.",
            MEDIASERVER::NS_E_INVALID_CHANNEL => "The specified station does not exist.",
            MEDIASERVER::NS_E_INVALID_STREAM => "The specified stream does not exist.",
            MEDIASERVER::NS_E_INVALID_ARCHIVE => "The specified archive could not be opened.",
            MEDIASERVER::NS_E_NOTITLES => "The system cannot find any titles on the server.",
            MEDIASERVER::NS_E_INVALID_CLIENT => "The system cannot find the client specified.",
            MEDIASERVER::NS_E_INVALID_BLACKHOLE_ADDRESS => "The Blackhole Address is not initialized.",
            MEDIASERVER::NS_E_INCOMPATIBLE_FORMAT => "The station does not support the stream format.",
            MEDIASERVER::NS_E_INVALID_KEY => "The specified key is not valid.",
            MEDIASERVER::NS_E_INVALID_PORT => "The specified port is not valid.",
            MEDIASERVER::NS_E_INVALID_TTL => "The specified TTL is not valid.",
            MEDIASERVER::NS_E_STRIDE_REFUSED => "The request to fast forward or rewind could not be fulfilled.",
            MEDIASERVER::NS_E_MMSAUTOSERVER_CANTFINDWALKER => "Unable to load the appropriate file parser.",
            MEDIASERVER::NS_E_MAX_BITRATE => "Cannot exceed the maximum bandwidth limit.",
            MEDIASERVER::NS_E_LOGFILEPERIOD => "Invalid value for LogFilePeriod.",
            MEDIASERVER::NS_E_MAX_CLIENTS => "Cannot exceed the maximum client limit.",
            MEDIASERVER::NS_E_LOG_FILE_SIZE => "The maximum log file size has been reached.",
            MEDIASERVER::NS_E_MAX_FILERATE => "Cannot exceed the maximum file rate.",
            MEDIASERVER::NS_E_WALKER_UNKNOWN => "Unknown file type.",
            MEDIASERVER::NS_E_WALKER_SERVER => "The specified file, %1, cannot be loaded onto the specified server, %2.",
            MEDIASERVER::NS_E_WALKER_USAGE => "There was a usage error with file parser.",
            MEDIASERVER::NS_E_TIGER_FAIL => "The Title Server %1 has failed.",
            MEDIASERVER::NS_E_CUB_FAIL => "Content Server %1 (%2) has failed.",
            MEDIASERVER::NS_E_DISK_FAIL => "Disk %1 ( %2 ) on Content Server %3, has failed.",
            MEDIASERVER::NS_E_MAX_FUNNELS_ALERT => "The NetShow data stream limit of %1 streams was reached.",
            MEDIASERVER::NS_E_ALLOCATE_FILE_FAIL => "The NetShow Video Server was unable to allocate a %1 block file named %2.",
            MEDIASERVER::NS_E_PAGING_ERROR => "A Content Server was unable to page a block.",
            MEDIASERVER::NS_E_BAD_BLOCK0_VERSION => "Disk %1 has unrecognized control block version %2.",
            MEDIASERVER::NS_E_BAD_DISK_UID => "Disk %1 has incorrect uid %2.",
            MEDIASERVER::NS_E_BAD_FSMAJOR_VERSION => "Disk %1 has unsupported file system major version %2.",
            MEDIASERVER::NS_E_BAD_STAMPNUMBER => "Disk %1 has bad stamp number in control block.",
            MEDIASERVER::NS_E_PARTIALLY_REBUILT_DISK => "Disk %1 is partially reconstructed.",
            MEDIASERVER::NS_E_ENACTPLAN_GIVEUP => "EnactPlan gives up.",
            MEDIASERVER::MCMADM_E_REGKEY_NOT_FOUND => "The key was not found in the registry.",
            MEDIASERVER::NS_E_NO_FORMATS => "The publishing point cannot be started because the server does not have the appropriate stream formats. Use the Multicast Announcement Wizard to create a new announcement for this publishing point.",
            MEDIASERVER::NS_E_NO_REFERENCES => "No reference URLs were found in an ASX file.",
            MEDIASERVER::NS_E_WAVE_OPEN => "Error opening wave device, the device might be in use.",
            MEDIASERVER::NS_E_CANNOTCONNECTEVENTS => "Unable to establish a connection to the NetShow event monitor service.",
            MEDIASERVER::NS_E_NO_DEVICE => "No device driver is present on the system.",
            MEDIASERVER::NS_E_NO_SPECIFIED_DEVICE => "No specified device driver is present.",
            MEDIASERVER::NS_E_MONITOR_GIVEUP => "Netshow Events Monitor is not operational and has been disconnected.",
            MEDIASERVER::NS_E_REMIRRORED_DISK => "Disk %1 is remirrored.",
            MEDIASERVER::NS_E_INSUFFICIENT_DATA => "Insufficient data found.",
            MEDIASERVER::NS_E_ASSERT => "1 failed in file %2 line %3.",
            MEDIASERVER::NS_E_BAD_ADAPTER_NAME => "The specified adapter name is invalid.",
            MEDIASERVER::NS_E_NOT_LICENSED => "The application is not licensed for this feature.",
            MEDIASERVER::NS_E_NO_SERVER_CONTACT => "Unable to contact the server.",
            MEDIASERVER::NS_E_TOO_MANY_TITLES => "Maximum number of titles exceeded.",
            MEDIASERVER::NS_E_TITLE_SIZE_EXCEEDED => "Maximum size of a title exceeded.",
            MEDIASERVER::NS_E_UDP_DISABLED => "UDP protocol not enabled. Not trying %1!ls!.",
            MEDIASERVER::NS_E_TCP_DISABLED => "TCP protocol not enabled. Not trying %1!ls!.",
            MEDIASERVER::NS_E_HTTP_DISABLED => "HTTP protocol not enabled. Not trying %1!ls!.",
            MEDIASERVER::NS_E_LICENSE_EXPIRED => "The product license has expired.",
            MEDIASERVER::NS_E_TITLE_BITRATE => "Source file exceeds the per title maximum bitrate. See NetShow Theater documentation for more information.",
            MEDIASERVER::NS_E_EMPTY_PROGRAM_NAME => "The program name cannot be empty.",
            MEDIASERVER::NS_E_MISSING_CHANNEL => "Station %1 does not exist.",
            MEDIASERVER::NS_E_NO_CHANNELS => "You need to define at least one station before this operation can complete.",
            MEDIASERVER::NS_E_INVALID_INDEX2 => "The index specified is invalid.",
            MEDIASERVER::NS_E_CUB_FAIL_LINK => "Content Server %1 (%2) has failed its link to Content Server %3.",
            MEDIASERVER::NS_E_BAD_CUB_UID => "Content Server %1 (%2) has incorrect uid %3.",
            MEDIASERVER::NS_E_GLITCH_MODE => "Server unreliable because multiple components failed.",
            MEDIASERVER::NS_E_NO_MEDIA_PROTOCOL => "Content Server %1 (%2) is unable to communicate with the Media System Network Protocol.",
            MEDIASERVER::ASF_E_BUFFEROVERRUN => "ASF Error: An attempt was made to seek or position past the end of a buffer.",
            MEDIASERVER::ASF_E_BUFFERTOOSMALL => "ASF Error: The supplied input or output buffer was too small.",
            MEDIASERVER::ASF_E_BADLANGUAGEID => "ASF Error: The language ID was not found.",
            MEDIASERVER::ASF_E_NOPAYLOADLENGTH => "ASF Error: The multiple payload packet is missing the payload length.",
            MEDIASERVER::ASF_E_TOOMANYPAYLOADS => "ASF Error: The packet contains too many payloads.",
            MEDIASERVER::ASF_E_PACKETCONTENTTOOLARGE => "ASF Error: The packet content is too large.",
            MEDIASERVER::ASF_E_UNKNOWNPACKETSIZE => "ASF Error: Expecting a fixed packet size but minimum and maximum are not equal.",
            MEDIASERVER::ASF_E_INVALIDHEADER => "ASF Error: The ASF file header does not contain enough information.",
            MEDIASERVER::ASF_E_NOCLOCKOBJECT => "ASF Error: The object does not have a valid clock object.",
            MEDIASERVER::ASF_E_UNKNOWNCLOCKTYPE => "ASF Error: An unknown clock type was specified for the stream clock type.",
            MEDIASERVER::ASF_E_OPAQUEPACKET => "ASF Error: An attempt was made to restore or access an opaque packet.",
            MEDIASERVER::ASF_E_WRONGVERSION => "ASF Error: The wrong ASF version is being used.",
            MEDIASERVER::ASF_E_OVERFLOW => "ASF Error: An attempt was made to store a value which was larger than the destination's maximum value.",
            MEDIASERVER::ASF_E_NOTFOUND => "ASF Error: The object was not found.",
            MEDIASERVER::NS_E_NOTHING_TO_DO => "Nothing to do.",
            MEDIASERVER::NS_E_NO_MULTICAST => "Not receiving data from the server.",
            MEDIASERVER::ASF_E_OBJECTTOOBIG => "ASF Error: The object is too large to be processed in the requested manner.",
            MEDIASERVER::ASF_E_UNEXPECTEDVALUE => "ASF Error: A value was not set as expected.",
            MEDIASERVER::ASF_E_INVALIDSTATE => "ASF Error: The request is not valid in the object's current state.",
            MEDIASERVER::ASF_E_NOLIBRARY => "ASF Error: This object does not have a valid library pointer; it was not properly created or it has been shut down.",
            MEDIASERVER::ASF_E_ALREADYINITIALIZED => "ASF Error: This object has already been initialized; the setting cannot be changed.",
            MEDIASERVER::ASF_E_INVALIDINIT => "ASF Error: This object has not been initialized properly; that operation cannot be performed.",
            MEDIASERVER::ASF_E_NOHEADEROBJECT => "ASF Error: The ASF Header object could not be found.",
            MEDIASERVER::ASF_E_NODATAOBJECT => "ASF Error: The ASF Data object could not be found.",
            MEDIASERVER::ASF_E_NOINDEXOBJECT => "ASF Error: The ASF Index object could not be found.",
            MEDIASERVER::ASF_E_NOSTREAMPROPS => "ASF Error: A Stream Properties object with the correct stream number could not be found.",
            MEDIASERVER::ASF_E_NOFILEPROPS => "ASF Error: The File Properties object could not be found.",
            MEDIASERVER::ASF_E_INVALIDFLAGS => "ASF Error: The flags for this object or set of objects have not been properly set.",
            MEDIASERVER::ASF_E_BADDATADESCRIPTOR => "ASF Error: One or more data descriptors are not properly set.",
            MEDIASERVER::ASF_E_BADINDEXINTERVAL => "ASF Error: The index has an invalid time interval (probably zero).",
            MEDIASERVER::ASF_E_INVALIDTIME => "ASF Error: The given time value is not valid.",
            MEDIASERVER::ASF_E_INVALIDINDEX => "ASF Error: The given index value is not valid.",
            MEDIASERVER::ASF_E_STREAMNUMBERINUSE => "ASF Error: The specified stream number is already in use.",
            MEDIASERVER::ASF_E_BADMEDIATYPE => "ASF Error: The specified media type does not work with this component.",
            MEDIASERVER::ASF_E_WRITEFAILED => "ASF Error: The object could not be written as specified.",
            MEDIASERVER::ASF_E_NOTENOUGHDESCRIPTORS => "ASF Error: The specified data unit requires a larger number of descriptors before it can be fully parsed.",
            MEDIASERVER::ASF_E_INDEXBLOCKUNLOADED => "ASF Error: The index entries for the specified index block have been unloaded from memory and are not available.",
            MEDIASERVER::ASF_E_NOTENOUGHBANDWIDTH => "ASF Error: The specified bandwidth is not large enough.",
            MEDIASERVER::ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE => "ASF Error: The object has exceeded its maximum size.",
            MEDIASERVER::ASF_E_BADDATAUNIT => "ASF Error: The given data unit is corrupted, badly formatted, or otherwise not valid.",
            MEDIASERVER::ASF_E_HEADERSIZE => "ASF Error: The ASF header has exceeded the specified maximum size.",
            MEDIASERVER::NS_E_INVALID_INPUT_FORMAT => "The input media format is invalid.",
            MEDIASERVER::NS_E_MSAUDIO_NOT_INSTALLED => "The MSAudio codec is not installed on this system.",
            MEDIASERVER::NS_E_UNEXPECTED_MSAUDIO_ERROR => "An unexpected error occurred with the MSAudio codec.",
            MEDIASERVER::NS_E_INVALID_OUTPUT_FORMAT => "The output media format is invalid.",
            MEDIASERVER::NS_E_NOT_CONFIGURED => "The object must be fully configured before audio samples can be processed.",
            MEDIASERVER::NS_E_PROTECTED_CONTENT => "You need a license to perform the requested operation on this media file.",
            MEDIASERVER::NS_E_LICENSE_REQUIRED => "You need a license to perform the requested operation on this media file.",
            MEDIASERVER::NS_E_TAMPERED_CONTENT => "This media file is corrupted or invalid. Contact the content provider for a new file.",
            MEDIASERVER::NS_E_LICENSE_OUTOFDATE => "The license for this media file has expired. Get a new license or contact the content provider for further assistance.",
            MEDIASERVER::NS_E_LICENSE_INCORRECT_RIGHTS => "You are not allowed to open this file. Contact the content provider for further assistance.",
            MEDIASERVER::NS_E_AUDIO_CODEC_NOT_INSTALLED => "The requested audio codec is not installed on this system.",
            MEDIASERVER::NS_E_AUDIO_CODEC_ERROR => "An unexpected error occurred with the audio codec.",
            MEDIASERVER::NS_E_VIDEO_CODEC_NOT_INSTALLED => "The requested video codec is not installed on this system.",
            MEDIASERVER::NS_E_VIDEO_CODEC_ERROR => "An unexpected error occurred with the video codec.",
            MEDIASERVER::NS_E_INVALIDPROFILE => "The Profile is invalid.",
            MEDIASERVER::NS_E_INCOMPATIBLE_VERSION => "A new version of the SDK is needed to play the requested content.",
            MEDIASERVER::NS_E_OFFLINE_MODE => "The requested URL is not available in offline mode.",
            MEDIASERVER::NS_E_NOT_CONNECTED => "The requested URL cannot be accessed because there is no network connection.",
            MEDIASERVER::NS_E_TOO_MUCH_DATA => "The encoding process was unable to keep up with the amount of supplied data.",
            MEDIASERVER::NS_E_UNSUPPORTED_PROPERTY => "The given property is not supported.",
            MEDIASERVER::NS_E_8BIT_WAVE_UNSUPPORTED => "Windows Media Player cannot copy the files to the CD because they are 8-bit. Convert the files to 16-bit, 44-kHz stereo files by using Sound Recorder or another audio-processing program, and then try again.",
            MEDIASERVER::NS_E_NO_MORE_SAMPLES => "There are no more samples in the current range.",
            MEDIASERVER::NS_E_INVALID_SAMPLING_RATE => "The given sampling rate is invalid.",
            MEDIASERVER::NS_E_MAX_PACKET_SIZE_TOO_SMALL => "The given maximum packet size is too small to accommodate this profile.)",
            MEDIASERVER::NS_E_LATE_PACKET => "The packet arrived too late to be of use.",
            MEDIASERVER::NS_E_DUPLICATE_PACKET => "The packet is a duplicate of one received before.",
            MEDIASERVER::NS_E_SDK_BUFFERTOOSMALL => "Supplied buffer is too small.",
            MEDIASERVER::NS_E_INVALID_NUM_PASSES => "The wrong number of preprocessing passes was used for the stream's output type.",
            MEDIASERVER::NS_E_ATTRIBUTE_READ_ONLY => "An attempt was made to add, modify, or delete a read only attribute.",
            MEDIASERVER::NS_E_ATTRIBUTE_NOT_ALLOWED => "An attempt was made to add attribute that is not allowed for the given media type.",
            MEDIASERVER::NS_E_INVALID_EDL => "The EDL provided is invalid.",
            MEDIASERVER::NS_E_DATA_UNIT_EXTENSION_TOO_LARGE => "The Data Unit Extension data was too large to be used.",
            MEDIASERVER::NS_E_CODEC_DMO_ERROR => "An unexpected error occurred with a DMO codec.",
            MEDIASERVER::NS_E_FEATURE_DISABLED_BY_GROUP_POLICY => "This feature has been disabled by group policy.",
            MEDIASERVER::NS_E_FEATURE_DISABLED_IN_SKU => "This feature is disabled in this SKU.",
            MEDIASERVER::NS_E_NO_CD => "There is no CD in the CD drive. Insert a CD, and then try again.",
            MEDIASERVER::NS_E_CANT_READ_DIGITAL => "Windows Media Player could not use digital playback to play the CD. To switch to analog playback, on the Tools menu, click Options, and then click the Devices tab. Double-click the CD drive, and then in the Playback area, click Analog. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_DEVICE_DISCONNECTED => "Windows Media Player no longer detects a connected portable device. Reconnect your portable device, and then try synchronizing the file again.",
            MEDIASERVER::NS_E_DEVICE_NOT_SUPPORT_FORMAT => "Windows Media Player cannot play the file. The portable device does not support the specified file type.",
            MEDIASERVER::NS_E_SLOW_READ_DIGITAL => "Windows Media Player could not use digital playback to play the CD. The Player has automatically switched the CD drive to analog playback. To switch back to digital CD playback, use the Devices tab. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_MIXER_INVALID_LINE => "An invalid line error occurred in the mixer.",
            MEDIASERVER::NS_E_MIXER_INVALID_CONTROL => "An invalid control error occurred in the mixer.",
            MEDIASERVER::NS_E_MIXER_INVALID_VALUE => "An invalid value error occurred in the mixer.",
            MEDIASERVER::NS_E_MIXER_UNKNOWN_MMRESULT => "An unrecognized MMRESULT occurred in the mixer.",
            MEDIASERVER::NS_E_USER_STOP => "User has stopped the operation.",
            MEDIASERVER::NS_E_MP3_FORMAT_NOT_FOUND => "Windows Media Player cannot rip the track because a compatible MP3 encoder is not installed on your computer. Install a compatible MP3 encoder or choose a different format to rip to (such as Windows Media Audio).",
            MEDIASERVER::NS_E_CD_READ_ERROR_NO_CORRECTION => "Windows Media Player cannot read the CD. The disc might be dirty or damaged. Turn on error correction, and then try again.",
            MEDIASERVER::NS_E_CD_READ_ERROR => "Windows Media Player cannot read the CD. The disc might be dirty or damaged or the CD drive might be malfunctioning.",
            MEDIASERVER::NS_E_CD_SLOW_COPY => "For best performance, do not play CD tracks while ripping them.",
            MEDIASERVER::NS_E_CD_COPYTO_CD => "It is not possible to directly burn tracks from one CD to another CD. You must first rip the tracks from the CD to your computer, and then burn the files to a blank CD.",
            MEDIASERVER::NS_E_MIXER_NODRIVER => "Could not open a sound mixer driver.",
            MEDIASERVER::NS_E_REDBOOK_ENABLED_WHILE_COPYING => "Windows Media Player cannot rip tracks from the CD correctly because the CD drive settings in Device Manager do not match the CD drive settings in the Player.",
            MEDIASERVER::NS_E_CD_REFRESH => "Windows Media Player is busy reading the CD.",
            MEDIASERVER::NS_E_CD_DRIVER_PROBLEM => "Windows Media Player could not use digital playback to play the CD. The Player has automatically switched the CD drive to analog playback. To switch back to digital CD playback, use the Devices tab. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WONT_DO_DIGITAL => "Windows Media Player could not use digital playback to play the CD. The Player has automatically switched the CD drive to analog playback. To switch back to digital CD playback, use the Devices tab. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMPXML_NOERROR => "A call was made to GetParseError on the XML parser but there was no error to retrieve.",
            MEDIASERVER::NS_E_WMPXML_ENDOFDATA => "The XML Parser ran out of data while parsing.",
            MEDIASERVER::NS_E_WMPXML_PARSEERROR => "A generic parse error occurred in the XML parser but no information is available.",
            MEDIASERVER::NS_E_WMPXML_ATTRIBUTENOTFOUND => "A call get GetNamedAttribute or GetNamedAttributeIndex on the XML parser resulted in the index not being found.",
            MEDIASERVER::NS_E_WMPXML_PINOTFOUND => "A call was made go GetNamedPI on the XML parser, but the requested Processing Instruction was not found.",
            MEDIASERVER::NS_E_WMPXML_EMPTYDOC => "Persist was called on the XML parser, but the parser has no data to persist.",
            MEDIASERVER::NS_E_WMP_PATH_ALREADY_IN_LIBRARY => "This file path is already in the library.",
            MEDIASERVER::NS_E_WMP_FILESCANALREADYSTARTED => "Windows Media Player is already searching for files to add to your library. Wait for the current process to finish before attempting to search again.",
            MEDIASERVER::NS_E_WMP_HME_INVALIDOBJECTID => "Windows Media Player is unable to find the media you are looking for.",
            MEDIASERVER::NS_E_WMP_MF_CODE_EXPIRED => "A component of Windows Media Player is out-of-date. If you are running a pre-release version of Windows, try upgrading to a more recent version.",
            MEDIASERVER::NS_E_WMP_HME_NOTSEARCHABLEFORITEMS => "This container does not support search on items.",
            MEDIASERVER::NS_E_WMP_ADDTOLIBRARY_FAILED => "Windows Media Player encountered a problem while adding one or more files to the library. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_WINDOWSAPIFAILURE => "A Windows API call failed but no error information was available.",
            MEDIASERVER::NS_E_WMP_RECORDING_NOT_ALLOWED => "This file does not have burn rights. If you obtained this file from an online store, go to the online store to get burn rights.",
            MEDIASERVER::NS_E_DEVICE_NOT_READY => "Windows Media Player no longer detects a connected portable device. Reconnect your portable device, and then try to sync the file again.",
            MEDIASERVER::NS_E_DAMAGED_FILE => "Windows Media Player cannot play the file because it is corrupted.",
            MEDIASERVER::NS_E_MPDB_GENERIC => "Windows Media Player encountered an error while attempting to access information in the library. Try restarting the Player.",
            MEDIASERVER::NS_E_FILE_FAILED_CHECKS => "The file cannot be added to the library because it is smaller than the 'Skip files smaller than' setting. To add the file, change the setting on the Library tab. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_MEDIA_LIBRARY_FAILED => "Windows Media Player cannot create the library. You must be logged on as an administrator or a member of the Administrators group to install the Player. For more information, contact your system administrator.",
            MEDIASERVER::NS_E_SHARING_VIOLATION => "The file is already in use. Close other programs that might be using the file, or stop playing the file, and then try again.",
            MEDIASERVER::NS_E_NO_ERROR_STRING_FOUND => "Windows Media Player has encountered an unknown error.",
            MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_CORE => "The Windows Media Player ActiveX control cannot connect to remote media services, but will continue with local media services.",
            MEDIASERVER::NS_E_WMPOCX_NO_ACTIVE_CORE => "The requested method or property is not available because the Windows Media Player ActiveX control has not been properly activated.",
            MEDIASERVER::NS_E_WMPOCX_NOT_RUNNING_REMOTELY => "The Windows Media Player ActiveX control is not running in remote mode.",
            MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_WINDOW => "An error occurred while trying to get the remote Windows Media Player window.",
            MEDIASERVER::NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE => "Windows Media Player has encountered an unknown error.",
            MEDIASERVER::NS_E_PLUGIN_NOTSHUTDOWN => "Windows Media Player was not closed properly. A damaged or incompatible plug-in might have caused the problem to occur. As a precaution, all optional plug-ins have been disabled.",
            MEDIASERVER::NS_E_WMP_CANNOT_FIND_FOLDER => "Windows Media Player cannot find the specified path. Verify that the path is typed correctly. If it is, the path does not exist in the specified location, or the computer where the path is located is not available.",
            MEDIASERVER::NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED => "Windows Media Player cannot save a file that is being streamed.",
            MEDIASERVER::NS_E_WMP_PLUGINDLL_NOTFOUND => "Windows Media Player cannot find the selected plug-in. The Player will try to remove it from the menu. To use this plug-in, install it again.",
            MEDIASERVER::NS_E_NEED_TO_ASK_USER => "Action requires input from the user.",
            MEDIASERVER::NS_E_WMPOCX_PLAYER_NOT_DOCKED => "The Windows Media Player ActiveX control must be in a docked state for this action to be performed.",
            MEDIASERVER::NS_E_WMP_EXTERNAL_NOTREADY => "The Windows Media Player external object is not ready.",
            MEDIASERVER::NS_E_WMP_MLS_STALE_DATA => "Windows Media Player cannot perform the requested action. Your computer's time and date might not be set correctly.",
            MEDIASERVER::NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED => "The control (%s) does not support creation of sub-controls, yet (%d) sub-controls have been specified.",
            MEDIASERVER::NS_E_WMP_UI_VERSIONMISMATCH => "Version mismatch: (%.1f required, %.1f found).",
            MEDIASERVER::NS_E_WMP_UI_NOTATHEMEFILE => "The layout manager was given valid XML that wasn't a theme file.",
            MEDIASERVER::NS_E_WMP_UI_SUBELEMENTNOTFOUND => "The %s subelement could not be found on the %s object.",
            MEDIASERVER::NS_E_WMP_UI_VERSIONPARSE => "An error occurred parsing the version tag. Valid version tags are of the form: <?wmp version='1.0'?>.",
            MEDIASERVER::NS_E_WMP_UI_VIEWIDNOTFOUND => "The view specified in for the 'currentViewID' property (%s) was not found in this theme file.",
            MEDIASERVER::NS_E_WMP_UI_PASSTHROUGH => "This error used internally for hit testing.",
            MEDIASERVER::NS_E_WMP_UI_OBJECTNOTFOUND => "Attributes were specified for the %s object, but the object was not available to send them to.",
            MEDIASERVER::NS_E_WMP_UI_SECONDHANDLER => "The %s event already has a handler, the second handler was ignored.",
            MEDIASERVER::NS_E_WMP_UI_NOSKININZIP => "No .wms file found in skin archive.",
            MEDIASERVER::NS_E_WMP_URLDOWNLOADFAILED => "Windows Media Player encountered a problem while downloading the file. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN => "The Windows Media Player ActiveX control cannot load the requested uiMode and cannot roll back to the existing uiMode.",
            MEDIASERVER::NS_E_WMP_INVALID_SKIN => "Windows Media Player encountered a problem with the skin file. The skin file might not be valid.",
            MEDIASERVER::NS_E_WMP_SENDMAILFAILED => "Windows Media Player cannot send the link because your email program is not responding. Verify that your email program is configured properly, and then try again. For more information about email, see Windows Help.",
            MEDIASERVER::NS_E_WMP_LOCKEDINSKINMODE => "Windows Media Player cannot switch to full mode because your computer administrator has locked this skin.",
            MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_FILE => "Windows Media Player encountered a problem while saving the file. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_SAVEAS_READONLY => "Windows Media Player cannot overwrite a read-only file. Try using a different file name.",
            MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_PLAYLIST => "Windows Media Player encountered a problem while creating or saving the playlist. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_WMD => "Windows Media Player cannot open the Windows Media Download file. The file might be damaged.",
            MEDIASERVER::NS_E_WMP_CANT_PLAY_PROTECTED => "The file cannot be added to the library because it is a protected DVR-MS file. This content cannot be played back by Windows Media Player.",
            MEDIASERVER::NS_E_SHARING_STATE_OUT_OF_SYNC => "Media sharing has been turned off because a required Windows setting or component has changed. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING => "Exclusive Services launch failed because the Windows Media Player is already running.",
            MEDIASERVER::NS_E_WMP_RBC_JPGMAPPINGIMAGE => "JPG Images are not recommended for use as a mappingImage.",
            MEDIASERVER::NS_E_WMP_JPGTRANSPARENCY => "JPG Images are not recommended when using a transparencyColor.",
            MEDIASERVER::NS_E_WMP_INVALID_MAX_VAL => "The Max property cannot be less than Min property.",
            MEDIASERVER::NS_E_WMP_INVALID_MIN_VAL => "The Min property cannot be greater than Max property.",
            MEDIASERVER::NS_E_WMP_CS_JPGPOSITIONIMAGE => "JPG Images are not recommended for use as a positionImage.",
            MEDIASERVER::NS_E_WMP_CS_NOTEVENLYDIVISIBLE => "The (%s) image's size is not evenly divisible by the positionImage's size.",
            MEDIASERVER::NS_E_WMPZIP_NOTAZIPFILE => "The ZIP reader opened a file and its signature did not match that of the ZIP files.",
            MEDIASERVER::NS_E_WMPZIP_CORRUPT => "The ZIP reader has detected that the file is corrupted.",
            MEDIASERVER::NS_E_WMPZIP_FILENOTFOUND => "GetFileStream, SaveToFile, or SaveTemp file was called on the ZIP reader with a file name that was not found in the ZIP file.",
            MEDIASERVER::NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED => "Image type not supported.",
            MEDIASERVER::NS_E_WMP_IMAGE_INVALID_FORMAT => "Image file might be corrupt.",
            MEDIASERVER::NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE => "Unexpected end of file. GIF file might be corrupt.",
            MEDIASERVER::NS_E_WMP_GIF_INVALID_FORMAT => "Invalid GIF file.",
            MEDIASERVER::NS_E_WMP_GIF_BAD_VERSION_NUMBER => "Invalid GIF version. Only 87a or 89a supported.",
            MEDIASERVER::NS_E_WMP_GIF_NO_IMAGE_IN_FILE => "No images found in GIF file.",
            MEDIASERVER::NS_E_WMP_PNG_INVALIDFORMAT => "Invalid PNG image file format.",
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH => "PNG bitdepth not supported.",
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION => "Compression format defined in PNG file not supported,",
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_FILTER => "Filter method defined in PNG file not supported.",
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_INTERLACE => "Interlace method defined in PNG file not supported.",
            MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC => "Bad CRC in PNG file.",
            MEDIASERVER::NS_E_WMP_BMP_INVALID_BITMASK => "Invalid bitmask in BMP file.",
            MEDIASERVER::NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED => "Topdown DIB not supported.",
            MEDIASERVER::NS_E_WMP_BMP_BITMAP_NOT_CREATED => "Bitmap could not be created.",
            MEDIASERVER::NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED => "Compression format defined in BMP not supported.",
            MEDIASERVER::NS_E_WMP_BMP_INVALID_FORMAT => "Invalid Bitmap format.",
            MEDIASERVER::NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL => "JPEG Arithmetic coding not supported.",
            MEDIASERVER::NS_E_WMP_JPG_INVALID_FORMAT => "Invalid JPEG format.",
            MEDIASERVER::NS_E_WMP_JPG_BAD_DCTSIZE => "Invalid JPEG format.",
            MEDIASERVER::NS_E_WMP_JPG_BAD_VERSION_NUMBER => "Internal version error. Unexpected JPEG library version.",
            MEDIASERVER::NS_E_WMP_JPG_BAD_PRECISION => "Internal JPEG Library error. Unsupported JPEG data precision.",
            MEDIASERVER::NS_E_WMP_JPG_CCIR601_NOTIMPL => "JPEG CCIR601 not supported.",
            MEDIASERVER::NS_E_WMP_JPG_NO_IMAGE_IN_FILE => "No image found in JPEG file.",
            MEDIASERVER::NS_E_WMP_JPG_READ_ERROR => "Could not read JPEG file.",
            MEDIASERVER::NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL => "JPEG Fractional sampling not supported.",
            MEDIASERVER::NS_E_WMP_JPG_IMAGE_TOO_BIG => "JPEG image too large. Maximum image size supported is 65500 X 65500.",
            MEDIASERVER::NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE => "Unexpected end of file reached in JPEG file.",
            MEDIASERVER::NS_E_WMP_JPG_SOF_UNSUPPORTED => "Unsupported JPEG SOF marker found.",
            MEDIASERVER::NS_E_WMP_JPG_UNKNOWN_MARKER => "Unknown JPEG marker found.",
            MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_IMAGE => "Windows Media Player cannot display the picture file. The player either does not support the picture type or the picture is corrupted.",
            MEDIASERVER::NS_E_WMP_DAI_SONGTOOSHORT => "Windows Media Player cannot compute a Digital Audio Id for the song. It is too short.",
            MEDIASERVER::NS_E_WMG_RATEUNAVAILABLE => "Windows Media Player cannot play the file at the requested speed.",
            MEDIASERVER::NS_E_WMG_PLUGINUNAVAILABLE => "The rendering or digital signal processing plug-in cannot be instantiated.",
            MEDIASERVER::NS_E_WMG_CANNOTQUEUE => "The file cannot be queued for seamless playback.",
            MEDIASERVER::NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED => "Windows Media Player cannot download media usage rights for a file in the playlist.",
            MEDIASERVER::NS_E_WMG_UNEXPECTEDPREROLLSTATUS => "Windows Media Player encountered an error while trying to queue a file.",
            MEDIASERVER::NS_E_WMG_INVALID_COPP_CERTIFICATE => "Windows Media Player cannot play the protected file. The Player cannot verify that the connection to your video card is secure. Try installing an updated device driver for your video card.",
            MEDIASERVER::NS_E_WMG_COPP_SECURITY_INVALID => "Windows Media Player cannot play the protected file. The Player detected that the connection to your hardware might not be secure.",
            MEDIASERVER::NS_E_WMG_COPP_UNSUPPORTED => "Windows Media Player output link protection is unsupported on this system.",
            MEDIASERVER::NS_E_WMG_INVALIDSTATE => "Operation attempted in an invalid graph state.",
            MEDIASERVER::NS_E_WMG_SINKALREADYEXISTS => "A renderer cannot be inserted in a stream while one already exists.",
            MEDIASERVER::NS_E_WMG_NOSDKINTERFACE => "The Windows Media SDK interface needed to complete the operation does not exist at this time.",
            MEDIASERVER::NS_E_WMG_NOTALLOUTPUTSRENDERED => "Windows Media Player cannot play a portion of the file because it requires a codec that either could not be downloaded or that is not supported by the Player.",
            MEDIASERVER::NS_E_WMG_FILETRANSFERNOTALLOWED => "File transfer streams are not allowed in the standalone Player.",
            MEDIASERVER::NS_E_WMR_UNSUPPORTEDSTREAM => "Windows Media Player cannot play the file. The Player does not support the format you are trying to play.",
            MEDIASERVER::NS_E_WMR_PINNOTFOUND => "An operation was attempted on a pin that does not exist in the DirectShow filter graph.",
            MEDIASERVER::NS_E_WMR_WAITINGONFORMATSWITCH => "Specified operation cannot be completed while waiting for a media format change from the SDK.",
            MEDIASERVER::NS_E_WMR_NOSOURCEFILTER => "Specified operation cannot be completed because the source filter does not exist.",
            MEDIASERVER::NS_E_WMR_PINTYPENOMATCH => "The specified type does not match this pin.",
            MEDIASERVER::NS_E_WMR_NOCALLBACKAVAILABLE => "The WMR Source Filter does not have a callback available.",
            MEDIASERVER::NS_E_WMR_SAMPLEPROPERTYNOTSET => "The specified property has not been set on this sample.",
            MEDIASERVER::NS_E_WMR_CANNOT_RENDER_BINARY_STREAM => "A plug-in is required to correctly play the file. To determine if the plug-in is available to download, click Web Help.",
            MEDIASERVER::NS_E_WMG_LICENSE_TAMPERED => "Windows Media Player cannot play the file because your media usage rights are corrupted. If you previously backed up your media usage rights, try restoring them.",
            MEDIASERVER::NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM => "Windows Media Player cannot play protected files that contain binary streams.",
            MEDIASERVER::NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT => "Windows Media Player cannot play the playlist because it is not valid.",
            MEDIASERVER::NS_E_ASX_INVALIDFORMAT => "Windows Media Player cannot play the playlist because it is not valid.",
            MEDIASERVER::NS_E_ASX_INVALIDVERSION => "A later version of Windows Media Player might be required to play this playlist.",
            MEDIASERVER::NS_E_ASX_INVALID_REPEAT_BLOCK => "The format of a REPEAT loop within the current playlist file is not valid.",
            MEDIASERVER::NS_E_ASX_NOTHING_TO_WRITE => "Windows Media Player cannot save the playlist because it does not contain any items.",
            MEDIASERVER::NS_E_URLLIST_INVALIDFORMAT => "Windows Media Player cannot play the playlist because it is not valid.",
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST => "The specified attribute does not exist.",
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS => "The specified attribute already exists.",
            MEDIASERVER::NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE => "Cannot retrieve the specified attribute.",
            MEDIASERVER::NS_E_WMX_ITEM_DOES_NOT_EXIST => "The specified item does not exist in the current playlist.",
            MEDIASERVER::NS_E_WMX_ITEM_TYPE_ILLEGAL => "Items of the specified type cannot be created within the current playlist.",
            MEDIASERVER::NS_E_WMX_ITEM_UNSETTABLE => "The specified item cannot be set in the current playlist.",
            MEDIASERVER::NS_E_WMX_PLAYLIST_EMPTY => "Windows Media Player cannot perform the requested action because the playlist does not contain any items.",
            MEDIASERVER::NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED => "The specified auto playlist contains a filter type that is either not valid or is not installed on this computer.",
            MEDIASERVER::NS_E_WMX_INVALID_FORMAT_OVER_NESTING => "Windows Media Player cannot play the file because the associated playlist contains too many nested playlists.",
            MEDIASERVER::NS_E_WMPCORE_NOSOURCEURLSTRING => "Windows Media Player cannot find the file. Verify that the path is typed correctly. If it is, the file might not exist in the specified location, or the computer where the file is stored might not be available.",
            MEDIASERVER::NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT => "Failed to create the Global Interface Table.",
            MEDIASERVER::NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE => "Failed to get the marshaled graph event handler interface.",
            MEDIASERVER::NS_E_WMPCORE_BUFFERTOOSMALL => "Buffer is too small for copying media type.",
            MEDIASERVER::NS_E_WMPCORE_UNAVAILABLE => "The current state of the Player does not allow this operation.",
            MEDIASERVER::NS_E_WMPCORE_INVALIDPLAYLISTMODE => "The playlist manager does not understand the current play mode (for example, shuffle or normal).",
            MEDIASERVER::NS_E_WMPCORE_ITEMNOTINPLAYLIST => "Windows Media Player cannot play the file because it is not in the current playlist.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLISTEMPTY => "There are no items in the playlist. Add items to the playlist, and then try again.",
            MEDIASERVER::NS_E_WMPCORE_NOBROWSER => "The web page cannot be displayed because no web browser is installed on your computer.",
            MEDIASERVER::NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL => "Windows Media Player cannot find the specified file. Verify the path is typed correctly. If it is, the file does not exist in the specified location, or the computer where the file is stored is not available.",
            MEDIASERVER::NS_E_WMPCORE_GRAPH_NOT_IN_LIST => "Graph with the specified URL was not found in the prerolled graph list.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA => "Windows Media Player cannot perform the requested operation because there is only one item in the playlist.",
            MEDIASERVER::NS_E_WMPCORE_ERRORSINKNOTREGISTERED => "An error sink was never registered for the calling object.",
            MEDIASERVER::NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE => "The error manager is not available to respond to errors.",
            MEDIASERVER::NS_E_WMPCORE_WEBHELPFAILED => "The Web Help URL cannot be opened.",
            MEDIASERVER::NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED => "Could not resume playing next item in playlist.",
            MEDIASERVER::NS_E_WMPCORE_NO_REF_IN_ENTRY => "Windows Media Player cannot play the file because the associated playlist does not contain any items or the playlist is not valid.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY => "An empty string for playlist attribute name was found.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL => "A playlist attribute name that is not valid was found.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY => "An empty string for a playlist attribute value was found.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL => "An illegal value for a playlist attribute was found.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY => "An empty string for a playlist item attribute name was found.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL => "An illegal value for a playlist item attribute name was found.",
            MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY => "An illegal value for a playlist item attribute was found.",
            MEDIASERVER::NS_E_WMPCORE_LIST_ENTRY_NO_REF => "The playlist does not contain any items.",
            MEDIASERVER::NS_E_WMPCORE_MISNAMED_FILE => "Windows Media Player cannot play the file. The file is either corrupted or the Player does not support the format you are trying to play.",
            MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_TRUSTED => "The codec downloaded for this file does not appear to be properly signed, so it cannot be installed.",
            MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_FOUND => "Windows Media Player cannot play the file. One or more codecs required to play the file could not be found.",
            MEDIASERVER::NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED => "Windows Media Player cannot play the file because a required codec is not installed on your computer. To try downloading the codec, turn on the 'Download codecs automatically' option.",
            MEDIASERVER::NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST => "Windows Media Player encountered a problem while downloading the playlist. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST => "Failed to build the playlist.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE => "Playlist has no alternates to switch into.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED => "No more playlist alternates available to switch to.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND => "Could not find the name of the alternate playlist to switch into.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED => "Failed to switch to an alternate for this media.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED => "Failed to initialize an alternate for the media.",
            MEDIASERVER::NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY => "No URL specified for the roll over Refs in the playlist file.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME => "Encountered a playlist with no name.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT => "A required attribute in the event block of the playlist was not found.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY => "No items were found in the event block of the playlist.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_STACK_EMPTY => "No playlist was found while returning from a nested playlist.",
            MEDIASERVER::NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE => "The media item is not active currently.",
            MEDIASERVER::NS_E_WMPCORE_USER_CANCEL => "Windows Media Player cannot perform the requested action because you chose to cancel it.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY => "Windows Media Player encountered a problem with the playlist. The format of the playlist is not valid.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE => "Media object corresponding to start of a playlist repeat block was not found.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE => "Media object corresponding to the end of a playlist repeat block was not found.",
            MEDIASERVER::NS_E_WMPCORE_INVALID_PLAYLIST_URL => "The playlist URL supplied to the playlist manager is not valid.",
            MEDIASERVER::NS_E_WMPCORE_MISMATCHED_RUNTIME => "Windows Media Player cannot play the file because it is corrupted.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS => "Windows Media Player cannot add the playlist to the library because the playlist does not contain any items.",
            MEDIASERVER::NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION => "An error has occurred that could prevent the changing of the video contrast on this media.",
            MEDIASERVER::NS_E_WMPCORE_MEDIA_UNAVAILABLE => "Windows Media Player cannot play the file. If the file is located on the Internet, connect to the Internet. If the file is located on a removable storage card, insert the storage card.",
            MEDIASERVER::NS_E_WMPCORE_WMX_ENTRYREF_NO_REF => "The playlist contains an ENTRYREF for which no href was parsed. Check the syntax of playlist file.",
            MEDIASERVER::NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST => "Windows Media Player cannot play any items in the playlist. To find information about the problem, click the Now Playing tab, and then click the icon next to each file in the List pane.",
            MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS => "Windows Media Player cannot play some or all of the items in the playlist because the playlist is nested.",
            MEDIASERVER::NS_E_WMPCORE_BUSY => "Windows Media Player cannot play the file at this time. Try again later.",
            MEDIASERVER::NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE => "There is no child playlist available for this media item at this time.",
            MEDIASERVER::NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST => "There is no child playlist for this media item.",
            MEDIASERVER::NS_E_WMPCORE_FILE_NOT_FOUND => "Windows Media Player cannot find the file. The link from the item in the library to its associated digital media file might be broken. To fix the problem, try repairing the link or removing the item from the library.",
            MEDIASERVER::NS_E_WMPCORE_TEMP_FILE_NOT_FOUND => "The temporary file was not found.",
            MEDIASERVER::NS_E_WMDM_REVOKED => "Windows Media Player cannot sync the file because the device needs to be updated.",
            MEDIASERVER::NS_E_DDRAW_GENERIC => "Windows Media Player cannot play the video because there is a problem with your video card.",
            MEDIASERVER::NS_E_DISPLAY_MODE_CHANGE_FAILED => "Windows Media Player failed to change the screen mode for full-screen video playback.",
            MEDIASERVER::NS_E_PLAYLIST_CONTAINS_ERRORS => "Windows Media Player cannot play one or more files. For additional information, right-click an item that cannot be played, and then click Error Details.",
            MEDIASERVER::NS_E_CHANGING_PROXY_NAME => "Cannot change the proxy name if the proxy setting is not set to custom.",
            MEDIASERVER::NS_E_CHANGING_PROXY_PORT => "Cannot change the proxy port if the proxy setting is not set to custom.",
            MEDIASERVER::NS_E_CHANGING_PROXY_EXCEPTIONLIST => "Cannot change the proxy exception list if the proxy setting is not set to custom.",
            MEDIASERVER::NS_E_CHANGING_PROXYBYPASS => "Cannot change the proxy bypass flag if the proxy setting is not set to custom.",
            MEDIASERVER::NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND => "Cannot find the specified protocol.",
            MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGE => "Cannot change the language settings. Either the graph has no audio or the audio only supports one language.",
            MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGESELECTED => "The graph has no audio language selected.",
            MEDIASERVER::NS_E_CORECD_NOTAMEDIACD => "This is not a media CD.",
            MEDIASERVER::NS_E_WMPCORE_MEDIA_URL_TOO_LONG => "Windows Media Player cannot play the file because the URL is too long.",
            MEDIASERVER::NS_E_WMPFLASH_CANT_FIND_COM_SERVER => "To play the selected item, you must install the Macromedia Flash Player. To download the Macromedia Flash Player, go to the Adobe website.",
            MEDIASERVER::NS_E_WMPFLASH_INCOMPATIBLEVERSION => "To play the selected item, you must install a later version of the Macromedia Flash Player. To download the Macromedia Flash Player, go to the Adobe website.",
            MEDIASERVER::NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS => "Windows Media Player cannot play the file because your Internet security settings prohibit the use of ActiveX controls.",
            MEDIASERVER::NS_E_NEED_CORE_REFERENCE => "The use of this method requires an existing reference to the Player object.",
            MEDIASERVER::NS_E_MEDIACD_READ_ERROR => "Windows Media Player cannot play the CD. The disc might be dirty or damaged.",
            MEDIASERVER::NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS => "Windows Media Player cannot play the file because your Internet security settings prohibit the use of ActiveX controls.",
            MEDIASERVER::NS_E_FLASH_PLAYBACK_NOT_ALLOWED => "Flash playback has been turned off in Windows Media Player.",
            MEDIASERVER::NS_E_UNABLE_TO_CREATE_RIP_LOCATION => "Windows Media Player cannot rip the CD because a valid rip location cannot be created.",
            MEDIASERVER::NS_E_WMPCORE_SOME_CODECS_MISSING => "Windows Media Player cannot play the file because a required codec is not installed on your computer.",
            MEDIASERVER::NS_E_WMP_RIP_FAILED => "Windows Media Player cannot rip one or more tracks from the CD.",
            MEDIASERVER::NS_E_WMP_FAILED_TO_RIP_TRACK => "Windows Media Player encountered a problem while ripping the track from the CD. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_ERASE_FAILED => "Windows Media Player encountered a problem while erasing the disc. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_FORMAT_FAILED => "Windows Media Player encountered a problem while formatting the device. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE => "This file cannot be burned to a CD because it is not located on your computer.",
            MEDIASERVER::NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD => "It is not possible to burn this file type to an audio CD. Windows Media Player can burn the following file types to an audio CD: WMA, MP3, or WAV.",
            MEDIASERVER::NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD => "This file is too large to fit on a disc.",
            MEDIASERVER::NS_E_WMP_FILE_NO_DURATION => "It is not possible to determine if this file can fit on a disc because Windows Media Player cannot detect the length of the file. Playing the file before burning might enable the Player to detect the file length.",
            MEDIASERVER::NS_E_PDA_FAILED_TO_BURN => "Windows Media Player encountered a problem while burning the file to the disc. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_FAILED_DOWNLOAD_ABORT_BURN => "Windows Media Player cannot burn the audio CD because some items in the list that you chose to buy could not be downloaded from the online store.",
            MEDIASERVER::NS_E_WMPCORE_DEVICE_DRIVERS_MISSING => "Windows Media Player cannot play the file. Try using Windows Update or Device Manager to update the device drivers for your audio and video cards. For information about using Windows Update or Device Manager, see Windows Help.",
            MEDIASERVER::NS_E_WMPIM_USEROFFLINE => "Windows Media Player has detected that you are not connected to the Internet. Connect to the Internet, and then try again.",
            MEDIASERVER::NS_E_WMPIM_USERCANCELED => "The attempt to connect to the Internet was canceled.",
            MEDIASERVER::NS_E_WMPIM_DIALUPFAILED => "The attempt to connect to the Internet failed.",
            MEDIASERVER::NS_E_WINSOCK_ERROR_STRING => "Windows Media Player has encountered an unknown network error.",
            MEDIASERVER::NS_E_WMPBR_NOLISTENER => "No window is currently listening to Backup and Restore events.",
            MEDIASERVER::NS_E_WMPBR_BACKUPCANCEL => "Your media usage rights were not backed up because the backup was canceled.",
            MEDIASERVER::NS_E_WMPBR_RESTORECANCEL => "Your media usage rights were not restored because the restoration was canceled.",
            MEDIASERVER::NS_E_WMPBR_ERRORWITHURL => "An error occurred while backing up or restoring your media usage rights. A required web page cannot be displayed.",
            MEDIASERVER::NS_E_WMPBR_NAMECOLLISION => "Your media usage rights were not backed up because the backup was canceled.",
            MEDIASERVER::NS_E_WMPBR_DRIVE_INVALID => "Windows Media Player cannot restore your media usage rights from the specified location. Choose another location, and then try again.",
            MEDIASERVER::NS_E_WMPBR_BACKUPRESTOREFAILED => "Windows Media Player cannot backup or restore your media usage rights.",
            MEDIASERVER::NS_E_WMP_CONVERT_FILE_FAILED => "Windows Media Player cannot add the file to the library.",
            MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL => "Windows Media Player cannot add the file to the library because the content provider prohibits it. For assistance, contact the company that provided the file.",
            MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL => "Windows Media Player cannot add the file to the library because the content provider prohibits it. For assistance, contact the company that provided the file.",
            MEDIASERVER::NS_E_WMP_CONVERT_FILE_CORRUPT => "Windows Media Player cannot add the file to the library. The file might not be valid.",
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL => "Windows Media Player cannot add the file to the library. The plug-in required to add the file is not installed properly. For assistance, click Web Help to display the website of the company that provided the file.",
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL => "Windows Media Player cannot add the file to the library. The plug-in required to add the file is not installed properly. For assistance, contact the company that provided the file.",
            MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER => "Windows Media Player cannot add the file to the library. The plug-in required to add the file is not installed properly. For assistance, contact the company that provided the file.",
            MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS => "Windows Media Player cannot play this DVD. Try installing an updated driver for your video card or obtaining a newer video card.",
            MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED => "This DVD's resolution exceeds the maximum allowed by your component video outputs. Try reducing your screen resolution to 640 x 480, or turn off analog component outputs and use a VGA connection to your monitor.",
            MEDIASERVER::NS_E_DVD_NO_SUBPICTURE_STREAM => "Windows Media Player cannot display subtitles or highlights in DVD menus. Reinstall the DVD decoder or contact the DVD drive manufacturer to obtain an updated decoder.",
            MEDIASERVER::NS_E_DVD_COPY_PROTECT => "Windows Media Player cannot play this DVD because there is a problem with digital copy protection between your DVD drive, decoder, and video card. Try installing an updated driver for your video card.",
            MEDIASERVER::NS_E_DVD_AUTHORING_PROBLEM => "Windows Media Player cannot play the DVD. The disc was created in a manner that the Player does not support.",
            MEDIASERVER::NS_E_DVD_INVALID_DISC_REGION => "Windows Media Player cannot play the DVD because the disc prohibits playback in your region of the world. You must obtain a disc that is intended for your geographic region.",
            MEDIASERVER::NS_E_DVD_COMPATIBLE_VIDEO_CARD => "Windows Media Player cannot play the DVD because your video card does not support DVD playback.",
            MEDIASERVER::NS_E_DVD_MACROVISION => "Windows Media Player cannot play this DVD because it is not possible to turn on analog copy protection on the output display. Try installing an updated driver for your video card.",
            MEDIASERVER::NS_E_DVD_SYSTEM_DECODER_REGION => "Windows Media Player cannot play the DVD because the region assigned to your DVD drive does not match the region assigned to your DVD decoder.",
            MEDIASERVER::NS_E_DVD_DISC_DECODER_REGION => "Windows Media Player cannot play the DVD because the disc prohibits playback in your region of the world. You must obtain a disc that is intended for your geographic region.",
            MEDIASERVER::NS_E_DVD_NO_VIDEO_STREAM => "Windows Media Player cannot play DVD video. You might need to adjust your Windows display settings. Open display settings in Control Panel, and then try lowering your screen resolution and color quality settings.",
            MEDIASERVER::NS_E_DVD_NO_AUDIO_STREAM => "Windows Media Player cannot play DVD audio. Verify that your sound card is set up correctly, and then try again.",
            MEDIASERVER::NS_E_DVD_GRAPH_BUILDING => "Windows Media Player cannot play DVD video. Close any open files and quit any other programs, and then try again. If the problem persists, restart your computer.",
            MEDIASERVER::NS_E_DVD_NO_DECODER => "Windows Media Player cannot play the DVD because a compatible DVD decoder is not installed on your computer.",
            MEDIASERVER::NS_E_DVD_PARENTAL => "Windows Media Player cannot play the scene because it has a parental rating higher than the rating that you are authorized to view.",
            MEDIASERVER::NS_E_DVD_CANNOT_JUMP => "Windows Media Player cannot skip to the requested location on the DVD.",
            MEDIASERVER::NS_E_DVD_DEVICE_CONTENTION => "Windows Media Player cannot play the DVD because it is currently in use by another program. Quit the other program that is using the DVD, and then try again.",
            MEDIASERVER::NS_E_DVD_NO_VIDEO_MEMORY => "Windows Media Player cannot play DVD video. You might need to adjust your Windows display settings. Open display settings in Control Panel, and then try lowering your screen resolution and color quality settings.",
            MEDIASERVER::NS_E_DVD_CANNOT_COPY_PROTECTED => "Windows Media Player cannot rip the DVD because it is copy protected.",
            MEDIASERVER::NS_E_DVD_REQUIRED_PROPERTY_NOT_SET => "One of more of the required properties has not been set.",
            MEDIASERVER::NS_E_DVD_INVALID_TITLE_CHAPTER => "The specified title and/or chapter number does not exist on this DVD.",
            MEDIASERVER::NS_E_NO_CD_BURNER => "Windows Media Player cannot burn the files because the Player cannot find a burner. If the burner is connected properly, try using Windows Update to install the latest device driver.",
            MEDIASERVER::NS_E_DEVICE_IS_NOT_READY => "Windows Media Player does not detect storage media in the selected device. Insert storage media into the device, and then try again.",
            MEDIASERVER::NS_E_PDA_UNSUPPORTED_FORMAT => "Windows Media Player cannot sync this file. The Player might not support the file type.",
            MEDIASERVER::NS_E_NO_PDA => "Windows Media Player does not detect a portable device. Connect your portable device, and then try again.",
            MEDIASERVER::NS_E_PDA_UNSPECIFIED_ERROR => "Windows Media Player encountered an error while communicating with the device. The storage card on the device might be full, the device might be turned off, or the device might not allow playlists or folders to be created on it.",
            MEDIASERVER::NS_E_MEMSTORAGE_BAD_DATA => "Windows Media Player encountered an error while burning a CD.",
            MEDIASERVER::NS_E_PDA_FAIL_SELECT_DEVICE => "Windows Media Player encountered an error while communicating with a portable device or CD drive.",
            MEDIASERVER::NS_E_PDA_FAIL_READ_WAVE_FILE => "Windows Media Player cannot open the WAV file.",
            MEDIASERVER::NS_E_IMAPI_LOSSOFSTREAMING => "Windows Media Player failed to burn all the files to the CD. Select a slower recording speed, and then try again.",
            MEDIASERVER::NS_E_PDA_DEVICE_FULL => "There is not enough storage space on the portable device to complete this operation. Delete some unneeded files on the portable device, and then try again.",
            MEDIASERVER::NS_E_FAIL_LAUNCH_ROXIO_PLUGIN => "Windows Media Player cannot burn the files. Verify that your burner is connected properly, and then try again. If the problem persists, reinstall the Player.",
            MEDIASERVER::NS_E_PDA_DEVICE_FULL_IN_SESSION => "Windows Media Player did not sync some files to the device because there is not enough storage space on the device.",
            MEDIASERVER::NS_E_IMAPI_MEDIUM_INVALIDTYPE => "The disc in the burner is not valid. Insert a blank disc into the burner, and then try again.",
            MEDIASERVER::NS_E_PDA_MANUALDEVICE => "Windows Media Player cannot perform the requested action because the device does not support sync.",
            MEDIASERVER::NS_E_PDA_PARTNERSHIPNOTEXIST => "To perform the requested action, you must first set up sync with the device.",
            MEDIASERVER::NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP => "You have already created sync partnerships with 16 devices. To create a new sync partnership, you must first end an existing partnership.",
            MEDIASERVER::NS_E_PDA_NO_TRANSCODE_OF_DRM => "Windows Media Player cannot sync the file because protected files cannot be converted to the required quality level or file format.",
            MEDIASERVER::NS_E_PDA_TRANSCODECACHEFULL => "The folder that stores converted files is full. Either empty the folder or increase its size, and then try again.",
            MEDIASERVER::NS_E_PDA_TOO_MANY_FILE_COLLISIONS => "There are too many files with the same name in the folder on the device. Change the file name or sync to a different folder.",
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE => "Windows Media Player cannot convert the file to the format required by the device.",
            MEDIASERVER::NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY => "You have reached the maximum number of files your device allows in a folder. If your device supports playback from subfolders, try creating subfolders on the device and storing some files in them.",
            MEDIASERVER::NS_E_PROCESSINGSHOWSYNCWIZARD => "Windows Media Player is already trying to start the Device Setup Wizard.",
            MEDIASERVER::NS_E_PDA_TRANSCODE_NOT_PERMITTED => "Windows Media Player cannot convert this file format. If an updated version of the codec used to compress this file is available, install it and then try to sync the file again.",
            MEDIASERVER::NS_E_PDA_INITIALIZINGDEVICES => "Windows Media Player is busy setting up devices. Try again later.",
            MEDIASERVER::NS_E_PDA_OBSOLETE_SP => "Your device is using an outdated driver that is no longer supported by Windows Media Player. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_PDA_TITLE_COLLISION => "Windows Media Player cannot sync the file because a file with the same name already exists on the device. Change the file name or try to sync the file to a different folder.",
            MEDIASERVER::NS_E_PDA_DEVICESUPPORTDISABLED => "Automatic and manual sync have been turned off temporarily. To sync to a device, restart Windows Media Player.",
            MEDIASERVER::NS_E_PDA_NO_LONGER_AVAILABLE => "This device is not available. Connect the device to the computer, and then try again.",
            MEDIASERVER::NS_E_PDA_ENCODER_NOT_RESPONDING => "Windows Media Player cannot sync the file because an error occurred while converting the file to another quality level or format. If the problem persists, remove the file from the list of files to sync.",
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_LOCATION => "Windows Media Player cannot sync the file to your device. The file might be stored in a location that is not supported. Copy the file from its current location to your hard disk, add it to your library, and then try to sync the file again.",
            MEDIASERVER::NS_E_WMP_PROTOCOL_PROBLEM => "Windows Media Player cannot open the specified URL. Verify that the Player is configured to use all available protocols, and then try again.",
            MEDIASERVER::NS_E_WMP_NO_DISK_SPACE => "Windows Media Player cannot perform the requested action because there is not enough storage space on your computer. Delete some unneeded files on your hard disk, and then try again.",
            MEDIASERVER::NS_E_WMP_LOGON_FAILURE => "The server denied access to the file. Verify that you are using the correct user name and password.",
            MEDIASERVER::NS_E_WMP_CANNOT_FIND_FILE => "Windows Media Player cannot find the file. If you are trying to play, burn, or sync an item that is in your library, the item might point to a file that has been moved, renamed, or deleted.",
            MEDIASERVER::NS_E_WMP_SERVER_INACCESSIBLE => "Windows Media Player cannot connect to the server. The server name might not be correct, the server might not be available, or your proxy settings might not be correct.",
            MEDIASERVER::NS_E_WMP_UNSUPPORTED_FORMAT => "Windows Media Player cannot play the file. The Player might not support the file type or might not support the codec that was used to compress the file.",
            MEDIASERVER::NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT => "Windows Media Player cannot play the file. The Player might not support the file type or a required codec might not be installed on your computer.",
            MEDIASERVER::NS_E_WMP_PLAYLIST_EXISTS => "Windows Media Player cannot create the playlist because the name already exists. Type a different playlist name.",
            MEDIASERVER::NS_E_WMP_NONMEDIA_FILES => "Windows Media Player cannot delete the playlist because it contains items that are not digital media files. Any digital media files in the playlist were deleted.",
            MEDIASERVER::NS_E_WMP_INVALID_ASX => "The playlist cannot be opened because it is stored in a shared folder on another computer. If possible, move the playlist to the playlists folder on your computer.",
            MEDIASERVER::NS_E_WMP_ALREADY_IN_USE => "Windows Media Player is already in use. Stop playing any items, close all Player dialog boxes, and then try again.",
            MEDIASERVER::NS_E_WMP_IMAPI_FAILURE => "Windows Media Player encountered an error while burning. Verify that the burner is connected properly and that the disc is clean and not damaged.",
            MEDIASERVER::NS_E_WMP_WMDM_FAILURE => "Windows Media Player has encountered an unknown error with your portable device. Reconnect your portable device, and then try again.",
            MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_4CC => "A codec is required to play this file. To determine if this codec is available to download from the web, click Web Help.",
            MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG => "An audio codec is needed to play this file. To determine if this codec is available to download from the web, click Web Help.",
            MEDIASERVER::NS_E_WMP_MSSAP_NOT_AVAILABLE => "To play the file, you must install the latest Windows service pack. To install the service pack from the Windows Update website, click Web Help.",
            MEDIASERVER::NS_E_WMP_WMDM_INTERFACEDEAD => "Windows Media Player no longer detects a portable device. Reconnect your portable device, and then try again.",
            MEDIASERVER::NS_E_WMP_WMDM_NOTCERTIFIED => "Windows Media Player cannot sync the file because the portable device does not support protected files.",
            MEDIASERVER::NS_E_WMP_WMDM_LICENSE_NOTEXIST => "This file does not have sync rights. If you obtained this file from an online store, go to the online store to get sync rights.",
            MEDIASERVER::NS_E_WMP_WMDM_LICENSE_EXPIRED => "Windows Media Player cannot sync the file because the sync rights have expired. Go to the content provider's online store to get new sync rights.",
            MEDIASERVER::NS_E_WMP_WMDM_BUSY => "The portable device is already in use. Wait until the current task finishes or quit other programs that might be using the portable device, and then try again.",
            MEDIASERVER::NS_E_WMP_WMDM_NORIGHTS => "Windows Media Player cannot sync the file because the content provider or device prohibits it. You might be able to resolve this problem by going to the content provider's online store to get sync rights.",
            MEDIASERVER::NS_E_WMP_WMDM_INCORRECT_RIGHTS => "The content provider has not granted you the right to sync this file. Go to the content provider's online store to get sync rights.",
            MEDIASERVER::NS_E_WMP_IMAPI_GENERIC => "Windows Media Player cannot burn the files to the CD. Verify that the disc is clean and not damaged. If necessary, select a slower recording speed or try a different brand of blank discs.",
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_NOTPRESENT => "Windows Media Player cannot burn the files. Verify that the burner is connected properly, and then try again.",
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_BUSY => "Windows Media Player cannot burn the files. Verify that the burner is connected properly and that the disc is clean and not damaged. If the burner is already in use, wait until the current task finishes or quit other programs that might be using the burner.",
            MEDIASERVER::NS_E_WMP_IMAPI_LOSS_OF_STREAMING => "Windows Media Player cannot burn the files to the CD.",
            MEDIASERVER::NS_E_WMP_SERVER_UNAVAILABLE => "Windows Media Player cannot play the file. The server might not be available or there might be a problem with your network or firewall settings.",
            MEDIASERVER::NS_E_WMP_FILE_OPEN_FAILED => "Windows Media Player encountered a problem while playing the file. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_VERIFY_ONLINE => "Windows Media Player must connect to the Internet to verify the file's media usage rights. Connect to the Internet, and then try again.",
            MEDIASERVER::NS_E_WMP_SERVER_NOT_RESPONDING => "Windows Media Player cannot play the file because a network error occurred. The server might not be available. Verify that you are connected to the network and that your proxy settings are correct.",
            MEDIASERVER::NS_E_WMP_DRM_CORRUPT_BACKUP => "Windows Media Player cannot restore your media usage rights because it could not find any backed up rights on your computer.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE => "Windows Media Player cannot download media usage rights because the server is not available (for example, the server might be busy or not online).",
            MEDIASERVER::NS_E_WMP_NETWORK_FIREWALL => "Windows Media Player cannot play the file. A network firewall might be preventing the Player from opening the file by using the UDP transport protocol. If you typed a URL in the Open URL dialog box, try using a different transport protocol (for example, 'http:').",
            MEDIASERVER::NS_E_WMP_NO_REMOVABLE_MEDIA => "Insert the removable media, and then try again.",
            MEDIASERVER::NS_E_WMP_PROXY_CONNECT_TIMEOUT => "Windows Media Player cannot play the file because the proxy server is not responding. The proxy server might be temporarily unavailable or your Player proxy settings might not be valid.",
            MEDIASERVER::NS_E_WMP_NEED_UPGRADE => "To play the file, you might need to install a later version of Windows Media Player. On the Help menu, click Check for Updates, and then follow the instructions. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_AUDIO_HW_PROBLEM => "Windows Media Player cannot play the file because there is a problem with your sound device. There might not be a sound device installed on your computer, it might be in use by another program, or it might not be functioning properly.",
            MEDIASERVER::NS_E_WMP_INVALID_PROTOCOL => "Windows Media Player cannot play the file because the specified protocol is not supported. If you typed a URL in the Open URL dialog box, try using a different transport protocol (for example, 'http:' or 'rtsp:').",
            MEDIASERVER::NS_E_WMP_INVALID_LIBRARY_ADD => "Windows Media Player cannot add the file to the library because the file format is not supported.",
            MEDIASERVER::NS_E_WMP_MMS_NOT_SUPPORTED => "Windows Media Player cannot play the file because the specified protocol is not supported. If you typed a URL in the Open URL dialog box, try using a different transport protocol (for example, 'mms:').",
            MEDIASERVER::NS_E_WMP_NO_PROTOCOLS_SELECTED => "Windows Media Player cannot play the file because there are no streaming protocols selected. Select one or more protocols, and then try again.",
            MEDIASERVER::NS_E_WMP_GOFULLSCREEN_FAILED => "Windows Media Player cannot switch to Full Screen. You might need to adjust your Windows display settings. Open display settings in Control Panel, and then try setting Hardware acceleration to Full.",
            MEDIASERVER::NS_E_WMP_NETWORK_ERROR => "Windows Media Player cannot play the file because a network error occurred. The server might not be available (for example, the server is busy or not online) or you might not be connected to the network.",
            MEDIASERVER::NS_E_WMP_CONNECT_TIMEOUT => "Windows Media Player cannot play the file because the server is not responding. Verify that you are connected to the network, and then try again later.",
            MEDIASERVER::NS_E_WMP_MULTICAST_DISABLED => "Windows Media Player cannot play the file because the multicast protocol is not enabled. On the Tools menu, click Options, click the Network tab, and then select the Multicast check box. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_SERVER_DNS_TIMEOUT => "Windows Media Player cannot play the file because a network problem occurred. Verify that you are connected to the network, and then try again later.",
            MEDIASERVER::NS_E_WMP_PROXY_NOT_FOUND => "Windows Media Player cannot play the file because the network proxy server cannot be found. Verify that your proxy settings are correct, and then try again.",
            MEDIASERVER::NS_E_WMP_TAMPERED_CONTENT => "Windows Media Player cannot play the file because it is corrupted.",
            MEDIASERVER::NS_E_WMP_OUTOFMEMORY => "Your computer is running low on memory. Quit other programs, and then try again.",
            MEDIASERVER::NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED => "Windows Media Player cannot play, burn, rip, or sync the file because a required audio codec is not installed on your computer.",
            MEDIASERVER::NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED => "Windows Media Player cannot play the file because the required video codec is not installed on your computer.",
            MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE => "Windows Media Player cannot burn the files. If the burner is busy, wait for the current task to finish. If necessary, verify that the burner is connected properly and that you have installed the latest device driver.",
            MEDIASERVER::NS_E_WMP_DRM_DRIVER_AUTH_FAILURE => "Windows Media Player cannot play the protected file because there is a problem with your sound device. Try installing a new device driver or use a different sound device.",
            MEDIASERVER::NS_E_WMP_NETWORK_RESOURCE_FAILURE => "Windows Media Player encountered a network error. Restart the Player.",
            MEDIASERVER::NS_E_WMP_UPGRADE_APPLICATION => "Windows Media Player is not installed properly. Reinstall the Player.",
            MEDIASERVER::NS_E_WMP_UNKNOWN_ERROR => "Windows Media Player encountered an unknown error. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_INVALID_KEY => "Windows Media Player cannot play the file because the required codec is not valid.",
            MEDIASERVER::NS_E_WMP_CD_ANOTHER_USER => "The CD drive is in use by another user. Wait for the task to complete, and then try again.",
            MEDIASERVER::NS_E_WMP_DRM_NEEDS_AUTHORIZATION => "Windows Media Player cannot play, sync, or burn the protected file because a problem occurred with the Windows Media Digital Rights Management (DRM) system. You might need to connect to the Internet to update your DRM components. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_BAD_DRIVER => "Windows Media Player cannot play the file because there might be a problem with your sound or video device. Try installing an updated device driver.",
            MEDIASERVER::NS_E_WMP_ACCESS_DENIED => "Windows Media Player cannot access the file. The file might be in use, you might not have access to the computer where the file is stored, or your proxy settings might not be correct.",
            MEDIASERVER::NS_E_WMP_LICENSE_RESTRICTS => "The content provider prohibits this action. Go to the content provider's online store to get new media usage rights.",
            MEDIASERVER::NS_E_WMP_INVALID_REQUEST => "Windows Media Player cannot perform the requested action at this time.",
            MEDIASERVER::NS_E_WMP_CD_STASH_NO_SPACE => "Windows Media Player cannot burn the files because there is not enough free disk space to store the temporary files. Delete some unneeded files on your hard disk, and then try again.",
            MEDIASERVER::NS_E_WMP_DRM_NEW_HARDWARE => "Your media usage rights have become corrupted or are no longer valid. This might happen if you have replaced hardware components in your computer.",
            MEDIASERVER::NS_E_WMP_DRM_INVALID_SIG => "The required Windows Media Digital Rights Management (DRM) component cannot be validated. You might be able resolve the problem by reinstalling the Player.",
            MEDIASERVER::NS_E_WMP_DRM_CANNOT_RESTORE => "You have exceeded your restore limit for the day. Try restoring your media usage rights tomorrow.",
            MEDIASERVER::NS_E_WMP_BURN_DISC_OVERFLOW => "Some files might not fit on the CD. The required space cannot be calculated accurately because some files might be missing duration information. To ensure the calculation is accurate, play the files that are missing duration information.",
            MEDIASERVER::NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE => "Windows Media Player cannot verify the file's media usage rights. If you obtained this file from an online store, go to the online store to get the necessary rights.",
            MEDIASERVER::NS_E_WMP_DRM_NO_SECURE_CLOCK => "It is not possible to sync because this device's internal clock is not set correctly. To set the clock, select the option to set the device clock on the Privacy tab of the Options dialog box, connect to the Internet, and then sync the device again. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_WMP_DRM_NO_RIGHTS => "Windows Media Player cannot play, burn, rip, or sync the protected file because you do not have the appropriate rights.",
            MEDIASERVER::NS_E_WMP_DRM_INDIV_FAILED => "Windows Media Player encountered an error during upgrade.",
            MEDIASERVER::NS_E_WMP_SERVER_NONEWCONNECTIONS => "Windows Media Player cannot connect to the server because it is not accepting any new connections. This could be because it has reached its maximum connection limit. Please try again later.",
            MEDIASERVER::NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST => "A number of queued files cannot be played. To find information about the problem, click the Now Playing tab, and then click the icon next to each file in the List pane.",
            MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_FAIL => "Windows Media Player encountered an error while erasing the rewritable CD or DVD. Verify that the CD or DVD burner is connected properly and that the disc is clean and not damaged.",
            MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY => "Windows Media Player cannot erase the rewritable CD or DVD. Verify that the CD or DVD burner is connected properly and that the disc is clean and not damaged. If the burner is already in use, wait until the current task finishes or quit other programs that might be using the burner.",
            MEDIASERVER::NS_E_WMP_DRM_COMPONENT_FAILURE => "A Windows Media Digital Rights Management (DRM) component encountered a problem. If you are trying to use a file that you obtained from an online store, try going to the online store and getting the appropriate usage rights.",
            MEDIASERVER::NS_E_WMP_DRM_NO_DEVICE_CERT => "It is not possible to obtain device's certificate. Please contact the device manufacturer for a firmware update or for other steps to resolve this problem.",
            MEDIASERVER::NS_E_WMP_SERVER_SECURITY_ERROR => "Windows Media Player encountered an error when connecting to the server. The security information from the server could not be validated.",
            MEDIASERVER::NS_E_WMP_AUDIO_DEVICE_LOST => "An audio device was disconnected or reconfigured. Verify that the audio device is connected, and then try to play the item again.",
            MEDIASERVER::NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE => "Windows Media Player could not complete burning because the disc is not compatible with your drive. Try inserting a different kind of recordable media or use a disc that supports a write speed that is compatible with your drive.",
            MEDIASERVER::NS_E_SYNCWIZ_DEVICE_FULL => "Windows Media Player cannot save the sync settings because your device is full. Delete some unneeded files on your device and then try again.",
            MEDIASERVER::NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS => "It is not possible to change sync settings at this time. Try again later.",
            MEDIASERVER::NS_E_TRANSCODE_DELETECACHEERROR => "Windows Media Player cannot delete these files currently. If the Player is synchronizing, wait until it is complete and then try again.",
            MEDIASERVER::NS_E_CD_NO_BUFFERS_READ => "Windows Media Player could not use digital mode to read the CD. The Player has automatically switched the CD drive to analog mode. To switch back to digital mode, use the Devices tab. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_CD_EMPTY_TRACK_QUEUE => "No CD track was specified for playback.",
            MEDIASERVER::NS_E_CD_NO_READER => "The CD filter was not able to create the CD reader.",
            MEDIASERVER::NS_E_CD_ISRC_INVALID => "Invalid ISRC code.",
            MEDIASERVER::NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID => "Invalid Media Catalog Number.",
            MEDIASERVER::NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION => "Windows Media Player cannot play audio CDs correctly because the CD drive is slow and error correction is turned on. To increase performance, turn off playback error correction for this drive.",
            MEDIASERVER::NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS => "Windows Media Player cannot estimate the CD drive's playback speed because the CD track is too short.",
            MEDIASERVER::NS_E_CD_QUEUEING_DISABLED => "Cannot queue the CD track because queuing is not enabled.",
            MEDIASERVER::NS_E_WMP_DRM_ACQUIRING_LICENSE => "Windows Media Player cannot download additional media usage rights until the current download is complete.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_EXPIRED => "The media usage rights for this file have expired or are no longer valid. If you obtained the file from an online store, sign in to the store, and then try again.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTACQUIRED => "Windows Media Player cannot download the media usage rights for the file. If you obtained the file from an online store, sign in to the store, and then try again.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTENABLED => "The media usage rights for this file are not yet valid. To see when they will become valid, right-click the file in the library, click Properties, and then click the Media Usage Rights tab.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_UNUSABLE => "The media usage rights for this file are not valid. If you obtained this file from an online store, contact the store for assistance.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED => "The content provider has revoked the media usage rights for this file. If you obtained this file from an online store, ask the store if a new version of the file is available.",
            MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOSAP => "The media usage rights for this file require a feature that is not supported in your current version of Windows Media Player or your current version of Windows. Try installing the latest version of the Player. If you obtained this file from an online store, contact the store for further assistance.",
            MEDIASERVER::NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE => "Windows Media Player cannot download media usage rights at this time. Try again later.",
            MEDIASERVER::NS_E_WMP_LICENSE_REQUIRED => "Windows Media Player cannot play, burn, or sync the file because the media usage rights are missing. If you obtained the file from an online store, sign in to the store, and then try again.",
            MEDIASERVER::NS_E_WMP_PROTECTED_CONTENT => "Windows Media Player cannot play, burn, or sync the file because the media usage rights are missing. If you obtained the file from an online store, sign in to the store, and then try again.",
            MEDIASERVER::NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED => "Windows Media Player cannot read a policy. This can occur when the policy does not exist in the registry or when the registry cannot be read.",
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_INTERNET => "Windows Media Player cannot sync content streamed directly from the Internet. If possible, download the file to your computer, and then try to sync the file.",
            MEDIASERVER::NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST => "This playlist is not valid or is corrupted. Create a new playlist using Windows Media Player, then sync the new playlist instead.",
            MEDIASERVER::NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE => "Windows Media Player encountered a problem while synchronizing the file to the device. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_PDA_SYNC_FAILED => "Windows Media Player encountered an error while synchronizing to the device.",
            MEDIASERVER::NS_E_PDA_DELETE_FAILED => "Windows Media Player cannot delete a file from the device.",
            MEDIASERVER::NS_E_PDA_FAILED_TO_RETRIEVE_FILE => "Windows Media Player cannot copy a file from the device to your library.",
            MEDIASERVER::NS_E_PDA_DEVICE_NOT_RESPONDING => "Windows Media Player cannot communicate with the device because the device is not responding. Try reconnecting the device, resetting the device, or contacting the device manufacturer for updated firmware.",
            MEDIASERVER::NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO => "Windows Media Player cannot sync the picture to the device because a problem occurred while converting the file to another quality level or format. The original file might be damaged or corrupted.",
            MEDIASERVER::NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE => "Windows Media Player cannot convert the file. The file might have been encrypted by the Encrypted File System (EFS). Try decrypting the file first and then synchronizing it. For information about how to decrypt a file, see Windows Help and Support.",
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO => "Your device requires that this file be converted in order to play on the device. However, the device either does not support playing audio, or Windows Media Player cannot convert the file to an audio format that is supported by the device.",
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO => "Your device requires that this file be converted in order to play on the device. However, the device either does not support playing video, or Windows Media Player cannot convert the file to a video format that is supported by the device.",
            MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE => "Your device requires that this file be converted in order to play on the device. However, the device either does not support displaying pictures, or Windows Media Player cannot convert the file to a picture format that is supported by the device.",
            MEDIASERVER::NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG => "Windows Media Player cannot sync the file to your computer because the file name is too long. Try renaming the file on the device.",
            MEDIASERVER::NS_E_PDA_CEWMDM_DRM_ERROR => "Windows Media Player cannot sync the file because the device is not responding. This typically occurs when there is a problem with the device firmware. For additional assistance, click Web Help.",
            MEDIASERVER::NS_E_INCOMPLETE_PLAYLIST => "Incomplete playlist.",
            MEDIASERVER::NS_E_PDA_SYNC_RUNNING => "It is not possible to perform the requested action because sync is in progress. You can either stop sync or wait for it to complete, and then try again.",
            MEDIASERVER::NS_E_PDA_SYNC_LOGIN_ERROR => "Windows Media Player cannot sync the subscription content because you are not signed in to the online store that provided it. Sign in to the online store, and then try again.",
            MEDIASERVER::NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND => "Windows Media Player cannot convert the file to the format required by the device. One or more codecs required to convert the file could not be found.",
            MEDIASERVER::NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE => "It is not possible to sync subscription files to this device.",
            MEDIASERVER::NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING => "Your device is operating slowly or is not responding. Until the device responds, it is not possible to sync again. To return the device to normal operation, try disconnecting it from the computer or resetting it.",
            MEDIASERVER::NS_E_WMP_HWND_NOTFOUND => "The Windows Media Player download manager cannot function properly because the Player main window cannot be found. Try restarting the Player.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_WRONG_NO_FILES => "Windows Media Player encountered a download that has the wrong number of files. This might occur if another program is trying to create jobs with the same signature as the Player.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB => "Windows Media Player tried to complete a download that was already canceled. The file will not be available.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB => "Windows Media Player tried to cancel a download that was already completed. The file will not be removed.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_NOJOBPOINTER => "Windows Media Player is trying to access a download that is not valid.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE => "This download was not created by Windows Media Player.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE => "The Windows Media Player download manager cannot create a temporary file name. This might occur if the path is not valid or if the disk is full.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE => "The Windows Media Player download manager plug-in cannot start. This might occur if the system is out of resources.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE => "The Windows Media Player download manager cannot move the file.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCFAILED => "The Windows Media Player download manager cannot perform a task because the system has no resources to allocate.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT => "The Windows Media Player download manager cannot perform a task because the task took too long to run.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCENDED => "The Windows Media Player download manager cannot perform a task because the Player is terminating the service. The task will be recovered when the Player restarts.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_WMDUNPACKFAILED => "The Windows Media Player download manager cannot expand a WMD file. The file will be deleted and the operation will not be completed successfully.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_FAILEDINITIALIZE => "The Windows Media Player download manager cannot start. This might occur if the system is out of resources.",
            MEDIASERVER::NS_E_INTERFACE_NOT_REGISTERED_IN_GIT => "Windows Media Player cannot access a required functionality. This might occur if the wrong system files or Player DLLs are loaded.",
            MEDIASERVER::NS_E_BKGDOWNLOAD_INVALID_FILE_NAME => "Windows Media Player cannot get the file name of the requested download. The requested download will be canceled.",
            MEDIASERVER::NS_E_IMAGE_DOWNLOAD_FAILED => "Windows Media Player encountered an error while downloading an image.",
            MEDIASERVER::NS_E_WMP_UDRM_NOUSERLIST => "Windows Media Player cannot update your media usage rights because the Player cannot verify the list of activated users of this computer.",
            MEDIASERVER::NS_E_WMP_DRM_NOT_ACQUIRING => "Windows Media Player is trying to acquire media usage rights for a file that is no longer being used. Rights acquisition will stop.",
            MEDIASERVER::NS_E_WMP_BSTR_TOO_LONG => "The parameter is not valid.",
            MEDIASERVER::NS_E_WMP_AUTOPLAY_INVALID_STATE => "The state is not valid for this request.",
            MEDIASERVER::NS_E_WMP_COMPONENT_REVOKED => "Windows Media Player cannot play this file until you complete the software component upgrade. After the component has been upgraded, try to play the file again.",
            MEDIASERVER::NS_E_CURL_NOTSAFE => "The URL is not safe for the operation specified.",
            MEDIASERVER::NS_E_CURL_INVALIDCHAR => "The URL contains one or more characters that are not valid.",
            MEDIASERVER::NS_E_CURL_INVALIDHOSTNAME => "The URL contains a host name that is not valid.",
            MEDIASERVER::NS_E_CURL_INVALIDPATH => "The URL contains a path that is not valid.",
            MEDIASERVER::NS_E_CURL_INVALIDSCHEME => "The URL contains a scheme that is not valid.",
            MEDIASERVER::NS_E_CURL_INVALIDURL => "The URL is not valid.",
            MEDIASERVER::NS_E_CURL_CANTWALK => "Windows Media Player cannot play the file. If you clicked a link on a web page, the link might not be valid.",
            MEDIASERVER::NS_E_CURL_INVALIDPORT => "The URL port is not valid.",
            MEDIASERVER::NS_E_CURLHELPER_NOTADIRECTORY => "The URL is not a directory.",
            MEDIASERVER::NS_E_CURLHELPER_NOTAFILE => "The URL is not a file.",
            MEDIASERVER::NS_E_CURL_CANTDECODE => "The URL contains characters that cannot be decoded. The URL might be truncated or incomplete.",
            MEDIASERVER::NS_E_CURLHELPER_NOTRELATIVE => "The specified URL is not a relative URL.",
            MEDIASERVER::NS_E_CURL_INVALIDBUFFERSIZE => "The buffer is smaller than the size specified.",
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED => "The content provider has not granted you the right to play this file. Go to the content provider's online store to get play rights.",
            MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES => "Windows Media Player cannot purchase or download content from multiple online stores.",
            MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT => "The file cannot be purchased or downloaded. The file might not be available from the online store.",
            MEDIASERVER::NS_E_NOT_CONTENT_PARTNER_TRACK => "The provider of this file cannot be identified.",
            MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE => "The file is only available for download when you buy the entire album.",
            MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE => "You must buy the file before you can download it.",
            MEDIASERVER::NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED => "You have exceeded the maximum number of files that can be purchased in a single transaction.",
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED => "Windows Media Player cannot sign in to the online store. Verify that you are using the correct user name and password. If the problem persists, the store might be temporarily unavailable.",
            MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT => "Windows Media Player cannot download this item because the server is not responding. The server might be temporarily unavailable or the Internet connection might be lost.",
            MEDIASERVER::NS_E_CONTENT_PARTNER_STILL_INITIALIZING => "Content Partner still initializing.",
            MEDIASERVER::NS_E_OPEN_CONTAINING_FOLDER_FAILED => "The folder could not be opened. The folder might have been moved or deleted.",
            MEDIASERVER::NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES => "Windows Media Player could not add all of the images to the file because the images exceeded the 7 megabyte (MB) limit.",
            MEDIASERVER::NS_E_REDIRECT => "The client redirected to another server.",
            MEDIASERVER::NS_E_STALE_PRESENTATION => "The streaming media description is no longer current.",
            MEDIASERVER::NS_E_NAMESPACE_WRONG_PERSIST => "It is not possible to create a persistent namespace node under a transient parent node.",
            MEDIASERVER::NS_E_NAMESPACE_WRONG_TYPE => "It is not possible to store a value in a namespace node that has a different value type.",
            MEDIASERVER::NS_E_NAMESPACE_NODE_CONFLICT => "It is not possible to remove the root namespace node.",
            MEDIASERVER::NS_E_NAMESPACE_NODE_NOT_FOUND => "The specified namespace node could not be found.",
            MEDIASERVER::NS_E_NAMESPACE_BUFFER_TOO_SMALL => "The buffer supplied to hold namespace node string is too small.",
            MEDIASERVER::NS_E_NAMESPACE_TOO_MANY_CALLBACKS => "The callback list on a namespace node is at the maximum size.",
            MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_CALLBACK => "It is not possible to register an already-registered callback on a namespace node.",
            MEDIASERVER::NS_E_NAMESPACE_CALLBACK_NOT_FOUND => "Cannot find the callback in the namespace when attempting to remove the callback.",
            MEDIASERVER::NS_E_NAMESPACE_NAME_TOO_LONG => "The namespace node name exceeds the allowed maximum length.",
            MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_NAME => "Cannot create a namespace node that already exists.",
            MEDIASERVER::NS_E_NAMESPACE_EMPTY_NAME => "The namespace node name cannot be a null string.",
            MEDIASERVER::NS_E_NAMESPACE_INDEX_TOO_LARGE => "Finding a child namespace node by index failed because the index exceeded the number of children.",
            MEDIASERVER::NS_E_NAMESPACE_BAD_NAME => "The namespace node name is invalid.",
            MEDIASERVER::NS_E_NAMESPACE_WRONG_SECURITY => "It is not possible to store a value in a namespace node that has a different security type.",
            MEDIASERVER::NS_E_CACHE_ARCHIVE_CONFLICT => "The archive request conflicts with other requests in progress.",
            MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND => "The specified origin server cannot be found.",
            MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_TIMEOUT => "The specified origin server is not responding.",
            MEDIASERVER::NS_E_CACHE_NOT_BROADCAST => "The internal code for HTTP status code 412 Precondition Failed due to not broadcast type.",
            MEDIASERVER::NS_E_CACHE_CANNOT_BE_CACHED => "The internal code for HTTP status code 403 Forbidden due to not cacheable.",
            MEDIASERVER::NS_E_CACHE_NOT_MODIFIED => "The internal code for HTTP status code 304 Not Modified.",
            MEDIASERVER::NS_E_CANNOT_REMOVE_PUBLISHING_POINT => "It is not possible to remove a cache or proxy publishing point.",
            MEDIASERVER::NS_E_CANNOT_REMOVE_PLUGIN => "It is not possible to remove the last instance of a type of plug-in.",
            MEDIASERVER::NS_E_WRONG_PUBLISHING_POINT_TYPE => "Cache and proxy publishing points do not support this property or method.",
            MEDIASERVER::NS_E_UNSUPPORTED_LOAD_TYPE => "The plug-in does not support the specified load type.",
            MEDIASERVER::NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION => "The plug-in does not support any load types. The plug-in must support at least one load type.",
            MEDIASERVER::NS_E_INVALID_PUBLISHING_POINT_NAME => "The publishing point name is invalid.",
            MEDIASERVER::NS_E_TOO_MANY_MULTICAST_SINKS => "Only one multicast data writer plug-in can be enabled for a publishing point.",
            MEDIASERVER::NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED => "The requested operation cannot be completed while the publishing point is started.",
            MEDIASERVER::NS_E_MULTICAST_PLUGIN_NOT_ENABLED => "A multicast data writer plug-in must be enabled in order for this operation to be completed.",
            MEDIASERVER::NS_E_INVALID_OPERATING_SYSTEM_VERSION => "This feature requires Windows Server 2003, Enterprise Edition.",
            MEDIASERVER::NS_E_PUBLISHING_POINT_REMOVED => "The requested operation cannot be completed because the specified publishing point has been removed.",
            MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST => "Push publishing points are started when the encoder starts pushing the stream. This publishing point cannot be started by the server administrator.",
            MEDIASERVER::NS_E_UNSUPPORTED_LANGUAGE => "The specified language is not supported.",
            MEDIASERVER::NS_E_WRONG_OS_VERSION => "Windows Media Services will only run on Windows Server 2003, Standard Edition and Windows Server 2003, Enterprise Edition.",
            MEDIASERVER::NS_E_PUBLISHING_POINT_STOPPED => "The operation cannot be completed because the publishing point has been stopped.",
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING => "The playlist entry is already playing.",
            MEDIASERVER::NS_E_EMPTY_PLAYLIST => "The playlist or directory you are requesting does not contain content.",
            MEDIASERVER::NS_E_PLAYLIST_PARSE_FAILURE => "The server was unable to parse the requested playlist file.",
            MEDIASERVER::NS_E_PLAYLIST_UNSUPPORTED_ENTRY => "The requested operation is not supported for this type of playlist entry.",
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST => "Cannot jump to a playlist entry that is not inserted in the playlist.",
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_SEEK => "Cannot seek to the desired playlist entry.",
            MEDIASERVER::NS_E_PLAYLIST_RECURSIVE_PLAYLISTS => "Cannot play recursive playlist.",
            MEDIASERVER::NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS => "The number of nested playlists exceeded the limit the server can handle.",
            MEDIASERVER::NS_E_PLAYLIST_SHUTDOWN => "Cannot execute the requested operation because the playlist has been shut down by the Media Server.",
            MEDIASERVER::NS_E_PLAYLIST_END_RECEDING => "The playlist has ended while receding.",
            MEDIASERVER::NS_E_DATAPATH_NO_SINK => "The data path does not have an associated data writer plug-in.",
            MEDIASERVER::NS_E_INVALID_PUSH_TEMPLATE => "The specified push template is invalid.",
            MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT => "The specified push publishing point is invalid.",
            MEDIASERVER::NS_E_CRITICAL_ERROR => "The requested operation cannot be performed because the server or publishing point is in a critical error state.",
            MEDIASERVER::NS_E_NO_NEW_CONNECTIONS => "The content cannot be played because the server is not currently accepting connections. Try connecting at a later time.",
            MEDIASERVER::NS_E_WSX_INVALID_VERSION => "The version of this playlist is not supported by the server.",
            MEDIASERVER::NS_E_HEADER_MISMATCH => "The command does not apply to the current media header user by a server component.",
            MEDIASERVER::NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME => "The specified publishing point name is already in use.",
            MEDIASERVER::NS_E_NO_SCRIPT_ENGINE => "There is no script engine available for this file.",
            MEDIASERVER::NS_E_PLUGIN_ERROR_REPORTED => "The plug-in has reported an error. See the Troubleshooting tab or the NT Application Event Log for details.",
            MEDIASERVER::NS_E_SOURCE_PLUGIN_NOT_FOUND => "No enabled data source plug-in is available to access the requested content.",
            MEDIASERVER::NS_E_PLAYLIST_PLUGIN_NOT_FOUND => "No enabled playlist parser plug-in is available to access the requested content.",
            MEDIASERVER::NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED => "The data source plug-in does not support enumeration.",
            MEDIASERVER::NS_E_MEDIA_PARSER_INVALID_FORMAT => "The server cannot stream the selected file because it is either damaged or corrupt. Select a different file.",
            MEDIASERVER::NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED => "The plug-in cannot be enabled because a compatible script debugger is not installed on this system. Install a script debugger, or disable the script debugger option on the general tab of the plug-in's properties page and try again.",
            MEDIASERVER::NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER => "The plug-in cannot be loaded because it requires Windows Server 2003, Enterprise Edition.",
            MEDIASERVER::NS_E_WIZARD_RUNNING => "Another wizard is currently running. Please close the other wizard or wait until it finishes before attempting to run this wizard again.",
            MEDIASERVER::NS_E_INVALID_LOG_URL => "Invalid log URL. Multicast logging URL must look like 'http://servername/isapibackend.dll'.",
            MEDIASERVER::NS_E_INVALID_MTU_RANGE => "Invalid MTU specified. The valid range for maximum packet size is between 36 and 65507 bytes.",
            MEDIASERVER::NS_E_INVALID_PLAY_STATISTICS => "Invalid play statistics for logging.",
            MEDIASERVER::NS_E_LOG_NEED_TO_BE_SKIPPED => "The log needs to be skipped.",
            MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED => "The size of the data exceeded the limit the WMS HTTP Download Data Source plugin can handle.",
            MEDIASERVER::NS_E_PORT_IN_USE => "One usage of each socket address (protocol/network address/port) is permitted. Verify that other services or applications are not attempting to use the same port and then try to enable the plug-in again.",
            MEDIASERVER::NS_E_PORT_IN_USE_HTTP => "One usage of each socket address (protocol/network address/port) is permitted. Verify that other services (such as IIS) or applications are not attempting to use the same port and then try to enable the plug-in again.",
            MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE => "The WMS HTTP Download Data Source plugin was unable to receive the remote server's response.",
            MEDIASERVER::NS_E_ARCHIVE_REACH_QUOTA => "The archive plug-in has reached its quota.",
            MEDIASERVER::NS_E_ARCHIVE_ABORT_DUE_TO_BCAST => "The archive plug-in aborted because the source was from broadcast.",
            MEDIASERVER::NS_E_ARCHIVE_GAP_DETECTED => "The archive plug-in detected an interrupt in the source.",
            MEDIASERVER::NS_E_AUTHORIZATION_FILE_NOT_FOUND => "The system cannot find the file specified.",
            MEDIASERVER::NS_E_BAD_MARKIN => "The mark-in time should be greater than 0 and less than the mark-out time.",
            MEDIASERVER::NS_E_BAD_MARKOUT => "The mark-out time should be greater than the mark-in time and less than the file duration.",
            MEDIASERVER::NS_E_NOMATCHING_MEDIASOURCE => "No matching media type is found in the source %1.",
            MEDIASERVER::NS_E_UNSUPPORTED_SOURCETYPE => "The specified source type is not supported.",
            MEDIASERVER::NS_E_TOO_MANY_AUDIO => "It is not possible to specify more than one audio input.",
            MEDIASERVER::NS_E_TOO_MANY_VIDEO => "It is not possible to specify more than two video inputs.",
            MEDIASERVER::NS_E_NOMATCHING_ELEMENT => "No matching element is found in the list.",
            MEDIASERVER::NS_E_MISMATCHED_MEDIACONTENT => "The profile's media types must match the media types defined for the session.",
            MEDIASERVER::NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP => "It is not possible to remove an active source while encoding.",
            MEDIASERVER::NS_E_AUDIODEVICE_BUSY => "It is not possible to open the specified audio capture device because it is currently in use.",
            MEDIASERVER::NS_E_AUDIODEVICE_UNEXPECTED => "It is not possible to open the specified audio capture device because an unexpected error has occurred.",
            MEDIASERVER::NS_E_AUDIODEVICE_BADFORMAT => "The audio capture device does not support the specified audio format.",
            MEDIASERVER::NS_E_VIDEODEVICE_BUSY => "It is not possible to open the specified video capture device because it is currently in use.",
            MEDIASERVER::NS_E_VIDEODEVICE_UNEXPECTED => "It is not possible to open the specified video capture device because an unexpected error has occurred.",
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING => "This operation is not allowed while encoding.",
            MEDIASERVER::NS_E_NO_PROFILE_IN_SOURCEGROUP => "No profile is set for the source.",
            MEDIASERVER::NS_E_VIDEODRIVER_UNSTABLE => "The video capture driver returned an unrecoverable error. It is now in an unstable state.",
            MEDIASERVER::NS_E_VIDCAPSTARTFAILED => "It was not possible to start the video device.",
            MEDIASERVER::NS_E_VIDSOURCECOMPRESSION => "The video source does not support the requested output format or color depth.",
            MEDIASERVER::NS_E_VIDSOURCESIZE => "The video source does not support the requested capture size.",
            MEDIASERVER::NS_E_ICMQUERYFORMAT => "It was not possible to obtain output information from the video compressor.",
            MEDIASERVER::NS_E_VIDCAPCREATEWINDOW => "It was not possible to create a video capture window.",
            MEDIASERVER::NS_E_VIDCAPDRVINUSE => "There is already a stream active on this video device.",
            MEDIASERVER::NS_E_NO_MEDIAFORMAT_IN_SOURCE => "No media format is set in source.",
            MEDIASERVER::NS_E_NO_VALID_OUTPUT_STREAM => "Cannot find a valid output stream from the source.",
            MEDIASERVER::NS_E_NO_VALID_SOURCE_PLUGIN => "It was not possible to find a valid source plug-in for the specified source.",
            MEDIASERVER::NS_E_NO_ACTIVE_SOURCEGROUP => "No source is currently active.",
            MEDIASERVER::NS_E_NO_SCRIPT_STREAM => "No script stream is set in the current source.",
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING => "This operation is not allowed while archiving.",
            MEDIASERVER::NS_E_INVALIDPACKETSIZE => "The setting for the maximum packet size is not valid.",
            MEDIASERVER::NS_E_PLUGIN_CLSID_INVALID => "The plug-in CLSID specified is not valid.",
            MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVETYPE => "This archive type is not supported.",
            MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVEOPERATION => "This archive operation is not supported.",
            MEDIASERVER::NS_E_ARCHIVE_FILENAME_NOTSET => "The local archive file name was not set.",
            MEDIASERVER::NS_E_SOURCEGROUP_NOTPREPARED => "The source is not yet prepared.",
            MEDIASERVER::NS_E_PROFILE_MISMATCH => "Profiles on the sources do not match.",
            MEDIASERVER::NS_E_INCORRECTCLIPSETTINGS => "The specified crop values are not valid.",
            MEDIASERVER::NS_E_NOSTATSAVAILABLE => "No statistics are available at this time.",
            MEDIASERVER::NS_E_NOTARCHIVING => "The encoder is not archiving.",
            MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED => "This operation is only allowed during encoding.",
            MEDIASERVER::NS_E_NOSOURCEGROUPS => "This SourceGroupCollection doesn't contain any SourceGroups.",
            MEDIASERVER::NS_E_INVALIDINPUTFPS => "This source does not have a frame rate of 30 fps. Therefore, it is not possible to apply the inverse telecine filter to the source.",
            MEDIASERVER::NS_E_NO_DATAVIEW_SUPPORT => "It is not possible to display your source or output video in the Video panel.",
            MEDIASERVER::NS_E_CODEC_UNAVAILABLE => "One or more codecs required to open this content could not be found.",
            MEDIASERVER::NS_E_ARCHIVE_SAME_AS_INPUT => "The archive file has the same name as an input file. Change one of the names before continuing.",
            MEDIASERVER::NS_E_SOURCE_NOTSPECIFIED => "The source has not been set up completely.",
            MEDIASERVER::NS_E_NO_REALTIME_TIMECOMPRESSION => "It is not possible to apply time compression to a broadcast session.",
            MEDIASERVER::NS_E_UNSUPPORTED_ENCODER_DEVICE => "It is not possible to open this device.",
            MEDIASERVER::NS_E_UNEXPECTED_DISPLAY_SETTINGS => "It is not possible to start encoding because the display size or color has changed since the current session was defined. Restore the previous settings or create a new session.",
            MEDIASERVER::NS_E_NO_AUDIODATA => "No audio data has been received for several seconds. Check the audio source and restart the encoder.",
            MEDIASERVER::NS_E_INPUTSOURCE_PROBLEM => "One or all of the specified sources are not working properly. Check that the sources are configured correctly.",
            MEDIASERVER::NS_E_WME_VERSION_MISMATCH => "The supplied configuration file is not supported by this version of the encoder.",
            MEDIASERVER::NS_E_NO_REALTIME_PREPROCESS => "It is not possible to use image preprocessing with live encoding.",
            MEDIASERVER::NS_E_NO_REPEAT_PREPROCESS => "It is not possible to use two-pass encoding when the source is set to loop.",
            MEDIASERVER::NS_E_CANNOT_PAUSE_LIVEBROADCAST => "It is not possible to pause encoding during a broadcast.",
            MEDIASERVER::NS_E_DRM_PROFILE_NOT_SET => "A DRM profile has not been set for the current session.",
            MEDIASERVER::NS_E_DUPLICATE_DRMPROFILE => "The profile ID is already used by a DRM profile. Specify a different profile ID.",
            MEDIASERVER::NS_E_INVALID_DEVICE => "The setting of the selected device does not support control for playing back tapes.",
            MEDIASERVER::NS_E_SPEECHEDL_ON_NON_MIXEDMODE => "You must specify a mixed voice and audio mode in order to use an optimization definition file.",
            MEDIASERVER::NS_E_DRM_PASSWORD_TOO_LONG => "The specified password is too long. Type a password with fewer than 8 characters.",
            MEDIASERVER::NS_E_DEVCONTROL_FAILED_SEEK => "It is not possible to seek to the specified mark-in point.",
            MEDIASERVER::NS_E_INTERLACE_REQUIRE_SAMESIZE => "When you choose to maintain the interlacing in your video, the output video size must match the input video size.",
            MEDIASERVER::NS_E_TOO_MANY_DEVICECONTROL => "Only one device control plug-in can control a device.",
            MEDIASERVER::NS_E_NO_MULTIPASS_FOR_LIVEDEVICE => "You must also enable storing content to hard disk temporarily in order to use two-pass encoding with the input device.",
            MEDIASERVER::NS_E_MISSING_AUDIENCE => "An audience is missing from the output stream configuration.",
            MEDIASERVER::NS_E_AUDIENCE_CONTENTTYPE_MISMATCH => "All audiences in the output tree must have the same content type.",
            MEDIASERVER::NS_E_MISSING_SOURCE_INDEX => "A source index is missing from the output stream configuration.",
            MEDIASERVER::NS_E_NUM_LANGUAGE_MISMATCH => "The same source index in different audiences should have the same number of languages.",
            MEDIASERVER::NS_E_LANGUAGE_MISMATCH => "The same source index in different audiences should have the same languages.",
            MEDIASERVER::NS_E_VBRMODE_MISMATCH => "The same source index in different audiences should use the same VBR encoding mode.",
            MEDIASERVER::NS_E_INVALID_INPUT_AUDIENCE_INDEX => "The bit rate index specified is not valid.",
            MEDIASERVER::NS_E_INVALID_INPUT_LANGUAGE => "The specified language is not valid.",
            MEDIASERVER::NS_E_INVALID_INPUT_STREAM => "The specified source type is not valid.",
            MEDIASERVER::NS_E_EXPECT_MONO_WAV_INPUT => "The source must be a mono channel .wav file.",
            MEDIASERVER::NS_E_INPUT_WAVFORMAT_MISMATCH => "All the source .wav files must have the same format.",
            MEDIASERVER::NS_E_RECORDQ_DISK_FULL => "The hard disk being used for temporary storage of content has reached the minimum allowed disk space. Create more space on the hard disk and restart encoding.",
            MEDIASERVER::NS_E_NO_PAL_INVERSE_TELECINE => "It is not possible to apply the inverse telecine feature to PAL content.",
            MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_DISCONNECTED => "A capture device in the current active source is no longer available.",
            MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED => "A device used in the current active source for device control is no longer available.",
            MEDIASERVER::NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER => "No frames have been submitted to the analyzer for analysis.",
            MEDIASERVER::NS_E_INPUT_DOESNOT_SUPPORT_SMPTE => "The source video does not support time codes.",
            MEDIASERVER::NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS => "It is not possible to generate a time code when there are multiple sources in a session.",
            MEDIASERVER::NS_E_BAD_CONTENTEDL => "The voice codec optimization definition file cannot be found or is corrupted.",
            MEDIASERVER::NS_E_INTERLACEMODE_MISMATCH => "The same source index in different audiences should have the same interlace mode.",
            MEDIASERVER::NS_E_NONSQUAREPIXELMODE_MISMATCH => "The same source index in different audiences should have the same nonsquare pixel mode.",
            MEDIASERVER::NS_E_SMPTEMODE_MISMATCH => "The same source index in different audiences should have the same time code mode.",
            MEDIASERVER::NS_E_END_OF_TAPE => "Either the end of the tape has been reached or there is no tape. Check the device and tape.",
            MEDIASERVER::NS_E_NO_MEDIA_IN_AUDIENCE => "No audio or video input has been specified.",
            MEDIASERVER::NS_E_NO_AUDIENCES => "The profile must contain a bit rate.",
            MEDIASERVER::NS_E_NO_AUDIO_COMPAT => "You must specify at least one audio stream to be compatible with Windows Media Player 7.1.",
            MEDIASERVER::NS_E_INVALID_VBR_COMPAT => "Using a VBR encoding mode is not compatible with Windows Media Player 7.1.",
            MEDIASERVER::NS_E_NO_PROFILE_NAME => "You must specify a profile name.",
            MEDIASERVER::NS_E_INVALID_VBR_WITH_UNCOMP => "It is not possible to use a VBR encoding mode with uncompressed audio or video.",
            MEDIASERVER::NS_E_MULTIPLE_VBR_AUDIENCES => "It is not possible to use MBR encoding with VBR encoding.",
            MEDIASERVER::NS_E_UNCOMP_COMP_COMBINATION => "It is not possible to mix uncompressed and compressed content in a session.",
            MEDIASERVER::NS_E_MULTIPLE_AUDIO_CODECS => "All audiences must use the same audio codec.",
            MEDIASERVER::NS_E_MULTIPLE_AUDIO_FORMATS => "All audiences should use the same audio format to be compatible with Windows Media Player 7.1.",
            MEDIASERVER::NS_E_AUDIO_BITRATE_STEPDOWN => "The audio bit rate for an audience with a higher total bit rate must be greater than one with a lower total bit rate.",
            MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE => "The audio peak bit rate setting is not valid.",
            MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE_2 => "The audio peak bit rate setting must be greater than the audio bit rate setting.",
            MEDIASERVER::NS_E_INVALID_AUDIO_BUFFERMAX => "The setting for the maximum buffer size for audio is not valid.",
            MEDIASERVER::NS_E_MULTIPLE_VIDEO_CODECS => "All audiences must use the same video codec.",
            MEDIASERVER::NS_E_MULTIPLE_VIDEO_SIZES => "All audiences should use the same video size to be compatible with Windows Media Player 7.1.",
            MEDIASERVER::NS_E_INVALID_VIDEO_BITRATE => "The video bit rate setting is not valid.",
            MEDIASERVER::NS_E_VIDEO_BITRATE_STEPDOWN => "The video bit rate for an audience with a higher total bit rate must be greater than one with a lower total bit rate.",
            MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE => "The video peak bit rate setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE_2 => "The video peak bit rate setting must be greater than the video bit rate setting.",
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH => "The video width setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT => "The video height setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_FPS => "The video frame rate setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_KEYFRAME => "The video key frame setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_IQUALITY => "The video image quality setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_CQUALITY => "The video codec quality setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFER => "The video buffer setting is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX => "The setting for the maximum buffer size for video is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX_2 => "The value of the video maximum buffer size setting must be greater than the video buffer size setting.",
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_ALIGN => "The alignment of the video width is not valid.",
            MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT_ALIGN => "The alignment of the video height is not valid.",
            MEDIASERVER::NS_E_MULTIPLE_SCRIPT_BITRATES => "All bit rates must have the same script bit rate.",
            MEDIASERVER::NS_E_INVALID_SCRIPT_BITRATE => "The script bit rate specified is not valid.",
            MEDIASERVER::NS_E_MULTIPLE_FILE_BITRATES => "All bit rates must have the same file transfer bit rate.",
            MEDIASERVER::NS_E_INVALID_FILE_BITRATE => "The file transfer bit rate is not valid.",
            MEDIASERVER::NS_E_SAME_AS_INPUT_COMBINATION => "All audiences in a profile should either be same as input or have video width and height specified.",
            MEDIASERVER::NS_E_SOURCE_CANNOT_LOOP => "This source type does not support looping.",
            MEDIASERVER::NS_E_INVALID_FOLDDOWN_COEFFICIENTS => "The fold-down value needs to be between -144 and 0.",
            MEDIASERVER::NS_E_DRMPROFILE_NOTFOUND => "The specified DRM profile does not exist in the system.",
            MEDIASERVER::NS_E_INVALID_TIMECODE => "The specified time code is not valid.",
            MEDIASERVER::NS_E_NO_AUDIO_TIMECOMPRESSION => "It is not possible to apply time compression to a video-only session.",
            MEDIASERVER::NS_E_NO_TWOPASS_TIMECOMPRESSION => "It is not possible to apply time compression to a session that is using two-pass encoding.",
            MEDIASERVER::NS_E_TIMECODE_REQUIRES_VIDEOSTREAM => "It is not possible to generate a time code for an audio-only session.",
            MEDIASERVER::NS_E_NO_MBR_WITH_TIMECODE => "It is not possible to generate a time code when you are encoding content at multiple bit rates.",
            MEDIASERVER::NS_E_INVALID_INTERLACEMODE => "The video codec selected does not support maintaining interlacing in video.",
            MEDIASERVER::NS_E_INVALID_INTERLACE_COMPAT => "Maintaining interlacing in video is not compatible with Windows Media Player 7.1.",
            MEDIASERVER::NS_E_INVALID_NONSQUAREPIXEL_COMPAT => "Allowing nonsquare pixel output is not compatible with Windows Media Player 7.1.",
            MEDIASERVER::NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL => "Only capture devices can be used with device control.",
            MEDIASERVER::NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR => "It is not possible to generate the stream format file if you are using quality-based VBR encoding for the audio or video stream. Instead use the Windows Media file generated after encoding to create the announcement file.",
            MEDIASERVER::NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT => "It is not possible to create a DRM profile because the maximum number of profiles has been reached. You must delete some DRM profiles before creating new ones.",
            MEDIASERVER::NS_E_DEVICECONTROL_UNSTABLE => "The device is in an unstable state. Check that the device is functioning properly and a tape is in place.",
            MEDIASERVER::NS_E_INVALID_PIXEL_ASPECT_RATIO => "The pixel aspect ratio value must be between 1 and 255.",
            MEDIASERVER::NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH => "All streams with different languages in the same audience must have same properties.",
            MEDIASERVER::NS_E_INVALID_PROFILE_CONTENTTYPE => "The profile must contain at least one audio or video stream.",
            MEDIASERVER::NS_E_TRANSFORM_PLUGIN_NOT_FOUND => "The transform plug-in could not be found.",
            MEDIASERVER::NS_E_TRANSFORM_PLUGIN_INVALID => "The transform plug-in is not valid. It might be damaged or you might not have the required permissions to access the plug-in.",
            MEDIASERVER::NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS => "To use two-pass encoding, you must enable device control and setup an edit decision list (EDL) that has at least one entry.",
            MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING => "When you choose to maintain the interlacing in your video, the output video size must be a multiple of 4.",
            MEDIASERVER::NS_E_MARKIN_UNSUPPORTED => "Markin/Markout is unsupported with this source type.",
            MEDIASERVER::NS_E_DRM_INVALID_APPLICATION => "A problem has occurred in the Digital Rights Management component. Contact product support for this application.",
            MEDIASERVER::NS_E_DRM_LICENSE_STORE_ERROR => "License storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_SECURE_STORE_ERROR => "Secure storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_LICENSE_STORE_SAVE_ERROR => "License acquisition did not work. Acquire a new license or contact the content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_SECURE_STORE_UNLOCK_ERROR => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INVALID_CONTENT => "The media file is corrupted. Contact the content provider to get a new file.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_LICENSE => "The license is corrupted. Acquire a new license.",
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE => "The license is corrupted or invalid. Acquire a new license",
            MEDIASERVER::NS_E_DRM_INVALID_MACHINE => "Licenses cannot be copied from one computer to another. Use License Management to transfer licenses, or get a new license for the media file.",
            MEDIASERVER::NS_E_DRM_ENUM_LICENSE_FAILED => "License storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE_REQUEST => "The media file is corrupted. Contact the content provider to get a new file.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_INITIALIZE => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE => "The license could not be acquired. Try again later.",
            MEDIASERVER::NS_E_DRM_INVALID_LICENSE_ACQUIRED => "License acquisition did not work. Acquire a new license or contact the content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_NO_RIGHTS => "The requested operation cannot be performed on this file.",
            MEDIASERVER::NS_E_DRM_KEY_ERROR => "The requested action cannot be performed because a problem occurred with the Windows Media Digital Rights Management (DRM) components on your computer.",
            MEDIASERVER::NS_E_DRM_ENCRYPT_ERROR => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_DECRYPT_ERROR => "The media file is corrupted. Contact the content provider to get a new file.",
            MEDIASERVER::NS_E_DRM_LICENSE_INVALID_XML => "The license is corrupted. Acquire a new license.",
            MEDIASERVER::NS_E_DRM_NEEDS_INDIVIDUALIZATION => "A security upgrade is required to perform the operation on this media file.",
            MEDIASERVER::NS_E_DRM_ALREADY_INDIVIDUALIZED => "You already have the latest security components. No upgrade is necessary at this time.",
            MEDIASERVER::NS_E_DRM_ACTION_NOT_QUERIED => "The application cannot perform this action. Contact product support for this application.",
            MEDIASERVER::NS_E_DRM_ACQUIRING_LICENSE => "You cannot begin a new license acquisition process until the current one has been completed.",
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZING => "You cannot begin a new security upgrade until the current one has been completed.",
            MEDIASERVER::NS_E_BACKUP_RESTORE_FAILURE => "Failure in Backup-Restore.",
            MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_REQUEST_ID => "Bad Request ID in Backup-Restore.",
            MEDIASERVER::NS_E_DRM_PARAMETERS_MISMATCHED => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT => "A license cannot be created for this media file. Reinstall the application.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZE_ERROR => "The security upgrade failed. Try again later.",
            MEDIASERVER::NS_E_DRM_LICENSE_OPEN_ERROR => "License storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_LICENSE_CLOSE_ERROR => "License storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_GET_LICENSE_ERROR => "License storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_QUERY_ERROR => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_REPORT_ERROR => "A problem has occurred in the Digital Rights Management component. Contact product support for this application.",
            MEDIASERVER::NS_E_DRM_GET_LICENSESTRING_ERROR => "License storage is not working. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_GET_CONTENTSTRING_ERROR => "The media file is corrupted. Contact the content provider to get a new file.",
            MEDIASERVER::NS_E_DRM_MONITOR_ERROR => "A problem has occurred in the Digital Rights Management component. Try again later.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_PARAMETER => "The application has made an invalid call to the Digital Rights Management component. Contact product support for this application.",
            MEDIASERVER::NS_E_DRM_INVALID_APPDATA => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INVALID_APPDATA_VERSION => "A problem has occurred in the Digital Rights Management component. Contact product support for this application.",
            MEDIASERVER::NS_E_DRM_BACKUP_EXISTS => "Licenses are already backed up in this location.",
            MEDIASERVER::NS_E_DRM_BACKUP_CORRUPT => "One or more backed-up licenses are missing or corrupt.",
            MEDIASERVER::NS_E_DRM_BACKUPRESTORE_BUSY => "You cannot begin a new backup process until the current process has been completed.",
            MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_DATA => "Bad Data sent to Backup-Restore.",
            MEDIASERVER::NS_E_DRM_LICENSE_UNUSABLE => "The license is invalid. Contact the content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_INVALID_PROPERTY => "A required property was not set by the application. Contact product support for this application.",
            MEDIASERVER::NS_E_DRM_SECURE_STORE_NOT_FOUND => "A problem has occurred in the Digital Rights Management component of this application. Try to acquire a license again.",
            MEDIASERVER::NS_E_DRM_CACHED_CONTENT_ERROR => "A license cannot be found for this media file. Use License Management to transfer a license for this file from the original computer, or acquire a new license.",
            MEDIASERVER::NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE => "A problem occurred during the security upgrade. Try again later.",
            MEDIASERVER::NS_E_DRM_DRIVER_AUTH_FAILURE => "Certified driver components are required to play this media file. Contact Windows Update to see whether updated drivers are available for your hardware.",
            MEDIASERVER::NS_E_DRM_NEED_UPGRADE_MSSAP => "One or more of the Secure Audio Path components were not found or an entry point in those components was not found.",
            MEDIASERVER::NS_E_DRM_REOPEN_CONTENT => "Status message: Reopen the file.",
            MEDIASERVER::NS_E_DRM_DRIVER_DIGIOUT_FAILURE => "Certain driver functionality is required to play this media file. Contact Windows Update to see whether updated drivers are available for your hardware.",
            MEDIASERVER::NS_E_DRM_INVALID_SECURESTORE_PASSWORD => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_APPCERT_REVOKED => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_RESTORE_FRAUD => "You cannot restore your license(s).",
            MEDIASERVER::NS_E_DRM_HARDWARE_INCONSISTENT => "The licenses for your media files are corrupted. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_SDMI_TRIGGER => "To transfer this media file, you must upgrade the application.",
            MEDIASERVER::NS_E_DRM_SDMI_NOMORECOPIES => "You cannot make any more copies of this media file.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_LICENSE_NOTACQUIRED => "Unable to obtain license.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_BUFFER_TOO_SMALL => "The buffer supplied is not sufficient.",
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROPERTY => "The property requested is not supported.",
            MEDIASERVER::NS_E_DRM_ERROR_BAD_NET_RESP => "The specified server cannot perform the requested operation.",
            MEDIASERVER::NS_E_DRM_STORE_NOTALLSTORED => "Some of the licenses could not be stored.",
            MEDIASERVER::NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID => "The Digital Rights Management security upgrade component could not be validated. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INVALID_DATA => "Invalid or corrupt data was encountered.",
            MEDIASERVER::NS_E_DRM_POLICY_DISABLE_ONLINE => "The Windows Media Digital Rights Management system cannot perform the requested action because your computer or network administrator has enabled the group policy Prevent Windows Media DRM Internet Access. For assistance, contact your administrator.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_NOT_CONFIGURED => "Not all of the necessary properties for DRM have been set.",
            MEDIASERVER::NS_E_DRM_DEVICE_ACTIVATION_CANCELED => "The portable device does not have the security required to copy protected files to it. To obtain the additional security, try to copy the file to your portable device again. When a message appears, click OK.",
            MEDIASERVER::NS_E_BACKUP_RESTORE_TOO_MANY_RESETS => "Too many resets in Backup-Restore.",
            MEDIASERVER::NS_E_DRM_DEBUGGING_NOT_ALLOWED => "Running this process under a debugger while using DRM content is not allowed.",
            MEDIASERVER::NS_E_DRM_OPERATION_CANCELED => "The user canceled the DRM operation.",
            MEDIASERVER::NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED => "The license you are using has assocaited output restrictions. This license is unusable until these restrictions are queried.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION => "The specified track has exceeded it's specified playlist burn limit in this playlist.",
            MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION => "The specified track has exceeded it's track burn limit.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT => "A problem has occurred in obtaining the device's certificate. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK => "A problem has occurred in obtaining the device's secure clock. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK => "A problem has occurred in setting the device's secure clock. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER => "A problem has occurred in obtaining the secure clock from server. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_POLICY_METERING_DISABLED => "This content requires the metering policy to be enabled.",
            MEDIASERVER::NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED => "Transfer of chained licenses unsupported.",
            MEDIASERVER::NS_E_DRM_SDK_VERSIONMISMATCH => "The Digital Rights Management component is not installed properly. Reinstall the Player.",
            MEDIASERVER::NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET => "The file could not be transferred because the device clock is not set.",
            MEDIASERVER::NS_E_LICENSE_HEADER_MISSING_URL => "The content header is missing an acquisition URL.",
            MEDIASERVER::NS_E_DEVICE_NOT_WMDRM_DEVICE => "The current attached device does not support WMDRM.",
            MEDIASERVER::NS_E_DRM_INVALID_APPCERT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION => "The client application has been forcefully terminated during a DRM petition.",
            MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE => "The client application has been forcefully terminated during a DRM challenge.",
            MEDIASERVER::NS_E_DRM_CHECKPOINT_FAILED => "Secure storage protection error. Restore your licenses from a previous backup and try again.",
            MEDIASERVER::NS_E_DRM_BB_UNABLE_TO_INITIALIZE => "A problem has occurred in the Digital Rights Management root of trust. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID => "A problem has occurred in retrieving the Digital Rights Management machine identification. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE => "A problem has occurred in opening the Digital Rights Management data storage file. Contact Microsoft product.",
            MEDIASERVER::NS_E_DRM_DATASTORE_CORRUPT => "The Digital Rights Management data storage is not functioning properly. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_STUBLIB_REQUIRED => "A secured library is required to access the requested functionality.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE => "A problem has occurred in the Digital Rights Management component during license migration. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INVALID_MIGRATION_IMAGE => "A problem has occurred in the Digital Rights Management component during license migration. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED => "A problem has occurred in the Digital Rights Management component during license migration. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE => "A problem has occurred in the Digital Rights Management component during license migration. Contact Microsoft product support.",
            MEDIASERVER::NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID => "A problem has occurred in the Digital Rights Management component during license migration. Contact Microsoft product support.",
            MEDIASERVER::NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE => "The Digital Rights Management component is in use during license migration. Contact Microsoft product support.",
            MEDIASERVER::NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH => "Licenses are being migrated to a machine running XP or downlevel OS. This operation can only be performed on Windows Vista or a later OS. Contact Microsoft product support.",
            MEDIASERVER::NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS => "Migration Image already exists. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_HARDWAREID_MISMATCH => "The requested action cannot be performed because a hardware configuration change has been detected by the Windows Media Digital Rights Management (DRM) components on your computer.",
            MEDIASERVER::NS_E_INVALID_DRMV2CLT_STUBLIB => "The wrong stublib has been linked to an application or DLL using drmv2clt.dll.",
            MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA => "The legacy V2 data being imported is invalid.",
            MEDIASERVER::NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS => "The license being imported already exists.",
            MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD => "The password of the Legacy V2 SST entry being imported is incorrect.",
            MEDIASERVER::NS_E_DRM_MIGRATION_NOT_SUPPORTED => "Migration is not supported by the plugin.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT => "A migration importer cannot be created for this media file. Reinstall the application.",
            MEDIASERVER::NS_E_DRM_CHECKPOINT_MISMATCH => "The requested action cannot be performed because a problem occurred with the Windows Media Digital Rights Management (DRM) components on your computer.",
            MEDIASERVER::NS_E_DRM_CHECKPOINT_CORRUPT => "The requested action cannot be performed because a problem occurred with the Windows Media Digital Rights Management (DRM) components on your computer.",
            MEDIASERVER::NS_E_REG_FLUSH_FAILURE => "The requested action cannot be performed because a problem occurred with the Windows Media Digital Rights Management (DRM) components on your computer.",
            MEDIASERVER::NS_E_HDS_KEY_MISMATCH => "The requested action cannot be performed because a problem occurred with the Windows Media Digital Rights Management (DRM) components on your computer.",
            MEDIASERVER::NS_E_DRM_MIGRATION_OPERATION_CANCELLED => "Migration was canceled by the user.",
            MEDIASERVER::NS_E_DRM_MIGRATION_OBJECT_IN_USE => "Migration object is already in use and cannot be called until the current operation completes.",
            MEDIASERVER::NS_E_DRM_MALFORMED_CONTENT_HEADER => "The content header does not comply with DRM requirements and cannot be used.",
            MEDIASERVER::NS_E_DRM_LICENSE_EXPIRED => "The license for this file has expired and is no longer valid. Contact your content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_LICENSE_NOTENABLED => "The license for this file is not valid yet, but will be at a future date.",
            MEDIASERVER::NS_E_DRM_LICENSE_APPSECLOW => "The license for this file requires a higher level of security than the player you are currently using has. Try using a different player or download a newer version of your current player.",
            MEDIASERVER::NS_E_DRM_STORE_NEEDINDI => "The license cannot be stored as it requires security upgrade of Digital Rights Management component.",
            MEDIASERVER::NS_E_DRM_STORE_NOTALLOWED => "Your machine does not meet the requirements for storing the license.",
            MEDIASERVER::NS_E_DRM_LICENSE_APP_NOTALLOWED => "The license for this file requires an upgraded version of your player or a different player.",
            MEDIASERVER::NS_E_DRM_LICENSE_CERT_EXPIRED => "The license server's certificate expired. Make sure your system clock is set correctly. Contact your content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_LICENSE_SECLOW => "The license for this file requires a higher level of security than the player you are currently using has. Try using a different player or download a newer version of your current player.",
            MEDIASERVER::NS_E_DRM_LICENSE_CONTENT_REVOKED => "The content owner for the license you just acquired is no longer supporting their content. Contact the content owner for a newer version of the content.",
            MEDIASERVER::NS_E_DRM_DEVICE_NOT_REGISTERED => "The content owner for the license you just acquired requires your device to register to the current machine.",
            MEDIASERVER::NS_E_DRM_LICENSE_NOSAP => "The license for this file requires a feature that is not supported in your current player or operating system. You can try with newer version of your current player or contact your content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_LICENSE_NOSVP => "The license for this file requires a feature that is not supported in your current player or operating system. You can try with newer version of your current player or contact your content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_LICENSE_NOWDM => "The license for this file requires Windows Driver Model (WDM) audio drivers. Contact your sound card manufacturer for further assistance.",
            MEDIASERVER::NS_E_DRM_LICENSE_NOTRUSTEDCODEC => "The license for this file requires a higher level of security than the player you are currently using has. Try using a different player or download a newer version of your current player.",
            MEDIASERVER::NS_E_DRM_SOURCEID_NOT_SUPPORTED => "The license for this file is not supported by your current player. You can try with newer version of your current player or contact your content provider for further assistance.",
            MEDIASERVER::NS_E_DRM_NEEDS_UPGRADE_TEMPFILE => "An updated version of your media player is required to play the selected content.",
            MEDIASERVER::NS_E_DRM_NEED_UPGRADE_PD => "A new version of the Digital Rights Management component is required. Contact product support for this application to get the latest version.",
            MEDIASERVER::NS_E_DRM_SIGNATURE_FAILURE => "Failed to either create or verify the content header.",
            MEDIASERVER::NS_E_DRM_LICENSE_SERVER_INFO_MISSING => "Could not read the necessary information from the system registry.",
            MEDIASERVER::NS_E_DRM_BUSY => "The DRM subsystem is currently locked by another application or user. Try again later.",
            MEDIASERVER::NS_E_DRM_PD_TOO_MANY_DEVICES => "There are too many target devices registered on the portable media.",
            MEDIASERVER::NS_E_DRM_INDIV_FRAUD => "The security upgrade cannot be completed because the allowed number of daily upgrades has been exceeded. Try again tomorrow.",
            MEDIASERVER::NS_E_DRM_INDIV_NO_CABS => "The security upgrade cannot be completed because the server is unable to perform the operation. Try again later.",
            MEDIASERVER::NS_E_DRM_INDIV_SERVICE_UNAVAILABLE => "The security upgrade cannot be performed because the server is not available. Try again later.",
            MEDIASERVER::NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE => "Windows Media Player cannot restore your licenses because the server is not available. Try again later.",
            MEDIASERVER::NS_E_DRM_CLIENT_CODE_EXPIRED => "Windows Media Player cannot play the protected file. Verify that your computer's date is set correctly. If it is correct, on the Help menu, click Check for Player Updates to install the latest version of the Player.",
            MEDIASERVER::NS_E_DRM_NO_UPLINK_LICENSE => "The chained license cannot be created because the referenced uplink license does not exist.",
            MEDIASERVER::NS_E_DRM_INVALID_KID => "The specified KID is invalid.",
            MEDIASERVER::NS_E_DRM_LICENSE_INITIALIZATION_ERROR => "License initialization did not work. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_CHAIN_TOO_LONG => "The uplink license of a chained license cannot itself be a chained license.",
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_ALGORITHM => "The specified encryption algorithm is unsupported.",
            MEDIASERVER::NS_E_DRM_LICENSE_DELETION_ERROR => "License deletion did not work. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INVALID_CERTIFICATE => "The client's certificate is corrupted or the signature cannot be verified.",
            MEDIASERVER::NS_E_DRM_CERTIFICATE_REVOKED => "The client's certificate has been revoked.",
            MEDIASERVER::NS_E_DRM_LICENSE_UNAVAILABLE => "There is no license available for the requested action.",
            MEDIASERVER::NS_E_DRM_DEVICE_LIMIT_REACHED => "The maximum number of devices in use has been reached. Unable to open additional devices.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY => "The proximity detection procedure could not confirm that the receiver is near the transmitter in the network.",
            MEDIASERVER::NS_E_DRM_MUST_REGISTER => "The client must be registered before executing the intended operation.",
            MEDIASERVER::NS_E_DRM_MUST_APPROVE => "The client must be approved before executing the intended operation.",
            MEDIASERVER::NS_E_DRM_MUST_REVALIDATE => "The client must be revalidated before executing the intended operation.",
            MEDIASERVER::NS_E_DRM_INVALID_PROXIMITY_RESPONSE => "The response to the proximity detection challenge is invalid.",
            MEDIASERVER::NS_E_DRM_INVALID_SESSION => "The requested session is invalid.",
            MEDIASERVER::NS_E_DRM_DEVICE_NOT_OPEN => "The device must be opened before it can be used to receive content.",
            MEDIASERVER::NS_E_DRM_DEVICE_ALREADY_REGISTERED => "Device registration failed because the device is already registered.",
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION => "Unsupported WMDRM-ND protocol version.",
            MEDIASERVER::NS_E_DRM_UNSUPPORTED_ACTION => "The requested action is not supported.",
            MEDIASERVER::NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE => "The certificate does not have an adequate security level for the requested action.",
            MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_PORT => "Unable to open the specified port for receiving Proximity messages.",
            MEDIASERVER::NS_E_DRM_BAD_REQUEST => "The message format is invalid.",
            MEDIASERVER::NS_E_DRM_INVALID_CRL => "The Certificate Revocation List is invalid or corrupted.",
            MEDIASERVER::NS_E_DRM_ATTRIBUTE_TOO_LONG => "The length of the attribute name or value is too long.",
            MEDIASERVER::NS_E_DRM_EXPIRED_LICENSEBLOB => "The license blob passed in the cardea request is expired.",
            MEDIASERVER::NS_E_DRM_INVALID_LICENSEBLOB => "The license blob passed in the cardea request is invalid. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_INCLUSION_LIST_REQUIRED => "The requested operation cannot be performed because the license does not contain an inclusion list.",
            MEDIASERVER::NS_E_DRM_DRMV2CLT_REVOKED => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_DRM_RIV_TOO_SMALL => "A problem has occurred in the Digital Rights Management component. Contact Microsoft product support.",
            MEDIASERVER::NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED => "Windows Media Player does not support the level of output protection required by the content.",
            MEDIASERVER::NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => "Windows Media Player does not support the level of protection required for compressed digital video.",
            MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => "Windows Media Player does not support the level of protection required for uncompressed digital video.",
            MEDIASERVER::NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED => "Windows Media Player does not support the level of protection required for analog video.",
            MEDIASERVER::NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED => "Windows Media Player does not support the level of protection required for compressed digital audio.",
            MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED => "Windows Media Player does not support the level of protection required for uncompressed digital audio.",
            MEDIASERVER::NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED => "Windows Media Player does not support the scheme of output protection required by the content.",
            MEDIASERVER::NS_E_REBOOT_RECOMMENDED => "Installation was not successful and some file cleanup is not complete. For best results, restart your computer.",
            MEDIASERVER::NS_E_REBOOT_REQUIRED => "Installation was not successful. To continue, you must restart your computer.",
            MEDIASERVER::NS_E_SETUP_INCOMPLETE => "Installation was not successful.",
            MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED => "Setup cannot migrate the Windows Media Digital Rights Management (DRM) components.",
            MEDIASERVER::NS_E_SETUP_IGNORABLE_FAILURE => "Some skin or playlist components cannot be installed.",
            MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE => "Setup cannot migrate the Windows Media Digital Rights Management (DRM) components. In addition, some skin or playlist components cannot be installed.",
            MEDIASERVER::NS_E_SETUP_BLOCKED => "Installation is blocked because your computer does not meet one or more of the setup requirements.",
            MEDIASERVER::NS_E_UNKNOWN_PROTOCOL => "The specified protocol is not supported.",
            MEDIASERVER::NS_E_REDIRECT_TO_PROXY => "The client is redirected to a proxy server.",
            MEDIASERVER::NS_E_INTERNAL_SERVER_ERROR => "The server encountered an unexpected condition which prevented it from fulfilling the request.",
            MEDIASERVER::NS_E_BAD_REQUEST => "The request could not be understood by the server.",
            MEDIASERVER::NS_E_ERROR_FROM_PROXY => "The proxy experienced an error while attempting to contact the media server.",
            MEDIASERVER::NS_E_PROXY_TIMEOUT => "The proxy did not receive a timely response while attempting to contact the media server.",
            MEDIASERVER::NS_E_SERVER_UNAVAILABLE => "The server is currently unable to handle the request due to a temporary overloading or maintenance of the server.",
            MEDIASERVER::NS_E_REFUSED_BY_SERVER => "The server is refusing to fulfill the requested operation.",
            MEDIASERVER::NS_E_INCOMPATIBLE_SERVER => "The server is not a compatible streaming media server.",
            MEDIASERVER::NS_E_MULTICAST_DISABLED => "The content cannot be streamed because the Multicast protocol has been disabled.",
            MEDIASERVER::NS_E_INVALID_REDIRECT => "The server redirected the player to an invalid location.",
            MEDIASERVER::NS_E_ALL_PROTOCOLS_DISABLED => "The content cannot be streamed because all protocols have been disabled.",
            MEDIASERVER::NS_E_MSBD_NO_LONGER_SUPPORTED => "The MSBD protocol is no longer supported. Please use HTTP to connect to the Windows Media stream.",
            MEDIASERVER::NS_E_PROXY_NOT_FOUND => "The proxy server could not be located. Please check your proxy server configuration.",
            MEDIASERVER::NS_E_CANNOT_CONNECT_TO_PROXY => "Unable to establish a connection to the proxy server. Please check your proxy server configuration.",
            MEDIASERVER::NS_E_SERVER_DNS_TIMEOUT => "Unable to locate the media server. The operation timed out.",
            MEDIASERVER::NS_E_PROXY_DNS_TIMEOUT => "Unable to locate the proxy server. The operation timed out.",
            MEDIASERVER::NS_E_CLOSED_ON_SUSPEND => "Media closed because Windows was shut down.",
            MEDIASERVER::NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER => "Unable to read the contents of a playlist file from a media server.",
            MEDIASERVER::NS_E_SESSION_NOT_FOUND => "Session not found.",
            MEDIASERVER::NS_E_REQUIRE_STREAMING_CLIENT => "Content requires a streaming media client.",
            MEDIASERVER::NS_E_PLAYLIST_ENTRY_HAS_CHANGED => "A command applies to a previous playlist entry.",
            MEDIASERVER::NS_E_PROXY_ACCESSDENIED => "The proxy server is denying access. The username and/or password might be incorrect.",
            MEDIASERVER::NS_E_PROXY_SOURCE_ACCESSDENIED => "The proxy could not provide valid authentication credentials to the media server.",
            MEDIASERVER::NS_E_NETWORK_SINK_WRITE => "The network sink failed to write data to the network.",
            MEDIASERVER::NS_E_FIREWALL => "Packets are not being received from the server. The packets might be blocked by a filtering device, such as a network firewall.",
            MEDIASERVER::NS_E_MMS_NOT_SUPPORTED => "The MMS protocol is not supported. Please use HTTP or RTSP to connect to the Windows Media stream.",
            MEDIASERVER::NS_E_SERVER_ACCESSDENIED => "The Windows Media server is denying access. The username and/or password might be incorrect.",
            MEDIASERVER::NS_E_RESOURCE_GONE => "The Publishing Point or file on the Windows Media Server is no longer available.",
            MEDIASERVER::NS_E_NO_EXISTING_PACKETIZER => "There is no existing packetizer plugin for a stream.",
            MEDIASERVER::NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE => "The response from the media server could not be understood. This might be caused by an incompatible proxy server or media server.",
            MEDIASERVER::NS_E_RESET_SOCKET_CONNECTION => "The Windows Media Server reset the network connection.",
            MEDIASERVER::NS_E_TOO_MANY_HOPS => "The request could not reach the media server (too many hops).",
            MEDIASERVER::NS_E_TOO_MUCH_DATA_FROM_SERVER => "The server is sending too much data. The connection has been terminated.",
            MEDIASERVER::NS_E_CONNECT_TIMEOUT => "It was not possible to establish a connection to the media server in a timely manner. The media server might be down for maintenance, or it might be necessary to use a proxy server to access this media server.",
            MEDIASERVER::NS_E_PROXY_CONNECT_TIMEOUT => "It was not possible to establish a connection to the proxy server in a timely manner. Please check your proxy server configuration.",
            MEDIASERVER::NS_E_SESSION_INVALID => "Session not found.",
            MEDIASERVER::NS_E_PACKETSINK_UNKNOWN_FEC_STREAM => "Unknown packet sink stream.",
            MEDIASERVER::NS_E_PUSH_CANNOTCONNECT => "Unable to establish a connection to the server. Ensure Windows Media Services is started and the HTTP Server control protocol is properly enabled.",
            MEDIASERVER::NS_E_INCOMPATIBLE_PUSH_SERVER => "The Server service that received the HTTP push request is not a compatible version of Windows Media Services (WMS). This error might indicate the push request was received by IIS instead of WMS. Ensure WMS is started and has the HTTP Server control protocol properly enabled and try again.",
            MEDIASERVER::NS_E_END_OF_PLAYLIST => "The playlist has reached its end.",
            MEDIASERVER::NS_E_USE_FILE_SOURCE => "Use file source.",
            MEDIASERVER::NS_E_PROPERTY_NOT_FOUND => "The property was not found.",
            MEDIASERVER::NS_E_PROPERTY_READ_ONLY => "The property is read only.",
            MEDIASERVER::NS_E_TABLE_KEY_NOT_FOUND => "The table key was not found.",
            MEDIASERVER::NS_E_INVALID_QUERY_OPERATOR => "Invalid query operator.",
            MEDIASERVER::NS_E_INVALID_QUERY_PROPERTY => "Invalid query property.",
            MEDIASERVER::NS_E_PROPERTY_NOT_SUPPORTED => "The property is not supported.",
            MEDIASERVER::NS_E_SCHEMA_CLASSIFY_FAILURE => "Schema classification failure.",
            MEDIASERVER::NS_E_METADATA_FORMAT_NOT_SUPPORTED => "The metadata format is not supported.",
            MEDIASERVER::NS_E_METADATA_NO_EDITING_CAPABILITY => "Cannot edit the metadata.",
            MEDIASERVER::NS_E_METADATA_CANNOT_SET_LOCALE => "Cannot set the locale id.",
            MEDIASERVER::NS_E_METADATA_LANGUAGE_NOT_SUPORTED => "The language is not supported in the format.",
            MEDIASERVER::NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE => "There is no RFC1766 name translation for the supplied locale id.",
            MEDIASERVER::NS_E_METADATA_NOT_AVAILABLE => "The metadata (or metadata item) is not available.",
            MEDIASERVER::NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE => "The cached metadata (or metadata item) is not available.",
            MEDIASERVER::NS_E_METADATA_INVALID_DOCUMENT_TYPE => "The metadata document is invalid.",
            MEDIASERVER::NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE => "The metadata content identifier is not available.",
            MEDIASERVER::NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE => "Cannot retrieve metadata from the offline metadata cache.",
            MEDIASERVER::MF_E_PLATFORM_NOT_INITIALIZED => "Platform not initialized. Please call MFStartup().",
            MEDIASERVER::MF_E_BUFFERTOOSMALL => "The buffer was too small to carry out the requested action.",
            MEDIASERVER::MF_E_INVALIDREQUEST => "The request is invalid in the current state.",
            MEDIASERVER::MF_E_INVALIDSTREAMNUMBER => "The stream number provided was invalid.",
            MEDIASERVER::MF_E_INVALIDMEDIATYPE => "The data specified for the media type is invalid, inconsistent, or not supported by this object.",
            MEDIASERVER::MF_E_NOTACCEPTING => "The callee is currently not accepting further input.",
            MEDIASERVER::MF_E_NOT_INITIALIZED => "This object needs to be initialized before the requested operation can be carried out.",
            MEDIASERVER::MF_E_UNSUPPORTED_REPRESENTATION => "The requested representation is not supported by this object.",
            MEDIASERVER::MF_E_NO_MORE_TYPES => "An object ran out of media types to suggest therefore the requested chain of streaming objects cannot be completed.",
            MEDIASERVER::MF_E_UNSUPPORTED_SERVICE => "The object does not support the specified service.",
            MEDIASERVER::MF_E_UNEXPECTED => "An unexpected error has occurred in the operation requested.",
            MEDIASERVER::MF_E_INVALIDNAME => "Invalid name.",
            MEDIASERVER::MF_E_INVALIDTYPE => "Invalid type.",
            MEDIASERVER::MF_E_INVALID_FILE_FORMAT => "The file does not conform to the relevant file format specification.",
            MEDIASERVER::MF_E_INVALIDINDEX => "Invalid index.",
            MEDIASERVER::MF_E_INVALID_TIMESTAMP => "An invalid timestamp was given.",
            MEDIASERVER::MF_E_UNSUPPORTED_SCHEME => "The scheme of the given URL is unsupported.",
            MEDIASERVER::MF_E_UNSUPPORTED_BYTESTREAM_TYPE => "The byte stream type of the given URL is unsupported.",
            MEDIASERVER::MF_E_UNSUPPORTED_TIME_FORMAT => "The given time format is unsupported.",
            MEDIASERVER::MF_E_NO_SAMPLE_TIMESTAMP => "The Media Sample does not have a timestamp.",
            MEDIASERVER::MF_E_NO_SAMPLE_DURATION => "The Media Sample does not have a duration.",
            MEDIASERVER::MF_E_INVALID_STREAM_DATA => "The request failed because the data in the stream is corrupt.",
            MEDIASERVER::MF_E_RT_UNAVAILABLE => "Real time services are not available.",
            MEDIASERVER::MF_E_UNSUPPORTED_RATE => "The specified rate is not supported.",
            MEDIASERVER::MF_E_THINNING_UNSUPPORTED => "This component does not support stream-thinning.",
            MEDIASERVER::MF_E_REVERSE_UNSUPPORTED => "The call failed because no reverse playback rates are available.",
            MEDIASERVER::MF_E_UNSUPPORTED_RATE_TRANSITION => "The requested rate transition cannot occur in the current state.",
            MEDIASERVER::MF_E_RATE_CHANGE_PREEMPTED => "The requested rate change has been pre-empted and will not occur.",
            MEDIASERVER::MF_E_NOT_FOUND => "The specified object or value does not exist.",
            MEDIASERVER::MF_E_NOT_AVAILABLE => "The requested value is not available.",
            MEDIASERVER::MF_E_NO_CLOCK => "The specified operation requires a clock and no clock is available.",
            MEDIASERVER::MF_E_MULTIPLE_BEGIN => "This callback has already been passed in to this event generator.",
            MEDIASERVER::MF_E_MULTIPLE_SUBSCRIBERS => "Some component is already listening to events on this event generator.",
            MEDIASERVER::MF_E_TIMER_ORPHANED => "This timer was orphaned before its callback time arrived.",
            MEDIASERVER::MF_E_STATE_TRANSITION_PENDING => "A state transition is already pending.",
            MEDIASERVER::MF_E_UNSUPPORTED_STATE_TRANSITION => "The requested state transition is unsupported.",
            MEDIASERVER::MF_E_UNRECOVERABLE_ERROR_OCCURRED => "An unrecoverable error has occurred.",
            MEDIASERVER::MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS => "The provided sample has too many buffers.",
            MEDIASERVER::MF_E_SAMPLE_NOT_WRITABLE => "The provided sample is not writable.",
            MEDIASERVER::MF_E_INVALID_KEY => "The specified key is not valid.",
            MEDIASERVER::MF_E_BAD_STARTUP_VERSION => "You are calling MFStartup with the wrong MF_VERSION. Mismatched bits?",
            MEDIASERVER::MF_E_UNSUPPORTED_CAPTION => "The caption of the given URL is unsupported.",
            MEDIASERVER::MF_E_INVALID_POSITION => "The operation on the current offset is not permitted.",
            MEDIASERVER::MF_E_ATTRIBUTENOTFOUND => "The requested attribute was not found.",
            MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_ALLOWED => "The specified property type is not allowed in this context.",
            MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_SUPPORTED => "The specified property type is not supported.",
            MEDIASERVER::MF_E_PROPERTY_EMPTY => "The specified property is empty.",
            MEDIASERVER::MF_E_PROPERTY_NOT_EMPTY => "The specified property is not empty.",
            MEDIASERVER::MF_E_PROPERTY_VECTOR_NOT_ALLOWED => "The vector property specified is not allowed in this context.",
            MEDIASERVER::MF_E_PROPERTY_VECTOR_REQUIRED => "A vector property is required in this context.",
            MEDIASERVER::MF_E_OPERATION_CANCELLED => "The operation is cancelled.",
            MEDIASERVER::MF_E_BYTESTREAM_NOT_SEEKABLE => "The provided bytestream was expected to be seekable but it was not.",
            MEDIASERVER::MF_E_DISABLED_IN_SAFEMODE => "The Media Foundation platform is disabled when the system is running in Safe Mode.",
            MEDIASERVER::MF_E_CANNOT_PARSE_BYTESTREAM => "The Media Source could not parse the byte stream.",
            MEDIASERVER::MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS => "Mutually exclusive flags have been specified to source resolver. This flag combination is invalid.",
            MEDIASERVER::MF_E_MEDIAPROC_WRONGSTATE => "MediaProc is in the wrong state",
            MEDIASERVER::MF_E_RT_THROUGHPUT_NOT_AVAILABLE => "Real time I/O service can not provide requested throughput.",
            MEDIASERVER::MF_E_RT_TOO_MANY_CLASSES => "The work queue cannot be registered with more classes.",
            MEDIASERVER::MF_E_RT_WOULDBLOCK => "This operation cannot succeed because another thread owns this object.",
            MEDIASERVER::MF_E_NO_BITPUMP => "Internal. Bitpump not found.",
            MEDIASERVER::MF_E_RT_OUTOFMEMORY => "No more RT memory available.",
            MEDIASERVER::MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED => "An MMCSS class has not been set for this work queue.",
            MEDIASERVER::MF_E_CANNOT_CREATE_SINK => "Activate failed to create a media sink. Call OutputNode::GetUINT32(MF_TOPONODE_MAJORTYPE) for more information.",
            MEDIASERVER::MF_E_BYTESTREAM_UNKNOWN_LENGTH => "The length of the provided bytestream is unknown.",
            MEDIASERVER::MF_E_SESSION_PAUSEWHILESTOPPED => "The media session cannot pause from a stopped state.",
            MEDIASERVER::MF_E_FORMAT_CHANGE_NOT_SUPPORTED => "The data specified for the media type is supported, but would require a format change, which is not supported by this object.",
            MEDIASERVER::MF_E_INVALID_WORKQUEUE => "The operation failed because an invalid combination of work queue ID and flags was specified.",
            MEDIASERVER::MF_E_DRM_UNSUPPORTED => "No DRM support is available.",
            MEDIASERVER::MF_E_UNAUTHORIZED => "This operation is not authorized.",
            MEDIASERVER::MF_E_OUT_OF_RANGE => "The value is not in the specified or valid range.",
            MEDIASERVER::MF_E_INVALID_CODEC_MERIT => "The registered codec merit is not valid.",
            MEDIASERVER::MF_E_HW_MFT_FAILED_START_STREAMING => "Hardware MFT failed to start streaming due to lack of hardware resources.",
            MEDIASERVER::MF_E_ASF_PARSINGINCOMPLETE => "Not enough data has been parsed to carry out the requested action.",
            MEDIASERVER::MF_E_ASF_MISSINGDATA => "There is a gap in the ASF data provided.",
            MEDIASERVER::MF_E_ASF_INVALIDDATA => "The data provided are not valid ASF.",
            MEDIASERVER::MF_E_ASF_OPAQUEPACKET => "The packet is opaque, so the requested information cannot be returned.",
            MEDIASERVER::MF_E_ASF_NOINDEX => "The requested operation failed since there is no appropriate ASF index.",
            MEDIASERVER::MF_E_ASF_OUTOFRANGE => "The value supplied is out of range for this operation.",
            MEDIASERVER::MF_E_ASF_INDEXNOTLOADED => "The index entry requested needs to be loaded before it can be available.",
            MEDIASERVER::MF_E_ASF_TOO_MANY_PAYLOADS => "The packet has reached the maximum number of payloads.",
            MEDIASERVER::MF_E_ASF_UNSUPPORTED_STREAM_TYPE => "Stream type is not supported.",
            MEDIASERVER::MF_E_ASF_DROPPED_PACKET => "One or more ASF packets were dropped.",
            MEDIASERVER::MF_E_NO_EVENTS_AVAILABLE => "There are no events available in the queue.",
            MEDIASERVER::MF_E_INVALID_STATE_TRANSITION => "A media source cannot go from the stopped state to the paused state.",
            MEDIASERVER::MF_E_END_OF_STREAM => "The media stream cannot process any more samples because there are no more samples in the stream.",
            MEDIASERVER::MF_E_SHUTDOWN => "The request is invalid because Shutdown() has been called.",
            MEDIASERVER::MF_E_MP3_NOTFOUND => "The MP3 object was not found.",
            MEDIASERVER::MF_E_MP3_OUTOFDATA => "The MP3 parser ran out of data before finding the MP3 object.",
            MEDIASERVER::MF_E_MP3_NOTMP3 => "The file is not really a MP3 file.",
            MEDIASERVER::MF_E_MP3_NOTSUPPORTED => "The MP3 file is not supported.",
            MEDIASERVER::MF_E_NO_DURATION => "The Media stream has no duration.",
            MEDIASERVER::MF_E_INVALID_FORMAT => "The Media format is recognized but is invalid.",
            MEDIASERVER::MF_E_PROPERTY_NOT_FOUND => "The property requested was not found.",
            MEDIASERVER::MF_E_PROPERTY_READ_ONLY => "The property is read only.",
            MEDIASERVER::MF_E_PROPERTY_NOT_ALLOWED => "The specified property is not allowed in this context.",
            MEDIASERVER::MF_E_MEDIA_SOURCE_NOT_STARTED => "The media source has not started.",
            MEDIASERVER::MF_E_UNSUPPORTED_FORMAT => "The Media format is recognized but not supported.",
            MEDIASERVER::MF_E_MP3_BAD_CRC => "The MPEG frame has bad CRC.",
            MEDIASERVER::MF_E_NOT_PROTECTED => "The file is not protected.",
            MEDIASERVER::MF_E_MEDIA_SOURCE_WRONGSTATE => "The media source is in the wrong state.",
            MEDIASERVER::MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED => "No streams are selected in the source presentation descriptor.",
            MEDIASERVER::MF_E_CANNOT_FIND_KEYFRAME_SAMPLE => "No key frame sample was found.",
            MEDIASERVER::MF_E_NETWORK_RESOURCE_FAILURE => "An attempt to acquire a network resource failed.",
            MEDIASERVER::MF_E_NET_WRITE => "Error writing to the network.",
            MEDIASERVER::MF_E_NET_READ => "Error reading from the network.",
            MEDIASERVER::MF_E_NET_REQUIRE_NETWORK => "Internal. Entry cannot complete operation without network.",
            MEDIASERVER::MF_E_NET_REQUIRE_ASYNC => "Internal. Async op is required.",
            MEDIASERVER::MF_E_NET_BWLEVEL_NOT_SUPPORTED => "Internal. Bandwidth levels are not supported.",
            MEDIASERVER::MF_E_NET_STREAMGROUPS_NOT_SUPPORTED => "Internal. Stream groups are not supported.",
            MEDIASERVER::MF_E_NET_MANUALSS_NOT_SUPPORTED => "Manual stream selection is not supported.",
            MEDIASERVER::MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR => "Invalid presentation descriptor.",
            MEDIASERVER::MF_E_NET_CACHESTREAM_NOT_FOUND => "Cannot find the cache stream.",
            MEDIASERVER::MF_E_NET_REQUIRE_INPUT => "Internal. Entry cannot complete operation without input.",
            MEDIASERVER::MF_E_NET_REDIRECT => "The client was redirected to another server.",
            MEDIASERVER::MF_E_NET_REDIRECT_TO_PROXY => "The client was redirected to a proxy server.",
            MEDIASERVER::MF_E_NET_TOO_MANY_REDIRECTS => "The client reached the maximum redirection limit.",
            MEDIASERVER::MF_E_NET_TIMEOUT => "The server, a computer set up to offer multimedia content to other computers, could not handle your request for multimedia content in a timely manner. Please try again later.",
            MEDIASERVER::MF_E_NET_CLIENT_CLOSE => "The control socket is closed by the client.",
            MEDIASERVER::MF_E_NET_BAD_CONTROL_DATA => "The server received invalid data from the client on the control connection.",
            MEDIASERVER::MF_E_NET_INCOMPATIBLE_SERVER => "The server is not a compatible streaming media server.",
            MEDIASERVER::MF_E_NET_UNSAFE_URL => "Url.",
            MEDIASERVER::MF_E_NET_CACHE_NO_DATA => "Data is not available.",
            MEDIASERVER::MF_E_NET_EOL => "End of line.",
            MEDIASERVER::MF_E_NET_BAD_REQUEST => "The request could not be understood by the server.",
            MEDIASERVER::MF_E_NET_INTERNAL_SERVER_ERROR => "The server encountered an unexpected condition which prevented it from fulfilling the request.",
            MEDIASERVER::MF_E_NET_SESSION_NOT_FOUND => "Session not found.",
            MEDIASERVER::MF_E_NET_NOCONNECTION => "There is no connection established with the Windows Media server. The operation failed.",
            MEDIASERVER::MF_E_NET_CONNECTION_FAILURE => "The network connection has failed.",
            MEDIASERVER::MF_E_NET_INCOMPATIBLE_PUSHSERVER => "The Server service that received the HTTP push request is not a compatible version of Windows Media Services (WMS). This error can indicate the push request was received by IIS instead of WMS. Ensure WMS has started and has the HTTP Server control protocol properly enabled and try again.",
            MEDIASERVER::MF_E_NET_SERVER_ACCESSDENIED => "The Windows Media server is denying access. The username and/or password could be incorrect.",
            MEDIASERVER::MF_E_NET_PROXY_ACCESSDENIED => "The proxy server is denying access. The username and/or password could be incorrect.",
            MEDIASERVER::MF_E_NET_CANNOTCONNECT => "Unable to establish a connection to the server.",
            MEDIASERVER::MF_E_NET_INVALID_PUSH_TEMPLATE => "The specified push template is invalid.",
            MEDIASERVER::MF_E_NET_INVALID_PUSH_PUBLISHING_POINT => "The specified push publishing point is invalid.",
            MEDIASERVER::MF_E_NET_BUSY => "The requested resource is in use.",
            MEDIASERVER::MF_E_NET_RESOURCE_GONE => "The Publishing Point or file on the Windows Media Server is no longer available.",
            MEDIASERVER::MF_E_NET_ERROR_FROM_PROXY => "The proxy experienced an error while attempting to contact the media server.",
            MEDIASERVER::MF_E_NET_PROXY_TIMEOUT => "The proxy did not receive a timely response while attempting to contact the media server.",
            MEDIASERVER::MF_E_NET_SERVER_UNAVAILABLE => "The server is currently unable to handle the request due to temporary overloading or maintenance of the server.",
            MEDIASERVER::MF_E_NET_TOO_MUCH_DATA => "The encoding process was unable to keep up with the amount of data supplied.",
            MEDIASERVER::MF_E_NET_SESSION_INVALID => "Session not found.",
            MEDIASERVER::MF_E_OFFLINE_MODE => "The requested URL is not available in offline mode.",
            MEDIASERVER::MF_E_NET_UDP_BLOCKED => "A device in the network is blocking UDP traffic.",
            MEDIASERVER::MF_E_NET_UNSUPPORTED_CONFIGURATION => "The specified configuration value is not supported.",
            MEDIASERVER::MF_E_NET_PROTOCOL_DISABLED => "The networking protocol is disabled.",
            MEDIASERVER::MF_E_ALREADY_INITIALIZED => "This object has already been initialized and cannot be re-initialized at this time.",
            MEDIASERVER::MF_E_BANDWIDTH_OVERRUN => "The amount of data passed in exceeds the given bitrate and buffer window.",
            MEDIASERVER::MF_E_LATE_SAMPLE => "The sample was passed in too late to be correctly processed.",
            MEDIASERVER::MF_E_FLUSH_NEEDED => "The requested action cannot be carried out until the object is flushed and the queue is emptied.",
            MEDIASERVER::MF_E_INVALID_PROFILE => "The profile is invalid.",
            MEDIASERVER::MF_E_INDEX_NOT_COMMITTED => "The index that is being generated needs to be committed before the requested action can be carried out.",
            MEDIASERVER::MF_E_NO_INDEX => "The index that is necessary for the requested action is not found.",
            MEDIASERVER::MF_E_CANNOT_INDEX_IN_PLACE => "The requested index cannot be added in-place to the specified ASF content.",
            MEDIASERVER::MF_E_MISSING_ASF_LEAKYBUCKET => "The ASF leaky bucket parameters must be specified in order to carry out this request.",
            MEDIASERVER::MF_E_INVALID_ASF_STREAMID => "The stream id is invalid. The valid range for ASF stream id is from 1 to 127.",
            MEDIASERVER::MF_E_STREAMSINK_REMOVED => "The requested Stream Sink has been removed and cannot be used.",
            MEDIASERVER::MF_E_STREAMSINKS_OUT_OF_SYNC => "The various Stream Sinks in this Media Sink are too far out of sync for the requested action to take place.",
            MEDIASERVER::MF_E_STREAMSINKS_FIXED => "Stream Sinks cannot be added to or removed from this Media Sink because its set of streams is fixed.",
            MEDIASERVER::MF_E_STREAMSINK_EXISTS => "The given Stream Sink already exists.",
            MEDIASERVER::MF_E_SAMPLEALLOCATOR_CANCELED => "Sample allocations have been canceled.",
            MEDIASERVER::MF_E_SAMPLEALLOCATOR_EMPTY => "The sample allocator is currently empty, due to outstanding requests.",
            MEDIASERVER::MF_E_SINK_ALREADYSTOPPED => "The stream sink is already stopped.",
            MEDIASERVER::MF_E_ASF_FILESINK_BITRATE_UNKNOWN => "The ASF file sink could not reserve AVIO because the bitrate is unknown.",
            MEDIASERVER::MF_E_SINK_NO_STREAMS => "No streams are selected in the sink presentation descriptor.",
            MEDIASERVER::MF_E_METADATA_TOO_LONG => "A metadata item was too long to write to the output container.",
            MEDIASERVER::MF_E_SINK_NO_SAMPLES_PROCESSED => "The operation failed because no samples were processed by the sink.",
            MEDIASERVER::MF_E_VIDEO_REN_NO_PROCAMP_HW => "There is no available procamp hardware with which to perform color correction.",
            MEDIASERVER::MF_E_VIDEO_REN_NO_DEINTERLACE_HW => "There is no available deinterlacing hardware with which to deinterlace the video stream.",
            MEDIASERVER::MF_E_VIDEO_REN_COPYPROT_FAILED => "A video stream requires copy protection to be enabled, but there was a failure in attempting to enable copy protection.",
            MEDIASERVER::MF_E_VIDEO_REN_SURFACE_NOT_SHARED => "A component is attempting to access a surface for sharing that is not shared.",
            MEDIASERVER::MF_E_VIDEO_DEVICE_LOCKED => "A component is attempting to access a shared device that is already locked by another component.",
            MEDIASERVER::MF_E_NEW_VIDEO_DEVICE => "The device is no longer available. The handle should be closed and a new one opened.",
            MEDIASERVER::MF_E_NO_VIDEO_SAMPLE_AVAILABLE => "A video sample is not currently queued on a stream that is required for mixing.",
            MEDIASERVER::MF_E_NO_AUDIO_PLAYBACK_DEVICE => "No audio playback device was found.",
            MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE => "The requested audio playback device is currently in use.",
            MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED => "The audio playback device is no longer present.",
            MEDIASERVER::MF_E_AUDIO_SERVICE_NOT_RUNNING => "The audio service is not running.",
            MEDIASERVER::MF_E_TOPO_INVALID_OPTIONAL_NODE => "The topology contains an invalid optional node. Possible reasons are an incorrect number of outputs and inputs or an optional node is at the beginning or end of a segment.",
            MEDIASERVER::MF_E_TOPO_CANNOT_FIND_DECRYPTOR => "No suitable transform was found to decrypt the content.",
            MEDIASERVER::MF_E_TOPO_CODEC_NOT_FOUND => "No suitable transform was found to encode or decode the content.",
            MEDIASERVER::MF_E_TOPO_CANNOT_CONNECT => "Unable to find a way to connect nodes.",
            MEDIASERVER::MF_E_TOPO_UNSUPPORTED => "Unsupported operations in the topoloader.",
            MEDIASERVER::MF_E_TOPO_INVALID_TIME_ATTRIBUTES => "The topology or its nodes contain incorrectly set time attributes.",
            MEDIASERVER::MF_E_TOPO_LOOPS_IN_TOPOLOGY => "The topology contains loops, which are unsupported in media foundation topologies.",
            MEDIASERVER::MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR => "A source stream node in the topology does not have a presentation descriptor.",
            MEDIASERVER::MF_E_TOPO_MISSING_STREAM_DESCRIPTOR => "A source stream node in the topology does not have a stream descriptor.",
            MEDIASERVER::MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED => "A stream descriptor was set on a source stream node but it was not selected on the presentation descriptor.",
            MEDIASERVER::MF_E_TOPO_MISSING_SOURCE => "A source stream node in the topology does not have a source.",
            MEDIASERVER::MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED => "The topology loader does not support sink activates on output nodes.",
            MEDIASERVER::MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID => "The sequencer cannot find a segment with the given ID.",
            MEDIASERVER::MF_E_NO_SOURCE_IN_CACHE => "Cannot find source in the source cache.",
            MEDIASERVER::MF_E_TRANSFORM_TYPE_NOT_SET => "A valid type has not been set for this stream or a stream that it depends on.",
            MEDIASERVER::MF_E_TRANSFORM_STREAM_CHANGE => "A stream change has occurred. Output cannot be produced until the streams have been renegotiated.",
            MEDIASERVER::MF_E_TRANSFORM_INPUT_REMAINING => "The transform cannot take the requested action until all of the input data it currently holds is processed or flushed.",
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_MISSING => "The transform requires a profile but no profile was supplied or found.",
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT => "The transform requires a profile but the supplied profile was invalid or corrupt.",
            MEDIASERVER::MF_E_TRANSFORM_PROFILE_TRUNCATED => "The transform requires a profile but the supplied profile ended unexpectedly while parsing.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED => "The property ID does not match any property supported by the transform.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG => "The variant does not have the type expected for this property ID.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE => "An attempt was made to set the value on a read-only property.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM => "The array property value has an unexpected number of dimensions.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG => "The array or blob property value has an unexpected size.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE => "The property value is out of range for this transform.",
            MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE => "The property value is incompatible with some other property or media type set on the transform.",
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE => "The requested operation is not supported for the currently set output media type.",
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE => "The requested operation is not supported for the currently set input media type.",
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION => "The requested operation is not supported for the currently set combination of media types.",
            MEDIASERVER::MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES => "The requested feature is not supported in combination with some other currently enabled feature.",
            MEDIASERVER::MF_E_TRANSFORM_NEED_MORE_INPUT => "The transform cannot produce output until it gets more input samples.",
            MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG => "The requested operation is not supported for the current speaker configuration.",
            MEDIASERVER::MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING => "The transform cannot accept media type changes in the middle of processing.",
            MEDIASERVER::MF_E_UNSUPPORTED_D3D_TYPE => "The input type is not supported for D3D device.",
            MEDIASERVER::MF_E_TRANSFORM_ASYNC_LOCKED => "The caller does not appear to support this transform's asynchronous capabilities.",
            MEDIASERVER::MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER => "An audio compression manager driver could not be initialized by the transform.",
            MEDIASERVER::MF_E_LICENSE_INCORRECT_RIGHTS => "You are not allowed to open this file. Contact the content provider for further assistance.",
            MEDIASERVER::MF_E_LICENSE_OUTOFDATE => "The license for this media file has expired. Get a new license or contact the content provider for further assistance.",
            MEDIASERVER::MF_E_LICENSE_REQUIRED => "You need a license to perform the requested operation on this media file.",
            MEDIASERVER::MF_E_DRM_HARDWARE_INCONSISTENT => "The licenses for your media files are corrupted. Contact Microsoft product support.",
            MEDIASERVER::MF_E_NO_CONTENT_PROTECTION_MANAGER => "The APP needs to provide an IMFContentProtectionManager callback to access the protected media file.",
            MEDIASERVER::MF_E_LICENSE_RESTORE_NO_RIGHTS => "Client does not have rights to restore licenses.",
            MEDIASERVER::MF_E_BACKUP_RESTRICTED_LICENSE => "Licenses are restricted and hence cannot be backed up.",
            MEDIASERVER::MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION => "License restore requires the machine to be individualized.",
            MEDIASERVER::MF_E_COMPONENT_REVOKED => "Component is revoked.",
            MEDIASERVER::MF_E_TRUST_DISABLED => "Trusted functionality is currently disabled on this component.",
            MEDIASERVER::MF_E_WMDRMOTA_NO_ACTION => "No Action is set on WMDRM Output Trust Authority.",
            MEDIASERVER::MF_E_WMDRMOTA_ACTION_ALREADY_SET => "Action is already set on WMDRM Output Trust Authority.",
            MEDIASERVER::MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE => "DRM Header is not available.",
            MEDIASERVER::MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED => "Current encryption scheme is not supported.",
            MEDIASERVER::MF_E_WMDRMOTA_ACTION_MISMATCH => "Action does not match the current configuration.",
            MEDIASERVER::MF_E_WMDRMOTA_INVALID_POLICY => "Invalid policy for WMDRM Output Trust Authority.",
            MEDIASERVER::MF_E_POLICY_UNSUPPORTED => "The policies that the Input Trust Authority requires to be enforced are unsupported by the outputs.",
            MEDIASERVER::MF_E_OPL_NOT_SUPPORTED => "The OPL that the license requires to be enforced are not supported by the Input Trust Authority.",
            MEDIASERVER::MF_E_TOPOLOGY_VERIFICATION_FAILED => "The topology could not be successfully verified.",
            MEDIASERVER::MF_E_SIGNATURE_VERIFICATION_FAILED => "Signature verification could not be completed successfully for this component.",
            MEDIASERVER::MF_E_DEBUGGING_NOT_ALLOWED => "Running this process under a debugger while using protected content is not allowed.",
            MEDIASERVER::MF_E_CODE_EXPIRED => "MF component has expired.",
            MEDIASERVER::MF_E_GRL_VERSION_TOO_LOW => "The current GRL on the machine does not meet the minimum version requirements.",
            MEDIASERVER::MF_E_GRL_RENEWAL_NOT_FOUND => "The current GRL on the machine does not contain any renewal entries for the specified revocation.",
            MEDIASERVER::MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND => "The current GRL on the machine does not contain any extensible entries for the specified extension GUID.",
            MEDIASERVER::MF_E_KERNEL_UNTRUSTED => "The kernel is not secure for high security level content.",
            MEDIASERVER::MF_E_PEAUTH_UNTRUSTED => "The response from the protected environment driver is not valid.",
            MEDIASERVER::MF_E_NON_PE_PROCESS => "A non-PE process tried to talk to PEAuth.",
            MEDIASERVER::MF_E_REBOOT_REQUIRED => "We need to reboot the machine.",
            MEDIASERVER::MF_E_GRL_INVALID_FORMAT => "The GRL file is not correctly formed: it may have been corrupted or overwritten.",
            MEDIASERVER::MF_E_GRL_UNRECOGNIZED_FORMAT => "The GRL file is in a format newer than those recognized by this GRL Reader.",
            MEDIASERVER::MF_E_ALL_PROCESS_RESTART_REQUIRED => "The GRL was reloaded and required all processes that can run protected media to restart.",
            MEDIASERVER::MF_E_PROCESS_RESTART_REQUIRED => "The GRL was reloaded and the current process needs to restart.",
            MEDIASERVER::MF_E_USERMODE_UNTRUSTED => "The user space is untrusted for protected content play.",
            MEDIASERVER::MF_E_PEAUTH_SESSION_NOT_STARTED => "PEAuth communication session has not been started.",
            MEDIASERVER::MF_E_INSUFFICIENT_BUFFER => "Insufficient memory for response.",
            MEDIASERVER::MF_E_PEAUTH_PUBLICKEY_REVOKED => "PEAuth's public key is revoked.",
            MEDIASERVER::MF_E_GRL_ABSENT => "The GRL is absent.",
            MEDIASERVER::MF_E_PE_UNTRUSTED => "The Protected Environment is untrusted.",
            MEDIASERVER::MF_E_PEAUTH_NOT_STARTED => "The Protected Environment Authorization service (PEAUTH) has not been started.",
            MEDIASERVER::MF_E_INCOMPATIBLE_SAMPLE_PROTECTION => "The sample protection algorithms supported by components are not compatible.",
            MEDIASERVER::MF_E_PE_SESSIONS_MAXED => "No more protected environment sessions can be supported.",
            MEDIASERVER::MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED => "WMDRM ITA does not allow protected content with high security level for this release.",
            MEDIASERVER::MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED => "WMDRM ITA cannot allow the requested action for the content as one or more components are not properly signed.",
            MEDIASERVER::MF_E_ITA_UNSUPPORTED_ACTION => "WMDRM ITA does not support the requested action.",
            MEDIASERVER::MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS => "WMDRM ITA encountered an error in parsing the Secure Audio Path parameters.",
            MEDIASERVER::MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS => "The Policy Manager action passed in is invalid.",
            MEDIASERVER::MF_E_BAD_OPL_STRUCTURE_FORMAT => "The structure specifying Output Protection Level is not the correct format.",
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID => "WMDRM ITA does not recognize the Explicit Analog Video Output Protection guid specified in the license.",
            MEDIASERVER::MF_E_NO_PMP_HOST => "IMFPMPHost object not available.",
            MEDIASERVER::MF_E_ITA_OPL_DATA_NOT_INITIALIZED => "WMDRM ITA could not initialize the Output Protection Level data.",
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT => "WMDRM ITA does not recognize the Analog Video Output specified by the OTA.",
            MEDIASERVER::MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT => "WMDRM ITA does not recognize the Digital Video Output specified by the OTA.",
            MEDIASERVER::MF_E_CLOCK_INVALID_CONTINUITY_KEY => "The continuity key supplied is not currently valid.",
            MEDIASERVER::MF_E_CLOCK_NO_TIME_SOURCE => "No Presentation Time Source has been specified.",
            MEDIASERVER::MF_E_CLOCK_STATE_ALREADY_SET => "The clock is already in the requested state.",
            MEDIASERVER::MF_E_CLOCK_NOT_SIMPLE => "The clock has too many advanced features to carry out the request.",
            MEDIASERVER::MF_E_NO_MORE_DROP_MODES => "The component does not support any more drop modes.",
            MEDIASERVER::MF_E_NO_MORE_QUALITY_LEVELS => "The component does not support any more quality levels.",
            MEDIASERVER::MF_E_DROPTIME_NOT_SUPPORTED => "The component does not support drop-time functionality.",
            MEDIASERVER::MF_E_QUALITYKNOB_WAIT_LONGER => "The Quality Manager needs to wait longer before bumping the Quality Level up.",
            MEDIASERVER::MF_E_QM_INVALIDSTATE => "The Quality Manager is in an invalid state. Quality Management is off at this moment.",
            MEDIASERVER::MF_E_TRANSCODE_NO_CONTAINERTYPE => "No transcode output container type is specified.",
            MEDIASERVER::MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS => "The profile does not have a media type configuration for any selected source streams.",
            MEDIASERVER::MF_E_TRANSCODE_NO_MATCHING_ENCODER => "Cannot find an encoder MFT that accepts the user preferred output type.",
            MEDIASERVER::MF_E_ALLOCATOR_NOT_INITIALIZED => "Memory allocator is not initialized.",
            MEDIASERVER::MF_E_ALLOCATOR_NOT_COMMITED => "Memory allocator is not committed yet.",
            MEDIASERVER::MF_E_ALLOCATOR_ALREADY_COMMITED => "Memory allocator has already been committed.",
            MEDIASERVER::MF_E_STREAM_ERROR => "An error occurred in the media stream.",
            MEDIASERVER::MF_E_INVALID_STREAM_STATE => "The stream is not in a state to handle the request.",
            MEDIASERVER::MF_E_HW_STREAM_NOT_CONNECTED => "The hardware stream is not connected yet.",
        }
    }

    pub fn from_name(name: &str) -> MEDIASERVER {
        return match name {
            "NS_S_CALLPENDING" => MEDIASERVER::NS_S_CALLPENDING,
            "NS_S_CALLABORTED" => MEDIASERVER::NS_S_CALLABORTED,
            "NS_S_STREAM_TRUNCATED" => MEDIASERVER::NS_S_STREAM_TRUNCATED,
            "NS_S_REBUFFERING" => MEDIASERVER::NS_S_REBUFFERING,
            "NS_S_DEGRADING_QUALITY" => MEDIASERVER::NS_S_DEGRADING_QUALITY,
            "NS_S_TRANSCRYPTOR_EOF" => MEDIASERVER::NS_S_TRANSCRYPTOR_EOF,
            "NS_S_WMP_UI_VERSIONMISMATCH" => MEDIASERVER::NS_S_WMP_UI_VERSIONMISMATCH,
            "NS_S_WMP_EXCEPTION" => MEDIASERVER::NS_S_WMP_EXCEPTION,
            "NS_S_WMP_LOADED_GIF_IMAGE" => MEDIASERVER::NS_S_WMP_LOADED_GIF_IMAGE,
            "NS_S_WMP_LOADED_PNG_IMAGE" => MEDIASERVER::NS_S_WMP_LOADED_PNG_IMAGE,
            "NS_S_WMP_LOADED_BMP_IMAGE" => MEDIASERVER::NS_S_WMP_LOADED_BMP_IMAGE,
            "NS_S_WMP_LOADED_JPG_IMAGE" => MEDIASERVER::NS_S_WMP_LOADED_JPG_IMAGE,
            "NS_S_WMG_FORCE_DROP_FRAME" => MEDIASERVER::NS_S_WMG_FORCE_DROP_FRAME,
            "NS_S_WMR_ALREADYRENDERED" => MEDIASERVER::NS_S_WMR_ALREADYRENDERED,
            "NS_S_WMR_PINTYPEPARTIALMATCH" => MEDIASERVER::NS_S_WMR_PINTYPEPARTIALMATCH,
            "NS_S_WMR_PINTYPEFULLMATCH" => MEDIASERVER::NS_S_WMR_PINTYPEFULLMATCH,
            "NS_S_WMG_ADVISE_DROP_FRAME" => MEDIASERVER::NS_S_WMG_ADVISE_DROP_FRAME,
            "NS_S_WMG_ADVISE_DROP_TO_KEYFRAME" => MEDIASERVER::NS_S_WMG_ADVISE_DROP_TO_KEYFRAME,
            "NS_S_NEED_TO_BUY_BURN_RIGHTS" => MEDIASERVER::NS_S_NEED_TO_BUY_BURN_RIGHTS,
            "NS_S_WMPCORE_PLAYLISTCLEARABORT" => MEDIASERVER::NS_S_WMPCORE_PLAYLISTCLEARABORT,
            "NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT" => MEDIASERVER::NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT,
            "NS_S_WMPCORE_PLAYLIST_CREATION_PENDING" => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_CREATION_PENDING,
            "NS_S_WMPCORE_MEDIA_VALIDATION_PENDING" => MEDIASERVER::NS_S_WMPCORE_MEDIA_VALIDATION_PENDING,
            "NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED" => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED,
            "NS_S_WMPCORE_COMMAND_NOT_AVAILABLE" => MEDIASERVER::NS_S_WMPCORE_COMMAND_NOT_AVAILABLE,
            "NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED" => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED,
            "NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS" => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS,
            "NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA" => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA,
            "NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING" => MEDIASERVER::NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING,
            "NS_S_WMPCORE_MORE_NODES_AVAIABLE" => MEDIASERVER::NS_S_WMPCORE_MORE_NODES_AVAIABLE,
            "NS_S_WMPBR_SUCCESS" => MEDIASERVER::NS_S_WMPBR_SUCCESS,
            "NS_S_WMPBR_PARTIALSUCCESS" => MEDIASERVER::NS_S_WMPBR_PARTIALSUCCESS,
            "NS_S_WMPEFFECT_TRANSPARENT" => MEDIASERVER::NS_S_WMPEFFECT_TRANSPARENT,
            "NS_S_WMPEFFECT_OPAQUE" => MEDIASERVER::NS_S_WMPEFFECT_OPAQUE,
            "NS_S_OPERATION_PENDING" => MEDIASERVER::NS_S_OPERATION_PENDING,
            "NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE" => MEDIASERVER::NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE,
            "NS_S_NAVIGATION_COMPLETE_WITH_ERRORS" => MEDIASERVER::NS_S_NAVIGATION_COMPLETE_WITH_ERRORS,
            "NS_S_TRACK_ALREADY_DOWNLOADED" => MEDIASERVER::NS_S_TRACK_ALREADY_DOWNLOADED,
            "NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS" => MEDIASERVER::NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS,
            "NS_S_DRM_LICENSE_ACQUIRED" => MEDIASERVER::NS_S_DRM_LICENSE_ACQUIRED,
            "NS_S_DRM_INDIVIDUALIZED" => MEDIASERVER::NS_S_DRM_INDIVIDUALIZED,
            "NS_S_DRM_MONITOR_CANCELLED" => MEDIASERVER::NS_S_DRM_MONITOR_CANCELLED,
            "NS_S_DRM_ACQUIRE_CANCELLED" => MEDIASERVER::NS_S_DRM_ACQUIRE_CANCELLED,
            "NS_S_DRM_BURNABLE_TRACK" => MEDIASERVER::NS_S_DRM_BURNABLE_TRACK,
            "NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION" => MEDIASERVER::NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION,
            "NS_S_DRM_NEEDS_INDIVIDUALIZATION" => MEDIASERVER::NS_S_DRM_NEEDS_INDIVIDUALIZATION,
            "NS_S_REBOOT_RECOMMENDED" => MEDIASERVER::NS_S_REBOOT_RECOMMENDED,
            "NS_S_REBOOT_REQUIRED" => MEDIASERVER::NS_S_REBOOT_REQUIRED,
            "NS_S_EOSRECEDING" => MEDIASERVER::NS_S_EOSRECEDING,
            "NS_S_CHANGENOTICE" => MEDIASERVER::NS_S_CHANGENOTICE,
            "MF_S_MULTIPLE_BEGIN" => MEDIASERVER::MF_S_MULTIPLE_BEGIN,
            "MF_S_ACTIVATE_REPLACED" => MEDIASERVER::MF_S_ACTIVATE_REPLACED,
            "MF_S_SINK_NOT_FINALIZED" => MEDIASERVER::MF_S_SINK_NOT_FINALIZED,
            "MF_S_SEQUENCER_CONTEXT_CANCELED" => MEDIASERVER::MF_S_SEQUENCER_CONTEXT_CANCELED,
            "MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM" => MEDIASERVER::MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM,
            "MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT" => MEDIASERVER::MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT,
            "MF_S_PROTECTION_NOT_REQUIRED" => MEDIASERVER::MF_S_PROTECTION_NOT_REQUIRED,
            "MF_S_WAIT_FOR_POLICY_SET" => MEDIASERVER::MF_S_WAIT_FOR_POLICY_SET,
            "MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT" => MEDIASERVER::MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT,
            "MF_S_PE_TRUSTED" => MEDIASERVER::MF_S_PE_TRUSTED,
            "MF_S_CLOCK_STOPPED" => MEDIASERVER::MF_S_CLOCK_STOPPED,
            "NS_I_TIGER_START" => MEDIASERVER::NS_I_TIGER_START,
            "NS_I_CUB_START" => MEDIASERVER::NS_I_CUB_START,
            "NS_I_CUB_RUNNING" => MEDIASERVER::NS_I_CUB_RUNNING,
            "NS_I_DISK_START" => MEDIASERVER::NS_I_DISK_START,
            "NS_I_DISK_REBUILD_STARTED" => MEDIASERVER::NS_I_DISK_REBUILD_STARTED,
            "NS_I_DISK_REBUILD_FINISHED" => MEDIASERVER::NS_I_DISK_REBUILD_FINISHED,
            "NS_I_DISK_REBUILD_ABORTED" => MEDIASERVER::NS_I_DISK_REBUILD_ABORTED,
            "NS_I_LIMIT_FUNNELS" => MEDIASERVER::NS_I_LIMIT_FUNNELS,
            "NS_I_START_DISK" => MEDIASERVER::NS_I_START_DISK,
            "NS_I_STOP_DISK" => MEDIASERVER::NS_I_STOP_DISK,
            "NS_I_STOP_CUB" => MEDIASERVER::NS_I_STOP_CUB,
            "NS_I_KILL_USERSESSION" => MEDIASERVER::NS_I_KILL_USERSESSION,
            "NS_I_KILL_CONNECTION" => MEDIASERVER::NS_I_KILL_CONNECTION,
            "NS_I_REBUILD_DISK" => MEDIASERVER::NS_I_REBUILD_DISK,
            "MCMADM_I_NO_EVENTS" => MEDIASERVER::MCMADM_I_NO_EVENTS,
            "NS_I_LOGGING_FAILED" => MEDIASERVER::NS_I_LOGGING_FAILED,
            "NS_I_LIMIT_BANDWIDTH" => MEDIASERVER::NS_I_LIMIT_BANDWIDTH,
            "NS_I_CUB_UNFAIL_LINK" => MEDIASERVER::NS_I_CUB_UNFAIL_LINK,
            "NS_I_RESTRIPE_START" => MEDIASERVER::NS_I_RESTRIPE_START,
            "NS_I_RESTRIPE_DONE" => MEDIASERVER::NS_I_RESTRIPE_DONE,
            "NS_I_RESTRIPE_DISK_OUT" => MEDIASERVER::NS_I_RESTRIPE_DISK_OUT,
            "NS_I_RESTRIPE_CUB_OUT" => MEDIASERVER::NS_I_RESTRIPE_CUB_OUT,
            "NS_I_DISK_STOP" => MEDIASERVER::NS_I_DISK_STOP,
            "NS_I_PLAYLIST_CHANGE_RECEDING" => MEDIASERVER::NS_I_PLAYLIST_CHANGE_RECEDING,
            "NS_I_RECONNECTED" => MEDIASERVER::NS_I_RECONNECTED,
            "NS_I_NOLOG_STOP" => MEDIASERVER::NS_I_NOLOG_STOP,
            "NS_I_EXISTING_PACKETIZER" => MEDIASERVER::NS_I_EXISTING_PACKETIZER,
            "NS_I_MANUAL_PROXY" => MEDIASERVER::NS_I_MANUAL_PROXY,
            "MF_S_ASF_PARSEINPROGRESS" => MEDIASERVER::MF_S_ASF_PARSEINPROGRESS,
            "MF_I_MANUAL_PROXY" => MEDIASERVER::MF_I_MANUAL_PROXY,
            "NS_W_SERVER_BANDWIDTH_LIMIT" => MEDIASERVER::NS_W_SERVER_BANDWIDTH_LIMIT,
            "NS_W_FILE_BANDWIDTH_LIMIT" => MEDIASERVER::NS_W_FILE_BANDWIDTH_LIMIT,
            "NS_W_UNKNOWN_EVENT" => MEDIASERVER::NS_W_UNKNOWN_EVENT,
            "NS_I_CATATONIC_FAILURE" => MEDIASERVER::NS_I_CATATONIC_FAILURE,
            "NS_I_CATATONIC_AUTO_UNFAIL" => MEDIASERVER::NS_I_CATATONIC_AUTO_UNFAIL,
            "NS_E_NOCONNECTION" => MEDIASERVER::NS_E_NOCONNECTION,
            "NS_E_CANNOTCONNECT" => MEDIASERVER::NS_E_CANNOTCONNECT,
            "NS_E_CANNOTDESTROYTITLE" => MEDIASERVER::NS_E_CANNOTDESTROYTITLE,
            "NS_E_CANNOTRENAMETITLE" => MEDIASERVER::NS_E_CANNOTRENAMETITLE,
            "NS_E_CANNOTOFFLINEDISK" => MEDIASERVER::NS_E_CANNOTOFFLINEDISK,
            "NS_E_CANNOTONLINEDISK" => MEDIASERVER::NS_E_CANNOTONLINEDISK,
            "NS_E_NOREGISTEREDWALKER" => MEDIASERVER::NS_E_NOREGISTEREDWALKER,
            "NS_E_NOFUNNEL" => MEDIASERVER::NS_E_NOFUNNEL,
            "NS_E_NO_LOCALPLAY" => MEDIASERVER::NS_E_NO_LOCALPLAY,
            "NS_E_NETWORK_BUSY" => MEDIASERVER::NS_E_NETWORK_BUSY,
            "NS_E_TOO_MANY_SESS" => MEDIASERVER::NS_E_TOO_MANY_SESS,
            "NS_E_ALREADY_CONNECTED" => MEDIASERVER::NS_E_ALREADY_CONNECTED,
            "NS_E_INVALID_INDEX" => MEDIASERVER::NS_E_INVALID_INDEX,
            "NS_E_PROTOCOL_MISMATCH" => MEDIASERVER::NS_E_PROTOCOL_MISMATCH,
            "NS_E_TIMEOUT" => MEDIASERVER::NS_E_TIMEOUT,
            "NS_E_NET_WRITE" => MEDIASERVER::NS_E_NET_WRITE,
            "NS_E_NET_READ" => MEDIASERVER::NS_E_NET_READ,
            "NS_E_DISK_WRITE" => MEDIASERVER::NS_E_DISK_WRITE,
            "NS_E_DISK_READ" => MEDIASERVER::NS_E_DISK_READ,
            "NS_E_FILE_WRITE" => MEDIASERVER::NS_E_FILE_WRITE,
            "NS_E_FILE_READ" => MEDIASERVER::NS_E_FILE_READ,
            "NS_E_FILE_NOT_FOUND" => MEDIASERVER::NS_E_FILE_NOT_FOUND,
            "NS_E_FILE_EXISTS" => MEDIASERVER::NS_E_FILE_EXISTS,
            "NS_E_INVALID_NAME" => MEDIASERVER::NS_E_INVALID_NAME,
            "NS_E_FILE_OPEN_FAILED" => MEDIASERVER::NS_E_FILE_OPEN_FAILED,
            "NS_E_FILE_ALLOCATION_FAILED" => MEDIASERVER::NS_E_FILE_ALLOCATION_FAILED,
            "NS_E_FILE_INIT_FAILED" => MEDIASERVER::NS_E_FILE_INIT_FAILED,
            "NS_E_FILE_PLAY_FAILED" => MEDIASERVER::NS_E_FILE_PLAY_FAILED,
            "NS_E_SET_DISK_UID_FAILED" => MEDIASERVER::NS_E_SET_DISK_UID_FAILED,
            "NS_E_INDUCED" => MEDIASERVER::NS_E_INDUCED,
            "NS_E_CCLINK_DOWN" => MEDIASERVER::NS_E_CCLINK_DOWN,
            "NS_E_INTERNAL" => MEDIASERVER::NS_E_INTERNAL,
            "NS_E_BUSY" => MEDIASERVER::NS_E_BUSY,
            "NS_E_UNRECOGNIZED_STREAM_TYPE" => MEDIASERVER::NS_E_UNRECOGNIZED_STREAM_TYPE,
            "NS_E_NETWORK_SERVICE_FAILURE" => MEDIASERVER::NS_E_NETWORK_SERVICE_FAILURE,
            "NS_E_NETWORK_RESOURCE_FAILURE" => MEDIASERVER::NS_E_NETWORK_RESOURCE_FAILURE,
            "NS_E_CONNECTION_FAILURE" => MEDIASERVER::NS_E_CONNECTION_FAILURE,
            "NS_E_SHUTDOWN" => MEDIASERVER::NS_E_SHUTDOWN,
            "NS_E_INVALID_REQUEST" => MEDIASERVER::NS_E_INVALID_REQUEST,
            "NS_E_INSUFFICIENT_BANDWIDTH" => MEDIASERVER::NS_E_INSUFFICIENT_BANDWIDTH,
            "NS_E_NOT_REBUILDING" => MEDIASERVER::NS_E_NOT_REBUILDING,
            "NS_E_LATE_OPERATION" => MEDIASERVER::NS_E_LATE_OPERATION,
            "NS_E_INVALID_DATA" => MEDIASERVER::NS_E_INVALID_DATA,
            "NS_E_FILE_BANDWIDTH_LIMIT" => MEDIASERVER::NS_E_FILE_BANDWIDTH_LIMIT,
            "NS_E_OPEN_FILE_LIMIT" => MEDIASERVER::NS_E_OPEN_FILE_LIMIT,
            "NS_E_BAD_CONTROL_DATA" => MEDIASERVER::NS_E_BAD_CONTROL_DATA,
            "NS_E_NO_STREAM" => MEDIASERVER::NS_E_NO_STREAM,
            "NS_E_STREAM_END" => MEDIASERVER::NS_E_STREAM_END,
            "NS_E_SERVER_NOT_FOUND" => MEDIASERVER::NS_E_SERVER_NOT_FOUND,
            "NS_E_DUPLICATE_NAME" => MEDIASERVER::NS_E_DUPLICATE_NAME,
            "NS_E_DUPLICATE_ADDRESS" => MEDIASERVER::NS_E_DUPLICATE_ADDRESS,
            "NS_E_BAD_MULTICAST_ADDRESS" => MEDIASERVER::NS_E_BAD_MULTICAST_ADDRESS,
            "NS_E_BAD_ADAPTER_ADDRESS" => MEDIASERVER::NS_E_BAD_ADAPTER_ADDRESS,
            "NS_E_BAD_DELIVERY_MODE" => MEDIASERVER::NS_E_BAD_DELIVERY_MODE,
            "NS_E_INVALID_CHANNEL" => MEDIASERVER::NS_E_INVALID_CHANNEL,
            "NS_E_INVALID_STREAM" => MEDIASERVER::NS_E_INVALID_STREAM,
            "NS_E_INVALID_ARCHIVE" => MEDIASERVER::NS_E_INVALID_ARCHIVE,
            "NS_E_NOTITLES" => MEDIASERVER::NS_E_NOTITLES,
            "NS_E_INVALID_CLIENT" => MEDIASERVER::NS_E_INVALID_CLIENT,
            "NS_E_INVALID_BLACKHOLE_ADDRESS" => MEDIASERVER::NS_E_INVALID_BLACKHOLE_ADDRESS,
            "NS_E_INCOMPATIBLE_FORMAT" => MEDIASERVER::NS_E_INCOMPATIBLE_FORMAT,
            "NS_E_INVALID_KEY" => MEDIASERVER::NS_E_INVALID_KEY,
            "NS_E_INVALID_PORT" => MEDIASERVER::NS_E_INVALID_PORT,
            "NS_E_INVALID_TTL" => MEDIASERVER::NS_E_INVALID_TTL,
            "NS_E_STRIDE_REFUSED" => MEDIASERVER::NS_E_STRIDE_REFUSED,
            "NS_E_MMSAUTOSERVER_CANTFINDWALKER" => MEDIASERVER::NS_E_MMSAUTOSERVER_CANTFINDWALKER,
            "NS_E_MAX_BITRATE" => MEDIASERVER::NS_E_MAX_BITRATE,
            "NS_E_LOGFILEPERIOD" => MEDIASERVER::NS_E_LOGFILEPERIOD,
            "NS_E_MAX_CLIENTS" => MEDIASERVER::NS_E_MAX_CLIENTS,
            "NS_E_LOG_FILE_SIZE" => MEDIASERVER::NS_E_LOG_FILE_SIZE,
            "NS_E_MAX_FILERATE" => MEDIASERVER::NS_E_MAX_FILERATE,
            "NS_E_WALKER_UNKNOWN" => MEDIASERVER::NS_E_WALKER_UNKNOWN,
            "NS_E_WALKER_SERVER" => MEDIASERVER::NS_E_WALKER_SERVER,
            "NS_E_WALKER_USAGE" => MEDIASERVER::NS_E_WALKER_USAGE,
            "NS_E_TIGER_FAIL" => MEDIASERVER::NS_E_TIGER_FAIL,
            "NS_E_CUB_FAIL" => MEDIASERVER::NS_E_CUB_FAIL,
            "NS_E_DISK_FAIL" => MEDIASERVER::NS_E_DISK_FAIL,
            "NS_E_MAX_FUNNELS_ALERT" => MEDIASERVER::NS_E_MAX_FUNNELS_ALERT,
            "NS_E_ALLOCATE_FILE_FAIL" => MEDIASERVER::NS_E_ALLOCATE_FILE_FAIL,
            "NS_E_PAGING_ERROR" => MEDIASERVER::NS_E_PAGING_ERROR,
            "NS_E_BAD_BLOCK0_VERSION" => MEDIASERVER::NS_E_BAD_BLOCK0_VERSION,
            "NS_E_BAD_DISK_UID" => MEDIASERVER::NS_E_BAD_DISK_UID,
            "NS_E_BAD_FSMAJOR_VERSION" => MEDIASERVER::NS_E_BAD_FSMAJOR_VERSION,
            "NS_E_BAD_STAMPNUMBER" => MEDIASERVER::NS_E_BAD_STAMPNUMBER,
            "NS_E_PARTIALLY_REBUILT_DISK" => MEDIASERVER::NS_E_PARTIALLY_REBUILT_DISK,
            "NS_E_ENACTPLAN_GIVEUP" => MEDIASERVER::NS_E_ENACTPLAN_GIVEUP,
            "MCMADM_E_REGKEY_NOT_FOUND" => MEDIASERVER::MCMADM_E_REGKEY_NOT_FOUND,
            "NS_E_NO_FORMATS" => MEDIASERVER::NS_E_NO_FORMATS,
            "NS_E_NO_REFERENCES" => MEDIASERVER::NS_E_NO_REFERENCES,
            "NS_E_WAVE_OPEN" => MEDIASERVER::NS_E_WAVE_OPEN,
            "NS_E_CANNOTCONNECTEVENTS" => MEDIASERVER::NS_E_CANNOTCONNECTEVENTS,
            "NS_E_NO_DEVICE" => MEDIASERVER::NS_E_NO_DEVICE,
            "NS_E_NO_SPECIFIED_DEVICE" => MEDIASERVER::NS_E_NO_SPECIFIED_DEVICE,
            "NS_E_MONITOR_GIVEUP" => MEDIASERVER::NS_E_MONITOR_GIVEUP,
            "NS_E_REMIRRORED_DISK" => MEDIASERVER::NS_E_REMIRRORED_DISK,
            "NS_E_INSUFFICIENT_DATA" => MEDIASERVER::NS_E_INSUFFICIENT_DATA,
            "NS_E_ASSERT" => MEDIASERVER::NS_E_ASSERT,
            "NS_E_BAD_ADAPTER_NAME" => MEDIASERVER::NS_E_BAD_ADAPTER_NAME,
            "NS_E_NOT_LICENSED" => MEDIASERVER::NS_E_NOT_LICENSED,
            "NS_E_NO_SERVER_CONTACT" => MEDIASERVER::NS_E_NO_SERVER_CONTACT,
            "NS_E_TOO_MANY_TITLES" => MEDIASERVER::NS_E_TOO_MANY_TITLES,
            "NS_E_TITLE_SIZE_EXCEEDED" => MEDIASERVER::NS_E_TITLE_SIZE_EXCEEDED,
            "NS_E_UDP_DISABLED" => MEDIASERVER::NS_E_UDP_DISABLED,
            "NS_E_TCP_DISABLED" => MEDIASERVER::NS_E_TCP_DISABLED,
            "NS_E_HTTP_DISABLED" => MEDIASERVER::NS_E_HTTP_DISABLED,
            "NS_E_LICENSE_EXPIRED" => MEDIASERVER::NS_E_LICENSE_EXPIRED,
            "NS_E_TITLE_BITRATE" => MEDIASERVER::NS_E_TITLE_BITRATE,
            "NS_E_EMPTY_PROGRAM_NAME" => MEDIASERVER::NS_E_EMPTY_PROGRAM_NAME,
            "NS_E_MISSING_CHANNEL" => MEDIASERVER::NS_E_MISSING_CHANNEL,
            "NS_E_NO_CHANNELS" => MEDIASERVER::NS_E_NO_CHANNELS,
            "NS_E_INVALID_INDEX2" => MEDIASERVER::NS_E_INVALID_INDEX2,
            "NS_E_CUB_FAIL_LINK" => MEDIASERVER::NS_E_CUB_FAIL_LINK,
            "NS_E_BAD_CUB_UID" => MEDIASERVER::NS_E_BAD_CUB_UID,
            "NS_E_GLITCH_MODE" => MEDIASERVER::NS_E_GLITCH_MODE,
            "NS_E_NO_MEDIA_PROTOCOL" => MEDIASERVER::NS_E_NO_MEDIA_PROTOCOL,
            "ASF_E_BUFFEROVERRUN" => MEDIASERVER::ASF_E_BUFFEROVERRUN,
            "ASF_E_BUFFERTOOSMALL" => MEDIASERVER::ASF_E_BUFFERTOOSMALL,
            "ASF_E_BADLANGUAGEID" => MEDIASERVER::ASF_E_BADLANGUAGEID,
            "ASF_E_NOPAYLOADLENGTH" => MEDIASERVER::ASF_E_NOPAYLOADLENGTH,
            "ASF_E_TOOMANYPAYLOADS" => MEDIASERVER::ASF_E_TOOMANYPAYLOADS,
            "ASF_E_PACKETCONTENTTOOLARGE" => MEDIASERVER::ASF_E_PACKETCONTENTTOOLARGE,
            "ASF_E_UNKNOWNPACKETSIZE" => MEDIASERVER::ASF_E_UNKNOWNPACKETSIZE,
            "ASF_E_INVALIDHEADER" => MEDIASERVER::ASF_E_INVALIDHEADER,
            "ASF_E_NOCLOCKOBJECT" => MEDIASERVER::ASF_E_NOCLOCKOBJECT,
            "ASF_E_UNKNOWNCLOCKTYPE" => MEDIASERVER::ASF_E_UNKNOWNCLOCKTYPE,
            "ASF_E_OPAQUEPACKET" => MEDIASERVER::ASF_E_OPAQUEPACKET,
            "ASF_E_WRONGVERSION" => MEDIASERVER::ASF_E_WRONGVERSION,
            "ASF_E_OVERFLOW" => MEDIASERVER::ASF_E_OVERFLOW,
            "ASF_E_NOTFOUND" => MEDIASERVER::ASF_E_NOTFOUND,
            "NS_E_NOTHING_TO_DO" => MEDIASERVER::NS_E_NOTHING_TO_DO,
            "NS_E_NO_MULTICAST" => MEDIASERVER::NS_E_NO_MULTICAST,
            "ASF_E_OBJECTTOOBIG" => MEDIASERVER::ASF_E_OBJECTTOOBIG,
            "ASF_E_UNEXPECTEDVALUE" => MEDIASERVER::ASF_E_UNEXPECTEDVALUE,
            "ASF_E_INVALIDSTATE" => MEDIASERVER::ASF_E_INVALIDSTATE,
            "ASF_E_NOLIBRARY" => MEDIASERVER::ASF_E_NOLIBRARY,
            "ASF_E_ALREADYINITIALIZED" => MEDIASERVER::ASF_E_ALREADYINITIALIZED,
            "ASF_E_INVALIDINIT" => MEDIASERVER::ASF_E_INVALIDINIT,
            "ASF_E_NOHEADEROBJECT" => MEDIASERVER::ASF_E_NOHEADEROBJECT,
            "ASF_E_NODATAOBJECT" => MEDIASERVER::ASF_E_NODATAOBJECT,
            "ASF_E_NOINDEXOBJECT" => MEDIASERVER::ASF_E_NOINDEXOBJECT,
            "ASF_E_NOSTREAMPROPS" => MEDIASERVER::ASF_E_NOSTREAMPROPS,
            "ASF_E_NOFILEPROPS" => MEDIASERVER::ASF_E_NOFILEPROPS,
            "ASF_E_INVALIDFLAGS" => MEDIASERVER::ASF_E_INVALIDFLAGS,
            "ASF_E_BADDATADESCRIPTOR" => MEDIASERVER::ASF_E_BADDATADESCRIPTOR,
            "ASF_E_BADINDEXINTERVAL" => MEDIASERVER::ASF_E_BADINDEXINTERVAL,
            "ASF_E_INVALIDTIME" => MEDIASERVER::ASF_E_INVALIDTIME,
            "ASF_E_INVALIDINDEX" => MEDIASERVER::ASF_E_INVALIDINDEX,
            "ASF_E_STREAMNUMBERINUSE" => MEDIASERVER::ASF_E_STREAMNUMBERINUSE,
            "ASF_E_BADMEDIATYPE" => MEDIASERVER::ASF_E_BADMEDIATYPE,
            "ASF_E_WRITEFAILED" => MEDIASERVER::ASF_E_WRITEFAILED,
            "ASF_E_NOTENOUGHDESCRIPTORS" => MEDIASERVER::ASF_E_NOTENOUGHDESCRIPTORS,
            "ASF_E_INDEXBLOCKUNLOADED" => MEDIASERVER::ASF_E_INDEXBLOCKUNLOADED,
            "ASF_E_NOTENOUGHBANDWIDTH" => MEDIASERVER::ASF_E_NOTENOUGHBANDWIDTH,
            "ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE" => MEDIASERVER::ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE,
            "ASF_E_BADDATAUNIT" => MEDIASERVER::ASF_E_BADDATAUNIT,
            "ASF_E_HEADERSIZE" => MEDIASERVER::ASF_E_HEADERSIZE,
            "NS_E_INVALID_INPUT_FORMAT" => MEDIASERVER::NS_E_INVALID_INPUT_FORMAT,
            "NS_E_MSAUDIO_NOT_INSTALLED" => MEDIASERVER::NS_E_MSAUDIO_NOT_INSTALLED,
            "NS_E_UNEXPECTED_MSAUDIO_ERROR" => MEDIASERVER::NS_E_UNEXPECTED_MSAUDIO_ERROR,
            "NS_E_INVALID_OUTPUT_FORMAT" => MEDIASERVER::NS_E_INVALID_OUTPUT_FORMAT,
            "NS_E_NOT_CONFIGURED" => MEDIASERVER::NS_E_NOT_CONFIGURED,
            "NS_E_PROTECTED_CONTENT" => MEDIASERVER::NS_E_PROTECTED_CONTENT,
            "NS_E_LICENSE_REQUIRED" => MEDIASERVER::NS_E_LICENSE_REQUIRED,
            "NS_E_TAMPERED_CONTENT" => MEDIASERVER::NS_E_TAMPERED_CONTENT,
            "NS_E_LICENSE_OUTOFDATE" => MEDIASERVER::NS_E_LICENSE_OUTOFDATE,
            "NS_E_LICENSE_INCORRECT_RIGHTS" => MEDIASERVER::NS_E_LICENSE_INCORRECT_RIGHTS,
            "NS_E_AUDIO_CODEC_NOT_INSTALLED" => MEDIASERVER::NS_E_AUDIO_CODEC_NOT_INSTALLED,
            "NS_E_AUDIO_CODEC_ERROR" => MEDIASERVER::NS_E_AUDIO_CODEC_ERROR,
            "NS_E_VIDEO_CODEC_NOT_INSTALLED" => MEDIASERVER::NS_E_VIDEO_CODEC_NOT_INSTALLED,
            "NS_E_VIDEO_CODEC_ERROR" => MEDIASERVER::NS_E_VIDEO_CODEC_ERROR,
            "NS_E_INVALIDPROFILE" => MEDIASERVER::NS_E_INVALIDPROFILE,
            "NS_E_INCOMPATIBLE_VERSION" => MEDIASERVER::NS_E_INCOMPATIBLE_VERSION,
            "NS_E_OFFLINE_MODE" => MEDIASERVER::NS_E_OFFLINE_MODE,
            "NS_E_NOT_CONNECTED" => MEDIASERVER::NS_E_NOT_CONNECTED,
            "NS_E_TOO_MUCH_DATA" => MEDIASERVER::NS_E_TOO_MUCH_DATA,
            "NS_E_UNSUPPORTED_PROPERTY" => MEDIASERVER::NS_E_UNSUPPORTED_PROPERTY,
            "NS_E_8BIT_WAVE_UNSUPPORTED" => MEDIASERVER::NS_E_8BIT_WAVE_UNSUPPORTED,
            "NS_E_NO_MORE_SAMPLES" => MEDIASERVER::NS_E_NO_MORE_SAMPLES,
            "NS_E_INVALID_SAMPLING_RATE" => MEDIASERVER::NS_E_INVALID_SAMPLING_RATE,
            "NS_E_MAX_PACKET_SIZE_TOO_SMALL" => MEDIASERVER::NS_E_MAX_PACKET_SIZE_TOO_SMALL,
            "NS_E_LATE_PACKET" => MEDIASERVER::NS_E_LATE_PACKET,
            "NS_E_DUPLICATE_PACKET" => MEDIASERVER::NS_E_DUPLICATE_PACKET,
            "NS_E_SDK_BUFFERTOOSMALL" => MEDIASERVER::NS_E_SDK_BUFFERTOOSMALL,
            "NS_E_INVALID_NUM_PASSES" => MEDIASERVER::NS_E_INVALID_NUM_PASSES,
            "NS_E_ATTRIBUTE_READ_ONLY" => MEDIASERVER::NS_E_ATTRIBUTE_READ_ONLY,
            "NS_E_ATTRIBUTE_NOT_ALLOWED" => MEDIASERVER::NS_E_ATTRIBUTE_NOT_ALLOWED,
            "NS_E_INVALID_EDL" => MEDIASERVER::NS_E_INVALID_EDL,
            "NS_E_DATA_UNIT_EXTENSION_TOO_LARGE" => MEDIASERVER::NS_E_DATA_UNIT_EXTENSION_TOO_LARGE,
            "NS_E_CODEC_DMO_ERROR" => MEDIASERVER::NS_E_CODEC_DMO_ERROR,
            "NS_E_FEATURE_DISABLED_BY_GROUP_POLICY" => MEDIASERVER::NS_E_FEATURE_DISABLED_BY_GROUP_POLICY,
            "NS_E_FEATURE_DISABLED_IN_SKU" => MEDIASERVER::NS_E_FEATURE_DISABLED_IN_SKU,
            "NS_E_NO_CD" => MEDIASERVER::NS_E_NO_CD,
            "NS_E_CANT_READ_DIGITAL" => MEDIASERVER::NS_E_CANT_READ_DIGITAL,
            "NS_E_DEVICE_DISCONNECTED" => MEDIASERVER::NS_E_DEVICE_DISCONNECTED,
            "NS_E_DEVICE_NOT_SUPPORT_FORMAT" => MEDIASERVER::NS_E_DEVICE_NOT_SUPPORT_FORMAT,
            "NS_E_SLOW_READ_DIGITAL" => MEDIASERVER::NS_E_SLOW_READ_DIGITAL,
            "NS_E_MIXER_INVALID_LINE" => MEDIASERVER::NS_E_MIXER_INVALID_LINE,
            "NS_E_MIXER_INVALID_CONTROL" => MEDIASERVER::NS_E_MIXER_INVALID_CONTROL,
            "NS_E_MIXER_INVALID_VALUE" => MEDIASERVER::NS_E_MIXER_INVALID_VALUE,
            "NS_E_MIXER_UNKNOWN_MMRESULT" => MEDIASERVER::NS_E_MIXER_UNKNOWN_MMRESULT,
            "NS_E_USER_STOP" => MEDIASERVER::NS_E_USER_STOP,
            "NS_E_MP3_FORMAT_NOT_FOUND" => MEDIASERVER::NS_E_MP3_FORMAT_NOT_FOUND,
            "NS_E_CD_READ_ERROR_NO_CORRECTION" => MEDIASERVER::NS_E_CD_READ_ERROR_NO_CORRECTION,
            "NS_E_CD_READ_ERROR" => MEDIASERVER::NS_E_CD_READ_ERROR,
            "NS_E_CD_SLOW_COPY" => MEDIASERVER::NS_E_CD_SLOW_COPY,
            "NS_E_CD_COPYTO_CD" => MEDIASERVER::NS_E_CD_COPYTO_CD,
            "NS_E_MIXER_NODRIVER" => MEDIASERVER::NS_E_MIXER_NODRIVER,
            "NS_E_REDBOOK_ENABLED_WHILE_COPYING" => MEDIASERVER::NS_E_REDBOOK_ENABLED_WHILE_COPYING,
            "NS_E_CD_REFRESH" => MEDIASERVER::NS_E_CD_REFRESH,
            "NS_E_CD_DRIVER_PROBLEM" => MEDIASERVER::NS_E_CD_DRIVER_PROBLEM,
            "NS_E_WONT_DO_DIGITAL" => MEDIASERVER::NS_E_WONT_DO_DIGITAL,
            "NS_E_WMPXML_NOERROR" => MEDIASERVER::NS_E_WMPXML_NOERROR,
            "NS_E_WMPXML_ENDOFDATA" => MEDIASERVER::NS_E_WMPXML_ENDOFDATA,
            "NS_E_WMPXML_PARSEERROR" => MEDIASERVER::NS_E_WMPXML_PARSEERROR,
            "NS_E_WMPXML_ATTRIBUTENOTFOUND" => MEDIASERVER::NS_E_WMPXML_ATTRIBUTENOTFOUND,
            "NS_E_WMPXML_PINOTFOUND" => MEDIASERVER::NS_E_WMPXML_PINOTFOUND,
            "NS_E_WMPXML_EMPTYDOC" => MEDIASERVER::NS_E_WMPXML_EMPTYDOC,
            "NS_E_WMP_PATH_ALREADY_IN_LIBRARY" => MEDIASERVER::NS_E_WMP_PATH_ALREADY_IN_LIBRARY,
            "NS_E_WMP_FILESCANALREADYSTARTED" => MEDIASERVER::NS_E_WMP_FILESCANALREADYSTARTED,
            "NS_E_WMP_HME_INVALIDOBJECTID" => MEDIASERVER::NS_E_WMP_HME_INVALIDOBJECTID,
            "NS_E_WMP_MF_CODE_EXPIRED" => MEDIASERVER::NS_E_WMP_MF_CODE_EXPIRED,
            "NS_E_WMP_HME_NOTSEARCHABLEFORITEMS" => MEDIASERVER::NS_E_WMP_HME_NOTSEARCHABLEFORITEMS,
            "NS_E_WMP_ADDTOLIBRARY_FAILED" => MEDIASERVER::NS_E_WMP_ADDTOLIBRARY_FAILED,
            "NS_E_WMP_WINDOWSAPIFAILURE" => MEDIASERVER::NS_E_WMP_WINDOWSAPIFAILURE,
            "NS_E_WMP_RECORDING_NOT_ALLOWED" => MEDIASERVER::NS_E_WMP_RECORDING_NOT_ALLOWED,
            "NS_E_DEVICE_NOT_READY" => MEDIASERVER::NS_E_DEVICE_NOT_READY,
            "NS_E_DAMAGED_FILE" => MEDIASERVER::NS_E_DAMAGED_FILE,
            "NS_E_MPDB_GENERIC" => MEDIASERVER::NS_E_MPDB_GENERIC,
            "NS_E_FILE_FAILED_CHECKS" => MEDIASERVER::NS_E_FILE_FAILED_CHECKS,
            "NS_E_MEDIA_LIBRARY_FAILED" => MEDIASERVER::NS_E_MEDIA_LIBRARY_FAILED,
            "NS_E_SHARING_VIOLATION" => MEDIASERVER::NS_E_SHARING_VIOLATION,
            "NS_E_NO_ERROR_STRING_FOUND" => MEDIASERVER::NS_E_NO_ERROR_STRING_FOUND,
            "NS_E_WMPOCX_NO_REMOTE_CORE" => MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_CORE,
            "NS_E_WMPOCX_NO_ACTIVE_CORE" => MEDIASERVER::NS_E_WMPOCX_NO_ACTIVE_CORE,
            "NS_E_WMPOCX_NOT_RUNNING_REMOTELY" => MEDIASERVER::NS_E_WMPOCX_NOT_RUNNING_REMOTELY,
            "NS_E_WMPOCX_NO_REMOTE_WINDOW" => MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_WINDOW,
            "NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE" => MEDIASERVER::NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE,
            "NS_E_PLUGIN_NOTSHUTDOWN" => MEDIASERVER::NS_E_PLUGIN_NOTSHUTDOWN,
            "NS_E_WMP_CANNOT_FIND_FOLDER" => MEDIASERVER::NS_E_WMP_CANNOT_FIND_FOLDER,
            "NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED" => MEDIASERVER::NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED,
            "NS_E_WMP_PLUGINDLL_NOTFOUND" => MEDIASERVER::NS_E_WMP_PLUGINDLL_NOTFOUND,
            "NS_E_NEED_TO_ASK_USER" => MEDIASERVER::NS_E_NEED_TO_ASK_USER,
            "NS_E_WMPOCX_PLAYER_NOT_DOCKED" => MEDIASERVER::NS_E_WMPOCX_PLAYER_NOT_DOCKED,
            "NS_E_WMP_EXTERNAL_NOTREADY" => MEDIASERVER::NS_E_WMP_EXTERNAL_NOTREADY,
            "NS_E_WMP_MLS_STALE_DATA" => MEDIASERVER::NS_E_WMP_MLS_STALE_DATA,
            "NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED" => MEDIASERVER::NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED,
            "NS_E_WMP_UI_VERSIONMISMATCH" => MEDIASERVER::NS_E_WMP_UI_VERSIONMISMATCH,
            "NS_E_WMP_UI_NOTATHEMEFILE" => MEDIASERVER::NS_E_WMP_UI_NOTATHEMEFILE,
            "NS_E_WMP_UI_SUBELEMENTNOTFOUND" => MEDIASERVER::NS_E_WMP_UI_SUBELEMENTNOTFOUND,
            "NS_E_WMP_UI_VERSIONPARSE" => MEDIASERVER::NS_E_WMP_UI_VERSIONPARSE,
            "NS_E_WMP_UI_VIEWIDNOTFOUND" => MEDIASERVER::NS_E_WMP_UI_VIEWIDNOTFOUND,
            "NS_E_WMP_UI_PASSTHROUGH" => MEDIASERVER::NS_E_WMP_UI_PASSTHROUGH,
            "NS_E_WMP_UI_OBJECTNOTFOUND" => MEDIASERVER::NS_E_WMP_UI_OBJECTNOTFOUND,
            "NS_E_WMP_UI_SECONDHANDLER" => MEDIASERVER::NS_E_WMP_UI_SECONDHANDLER,
            "NS_E_WMP_UI_NOSKININZIP" => MEDIASERVER::NS_E_WMP_UI_NOSKININZIP,
            "NS_E_WMP_URLDOWNLOADFAILED" => MEDIASERVER::NS_E_WMP_URLDOWNLOADFAILED,
            "NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN" => MEDIASERVER::NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN,
            "NS_E_WMP_INVALID_SKIN" => MEDIASERVER::NS_E_WMP_INVALID_SKIN,
            "NS_E_WMP_SENDMAILFAILED" => MEDIASERVER::NS_E_WMP_SENDMAILFAILED,
            "NS_E_WMP_LOCKEDINSKINMODE" => MEDIASERVER::NS_E_WMP_LOCKEDINSKINMODE,
            "NS_E_WMP_FAILED_TO_SAVE_FILE" => MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_FILE,
            "NS_E_WMP_SAVEAS_READONLY" => MEDIASERVER::NS_E_WMP_SAVEAS_READONLY,
            "NS_E_WMP_FAILED_TO_SAVE_PLAYLIST" => MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_PLAYLIST,
            "NS_E_WMP_FAILED_TO_OPEN_WMD" => MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_WMD,
            "NS_E_WMP_CANT_PLAY_PROTECTED" => MEDIASERVER::NS_E_WMP_CANT_PLAY_PROTECTED,
            "NS_E_SHARING_STATE_OUT_OF_SYNC" => MEDIASERVER::NS_E_SHARING_STATE_OUT_OF_SYNC,
            "NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING" => MEDIASERVER::NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING,
            "NS_E_WMP_RBC_JPGMAPPINGIMAGE" => MEDIASERVER::NS_E_WMP_RBC_JPGMAPPINGIMAGE,
            "NS_E_WMP_JPGTRANSPARENCY" => MEDIASERVER::NS_E_WMP_JPGTRANSPARENCY,
            "NS_E_WMP_INVALID_MAX_VAL" => MEDIASERVER::NS_E_WMP_INVALID_MAX_VAL,
            "NS_E_WMP_INVALID_MIN_VAL" => MEDIASERVER::NS_E_WMP_INVALID_MIN_VAL,
            "NS_E_WMP_CS_JPGPOSITIONIMAGE" => MEDIASERVER::NS_E_WMP_CS_JPGPOSITIONIMAGE,
            "NS_E_WMP_CS_NOTEVENLYDIVISIBLE" => MEDIASERVER::NS_E_WMP_CS_NOTEVENLYDIVISIBLE,
            "NS_E_WMPZIP_NOTAZIPFILE" => MEDIASERVER::NS_E_WMPZIP_NOTAZIPFILE,
            "NS_E_WMPZIP_CORRUPT" => MEDIASERVER::NS_E_WMPZIP_CORRUPT,
            "NS_E_WMPZIP_FILENOTFOUND" => MEDIASERVER::NS_E_WMPZIP_FILENOTFOUND,
            "NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED" => MEDIASERVER::NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED,
            "NS_E_WMP_IMAGE_INVALID_FORMAT" => MEDIASERVER::NS_E_WMP_IMAGE_INVALID_FORMAT,
            "NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE" => MEDIASERVER::NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE,
            "NS_E_WMP_GIF_INVALID_FORMAT" => MEDIASERVER::NS_E_WMP_GIF_INVALID_FORMAT,
            "NS_E_WMP_GIF_BAD_VERSION_NUMBER" => MEDIASERVER::NS_E_WMP_GIF_BAD_VERSION_NUMBER,
            "NS_E_WMP_GIF_NO_IMAGE_IN_FILE" => MEDIASERVER::NS_E_WMP_GIF_NO_IMAGE_IN_FILE,
            "NS_E_WMP_PNG_INVALIDFORMAT" => MEDIASERVER::NS_E_WMP_PNG_INVALIDFORMAT,
            "NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH" => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH,
            "NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION" => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION,
            "NS_E_WMP_PNG_UNSUPPORTED_FILTER" => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_FILTER,
            "NS_E_WMP_PNG_UNSUPPORTED_INTERLACE" => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_INTERLACE,
            "NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC" => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC,
            "NS_E_WMP_BMP_INVALID_BITMASK" => MEDIASERVER::NS_E_WMP_BMP_INVALID_BITMASK,
            "NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED" => MEDIASERVER::NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED,
            "NS_E_WMP_BMP_BITMAP_NOT_CREATED" => MEDIASERVER::NS_E_WMP_BMP_BITMAP_NOT_CREATED,
            "NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED" => MEDIASERVER::NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED,
            "NS_E_WMP_BMP_INVALID_FORMAT" => MEDIASERVER::NS_E_WMP_BMP_INVALID_FORMAT,
            "NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL" => MEDIASERVER::NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL,
            "NS_E_WMP_JPG_INVALID_FORMAT" => MEDIASERVER::NS_E_WMP_JPG_INVALID_FORMAT,
            "NS_E_WMP_JPG_BAD_DCTSIZE" => MEDIASERVER::NS_E_WMP_JPG_BAD_DCTSIZE,
            "NS_E_WMP_JPG_BAD_VERSION_NUMBER" => MEDIASERVER::NS_E_WMP_JPG_BAD_VERSION_NUMBER,
            "NS_E_WMP_JPG_BAD_PRECISION" => MEDIASERVER::NS_E_WMP_JPG_BAD_PRECISION,
            "NS_E_WMP_JPG_CCIR601_NOTIMPL" => MEDIASERVER::NS_E_WMP_JPG_CCIR601_NOTIMPL,
            "NS_E_WMP_JPG_NO_IMAGE_IN_FILE" => MEDIASERVER::NS_E_WMP_JPG_NO_IMAGE_IN_FILE,
            "NS_E_WMP_JPG_READ_ERROR" => MEDIASERVER::NS_E_WMP_JPG_READ_ERROR,
            "NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL" => MEDIASERVER::NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL,
            "NS_E_WMP_JPG_IMAGE_TOO_BIG" => MEDIASERVER::NS_E_WMP_JPG_IMAGE_TOO_BIG,
            "NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE" => MEDIASERVER::NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE,
            "NS_E_WMP_JPG_SOF_UNSUPPORTED" => MEDIASERVER::NS_E_WMP_JPG_SOF_UNSUPPORTED,
            "NS_E_WMP_JPG_UNKNOWN_MARKER" => MEDIASERVER::NS_E_WMP_JPG_UNKNOWN_MARKER,
            "NS_E_WMP_FAILED_TO_OPEN_IMAGE" => MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_IMAGE,
            "NS_E_WMP_DAI_SONGTOOSHORT" => MEDIASERVER::NS_E_WMP_DAI_SONGTOOSHORT,
            "NS_E_WMG_RATEUNAVAILABLE" => MEDIASERVER::NS_E_WMG_RATEUNAVAILABLE,
            "NS_E_WMG_PLUGINUNAVAILABLE" => MEDIASERVER::NS_E_WMG_PLUGINUNAVAILABLE,
            "NS_E_WMG_CANNOTQUEUE" => MEDIASERVER::NS_E_WMG_CANNOTQUEUE,
            "NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED" => MEDIASERVER::NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED,
            "NS_E_WMG_UNEXPECTEDPREROLLSTATUS" => MEDIASERVER::NS_E_WMG_UNEXPECTEDPREROLLSTATUS,
            "NS_E_WMG_INVALID_COPP_CERTIFICATE" => MEDIASERVER::NS_E_WMG_INVALID_COPP_CERTIFICATE,
            "NS_E_WMG_COPP_SECURITY_INVALID" => MEDIASERVER::NS_E_WMG_COPP_SECURITY_INVALID,
            "NS_E_WMG_COPP_UNSUPPORTED" => MEDIASERVER::NS_E_WMG_COPP_UNSUPPORTED,
            "NS_E_WMG_INVALIDSTATE" => MEDIASERVER::NS_E_WMG_INVALIDSTATE,
            "NS_E_WMG_SINKALREADYEXISTS" => MEDIASERVER::NS_E_WMG_SINKALREADYEXISTS,
            "NS_E_WMG_NOSDKINTERFACE" => MEDIASERVER::NS_E_WMG_NOSDKINTERFACE,
            "NS_E_WMG_NOTALLOUTPUTSRENDERED" => MEDIASERVER::NS_E_WMG_NOTALLOUTPUTSRENDERED,
            "NS_E_WMG_FILETRANSFERNOTALLOWED" => MEDIASERVER::NS_E_WMG_FILETRANSFERNOTALLOWED,
            "NS_E_WMR_UNSUPPORTEDSTREAM" => MEDIASERVER::NS_E_WMR_UNSUPPORTEDSTREAM,
            "NS_E_WMR_PINNOTFOUND" => MEDIASERVER::NS_E_WMR_PINNOTFOUND,
            "NS_E_WMR_WAITINGONFORMATSWITCH" => MEDIASERVER::NS_E_WMR_WAITINGONFORMATSWITCH,
            "NS_E_WMR_NOSOURCEFILTER" => MEDIASERVER::NS_E_WMR_NOSOURCEFILTER,
            "NS_E_WMR_PINTYPENOMATCH" => MEDIASERVER::NS_E_WMR_PINTYPENOMATCH,
            "NS_E_WMR_NOCALLBACKAVAILABLE" => MEDIASERVER::NS_E_WMR_NOCALLBACKAVAILABLE,
            "NS_E_WMR_SAMPLEPROPERTYNOTSET" => MEDIASERVER::NS_E_WMR_SAMPLEPROPERTYNOTSET,
            "NS_E_WMR_CANNOT_RENDER_BINARY_STREAM" => MEDIASERVER::NS_E_WMR_CANNOT_RENDER_BINARY_STREAM,
            "NS_E_WMG_LICENSE_TAMPERED" => MEDIASERVER::NS_E_WMG_LICENSE_TAMPERED,
            "NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM" => MEDIASERVER::NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM,
            "NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT" => MEDIASERVER::NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT,
            "NS_E_ASX_INVALIDFORMAT" => MEDIASERVER::NS_E_ASX_INVALIDFORMAT,
            "NS_E_ASX_INVALIDVERSION" => MEDIASERVER::NS_E_ASX_INVALIDVERSION,
            "NS_E_ASX_INVALID_REPEAT_BLOCK" => MEDIASERVER::NS_E_ASX_INVALID_REPEAT_BLOCK,
            "NS_E_ASX_NOTHING_TO_WRITE" => MEDIASERVER::NS_E_ASX_NOTHING_TO_WRITE,
            "NS_E_URLLIST_INVALIDFORMAT" => MEDIASERVER::NS_E_URLLIST_INVALIDFORMAT,
            "NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST" => MEDIASERVER::NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST,
            "NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS" => MEDIASERVER::NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS,
            "NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE" => MEDIASERVER::NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE,
            "NS_E_WMX_ITEM_DOES_NOT_EXIST" => MEDIASERVER::NS_E_WMX_ITEM_DOES_NOT_EXIST,
            "NS_E_WMX_ITEM_TYPE_ILLEGAL" => MEDIASERVER::NS_E_WMX_ITEM_TYPE_ILLEGAL,
            "NS_E_WMX_ITEM_UNSETTABLE" => MEDIASERVER::NS_E_WMX_ITEM_UNSETTABLE,
            "NS_E_WMX_PLAYLIST_EMPTY" => MEDIASERVER::NS_E_WMX_PLAYLIST_EMPTY,
            "NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED" => MEDIASERVER::NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED,
            "NS_E_WMX_INVALID_FORMAT_OVER_NESTING" => MEDIASERVER::NS_E_WMX_INVALID_FORMAT_OVER_NESTING,
            "NS_E_WMPCORE_NOSOURCEURLSTRING" => MEDIASERVER::NS_E_WMPCORE_NOSOURCEURLSTRING,
            "NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT" => MEDIASERVER::NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT,
            "NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE" => MEDIASERVER::NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE,
            "NS_E_WMPCORE_BUFFERTOOSMALL" => MEDIASERVER::NS_E_WMPCORE_BUFFERTOOSMALL,
            "NS_E_WMPCORE_UNAVAILABLE" => MEDIASERVER::NS_E_WMPCORE_UNAVAILABLE,
            "NS_E_WMPCORE_INVALIDPLAYLISTMODE" => MEDIASERVER::NS_E_WMPCORE_INVALIDPLAYLISTMODE,
            "NS_E_WMPCORE_ITEMNOTINPLAYLIST" => MEDIASERVER::NS_E_WMPCORE_ITEMNOTINPLAYLIST,
            "NS_E_WMPCORE_PLAYLISTEMPTY" => MEDIASERVER::NS_E_WMPCORE_PLAYLISTEMPTY,
            "NS_E_WMPCORE_NOBROWSER" => MEDIASERVER::NS_E_WMPCORE_NOBROWSER,
            "NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL" => MEDIASERVER::NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL,
            "NS_E_WMPCORE_GRAPH_NOT_IN_LIST" => MEDIASERVER::NS_E_WMPCORE_GRAPH_NOT_IN_LIST,
            "NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA,
            "NS_E_WMPCORE_ERRORSINKNOTREGISTERED" => MEDIASERVER::NS_E_WMPCORE_ERRORSINKNOTREGISTERED,
            "NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE" => MEDIASERVER::NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE,
            "NS_E_WMPCORE_WEBHELPFAILED" => MEDIASERVER::NS_E_WMPCORE_WEBHELPFAILED,
            "NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED" => MEDIASERVER::NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED,
            "NS_E_WMPCORE_NO_REF_IN_ENTRY" => MEDIASERVER::NS_E_WMPCORE_NO_REF_IN_ENTRY,
            "NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY,
            "NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL,
            "NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY,
            "NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL,
            "NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY,
            "NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL,
            "NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY" => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY,
            "NS_E_WMPCORE_LIST_ENTRY_NO_REF" => MEDIASERVER::NS_E_WMPCORE_LIST_ENTRY_NO_REF,
            "NS_E_WMPCORE_MISNAMED_FILE" => MEDIASERVER::NS_E_WMPCORE_MISNAMED_FILE,
            "NS_E_WMPCORE_CODEC_NOT_TRUSTED" => MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_TRUSTED,
            "NS_E_WMPCORE_CODEC_NOT_FOUND" => MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_FOUND,
            "NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED" => MEDIASERVER::NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED,
            "NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST" => MEDIASERVER::NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST,
            "NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST" => MEDIASERVER::NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST,
            "NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE,
            "NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED,
            "NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND,
            "NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED,
            "NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED,
            "NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY" => MEDIASERVER::NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY,
            "NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME,
            "NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT,
            "NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY,
            "NS_E_WMPCORE_PLAYLIST_STACK_EMPTY" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_STACK_EMPTY,
            "NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE" => MEDIASERVER::NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE,
            "NS_E_WMPCORE_USER_CANCEL" => MEDIASERVER::NS_E_WMPCORE_USER_CANCEL,
            "NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY,
            "NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE,
            "NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE,
            "NS_E_WMPCORE_INVALID_PLAYLIST_URL" => MEDIASERVER::NS_E_WMPCORE_INVALID_PLAYLIST_URL,
            "NS_E_WMPCORE_MISMATCHED_RUNTIME" => MEDIASERVER::NS_E_WMPCORE_MISMATCHED_RUNTIME,
            "NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS,
            "NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION" => MEDIASERVER::NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION,
            "NS_E_WMPCORE_MEDIA_UNAVAILABLE" => MEDIASERVER::NS_E_WMPCORE_MEDIA_UNAVAILABLE,
            "NS_E_WMPCORE_WMX_ENTRYREF_NO_REF" => MEDIASERVER::NS_E_WMPCORE_WMX_ENTRYREF_NO_REF,
            "NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST" => MEDIASERVER::NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST,
            "NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS" => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS,
            "NS_E_WMPCORE_BUSY" => MEDIASERVER::NS_E_WMPCORE_BUSY,
            "NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE" => MEDIASERVER::NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE,
            "NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST" => MEDIASERVER::NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST,
            "NS_E_WMPCORE_FILE_NOT_FOUND" => MEDIASERVER::NS_E_WMPCORE_FILE_NOT_FOUND,
            "NS_E_WMPCORE_TEMP_FILE_NOT_FOUND" => MEDIASERVER::NS_E_WMPCORE_TEMP_FILE_NOT_FOUND,
            "NS_E_WMDM_REVOKED" => MEDIASERVER::NS_E_WMDM_REVOKED,
            "NS_E_DDRAW_GENERIC" => MEDIASERVER::NS_E_DDRAW_GENERIC,
            "NS_E_DISPLAY_MODE_CHANGE_FAILED" => MEDIASERVER::NS_E_DISPLAY_MODE_CHANGE_FAILED,
            "NS_E_PLAYLIST_CONTAINS_ERRORS" => MEDIASERVER::NS_E_PLAYLIST_CONTAINS_ERRORS,
            "NS_E_CHANGING_PROXY_NAME" => MEDIASERVER::NS_E_CHANGING_PROXY_NAME,
            "NS_E_CHANGING_PROXY_PORT" => MEDIASERVER::NS_E_CHANGING_PROXY_PORT,
            "NS_E_CHANGING_PROXY_EXCEPTIONLIST" => MEDIASERVER::NS_E_CHANGING_PROXY_EXCEPTIONLIST,
            "NS_E_CHANGING_PROXYBYPASS" => MEDIASERVER::NS_E_CHANGING_PROXYBYPASS,
            "NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND" => MEDIASERVER::NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND,
            "NS_E_GRAPH_NOAUDIOLANGUAGE" => MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGE,
            "NS_E_GRAPH_NOAUDIOLANGUAGESELECTED" => MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGESELECTED,
            "NS_E_CORECD_NOTAMEDIACD" => MEDIASERVER::NS_E_CORECD_NOTAMEDIACD,
            "NS_E_WMPCORE_MEDIA_URL_TOO_LONG" => MEDIASERVER::NS_E_WMPCORE_MEDIA_URL_TOO_LONG,
            "NS_E_WMPFLASH_CANT_FIND_COM_SERVER" => MEDIASERVER::NS_E_WMPFLASH_CANT_FIND_COM_SERVER,
            "NS_E_WMPFLASH_INCOMPATIBLEVERSION" => MEDIASERVER::NS_E_WMPFLASH_INCOMPATIBLEVERSION,
            "NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS" => MEDIASERVER::NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS,
            "NS_E_NEED_CORE_REFERENCE" => MEDIASERVER::NS_E_NEED_CORE_REFERENCE,
            "NS_E_MEDIACD_READ_ERROR" => MEDIASERVER::NS_E_MEDIACD_READ_ERROR,
            "NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS" => MEDIASERVER::NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS,
            "NS_E_FLASH_PLAYBACK_NOT_ALLOWED" => MEDIASERVER::NS_E_FLASH_PLAYBACK_NOT_ALLOWED,
            "NS_E_UNABLE_TO_CREATE_RIP_LOCATION" => MEDIASERVER::NS_E_UNABLE_TO_CREATE_RIP_LOCATION,
            "NS_E_WMPCORE_SOME_CODECS_MISSING" => MEDIASERVER::NS_E_WMPCORE_SOME_CODECS_MISSING,
            "NS_E_WMP_RIP_FAILED" => MEDIASERVER::NS_E_WMP_RIP_FAILED,
            "NS_E_WMP_FAILED_TO_RIP_TRACK" => MEDIASERVER::NS_E_WMP_FAILED_TO_RIP_TRACK,
            "NS_E_WMP_ERASE_FAILED" => MEDIASERVER::NS_E_WMP_ERASE_FAILED,
            "NS_E_WMP_FORMAT_FAILED" => MEDIASERVER::NS_E_WMP_FORMAT_FAILED,
            "NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE" => MEDIASERVER::NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE,
            "NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD" => MEDIASERVER::NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD,
            "NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD" => MEDIASERVER::NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD,
            "NS_E_WMP_FILE_NO_DURATION" => MEDIASERVER::NS_E_WMP_FILE_NO_DURATION,
            "NS_E_PDA_FAILED_TO_BURN" => MEDIASERVER::NS_E_PDA_FAILED_TO_BURN,
            "NS_E_FAILED_DOWNLOAD_ABORT_BURN" => MEDIASERVER::NS_E_FAILED_DOWNLOAD_ABORT_BURN,
            "NS_E_WMPCORE_DEVICE_DRIVERS_MISSING" => MEDIASERVER::NS_E_WMPCORE_DEVICE_DRIVERS_MISSING,
            "NS_E_WMPIM_USEROFFLINE" => MEDIASERVER::NS_E_WMPIM_USEROFFLINE,
            "NS_E_WMPIM_USERCANCELED" => MEDIASERVER::NS_E_WMPIM_USERCANCELED,
            "NS_E_WMPIM_DIALUPFAILED" => MEDIASERVER::NS_E_WMPIM_DIALUPFAILED,
            "NS_E_WINSOCK_ERROR_STRING" => MEDIASERVER::NS_E_WINSOCK_ERROR_STRING,
            "NS_E_WMPBR_NOLISTENER" => MEDIASERVER::NS_E_WMPBR_NOLISTENER,
            "NS_E_WMPBR_BACKUPCANCEL" => MEDIASERVER::NS_E_WMPBR_BACKUPCANCEL,
            "NS_E_WMPBR_RESTORECANCEL" => MEDIASERVER::NS_E_WMPBR_RESTORECANCEL,
            "NS_E_WMPBR_ERRORWITHURL" => MEDIASERVER::NS_E_WMPBR_ERRORWITHURL,
            "NS_E_WMPBR_NAMECOLLISION" => MEDIASERVER::NS_E_WMPBR_NAMECOLLISION,
            "NS_E_WMPBR_DRIVE_INVALID" => MEDIASERVER::NS_E_WMPBR_DRIVE_INVALID,
            "NS_E_WMPBR_BACKUPRESTOREFAILED" => MEDIASERVER::NS_E_WMPBR_BACKUPRESTOREFAILED,
            "NS_E_WMP_CONVERT_FILE_FAILED" => MEDIASERVER::NS_E_WMP_CONVERT_FILE_FAILED,
            "NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL" => MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL,
            "NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL" => MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL,
            "NS_E_WMP_CONVERT_FILE_CORRUPT" => MEDIASERVER::NS_E_WMP_CONVERT_FILE_CORRUPT,
            "NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL" => MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL,
            "NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL" => MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL,
            "NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER" => MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER,
            "NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS" => MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS,
            "NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED" => MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED,
            "NS_E_DVD_NO_SUBPICTURE_STREAM" => MEDIASERVER::NS_E_DVD_NO_SUBPICTURE_STREAM,
            "NS_E_DVD_COPY_PROTECT" => MEDIASERVER::NS_E_DVD_COPY_PROTECT,
            "NS_E_DVD_AUTHORING_PROBLEM" => MEDIASERVER::NS_E_DVD_AUTHORING_PROBLEM,
            "NS_E_DVD_INVALID_DISC_REGION" => MEDIASERVER::NS_E_DVD_INVALID_DISC_REGION,
            "NS_E_DVD_COMPATIBLE_VIDEO_CARD" => MEDIASERVER::NS_E_DVD_COMPATIBLE_VIDEO_CARD,
            "NS_E_DVD_MACROVISION" => MEDIASERVER::NS_E_DVD_MACROVISION,
            "NS_E_DVD_SYSTEM_DECODER_REGION" => MEDIASERVER::NS_E_DVD_SYSTEM_DECODER_REGION,
            "NS_E_DVD_DISC_DECODER_REGION" => MEDIASERVER::NS_E_DVD_DISC_DECODER_REGION,
            "NS_E_DVD_NO_VIDEO_STREAM" => MEDIASERVER::NS_E_DVD_NO_VIDEO_STREAM,
            "NS_E_DVD_NO_AUDIO_STREAM" => MEDIASERVER::NS_E_DVD_NO_AUDIO_STREAM,
            "NS_E_DVD_GRAPH_BUILDING" => MEDIASERVER::NS_E_DVD_GRAPH_BUILDING,
            "NS_E_DVD_NO_DECODER" => MEDIASERVER::NS_E_DVD_NO_DECODER,
            "NS_E_DVD_PARENTAL" => MEDIASERVER::NS_E_DVD_PARENTAL,
            "NS_E_DVD_CANNOT_JUMP" => MEDIASERVER::NS_E_DVD_CANNOT_JUMP,
            "NS_E_DVD_DEVICE_CONTENTION" => MEDIASERVER::NS_E_DVD_DEVICE_CONTENTION,
            "NS_E_DVD_NO_VIDEO_MEMORY" => MEDIASERVER::NS_E_DVD_NO_VIDEO_MEMORY,
            "NS_E_DVD_CANNOT_COPY_PROTECTED" => MEDIASERVER::NS_E_DVD_CANNOT_COPY_PROTECTED,
            "NS_E_DVD_REQUIRED_PROPERTY_NOT_SET" => MEDIASERVER::NS_E_DVD_REQUIRED_PROPERTY_NOT_SET,
            "NS_E_DVD_INVALID_TITLE_CHAPTER" => MEDIASERVER::NS_E_DVD_INVALID_TITLE_CHAPTER,
            "NS_E_NO_CD_BURNER" => MEDIASERVER::NS_E_NO_CD_BURNER,
            "NS_E_DEVICE_IS_NOT_READY" => MEDIASERVER::NS_E_DEVICE_IS_NOT_READY,
            "NS_E_PDA_UNSUPPORTED_FORMAT" => MEDIASERVER::NS_E_PDA_UNSUPPORTED_FORMAT,
            "NS_E_NO_PDA" => MEDIASERVER::NS_E_NO_PDA,
            "NS_E_PDA_UNSPECIFIED_ERROR" => MEDIASERVER::NS_E_PDA_UNSPECIFIED_ERROR,
            "NS_E_MEMSTORAGE_BAD_DATA" => MEDIASERVER::NS_E_MEMSTORAGE_BAD_DATA,
            "NS_E_PDA_FAIL_SELECT_DEVICE" => MEDIASERVER::NS_E_PDA_FAIL_SELECT_DEVICE,
            "NS_E_PDA_FAIL_READ_WAVE_FILE" => MEDIASERVER::NS_E_PDA_FAIL_READ_WAVE_FILE,
            "NS_E_IMAPI_LOSSOFSTREAMING" => MEDIASERVER::NS_E_IMAPI_LOSSOFSTREAMING,
            "NS_E_PDA_DEVICE_FULL" => MEDIASERVER::NS_E_PDA_DEVICE_FULL,
            "NS_E_FAIL_LAUNCH_ROXIO_PLUGIN" => MEDIASERVER::NS_E_FAIL_LAUNCH_ROXIO_PLUGIN,
            "NS_E_PDA_DEVICE_FULL_IN_SESSION" => MEDIASERVER::NS_E_PDA_DEVICE_FULL_IN_SESSION,
            "NS_E_IMAPI_MEDIUM_INVALIDTYPE" => MEDIASERVER::NS_E_IMAPI_MEDIUM_INVALIDTYPE,
            "NS_E_PDA_MANUALDEVICE" => MEDIASERVER::NS_E_PDA_MANUALDEVICE,
            "NS_E_PDA_PARTNERSHIPNOTEXIST" => MEDIASERVER::NS_E_PDA_PARTNERSHIPNOTEXIST,
            "NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP" => MEDIASERVER::NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP,
            "NS_E_PDA_NO_TRANSCODE_OF_DRM" => MEDIASERVER::NS_E_PDA_NO_TRANSCODE_OF_DRM,
            "NS_E_PDA_TRANSCODECACHEFULL" => MEDIASERVER::NS_E_PDA_TRANSCODECACHEFULL,
            "NS_E_PDA_TOO_MANY_FILE_COLLISIONS" => MEDIASERVER::NS_E_PDA_TOO_MANY_FILE_COLLISIONS,
            "NS_E_PDA_CANNOT_TRANSCODE" => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE,
            "NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY" => MEDIASERVER::NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY,
            "NS_E_PROCESSINGSHOWSYNCWIZARD" => MEDIASERVER::NS_E_PROCESSINGSHOWSYNCWIZARD,
            "NS_E_PDA_TRANSCODE_NOT_PERMITTED" => MEDIASERVER::NS_E_PDA_TRANSCODE_NOT_PERMITTED,
            "NS_E_PDA_INITIALIZINGDEVICES" => MEDIASERVER::NS_E_PDA_INITIALIZINGDEVICES,
            "NS_E_PDA_OBSOLETE_SP" => MEDIASERVER::NS_E_PDA_OBSOLETE_SP,
            "NS_E_PDA_TITLE_COLLISION" => MEDIASERVER::NS_E_PDA_TITLE_COLLISION,
            "NS_E_PDA_DEVICESUPPORTDISABLED" => MEDIASERVER::NS_E_PDA_DEVICESUPPORTDISABLED,
            "NS_E_PDA_NO_LONGER_AVAILABLE" => MEDIASERVER::NS_E_PDA_NO_LONGER_AVAILABLE,
            "NS_E_PDA_ENCODER_NOT_RESPONDING" => MEDIASERVER::NS_E_PDA_ENCODER_NOT_RESPONDING,
            "NS_E_PDA_CANNOT_SYNC_FROM_LOCATION" => MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_LOCATION,
            "NS_E_WMP_PROTOCOL_PROBLEM" => MEDIASERVER::NS_E_WMP_PROTOCOL_PROBLEM,
            "NS_E_WMP_NO_DISK_SPACE" => MEDIASERVER::NS_E_WMP_NO_DISK_SPACE,
            "NS_E_WMP_LOGON_FAILURE" => MEDIASERVER::NS_E_WMP_LOGON_FAILURE,
            "NS_E_WMP_CANNOT_FIND_FILE" => MEDIASERVER::NS_E_WMP_CANNOT_FIND_FILE,
            "NS_E_WMP_SERVER_INACCESSIBLE" => MEDIASERVER::NS_E_WMP_SERVER_INACCESSIBLE,
            "NS_E_WMP_UNSUPPORTED_FORMAT" => MEDIASERVER::NS_E_WMP_UNSUPPORTED_FORMAT,
            "NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT" => MEDIASERVER::NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT,
            "NS_E_WMP_PLAYLIST_EXISTS" => MEDIASERVER::NS_E_WMP_PLAYLIST_EXISTS,
            "NS_E_WMP_NONMEDIA_FILES" => MEDIASERVER::NS_E_WMP_NONMEDIA_FILES,
            "NS_E_WMP_INVALID_ASX" => MEDIASERVER::NS_E_WMP_INVALID_ASX,
            "NS_E_WMP_ALREADY_IN_USE" => MEDIASERVER::NS_E_WMP_ALREADY_IN_USE,
            "NS_E_WMP_IMAPI_FAILURE" => MEDIASERVER::NS_E_WMP_IMAPI_FAILURE,
            "NS_E_WMP_WMDM_FAILURE" => MEDIASERVER::NS_E_WMP_WMDM_FAILURE,
            "NS_E_WMP_CODEC_NEEDED_WITH_4CC" => MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_4CC,
            "NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG" => MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG,
            "NS_E_WMP_MSSAP_NOT_AVAILABLE" => MEDIASERVER::NS_E_WMP_MSSAP_NOT_AVAILABLE,
            "NS_E_WMP_WMDM_INTERFACEDEAD" => MEDIASERVER::NS_E_WMP_WMDM_INTERFACEDEAD,
            "NS_E_WMP_WMDM_NOTCERTIFIED" => MEDIASERVER::NS_E_WMP_WMDM_NOTCERTIFIED,
            "NS_E_WMP_WMDM_LICENSE_NOTEXIST" => MEDIASERVER::NS_E_WMP_WMDM_LICENSE_NOTEXIST,
            "NS_E_WMP_WMDM_LICENSE_EXPIRED" => MEDIASERVER::NS_E_WMP_WMDM_LICENSE_EXPIRED,
            "NS_E_WMP_WMDM_BUSY" => MEDIASERVER::NS_E_WMP_WMDM_BUSY,
            "NS_E_WMP_WMDM_NORIGHTS" => MEDIASERVER::NS_E_WMP_WMDM_NORIGHTS,
            "NS_E_WMP_WMDM_INCORRECT_RIGHTS" => MEDIASERVER::NS_E_WMP_WMDM_INCORRECT_RIGHTS,
            "NS_E_WMP_IMAPI_GENERIC" => MEDIASERVER::NS_E_WMP_IMAPI_GENERIC,
            "NS_E_WMP_IMAPI_DEVICE_NOTPRESENT" => MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_NOTPRESENT,
            "NS_E_WMP_IMAPI_DEVICE_BUSY" => MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_BUSY,
            "NS_E_WMP_IMAPI_LOSS_OF_STREAMING" => MEDIASERVER::NS_E_WMP_IMAPI_LOSS_OF_STREAMING,
            "NS_E_WMP_SERVER_UNAVAILABLE" => MEDIASERVER::NS_E_WMP_SERVER_UNAVAILABLE,
            "NS_E_WMP_FILE_OPEN_FAILED" => MEDIASERVER::NS_E_WMP_FILE_OPEN_FAILED,
            "NS_E_WMP_VERIFY_ONLINE" => MEDIASERVER::NS_E_WMP_VERIFY_ONLINE,
            "NS_E_WMP_SERVER_NOT_RESPONDING" => MEDIASERVER::NS_E_WMP_SERVER_NOT_RESPONDING,
            "NS_E_WMP_DRM_CORRUPT_BACKUP" => MEDIASERVER::NS_E_WMP_DRM_CORRUPT_BACKUP,
            "NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE,
            "NS_E_WMP_NETWORK_FIREWALL" => MEDIASERVER::NS_E_WMP_NETWORK_FIREWALL,
            "NS_E_WMP_NO_REMOVABLE_MEDIA" => MEDIASERVER::NS_E_WMP_NO_REMOVABLE_MEDIA,
            "NS_E_WMP_PROXY_CONNECT_TIMEOUT" => MEDIASERVER::NS_E_WMP_PROXY_CONNECT_TIMEOUT,
            "NS_E_WMP_NEED_UPGRADE" => MEDIASERVER::NS_E_WMP_NEED_UPGRADE,
            "NS_E_WMP_AUDIO_HW_PROBLEM" => MEDIASERVER::NS_E_WMP_AUDIO_HW_PROBLEM,
            "NS_E_WMP_INVALID_PROTOCOL" => MEDIASERVER::NS_E_WMP_INVALID_PROTOCOL,
            "NS_E_WMP_INVALID_LIBRARY_ADD" => MEDIASERVER::NS_E_WMP_INVALID_LIBRARY_ADD,
            "NS_E_WMP_MMS_NOT_SUPPORTED" => MEDIASERVER::NS_E_WMP_MMS_NOT_SUPPORTED,
            "NS_E_WMP_NO_PROTOCOLS_SELECTED" => MEDIASERVER::NS_E_WMP_NO_PROTOCOLS_SELECTED,
            "NS_E_WMP_GOFULLSCREEN_FAILED" => MEDIASERVER::NS_E_WMP_GOFULLSCREEN_FAILED,
            "NS_E_WMP_NETWORK_ERROR" => MEDIASERVER::NS_E_WMP_NETWORK_ERROR,
            "NS_E_WMP_CONNECT_TIMEOUT" => MEDIASERVER::NS_E_WMP_CONNECT_TIMEOUT,
            "NS_E_WMP_MULTICAST_DISABLED" => MEDIASERVER::NS_E_WMP_MULTICAST_DISABLED,
            "NS_E_WMP_SERVER_DNS_TIMEOUT" => MEDIASERVER::NS_E_WMP_SERVER_DNS_TIMEOUT,
            "NS_E_WMP_PROXY_NOT_FOUND" => MEDIASERVER::NS_E_WMP_PROXY_NOT_FOUND,
            "NS_E_WMP_TAMPERED_CONTENT" => MEDIASERVER::NS_E_WMP_TAMPERED_CONTENT,
            "NS_E_WMP_OUTOFMEMORY" => MEDIASERVER::NS_E_WMP_OUTOFMEMORY,
            "NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED" => MEDIASERVER::NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED,
            "NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED" => MEDIASERVER::NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED,
            "NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE" => MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE,
            "NS_E_WMP_DRM_DRIVER_AUTH_FAILURE" => MEDIASERVER::NS_E_WMP_DRM_DRIVER_AUTH_FAILURE,
            "NS_E_WMP_NETWORK_RESOURCE_FAILURE" => MEDIASERVER::NS_E_WMP_NETWORK_RESOURCE_FAILURE,
            "NS_E_WMP_UPGRADE_APPLICATION" => MEDIASERVER::NS_E_WMP_UPGRADE_APPLICATION,
            "NS_E_WMP_UNKNOWN_ERROR" => MEDIASERVER::NS_E_WMP_UNKNOWN_ERROR,
            "NS_E_WMP_INVALID_KEY" => MEDIASERVER::NS_E_WMP_INVALID_KEY,
            "NS_E_WMP_CD_ANOTHER_USER" => MEDIASERVER::NS_E_WMP_CD_ANOTHER_USER,
            "NS_E_WMP_DRM_NEEDS_AUTHORIZATION" => MEDIASERVER::NS_E_WMP_DRM_NEEDS_AUTHORIZATION,
            "NS_E_WMP_BAD_DRIVER" => MEDIASERVER::NS_E_WMP_BAD_DRIVER,
            "NS_E_WMP_ACCESS_DENIED" => MEDIASERVER::NS_E_WMP_ACCESS_DENIED,
            "NS_E_WMP_LICENSE_RESTRICTS" => MEDIASERVER::NS_E_WMP_LICENSE_RESTRICTS,
            "NS_E_WMP_INVALID_REQUEST" => MEDIASERVER::NS_E_WMP_INVALID_REQUEST,
            "NS_E_WMP_CD_STASH_NO_SPACE" => MEDIASERVER::NS_E_WMP_CD_STASH_NO_SPACE,
            "NS_E_WMP_DRM_NEW_HARDWARE" => MEDIASERVER::NS_E_WMP_DRM_NEW_HARDWARE,
            "NS_E_WMP_DRM_INVALID_SIG" => MEDIASERVER::NS_E_WMP_DRM_INVALID_SIG,
            "NS_E_WMP_DRM_CANNOT_RESTORE" => MEDIASERVER::NS_E_WMP_DRM_CANNOT_RESTORE,
            "NS_E_WMP_BURN_DISC_OVERFLOW" => MEDIASERVER::NS_E_WMP_BURN_DISC_OVERFLOW,
            "NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE" => MEDIASERVER::NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE,
            "NS_E_WMP_DRM_NO_SECURE_CLOCK" => MEDIASERVER::NS_E_WMP_DRM_NO_SECURE_CLOCK,
            "NS_E_WMP_DRM_NO_RIGHTS" => MEDIASERVER::NS_E_WMP_DRM_NO_RIGHTS,
            "NS_E_WMP_DRM_INDIV_FAILED" => MEDIASERVER::NS_E_WMP_DRM_INDIV_FAILED,
            "NS_E_WMP_SERVER_NONEWCONNECTIONS" => MEDIASERVER::NS_E_WMP_SERVER_NONEWCONNECTIONS,
            "NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST" => MEDIASERVER::NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST,
            "NS_E_WMP_IMAPI2_ERASE_FAIL" => MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_FAIL,
            "NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY" => MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY,
            "NS_E_WMP_DRM_COMPONENT_FAILURE" => MEDIASERVER::NS_E_WMP_DRM_COMPONENT_FAILURE,
            "NS_E_WMP_DRM_NO_DEVICE_CERT" => MEDIASERVER::NS_E_WMP_DRM_NO_DEVICE_CERT,
            "NS_E_WMP_SERVER_SECURITY_ERROR" => MEDIASERVER::NS_E_WMP_SERVER_SECURITY_ERROR,
            "NS_E_WMP_AUDIO_DEVICE_LOST" => MEDIASERVER::NS_E_WMP_AUDIO_DEVICE_LOST,
            "NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE" => MEDIASERVER::NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE,
            "NS_E_SYNCWIZ_DEVICE_FULL" => MEDIASERVER::NS_E_SYNCWIZ_DEVICE_FULL,
            "NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS" => MEDIASERVER::NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS,
            "NS_E_TRANSCODE_DELETECACHEERROR" => MEDIASERVER::NS_E_TRANSCODE_DELETECACHEERROR,
            "NS_E_CD_NO_BUFFERS_READ" => MEDIASERVER::NS_E_CD_NO_BUFFERS_READ,
            "NS_E_CD_EMPTY_TRACK_QUEUE" => MEDIASERVER::NS_E_CD_EMPTY_TRACK_QUEUE,
            "NS_E_CD_NO_READER" => MEDIASERVER::NS_E_CD_NO_READER,
            "NS_E_CD_ISRC_INVALID" => MEDIASERVER::NS_E_CD_ISRC_INVALID,
            "NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID" => MEDIASERVER::NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID,
            "NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION" => MEDIASERVER::NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION,
            "NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS" => MEDIASERVER::NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS,
            "NS_E_CD_QUEUEING_DISABLED" => MEDIASERVER::NS_E_CD_QUEUEING_DISABLED,
            "NS_E_WMP_DRM_ACQUIRING_LICENSE" => MEDIASERVER::NS_E_WMP_DRM_ACQUIRING_LICENSE,
            "NS_E_WMP_DRM_LICENSE_EXPIRED" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_EXPIRED,
            "NS_E_WMP_DRM_LICENSE_NOTACQUIRED" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTACQUIRED,
            "NS_E_WMP_DRM_LICENSE_NOTENABLED" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTENABLED,
            "NS_E_WMP_DRM_LICENSE_UNUSABLE" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_UNUSABLE,
            "NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED,
            "NS_E_WMP_DRM_LICENSE_NOSAP" => MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOSAP,
            "NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE" => MEDIASERVER::NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE,
            "NS_E_WMP_LICENSE_REQUIRED" => MEDIASERVER::NS_E_WMP_LICENSE_REQUIRED,
            "NS_E_WMP_PROTECTED_CONTENT" => MEDIASERVER::NS_E_WMP_PROTECTED_CONTENT,
            "NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED" => MEDIASERVER::NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED,
            "NS_E_PDA_CANNOT_SYNC_FROM_INTERNET" => MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_INTERNET,
            "NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST" => MEDIASERVER::NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST,
            "NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE" => MEDIASERVER::NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE,
            "NS_E_PDA_SYNC_FAILED" => MEDIASERVER::NS_E_PDA_SYNC_FAILED,
            "NS_E_PDA_DELETE_FAILED" => MEDIASERVER::NS_E_PDA_DELETE_FAILED,
            "NS_E_PDA_FAILED_TO_RETRIEVE_FILE" => MEDIASERVER::NS_E_PDA_FAILED_TO_RETRIEVE_FILE,
            "NS_E_PDA_DEVICE_NOT_RESPONDING" => MEDIASERVER::NS_E_PDA_DEVICE_NOT_RESPONDING,
            "NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO" => MEDIASERVER::NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO,
            "NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE" => MEDIASERVER::NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE,
            "NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO" => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO,
            "NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO" => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO,
            "NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE" => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE,
            "NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG" => MEDIASERVER::NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG,
            "NS_E_PDA_CEWMDM_DRM_ERROR" => MEDIASERVER::NS_E_PDA_CEWMDM_DRM_ERROR,
            "NS_E_INCOMPLETE_PLAYLIST" => MEDIASERVER::NS_E_INCOMPLETE_PLAYLIST,
            "NS_E_PDA_SYNC_RUNNING" => MEDIASERVER::NS_E_PDA_SYNC_RUNNING,
            "NS_E_PDA_SYNC_LOGIN_ERROR" => MEDIASERVER::NS_E_PDA_SYNC_LOGIN_ERROR,
            "NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND" => MEDIASERVER::NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND,
            "NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE" => MEDIASERVER::NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE,
            "NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING" => MEDIASERVER::NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING,
            "NS_E_WMP_HWND_NOTFOUND" => MEDIASERVER::NS_E_WMP_HWND_NOTFOUND,
            "NS_E_BKGDOWNLOAD_WRONG_NO_FILES" => MEDIASERVER::NS_E_BKGDOWNLOAD_WRONG_NO_FILES,
            "NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB" => MEDIASERVER::NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB,
            "NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB" => MEDIASERVER::NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB,
            "NS_E_BKGDOWNLOAD_NOJOBPOINTER" => MEDIASERVER::NS_E_BKGDOWNLOAD_NOJOBPOINTER,
            "NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE" => MEDIASERVER::NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE,
            "NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE" => MEDIASERVER::NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE,
            "NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE" => MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE,
            "NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE" => MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE,
            "NS_E_BKGDOWNLOAD_CALLFUNCFAILED" => MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCFAILED,
            "NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT" => MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT,
            "NS_E_BKGDOWNLOAD_CALLFUNCENDED" => MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCENDED,
            "NS_E_BKGDOWNLOAD_WMDUNPACKFAILED" => MEDIASERVER::NS_E_BKGDOWNLOAD_WMDUNPACKFAILED,
            "NS_E_BKGDOWNLOAD_FAILEDINITIALIZE" => MEDIASERVER::NS_E_BKGDOWNLOAD_FAILEDINITIALIZE,
            "NS_E_INTERFACE_NOT_REGISTERED_IN_GIT" => MEDIASERVER::NS_E_INTERFACE_NOT_REGISTERED_IN_GIT,
            "NS_E_BKGDOWNLOAD_INVALID_FILE_NAME" => MEDIASERVER::NS_E_BKGDOWNLOAD_INVALID_FILE_NAME,
            "NS_E_IMAGE_DOWNLOAD_FAILED" => MEDIASERVER::NS_E_IMAGE_DOWNLOAD_FAILED,
            "NS_E_WMP_UDRM_NOUSERLIST" => MEDIASERVER::NS_E_WMP_UDRM_NOUSERLIST,
            "NS_E_WMP_DRM_NOT_ACQUIRING" => MEDIASERVER::NS_E_WMP_DRM_NOT_ACQUIRING,
            "NS_E_WMP_BSTR_TOO_LONG" => MEDIASERVER::NS_E_WMP_BSTR_TOO_LONG,
            "NS_E_WMP_AUTOPLAY_INVALID_STATE" => MEDIASERVER::NS_E_WMP_AUTOPLAY_INVALID_STATE,
            "NS_E_WMP_COMPONENT_REVOKED" => MEDIASERVER::NS_E_WMP_COMPONENT_REVOKED,
            "NS_E_CURL_NOTSAFE" => MEDIASERVER::NS_E_CURL_NOTSAFE,
            "NS_E_CURL_INVALIDCHAR" => MEDIASERVER::NS_E_CURL_INVALIDCHAR,
            "NS_E_CURL_INVALIDHOSTNAME" => MEDIASERVER::NS_E_CURL_INVALIDHOSTNAME,
            "NS_E_CURL_INVALIDPATH" => MEDIASERVER::NS_E_CURL_INVALIDPATH,
            "NS_E_CURL_INVALIDSCHEME" => MEDIASERVER::NS_E_CURL_INVALIDSCHEME,
            "NS_E_CURL_INVALIDURL" => MEDIASERVER::NS_E_CURL_INVALIDURL,
            "NS_E_CURL_CANTWALK" => MEDIASERVER::NS_E_CURL_CANTWALK,
            "NS_E_CURL_INVALIDPORT" => MEDIASERVER::NS_E_CURL_INVALIDPORT,
            "NS_E_CURLHELPER_NOTADIRECTORY" => MEDIASERVER::NS_E_CURLHELPER_NOTADIRECTORY,
            "NS_E_CURLHELPER_NOTAFILE" => MEDIASERVER::NS_E_CURLHELPER_NOTAFILE,
            "NS_E_CURL_CANTDECODE" => MEDIASERVER::NS_E_CURL_CANTDECODE,
            "NS_E_CURLHELPER_NOTRELATIVE" => MEDIASERVER::NS_E_CURLHELPER_NOTRELATIVE,
            "NS_E_CURL_INVALIDBUFFERSIZE" => MEDIASERVER::NS_E_CURL_INVALIDBUFFERSIZE,
            "NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED" => MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED,
            "NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES" => MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES,
            "NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT" => MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT,
            "NS_E_NOT_CONTENT_PARTNER_TRACK" => MEDIASERVER::NS_E_NOT_CONTENT_PARTNER_TRACK,
            "NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE" => MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE,
            "NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE" => MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE,
            "NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED" => MEDIASERVER::NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED,
            "NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED" => MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED,
            "NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT" => MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT,
            "NS_E_CONTENT_PARTNER_STILL_INITIALIZING" => MEDIASERVER::NS_E_CONTENT_PARTNER_STILL_INITIALIZING,
            "NS_E_OPEN_CONTAINING_FOLDER_FAILED" => MEDIASERVER::NS_E_OPEN_CONTAINING_FOLDER_FAILED,
            "NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES" => MEDIASERVER::NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES,
            "NS_E_REDIRECT" => MEDIASERVER::NS_E_REDIRECT,
            "NS_E_STALE_PRESENTATION" => MEDIASERVER::NS_E_STALE_PRESENTATION,
            "NS_E_NAMESPACE_WRONG_PERSIST" => MEDIASERVER::NS_E_NAMESPACE_WRONG_PERSIST,
            "NS_E_NAMESPACE_WRONG_TYPE" => MEDIASERVER::NS_E_NAMESPACE_WRONG_TYPE,
            "NS_E_NAMESPACE_NODE_CONFLICT" => MEDIASERVER::NS_E_NAMESPACE_NODE_CONFLICT,
            "NS_E_NAMESPACE_NODE_NOT_FOUND" => MEDIASERVER::NS_E_NAMESPACE_NODE_NOT_FOUND,
            "NS_E_NAMESPACE_BUFFER_TOO_SMALL" => MEDIASERVER::NS_E_NAMESPACE_BUFFER_TOO_SMALL,
            "NS_E_NAMESPACE_TOO_MANY_CALLBACKS" => MEDIASERVER::NS_E_NAMESPACE_TOO_MANY_CALLBACKS,
            "NS_E_NAMESPACE_DUPLICATE_CALLBACK" => MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_CALLBACK,
            "NS_E_NAMESPACE_CALLBACK_NOT_FOUND" => MEDIASERVER::NS_E_NAMESPACE_CALLBACK_NOT_FOUND,
            "NS_E_NAMESPACE_NAME_TOO_LONG" => MEDIASERVER::NS_E_NAMESPACE_NAME_TOO_LONG,
            "NS_E_NAMESPACE_DUPLICATE_NAME" => MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_NAME,
            "NS_E_NAMESPACE_EMPTY_NAME" => MEDIASERVER::NS_E_NAMESPACE_EMPTY_NAME,
            "NS_E_NAMESPACE_INDEX_TOO_LARGE" => MEDIASERVER::NS_E_NAMESPACE_INDEX_TOO_LARGE,
            "NS_E_NAMESPACE_BAD_NAME" => MEDIASERVER::NS_E_NAMESPACE_BAD_NAME,
            "NS_E_NAMESPACE_WRONG_SECURITY" => MEDIASERVER::NS_E_NAMESPACE_WRONG_SECURITY,
            "NS_E_CACHE_ARCHIVE_CONFLICT" => MEDIASERVER::NS_E_CACHE_ARCHIVE_CONFLICT,
            "NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND" => MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND,
            "NS_E_CACHE_ORIGIN_SERVER_TIMEOUT" => MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_TIMEOUT,
            "NS_E_CACHE_NOT_BROADCAST" => MEDIASERVER::NS_E_CACHE_NOT_BROADCAST,
            "NS_E_CACHE_CANNOT_BE_CACHED" => MEDIASERVER::NS_E_CACHE_CANNOT_BE_CACHED,
            "NS_E_CACHE_NOT_MODIFIED" => MEDIASERVER::NS_E_CACHE_NOT_MODIFIED,
            "NS_E_CANNOT_REMOVE_PUBLISHING_POINT" => MEDIASERVER::NS_E_CANNOT_REMOVE_PUBLISHING_POINT,
            "NS_E_CANNOT_REMOVE_PLUGIN" => MEDIASERVER::NS_E_CANNOT_REMOVE_PLUGIN,
            "NS_E_WRONG_PUBLISHING_POINT_TYPE" => MEDIASERVER::NS_E_WRONG_PUBLISHING_POINT_TYPE,
            "NS_E_UNSUPPORTED_LOAD_TYPE" => MEDIASERVER::NS_E_UNSUPPORTED_LOAD_TYPE,
            "NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION" => MEDIASERVER::NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION,
            "NS_E_INVALID_PUBLISHING_POINT_NAME" => MEDIASERVER::NS_E_INVALID_PUBLISHING_POINT_NAME,
            "NS_E_TOO_MANY_MULTICAST_SINKS" => MEDIASERVER::NS_E_TOO_MANY_MULTICAST_SINKS,
            "NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED" => MEDIASERVER::NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED,
            "NS_E_MULTICAST_PLUGIN_NOT_ENABLED" => MEDIASERVER::NS_E_MULTICAST_PLUGIN_NOT_ENABLED,
            "NS_E_INVALID_OPERATING_SYSTEM_VERSION" => MEDIASERVER::NS_E_INVALID_OPERATING_SYSTEM_VERSION,
            "NS_E_PUBLISHING_POINT_REMOVED" => MEDIASERVER::NS_E_PUBLISHING_POINT_REMOVED,
            "NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST" => MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST,
            "NS_E_UNSUPPORTED_LANGUAGE" => MEDIASERVER::NS_E_UNSUPPORTED_LANGUAGE,
            "NS_E_WRONG_OS_VERSION" => MEDIASERVER::NS_E_WRONG_OS_VERSION,
            "NS_E_PUBLISHING_POINT_STOPPED" => MEDIASERVER::NS_E_PUBLISHING_POINT_STOPPED,
            "NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING" => MEDIASERVER::NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING,
            "NS_E_EMPTY_PLAYLIST" => MEDIASERVER::NS_E_EMPTY_PLAYLIST,
            "NS_E_PLAYLIST_PARSE_FAILURE" => MEDIASERVER::NS_E_PLAYLIST_PARSE_FAILURE,
            "NS_E_PLAYLIST_UNSUPPORTED_ENTRY" => MEDIASERVER::NS_E_PLAYLIST_UNSUPPORTED_ENTRY,
            "NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST" => MEDIASERVER::NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST,
            "NS_E_PLAYLIST_ENTRY_SEEK" => MEDIASERVER::NS_E_PLAYLIST_ENTRY_SEEK,
            "NS_E_PLAYLIST_RECURSIVE_PLAYLISTS" => MEDIASERVER::NS_E_PLAYLIST_RECURSIVE_PLAYLISTS,
            "NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS" => MEDIASERVER::NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS,
            "NS_E_PLAYLIST_SHUTDOWN" => MEDIASERVER::NS_E_PLAYLIST_SHUTDOWN,
            "NS_E_PLAYLIST_END_RECEDING" => MEDIASERVER::NS_E_PLAYLIST_END_RECEDING,
            "NS_E_DATAPATH_NO_SINK" => MEDIASERVER::NS_E_DATAPATH_NO_SINK,
            "NS_E_INVALID_PUSH_TEMPLATE" => MEDIASERVER::NS_E_INVALID_PUSH_TEMPLATE,
            "NS_E_INVALID_PUSH_PUBLISHING_POINT" => MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT,
            "NS_E_CRITICAL_ERROR" => MEDIASERVER::NS_E_CRITICAL_ERROR,
            "NS_E_NO_NEW_CONNECTIONS" => MEDIASERVER::NS_E_NO_NEW_CONNECTIONS,
            "NS_E_WSX_INVALID_VERSION" => MEDIASERVER::NS_E_WSX_INVALID_VERSION,
            "NS_E_HEADER_MISMATCH" => MEDIASERVER::NS_E_HEADER_MISMATCH,
            "NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME" => MEDIASERVER::NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME,
            "NS_E_NO_SCRIPT_ENGINE" => MEDIASERVER::NS_E_NO_SCRIPT_ENGINE,
            "NS_E_PLUGIN_ERROR_REPORTED" => MEDIASERVER::NS_E_PLUGIN_ERROR_REPORTED,
            "NS_E_SOURCE_PLUGIN_NOT_FOUND" => MEDIASERVER::NS_E_SOURCE_PLUGIN_NOT_FOUND,
            "NS_E_PLAYLIST_PLUGIN_NOT_FOUND" => MEDIASERVER::NS_E_PLAYLIST_PLUGIN_NOT_FOUND,
            "NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED" => MEDIASERVER::NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED,
            "NS_E_MEDIA_PARSER_INVALID_FORMAT" => MEDIASERVER::NS_E_MEDIA_PARSER_INVALID_FORMAT,
            "NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED" => MEDIASERVER::NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED,
            "NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER" => MEDIASERVER::NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER,
            "NS_E_WIZARD_RUNNING" => MEDIASERVER::NS_E_WIZARD_RUNNING,
            "NS_E_INVALID_LOG_URL" => MEDIASERVER::NS_E_INVALID_LOG_URL,
            "NS_E_INVALID_MTU_RANGE" => MEDIASERVER::NS_E_INVALID_MTU_RANGE,
            "NS_E_INVALID_PLAY_STATISTICS" => MEDIASERVER::NS_E_INVALID_PLAY_STATISTICS,
            "NS_E_LOG_NEED_TO_BE_SKIPPED" => MEDIASERVER::NS_E_LOG_NEED_TO_BE_SKIPPED,
            "NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED" => MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED,
            "NS_E_PORT_IN_USE" => MEDIASERVER::NS_E_PORT_IN_USE,
            "NS_E_PORT_IN_USE_HTTP" => MEDIASERVER::NS_E_PORT_IN_USE_HTTP,
            "NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE" => MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE,
            "NS_E_ARCHIVE_REACH_QUOTA" => MEDIASERVER::NS_E_ARCHIVE_REACH_QUOTA,
            "NS_E_ARCHIVE_ABORT_DUE_TO_BCAST" => MEDIASERVER::NS_E_ARCHIVE_ABORT_DUE_TO_BCAST,
            "NS_E_ARCHIVE_GAP_DETECTED" => MEDIASERVER::NS_E_ARCHIVE_GAP_DETECTED,
            "NS_E_AUTHORIZATION_FILE_NOT_FOUND" => MEDIASERVER::NS_E_AUTHORIZATION_FILE_NOT_FOUND,
            "NS_E_BAD_MARKIN" => MEDIASERVER::NS_E_BAD_MARKIN,
            "NS_E_BAD_MARKOUT" => MEDIASERVER::NS_E_BAD_MARKOUT,
            "NS_E_NOMATCHING_MEDIASOURCE" => MEDIASERVER::NS_E_NOMATCHING_MEDIASOURCE,
            "NS_E_UNSUPPORTED_SOURCETYPE" => MEDIASERVER::NS_E_UNSUPPORTED_SOURCETYPE,
            "NS_E_TOO_MANY_AUDIO" => MEDIASERVER::NS_E_TOO_MANY_AUDIO,
            "NS_E_TOO_MANY_VIDEO" => MEDIASERVER::NS_E_TOO_MANY_VIDEO,
            "NS_E_NOMATCHING_ELEMENT" => MEDIASERVER::NS_E_NOMATCHING_ELEMENT,
            "NS_E_MISMATCHED_MEDIACONTENT" => MEDIASERVER::NS_E_MISMATCHED_MEDIACONTENT,
            "NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP" => MEDIASERVER::NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP,
            "NS_E_AUDIODEVICE_BUSY" => MEDIASERVER::NS_E_AUDIODEVICE_BUSY,
            "NS_E_AUDIODEVICE_UNEXPECTED" => MEDIASERVER::NS_E_AUDIODEVICE_UNEXPECTED,
            "NS_E_AUDIODEVICE_BADFORMAT" => MEDIASERVER::NS_E_AUDIODEVICE_BADFORMAT,
            "NS_E_VIDEODEVICE_BUSY" => MEDIASERVER::NS_E_VIDEODEVICE_BUSY,
            "NS_E_VIDEODEVICE_UNEXPECTED" => MEDIASERVER::NS_E_VIDEODEVICE_UNEXPECTED,
            "NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING" => MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING,
            "NS_E_NO_PROFILE_IN_SOURCEGROUP" => MEDIASERVER::NS_E_NO_PROFILE_IN_SOURCEGROUP,
            "NS_E_VIDEODRIVER_UNSTABLE" => MEDIASERVER::NS_E_VIDEODRIVER_UNSTABLE,
            "NS_E_VIDCAPSTARTFAILED" => MEDIASERVER::NS_E_VIDCAPSTARTFAILED,
            "NS_E_VIDSOURCECOMPRESSION" => MEDIASERVER::NS_E_VIDSOURCECOMPRESSION,
            "NS_E_VIDSOURCESIZE" => MEDIASERVER::NS_E_VIDSOURCESIZE,
            "NS_E_ICMQUERYFORMAT" => MEDIASERVER::NS_E_ICMQUERYFORMAT,
            "NS_E_VIDCAPCREATEWINDOW" => MEDIASERVER::NS_E_VIDCAPCREATEWINDOW,
            "NS_E_VIDCAPDRVINUSE" => MEDIASERVER::NS_E_VIDCAPDRVINUSE,
            "NS_E_NO_MEDIAFORMAT_IN_SOURCE" => MEDIASERVER::NS_E_NO_MEDIAFORMAT_IN_SOURCE,
            "NS_E_NO_VALID_OUTPUT_STREAM" => MEDIASERVER::NS_E_NO_VALID_OUTPUT_STREAM,
            "NS_E_NO_VALID_SOURCE_PLUGIN" => MEDIASERVER::NS_E_NO_VALID_SOURCE_PLUGIN,
            "NS_E_NO_ACTIVE_SOURCEGROUP" => MEDIASERVER::NS_E_NO_ACTIVE_SOURCEGROUP,
            "NS_E_NO_SCRIPT_STREAM" => MEDIASERVER::NS_E_NO_SCRIPT_STREAM,
            "NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING" => MEDIASERVER::NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING,
            "NS_E_INVALIDPACKETSIZE" => MEDIASERVER::NS_E_INVALIDPACKETSIZE,
            "NS_E_PLUGIN_CLSID_INVALID" => MEDIASERVER::NS_E_PLUGIN_CLSID_INVALID,
            "NS_E_UNSUPPORTED_ARCHIVETYPE" => MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVETYPE,
            "NS_E_UNSUPPORTED_ARCHIVEOPERATION" => MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVEOPERATION,
            "NS_E_ARCHIVE_FILENAME_NOTSET" => MEDIASERVER::NS_E_ARCHIVE_FILENAME_NOTSET,
            "NS_E_SOURCEGROUP_NOTPREPARED" => MEDIASERVER::NS_E_SOURCEGROUP_NOTPREPARED,
            "NS_E_PROFILE_MISMATCH" => MEDIASERVER::NS_E_PROFILE_MISMATCH,
            "NS_E_INCORRECTCLIPSETTINGS" => MEDIASERVER::NS_E_INCORRECTCLIPSETTINGS,
            "NS_E_NOSTATSAVAILABLE" => MEDIASERVER::NS_E_NOSTATSAVAILABLE,
            "NS_E_NOTARCHIVING" => MEDIASERVER::NS_E_NOTARCHIVING,
            "NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED" => MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED,
            "NS_E_NOSOURCEGROUPS" => MEDIASERVER::NS_E_NOSOURCEGROUPS,
            "NS_E_INVALIDINPUTFPS" => MEDIASERVER::NS_E_INVALIDINPUTFPS,
            "NS_E_NO_DATAVIEW_SUPPORT" => MEDIASERVER::NS_E_NO_DATAVIEW_SUPPORT,
            "NS_E_CODEC_UNAVAILABLE" => MEDIASERVER::NS_E_CODEC_UNAVAILABLE,
            "NS_E_ARCHIVE_SAME_AS_INPUT" => MEDIASERVER::NS_E_ARCHIVE_SAME_AS_INPUT,
            "NS_E_SOURCE_NOTSPECIFIED" => MEDIASERVER::NS_E_SOURCE_NOTSPECIFIED,
            "NS_E_NO_REALTIME_TIMECOMPRESSION" => MEDIASERVER::NS_E_NO_REALTIME_TIMECOMPRESSION,
            "NS_E_UNSUPPORTED_ENCODER_DEVICE" => MEDIASERVER::NS_E_UNSUPPORTED_ENCODER_DEVICE,
            "NS_E_UNEXPECTED_DISPLAY_SETTINGS" => MEDIASERVER::NS_E_UNEXPECTED_DISPLAY_SETTINGS,
            "NS_E_NO_AUDIODATA" => MEDIASERVER::NS_E_NO_AUDIODATA,
            "NS_E_INPUTSOURCE_PROBLEM" => MEDIASERVER::NS_E_INPUTSOURCE_PROBLEM,
            "NS_E_WME_VERSION_MISMATCH" => MEDIASERVER::NS_E_WME_VERSION_MISMATCH,
            "NS_E_NO_REALTIME_PREPROCESS" => MEDIASERVER::NS_E_NO_REALTIME_PREPROCESS,
            "NS_E_NO_REPEAT_PREPROCESS" => MEDIASERVER::NS_E_NO_REPEAT_PREPROCESS,
            "NS_E_CANNOT_PAUSE_LIVEBROADCAST" => MEDIASERVER::NS_E_CANNOT_PAUSE_LIVEBROADCAST,
            "NS_E_DRM_PROFILE_NOT_SET" => MEDIASERVER::NS_E_DRM_PROFILE_NOT_SET,
            "NS_E_DUPLICATE_DRMPROFILE" => MEDIASERVER::NS_E_DUPLICATE_DRMPROFILE,
            "NS_E_INVALID_DEVICE" => MEDIASERVER::NS_E_INVALID_DEVICE,
            "NS_E_SPEECHEDL_ON_NON_MIXEDMODE" => MEDIASERVER::NS_E_SPEECHEDL_ON_NON_MIXEDMODE,
            "NS_E_DRM_PASSWORD_TOO_LONG" => MEDIASERVER::NS_E_DRM_PASSWORD_TOO_LONG,
            "NS_E_DEVCONTROL_FAILED_SEEK" => MEDIASERVER::NS_E_DEVCONTROL_FAILED_SEEK,
            "NS_E_INTERLACE_REQUIRE_SAMESIZE" => MEDIASERVER::NS_E_INTERLACE_REQUIRE_SAMESIZE,
            "NS_E_TOO_MANY_DEVICECONTROL" => MEDIASERVER::NS_E_TOO_MANY_DEVICECONTROL,
            "NS_E_NO_MULTIPASS_FOR_LIVEDEVICE" => MEDIASERVER::NS_E_NO_MULTIPASS_FOR_LIVEDEVICE,
            "NS_E_MISSING_AUDIENCE" => MEDIASERVER::NS_E_MISSING_AUDIENCE,
            "NS_E_AUDIENCE_CONTENTTYPE_MISMATCH" => MEDIASERVER::NS_E_AUDIENCE_CONTENTTYPE_MISMATCH,
            "NS_E_MISSING_SOURCE_INDEX" => MEDIASERVER::NS_E_MISSING_SOURCE_INDEX,
            "NS_E_NUM_LANGUAGE_MISMATCH" => MEDIASERVER::NS_E_NUM_LANGUAGE_MISMATCH,
            "NS_E_LANGUAGE_MISMATCH" => MEDIASERVER::NS_E_LANGUAGE_MISMATCH,
            "NS_E_VBRMODE_MISMATCH" => MEDIASERVER::NS_E_VBRMODE_MISMATCH,
            "NS_E_INVALID_INPUT_AUDIENCE_INDEX" => MEDIASERVER::NS_E_INVALID_INPUT_AUDIENCE_INDEX,
            "NS_E_INVALID_INPUT_LANGUAGE" => MEDIASERVER::NS_E_INVALID_INPUT_LANGUAGE,
            "NS_E_INVALID_INPUT_STREAM" => MEDIASERVER::NS_E_INVALID_INPUT_STREAM,
            "NS_E_EXPECT_MONO_WAV_INPUT" => MEDIASERVER::NS_E_EXPECT_MONO_WAV_INPUT,
            "NS_E_INPUT_WAVFORMAT_MISMATCH" => MEDIASERVER::NS_E_INPUT_WAVFORMAT_MISMATCH,
            "NS_E_RECORDQ_DISK_FULL" => MEDIASERVER::NS_E_RECORDQ_DISK_FULL,
            "NS_E_NO_PAL_INVERSE_TELECINE" => MEDIASERVER::NS_E_NO_PAL_INVERSE_TELECINE,
            "NS_E_ACTIVE_SG_DEVICE_DISCONNECTED" => MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_DISCONNECTED,
            "NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED" => MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED,
            "NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER" => MEDIASERVER::NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER,
            "NS_E_INPUT_DOESNOT_SUPPORT_SMPTE" => MEDIASERVER::NS_E_INPUT_DOESNOT_SUPPORT_SMPTE,
            "NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS" => MEDIASERVER::NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS,
            "NS_E_BAD_CONTENTEDL" => MEDIASERVER::NS_E_BAD_CONTENTEDL,
            "NS_E_INTERLACEMODE_MISMATCH" => MEDIASERVER::NS_E_INTERLACEMODE_MISMATCH,
            "NS_E_NONSQUAREPIXELMODE_MISMATCH" => MEDIASERVER::NS_E_NONSQUAREPIXELMODE_MISMATCH,
            "NS_E_SMPTEMODE_MISMATCH" => MEDIASERVER::NS_E_SMPTEMODE_MISMATCH,
            "NS_E_END_OF_TAPE" => MEDIASERVER::NS_E_END_OF_TAPE,
            "NS_E_NO_MEDIA_IN_AUDIENCE" => MEDIASERVER::NS_E_NO_MEDIA_IN_AUDIENCE,
            "NS_E_NO_AUDIENCES" => MEDIASERVER::NS_E_NO_AUDIENCES,
            "NS_E_NO_AUDIO_COMPAT" => MEDIASERVER::NS_E_NO_AUDIO_COMPAT,
            "NS_E_INVALID_VBR_COMPAT" => MEDIASERVER::NS_E_INVALID_VBR_COMPAT,
            "NS_E_NO_PROFILE_NAME" => MEDIASERVER::NS_E_NO_PROFILE_NAME,
            "NS_E_INVALID_VBR_WITH_UNCOMP" => MEDIASERVER::NS_E_INVALID_VBR_WITH_UNCOMP,
            "NS_E_MULTIPLE_VBR_AUDIENCES" => MEDIASERVER::NS_E_MULTIPLE_VBR_AUDIENCES,
            "NS_E_UNCOMP_COMP_COMBINATION" => MEDIASERVER::NS_E_UNCOMP_COMP_COMBINATION,
            "NS_E_MULTIPLE_AUDIO_CODECS" => MEDIASERVER::NS_E_MULTIPLE_AUDIO_CODECS,
            "NS_E_MULTIPLE_AUDIO_FORMATS" => MEDIASERVER::NS_E_MULTIPLE_AUDIO_FORMATS,
            "NS_E_AUDIO_BITRATE_STEPDOWN" => MEDIASERVER::NS_E_AUDIO_BITRATE_STEPDOWN,
            "NS_E_INVALID_AUDIO_PEAKRATE" => MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE,
            "NS_E_INVALID_AUDIO_PEAKRATE_2" => MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE_2,
            "NS_E_INVALID_AUDIO_BUFFERMAX" => MEDIASERVER::NS_E_INVALID_AUDIO_BUFFERMAX,
            "NS_E_MULTIPLE_VIDEO_CODECS" => MEDIASERVER::NS_E_MULTIPLE_VIDEO_CODECS,
            "NS_E_MULTIPLE_VIDEO_SIZES" => MEDIASERVER::NS_E_MULTIPLE_VIDEO_SIZES,
            "NS_E_INVALID_VIDEO_BITRATE" => MEDIASERVER::NS_E_INVALID_VIDEO_BITRATE,
            "NS_E_VIDEO_BITRATE_STEPDOWN" => MEDIASERVER::NS_E_VIDEO_BITRATE_STEPDOWN,
            "NS_E_INVALID_VIDEO_PEAKRATE" => MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE,
            "NS_E_INVALID_VIDEO_PEAKRATE_2" => MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE_2,
            "NS_E_INVALID_VIDEO_WIDTH" => MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH,
            "NS_E_INVALID_VIDEO_HEIGHT" => MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT,
            "NS_E_INVALID_VIDEO_FPS" => MEDIASERVER::NS_E_INVALID_VIDEO_FPS,
            "NS_E_INVALID_VIDEO_KEYFRAME" => MEDIASERVER::NS_E_INVALID_VIDEO_KEYFRAME,
            "NS_E_INVALID_VIDEO_IQUALITY" => MEDIASERVER::NS_E_INVALID_VIDEO_IQUALITY,
            "NS_E_INVALID_VIDEO_CQUALITY" => MEDIASERVER::NS_E_INVALID_VIDEO_CQUALITY,
            "NS_E_INVALID_VIDEO_BUFFER" => MEDIASERVER::NS_E_INVALID_VIDEO_BUFFER,
            "NS_E_INVALID_VIDEO_BUFFERMAX" => MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX,
            "NS_E_INVALID_VIDEO_BUFFERMAX_2" => MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX_2,
            "NS_E_INVALID_VIDEO_WIDTH_ALIGN" => MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_ALIGN,
            "NS_E_INVALID_VIDEO_HEIGHT_ALIGN" => MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT_ALIGN,
            "NS_E_MULTIPLE_SCRIPT_BITRATES" => MEDIASERVER::NS_E_MULTIPLE_SCRIPT_BITRATES,
            "NS_E_INVALID_SCRIPT_BITRATE" => MEDIASERVER::NS_E_INVALID_SCRIPT_BITRATE,
            "NS_E_MULTIPLE_FILE_BITRATES" => MEDIASERVER::NS_E_MULTIPLE_FILE_BITRATES,
            "NS_E_INVALID_FILE_BITRATE" => MEDIASERVER::NS_E_INVALID_FILE_BITRATE,
            "NS_E_SAME_AS_INPUT_COMBINATION" => MEDIASERVER::NS_E_SAME_AS_INPUT_COMBINATION,
            "NS_E_SOURCE_CANNOT_LOOP" => MEDIASERVER::NS_E_SOURCE_CANNOT_LOOP,
            "NS_E_INVALID_FOLDDOWN_COEFFICIENTS" => MEDIASERVER::NS_E_INVALID_FOLDDOWN_COEFFICIENTS,
            "NS_E_DRMPROFILE_NOTFOUND" => MEDIASERVER::NS_E_DRMPROFILE_NOTFOUND,
            "NS_E_INVALID_TIMECODE" => MEDIASERVER::NS_E_INVALID_TIMECODE,
            "NS_E_NO_AUDIO_TIMECOMPRESSION" => MEDIASERVER::NS_E_NO_AUDIO_TIMECOMPRESSION,
            "NS_E_NO_TWOPASS_TIMECOMPRESSION" => MEDIASERVER::NS_E_NO_TWOPASS_TIMECOMPRESSION,
            "NS_E_TIMECODE_REQUIRES_VIDEOSTREAM" => MEDIASERVER::NS_E_TIMECODE_REQUIRES_VIDEOSTREAM,
            "NS_E_NO_MBR_WITH_TIMECODE" => MEDIASERVER::NS_E_NO_MBR_WITH_TIMECODE,
            "NS_E_INVALID_INTERLACEMODE" => MEDIASERVER::NS_E_INVALID_INTERLACEMODE,
            "NS_E_INVALID_INTERLACE_COMPAT" => MEDIASERVER::NS_E_INVALID_INTERLACE_COMPAT,
            "NS_E_INVALID_NONSQUAREPIXEL_COMPAT" => MEDIASERVER::NS_E_INVALID_NONSQUAREPIXEL_COMPAT,
            "NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL" => MEDIASERVER::NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL,
            "NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR" => MEDIASERVER::NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR,
            "NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT" => MEDIASERVER::NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT,
            "NS_E_DEVICECONTROL_UNSTABLE" => MEDIASERVER::NS_E_DEVICECONTROL_UNSTABLE,
            "NS_E_INVALID_PIXEL_ASPECT_RATIO" => MEDIASERVER::NS_E_INVALID_PIXEL_ASPECT_RATIO,
            "NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH" => MEDIASERVER::NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH,
            "NS_E_INVALID_PROFILE_CONTENTTYPE" => MEDIASERVER::NS_E_INVALID_PROFILE_CONTENTTYPE,
            "NS_E_TRANSFORM_PLUGIN_NOT_FOUND" => MEDIASERVER::NS_E_TRANSFORM_PLUGIN_NOT_FOUND,
            "NS_E_TRANSFORM_PLUGIN_INVALID" => MEDIASERVER::NS_E_TRANSFORM_PLUGIN_INVALID,
            "NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS" => MEDIASERVER::NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS,
            "NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING" => MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING,
            "NS_E_MARKIN_UNSUPPORTED" => MEDIASERVER::NS_E_MARKIN_UNSUPPORTED,
            "NS_E_DRM_INVALID_APPLICATION" => MEDIASERVER::NS_E_DRM_INVALID_APPLICATION,
            "NS_E_DRM_LICENSE_STORE_ERROR" => MEDIASERVER::NS_E_DRM_LICENSE_STORE_ERROR,
            "NS_E_DRM_SECURE_STORE_ERROR" => MEDIASERVER::NS_E_DRM_SECURE_STORE_ERROR,
            "NS_E_DRM_LICENSE_STORE_SAVE_ERROR" => MEDIASERVER::NS_E_DRM_LICENSE_STORE_SAVE_ERROR,
            "NS_E_DRM_SECURE_STORE_UNLOCK_ERROR" => MEDIASERVER::NS_E_DRM_SECURE_STORE_UNLOCK_ERROR,
            "NS_E_DRM_INVALID_CONTENT" => MEDIASERVER::NS_E_DRM_INVALID_CONTENT,
            "NS_E_DRM_UNABLE_TO_OPEN_LICENSE" => MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_LICENSE,
            "NS_E_DRM_INVALID_LICENSE" => MEDIASERVER::NS_E_DRM_INVALID_LICENSE,
            "NS_E_DRM_INVALID_MACHINE" => MEDIASERVER::NS_E_DRM_INVALID_MACHINE,
            "NS_E_DRM_ENUM_LICENSE_FAILED" => MEDIASERVER::NS_E_DRM_ENUM_LICENSE_FAILED,
            "NS_E_DRM_INVALID_LICENSE_REQUEST" => MEDIASERVER::NS_E_DRM_INVALID_LICENSE_REQUEST,
            "NS_E_DRM_UNABLE_TO_INITIALIZE" => MEDIASERVER::NS_E_DRM_UNABLE_TO_INITIALIZE,
            "NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE" => MEDIASERVER::NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE,
            "NS_E_DRM_INVALID_LICENSE_ACQUIRED" => MEDIASERVER::NS_E_DRM_INVALID_LICENSE_ACQUIRED,
            "NS_E_DRM_NO_RIGHTS" => MEDIASERVER::NS_E_DRM_NO_RIGHTS,
            "NS_E_DRM_KEY_ERROR" => MEDIASERVER::NS_E_DRM_KEY_ERROR,
            "NS_E_DRM_ENCRYPT_ERROR" => MEDIASERVER::NS_E_DRM_ENCRYPT_ERROR,
            "NS_E_DRM_DECRYPT_ERROR" => MEDIASERVER::NS_E_DRM_DECRYPT_ERROR,
            "NS_E_DRM_LICENSE_INVALID_XML" => MEDIASERVER::NS_E_DRM_LICENSE_INVALID_XML,
            "NS_E_DRM_NEEDS_INDIVIDUALIZATION" => MEDIASERVER::NS_E_DRM_NEEDS_INDIVIDUALIZATION,
            "NS_E_DRM_ALREADY_INDIVIDUALIZED" => MEDIASERVER::NS_E_DRM_ALREADY_INDIVIDUALIZED,
            "NS_E_DRM_ACTION_NOT_QUERIED" => MEDIASERVER::NS_E_DRM_ACTION_NOT_QUERIED,
            "NS_E_DRM_ACQUIRING_LICENSE" => MEDIASERVER::NS_E_DRM_ACQUIRING_LICENSE,
            "NS_E_DRM_INDIVIDUALIZING" => MEDIASERVER::NS_E_DRM_INDIVIDUALIZING,
            "NS_E_BACKUP_RESTORE_FAILURE" => MEDIASERVER::NS_E_BACKUP_RESTORE_FAILURE,
            "NS_E_BACKUP_RESTORE_BAD_REQUEST_ID" => MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_REQUEST_ID,
            "NS_E_DRM_PARAMETERS_MISMATCHED" => MEDIASERVER::NS_E_DRM_PARAMETERS_MISMATCHED,
            "NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT,
            "NS_E_DRM_INDIVIDUALIZE_ERROR" => MEDIASERVER::NS_E_DRM_INDIVIDUALIZE_ERROR,
            "NS_E_DRM_LICENSE_OPEN_ERROR" => MEDIASERVER::NS_E_DRM_LICENSE_OPEN_ERROR,
            "NS_E_DRM_LICENSE_CLOSE_ERROR" => MEDIASERVER::NS_E_DRM_LICENSE_CLOSE_ERROR,
            "NS_E_DRM_GET_LICENSE_ERROR" => MEDIASERVER::NS_E_DRM_GET_LICENSE_ERROR,
            "NS_E_DRM_QUERY_ERROR" => MEDIASERVER::NS_E_DRM_QUERY_ERROR,
            "NS_E_DRM_REPORT_ERROR" => MEDIASERVER::NS_E_DRM_REPORT_ERROR,
            "NS_E_DRM_GET_LICENSESTRING_ERROR" => MEDIASERVER::NS_E_DRM_GET_LICENSESTRING_ERROR,
            "NS_E_DRM_GET_CONTENTSTRING_ERROR" => MEDIASERVER::NS_E_DRM_GET_CONTENTSTRING_ERROR,
            "NS_E_DRM_MONITOR_ERROR" => MEDIASERVER::NS_E_DRM_MONITOR_ERROR,
            "NS_E_DRM_UNABLE_TO_SET_PARAMETER" => MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_PARAMETER,
            "NS_E_DRM_INVALID_APPDATA" => MEDIASERVER::NS_E_DRM_INVALID_APPDATA,
            "NS_E_DRM_INVALID_APPDATA_VERSION" => MEDIASERVER::NS_E_DRM_INVALID_APPDATA_VERSION,
            "NS_E_DRM_BACKUP_EXISTS" => MEDIASERVER::NS_E_DRM_BACKUP_EXISTS,
            "NS_E_DRM_BACKUP_CORRUPT" => MEDIASERVER::NS_E_DRM_BACKUP_CORRUPT,
            "NS_E_DRM_BACKUPRESTORE_BUSY" => MEDIASERVER::NS_E_DRM_BACKUPRESTORE_BUSY,
            "NS_E_BACKUP_RESTORE_BAD_DATA" => MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_DATA,
            "NS_E_DRM_LICENSE_UNUSABLE" => MEDIASERVER::NS_E_DRM_LICENSE_UNUSABLE,
            "NS_E_DRM_INVALID_PROPERTY" => MEDIASERVER::NS_E_DRM_INVALID_PROPERTY,
            "NS_E_DRM_SECURE_STORE_NOT_FOUND" => MEDIASERVER::NS_E_DRM_SECURE_STORE_NOT_FOUND,
            "NS_E_DRM_CACHED_CONTENT_ERROR" => MEDIASERVER::NS_E_DRM_CACHED_CONTENT_ERROR,
            "NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE" => MEDIASERVER::NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE,
            "NS_E_DRM_DRIVER_AUTH_FAILURE" => MEDIASERVER::NS_E_DRM_DRIVER_AUTH_FAILURE,
            "NS_E_DRM_NEED_UPGRADE_MSSAP" => MEDIASERVER::NS_E_DRM_NEED_UPGRADE_MSSAP,
            "NS_E_DRM_REOPEN_CONTENT" => MEDIASERVER::NS_E_DRM_REOPEN_CONTENT,
            "NS_E_DRM_DRIVER_DIGIOUT_FAILURE" => MEDIASERVER::NS_E_DRM_DRIVER_DIGIOUT_FAILURE,
            "NS_E_DRM_INVALID_SECURESTORE_PASSWORD" => MEDIASERVER::NS_E_DRM_INVALID_SECURESTORE_PASSWORD,
            "NS_E_DRM_APPCERT_REVOKED" => MEDIASERVER::NS_E_DRM_APPCERT_REVOKED,
            "NS_E_DRM_RESTORE_FRAUD" => MEDIASERVER::NS_E_DRM_RESTORE_FRAUD,
            "NS_E_DRM_HARDWARE_INCONSISTENT" => MEDIASERVER::NS_E_DRM_HARDWARE_INCONSISTENT,
            "NS_E_DRM_SDMI_TRIGGER" => MEDIASERVER::NS_E_DRM_SDMI_TRIGGER,
            "NS_E_DRM_SDMI_NOMORECOPIES" => MEDIASERVER::NS_E_DRM_SDMI_NOMORECOPIES,
            "NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT,
            "NS_E_DRM_LICENSE_NOTACQUIRED" => MEDIASERVER::NS_E_DRM_LICENSE_NOTACQUIRED,
            "NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT,
            "NS_E_DRM_BUFFER_TOO_SMALL" => MEDIASERVER::NS_E_DRM_BUFFER_TOO_SMALL,
            "NS_E_DRM_UNSUPPORTED_PROPERTY" => MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROPERTY,
            "NS_E_DRM_ERROR_BAD_NET_RESP" => MEDIASERVER::NS_E_DRM_ERROR_BAD_NET_RESP,
            "NS_E_DRM_STORE_NOTALLSTORED" => MEDIASERVER::NS_E_DRM_STORE_NOTALLSTORED,
            "NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID" => MEDIASERVER::NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID,
            "NS_E_DRM_INVALID_DATA" => MEDIASERVER::NS_E_DRM_INVALID_DATA,
            "NS_E_DRM_POLICY_DISABLE_ONLINE" => MEDIASERVER::NS_E_DRM_POLICY_DISABLE_ONLINE,
            "NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT,
            "NS_E_DRM_NOT_CONFIGURED" => MEDIASERVER::NS_E_DRM_NOT_CONFIGURED,
            "NS_E_DRM_DEVICE_ACTIVATION_CANCELED" => MEDIASERVER::NS_E_DRM_DEVICE_ACTIVATION_CANCELED,
            "NS_E_BACKUP_RESTORE_TOO_MANY_RESETS" => MEDIASERVER::NS_E_BACKUP_RESTORE_TOO_MANY_RESETS,
            "NS_E_DRM_DEBUGGING_NOT_ALLOWED" => MEDIASERVER::NS_E_DRM_DEBUGGING_NOT_ALLOWED,
            "NS_E_DRM_OPERATION_CANCELED" => MEDIASERVER::NS_E_DRM_OPERATION_CANCELED,
            "NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED" => MEDIASERVER::NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED,
            "NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT,
            "NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT,
            "NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION" => MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION,
            "NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION" => MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION,
            "NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT,
            "NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK" => MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK,
            "NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK" => MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK,
            "NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER" => MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER,
            "NS_E_DRM_POLICY_METERING_DISABLED" => MEDIASERVER::NS_E_DRM_POLICY_METERING_DISABLED,
            "NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED" => MEDIASERVER::NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED,
            "NS_E_DRM_SDK_VERSIONMISMATCH" => MEDIASERVER::NS_E_DRM_SDK_VERSIONMISMATCH,
            "NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET" => MEDIASERVER::NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET,
            "NS_E_LICENSE_HEADER_MISSING_URL" => MEDIASERVER::NS_E_LICENSE_HEADER_MISSING_URL,
            "NS_E_DEVICE_NOT_WMDRM_DEVICE" => MEDIASERVER::NS_E_DEVICE_NOT_WMDRM_DEVICE,
            "NS_E_DRM_INVALID_APPCERT" => MEDIASERVER::NS_E_DRM_INVALID_APPCERT,
            "NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION" => MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION,
            "NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE" => MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE,
            "NS_E_DRM_CHECKPOINT_FAILED" => MEDIASERVER::NS_E_DRM_CHECKPOINT_FAILED,
            "NS_E_DRM_BB_UNABLE_TO_INITIALIZE" => MEDIASERVER::NS_E_DRM_BB_UNABLE_TO_INITIALIZE,
            "NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID" => MEDIASERVER::NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID,
            "NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE" => MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE,
            "NS_E_DRM_DATASTORE_CORRUPT" => MEDIASERVER::NS_E_DRM_DATASTORE_CORRUPT,
            "NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT,
            "NS_E_DRM_STUBLIB_REQUIRED" => MEDIASERVER::NS_E_DRM_STUBLIB_REQUIRED,
            "NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT,
            "NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE" => MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE,
            "NS_E_DRM_INVALID_MIGRATION_IMAGE" => MEDIASERVER::NS_E_DRM_INVALID_MIGRATION_IMAGE,
            "NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED" => MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED,
            "NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE" => MEDIASERVER::NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE,
            "NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID" => MEDIASERVER::NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID,
            "NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE" => MEDIASERVER::NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE,
            "NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH" => MEDIASERVER::NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH,
            "NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS" => MEDIASERVER::NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS,
            "NS_E_DRM_HARDWAREID_MISMATCH" => MEDIASERVER::NS_E_DRM_HARDWAREID_MISMATCH,
            "NS_E_INVALID_DRMV2CLT_STUBLIB" => MEDIASERVER::NS_E_INVALID_DRMV2CLT_STUBLIB,
            "NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA" => MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA,
            "NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS" => MEDIASERVER::NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS,
            "NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD" => MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD,
            "NS_E_DRM_MIGRATION_NOT_SUPPORTED" => MEDIASERVER::NS_E_DRM_MIGRATION_NOT_SUPPORTED,
            "NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT,
            "NS_E_DRM_CHECKPOINT_MISMATCH" => MEDIASERVER::NS_E_DRM_CHECKPOINT_MISMATCH,
            "NS_E_DRM_CHECKPOINT_CORRUPT" => MEDIASERVER::NS_E_DRM_CHECKPOINT_CORRUPT,
            "NS_E_REG_FLUSH_FAILURE" => MEDIASERVER::NS_E_REG_FLUSH_FAILURE,
            "NS_E_HDS_KEY_MISMATCH" => MEDIASERVER::NS_E_HDS_KEY_MISMATCH,
            "NS_E_DRM_MIGRATION_OPERATION_CANCELLED" => MEDIASERVER::NS_E_DRM_MIGRATION_OPERATION_CANCELLED,
            "NS_E_DRM_MIGRATION_OBJECT_IN_USE" => MEDIASERVER::NS_E_DRM_MIGRATION_OBJECT_IN_USE,
            "NS_E_DRM_MALFORMED_CONTENT_HEADER" => MEDIASERVER::NS_E_DRM_MALFORMED_CONTENT_HEADER,
            "NS_E_DRM_LICENSE_EXPIRED" => MEDIASERVER::NS_E_DRM_LICENSE_EXPIRED,
            "NS_E_DRM_LICENSE_NOTENABLED" => MEDIASERVER::NS_E_DRM_LICENSE_NOTENABLED,
            "NS_E_DRM_LICENSE_APPSECLOW" => MEDIASERVER::NS_E_DRM_LICENSE_APPSECLOW,
            "NS_E_DRM_STORE_NEEDINDI" => MEDIASERVER::NS_E_DRM_STORE_NEEDINDI,
            "NS_E_DRM_STORE_NOTALLOWED" => MEDIASERVER::NS_E_DRM_STORE_NOTALLOWED,
            "NS_E_DRM_LICENSE_APP_NOTALLOWED" => MEDIASERVER::NS_E_DRM_LICENSE_APP_NOTALLOWED,
            "NS_E_DRM_LICENSE_CERT_EXPIRED" => MEDIASERVER::NS_E_DRM_LICENSE_CERT_EXPIRED,
            "NS_E_DRM_LICENSE_SECLOW" => MEDIASERVER::NS_E_DRM_LICENSE_SECLOW,
            "NS_E_DRM_LICENSE_CONTENT_REVOKED" => MEDIASERVER::NS_E_DRM_LICENSE_CONTENT_REVOKED,
            "NS_E_DRM_DEVICE_NOT_REGISTERED" => MEDIASERVER::NS_E_DRM_DEVICE_NOT_REGISTERED,
            "NS_E_DRM_LICENSE_NOSAP" => MEDIASERVER::NS_E_DRM_LICENSE_NOSAP,
            "NS_E_DRM_LICENSE_NOSVP" => MEDIASERVER::NS_E_DRM_LICENSE_NOSVP,
            "NS_E_DRM_LICENSE_NOWDM" => MEDIASERVER::NS_E_DRM_LICENSE_NOWDM,
            "NS_E_DRM_LICENSE_NOTRUSTEDCODEC" => MEDIASERVER::NS_E_DRM_LICENSE_NOTRUSTEDCODEC,
            "NS_E_DRM_SOURCEID_NOT_SUPPORTED" => MEDIASERVER::NS_E_DRM_SOURCEID_NOT_SUPPORTED,
            "NS_E_DRM_NEEDS_UPGRADE_TEMPFILE" => MEDIASERVER::NS_E_DRM_NEEDS_UPGRADE_TEMPFILE,
            "NS_E_DRM_NEED_UPGRADE_PD" => MEDIASERVER::NS_E_DRM_NEED_UPGRADE_PD,
            "NS_E_DRM_SIGNATURE_FAILURE" => MEDIASERVER::NS_E_DRM_SIGNATURE_FAILURE,
            "NS_E_DRM_LICENSE_SERVER_INFO_MISSING" => MEDIASERVER::NS_E_DRM_LICENSE_SERVER_INFO_MISSING,
            "NS_E_DRM_BUSY" => MEDIASERVER::NS_E_DRM_BUSY,
            "NS_E_DRM_PD_TOO_MANY_DEVICES" => MEDIASERVER::NS_E_DRM_PD_TOO_MANY_DEVICES,
            "NS_E_DRM_INDIV_FRAUD" => MEDIASERVER::NS_E_DRM_INDIV_FRAUD,
            "NS_E_DRM_INDIV_NO_CABS" => MEDIASERVER::NS_E_DRM_INDIV_NO_CABS,
            "NS_E_DRM_INDIV_SERVICE_UNAVAILABLE" => MEDIASERVER::NS_E_DRM_INDIV_SERVICE_UNAVAILABLE,
            "NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE" => MEDIASERVER::NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE,
            "NS_E_DRM_CLIENT_CODE_EXPIRED" => MEDIASERVER::NS_E_DRM_CLIENT_CODE_EXPIRED,
            "NS_E_DRM_NO_UPLINK_LICENSE" => MEDIASERVER::NS_E_DRM_NO_UPLINK_LICENSE,
            "NS_E_DRM_INVALID_KID" => MEDIASERVER::NS_E_DRM_INVALID_KID,
            "NS_E_DRM_LICENSE_INITIALIZATION_ERROR" => MEDIASERVER::NS_E_DRM_LICENSE_INITIALIZATION_ERROR,
            "NS_E_DRM_CHAIN_TOO_LONG" => MEDIASERVER::NS_E_DRM_CHAIN_TOO_LONG,
            "NS_E_DRM_UNSUPPORTED_ALGORITHM" => MEDIASERVER::NS_E_DRM_UNSUPPORTED_ALGORITHM,
            "NS_E_DRM_LICENSE_DELETION_ERROR" => MEDIASERVER::NS_E_DRM_LICENSE_DELETION_ERROR,
            "NS_E_DRM_INVALID_CERTIFICATE" => MEDIASERVER::NS_E_DRM_INVALID_CERTIFICATE,
            "NS_E_DRM_CERTIFICATE_REVOKED" => MEDIASERVER::NS_E_DRM_CERTIFICATE_REVOKED,
            "NS_E_DRM_LICENSE_UNAVAILABLE" => MEDIASERVER::NS_E_DRM_LICENSE_UNAVAILABLE,
            "NS_E_DRM_DEVICE_LIMIT_REACHED" => MEDIASERVER::NS_E_DRM_DEVICE_LIMIT_REACHED,
            "NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY" => MEDIASERVER::NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY,
            "NS_E_DRM_MUST_REGISTER" => MEDIASERVER::NS_E_DRM_MUST_REGISTER,
            "NS_E_DRM_MUST_APPROVE" => MEDIASERVER::NS_E_DRM_MUST_APPROVE,
            "NS_E_DRM_MUST_REVALIDATE" => MEDIASERVER::NS_E_DRM_MUST_REVALIDATE,
            "NS_E_DRM_INVALID_PROXIMITY_RESPONSE" => MEDIASERVER::NS_E_DRM_INVALID_PROXIMITY_RESPONSE,
            "NS_E_DRM_INVALID_SESSION" => MEDIASERVER::NS_E_DRM_INVALID_SESSION,
            "NS_E_DRM_DEVICE_NOT_OPEN" => MEDIASERVER::NS_E_DRM_DEVICE_NOT_OPEN,
            "NS_E_DRM_DEVICE_ALREADY_REGISTERED" => MEDIASERVER::NS_E_DRM_DEVICE_ALREADY_REGISTERED,
            "NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION" => MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION,
            "NS_E_DRM_UNSUPPORTED_ACTION" => MEDIASERVER::NS_E_DRM_UNSUPPORTED_ACTION,
            "NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE" => MEDIASERVER::NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE,
            "NS_E_DRM_UNABLE_TO_OPEN_PORT" => MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_PORT,
            "NS_E_DRM_BAD_REQUEST" => MEDIASERVER::NS_E_DRM_BAD_REQUEST,
            "NS_E_DRM_INVALID_CRL" => MEDIASERVER::NS_E_DRM_INVALID_CRL,
            "NS_E_DRM_ATTRIBUTE_TOO_LONG" => MEDIASERVER::NS_E_DRM_ATTRIBUTE_TOO_LONG,
            "NS_E_DRM_EXPIRED_LICENSEBLOB" => MEDIASERVER::NS_E_DRM_EXPIRED_LICENSEBLOB,
            "NS_E_DRM_INVALID_LICENSEBLOB" => MEDIASERVER::NS_E_DRM_INVALID_LICENSEBLOB,
            "NS_E_DRM_INCLUSION_LIST_REQUIRED" => MEDIASERVER::NS_E_DRM_INCLUSION_LIST_REQUIRED,
            "NS_E_DRM_DRMV2CLT_REVOKED" => MEDIASERVER::NS_E_DRM_DRMV2CLT_REVOKED,
            "NS_E_DRM_RIV_TOO_SMALL" => MEDIASERVER::NS_E_DRM_RIV_TOO_SMALL,
            "NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED" => MEDIASERVER::NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED,
            "NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED" => MEDIASERVER::NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
            "NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED" => MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
            "NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED" => MEDIASERVER::NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
            "NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED" => MEDIASERVER::NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED,
            "NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED" => MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED,
            "NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED" => MEDIASERVER::NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED,
            "NS_E_REBOOT_RECOMMENDED" => MEDIASERVER::NS_E_REBOOT_RECOMMENDED,
            "NS_E_REBOOT_REQUIRED" => MEDIASERVER::NS_E_REBOOT_REQUIRED,
            "NS_E_SETUP_INCOMPLETE" => MEDIASERVER::NS_E_SETUP_INCOMPLETE,
            "NS_E_SETUP_DRM_MIGRATION_FAILED" => MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED,
            "NS_E_SETUP_IGNORABLE_FAILURE" => MEDIASERVER::NS_E_SETUP_IGNORABLE_FAILURE,
            "NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE" => MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE,
            "NS_E_SETUP_BLOCKED" => MEDIASERVER::NS_E_SETUP_BLOCKED,
            "NS_E_UNKNOWN_PROTOCOL" => MEDIASERVER::NS_E_UNKNOWN_PROTOCOL,
            "NS_E_REDIRECT_TO_PROXY" => MEDIASERVER::NS_E_REDIRECT_TO_PROXY,
            "NS_E_INTERNAL_SERVER_ERROR" => MEDIASERVER::NS_E_INTERNAL_SERVER_ERROR,
            "NS_E_BAD_REQUEST" => MEDIASERVER::NS_E_BAD_REQUEST,
            "NS_E_ERROR_FROM_PROXY" => MEDIASERVER::NS_E_ERROR_FROM_PROXY,
            "NS_E_PROXY_TIMEOUT" => MEDIASERVER::NS_E_PROXY_TIMEOUT,
            "NS_E_SERVER_UNAVAILABLE" => MEDIASERVER::NS_E_SERVER_UNAVAILABLE,
            "NS_E_REFUSED_BY_SERVER" => MEDIASERVER::NS_E_REFUSED_BY_SERVER,
            "NS_E_INCOMPATIBLE_SERVER" => MEDIASERVER::NS_E_INCOMPATIBLE_SERVER,
            "NS_E_MULTICAST_DISABLED" => MEDIASERVER::NS_E_MULTICAST_DISABLED,
            "NS_E_INVALID_REDIRECT" => MEDIASERVER::NS_E_INVALID_REDIRECT,
            "NS_E_ALL_PROTOCOLS_DISABLED" => MEDIASERVER::NS_E_ALL_PROTOCOLS_DISABLED,
            "NS_E_MSBD_NO_LONGER_SUPPORTED" => MEDIASERVER::NS_E_MSBD_NO_LONGER_SUPPORTED,
            "NS_E_PROXY_NOT_FOUND" => MEDIASERVER::NS_E_PROXY_NOT_FOUND,
            "NS_E_CANNOT_CONNECT_TO_PROXY" => MEDIASERVER::NS_E_CANNOT_CONNECT_TO_PROXY,
            "NS_E_SERVER_DNS_TIMEOUT" => MEDIASERVER::NS_E_SERVER_DNS_TIMEOUT,
            "NS_E_PROXY_DNS_TIMEOUT" => MEDIASERVER::NS_E_PROXY_DNS_TIMEOUT,
            "NS_E_CLOSED_ON_SUSPEND" => MEDIASERVER::NS_E_CLOSED_ON_SUSPEND,
            "NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER" => MEDIASERVER::NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER,
            "NS_E_SESSION_NOT_FOUND" => MEDIASERVER::NS_E_SESSION_NOT_FOUND,
            "NS_E_REQUIRE_STREAMING_CLIENT" => MEDIASERVER::NS_E_REQUIRE_STREAMING_CLIENT,
            "NS_E_PLAYLIST_ENTRY_HAS_CHANGED" => MEDIASERVER::NS_E_PLAYLIST_ENTRY_HAS_CHANGED,
            "NS_E_PROXY_ACCESSDENIED" => MEDIASERVER::NS_E_PROXY_ACCESSDENIED,
            "NS_E_PROXY_SOURCE_ACCESSDENIED" => MEDIASERVER::NS_E_PROXY_SOURCE_ACCESSDENIED,
            "NS_E_NETWORK_SINK_WRITE" => MEDIASERVER::NS_E_NETWORK_SINK_WRITE,
            "NS_E_FIREWALL" => MEDIASERVER::NS_E_FIREWALL,
            "NS_E_MMS_NOT_SUPPORTED" => MEDIASERVER::NS_E_MMS_NOT_SUPPORTED,
            "NS_E_SERVER_ACCESSDENIED" => MEDIASERVER::NS_E_SERVER_ACCESSDENIED,
            "NS_E_RESOURCE_GONE" => MEDIASERVER::NS_E_RESOURCE_GONE,
            "NS_E_NO_EXISTING_PACKETIZER" => MEDIASERVER::NS_E_NO_EXISTING_PACKETIZER,
            "NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE" => MEDIASERVER::NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE,
            "NS_E_RESET_SOCKET_CONNECTION" => MEDIASERVER::NS_E_RESET_SOCKET_CONNECTION,
            "NS_E_TOO_MANY_HOPS" => MEDIASERVER::NS_E_TOO_MANY_HOPS,
            "NS_E_TOO_MUCH_DATA_FROM_SERVER" => MEDIASERVER::NS_E_TOO_MUCH_DATA_FROM_SERVER,
            "NS_E_CONNECT_TIMEOUT" => MEDIASERVER::NS_E_CONNECT_TIMEOUT,
            "NS_E_PROXY_CONNECT_TIMEOUT" => MEDIASERVER::NS_E_PROXY_CONNECT_TIMEOUT,
            "NS_E_SESSION_INVALID" => MEDIASERVER::NS_E_SESSION_INVALID,
            "NS_E_PACKETSINK_UNKNOWN_FEC_STREAM" => MEDIASERVER::NS_E_PACKETSINK_UNKNOWN_FEC_STREAM,
            "NS_E_PUSH_CANNOTCONNECT" => MEDIASERVER::NS_E_PUSH_CANNOTCONNECT,
            "NS_E_INCOMPATIBLE_PUSH_SERVER" => MEDIASERVER::NS_E_INCOMPATIBLE_PUSH_SERVER,
            "NS_E_END_OF_PLAYLIST" => MEDIASERVER::NS_E_END_OF_PLAYLIST,
            "NS_E_USE_FILE_SOURCE" => MEDIASERVER::NS_E_USE_FILE_SOURCE,
            "NS_E_PROPERTY_NOT_FOUND" => MEDIASERVER::NS_E_PROPERTY_NOT_FOUND,
            "NS_E_PROPERTY_READ_ONLY" => MEDIASERVER::NS_E_PROPERTY_READ_ONLY,
            "NS_E_TABLE_KEY_NOT_FOUND" => MEDIASERVER::NS_E_TABLE_KEY_NOT_FOUND,
            "NS_E_INVALID_QUERY_OPERATOR" => MEDIASERVER::NS_E_INVALID_QUERY_OPERATOR,
            "NS_E_INVALID_QUERY_PROPERTY" => MEDIASERVER::NS_E_INVALID_QUERY_PROPERTY,
            "NS_E_PROPERTY_NOT_SUPPORTED" => MEDIASERVER::NS_E_PROPERTY_NOT_SUPPORTED,
            "NS_E_SCHEMA_CLASSIFY_FAILURE" => MEDIASERVER::NS_E_SCHEMA_CLASSIFY_FAILURE,
            "NS_E_METADATA_FORMAT_NOT_SUPPORTED" => MEDIASERVER::NS_E_METADATA_FORMAT_NOT_SUPPORTED,
            "NS_E_METADATA_NO_EDITING_CAPABILITY" => MEDIASERVER::NS_E_METADATA_NO_EDITING_CAPABILITY,
            "NS_E_METADATA_CANNOT_SET_LOCALE" => MEDIASERVER::NS_E_METADATA_CANNOT_SET_LOCALE,
            "NS_E_METADATA_LANGUAGE_NOT_SUPORTED" => MEDIASERVER::NS_E_METADATA_LANGUAGE_NOT_SUPORTED,
            "NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE" => MEDIASERVER::NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE,
            "NS_E_METADATA_NOT_AVAILABLE" => MEDIASERVER::NS_E_METADATA_NOT_AVAILABLE,
            "NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE" => MEDIASERVER::NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE,
            "NS_E_METADATA_INVALID_DOCUMENT_TYPE" => MEDIASERVER::NS_E_METADATA_INVALID_DOCUMENT_TYPE,
            "NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE" => MEDIASERVER::NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE,
            "NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE" => MEDIASERVER::NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE,
            "MF_E_PLATFORM_NOT_INITIALIZED" => MEDIASERVER::MF_E_PLATFORM_NOT_INITIALIZED,
            "MF_E_BUFFERTOOSMALL" => MEDIASERVER::MF_E_BUFFERTOOSMALL,
            "MF_E_INVALIDREQUEST" => MEDIASERVER::MF_E_INVALIDREQUEST,
            "MF_E_INVALIDSTREAMNUMBER" => MEDIASERVER::MF_E_INVALIDSTREAMNUMBER,
            "MF_E_INVALIDMEDIATYPE" => MEDIASERVER::MF_E_INVALIDMEDIATYPE,
            "MF_E_NOTACCEPTING" => MEDIASERVER::MF_E_NOTACCEPTING,
            "MF_E_NOT_INITIALIZED" => MEDIASERVER::MF_E_NOT_INITIALIZED,
            "MF_E_UNSUPPORTED_REPRESENTATION" => MEDIASERVER::MF_E_UNSUPPORTED_REPRESENTATION,
            "MF_E_NO_MORE_TYPES" => MEDIASERVER::MF_E_NO_MORE_TYPES,
            "MF_E_UNSUPPORTED_SERVICE" => MEDIASERVER::MF_E_UNSUPPORTED_SERVICE,
            "MF_E_UNEXPECTED" => MEDIASERVER::MF_E_UNEXPECTED,
            "MF_E_INVALIDNAME" => MEDIASERVER::MF_E_INVALIDNAME,
            "MF_E_INVALIDTYPE" => MEDIASERVER::MF_E_INVALIDTYPE,
            "MF_E_INVALID_FILE_FORMAT" => MEDIASERVER::MF_E_INVALID_FILE_FORMAT,
            "MF_E_INVALIDINDEX" => MEDIASERVER::MF_E_INVALIDINDEX,
            "MF_E_INVALID_TIMESTAMP" => MEDIASERVER::MF_E_INVALID_TIMESTAMP,
            "MF_E_UNSUPPORTED_SCHEME" => MEDIASERVER::MF_E_UNSUPPORTED_SCHEME,
            "MF_E_UNSUPPORTED_BYTESTREAM_TYPE" => MEDIASERVER::MF_E_UNSUPPORTED_BYTESTREAM_TYPE,
            "MF_E_UNSUPPORTED_TIME_FORMAT" => MEDIASERVER::MF_E_UNSUPPORTED_TIME_FORMAT,
            "MF_E_NO_SAMPLE_TIMESTAMP" => MEDIASERVER::MF_E_NO_SAMPLE_TIMESTAMP,
            "MF_E_NO_SAMPLE_DURATION" => MEDIASERVER::MF_E_NO_SAMPLE_DURATION,
            "MF_E_INVALID_STREAM_DATA" => MEDIASERVER::MF_E_INVALID_STREAM_DATA,
            "MF_E_RT_UNAVAILABLE" => MEDIASERVER::MF_E_RT_UNAVAILABLE,
            "MF_E_UNSUPPORTED_RATE" => MEDIASERVER::MF_E_UNSUPPORTED_RATE,
            "MF_E_THINNING_UNSUPPORTED" => MEDIASERVER::MF_E_THINNING_UNSUPPORTED,
            "MF_E_REVERSE_UNSUPPORTED" => MEDIASERVER::MF_E_REVERSE_UNSUPPORTED,
            "MF_E_UNSUPPORTED_RATE_TRANSITION" => MEDIASERVER::MF_E_UNSUPPORTED_RATE_TRANSITION,
            "MF_E_RATE_CHANGE_PREEMPTED" => MEDIASERVER::MF_E_RATE_CHANGE_PREEMPTED,
            "MF_E_NOT_FOUND" => MEDIASERVER::MF_E_NOT_FOUND,
            "MF_E_NOT_AVAILABLE" => MEDIASERVER::MF_E_NOT_AVAILABLE,
            "MF_E_NO_CLOCK" => MEDIASERVER::MF_E_NO_CLOCK,
            "MF_E_MULTIPLE_BEGIN" => MEDIASERVER::MF_E_MULTIPLE_BEGIN,
            "MF_E_MULTIPLE_SUBSCRIBERS" => MEDIASERVER::MF_E_MULTIPLE_SUBSCRIBERS,
            "MF_E_TIMER_ORPHANED" => MEDIASERVER::MF_E_TIMER_ORPHANED,
            "MF_E_STATE_TRANSITION_PENDING" => MEDIASERVER::MF_E_STATE_TRANSITION_PENDING,
            "MF_E_UNSUPPORTED_STATE_TRANSITION" => MEDIASERVER::MF_E_UNSUPPORTED_STATE_TRANSITION,
            "MF_E_UNRECOVERABLE_ERROR_OCCURRED" => MEDIASERVER::MF_E_UNRECOVERABLE_ERROR_OCCURRED,
            "MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS" => MEDIASERVER::MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS,
            "MF_E_SAMPLE_NOT_WRITABLE" => MEDIASERVER::MF_E_SAMPLE_NOT_WRITABLE,
            "MF_E_INVALID_KEY" => MEDIASERVER::MF_E_INVALID_KEY,
            "MF_E_BAD_STARTUP_VERSION" => MEDIASERVER::MF_E_BAD_STARTUP_VERSION,
            "MF_E_UNSUPPORTED_CAPTION" => MEDIASERVER::MF_E_UNSUPPORTED_CAPTION,
            "MF_E_INVALID_POSITION" => MEDIASERVER::MF_E_INVALID_POSITION,
            "MF_E_ATTRIBUTENOTFOUND" => MEDIASERVER::MF_E_ATTRIBUTENOTFOUND,
            "MF_E_PROPERTY_TYPE_NOT_ALLOWED" => MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_ALLOWED,
            "MF_E_PROPERTY_TYPE_NOT_SUPPORTED" => MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_SUPPORTED,
            "MF_E_PROPERTY_EMPTY" => MEDIASERVER::MF_E_PROPERTY_EMPTY,
            "MF_E_PROPERTY_NOT_EMPTY" => MEDIASERVER::MF_E_PROPERTY_NOT_EMPTY,
            "MF_E_PROPERTY_VECTOR_NOT_ALLOWED" => MEDIASERVER::MF_E_PROPERTY_VECTOR_NOT_ALLOWED,
            "MF_E_PROPERTY_VECTOR_REQUIRED" => MEDIASERVER::MF_E_PROPERTY_VECTOR_REQUIRED,
            "MF_E_OPERATION_CANCELLED" => MEDIASERVER::MF_E_OPERATION_CANCELLED,
            "MF_E_BYTESTREAM_NOT_SEEKABLE" => MEDIASERVER::MF_E_BYTESTREAM_NOT_SEEKABLE,
            "MF_E_DISABLED_IN_SAFEMODE" => MEDIASERVER::MF_E_DISABLED_IN_SAFEMODE,
            "MF_E_CANNOT_PARSE_BYTESTREAM" => MEDIASERVER::MF_E_CANNOT_PARSE_BYTESTREAM,
            "MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS" => MEDIASERVER::MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS,
            "MF_E_MEDIAPROC_WRONGSTATE" => MEDIASERVER::MF_E_MEDIAPROC_WRONGSTATE,
            "MF_E_RT_THROUGHPUT_NOT_AVAILABLE" => MEDIASERVER::MF_E_RT_THROUGHPUT_NOT_AVAILABLE,
            "MF_E_RT_TOO_MANY_CLASSES" => MEDIASERVER::MF_E_RT_TOO_MANY_CLASSES,
            "MF_E_RT_WOULDBLOCK" => MEDIASERVER::MF_E_RT_WOULDBLOCK,
            "MF_E_NO_BITPUMP" => MEDIASERVER::MF_E_NO_BITPUMP,
            "MF_E_RT_OUTOFMEMORY" => MEDIASERVER::MF_E_RT_OUTOFMEMORY,
            "MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED" => MEDIASERVER::MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED,
            "MF_E_CANNOT_CREATE_SINK" => MEDIASERVER::MF_E_CANNOT_CREATE_SINK,
            "MF_E_BYTESTREAM_UNKNOWN_LENGTH" => MEDIASERVER::MF_E_BYTESTREAM_UNKNOWN_LENGTH,
            "MF_E_SESSION_PAUSEWHILESTOPPED" => MEDIASERVER::MF_E_SESSION_PAUSEWHILESTOPPED,
            "MF_E_FORMAT_CHANGE_NOT_SUPPORTED" => MEDIASERVER::MF_E_FORMAT_CHANGE_NOT_SUPPORTED,
            "MF_E_INVALID_WORKQUEUE" => MEDIASERVER::MF_E_INVALID_WORKQUEUE,
            "MF_E_DRM_UNSUPPORTED" => MEDIASERVER::MF_E_DRM_UNSUPPORTED,
            "MF_E_UNAUTHORIZED" => MEDIASERVER::MF_E_UNAUTHORIZED,
            "MF_E_OUT_OF_RANGE" => MEDIASERVER::MF_E_OUT_OF_RANGE,
            "MF_E_INVALID_CODEC_MERIT" => MEDIASERVER::MF_E_INVALID_CODEC_MERIT,
            "MF_E_HW_MFT_FAILED_START_STREAMING" => MEDIASERVER::MF_E_HW_MFT_FAILED_START_STREAMING,
            "MF_E_ASF_PARSINGINCOMPLETE" => MEDIASERVER::MF_E_ASF_PARSINGINCOMPLETE,
            "MF_E_ASF_MISSINGDATA" => MEDIASERVER::MF_E_ASF_MISSINGDATA,
            "MF_E_ASF_INVALIDDATA" => MEDIASERVER::MF_E_ASF_INVALIDDATA,
            "MF_E_ASF_OPAQUEPACKET" => MEDIASERVER::MF_E_ASF_OPAQUEPACKET,
            "MF_E_ASF_NOINDEX" => MEDIASERVER::MF_E_ASF_NOINDEX,
            "MF_E_ASF_OUTOFRANGE" => MEDIASERVER::MF_E_ASF_OUTOFRANGE,
            "MF_E_ASF_INDEXNOTLOADED" => MEDIASERVER::MF_E_ASF_INDEXNOTLOADED,
            "MF_E_ASF_TOO_MANY_PAYLOADS" => MEDIASERVER::MF_E_ASF_TOO_MANY_PAYLOADS,
            "MF_E_ASF_UNSUPPORTED_STREAM_TYPE" => MEDIASERVER::MF_E_ASF_UNSUPPORTED_STREAM_TYPE,
            "MF_E_ASF_DROPPED_PACKET" => MEDIASERVER::MF_E_ASF_DROPPED_PACKET,
            "MF_E_NO_EVENTS_AVAILABLE" => MEDIASERVER::MF_E_NO_EVENTS_AVAILABLE,
            "MF_E_INVALID_STATE_TRANSITION" => MEDIASERVER::MF_E_INVALID_STATE_TRANSITION,
            "MF_E_END_OF_STREAM" => MEDIASERVER::MF_E_END_OF_STREAM,
            "MF_E_SHUTDOWN" => MEDIASERVER::MF_E_SHUTDOWN,
            "MF_E_MP3_NOTFOUND" => MEDIASERVER::MF_E_MP3_NOTFOUND,
            "MF_E_MP3_OUTOFDATA" => MEDIASERVER::MF_E_MP3_OUTOFDATA,
            "MF_E_MP3_NOTMP3" => MEDIASERVER::MF_E_MP3_NOTMP3,
            "MF_E_MP3_NOTSUPPORTED" => MEDIASERVER::MF_E_MP3_NOTSUPPORTED,
            "MF_E_NO_DURATION" => MEDIASERVER::MF_E_NO_DURATION,
            "MF_E_INVALID_FORMAT" => MEDIASERVER::MF_E_INVALID_FORMAT,
            "MF_E_PROPERTY_NOT_FOUND" => MEDIASERVER::MF_E_PROPERTY_NOT_FOUND,
            "MF_E_PROPERTY_READ_ONLY" => MEDIASERVER::MF_E_PROPERTY_READ_ONLY,
            "MF_E_PROPERTY_NOT_ALLOWED" => MEDIASERVER::MF_E_PROPERTY_NOT_ALLOWED,
            "MF_E_MEDIA_SOURCE_NOT_STARTED" => MEDIASERVER::MF_E_MEDIA_SOURCE_NOT_STARTED,
            "MF_E_UNSUPPORTED_FORMAT" => MEDIASERVER::MF_E_UNSUPPORTED_FORMAT,
            "MF_E_MP3_BAD_CRC" => MEDIASERVER::MF_E_MP3_BAD_CRC,
            "MF_E_NOT_PROTECTED" => MEDIASERVER::MF_E_NOT_PROTECTED,
            "MF_E_MEDIA_SOURCE_WRONGSTATE" => MEDIASERVER::MF_E_MEDIA_SOURCE_WRONGSTATE,
            "MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED" => MEDIASERVER::MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED,
            "MF_E_CANNOT_FIND_KEYFRAME_SAMPLE" => MEDIASERVER::MF_E_CANNOT_FIND_KEYFRAME_SAMPLE,
            "MF_E_NETWORK_RESOURCE_FAILURE" => MEDIASERVER::MF_E_NETWORK_RESOURCE_FAILURE,
            "MF_E_NET_WRITE" => MEDIASERVER::MF_E_NET_WRITE,
            "MF_E_NET_READ" => MEDIASERVER::MF_E_NET_READ,
            "MF_E_NET_REQUIRE_NETWORK" => MEDIASERVER::MF_E_NET_REQUIRE_NETWORK,
            "MF_E_NET_REQUIRE_ASYNC" => MEDIASERVER::MF_E_NET_REQUIRE_ASYNC,
            "MF_E_NET_BWLEVEL_NOT_SUPPORTED" => MEDIASERVER::MF_E_NET_BWLEVEL_NOT_SUPPORTED,
            "MF_E_NET_STREAMGROUPS_NOT_SUPPORTED" => MEDIASERVER::MF_E_NET_STREAMGROUPS_NOT_SUPPORTED,
            "MF_E_NET_MANUALSS_NOT_SUPPORTED" => MEDIASERVER::MF_E_NET_MANUALSS_NOT_SUPPORTED,
            "MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR" => MEDIASERVER::MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR,
            "MF_E_NET_CACHESTREAM_NOT_FOUND" => MEDIASERVER::MF_E_NET_CACHESTREAM_NOT_FOUND,
            "MF_E_NET_REQUIRE_INPUT" => MEDIASERVER::MF_E_NET_REQUIRE_INPUT,
            "MF_E_NET_REDIRECT" => MEDIASERVER::MF_E_NET_REDIRECT,
            "MF_E_NET_REDIRECT_TO_PROXY" => MEDIASERVER::MF_E_NET_REDIRECT_TO_PROXY,
            "MF_E_NET_TOO_MANY_REDIRECTS" => MEDIASERVER::MF_E_NET_TOO_MANY_REDIRECTS,
            "MF_E_NET_TIMEOUT" => MEDIASERVER::MF_E_NET_TIMEOUT,
            "MF_E_NET_CLIENT_CLOSE" => MEDIASERVER::MF_E_NET_CLIENT_CLOSE,
            "MF_E_NET_BAD_CONTROL_DATA" => MEDIASERVER::MF_E_NET_BAD_CONTROL_DATA,
            "MF_E_NET_INCOMPATIBLE_SERVER" => MEDIASERVER::MF_E_NET_INCOMPATIBLE_SERVER,
            "MF_E_NET_UNSAFE_URL" => MEDIASERVER::MF_E_NET_UNSAFE_URL,
            "MF_E_NET_CACHE_NO_DATA" => MEDIASERVER::MF_E_NET_CACHE_NO_DATA,
            "MF_E_NET_EOL" => MEDIASERVER::MF_E_NET_EOL,
            "MF_E_NET_BAD_REQUEST" => MEDIASERVER::MF_E_NET_BAD_REQUEST,
            "MF_E_NET_INTERNAL_SERVER_ERROR" => MEDIASERVER::MF_E_NET_INTERNAL_SERVER_ERROR,
            "MF_E_NET_SESSION_NOT_FOUND" => MEDIASERVER::MF_E_NET_SESSION_NOT_FOUND,
            "MF_E_NET_NOCONNECTION" => MEDIASERVER::MF_E_NET_NOCONNECTION,
            "MF_E_NET_CONNECTION_FAILURE" => MEDIASERVER::MF_E_NET_CONNECTION_FAILURE,
            "MF_E_NET_INCOMPATIBLE_PUSHSERVER" => MEDIASERVER::MF_E_NET_INCOMPATIBLE_PUSHSERVER,
            "MF_E_NET_SERVER_ACCESSDENIED" => MEDIASERVER::MF_E_NET_SERVER_ACCESSDENIED,
            "MF_E_NET_PROXY_ACCESSDENIED" => MEDIASERVER::MF_E_NET_PROXY_ACCESSDENIED,
            "MF_E_NET_CANNOTCONNECT" => MEDIASERVER::MF_E_NET_CANNOTCONNECT,
            "MF_E_NET_INVALID_PUSH_TEMPLATE" => MEDIASERVER::MF_E_NET_INVALID_PUSH_TEMPLATE,
            "MF_E_NET_INVALID_PUSH_PUBLISHING_POINT" => MEDIASERVER::MF_E_NET_INVALID_PUSH_PUBLISHING_POINT,
            "MF_E_NET_BUSY" => MEDIASERVER::MF_E_NET_BUSY,
            "MF_E_NET_RESOURCE_GONE" => MEDIASERVER::MF_E_NET_RESOURCE_GONE,
            "MF_E_NET_ERROR_FROM_PROXY" => MEDIASERVER::MF_E_NET_ERROR_FROM_PROXY,
            "MF_E_NET_PROXY_TIMEOUT" => MEDIASERVER::MF_E_NET_PROXY_TIMEOUT,
            "MF_E_NET_SERVER_UNAVAILABLE" => MEDIASERVER::MF_E_NET_SERVER_UNAVAILABLE,
            "MF_E_NET_TOO_MUCH_DATA" => MEDIASERVER::MF_E_NET_TOO_MUCH_DATA,
            "MF_E_NET_SESSION_INVALID" => MEDIASERVER::MF_E_NET_SESSION_INVALID,
            "MF_E_OFFLINE_MODE" => MEDIASERVER::MF_E_OFFLINE_MODE,
            "MF_E_NET_UDP_BLOCKED" => MEDIASERVER::MF_E_NET_UDP_BLOCKED,
            "MF_E_NET_UNSUPPORTED_CONFIGURATION" => MEDIASERVER::MF_E_NET_UNSUPPORTED_CONFIGURATION,
            "MF_E_NET_PROTOCOL_DISABLED" => MEDIASERVER::MF_E_NET_PROTOCOL_DISABLED,
            "MF_E_ALREADY_INITIALIZED" => MEDIASERVER::MF_E_ALREADY_INITIALIZED,
            "MF_E_BANDWIDTH_OVERRUN" => MEDIASERVER::MF_E_BANDWIDTH_OVERRUN,
            "MF_E_LATE_SAMPLE" => MEDIASERVER::MF_E_LATE_SAMPLE,
            "MF_E_FLUSH_NEEDED" => MEDIASERVER::MF_E_FLUSH_NEEDED,
            "MF_E_INVALID_PROFILE" => MEDIASERVER::MF_E_INVALID_PROFILE,
            "MF_E_INDEX_NOT_COMMITTED" => MEDIASERVER::MF_E_INDEX_NOT_COMMITTED,
            "MF_E_NO_INDEX" => MEDIASERVER::MF_E_NO_INDEX,
            "MF_E_CANNOT_INDEX_IN_PLACE" => MEDIASERVER::MF_E_CANNOT_INDEX_IN_PLACE,
            "MF_E_MISSING_ASF_LEAKYBUCKET" => MEDIASERVER::MF_E_MISSING_ASF_LEAKYBUCKET,
            "MF_E_INVALID_ASF_STREAMID" => MEDIASERVER::MF_E_INVALID_ASF_STREAMID,
            "MF_E_STREAMSINK_REMOVED" => MEDIASERVER::MF_E_STREAMSINK_REMOVED,
            "MF_E_STREAMSINKS_OUT_OF_SYNC" => MEDIASERVER::MF_E_STREAMSINKS_OUT_OF_SYNC,
            "MF_E_STREAMSINKS_FIXED" => MEDIASERVER::MF_E_STREAMSINKS_FIXED,
            "MF_E_STREAMSINK_EXISTS" => MEDIASERVER::MF_E_STREAMSINK_EXISTS,
            "MF_E_SAMPLEALLOCATOR_CANCELED" => MEDIASERVER::MF_E_SAMPLEALLOCATOR_CANCELED,
            "MF_E_SAMPLEALLOCATOR_EMPTY" => MEDIASERVER::MF_E_SAMPLEALLOCATOR_EMPTY,
            "MF_E_SINK_ALREADYSTOPPED" => MEDIASERVER::MF_E_SINK_ALREADYSTOPPED,
            "MF_E_ASF_FILESINK_BITRATE_UNKNOWN" => MEDIASERVER::MF_E_ASF_FILESINK_BITRATE_UNKNOWN,
            "MF_E_SINK_NO_STREAMS" => MEDIASERVER::MF_E_SINK_NO_STREAMS,
            "MF_E_METADATA_TOO_LONG" => MEDIASERVER::MF_E_METADATA_TOO_LONG,
            "MF_E_SINK_NO_SAMPLES_PROCESSED" => MEDIASERVER::MF_E_SINK_NO_SAMPLES_PROCESSED,
            "MF_E_VIDEO_REN_NO_PROCAMP_HW" => MEDIASERVER::MF_E_VIDEO_REN_NO_PROCAMP_HW,
            "MF_E_VIDEO_REN_NO_DEINTERLACE_HW" => MEDIASERVER::MF_E_VIDEO_REN_NO_DEINTERLACE_HW,
            "MF_E_VIDEO_REN_COPYPROT_FAILED" => MEDIASERVER::MF_E_VIDEO_REN_COPYPROT_FAILED,
            "MF_E_VIDEO_REN_SURFACE_NOT_SHARED" => MEDIASERVER::MF_E_VIDEO_REN_SURFACE_NOT_SHARED,
            "MF_E_VIDEO_DEVICE_LOCKED" => MEDIASERVER::MF_E_VIDEO_DEVICE_LOCKED,
            "MF_E_NEW_VIDEO_DEVICE" => MEDIASERVER::MF_E_NEW_VIDEO_DEVICE,
            "MF_E_NO_VIDEO_SAMPLE_AVAILABLE" => MEDIASERVER::MF_E_NO_VIDEO_SAMPLE_AVAILABLE,
            "MF_E_NO_AUDIO_PLAYBACK_DEVICE" => MEDIASERVER::MF_E_NO_AUDIO_PLAYBACK_DEVICE,
            "MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE" => MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE,
            "MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED" => MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED,
            "MF_E_AUDIO_SERVICE_NOT_RUNNING" => MEDIASERVER::MF_E_AUDIO_SERVICE_NOT_RUNNING,
            "MF_E_TOPO_INVALID_OPTIONAL_NODE" => MEDIASERVER::MF_E_TOPO_INVALID_OPTIONAL_NODE,
            "MF_E_TOPO_CANNOT_FIND_DECRYPTOR" => MEDIASERVER::MF_E_TOPO_CANNOT_FIND_DECRYPTOR,
            "MF_E_TOPO_CODEC_NOT_FOUND" => MEDIASERVER::MF_E_TOPO_CODEC_NOT_FOUND,
            "MF_E_TOPO_CANNOT_CONNECT" => MEDIASERVER::MF_E_TOPO_CANNOT_CONNECT,
            "MF_E_TOPO_UNSUPPORTED" => MEDIASERVER::MF_E_TOPO_UNSUPPORTED,
            "MF_E_TOPO_INVALID_TIME_ATTRIBUTES" => MEDIASERVER::MF_E_TOPO_INVALID_TIME_ATTRIBUTES,
            "MF_E_TOPO_LOOPS_IN_TOPOLOGY" => MEDIASERVER::MF_E_TOPO_LOOPS_IN_TOPOLOGY,
            "MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR" => MEDIASERVER::MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR,
            "MF_E_TOPO_MISSING_STREAM_DESCRIPTOR" => MEDIASERVER::MF_E_TOPO_MISSING_STREAM_DESCRIPTOR,
            "MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED" => MEDIASERVER::MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED,
            "MF_E_TOPO_MISSING_SOURCE" => MEDIASERVER::MF_E_TOPO_MISSING_SOURCE,
            "MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED" => MEDIASERVER::MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED,
            "MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID" => MEDIASERVER::MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID,
            "MF_E_NO_SOURCE_IN_CACHE" => MEDIASERVER::MF_E_NO_SOURCE_IN_CACHE,
            "MF_E_TRANSFORM_TYPE_NOT_SET" => MEDIASERVER::MF_E_TRANSFORM_TYPE_NOT_SET,
            "MF_E_TRANSFORM_STREAM_CHANGE" => MEDIASERVER::MF_E_TRANSFORM_STREAM_CHANGE,
            "MF_E_TRANSFORM_INPUT_REMAINING" => MEDIASERVER::MF_E_TRANSFORM_INPUT_REMAINING,
            "MF_E_TRANSFORM_PROFILE_MISSING" => MEDIASERVER::MF_E_TRANSFORM_PROFILE_MISSING,
            "MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT" => MEDIASERVER::MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT,
            "MF_E_TRANSFORM_PROFILE_TRUNCATED" => MEDIASERVER::MF_E_TRANSFORM_PROFILE_TRUNCATED,
            "MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED,
            "MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG,
            "MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE,
            "MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM,
            "MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG,
            "MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE,
            "MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE" => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE,
            "MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE" => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE,
            "MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE" => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE,
            "MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION" => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION,
            "MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES" => MEDIASERVER::MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES,
            "MF_E_TRANSFORM_NEED_MORE_INPUT" => MEDIASERVER::MF_E_TRANSFORM_NEED_MORE_INPUT,
            "MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG" => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG,
            "MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING" => MEDIASERVER::MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING,
            "MF_E_UNSUPPORTED_D3D_TYPE" => MEDIASERVER::MF_E_UNSUPPORTED_D3D_TYPE,
            "MF_E_TRANSFORM_ASYNC_LOCKED" => MEDIASERVER::MF_E_TRANSFORM_ASYNC_LOCKED,
            "MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER" => MEDIASERVER::MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER,
            "MF_E_LICENSE_INCORRECT_RIGHTS" => MEDIASERVER::MF_E_LICENSE_INCORRECT_RIGHTS,
            "MF_E_LICENSE_OUTOFDATE" => MEDIASERVER::MF_E_LICENSE_OUTOFDATE,
            "MF_E_LICENSE_REQUIRED" => MEDIASERVER::MF_E_LICENSE_REQUIRED,
            "MF_E_DRM_HARDWARE_INCONSISTENT" => MEDIASERVER::MF_E_DRM_HARDWARE_INCONSISTENT,
            "MF_E_NO_CONTENT_PROTECTION_MANAGER" => MEDIASERVER::MF_E_NO_CONTENT_PROTECTION_MANAGER,
            "MF_E_LICENSE_RESTORE_NO_RIGHTS" => MEDIASERVER::MF_E_LICENSE_RESTORE_NO_RIGHTS,
            "MF_E_BACKUP_RESTRICTED_LICENSE" => MEDIASERVER::MF_E_BACKUP_RESTRICTED_LICENSE,
            "MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION" => MEDIASERVER::MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION,
            "MF_E_COMPONENT_REVOKED" => MEDIASERVER::MF_E_COMPONENT_REVOKED,
            "MF_E_TRUST_DISABLED" => MEDIASERVER::MF_E_TRUST_DISABLED,
            "MF_E_WMDRMOTA_NO_ACTION" => MEDIASERVER::MF_E_WMDRMOTA_NO_ACTION,
            "MF_E_WMDRMOTA_ACTION_ALREADY_SET" => MEDIASERVER::MF_E_WMDRMOTA_ACTION_ALREADY_SET,
            "MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE" => MEDIASERVER::MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE,
            "MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED" => MEDIASERVER::MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED,
            "MF_E_WMDRMOTA_ACTION_MISMATCH" => MEDIASERVER::MF_E_WMDRMOTA_ACTION_MISMATCH,
            "MF_E_WMDRMOTA_INVALID_POLICY" => MEDIASERVER::MF_E_WMDRMOTA_INVALID_POLICY,
            "MF_E_POLICY_UNSUPPORTED" => MEDIASERVER::MF_E_POLICY_UNSUPPORTED,
            "MF_E_OPL_NOT_SUPPORTED" => MEDIASERVER::MF_E_OPL_NOT_SUPPORTED,
            "MF_E_TOPOLOGY_VERIFICATION_FAILED" => MEDIASERVER::MF_E_TOPOLOGY_VERIFICATION_FAILED,
            "MF_E_SIGNATURE_VERIFICATION_FAILED" => MEDIASERVER::MF_E_SIGNATURE_VERIFICATION_FAILED,
            "MF_E_DEBUGGING_NOT_ALLOWED" => MEDIASERVER::MF_E_DEBUGGING_NOT_ALLOWED,
            "MF_E_CODE_EXPIRED" => MEDIASERVER::MF_E_CODE_EXPIRED,
            "MF_E_GRL_VERSION_TOO_LOW" => MEDIASERVER::MF_E_GRL_VERSION_TOO_LOW,
            "MF_E_GRL_RENEWAL_NOT_FOUND" => MEDIASERVER::MF_E_GRL_RENEWAL_NOT_FOUND,
            "MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND" => MEDIASERVER::MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND,
            "MF_E_KERNEL_UNTRUSTED" => MEDIASERVER::MF_E_KERNEL_UNTRUSTED,
            "MF_E_PEAUTH_UNTRUSTED" => MEDIASERVER::MF_E_PEAUTH_UNTRUSTED,
            "MF_E_NON_PE_PROCESS" => MEDIASERVER::MF_E_NON_PE_PROCESS,
            "MF_E_REBOOT_REQUIRED" => MEDIASERVER::MF_E_REBOOT_REQUIRED,
            "MF_E_GRL_INVALID_FORMAT" => MEDIASERVER::MF_E_GRL_INVALID_FORMAT,
            "MF_E_GRL_UNRECOGNIZED_FORMAT" => MEDIASERVER::MF_E_GRL_UNRECOGNIZED_FORMAT,
            "MF_E_ALL_PROCESS_RESTART_REQUIRED" => MEDIASERVER::MF_E_ALL_PROCESS_RESTART_REQUIRED,
            "MF_E_PROCESS_RESTART_REQUIRED" => MEDIASERVER::MF_E_PROCESS_RESTART_REQUIRED,
            "MF_E_USERMODE_UNTRUSTED" => MEDIASERVER::MF_E_USERMODE_UNTRUSTED,
            "MF_E_PEAUTH_SESSION_NOT_STARTED" => MEDIASERVER::MF_E_PEAUTH_SESSION_NOT_STARTED,
            "MF_E_INSUFFICIENT_BUFFER" => MEDIASERVER::MF_E_INSUFFICIENT_BUFFER,
            "MF_E_PEAUTH_PUBLICKEY_REVOKED" => MEDIASERVER::MF_E_PEAUTH_PUBLICKEY_REVOKED,
            "MF_E_GRL_ABSENT" => MEDIASERVER::MF_E_GRL_ABSENT,
            "MF_E_PE_UNTRUSTED" => MEDIASERVER::MF_E_PE_UNTRUSTED,
            "MF_E_PEAUTH_NOT_STARTED" => MEDIASERVER::MF_E_PEAUTH_NOT_STARTED,
            "MF_E_INCOMPATIBLE_SAMPLE_PROTECTION" => MEDIASERVER::MF_E_INCOMPATIBLE_SAMPLE_PROTECTION,
            "MF_E_PE_SESSIONS_MAXED" => MEDIASERVER::MF_E_PE_SESSIONS_MAXED,
            "MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED" => MEDIASERVER::MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED,
            "MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED" => MEDIASERVER::MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED,
            "MF_E_ITA_UNSUPPORTED_ACTION" => MEDIASERVER::MF_E_ITA_UNSUPPORTED_ACTION,
            "MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS" => MEDIASERVER::MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS,
            "MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS" => MEDIASERVER::MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS,
            "MF_E_BAD_OPL_STRUCTURE_FORMAT" => MEDIASERVER::MF_E_BAD_OPL_STRUCTURE_FORMAT,
            "MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID" => MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID,
            "MF_E_NO_PMP_HOST" => MEDIASERVER::MF_E_NO_PMP_HOST,
            "MF_E_ITA_OPL_DATA_NOT_INITIALIZED" => MEDIASERVER::MF_E_ITA_OPL_DATA_NOT_INITIALIZED,
            "MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT" => MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT,
            "MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT" => MEDIASERVER::MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT,
            "MF_E_CLOCK_INVALID_CONTINUITY_KEY" => MEDIASERVER::MF_E_CLOCK_INVALID_CONTINUITY_KEY,
            "MF_E_CLOCK_NO_TIME_SOURCE" => MEDIASERVER::MF_E_CLOCK_NO_TIME_SOURCE,
            "MF_E_CLOCK_STATE_ALREADY_SET" => MEDIASERVER::MF_E_CLOCK_STATE_ALREADY_SET,
            "MF_E_CLOCK_NOT_SIMPLE" => MEDIASERVER::MF_E_CLOCK_NOT_SIMPLE,
            "MF_E_NO_MORE_DROP_MODES" => MEDIASERVER::MF_E_NO_MORE_DROP_MODES,
            "MF_E_NO_MORE_QUALITY_LEVELS" => MEDIASERVER::MF_E_NO_MORE_QUALITY_LEVELS,
            "MF_E_DROPTIME_NOT_SUPPORTED" => MEDIASERVER::MF_E_DROPTIME_NOT_SUPPORTED,
            "MF_E_QUALITYKNOB_WAIT_LONGER" => MEDIASERVER::MF_E_QUALITYKNOB_WAIT_LONGER,
            "MF_E_QM_INVALIDSTATE" => MEDIASERVER::MF_E_QM_INVALIDSTATE,
            "MF_E_TRANSCODE_NO_CONTAINERTYPE" => MEDIASERVER::MF_E_TRANSCODE_NO_CONTAINERTYPE,
            "MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS" => MEDIASERVER::MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS,
            "MF_E_TRANSCODE_NO_MATCHING_ENCODER" => MEDIASERVER::MF_E_TRANSCODE_NO_MATCHING_ENCODER,
            "MF_E_ALLOCATOR_NOT_INITIALIZED" => MEDIASERVER::MF_E_ALLOCATOR_NOT_INITIALIZED,
            "MF_E_ALLOCATOR_NOT_COMMITED" => MEDIASERVER::MF_E_ALLOCATOR_NOT_COMMITED,
            "MF_E_ALLOCATOR_ALREADY_COMMITED" => MEDIASERVER::MF_E_ALLOCATOR_ALREADY_COMMITED,
            "MF_E_STREAM_ERROR" => MEDIASERVER::MF_E_STREAM_ERROR,
            "MF_E_INVALID_STREAM_STATE" => MEDIASERVER::MF_E_INVALID_STREAM_STATE,
            "MF_E_HW_STREAM_NOT_CONNECTED" => MEDIASERVER::MF_E_HW_STREAM_NOT_CONNECTED,
        }
    }
    pub fn from_code(code: u32) -> MEDIASERVER {
        return match code {
            0x000D0000 => MEDIASERVER::NS_S_CALLPENDING,
            0x000D0001 => MEDIASERVER::NS_S_CALLABORTED,
            0x000D0002 => MEDIASERVER::NS_S_STREAM_TRUNCATED,
            0x000D0BC8 => MEDIASERVER::NS_S_REBUFFERING,
            0x000D0BC9 => MEDIASERVER::NS_S_DEGRADING_QUALITY,
            0x000D0BDB => MEDIASERVER::NS_S_TRANSCRYPTOR_EOF,
            0x000D0FE8 => MEDIASERVER::NS_S_WMP_UI_VERSIONMISMATCH,
            0x000D0FE9 => MEDIASERVER::NS_S_WMP_EXCEPTION,
            0x000D1040 => MEDIASERVER::NS_S_WMP_LOADED_GIF_IMAGE,
            0x000D1041 => MEDIASERVER::NS_S_WMP_LOADED_PNG_IMAGE,
            0x000D1042 => MEDIASERVER::NS_S_WMP_LOADED_BMP_IMAGE,
            0x000D1043 => MEDIASERVER::NS_S_WMP_LOADED_JPG_IMAGE,
            0x000D104F => MEDIASERVER::NS_S_WMG_FORCE_DROP_FRAME,
            0x000D105F => MEDIASERVER::NS_S_WMR_ALREADYRENDERED,
            0x000D1060 => MEDIASERVER::NS_S_WMR_PINTYPEPARTIALMATCH,
            0x000D1061 => MEDIASERVER::NS_S_WMR_PINTYPEFULLMATCH,
            0x000D1066 => MEDIASERVER::NS_S_WMG_ADVISE_DROP_FRAME,
            0x000D1067 => MEDIASERVER::NS_S_WMG_ADVISE_DROP_TO_KEYFRAME,
            0x000D10DB => MEDIASERVER::NS_S_NEED_TO_BUY_BURN_RIGHTS,
            0x000D10FE => MEDIASERVER::NS_S_WMPCORE_PLAYLISTCLEARABORT,
            0x000D10FF => MEDIASERVER::NS_S_WMPCORE_PLAYLISTREMOVEITEMABORT,
            0x000D1102 => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_CREATION_PENDING,
            0x000D1103 => MEDIASERVER::NS_S_WMPCORE_MEDIA_VALIDATION_PENDING,
            0x000D1104 => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_REPEAT_SECONDARY_SEGMENTS_IGNORED,
            0x000D1105 => MEDIASERVER::NS_S_WMPCORE_COMMAND_NOT_AVAILABLE,
            0x000D1106 => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_NAME_AUTO_GENERATED,
            0x000D1107 => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_IMPORT_MISSING_ITEMS,
            0x000D1108 => MEDIASERVER::NS_S_WMPCORE_PLAYLIST_COLLAPSED_TO_SINGLE_MEDIA,
            0x000D1109 => MEDIASERVER::NS_S_WMPCORE_MEDIA_CHILD_PLAYLIST_OPEN_PENDING,
            0x000D110A => MEDIASERVER::NS_S_WMPCORE_MORE_NODES_AVAIABLE,
            0x000D1135 => MEDIASERVER::NS_S_WMPBR_SUCCESS,
            0x000D1136 => MEDIASERVER::NS_S_WMPBR_PARTIALSUCCESS,
            0x000D1144 => MEDIASERVER::NS_S_WMPEFFECT_TRANSPARENT,
            0x000D1145 => MEDIASERVER::NS_S_WMPEFFECT_OPAQUE,
            0x000D114E => MEDIASERVER::NS_S_OPERATION_PENDING,
            0x000D1359 => MEDIASERVER::NS_S_TRACK_BUY_REQUIRES_ALBUM_PURCHASE,
            0x000D135E => MEDIASERVER::NS_S_NAVIGATION_COMPLETE_WITH_ERRORS,
            0x000D1361 => MEDIASERVER::NS_S_TRACK_ALREADY_DOWNLOADED,
            0x000D1519 => MEDIASERVER::NS_S_PUBLISHING_POINT_STARTED_WITH_FAILED_SINKS,
            0x000D2726 => MEDIASERVER::NS_S_DRM_LICENSE_ACQUIRED,
            0x000D2727 => MEDIASERVER::NS_S_DRM_INDIVIDUALIZED,
            0x000D2746 => MEDIASERVER::NS_S_DRM_MONITOR_CANCELLED,
            0x000D2747 => MEDIASERVER::NS_S_DRM_ACQUIRE_CANCELLED,
            0x000D276E => MEDIASERVER::NS_S_DRM_BURNABLE_TRACK,
            0x000D276F => MEDIASERVER::NS_S_DRM_BURNABLE_TRACK_WITH_PLAYLIST_RESTRICTION,
            0x000D27DE => MEDIASERVER::NS_S_DRM_NEEDS_INDIVIDUALIZATION,
            0x000D2AF8 => MEDIASERVER::NS_S_REBOOT_RECOMMENDED,
            0x000D2AF9 => MEDIASERVER::NS_S_REBOOT_REQUIRED,
            0x000D2F09 => MEDIASERVER::NS_S_EOSRECEDING,
            0x000D2F0D => MEDIASERVER::NS_S_CHANGENOTICE,
            0x000D36D8 => MEDIASERVER::MF_S_MULTIPLE_BEGIN,
            0x000D36FD => MEDIASERVER::MF_S_ACTIVATE_REPLACED,
            0x000D4A42 => MEDIASERVER::MF_S_SINK_NOT_FINALIZED,
            0x000D61AD => MEDIASERVER::MF_S_SEQUENCER_CONTEXT_CANCELED,
            0x000D61AF => MEDIASERVER::MF_S_SEQUENCER_SEGMENT_AT_END_OF_STREAM,
            0x000D6D75 => MEDIASERVER::MF_S_TRANSFORM_DO_NOT_PROPAGATE_EVENT,
            0x000D7150 => MEDIASERVER::MF_S_PROTECTION_NOT_REQUIRED,
            0x000D7168 => MEDIASERVER::MF_S_WAIT_FOR_POLICY_SET,
            0x000D7169 => MEDIASERVER::MF_S_VIDEO_DISABLED_WITH_UNKNOWN_SOFTWARE_OUTPUT,
            0x000D7173 => MEDIASERVER::MF_S_PE_TRUSTED,
            0x000D9C44 => MEDIASERVER::MF_S_CLOCK_STOPPED,
            0x400D004F => MEDIASERVER::NS_I_TIGER_START,
            0x400D0051 => MEDIASERVER::NS_I_CUB_START,
            0x400D0052 => MEDIASERVER::NS_I_CUB_RUNNING,
            0x400D0054 => MEDIASERVER::NS_I_DISK_START,
            0x400D0056 => MEDIASERVER::NS_I_DISK_REBUILD_STARTED,
            0x400D0057 => MEDIASERVER::NS_I_DISK_REBUILD_FINISHED,
            0x400D0058 => MEDIASERVER::NS_I_DISK_REBUILD_ABORTED,
            0x400D0059 => MEDIASERVER::NS_I_LIMIT_FUNNELS,
            0x400D005A => MEDIASERVER::NS_I_START_DISK,
            0x400D005B => MEDIASERVER::NS_I_STOP_DISK,
            0x400D005C => MEDIASERVER::NS_I_STOP_CUB,
            0x400D005D => MEDIASERVER::NS_I_KILL_USERSESSION,
            0x400D005E => MEDIASERVER::NS_I_KILL_CONNECTION,
            0x400D005F => MEDIASERVER::NS_I_REBUILD_DISK,
            0x400D0069 => MEDIASERVER::MCMADM_I_NO_EVENTS,
            0x400D006E => MEDIASERVER::NS_I_LOGGING_FAILED,
            0x400D0070 => MEDIASERVER::NS_I_LIMIT_BANDWIDTH,
            0x400D0191 => MEDIASERVER::NS_I_CUB_UNFAIL_LINK,
            0x400D0193 => MEDIASERVER::NS_I_RESTRIPE_START,
            0x400D0194 => MEDIASERVER::NS_I_RESTRIPE_DONE,
            0x400D0196 => MEDIASERVER::NS_I_RESTRIPE_DISK_OUT,
            0x400D0197 => MEDIASERVER::NS_I_RESTRIPE_CUB_OUT,
            0x400D0198 => MEDIASERVER::NS_I_DISK_STOP,
            0x400D14BE => MEDIASERVER::NS_I_PLAYLIST_CHANGE_RECEDING,
            0x400D2EFF => MEDIASERVER::NS_I_RECONNECTED,
            0x400D2F01 => MEDIASERVER::NS_I_NOLOG_STOP,
            0x400D2F03 => MEDIASERVER::NS_I_EXISTING_PACKETIZER,
            0x400D2F04 => MEDIASERVER::NS_I_MANUAL_PROXY,
            0x400D3A98 => MEDIASERVER::MF_S_ASF_PARSEINPROGRESS,
            0x400D4272 => MEDIASERVER::MF_I_MANUAL_PROXY,
            0x800D0003 => MEDIASERVER::NS_W_SERVER_BANDWIDTH_LIMIT,
            0x800D0004 => MEDIASERVER::NS_W_FILE_BANDWIDTH_LIMIT,
            0x800D0060 => MEDIASERVER::NS_W_UNKNOWN_EVENT,
            0x800D0199 => MEDIASERVER::NS_I_CATATONIC_FAILURE,
            0x800D019A => MEDIASERVER::NS_I_CATATONIC_AUTO_UNFAIL,
            0xC00D0005 => MEDIASERVER::NS_E_NOCONNECTION,
            0xC00D0006 => MEDIASERVER::NS_E_CANNOTCONNECT,
            0xC00D0007 => MEDIASERVER::NS_E_CANNOTDESTROYTITLE,
            0xC00D0008 => MEDIASERVER::NS_E_CANNOTRENAMETITLE,
            0xC00D0009 => MEDIASERVER::NS_E_CANNOTOFFLINEDISK,
            0xC00D000A => MEDIASERVER::NS_E_CANNOTONLINEDISK,
            0xC00D000B => MEDIASERVER::NS_E_NOREGISTEREDWALKER,
            0xC00D000C => MEDIASERVER::NS_E_NOFUNNEL,
            0xC00D000D => MEDIASERVER::NS_E_NO_LOCALPLAY,
            0xC00D000E => MEDIASERVER::NS_E_NETWORK_BUSY,
            0xC00D000F => MEDIASERVER::NS_E_TOO_MANY_SESS,
            0xC00D0010 => MEDIASERVER::NS_E_ALREADY_CONNECTED,
            0xC00D0011 => MEDIASERVER::NS_E_INVALID_INDEX,
            0xC00D0012 => MEDIASERVER::NS_E_PROTOCOL_MISMATCH,
            0xC00D0013 => MEDIASERVER::NS_E_TIMEOUT,
            0xC00D0014 => MEDIASERVER::NS_E_NET_WRITE,
            0xC00D0015 => MEDIASERVER::NS_E_NET_READ,
            0xC00D0016 => MEDIASERVER::NS_E_DISK_WRITE,
            0xC00D0017 => MEDIASERVER::NS_E_DISK_READ,
            0xC00D0018 => MEDIASERVER::NS_E_FILE_WRITE,
            0xC00D0019 => MEDIASERVER::NS_E_FILE_READ,
            0xC00D001A => MEDIASERVER::NS_E_FILE_NOT_FOUND,
            0xC00D001B => MEDIASERVER::NS_E_FILE_EXISTS,
            0xC00D001C => MEDIASERVER::NS_E_INVALID_NAME,
            0xC00D001D => MEDIASERVER::NS_E_FILE_OPEN_FAILED,
            0xC00D001E => MEDIASERVER::NS_E_FILE_ALLOCATION_FAILED,
            0xC00D001F => MEDIASERVER::NS_E_FILE_INIT_FAILED,
            0xC00D0020 => MEDIASERVER::NS_E_FILE_PLAY_FAILED,
            0xC00D0021 => MEDIASERVER::NS_E_SET_DISK_UID_FAILED,
            0xC00D0022 => MEDIASERVER::NS_E_INDUCED,
            0xC00D0023 => MEDIASERVER::NS_E_CCLINK_DOWN,
            0xC00D0024 => MEDIASERVER::NS_E_INTERNAL,
            0xC00D0025 => MEDIASERVER::NS_E_BUSY,
            0xC00D0026 => MEDIASERVER::NS_E_UNRECOGNIZED_STREAM_TYPE,
            0xC00D0027 => MEDIASERVER::NS_E_NETWORK_SERVICE_FAILURE,
            0xC00D0028 => MEDIASERVER::NS_E_NETWORK_RESOURCE_FAILURE,
            0xC00D0029 => MEDIASERVER::NS_E_CONNECTION_FAILURE,
            0xC00D002A => MEDIASERVER::NS_E_SHUTDOWN,
            0xC00D002B => MEDIASERVER::NS_E_INVALID_REQUEST,
            0xC00D002C => MEDIASERVER::NS_E_INSUFFICIENT_BANDWIDTH,
            0xC00D002D => MEDIASERVER::NS_E_NOT_REBUILDING,
            0xC00D002E => MEDIASERVER::NS_E_LATE_OPERATION,
            0xC00D002F => MEDIASERVER::NS_E_INVALID_DATA,
            0xC00D0030 => MEDIASERVER::NS_E_FILE_BANDWIDTH_LIMIT,
            0xC00D0031 => MEDIASERVER::NS_E_OPEN_FILE_LIMIT,
            0xC00D0032 => MEDIASERVER::NS_E_BAD_CONTROL_DATA,
            0xC00D0033 => MEDIASERVER::NS_E_NO_STREAM,
            0xC00D0034 => MEDIASERVER::NS_E_STREAM_END,
            0xC00D0035 => MEDIASERVER::NS_E_SERVER_NOT_FOUND,
            0xC00D0036 => MEDIASERVER::NS_E_DUPLICATE_NAME,
            0xC00D0037 => MEDIASERVER::NS_E_DUPLICATE_ADDRESS,
            0xC00D0038 => MEDIASERVER::NS_E_BAD_MULTICAST_ADDRESS,
            0xC00D0039 => MEDIASERVER::NS_E_BAD_ADAPTER_ADDRESS,
            0xC00D003A => MEDIASERVER::NS_E_BAD_DELIVERY_MODE,
            0xC00D003B => MEDIASERVER::NS_E_INVALID_CHANNEL,
            0xC00D003C => MEDIASERVER::NS_E_INVALID_STREAM,
            0xC00D003D => MEDIASERVER::NS_E_INVALID_ARCHIVE,
            0xC00D003E => MEDIASERVER::NS_E_NOTITLES,
            0xC00D003F => MEDIASERVER::NS_E_INVALID_CLIENT,
            0xC00D0040 => MEDIASERVER::NS_E_INVALID_BLACKHOLE_ADDRESS,
            0xC00D0041 => MEDIASERVER::NS_E_INCOMPATIBLE_FORMAT,
            0xC00D0042 => MEDIASERVER::NS_E_INVALID_KEY,
            0xC00D0043 => MEDIASERVER::NS_E_INVALID_PORT,
            0xC00D0044 => MEDIASERVER::NS_E_INVALID_TTL,
            0xC00D0045 => MEDIASERVER::NS_E_STRIDE_REFUSED,
            0xC00D0046 => MEDIASERVER::NS_E_MMSAUTOSERVER_CANTFINDWALKER,
            0xC00D0047 => MEDIASERVER::NS_E_MAX_BITRATE,
            0xC00D0048 => MEDIASERVER::NS_E_LOGFILEPERIOD,
            0xC00D0049 => MEDIASERVER::NS_E_MAX_CLIENTS,
            0xC00D004A => MEDIASERVER::NS_E_LOG_FILE_SIZE,
            0xC00D004B => MEDIASERVER::NS_E_MAX_FILERATE,
            0xC00D004C => MEDIASERVER::NS_E_WALKER_UNKNOWN,
            0xC00D004D => MEDIASERVER::NS_E_WALKER_SERVER,
            0xC00D004E => MEDIASERVER::NS_E_WALKER_USAGE,
            0xC00D0050 => MEDIASERVER::NS_E_TIGER_FAIL,
            0xC00D0053 => MEDIASERVER::NS_E_CUB_FAIL,
            0xC00D0055 => MEDIASERVER::NS_E_DISK_FAIL,
            0xC00D0060 => MEDIASERVER::NS_E_MAX_FUNNELS_ALERT,
            0xC00D0061 => MEDIASERVER::NS_E_ALLOCATE_FILE_FAIL,
            0xC00D0062 => MEDIASERVER::NS_E_PAGING_ERROR,
            0xC00D0063 => MEDIASERVER::NS_E_BAD_BLOCK0_VERSION,
            0xC00D0064 => MEDIASERVER::NS_E_BAD_DISK_UID,
            0xC00D0065 => MEDIASERVER::NS_E_BAD_FSMAJOR_VERSION,
            0xC00D0066 => MEDIASERVER::NS_E_BAD_STAMPNUMBER,
            0xC00D0067 => MEDIASERVER::NS_E_PARTIALLY_REBUILT_DISK,
            0xC00D0068 => MEDIASERVER::NS_E_ENACTPLAN_GIVEUP,
            0xC00D006A => MEDIASERVER::MCMADM_E_REGKEY_NOT_FOUND,
            0xC00D006B => MEDIASERVER::NS_E_NO_FORMATS,
            0xC00D006C => MEDIASERVER::NS_E_NO_REFERENCES,
            0xC00D006D => MEDIASERVER::NS_E_WAVE_OPEN,
            0xC00D006F => MEDIASERVER::NS_E_CANNOTCONNECTEVENTS,
            0xC00D0071 => MEDIASERVER::NS_E_NO_DEVICE,
            0xC00D0072 => MEDIASERVER::NS_E_NO_SPECIFIED_DEVICE,
            0xC00D00C8 => MEDIASERVER::NS_E_MONITOR_GIVEUP,
            0xC00D00C9 => MEDIASERVER::NS_E_REMIRRORED_DISK,
            0xC00D00CA => MEDIASERVER::NS_E_INSUFFICIENT_DATA,
            0xC00D00CB => MEDIASERVER::NS_E_ASSERT,
            0xC00D00CC => MEDIASERVER::NS_E_BAD_ADAPTER_NAME,
            0xC00D00CD => MEDIASERVER::NS_E_NOT_LICENSED,
            0xC00D00CE => MEDIASERVER::NS_E_NO_SERVER_CONTACT,
            0xC00D00CF => MEDIASERVER::NS_E_TOO_MANY_TITLES,
            0xC00D00D0 => MEDIASERVER::NS_E_TITLE_SIZE_EXCEEDED,
            0xC00D00D1 => MEDIASERVER::NS_E_UDP_DISABLED,
            0xC00D00D2 => MEDIASERVER::NS_E_TCP_DISABLED,
            0xC00D00D3 => MEDIASERVER::NS_E_HTTP_DISABLED,
            0xC00D00D4 => MEDIASERVER::NS_E_LICENSE_EXPIRED,
            0xC00D00D5 => MEDIASERVER::NS_E_TITLE_BITRATE,
            0xC00D00D6 => MEDIASERVER::NS_E_EMPTY_PROGRAM_NAME,
            0xC00D00D7 => MEDIASERVER::NS_E_MISSING_CHANNEL,
            0xC00D00D8 => MEDIASERVER::NS_E_NO_CHANNELS,
            0xC00D00D9 => MEDIASERVER::NS_E_INVALID_INDEX2,
            0xC00D0190 => MEDIASERVER::NS_E_CUB_FAIL_LINK,
            0xC00D0192 => MEDIASERVER::NS_E_BAD_CUB_UID,
            0xC00D0195 => MEDIASERVER::NS_E_GLITCH_MODE,
            0xC00D019B => MEDIASERVER::NS_E_NO_MEDIA_PROTOCOL,
            0xC00D07D0 => MEDIASERVER::ASF_E_BUFFEROVERRUN,
            0xC00D07D1 => MEDIASERVER::ASF_E_BUFFERTOOSMALL,
            0xC00D07D2 => MEDIASERVER::ASF_E_BADLANGUAGEID,
            0xC00D07DB => MEDIASERVER::ASF_E_NOPAYLOADLENGTH,
            0xC00D07DC => MEDIASERVER::ASF_E_TOOMANYPAYLOADS,
            0xC00D07DE => MEDIASERVER::ASF_E_PACKETCONTENTTOOLARGE,
            0xC00D07E0 => MEDIASERVER::ASF_E_UNKNOWNPACKETSIZE,
            0xC00D07E2 => MEDIASERVER::ASF_E_INVALIDHEADER,
            0xC00D07E6 => MEDIASERVER::ASF_E_NOCLOCKOBJECT,
            0xC00D07EB => MEDIASERVER::ASF_E_UNKNOWNCLOCKTYPE,
            0xC00D07ED => MEDIASERVER::ASF_E_OPAQUEPACKET,
            0xC00D07EE => MEDIASERVER::ASF_E_WRONGVERSION,
            0xC00D07EF => MEDIASERVER::ASF_E_OVERFLOW,
            0xC00D07F0 => MEDIASERVER::ASF_E_NOTFOUND,
            0xC00D07F1 => MEDIASERVER::NS_E_NOTHING_TO_DO,
            0xC00D07F2 => MEDIASERVER::NS_E_NO_MULTICAST,
            0xC00D07F3 => MEDIASERVER::ASF_E_OBJECTTOOBIG,
            0xC00D07F4 => MEDIASERVER::ASF_E_UNEXPECTEDVALUE,
            0xC00D07F5 => MEDIASERVER::ASF_E_INVALIDSTATE,
            0xC00D07F6 => MEDIASERVER::ASF_E_NOLIBRARY,
            0xC00D07F7 => MEDIASERVER::ASF_E_ALREADYINITIALIZED,
            0xC00D07F8 => MEDIASERVER::ASF_E_INVALIDINIT,
            0xC00D07F9 => MEDIASERVER::ASF_E_NOHEADEROBJECT,
            0xC00D07FA => MEDIASERVER::ASF_E_NODATAOBJECT,
            0xC00D07FB => MEDIASERVER::ASF_E_NOINDEXOBJECT,
            0xC00D07FC => MEDIASERVER::ASF_E_NOSTREAMPROPS,
            0xC00D07FD => MEDIASERVER::ASF_E_NOFILEPROPS,
            0xC00D0801 => MEDIASERVER::ASF_E_INVALIDFLAGS,
            0xC00D0802 => MEDIASERVER::ASF_E_BADDATADESCRIPTOR,
            0xC00D0803 => MEDIASERVER::ASF_E_BADINDEXINTERVAL,
            0xC00D0804 => MEDIASERVER::ASF_E_INVALIDTIME,
            0xC00D0805 => MEDIASERVER::ASF_E_INVALIDINDEX,
            0xC00D0806 => MEDIASERVER::ASF_E_STREAMNUMBERINUSE,
            0xC00D0807 => MEDIASERVER::ASF_E_BADMEDIATYPE,
            0xC00D0808 => MEDIASERVER::ASF_E_WRITEFAILED,
            0xC00D0809 => MEDIASERVER::ASF_E_NOTENOUGHDESCRIPTORS,
            0xC00D080A => MEDIASERVER::ASF_E_INDEXBLOCKUNLOADED,
            0xC00D080B => MEDIASERVER::ASF_E_NOTENOUGHBANDWIDTH,
            0xC00D080C => MEDIASERVER::ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE,
            0xC00D080D => MEDIASERVER::ASF_E_BADDATAUNIT,
            0xC00D080E => MEDIASERVER::ASF_E_HEADERSIZE,
            0xC00D0BB8 => MEDIASERVER::NS_E_INVALID_INPUT_FORMAT,
            0xC00D0BB9 => MEDIASERVER::NS_E_MSAUDIO_NOT_INSTALLED,
            0xC00D0BBA => MEDIASERVER::NS_E_UNEXPECTED_MSAUDIO_ERROR,
            0xC00D0BBB => MEDIASERVER::NS_E_INVALID_OUTPUT_FORMAT,
            0xC00D0BBC => MEDIASERVER::NS_E_NOT_CONFIGURED,
            0xC00D0BBD => MEDIASERVER::NS_E_PROTECTED_CONTENT,
            0xC00D0BBE => MEDIASERVER::NS_E_LICENSE_REQUIRED,
            0xC00D0BBF => MEDIASERVER::NS_E_TAMPERED_CONTENT,
            0xC00D0BC0 => MEDIASERVER::NS_E_LICENSE_OUTOFDATE,
            0xC00D0BC1 => MEDIASERVER::NS_E_LICENSE_INCORRECT_RIGHTS,
            0xC00D0BC2 => MEDIASERVER::NS_E_AUDIO_CODEC_NOT_INSTALLED,
            0xC00D0BC3 => MEDIASERVER::NS_E_AUDIO_CODEC_ERROR,
            0xC00D0BC4 => MEDIASERVER::NS_E_VIDEO_CODEC_NOT_INSTALLED,
            0xC00D0BC5 => MEDIASERVER::NS_E_VIDEO_CODEC_ERROR,
            0xC00D0BC6 => MEDIASERVER::NS_E_INVALIDPROFILE,
            0xC00D0BC7 => MEDIASERVER::NS_E_INCOMPATIBLE_VERSION,
            0xC00D0BCA => MEDIASERVER::NS_E_OFFLINE_MODE,
            0xC00D0BCB => MEDIASERVER::NS_E_NOT_CONNECTED,
            0xC00D0BCC => MEDIASERVER::NS_E_TOO_MUCH_DATA,
            0xC00D0BCD => MEDIASERVER::NS_E_UNSUPPORTED_PROPERTY,
            0xC00D0BCE => MEDIASERVER::NS_E_8BIT_WAVE_UNSUPPORTED,
            0xC00D0BCF => MEDIASERVER::NS_E_NO_MORE_SAMPLES,
            0xC00D0BD0 => MEDIASERVER::NS_E_INVALID_SAMPLING_RATE,
            0xC00D0BD1 => MEDIASERVER::NS_E_MAX_PACKET_SIZE_TOO_SMALL,
            0xC00D0BD2 => MEDIASERVER::NS_E_LATE_PACKET,
            0xC00D0BD3 => MEDIASERVER::NS_E_DUPLICATE_PACKET,
            0xC00D0BD4 => MEDIASERVER::NS_E_SDK_BUFFERTOOSMALL,
            0xC00D0BD5 => MEDIASERVER::NS_E_INVALID_NUM_PASSES,
            0xC00D0BD6 => MEDIASERVER::NS_E_ATTRIBUTE_READ_ONLY,
            0xC00D0BD7 => MEDIASERVER::NS_E_ATTRIBUTE_NOT_ALLOWED,
            0xC00D0BD8 => MEDIASERVER::NS_E_INVALID_EDL,
            0xC00D0BD9 => MEDIASERVER::NS_E_DATA_UNIT_EXTENSION_TOO_LARGE,
            0xC00D0BDA => MEDIASERVER::NS_E_CODEC_DMO_ERROR,
            0xC00D0BDC => MEDIASERVER::NS_E_FEATURE_DISABLED_BY_GROUP_POLICY,
            0xC00D0BDD => MEDIASERVER::NS_E_FEATURE_DISABLED_IN_SKU,
            0xC00D0FA0 => MEDIASERVER::NS_E_NO_CD,
            0xC00D0FA1 => MEDIASERVER::NS_E_CANT_READ_DIGITAL,
            0xC00D0FA2 => MEDIASERVER::NS_E_DEVICE_DISCONNECTED,
            0xC00D0FA3 => MEDIASERVER::NS_E_DEVICE_NOT_SUPPORT_FORMAT,
            0xC00D0FA4 => MEDIASERVER::NS_E_SLOW_READ_DIGITAL,
            0xC00D0FA5 => MEDIASERVER::NS_E_MIXER_INVALID_LINE,
            0xC00D0FA6 => MEDIASERVER::NS_E_MIXER_INVALID_CONTROL,
            0xC00D0FA7 => MEDIASERVER::NS_E_MIXER_INVALID_VALUE,
            0xC00D0FA8 => MEDIASERVER::NS_E_MIXER_UNKNOWN_MMRESULT,
            0xC00D0FA9 => MEDIASERVER::NS_E_USER_STOP,
            0xC00D0FAA => MEDIASERVER::NS_E_MP3_FORMAT_NOT_FOUND,
            0xC00D0FAB => MEDIASERVER::NS_E_CD_READ_ERROR_NO_CORRECTION,
            0xC00D0FAC => MEDIASERVER::NS_E_CD_READ_ERROR,
            0xC00D0FAD => MEDIASERVER::NS_E_CD_SLOW_COPY,
            0xC00D0FAE => MEDIASERVER::NS_E_CD_COPYTO_CD,
            0xC00D0FAF => MEDIASERVER::NS_E_MIXER_NODRIVER,
            0xC00D0FB0 => MEDIASERVER::NS_E_REDBOOK_ENABLED_WHILE_COPYING,
            0xC00D0FB1 => MEDIASERVER::NS_E_CD_REFRESH,
            0xC00D0FB2 => MEDIASERVER::NS_E_CD_DRIVER_PROBLEM,
            0xC00D0FB3 => MEDIASERVER::NS_E_WONT_DO_DIGITAL,
            0xC00D0FB4 => MEDIASERVER::NS_E_WMPXML_NOERROR,
            0xC00D0FB5 => MEDIASERVER::NS_E_WMPXML_ENDOFDATA,
            0xC00D0FB6 => MEDIASERVER::NS_E_WMPXML_PARSEERROR,
            0xC00D0FB7 => MEDIASERVER::NS_E_WMPXML_ATTRIBUTENOTFOUND,
            0xC00D0FB8 => MEDIASERVER::NS_E_WMPXML_PINOTFOUND,
            0xC00D0FB9 => MEDIASERVER::NS_E_WMPXML_EMPTYDOC,
            0xC00D0FBA => MEDIASERVER::NS_E_WMP_PATH_ALREADY_IN_LIBRARY,
            0xC00D0FBE => MEDIASERVER::NS_E_WMP_FILESCANALREADYSTARTED,
            0xC00D0FBF => MEDIASERVER::NS_E_WMP_HME_INVALIDOBJECTID,
            0xC00D0FC0 => MEDIASERVER::NS_E_WMP_MF_CODE_EXPIRED,
            0xC00D0FC1 => MEDIASERVER::NS_E_WMP_HME_NOTSEARCHABLEFORITEMS,
            0xC00D0FC7 => MEDIASERVER::NS_E_WMP_ADDTOLIBRARY_FAILED,
            0xC00D0FC8 => MEDIASERVER::NS_E_WMP_WINDOWSAPIFAILURE,
            0xC00D0FC9 => MEDIASERVER::NS_E_WMP_RECORDING_NOT_ALLOWED,
            0xC00D0FCA => MEDIASERVER::NS_E_DEVICE_NOT_READY,
            0xC00D0FCB => MEDIASERVER::NS_E_DAMAGED_FILE,
            0xC00D0FCC => MEDIASERVER::NS_E_MPDB_GENERIC,
            0xC00D0FCD => MEDIASERVER::NS_E_FILE_FAILED_CHECKS,
            0xC00D0FCE => MEDIASERVER::NS_E_MEDIA_LIBRARY_FAILED,
            0xC00D0FCF => MEDIASERVER::NS_E_SHARING_VIOLATION,
            0xC00D0FD0 => MEDIASERVER::NS_E_NO_ERROR_STRING_FOUND,
            0xC00D0FD1 => MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_CORE,
            0xC00D0FD2 => MEDIASERVER::NS_E_WMPOCX_NO_ACTIVE_CORE,
            0xC00D0FD3 => MEDIASERVER::NS_E_WMPOCX_NOT_RUNNING_REMOTELY,
            0xC00D0FD4 => MEDIASERVER::NS_E_WMPOCX_NO_REMOTE_WINDOW,
            0xC00D0FD5 => MEDIASERVER::NS_E_WMPOCX_ERRORMANAGERNOTAVAILABLE,
            0xC00D0FD6 => MEDIASERVER::NS_E_PLUGIN_NOTSHUTDOWN,
            0xC00D0FD7 => MEDIASERVER::NS_E_WMP_CANNOT_FIND_FOLDER,
            0xC00D0FD8 => MEDIASERVER::NS_E_WMP_STREAMING_RECORDING_NOT_ALLOWED,
            0xC00D0FD9 => MEDIASERVER::NS_E_WMP_PLUGINDLL_NOTFOUND,
            0xC00D0FDA => MEDIASERVER::NS_E_NEED_TO_ASK_USER,
            0xC00D0FDB => MEDIASERVER::NS_E_WMPOCX_PLAYER_NOT_DOCKED,
            0xC00D0FDC => MEDIASERVER::NS_E_WMP_EXTERNAL_NOTREADY,
            0xC00D0FDD => MEDIASERVER::NS_E_WMP_MLS_STALE_DATA,
            0xC00D0FDE => MEDIASERVER::NS_E_WMP_UI_SUBCONTROLSNOTSUPPORTED,
            0xC00D0FDF => MEDIASERVER::NS_E_WMP_UI_VERSIONMISMATCH,
            0xC00D0FE0 => MEDIASERVER::NS_E_WMP_UI_NOTATHEMEFILE,
            0xC00D0FE1 => MEDIASERVER::NS_E_WMP_UI_SUBELEMENTNOTFOUND,
            0xC00D0FE2 => MEDIASERVER::NS_E_WMP_UI_VERSIONPARSE,
            0xC00D0FE3 => MEDIASERVER::NS_E_WMP_UI_VIEWIDNOTFOUND,
            0xC00D0FE4 => MEDIASERVER::NS_E_WMP_UI_PASSTHROUGH,
            0xC00D0FE5 => MEDIASERVER::NS_E_WMP_UI_OBJECTNOTFOUND,
            0xC00D0FE6 => MEDIASERVER::NS_E_WMP_UI_SECONDHANDLER,
            0xC00D0FE7 => MEDIASERVER::NS_E_WMP_UI_NOSKININZIP,
            0xC00D0FEA => MEDIASERVER::NS_E_WMP_URLDOWNLOADFAILED,
            0xC00D0FEB => MEDIASERVER::NS_E_WMPOCX_UNABLE_TO_LOAD_SKIN,
            0xC00D0FEC => MEDIASERVER::NS_E_WMP_INVALID_SKIN,
            0xC00D0FED => MEDIASERVER::NS_E_WMP_SENDMAILFAILED,
            0xC00D0FEE => MEDIASERVER::NS_E_WMP_LOCKEDINSKINMODE,
            0xC00D0FEF => MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_FILE,
            0xC00D0FF0 => MEDIASERVER::NS_E_WMP_SAVEAS_READONLY,
            0xC00D0FF1 => MEDIASERVER::NS_E_WMP_FAILED_TO_SAVE_PLAYLIST,
            0xC00D0FF2 => MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_WMD,
            0xC00D0FF3 => MEDIASERVER::NS_E_WMP_CANT_PLAY_PROTECTED,
            0xC00D0FF4 => MEDIASERVER::NS_E_SHARING_STATE_OUT_OF_SYNC,
            0xC00D0FFA => MEDIASERVER::NS_E_WMPOCX_REMOTE_PLAYER_ALREADY_RUNNING,
            0xC00D1004 => MEDIASERVER::NS_E_WMP_RBC_JPGMAPPINGIMAGE,
            0xC00D1005 => MEDIASERVER::NS_E_WMP_JPGTRANSPARENCY,
            0xC00D1009 => MEDIASERVER::NS_E_WMP_INVALID_MAX_VAL,
            0xC00D100A => MEDIASERVER::NS_E_WMP_INVALID_MIN_VAL,
            0xC00D100E => MEDIASERVER::NS_E_WMP_CS_JPGPOSITIONIMAGE,
            0xC00D100F => MEDIASERVER::NS_E_WMP_CS_NOTEVENLYDIVISIBLE,
            0xC00D1018 => MEDIASERVER::NS_E_WMPZIP_NOTAZIPFILE,
            0xC00D1019 => MEDIASERVER::NS_E_WMPZIP_CORRUPT,
            0xC00D101A => MEDIASERVER::NS_E_WMPZIP_FILENOTFOUND,
            0xC00D1022 => MEDIASERVER::NS_E_WMP_IMAGE_FILETYPE_UNSUPPORTED,
            0xC00D1023 => MEDIASERVER::NS_E_WMP_IMAGE_INVALID_FORMAT,
            0xC00D1024 => MEDIASERVER::NS_E_WMP_GIF_UNEXPECTED_ENDOFFILE,
            0xC00D1025 => MEDIASERVER::NS_E_WMP_GIF_INVALID_FORMAT,
            0xC00D1026 => MEDIASERVER::NS_E_WMP_GIF_BAD_VERSION_NUMBER,
            0xC00D1027 => MEDIASERVER::NS_E_WMP_GIF_NO_IMAGE_IN_FILE,
            0xC00D1028 => MEDIASERVER::NS_E_WMP_PNG_INVALIDFORMAT,
            0xC00D1029 => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BITDEPTH,
            0xC00D102A => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_COMPRESSION,
            0xC00D102B => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_FILTER,
            0xC00D102C => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_INTERLACE,
            0xC00D102D => MEDIASERVER::NS_E_WMP_PNG_UNSUPPORTED_BAD_CRC,
            0xC00D102E => MEDIASERVER::NS_E_WMP_BMP_INVALID_BITMASK,
            0xC00D102F => MEDIASERVER::NS_E_WMP_BMP_TOPDOWN_DIB_UNSUPPORTED,
            0xC00D1030 => MEDIASERVER::NS_E_WMP_BMP_BITMAP_NOT_CREATED,
            0xC00D1031 => MEDIASERVER::NS_E_WMP_BMP_COMPRESSION_UNSUPPORTED,
            0xC00D1032 => MEDIASERVER::NS_E_WMP_BMP_INVALID_FORMAT,
            0xC00D1033 => MEDIASERVER::NS_E_WMP_JPG_JERR_ARITHCODING_NOTIMPL,
            0xC00D1034 => MEDIASERVER::NS_E_WMP_JPG_INVALID_FORMAT,
            0xC00D1035 => MEDIASERVER::NS_E_WMP_JPG_BAD_DCTSIZE,
            0xC00D1036 => MEDIASERVER::NS_E_WMP_JPG_BAD_VERSION_NUMBER,
            0xC00D1037 => MEDIASERVER::NS_E_WMP_JPG_BAD_PRECISION,
            0xC00D1038 => MEDIASERVER::NS_E_WMP_JPG_CCIR601_NOTIMPL,
            0xC00D1039 => MEDIASERVER::NS_E_WMP_JPG_NO_IMAGE_IN_FILE,
            0xC00D103A => MEDIASERVER::NS_E_WMP_JPG_READ_ERROR,
            0xC00D103B => MEDIASERVER::NS_E_WMP_JPG_FRACT_SAMPLE_NOTIMPL,
            0xC00D103C => MEDIASERVER::NS_E_WMP_JPG_IMAGE_TOO_BIG,
            0xC00D103D => MEDIASERVER::NS_E_WMP_JPG_UNEXPECTED_ENDOFFILE,
            0xC00D103E => MEDIASERVER::NS_E_WMP_JPG_SOF_UNSUPPORTED,
            0xC00D103F => MEDIASERVER::NS_E_WMP_JPG_UNKNOWN_MARKER,
            0xC00D1044 => MEDIASERVER::NS_E_WMP_FAILED_TO_OPEN_IMAGE,
            0xC00D1049 => MEDIASERVER::NS_E_WMP_DAI_SONGTOOSHORT,
            0xC00D104A => MEDIASERVER::NS_E_WMG_RATEUNAVAILABLE,
            0xC00D104B => MEDIASERVER::NS_E_WMG_PLUGINUNAVAILABLE,
            0xC00D104C => MEDIASERVER::NS_E_WMG_CANNOTQUEUE,
            0xC00D104D => MEDIASERVER::NS_E_WMG_PREROLLLICENSEACQUISITIONNOTALLOWED,
            0xC00D104E => MEDIASERVER::NS_E_WMG_UNEXPECTEDPREROLLSTATUS,
            0xC00D1051 => MEDIASERVER::NS_E_WMG_INVALID_COPP_CERTIFICATE,
            0xC00D1052 => MEDIASERVER::NS_E_WMG_COPP_SECURITY_INVALID,
            0xC00D1053 => MEDIASERVER::NS_E_WMG_COPP_UNSUPPORTED,
            0xC00D1054 => MEDIASERVER::NS_E_WMG_INVALIDSTATE,
            0xC00D1055 => MEDIASERVER::NS_E_WMG_SINKALREADYEXISTS,
            0xC00D1056 => MEDIASERVER::NS_E_WMG_NOSDKINTERFACE,
            0xC00D1057 => MEDIASERVER::NS_E_WMG_NOTALLOUTPUTSRENDERED,
            0xC00D1058 => MEDIASERVER::NS_E_WMG_FILETRANSFERNOTALLOWED,
            0xC00D1059 => MEDIASERVER::NS_E_WMR_UNSUPPORTEDSTREAM,
            0xC00D105A => MEDIASERVER::NS_E_WMR_PINNOTFOUND,
            0xC00D105B => MEDIASERVER::NS_E_WMR_WAITINGONFORMATSWITCH,
            0xC00D105C => MEDIASERVER::NS_E_WMR_NOSOURCEFILTER,
            0xC00D105D => MEDIASERVER::NS_E_WMR_PINTYPENOMATCH,
            0xC00D105E => MEDIASERVER::NS_E_WMR_NOCALLBACKAVAILABLE,
            0xC00D1062 => MEDIASERVER::NS_E_WMR_SAMPLEPROPERTYNOTSET,
            0xC00D1063 => MEDIASERVER::NS_E_WMR_CANNOT_RENDER_BINARY_STREAM,
            0xC00D1064 => MEDIASERVER::NS_E_WMG_LICENSE_TAMPERED,
            0xC00D1065 => MEDIASERVER::NS_E_WMR_WILLNOT_RENDER_BINARY_STREAM,
            0xC00D1068 => MEDIASERVER::NS_E_WMX_UNRECOGNIZED_PLAYLIST_FORMAT,
            0xC00D1069 => MEDIASERVER::NS_E_ASX_INVALIDFORMAT,
            0xC00D106A => MEDIASERVER::NS_E_ASX_INVALIDVERSION,
            0xC00D106B => MEDIASERVER::NS_E_ASX_INVALID_REPEAT_BLOCK,
            0xC00D106C => MEDIASERVER::NS_E_ASX_NOTHING_TO_WRITE,
            0xC00D106D => MEDIASERVER::NS_E_URLLIST_INVALIDFORMAT,
            0xC00D106E => MEDIASERVER::NS_E_WMX_ATTRIBUTE_DOES_NOT_EXIST,
            0xC00D106F => MEDIASERVER::NS_E_WMX_ATTRIBUTE_ALREADY_EXISTS,
            0xC00D1070 => MEDIASERVER::NS_E_WMX_ATTRIBUTE_UNRETRIEVABLE,
            0xC00D1071 => MEDIASERVER::NS_E_WMX_ITEM_DOES_NOT_EXIST,
            0xC00D1072 => MEDIASERVER::NS_E_WMX_ITEM_TYPE_ILLEGAL,
            0xC00D1073 => MEDIASERVER::NS_E_WMX_ITEM_UNSETTABLE,
            0xC00D1074 => MEDIASERVER::NS_E_WMX_PLAYLIST_EMPTY,
            0xC00D1075 => MEDIASERVER::NS_E_MLS_SMARTPLAYLIST_FILTER_NOT_REGISTERED,
            0xC00D1076 => MEDIASERVER::NS_E_WMX_INVALID_FORMAT_OVER_NESTING,
            0xC00D107C => MEDIASERVER::NS_E_WMPCORE_NOSOURCEURLSTRING,
            0xC00D107D => MEDIASERVER::NS_E_WMPCORE_COCREATEFAILEDFORGITOBJECT,
            0xC00D107E => MEDIASERVER::NS_E_WMPCORE_FAILEDTOGETMARSHALLEDEVENTHANDLERINTERFACE,
            0xC00D107F => MEDIASERVER::NS_E_WMPCORE_BUFFERTOOSMALL,
            0xC00D1080 => MEDIASERVER::NS_E_WMPCORE_UNAVAILABLE,
            0xC00D1081 => MEDIASERVER::NS_E_WMPCORE_INVALIDPLAYLISTMODE,
            0xC00D1086 => MEDIASERVER::NS_E_WMPCORE_ITEMNOTINPLAYLIST,
            0xC00D1087 => MEDIASERVER::NS_E_WMPCORE_PLAYLISTEMPTY,
            0xC00D1088 => MEDIASERVER::NS_E_WMPCORE_NOBROWSER,
            0xC00D1089 => MEDIASERVER::NS_E_WMPCORE_UNRECOGNIZED_MEDIA_URL,
            0xC00D108A => MEDIASERVER::NS_E_WMPCORE_GRAPH_NOT_IN_LIST,
            0xC00D108B => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_OR_SINGLE_MEDIA,
            0xC00D108C => MEDIASERVER::NS_E_WMPCORE_ERRORSINKNOTREGISTERED,
            0xC00D108D => MEDIASERVER::NS_E_WMPCORE_ERRORMANAGERNOTAVAILABLE,
            0xC00D108E => MEDIASERVER::NS_E_WMPCORE_WEBHELPFAILED,
            0xC00D108F => MEDIASERVER::NS_E_WMPCORE_MEDIA_ERROR_RESUME_FAILED,
            0xC00D1090 => MEDIASERVER::NS_E_WMPCORE_NO_REF_IN_ENTRY,
            0xC00D1091 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_EMPTY,
            0xC00D1092 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_NAME_ILLEGAL,
            0xC00D1093 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_EMPTY,
            0xC00D1094 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ATTRIBUTE_VALUE_ILLEGAL,
            0xC00D1095 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_EMPTY,
            0xC00D1096 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_NAME_ILLEGAL,
            0xC00D1097 => MEDIASERVER::NS_E_WMPCORE_WMX_LIST_ITEM_ATTRIBUTE_VALUE_EMPTY,
            0xC00D1098 => MEDIASERVER::NS_E_WMPCORE_LIST_ENTRY_NO_REF,
            0xC00D1099 => MEDIASERVER::NS_E_WMPCORE_MISNAMED_FILE,
            0xC00D109A => MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_TRUSTED,
            0xC00D109B => MEDIASERVER::NS_E_WMPCORE_CODEC_NOT_FOUND,
            0xC00D109C => MEDIASERVER::NS_E_WMPCORE_CODEC_DOWNLOAD_NOT_ALLOWED,
            0xC00D109D => MEDIASERVER::NS_E_WMPCORE_ERROR_DOWNLOADING_PLAYLIST,
            0xC00D109E => MEDIASERVER::NS_E_WMPCORE_FAILED_TO_BUILD_PLAYLIST,
            0xC00D109F => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NONE,
            0xC00D10A0 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_EXHAUSTED,
            0xC00D10A1 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_NAME_NOT_FOUND,
            0xC00D10A2 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_MORPH_FAILED,
            0xC00D10A3 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_ITEM_ALTERNATE_INIT_FAILED,
            0xC00D10A4 => MEDIASERVER::NS_E_WMPCORE_MEDIA_ALTERNATE_REF_EMPTY,
            0xC00D10A5 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_NO_EVENT_NAME,
            0xC00D10A6 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_ATTRIBUTE_ABSENT,
            0xC00D10A7 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EVENT_EMPTY,
            0xC00D10A8 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_STACK_EMPTY,
            0xC00D10A9 => MEDIASERVER::NS_E_WMPCORE_CURRENT_MEDIA_NOT_ACTIVE,
            0xC00D10AB => MEDIASERVER::NS_E_WMPCORE_USER_CANCEL,
            0xC00D10AC => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_EMPTY,
            0xC00D10AD => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_START_MEDIA_NONE,
            0xC00D10AE => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_REPEAT_END_MEDIA_NONE,
            0xC00D10AF => MEDIASERVER::NS_E_WMPCORE_INVALID_PLAYLIST_URL,
            0xC00D10B0 => MEDIASERVER::NS_E_WMPCORE_MISMATCHED_RUNTIME,
            0xC00D10B1 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_IMPORT_FAILED_NO_ITEMS,
            0xC00D10B2 => MEDIASERVER::NS_E_WMPCORE_VIDEO_TRANSFORM_FILTER_INSERTION,
            0xC00D10B3 => MEDIASERVER::NS_E_WMPCORE_MEDIA_UNAVAILABLE,
            0xC00D10B4 => MEDIASERVER::NS_E_WMPCORE_WMX_ENTRYREF_NO_REF,
            0xC00D10B5 => MEDIASERVER::NS_E_WMPCORE_NO_PLAYABLE_MEDIA_IN_PLAYLIST,
            0xC00D10B6 => MEDIASERVER::NS_E_WMPCORE_PLAYLIST_EMPTY_NESTED_PLAYLIST_SKIPPED_ITEMS,
            0xC00D10B7 => MEDIASERVER::NS_E_WMPCORE_BUSY,
            0xC00D10B8 => MEDIASERVER::NS_E_WMPCORE_MEDIA_CHILD_PLAYLIST_UNAVAILABLE,
            0xC00D10B9 => MEDIASERVER::NS_E_WMPCORE_MEDIA_NO_CHILD_PLAYLIST,
            0xC00D10BA => MEDIASERVER::NS_E_WMPCORE_FILE_NOT_FOUND,
            0xC00D10BB => MEDIASERVER::NS_E_WMPCORE_TEMP_FILE_NOT_FOUND,
            0xC00D10BC => MEDIASERVER::NS_E_WMDM_REVOKED,
            0xC00D10BD => MEDIASERVER::NS_E_DDRAW_GENERIC,
            0xC00D10BE => MEDIASERVER::NS_E_DISPLAY_MODE_CHANGE_FAILED,
            0xC00D10BF => MEDIASERVER::NS_E_PLAYLIST_CONTAINS_ERRORS,
            0xC00D10C0 => MEDIASERVER::NS_E_CHANGING_PROXY_NAME,
            0xC00D10C1 => MEDIASERVER::NS_E_CHANGING_PROXY_PORT,
            0xC00D10C2 => MEDIASERVER::NS_E_CHANGING_PROXY_EXCEPTIONLIST,
            0xC00D10C3 => MEDIASERVER::NS_E_CHANGING_PROXYBYPASS,
            0xC00D10C4 => MEDIASERVER::NS_E_CHANGING_PROXY_PROTOCOL_NOT_FOUND,
            0xC00D10C5 => MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGE,
            0xC00D10C6 => MEDIASERVER::NS_E_GRAPH_NOAUDIOLANGUAGESELECTED,
            0xC00D10C7 => MEDIASERVER::NS_E_CORECD_NOTAMEDIACD,
            0xC00D10C8 => MEDIASERVER::NS_E_WMPCORE_MEDIA_URL_TOO_LONG,
            0xC00D10C9 => MEDIASERVER::NS_E_WMPFLASH_CANT_FIND_COM_SERVER,
            0xC00D10CA => MEDIASERVER::NS_E_WMPFLASH_INCOMPATIBLEVERSION,
            0xC00D10CB => MEDIASERVER::NS_E_WMPOCXGRAPH_IE_DISALLOWS_ACTIVEX_CONTROLS,
            0xC00D10CC => MEDIASERVER::NS_E_NEED_CORE_REFERENCE,
            0xC00D10CD => MEDIASERVER::NS_E_MEDIACD_READ_ERROR,
            0xC00D10CE => MEDIASERVER::NS_E_IE_DISALLOWS_ACTIVEX_CONTROLS,
            0xC00D10CF => MEDIASERVER::NS_E_FLASH_PLAYBACK_NOT_ALLOWED,
            0xC00D10D0 => MEDIASERVER::NS_E_UNABLE_TO_CREATE_RIP_LOCATION,
            0xC00D10D1 => MEDIASERVER::NS_E_WMPCORE_SOME_CODECS_MISSING,
            0xC00D10D2 => MEDIASERVER::NS_E_WMP_RIP_FAILED,
            0xC00D10D3 => MEDIASERVER::NS_E_WMP_FAILED_TO_RIP_TRACK,
            0xC00D10D4 => MEDIASERVER::NS_E_WMP_ERASE_FAILED,
            0xC00D10D5 => MEDIASERVER::NS_E_WMP_FORMAT_FAILED,
            0xC00D10D6 => MEDIASERVER::NS_E_WMP_CANNOT_BURN_NON_LOCAL_FILE,
            0xC00D10D7 => MEDIASERVER::NS_E_WMP_FILE_TYPE_CANNOT_BURN_TO_AUDIO_CD,
            0xC00D10D8 => MEDIASERVER::NS_E_WMP_FILE_DOES_NOT_FIT_ON_CD,
            0xC00D10D9 => MEDIASERVER::NS_E_WMP_FILE_NO_DURATION,
            0xC00D10DA => MEDIASERVER::NS_E_PDA_FAILED_TO_BURN,
            0xC00D10DC => MEDIASERVER::NS_E_FAILED_DOWNLOAD_ABORT_BURN,
            0xC00D10DD => MEDIASERVER::NS_E_WMPCORE_DEVICE_DRIVERS_MISSING,
            0xC00D1126 => MEDIASERVER::NS_E_WMPIM_USEROFFLINE,
            0xC00D1127 => MEDIASERVER::NS_E_WMPIM_USERCANCELED,
            0xC00D1128 => MEDIASERVER::NS_E_WMPIM_DIALUPFAILED,
            0xC00D1129 => MEDIASERVER::NS_E_WINSOCK_ERROR_STRING,
            0xC00D1130 => MEDIASERVER::NS_E_WMPBR_NOLISTENER,
            0xC00D1131 => MEDIASERVER::NS_E_WMPBR_BACKUPCANCEL,
            0xC00D1132 => MEDIASERVER::NS_E_WMPBR_RESTORECANCEL,
            0xC00D1133 => MEDIASERVER::NS_E_WMPBR_ERRORWITHURL,
            0xC00D1134 => MEDIASERVER::NS_E_WMPBR_NAMECOLLISION,
            0xC00D1137 => MEDIASERVER::NS_E_WMPBR_DRIVE_INVALID,
            0xC00D1138 => MEDIASERVER::NS_E_WMPBR_BACKUPRESTOREFAILED,
            0xC00D1158 => MEDIASERVER::NS_E_WMP_CONVERT_FILE_FAILED,
            0xC00D1159 => MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_ERRORURL,
            0xC00D115A => MEDIASERVER::NS_E_WMP_CONVERT_NO_RIGHTS_NOERRORURL,
            0xC00D115B => MEDIASERVER::NS_E_WMP_CONVERT_FILE_CORRUPT,
            0xC00D115C => MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_ERRORURL,
            0xC00D115D => MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNAVAILABLE_NOERRORURL,
            0xC00D115E => MEDIASERVER::NS_E_WMP_CONVERT_PLUGIN_UNKNOWN_FILE_OWNER,
            0xC00D1160 => MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_NS,
            0xC00D1161 => MEDIASERVER::NS_E_DVD_DISC_COPY_PROTECT_OUTPUT_FAILED,
            0xC00D1162 => MEDIASERVER::NS_E_DVD_NO_SUBPICTURE_STREAM,
            0xC00D1163 => MEDIASERVER::NS_E_DVD_COPY_PROTECT,
            0xC00D1164 => MEDIASERVER::NS_E_DVD_AUTHORING_PROBLEM,
            0xC00D1165 => MEDIASERVER::NS_E_DVD_INVALID_DISC_REGION,
            0xC00D1166 => MEDIASERVER::NS_E_DVD_COMPATIBLE_VIDEO_CARD,
            0xC00D1167 => MEDIASERVER::NS_E_DVD_MACROVISION,
            0xC00D1168 => MEDIASERVER::NS_E_DVD_SYSTEM_DECODER_REGION,
            0xC00D1169 => MEDIASERVER::NS_E_DVD_DISC_DECODER_REGION,
            0xC00D116A => MEDIASERVER::NS_E_DVD_NO_VIDEO_STREAM,
            0xC00D116B => MEDIASERVER::NS_E_DVD_NO_AUDIO_STREAM,
            0xC00D116C => MEDIASERVER::NS_E_DVD_GRAPH_BUILDING,
            0xC00D116D => MEDIASERVER::NS_E_DVD_NO_DECODER,
            0xC00D116E => MEDIASERVER::NS_E_DVD_PARENTAL,
            0xC00D116F => MEDIASERVER::NS_E_DVD_CANNOT_JUMP,
            0xC00D1170 => MEDIASERVER::NS_E_DVD_DEVICE_CONTENTION,
            0xC00D1171 => MEDIASERVER::NS_E_DVD_NO_VIDEO_MEMORY,
            0xC00D1172 => MEDIASERVER::NS_E_DVD_CANNOT_COPY_PROTECTED,
            0xC00D1173 => MEDIASERVER::NS_E_DVD_REQUIRED_PROPERTY_NOT_SET,
            0xC00D1174 => MEDIASERVER::NS_E_DVD_INVALID_TITLE_CHAPTER,
            0xC00D1176 => MEDIASERVER::NS_E_NO_CD_BURNER,
            0xC00D1177 => MEDIASERVER::NS_E_DEVICE_IS_NOT_READY,
            0xC00D1178 => MEDIASERVER::NS_E_PDA_UNSUPPORTED_FORMAT,
            0xC00D1179 => MEDIASERVER::NS_E_NO_PDA,
            0xC00D117A => MEDIASERVER::NS_E_PDA_UNSPECIFIED_ERROR,
            0xC00D117B => MEDIASERVER::NS_E_MEMSTORAGE_BAD_DATA,
            0xC00D117C => MEDIASERVER::NS_E_PDA_FAIL_SELECT_DEVICE,
            0xC00D117D => MEDIASERVER::NS_E_PDA_FAIL_READ_WAVE_FILE,
            0xC00D117E => MEDIASERVER::NS_E_IMAPI_LOSSOFSTREAMING,
            0xC00D117F => MEDIASERVER::NS_E_PDA_DEVICE_FULL,
            0xC00D1180 => MEDIASERVER::NS_E_FAIL_LAUNCH_ROXIO_PLUGIN,
            0xC00D1181 => MEDIASERVER::NS_E_PDA_DEVICE_FULL_IN_SESSION,
            0xC00D1182 => MEDIASERVER::NS_E_IMAPI_MEDIUM_INVALIDTYPE,
            0xC00D1183 => MEDIASERVER::NS_E_PDA_MANUALDEVICE,
            0xC00D1184 => MEDIASERVER::NS_E_PDA_PARTNERSHIPNOTEXIST,
            0xC00D1185 => MEDIASERVER::NS_E_PDA_CANNOT_CREATE_ADDITIONAL_SYNC_RELATIONSHIP,
            0xC00D1186 => MEDIASERVER::NS_E_PDA_NO_TRANSCODE_OF_DRM,
            0xC00D1187 => MEDIASERVER::NS_E_PDA_TRANSCODECACHEFULL,
            0xC00D1188 => MEDIASERVER::NS_E_PDA_TOO_MANY_FILE_COLLISIONS,
            0xC00D1189 => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE,
            0xC00D118A => MEDIASERVER::NS_E_PDA_TOO_MANY_FILES_IN_DIRECTORY,
            0xC00D118B => MEDIASERVER::NS_E_PROCESSINGSHOWSYNCWIZARD,
            0xC00D118C => MEDIASERVER::NS_E_PDA_TRANSCODE_NOT_PERMITTED,
            0xC00D118D => MEDIASERVER::NS_E_PDA_INITIALIZINGDEVICES,
            0xC00D118E => MEDIASERVER::NS_E_PDA_OBSOLETE_SP,
            0xC00D118F => MEDIASERVER::NS_E_PDA_TITLE_COLLISION,
            0xC00D1190 => MEDIASERVER::NS_E_PDA_DEVICESUPPORTDISABLED,
            0xC00D1191 => MEDIASERVER::NS_E_PDA_NO_LONGER_AVAILABLE,
            0xC00D1192 => MEDIASERVER::NS_E_PDA_ENCODER_NOT_RESPONDING,
            0xC00D1193 => MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_LOCATION,
            0xC00D1194 => MEDIASERVER::NS_E_WMP_PROTOCOL_PROBLEM,
            0xC00D1195 => MEDIASERVER::NS_E_WMP_NO_DISK_SPACE,
            0xC00D1196 => MEDIASERVER::NS_E_WMP_LOGON_FAILURE,
            0xC00D1197 => MEDIASERVER::NS_E_WMP_CANNOT_FIND_FILE,
            0xC00D1198 => MEDIASERVER::NS_E_WMP_SERVER_INACCESSIBLE,
            0xC00D1199 => MEDIASERVER::NS_E_WMP_UNSUPPORTED_FORMAT,
            0xC00D119A => MEDIASERVER::NS_E_WMP_DSHOW_UNSUPPORTED_FORMAT,
            0xC00D119B => MEDIASERVER::NS_E_WMP_PLAYLIST_EXISTS,
            0xC00D119C => MEDIASERVER::NS_E_WMP_NONMEDIA_FILES,
            0xC00D119D => MEDIASERVER::NS_E_WMP_INVALID_ASX,
            0xC00D119E => MEDIASERVER::NS_E_WMP_ALREADY_IN_USE,
            0xC00D119F => MEDIASERVER::NS_E_WMP_IMAPI_FAILURE,
            0xC00D11A0 => MEDIASERVER::NS_E_WMP_WMDM_FAILURE,
            0xC00D11A1 => MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_4CC,
            0xC00D11A2 => MEDIASERVER::NS_E_WMP_CODEC_NEEDED_WITH_FORMATTAG,
            0xC00D11A3 => MEDIASERVER::NS_E_WMP_MSSAP_NOT_AVAILABLE,
            0xC00D11A4 => MEDIASERVER::NS_E_WMP_WMDM_INTERFACEDEAD,
            0xC00D11A5 => MEDIASERVER::NS_E_WMP_WMDM_NOTCERTIFIED,
            0xC00D11A6 => MEDIASERVER::NS_E_WMP_WMDM_LICENSE_NOTEXIST,
            0xC00D11A7 => MEDIASERVER::NS_E_WMP_WMDM_LICENSE_EXPIRED,
            0xC00D11A8 => MEDIASERVER::NS_E_WMP_WMDM_BUSY,
            0xC00D11A9 => MEDIASERVER::NS_E_WMP_WMDM_NORIGHTS,
            0xC00D11AA => MEDIASERVER::NS_E_WMP_WMDM_INCORRECT_RIGHTS,
            0xC00D11AB => MEDIASERVER::NS_E_WMP_IMAPI_GENERIC,
            0xC00D11AD => MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_NOTPRESENT,
            0xC00D11AE => MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_BUSY,
            0xC00D11AF => MEDIASERVER::NS_E_WMP_IMAPI_LOSS_OF_STREAMING,
            0xC00D11B0 => MEDIASERVER::NS_E_WMP_SERVER_UNAVAILABLE,
            0xC00D11B1 => MEDIASERVER::NS_E_WMP_FILE_OPEN_FAILED,
            0xC00D11B2 => MEDIASERVER::NS_E_WMP_VERIFY_ONLINE,
            0xC00D11B3 => MEDIASERVER::NS_E_WMP_SERVER_NOT_RESPONDING,
            0xC00D11B4 => MEDIASERVER::NS_E_WMP_DRM_CORRUPT_BACKUP,
            0xC00D11B5 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_SERVER_UNAVAILABLE,
            0xC00D11B6 => MEDIASERVER::NS_E_WMP_NETWORK_FIREWALL,
            0xC00D11B7 => MEDIASERVER::NS_E_WMP_NO_REMOVABLE_MEDIA,
            0xC00D11B8 => MEDIASERVER::NS_E_WMP_PROXY_CONNECT_TIMEOUT,
            0xC00D11B9 => MEDIASERVER::NS_E_WMP_NEED_UPGRADE,
            0xC00D11BA => MEDIASERVER::NS_E_WMP_AUDIO_HW_PROBLEM,
            0xC00D11BB => MEDIASERVER::NS_E_WMP_INVALID_PROTOCOL,
            0xC00D11BC => MEDIASERVER::NS_E_WMP_INVALID_LIBRARY_ADD,
            0xC00D11BD => MEDIASERVER::NS_E_WMP_MMS_NOT_SUPPORTED,
            0xC00D11BE => MEDIASERVER::NS_E_WMP_NO_PROTOCOLS_SELECTED,
            0xC00D11BF => MEDIASERVER::NS_E_WMP_GOFULLSCREEN_FAILED,
            0xC00D11C0 => MEDIASERVER::NS_E_WMP_NETWORK_ERROR,
            0xC00D11C1 => MEDIASERVER::NS_E_WMP_CONNECT_TIMEOUT,
            0xC00D11C2 => MEDIASERVER::NS_E_WMP_MULTICAST_DISABLED,
            0xC00D11C3 => MEDIASERVER::NS_E_WMP_SERVER_DNS_TIMEOUT,
            0xC00D11C4 => MEDIASERVER::NS_E_WMP_PROXY_NOT_FOUND,
            0xC00D11C5 => MEDIASERVER::NS_E_WMP_TAMPERED_CONTENT,
            0xC00D11C6 => MEDIASERVER::NS_E_WMP_OUTOFMEMORY,
            0xC00D11C7 => MEDIASERVER::NS_E_WMP_AUDIO_CODEC_NOT_INSTALLED,
            0xC00D11C8 => MEDIASERVER::NS_E_WMP_VIDEO_CODEC_NOT_INSTALLED,
            0xC00D11C9 => MEDIASERVER::NS_E_WMP_IMAPI_DEVICE_INVALIDTYPE,
            0xC00D11CA => MEDIASERVER::NS_E_WMP_DRM_DRIVER_AUTH_FAILURE,
            0xC00D11CB => MEDIASERVER::NS_E_WMP_NETWORK_RESOURCE_FAILURE,
            0xC00D11CC => MEDIASERVER::NS_E_WMP_UPGRADE_APPLICATION,
            0xC00D11CD => MEDIASERVER::NS_E_WMP_UNKNOWN_ERROR,
            0xC00D11CE => MEDIASERVER::NS_E_WMP_INVALID_KEY,
            0xC00D11CF => MEDIASERVER::NS_E_WMP_CD_ANOTHER_USER,
            0xC00D11D0 => MEDIASERVER::NS_E_WMP_DRM_NEEDS_AUTHORIZATION,
            0xC00D11D1 => MEDIASERVER::NS_E_WMP_BAD_DRIVER,
            0xC00D11D2 => MEDIASERVER::NS_E_WMP_ACCESS_DENIED,
            0xC00D11D3 => MEDIASERVER::NS_E_WMP_LICENSE_RESTRICTS,
            0xC00D11D4 => MEDIASERVER::NS_E_WMP_INVALID_REQUEST,
            0xC00D11D5 => MEDIASERVER::NS_E_WMP_CD_STASH_NO_SPACE,
            0xC00D11D6 => MEDIASERVER::NS_E_WMP_DRM_NEW_HARDWARE,
            0xC00D11D7 => MEDIASERVER::NS_E_WMP_DRM_INVALID_SIG,
            0xC00D11D8 => MEDIASERVER::NS_E_WMP_DRM_CANNOT_RESTORE,
            0xC00D11D9 => MEDIASERVER::NS_E_WMP_BURN_DISC_OVERFLOW,
            0xC00D11DA => MEDIASERVER::NS_E_WMP_DRM_GENERIC_LICENSE_FAILURE,
            0xC00D11DB => MEDIASERVER::NS_E_WMP_DRM_NO_SECURE_CLOCK,
            0xC00D11DC => MEDIASERVER::NS_E_WMP_DRM_NO_RIGHTS,
            0xC00D11DD => MEDIASERVER::NS_E_WMP_DRM_INDIV_FAILED,
            0xC00D11DE => MEDIASERVER::NS_E_WMP_SERVER_NONEWCONNECTIONS,
            0xC00D11DF => MEDIASERVER::NS_E_WMP_MULTIPLE_ERROR_IN_PLAYLIST,
            0xC00D11E0 => MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_FAIL,
            0xC00D11E1 => MEDIASERVER::NS_E_WMP_IMAPI2_ERASE_DEVICE_BUSY,
            0xC00D11E2 => MEDIASERVER::NS_E_WMP_DRM_COMPONENT_FAILURE,
            0xC00D11E3 => MEDIASERVER::NS_E_WMP_DRM_NO_DEVICE_CERT,
            0xC00D11E4 => MEDIASERVER::NS_E_WMP_SERVER_SECURITY_ERROR,
            0xC00D11E5 => MEDIASERVER::NS_E_WMP_AUDIO_DEVICE_LOST,
            0xC00D11E6 => MEDIASERVER::NS_E_WMP_IMAPI_MEDIA_INCOMPATIBLE,
            0xC00D11EE => MEDIASERVER::NS_E_SYNCWIZ_DEVICE_FULL,
            0xC00D11EF => MEDIASERVER::NS_E_SYNCWIZ_CANNOT_CHANGE_SETTINGS,
            0xC00D11F0 => MEDIASERVER::NS_E_TRANSCODE_DELETECACHEERROR,
            0xC00D11F8 => MEDIASERVER::NS_E_CD_NO_BUFFERS_READ,
            0xC00D11F9 => MEDIASERVER::NS_E_CD_EMPTY_TRACK_QUEUE,
            0xC00D11FA => MEDIASERVER::NS_E_CD_NO_READER,
            0xC00D11FB => MEDIASERVER::NS_E_CD_ISRC_INVALID,
            0xC00D11FC => MEDIASERVER::NS_E_CD_MEDIA_CATALOG_NUMBER_INVALID,
            0xC00D11FD => MEDIASERVER::NS_E_SLOW_READ_DIGITAL_WITH_ERRORCORRECTION,
            0xC00D11FE => MEDIASERVER::NS_E_CD_SPEEDDETECT_NOT_ENOUGH_READS,
            0xC00D11FF => MEDIASERVER::NS_E_CD_QUEUEING_DISABLED,
            0xC00D1202 => MEDIASERVER::NS_E_WMP_DRM_ACQUIRING_LICENSE,
            0xC00D1203 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_EXPIRED,
            0xC00D1204 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTACQUIRED,
            0xC00D1205 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOTENABLED,
            0xC00D1206 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_UNUSABLE,
            0xC00D1207 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_CONTENT_REVOKED,
            0xC00D1208 => MEDIASERVER::NS_E_WMP_DRM_LICENSE_NOSAP,
            0xC00D1209 => MEDIASERVER::NS_E_WMP_DRM_UNABLE_TO_ACQUIRE_LICENSE,
            0xC00D120A => MEDIASERVER::NS_E_WMP_LICENSE_REQUIRED,
            0xC00D120B => MEDIASERVER::NS_E_WMP_PROTECTED_CONTENT,
            0xC00D122A => MEDIASERVER::NS_E_WMP_POLICY_VALUE_NOT_CONFIGURED,
            0xC00D1234 => MEDIASERVER::NS_E_PDA_CANNOT_SYNC_FROM_INTERNET,
            0xC00D1235 => MEDIASERVER::NS_E_PDA_CANNOT_SYNC_INVALID_PLAYLIST,
            0xC00D1236 => MEDIASERVER::NS_E_PDA_FAILED_TO_SYNCHRONIZE_FILE,
            0xC00D1237 => MEDIASERVER::NS_E_PDA_SYNC_FAILED,
            0xC00D1238 => MEDIASERVER::NS_E_PDA_DELETE_FAILED,
            0xC00D1239 => MEDIASERVER::NS_E_PDA_FAILED_TO_RETRIEVE_FILE,
            0xC00D123A => MEDIASERVER::NS_E_PDA_DEVICE_NOT_RESPONDING,
            0xC00D123B => MEDIASERVER::NS_E_PDA_FAILED_TO_TRANSCODE_PHOTO,
            0xC00D123C => MEDIASERVER::NS_E_PDA_FAILED_TO_ENCRYPT_TRANSCODED_FILE,
            0xC00D123D => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_AUDIO,
            0xC00D123E => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_VIDEO,
            0xC00D123F => MEDIASERVER::NS_E_PDA_CANNOT_TRANSCODE_TO_IMAGE,
            0xC00D1240 => MEDIASERVER::NS_E_PDA_RETRIEVED_FILE_FILENAME_TOO_LONG,
            0xC00D1241 => MEDIASERVER::NS_E_PDA_CEWMDM_DRM_ERROR,
            0xC00D1242 => MEDIASERVER::NS_E_INCOMPLETE_PLAYLIST,
            0xC00D1243 => MEDIASERVER::NS_E_PDA_SYNC_RUNNING,
            0xC00D1244 => MEDIASERVER::NS_E_PDA_SYNC_LOGIN_ERROR,
            0xC00D1245 => MEDIASERVER::NS_E_PDA_TRANSCODE_CODEC_NOT_FOUND,
            0xC00D1246 => MEDIASERVER::NS_E_CANNOT_SYNC_DRM_TO_NON_JANUS_DEVICE,
            0xC00D1247 => MEDIASERVER::NS_E_CANNOT_SYNC_PREVIOUS_SYNC_RUNNING,
            0xC00D125C => MEDIASERVER::NS_E_WMP_HWND_NOTFOUND,
            0xC00D125D => MEDIASERVER::NS_E_BKGDOWNLOAD_WRONG_NO_FILES,
            0xC00D125E => MEDIASERVER::NS_E_BKGDOWNLOAD_COMPLETECANCELLEDJOB,
            0xC00D125F => MEDIASERVER::NS_E_BKGDOWNLOAD_CANCELCOMPLETEDJOB,
            0xC00D1260 => MEDIASERVER::NS_E_BKGDOWNLOAD_NOJOBPOINTER,
            0xC00D1261 => MEDIASERVER::NS_E_BKGDOWNLOAD_INVALIDJOBSIGNATURE,
            0xC00D1262 => MEDIASERVER::NS_E_BKGDOWNLOAD_FAILED_TO_CREATE_TEMPFILE,
            0xC00D1263 => MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDINITIALIZE,
            0xC00D1264 => MEDIASERVER::NS_E_BKGDOWNLOAD_PLUGIN_FAILEDTOMOVEFILE,
            0xC00D1265 => MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCFAILED,
            0xC00D1266 => MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCTIMEOUT,
            0xC00D1267 => MEDIASERVER::NS_E_BKGDOWNLOAD_CALLFUNCENDED,
            0xC00D1268 => MEDIASERVER::NS_E_BKGDOWNLOAD_WMDUNPACKFAILED,
            0xC00D1269 => MEDIASERVER::NS_E_BKGDOWNLOAD_FAILEDINITIALIZE,
            0xC00D126A => MEDIASERVER::NS_E_INTERFACE_NOT_REGISTERED_IN_GIT,
            0xC00D126B => MEDIASERVER::NS_E_BKGDOWNLOAD_INVALID_FILE_NAME,
            0xC00D128E => MEDIASERVER::NS_E_IMAGE_DOWNLOAD_FAILED,
            0xC00D12C0 => MEDIASERVER::NS_E_WMP_UDRM_NOUSERLIST,
            0xC00D12C1 => MEDIASERVER::NS_E_WMP_DRM_NOT_ACQUIRING,
            0xC00D12F2 => MEDIASERVER::NS_E_WMP_BSTR_TOO_LONG,
            0xC00D12FC => MEDIASERVER::NS_E_WMP_AUTOPLAY_INVALID_STATE,
            0xC00D1306 => MEDIASERVER::NS_E_WMP_COMPONENT_REVOKED,
            0xC00D1324 => MEDIASERVER::NS_E_CURL_NOTSAFE,
            0xC00D1325 => MEDIASERVER::NS_E_CURL_INVALIDCHAR,
            0xC00D1326 => MEDIASERVER::NS_E_CURL_INVALIDHOSTNAME,
            0xC00D1327 => MEDIASERVER::NS_E_CURL_INVALIDPATH,
            0xC00D1328 => MEDIASERVER::NS_E_CURL_INVALIDSCHEME,
            0xC00D1329 => MEDIASERVER::NS_E_CURL_INVALIDURL,
            0xC00D132B => MEDIASERVER::NS_E_CURL_CANTWALK,
            0xC00D132C => MEDIASERVER::NS_E_CURL_INVALIDPORT,
            0xC00D132D => MEDIASERVER::NS_E_CURLHELPER_NOTADIRECTORY,
            0xC00D132E => MEDIASERVER::NS_E_CURLHELPER_NOTAFILE,
            0xC00D132F => MEDIASERVER::NS_E_CURL_CANTDECODE,
            0xC00D1330 => MEDIASERVER::NS_E_CURLHELPER_NOTRELATIVE,
            0xC00D1331 => MEDIASERVER::NS_E_CURL_INVALIDBUFFERSIZE,
            0xC00D1356 => MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_PLAYBACK_DISALLOWED,
            0xC00D1357 => MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_FROM_MULTIPLE_SERVICES,
            0xC00D1358 => MEDIASERVER::NS_E_CANNOT_BUY_OR_DOWNLOAD_CONTENT,
            0xC00D135A => MEDIASERVER::NS_E_NOT_CONTENT_PARTNER_TRACK,
            0xC00D135B => MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_ALBUM_PURCHASE,
            0xC00D135C => MEDIASERVER::NS_E_TRACK_DOWNLOAD_REQUIRES_PURCHASE,
            0xC00D135D => MEDIASERVER::NS_E_TRACK_PURCHASE_MAXIMUM_EXCEEDED,
            0xC00D135F => MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_LOGIN_FAILED,
            0xC00D1360 => MEDIASERVER::NS_E_SUBSCRIPTIONSERVICE_DOWNLOAD_TIMEOUT,
            0xC00D1362 => MEDIASERVER::NS_E_CONTENT_PARTNER_STILL_INITIALIZING,
            0xC00D1363 => MEDIASERVER::NS_E_OPEN_CONTAINING_FOLDER_FAILED,
            0xC00D136A => MEDIASERVER::NS_E_ADVANCEDEDIT_TOO_MANY_PICTURES,
            0xC00D1388 => MEDIASERVER::NS_E_REDIRECT,
            0xC00D1389 => MEDIASERVER::NS_E_STALE_PRESENTATION,
            0xC00D138A => MEDIASERVER::NS_E_NAMESPACE_WRONG_PERSIST,
            0xC00D138B => MEDIASERVER::NS_E_NAMESPACE_WRONG_TYPE,
            0xC00D138C => MEDIASERVER::NS_E_NAMESPACE_NODE_CONFLICT,
            0xC00D138D => MEDIASERVER::NS_E_NAMESPACE_NODE_NOT_FOUND,
            0xC00D138E => MEDIASERVER::NS_E_NAMESPACE_BUFFER_TOO_SMALL,
            0xC00D138F => MEDIASERVER::NS_E_NAMESPACE_TOO_MANY_CALLBACKS,
            0xC00D1390 => MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_CALLBACK,
            0xC00D1391 => MEDIASERVER::NS_E_NAMESPACE_CALLBACK_NOT_FOUND,
            0xC00D1392 => MEDIASERVER::NS_E_NAMESPACE_NAME_TOO_LONG,
            0xC00D1393 => MEDIASERVER::NS_E_NAMESPACE_DUPLICATE_NAME,
            0xC00D1394 => MEDIASERVER::NS_E_NAMESPACE_EMPTY_NAME,
            0xC00D1395 => MEDIASERVER::NS_E_NAMESPACE_INDEX_TOO_LARGE,
            0xC00D1396 => MEDIASERVER::NS_E_NAMESPACE_BAD_NAME,
            0xC00D1397 => MEDIASERVER::NS_E_NAMESPACE_WRONG_SECURITY,
            0xC00D13EC => MEDIASERVER::NS_E_CACHE_ARCHIVE_CONFLICT,
            0xC00D13ED => MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_NOT_FOUND,
            0xC00D13EE => MEDIASERVER::NS_E_CACHE_ORIGIN_SERVER_TIMEOUT,
            0xC00D13EF => MEDIASERVER::NS_E_CACHE_NOT_BROADCAST,
            0xC00D13F0 => MEDIASERVER::NS_E_CACHE_CANNOT_BE_CACHED,
            0xC00D13F1 => MEDIASERVER::NS_E_CACHE_NOT_MODIFIED,
            0xC00D1450 => MEDIASERVER::NS_E_CANNOT_REMOVE_PUBLISHING_POINT,
            0xC00D1451 => MEDIASERVER::NS_E_CANNOT_REMOVE_PLUGIN,
            0xC00D1452 => MEDIASERVER::NS_E_WRONG_PUBLISHING_POINT_TYPE,
            0xC00D1453 => MEDIASERVER::NS_E_UNSUPPORTED_LOAD_TYPE,
            0xC00D1454 => MEDIASERVER::NS_E_INVALID_PLUGIN_LOAD_TYPE_CONFIGURATION,
            0xC00D1455 => MEDIASERVER::NS_E_INVALID_PUBLISHING_POINT_NAME,
            0xC00D1456 => MEDIASERVER::NS_E_TOO_MANY_MULTICAST_SINKS,
            0xC00D1457 => MEDIASERVER::NS_E_PUBLISHING_POINT_INVALID_REQUEST_WHILE_STARTED,
            0xC00D1458 => MEDIASERVER::NS_E_MULTICAST_PLUGIN_NOT_ENABLED,
            0xC00D1459 => MEDIASERVER::NS_E_INVALID_OPERATING_SYSTEM_VERSION,
            0xC00D145A => MEDIASERVER::NS_E_PUBLISHING_POINT_REMOVED,
            0xC00D145B => MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT_START_REQUEST,
            0xC00D145C => MEDIASERVER::NS_E_UNSUPPORTED_LANGUAGE,
            0xC00D145D => MEDIASERVER::NS_E_WRONG_OS_VERSION,
            0xC00D145E => MEDIASERVER::NS_E_PUBLISHING_POINT_STOPPED,
            0xC00D14B4 => MEDIASERVER::NS_E_PLAYLIST_ENTRY_ALREADY_PLAYING,
            0xC00D14B5 => MEDIASERVER::NS_E_EMPTY_PLAYLIST,
            0xC00D14B6 => MEDIASERVER::NS_E_PLAYLIST_PARSE_FAILURE,
            0xC00D14B7 => MEDIASERVER::NS_E_PLAYLIST_UNSUPPORTED_ENTRY,
            0xC00D14B8 => MEDIASERVER::NS_E_PLAYLIST_ENTRY_NOT_IN_PLAYLIST,
            0xC00D14B9 => MEDIASERVER::NS_E_PLAYLIST_ENTRY_SEEK,
            0xC00D14BA => MEDIASERVER::NS_E_PLAYLIST_RECURSIVE_PLAYLISTS,
            0xC00D14BB => MEDIASERVER::NS_E_PLAYLIST_TOO_MANY_NESTED_PLAYLISTS,
            0xC00D14BC => MEDIASERVER::NS_E_PLAYLIST_SHUTDOWN,
            0xC00D14BD => MEDIASERVER::NS_E_PLAYLIST_END_RECEDING,
            0xC00D1518 => MEDIASERVER::NS_E_DATAPATH_NO_SINK,
            0xC00D151A => MEDIASERVER::NS_E_INVALID_PUSH_TEMPLATE,
            0xC00D151B => MEDIASERVER::NS_E_INVALID_PUSH_PUBLISHING_POINT,
            0xC00D151C => MEDIASERVER::NS_E_CRITICAL_ERROR,
            0xC00D151D => MEDIASERVER::NS_E_NO_NEW_CONNECTIONS,
            0xC00D151E => MEDIASERVER::NS_E_WSX_INVALID_VERSION,
            0xC00D151F => MEDIASERVER::NS_E_HEADER_MISMATCH,
            0xC00D1520 => MEDIASERVER::NS_E_PUSH_DUPLICATE_PUBLISHING_POINT_NAME,
            0xC00D157C => MEDIASERVER::NS_E_NO_SCRIPT_ENGINE,
            0xC00D157D => MEDIASERVER::NS_E_PLUGIN_ERROR_REPORTED,
            0xC00D157E => MEDIASERVER::NS_E_SOURCE_PLUGIN_NOT_FOUND,
            0xC00D157F => MEDIASERVER::NS_E_PLAYLIST_PLUGIN_NOT_FOUND,
            0xC00D1580 => MEDIASERVER::NS_E_DATA_SOURCE_ENUMERATION_NOT_SUPPORTED,
            0xC00D1581 => MEDIASERVER::NS_E_MEDIA_PARSER_INVALID_FORMAT,
            0xC00D1582 => MEDIASERVER::NS_E_SCRIPT_DEBUGGER_NOT_INSTALLED,
            0xC00D1583 => MEDIASERVER::NS_E_FEATURE_REQUIRES_ENTERPRISE_SERVER,
            0xC00D1584 => MEDIASERVER::NS_E_WIZARD_RUNNING,
            0xC00D1585 => MEDIASERVER::NS_E_INVALID_LOG_URL,
            0xC00D1586 => MEDIASERVER::NS_E_INVALID_MTU_RANGE,
            0xC00D1587 => MEDIASERVER::NS_E_INVALID_PLAY_STATISTICS,
            0xC00D1588 => MEDIASERVER::NS_E_LOG_NEED_TO_BE_SKIPPED,
            0xC00D1589 => MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_SIZE_LIMIT_EXCEEDED,
            0xC00D158A => MEDIASERVER::NS_E_PORT_IN_USE,
            0xC00D158B => MEDIASERVER::NS_E_PORT_IN_USE_HTTP,
            0xC00D158C => MEDIASERVER::NS_E_HTTP_TEXT_DATACONTAINER_INVALID_SERVER_RESPONSE,
            0xC00D158D => MEDIASERVER::NS_E_ARCHIVE_REACH_QUOTA,
            0xC00D158E => MEDIASERVER::NS_E_ARCHIVE_ABORT_DUE_TO_BCAST,
            0xC00D158F => MEDIASERVER::NS_E_ARCHIVE_GAP_DETECTED,
            0xC00D1590 => MEDIASERVER::NS_E_AUTHORIZATION_FILE_NOT_FOUND,
            0xC00D1B58 => MEDIASERVER::NS_E_BAD_MARKIN,
            0xC00D1B59 => MEDIASERVER::NS_E_BAD_MARKOUT,
            0xC00D1B5A => MEDIASERVER::NS_E_NOMATCHING_MEDIASOURCE,
            0xC00D1B5B => MEDIASERVER::NS_E_UNSUPPORTED_SOURCETYPE,
            0xC00D1B5C => MEDIASERVER::NS_E_TOO_MANY_AUDIO,
            0xC00D1B5D => MEDIASERVER::NS_E_TOO_MANY_VIDEO,
            0xC00D1B5E => MEDIASERVER::NS_E_NOMATCHING_ELEMENT,
            0xC00D1B5F => MEDIASERVER::NS_E_MISMATCHED_MEDIACONTENT,
            0xC00D1B60 => MEDIASERVER::NS_E_CANNOT_DELETE_ACTIVE_SOURCEGROUP,
            0xC00D1B61 => MEDIASERVER::NS_E_AUDIODEVICE_BUSY,
            0xC00D1B62 => MEDIASERVER::NS_E_AUDIODEVICE_UNEXPECTED,
            0xC00D1B63 => MEDIASERVER::NS_E_AUDIODEVICE_BADFORMAT,
            0xC00D1B64 => MEDIASERVER::NS_E_VIDEODEVICE_BUSY,
            0xC00D1B65 => MEDIASERVER::NS_E_VIDEODEVICE_UNEXPECTED,
            0xC00D1B66 => MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_RUNNING,
            0xC00D1B67 => MEDIASERVER::NS_E_NO_PROFILE_IN_SOURCEGROUP,
            0xC00D1B68 => MEDIASERVER::NS_E_VIDEODRIVER_UNSTABLE,
            0xC00D1B69 => MEDIASERVER::NS_E_VIDCAPSTARTFAILED,
            0xC00D1B6A => MEDIASERVER::NS_E_VIDSOURCECOMPRESSION,
            0xC00D1B6B => MEDIASERVER::NS_E_VIDSOURCESIZE,
            0xC00D1B6C => MEDIASERVER::NS_E_ICMQUERYFORMAT,
            0xC00D1B6D => MEDIASERVER::NS_E_VIDCAPCREATEWINDOW,
            0xC00D1B6E => MEDIASERVER::NS_E_VIDCAPDRVINUSE,
            0xC00D1B6F => MEDIASERVER::NS_E_NO_MEDIAFORMAT_IN_SOURCE,
            0xC00D1B70 => MEDIASERVER::NS_E_NO_VALID_OUTPUT_STREAM,
            0xC00D1B71 => MEDIASERVER::NS_E_NO_VALID_SOURCE_PLUGIN,
            0xC00D1B72 => MEDIASERVER::NS_E_NO_ACTIVE_SOURCEGROUP,
            0xC00D1B73 => MEDIASERVER::NS_E_NO_SCRIPT_STREAM,
            0xC00D1B74 => MEDIASERVER::NS_E_INVALIDCALL_WHILE_ARCHIVAL_RUNNING,
            0xC00D1B75 => MEDIASERVER::NS_E_INVALIDPACKETSIZE,
            0xC00D1B76 => MEDIASERVER::NS_E_PLUGIN_CLSID_INVALID,
            0xC00D1B77 => MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVETYPE,
            0xC00D1B78 => MEDIASERVER::NS_E_UNSUPPORTED_ARCHIVEOPERATION,
            0xC00D1B79 => MEDIASERVER::NS_E_ARCHIVE_FILENAME_NOTSET,
            0xC00D1B7A => MEDIASERVER::NS_E_SOURCEGROUP_NOTPREPARED,
            0xC00D1B7B => MEDIASERVER::NS_E_PROFILE_MISMATCH,
            0xC00D1B7C => MEDIASERVER::NS_E_INCORRECTCLIPSETTINGS,
            0xC00D1B7D => MEDIASERVER::NS_E_NOSTATSAVAILABLE,
            0xC00D1B7E => MEDIASERVER::NS_E_NOTARCHIVING,
            0xC00D1B7F => MEDIASERVER::NS_E_INVALIDCALL_WHILE_ENCODER_STOPPED,
            0xC00D1B80 => MEDIASERVER::NS_E_NOSOURCEGROUPS,
            0xC00D1B81 => MEDIASERVER::NS_E_INVALIDINPUTFPS,
            0xC00D1B82 => MEDIASERVER::NS_E_NO_DATAVIEW_SUPPORT,
            0xC00D1B83 => MEDIASERVER::NS_E_CODEC_UNAVAILABLE,
            0xC00D1B84 => MEDIASERVER::NS_E_ARCHIVE_SAME_AS_INPUT,
            0xC00D1B85 => MEDIASERVER::NS_E_SOURCE_NOTSPECIFIED,
            0xC00D1B86 => MEDIASERVER::NS_E_NO_REALTIME_TIMECOMPRESSION,
            0xC00D1B87 => MEDIASERVER::NS_E_UNSUPPORTED_ENCODER_DEVICE,
            0xC00D1B88 => MEDIASERVER::NS_E_UNEXPECTED_DISPLAY_SETTINGS,
            0xC00D1B89 => MEDIASERVER::NS_E_NO_AUDIODATA,
            0xC00D1B8A => MEDIASERVER::NS_E_INPUTSOURCE_PROBLEM,
            0xC00D1B8B => MEDIASERVER::NS_E_WME_VERSION_MISMATCH,
            0xC00D1B8C => MEDIASERVER::NS_E_NO_REALTIME_PREPROCESS,
            0xC00D1B8D => MEDIASERVER::NS_E_NO_REPEAT_PREPROCESS,
            0xC00D1B8E => MEDIASERVER::NS_E_CANNOT_PAUSE_LIVEBROADCAST,
            0xC00D1B8F => MEDIASERVER::NS_E_DRM_PROFILE_NOT_SET,
            0xC00D1B90 => MEDIASERVER::NS_E_DUPLICATE_DRMPROFILE,
            0xC00D1B91 => MEDIASERVER::NS_E_INVALID_DEVICE,
            0xC00D1B92 => MEDIASERVER::NS_E_SPEECHEDL_ON_NON_MIXEDMODE,
            0xC00D1B93 => MEDIASERVER::NS_E_DRM_PASSWORD_TOO_LONG,
            0xC00D1B94 => MEDIASERVER::NS_E_DEVCONTROL_FAILED_SEEK,
            0xC00D1B95 => MEDIASERVER::NS_E_INTERLACE_REQUIRE_SAMESIZE,
            0xC00D1B96 => MEDIASERVER::NS_E_TOO_MANY_DEVICECONTROL,
            0xC00D1B97 => MEDIASERVER::NS_E_NO_MULTIPASS_FOR_LIVEDEVICE,
            0xC00D1B98 => MEDIASERVER::NS_E_MISSING_AUDIENCE,
            0xC00D1B99 => MEDIASERVER::NS_E_AUDIENCE_CONTENTTYPE_MISMATCH,
            0xC00D1B9A => MEDIASERVER::NS_E_MISSING_SOURCE_INDEX,
            0xC00D1B9B => MEDIASERVER::NS_E_NUM_LANGUAGE_MISMATCH,
            0xC00D1B9C => MEDIASERVER::NS_E_LANGUAGE_MISMATCH,
            0xC00D1B9D => MEDIASERVER::NS_E_VBRMODE_MISMATCH,
            0xC00D1B9E => MEDIASERVER::NS_E_INVALID_INPUT_AUDIENCE_INDEX,
            0xC00D1B9F => MEDIASERVER::NS_E_INVALID_INPUT_LANGUAGE,
            0xC00D1BA0 => MEDIASERVER::NS_E_INVALID_INPUT_STREAM,
            0xC00D1BA1 => MEDIASERVER::NS_E_EXPECT_MONO_WAV_INPUT,
            0xC00D1BA2 => MEDIASERVER::NS_E_INPUT_WAVFORMAT_MISMATCH,
            0xC00D1BA3 => MEDIASERVER::NS_E_RECORDQ_DISK_FULL,
            0xC00D1BA4 => MEDIASERVER::NS_E_NO_PAL_INVERSE_TELECINE,
            0xC00D1BA5 => MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_DISCONNECTED,
            0xC00D1BA6 => MEDIASERVER::NS_E_ACTIVE_SG_DEVICE_CONTROL_DISCONNECTED,
            0xC00D1BA7 => MEDIASERVER::NS_E_NO_FRAMES_SUBMITTED_TO_ANALYZER,
            0xC00D1BA8 => MEDIASERVER::NS_E_INPUT_DOESNOT_SUPPORT_SMPTE,
            0xC00D1BA9 => MEDIASERVER::NS_E_NO_SMPTE_WITH_MULTIPLE_SOURCEGROUPS,
            0xC00D1BAA => MEDIASERVER::NS_E_BAD_CONTENTEDL,
            0xC00D1BAB => MEDIASERVER::NS_E_INTERLACEMODE_MISMATCH,
            0xC00D1BAC => MEDIASERVER::NS_E_NONSQUAREPIXELMODE_MISMATCH,
            0xC00D1BAD => MEDIASERVER::NS_E_SMPTEMODE_MISMATCH,
            0xC00D1BAE => MEDIASERVER::NS_E_END_OF_TAPE,
            0xC00D1BAF => MEDIASERVER::NS_E_NO_MEDIA_IN_AUDIENCE,
            0xC00D1BB0 => MEDIASERVER::NS_E_NO_AUDIENCES,
            0xC00D1BB1 => MEDIASERVER::NS_E_NO_AUDIO_COMPAT,
            0xC00D1BB2 => MEDIASERVER::NS_E_INVALID_VBR_COMPAT,
            0xC00D1BB3 => MEDIASERVER::NS_E_NO_PROFILE_NAME,
            0xC00D1BB4 => MEDIASERVER::NS_E_INVALID_VBR_WITH_UNCOMP,
            0xC00D1BB5 => MEDIASERVER::NS_E_MULTIPLE_VBR_AUDIENCES,
            0xC00D1BB6 => MEDIASERVER::NS_E_UNCOMP_COMP_COMBINATION,
            0xC00D1BB7 => MEDIASERVER::NS_E_MULTIPLE_AUDIO_CODECS,
            0xC00D1BB8 => MEDIASERVER::NS_E_MULTIPLE_AUDIO_FORMATS,
            0xC00D1BB9 => MEDIASERVER::NS_E_AUDIO_BITRATE_STEPDOWN,
            0xC00D1BBA => MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE,
            0xC00D1BBB => MEDIASERVER::NS_E_INVALID_AUDIO_PEAKRATE_2,
            0xC00D1BBC => MEDIASERVER::NS_E_INVALID_AUDIO_BUFFERMAX,
            0xC00D1BBD => MEDIASERVER::NS_E_MULTIPLE_VIDEO_CODECS,
            0xC00D1BBE => MEDIASERVER::NS_E_MULTIPLE_VIDEO_SIZES,
            0xC00D1BBF => MEDIASERVER::NS_E_INVALID_VIDEO_BITRATE,
            0xC00D1BC0 => MEDIASERVER::NS_E_VIDEO_BITRATE_STEPDOWN,
            0xC00D1BC1 => MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE,
            0xC00D1BC2 => MEDIASERVER::NS_E_INVALID_VIDEO_PEAKRATE_2,
            0xC00D1BC3 => MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH,
            0xC00D1BC4 => MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT,
            0xC00D1BC5 => MEDIASERVER::NS_E_INVALID_VIDEO_FPS,
            0xC00D1BC6 => MEDIASERVER::NS_E_INVALID_VIDEO_KEYFRAME,
            0xC00D1BC7 => MEDIASERVER::NS_E_INVALID_VIDEO_IQUALITY,
            0xC00D1BC8 => MEDIASERVER::NS_E_INVALID_VIDEO_CQUALITY,
            0xC00D1BC9 => MEDIASERVER::NS_E_INVALID_VIDEO_BUFFER,
            0xC00D1BCA => MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX,
            0xC00D1BCB => MEDIASERVER::NS_E_INVALID_VIDEO_BUFFERMAX_2,
            0xC00D1BCC => MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_ALIGN,
            0xC00D1BCD => MEDIASERVER::NS_E_INVALID_VIDEO_HEIGHT_ALIGN,
            0xC00D1BCE => MEDIASERVER::NS_E_MULTIPLE_SCRIPT_BITRATES,
            0xC00D1BCF => MEDIASERVER::NS_E_INVALID_SCRIPT_BITRATE,
            0xC00D1BD0 => MEDIASERVER::NS_E_MULTIPLE_FILE_BITRATES,
            0xC00D1BD1 => MEDIASERVER::NS_E_INVALID_FILE_BITRATE,
            0xC00D1BD2 => MEDIASERVER::NS_E_SAME_AS_INPUT_COMBINATION,
            0xC00D1BD3 => MEDIASERVER::NS_E_SOURCE_CANNOT_LOOP,
            0xC00D1BD4 => MEDIASERVER::NS_E_INVALID_FOLDDOWN_COEFFICIENTS,
            0xC00D1BD5 => MEDIASERVER::NS_E_DRMPROFILE_NOTFOUND,
            0xC00D1BD6 => MEDIASERVER::NS_E_INVALID_TIMECODE,
            0xC00D1BD7 => MEDIASERVER::NS_E_NO_AUDIO_TIMECOMPRESSION,
            0xC00D1BD8 => MEDIASERVER::NS_E_NO_TWOPASS_TIMECOMPRESSION,
            0xC00D1BD9 => MEDIASERVER::NS_E_TIMECODE_REQUIRES_VIDEOSTREAM,
            0xC00D1BDA => MEDIASERVER::NS_E_NO_MBR_WITH_TIMECODE,
            0xC00D1BDB => MEDIASERVER::NS_E_INVALID_INTERLACEMODE,
            0xC00D1BDC => MEDIASERVER::NS_E_INVALID_INTERLACE_COMPAT,
            0xC00D1BDD => MEDIASERVER::NS_E_INVALID_NONSQUAREPIXEL_COMPAT,
            0xC00D1BDE => MEDIASERVER::NS_E_INVALID_SOURCE_WITH_DEVICE_CONTROL,
            0xC00D1BDF => MEDIASERVER::NS_E_CANNOT_GENERATE_BROADCAST_INFO_FOR_QUALITYVBR,
            0xC00D1BE0 => MEDIASERVER::NS_E_EXCEED_MAX_DRM_PROFILE_LIMIT,
            0xC00D1BE1 => MEDIASERVER::NS_E_DEVICECONTROL_UNSTABLE,
            0xC00D1BE2 => MEDIASERVER::NS_E_INVALID_PIXEL_ASPECT_RATIO,
            0xC00D1BE3 => MEDIASERVER::NS_E_AUDIENCE__LANGUAGE_CONTENTTYPE_MISMATCH,
            0xC00D1BE4 => MEDIASERVER::NS_E_INVALID_PROFILE_CONTENTTYPE,
            0xC00D1BE5 => MEDIASERVER::NS_E_TRANSFORM_PLUGIN_NOT_FOUND,
            0xC00D1BE6 => MEDIASERVER::NS_E_TRANSFORM_PLUGIN_INVALID,
            0xC00D1BE7 => MEDIASERVER::NS_E_EDL_REQUIRED_FOR_DEVICE_MULTIPASS,
            0xC00D1BE8 => MEDIASERVER::NS_E_INVALID_VIDEO_WIDTH_FOR_INTERLACED_ENCODING,
            0xC00D1BE9 => MEDIASERVER::NS_E_MARKIN_UNSUPPORTED,
            0xC00D2711 => MEDIASERVER::NS_E_DRM_INVALID_APPLICATION,
            0xC00D2712 => MEDIASERVER::NS_E_DRM_LICENSE_STORE_ERROR,
            0xC00D2713 => MEDIASERVER::NS_E_DRM_SECURE_STORE_ERROR,
            0xC00D2714 => MEDIASERVER::NS_E_DRM_LICENSE_STORE_SAVE_ERROR,
            0xC00D2715 => MEDIASERVER::NS_E_DRM_SECURE_STORE_UNLOCK_ERROR,
            0xC00D2716 => MEDIASERVER::NS_E_DRM_INVALID_CONTENT,
            0xC00D2717 => MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_LICENSE,
            0xC00D2718 => MEDIASERVER::NS_E_DRM_INVALID_LICENSE,
            0xC00D2719 => MEDIASERVER::NS_E_DRM_INVALID_MACHINE,
            0xC00D271B => MEDIASERVER::NS_E_DRM_ENUM_LICENSE_FAILED,
            0xC00D271C => MEDIASERVER::NS_E_DRM_INVALID_LICENSE_REQUEST,
            0xC00D271D => MEDIASERVER::NS_E_DRM_UNABLE_TO_INITIALIZE,
            0xC00D271E => MEDIASERVER::NS_E_DRM_UNABLE_TO_ACQUIRE_LICENSE,
            0xC00D271F => MEDIASERVER::NS_E_DRM_INVALID_LICENSE_ACQUIRED,
            0xC00D2720 => MEDIASERVER::NS_E_DRM_NO_RIGHTS,
            0xC00D2721 => MEDIASERVER::NS_E_DRM_KEY_ERROR,
            0xC00D2722 => MEDIASERVER::NS_E_DRM_ENCRYPT_ERROR,
            0xC00D2723 => MEDIASERVER::NS_E_DRM_DECRYPT_ERROR,
            0xC00D2725 => MEDIASERVER::NS_E_DRM_LICENSE_INVALID_XML,
            0xC00D2728 => MEDIASERVER::NS_E_DRM_NEEDS_INDIVIDUALIZATION,
            0xC00D2729 => MEDIASERVER::NS_E_DRM_ALREADY_INDIVIDUALIZED,
            0xC00D272A => MEDIASERVER::NS_E_DRM_ACTION_NOT_QUERIED,
            0xC00D272B => MEDIASERVER::NS_E_DRM_ACQUIRING_LICENSE,
            0xC00D272C => MEDIASERVER::NS_E_DRM_INDIVIDUALIZING,
            0xC00D272D => MEDIASERVER::NS_E_BACKUP_RESTORE_FAILURE,
            0xC00D272E => MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_REQUEST_ID,
            0xC00D272F => MEDIASERVER::NS_E_DRM_PARAMETERS_MISMATCHED,
            0xC00D2730 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_LICENSE_OBJECT,
            0xC00D2731 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INDI_OBJECT,
            0xC00D2732 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_ENCRYPT_OBJECT,
            0xC00D2733 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DECRYPT_OBJECT,
            0xC00D2734 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PROPERTIES_OBJECT,
            0xC00D2735 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_BACKUP_OBJECT,
            0xC00D2736 => MEDIASERVER::NS_E_DRM_INDIVIDUALIZE_ERROR,
            0xC00D2737 => MEDIASERVER::NS_E_DRM_LICENSE_OPEN_ERROR,
            0xC00D2738 => MEDIASERVER::NS_E_DRM_LICENSE_CLOSE_ERROR,
            0xC00D2739 => MEDIASERVER::NS_E_DRM_GET_LICENSE_ERROR,
            0xC00D273A => MEDIASERVER::NS_E_DRM_QUERY_ERROR,
            0xC00D273B => MEDIASERVER::NS_E_DRM_REPORT_ERROR,
            0xC00D273C => MEDIASERVER::NS_E_DRM_GET_LICENSESTRING_ERROR,
            0xC00D273D => MEDIASERVER::NS_E_DRM_GET_CONTENTSTRING_ERROR,
            0xC00D273E => MEDIASERVER::NS_E_DRM_MONITOR_ERROR,
            0xC00D273F => MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_PARAMETER,
            0xC00D2740 => MEDIASERVER::NS_E_DRM_INVALID_APPDATA,
            0xC00D2741 => MEDIASERVER::NS_E_DRM_INVALID_APPDATA_VERSION,
            0xC00D2742 => MEDIASERVER::NS_E_DRM_BACKUP_EXISTS,
            0xC00D2743 => MEDIASERVER::NS_E_DRM_BACKUP_CORRUPT,
            0xC00D2744 => MEDIASERVER::NS_E_DRM_BACKUPRESTORE_BUSY,
            0xC00D2745 => MEDIASERVER::NS_E_BACKUP_RESTORE_BAD_DATA,
            0xC00D2748 => MEDIASERVER::NS_E_DRM_LICENSE_UNUSABLE,
            0xC00D2749 => MEDIASERVER::NS_E_DRM_INVALID_PROPERTY,
            0xC00D274A => MEDIASERVER::NS_E_DRM_SECURE_STORE_NOT_FOUND,
            0xC00D274B => MEDIASERVER::NS_E_DRM_CACHED_CONTENT_ERROR,
            0xC00D274C => MEDIASERVER::NS_E_DRM_INDIVIDUALIZATION_INCOMPLETE,
            0xC00D274D => MEDIASERVER::NS_E_DRM_DRIVER_AUTH_FAILURE,
            0xC00D274E => MEDIASERVER::NS_E_DRM_NEED_UPGRADE_MSSAP,
            0xC00D274F => MEDIASERVER::NS_E_DRM_REOPEN_CONTENT,
            0xC00D2750 => MEDIASERVER::NS_E_DRM_DRIVER_DIGIOUT_FAILURE,
            0xC00D2751 => MEDIASERVER::NS_E_DRM_INVALID_SECURESTORE_PASSWORD,
            0xC00D2752 => MEDIASERVER::NS_E_DRM_APPCERT_REVOKED,
            0xC00D2753 => MEDIASERVER::NS_E_DRM_RESTORE_FRAUD,
            0xC00D2754 => MEDIASERVER::NS_E_DRM_HARDWARE_INCONSISTENT,
            0xC00D2755 => MEDIASERVER::NS_E_DRM_SDMI_TRIGGER,
            0xC00D2756 => MEDIASERVER::NS_E_DRM_SDMI_NOMORECOPIES,
            0xC00D2757 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_HEADER_OBJECT,
            0xC00D2758 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_KEYS_OBJECT,
            0xC00D2759 => MEDIASERVER::NS_E_DRM_LICENSE_NOTACQUIRED,
            0xC00D275A => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CODING_OBJECT,
            0xC00D275B => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_STATE_DATA_OBJECT,
            0xC00D275C => MEDIASERVER::NS_E_DRM_BUFFER_TOO_SMALL,
            0xC00D275D => MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROPERTY,
            0xC00D275E => MEDIASERVER::NS_E_DRM_ERROR_BAD_NET_RESP,
            0xC00D275F => MEDIASERVER::NS_E_DRM_STORE_NOTALLSTORED,
            0xC00D2760 => MEDIASERVER::NS_E_DRM_SECURITY_COMPONENT_SIGNATURE_INVALID,
            0xC00D2761 => MEDIASERVER::NS_E_DRM_INVALID_DATA,
            0xC00D2762 => MEDIASERVER::NS_E_DRM_POLICY_DISABLE_ONLINE,
            0xC00D2763 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_AUTHENTICATION_OBJECT,
            0xC00D2764 => MEDIASERVER::NS_E_DRM_NOT_CONFIGURED,
            0xC00D2765 => MEDIASERVER::NS_E_DRM_DEVICE_ACTIVATION_CANCELED,
            0xC00D2766 => MEDIASERVER::NS_E_BACKUP_RESTORE_TOO_MANY_RESETS,
            0xC00D2767 => MEDIASERVER::NS_E_DRM_DEBUGGING_NOT_ALLOWED,
            0xC00D2768 => MEDIASERVER::NS_E_DRM_OPERATION_CANCELED,
            0xC00D2769 => MEDIASERVER::NS_E_DRM_RESTRICTIONS_NOT_RETRIEVED,
            0xC00D276A => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_OBJECT,
            0xC00D276B => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_PLAYLIST_BURN_OBJECT,
            0xC00D276C => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_DEVICE_REGISTRATION_OBJECT,
            0xC00D276D => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_METERING_OBJECT,
            0xC00D2770 => MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_PLAYLIST_RESTICTION,
            0xC00D2771 => MEDIASERVER::NS_E_DRM_TRACK_EXCEEDED_TRACKBURN_RESTRICTION,
            0xC00D2772 => MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_DEVICE_CERT,
            0xC00D2773 => MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK,
            0xC00D2774 => MEDIASERVER::NS_E_DRM_UNABLE_TO_SET_SECURE_CLOCK,
            0xC00D2775 => MEDIASERVER::NS_E_DRM_UNABLE_TO_GET_SECURE_CLOCK_FROM_SERVER,
            0xC00D2776 => MEDIASERVER::NS_E_DRM_POLICY_METERING_DISABLED,
            0xC00D2777 => MEDIASERVER::NS_E_DRM_TRANSFER_CHAINED_LICENSES_UNSUPPORTED,
            0xC00D2778 => MEDIASERVER::NS_E_DRM_SDK_VERSIONMISMATCH,
            0xC00D2779 => MEDIASERVER::NS_E_DRM_LIC_NEEDS_DEVICE_CLOCK_SET,
            0xC00D277A => MEDIASERVER::NS_E_LICENSE_HEADER_MISSING_URL,
            0xC00D277B => MEDIASERVER::NS_E_DEVICE_NOT_WMDRM_DEVICE,
            0xC00D277C => MEDIASERVER::NS_E_DRM_INVALID_APPCERT,
            0xC00D277D => MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_PETITION,
            0xC00D277E => MEDIASERVER::NS_E_DRM_PROTOCOL_FORCEFUL_TERMINATION_ON_CHALLENGE,
            0xC00D277F => MEDIASERVER::NS_E_DRM_CHECKPOINT_FAILED,
            0xC00D2780 => MEDIASERVER::NS_E_DRM_BB_UNABLE_TO_INITIALIZE,
            0xC00D2781 => MEDIASERVER::NS_E_DRM_UNABLE_TO_LOAD_HARDWARE_ID,
            0xC00D2782 => MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_DATA_STORE,
            0xC00D2783 => MEDIASERVER::NS_E_DRM_DATASTORE_CORRUPT,
            0xC00D2784 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_INMEMORYSTORE_OBJECT,
            0xC00D2785 => MEDIASERVER::NS_E_DRM_STUBLIB_REQUIRED,
            0xC00D2786 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_CERTIFICATE_OBJECT,
            0xC00D2787 => MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_NOT_ONLINE,
            0xC00D2788 => MEDIASERVER::NS_E_DRM_INVALID_MIGRATION_IMAGE,
            0xC00D2789 => MEDIASERVER::NS_E_DRM_MIGRATION_TARGET_STATES_CORRUPTED,
            0xC00D278A => MEDIASERVER::NS_E_DRM_MIGRATION_IMPORTER_NOT_AVAILABLE,
            0xC00D278B => MEDIASERVER::NS_DRM_E_MIGRATION_UPGRADE_WITH_DIFF_SID,
            0xC00D278C => MEDIASERVER::NS_DRM_E_MIGRATION_SOURCE_MACHINE_IN_USE,
            0xC00D278D => MEDIASERVER::NS_DRM_E_MIGRATION_TARGET_MACHINE_LESS_THAN_LH,
            0xC00D278E => MEDIASERVER::NS_DRM_E_MIGRATION_IMAGE_ALREADY_EXISTS,
            0xC00D278F => MEDIASERVER::NS_E_DRM_HARDWAREID_MISMATCH,
            0xC00D2790 => MEDIASERVER::NS_E_INVALID_DRMV2CLT_STUBLIB,
            0xC00D2791 => MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_DATA,
            0xC00D2792 => MEDIASERVER::NS_E_DRM_MIGRATION_LICENSE_ALREADY_EXISTS,
            0xC00D2793 => MEDIASERVER::NS_E_DRM_MIGRATION_INVALID_LEGACYV2_SST_PASSWORD,
            0xC00D2794 => MEDIASERVER::NS_E_DRM_MIGRATION_NOT_SUPPORTED,
            0xC00D2795 => MEDIASERVER::NS_E_DRM_UNABLE_TO_CREATE_MIGRATION_IMPORTER_OBJECT,
            0xC00D2796 => MEDIASERVER::NS_E_DRM_CHECKPOINT_MISMATCH,
            0xC00D2797 => MEDIASERVER::NS_E_DRM_CHECKPOINT_CORRUPT,
            0xC00D2798 => MEDIASERVER::NS_E_REG_FLUSH_FAILURE,
            0xC00D2799 => MEDIASERVER::NS_E_HDS_KEY_MISMATCH,
            0xC00D279A => MEDIASERVER::NS_E_DRM_MIGRATION_OPERATION_CANCELLED,
            0xC00D279B => MEDIASERVER::NS_E_DRM_MIGRATION_OBJECT_IN_USE,
            0xC00D279C => MEDIASERVER::NS_E_DRM_MALFORMED_CONTENT_HEADER,
            0xC00D27D8 => MEDIASERVER::NS_E_DRM_LICENSE_EXPIRED,
            0xC00D27D9 => MEDIASERVER::NS_E_DRM_LICENSE_NOTENABLED,
            0xC00D27DA => MEDIASERVER::NS_E_DRM_LICENSE_APPSECLOW,
            0xC00D27DB => MEDIASERVER::NS_E_DRM_STORE_NEEDINDI,
            0xC00D27DC => MEDIASERVER::NS_E_DRM_STORE_NOTALLOWED,
            0xC00D27DD => MEDIASERVER::NS_E_DRM_LICENSE_APP_NOTALLOWED,
            0xC00D27DF => MEDIASERVER::NS_E_DRM_LICENSE_CERT_EXPIRED,
            0xC00D27E0 => MEDIASERVER::NS_E_DRM_LICENSE_SECLOW,
            0xC00D27E1 => MEDIASERVER::NS_E_DRM_LICENSE_CONTENT_REVOKED,
            0xC00D27E2 => MEDIASERVER::NS_E_DRM_DEVICE_NOT_REGISTERED,
            0xC00D280A => MEDIASERVER::NS_E_DRM_LICENSE_NOSAP,
            0xC00D280B => MEDIASERVER::NS_E_DRM_LICENSE_NOSVP,
            0xC00D280C => MEDIASERVER::NS_E_DRM_LICENSE_NOWDM,
            0xC00D280D => MEDIASERVER::NS_E_DRM_LICENSE_NOTRUSTEDCODEC,
            0xC00D280E => MEDIASERVER::NS_E_DRM_SOURCEID_NOT_SUPPORTED,
            0xC00D283D => MEDIASERVER::NS_E_DRM_NEEDS_UPGRADE_TEMPFILE,
            0xC00D283E => MEDIASERVER::NS_E_DRM_NEED_UPGRADE_PD,
            0xC00D283F => MEDIASERVER::NS_E_DRM_SIGNATURE_FAILURE,
            0xC00D2840 => MEDIASERVER::NS_E_DRM_LICENSE_SERVER_INFO_MISSING,
            0xC00D2841 => MEDIASERVER::NS_E_DRM_BUSY,
            0xC00D2842 => MEDIASERVER::NS_E_DRM_PD_TOO_MANY_DEVICES,
            0xC00D2843 => MEDIASERVER::NS_E_DRM_INDIV_FRAUD,
            0xC00D2844 => MEDIASERVER::NS_E_DRM_INDIV_NO_CABS,
            0xC00D2845 => MEDIASERVER::NS_E_DRM_INDIV_SERVICE_UNAVAILABLE,
            0xC00D2846 => MEDIASERVER::NS_E_DRM_RESTORE_SERVICE_UNAVAILABLE,
            0xC00D2847 => MEDIASERVER::NS_E_DRM_CLIENT_CODE_EXPIRED,
            0xC00D2848 => MEDIASERVER::NS_E_DRM_NO_UPLINK_LICENSE,
            0xC00D2849 => MEDIASERVER::NS_E_DRM_INVALID_KID,
            0xC00D284A => MEDIASERVER::NS_E_DRM_LICENSE_INITIALIZATION_ERROR,
            0xC00D284C => MEDIASERVER::NS_E_DRM_CHAIN_TOO_LONG,
            0xC00D284D => MEDIASERVER::NS_E_DRM_UNSUPPORTED_ALGORITHM,
            0xC00D284E => MEDIASERVER::NS_E_DRM_LICENSE_DELETION_ERROR,
            0xC00D28A0 => MEDIASERVER::NS_E_DRM_INVALID_CERTIFICATE,
            0xC00D28A1 => MEDIASERVER::NS_E_DRM_CERTIFICATE_REVOKED,
            0xC00D28A2 => MEDIASERVER::NS_E_DRM_LICENSE_UNAVAILABLE,
            0xC00D28A3 => MEDIASERVER::NS_E_DRM_DEVICE_LIMIT_REACHED,
            0xC00D28A4 => MEDIASERVER::NS_E_DRM_UNABLE_TO_VERIFY_PROXIMITY,
            0xC00D28A5 => MEDIASERVER::NS_E_DRM_MUST_REGISTER,
            0xC00D28A6 => MEDIASERVER::NS_E_DRM_MUST_APPROVE,
            0xC00D28A7 => MEDIASERVER::NS_E_DRM_MUST_REVALIDATE,
            0xC00D28A8 => MEDIASERVER::NS_E_DRM_INVALID_PROXIMITY_RESPONSE,
            0xC00D28A9 => MEDIASERVER::NS_E_DRM_INVALID_SESSION,
            0xC00D28AA => MEDIASERVER::NS_E_DRM_DEVICE_NOT_OPEN,
            0xC00D28AB => MEDIASERVER::NS_E_DRM_DEVICE_ALREADY_REGISTERED,
            0xC00D28AC => MEDIASERVER::NS_E_DRM_UNSUPPORTED_PROTOCOL_VERSION,
            0xC00D28AD => MEDIASERVER::NS_E_DRM_UNSUPPORTED_ACTION,
            0xC00D28AE => MEDIASERVER::NS_E_DRM_CERTIFICATE_SECURITY_LEVEL_INADEQUATE,
            0xC00D28AF => MEDIASERVER::NS_E_DRM_UNABLE_TO_OPEN_PORT,
            0xC00D28B0 => MEDIASERVER::NS_E_DRM_BAD_REQUEST,
            0xC00D28B1 => MEDIASERVER::NS_E_DRM_INVALID_CRL,
            0xC00D28B2 => MEDIASERVER::NS_E_DRM_ATTRIBUTE_TOO_LONG,
            0xC00D28B3 => MEDIASERVER::NS_E_DRM_EXPIRED_LICENSEBLOB,
            0xC00D28B4 => MEDIASERVER::NS_E_DRM_INVALID_LICENSEBLOB,
            0xC00D28B5 => MEDIASERVER::NS_E_DRM_INCLUSION_LIST_REQUIRED,
            0xC00D28B6 => MEDIASERVER::NS_E_DRM_DRMV2CLT_REVOKED,
            0xC00D28B7 => MEDIASERVER::NS_E_DRM_RIV_TOO_SMALL,
            0xC00D2904 => MEDIASERVER::NS_E_OUTPUT_PROTECTION_LEVEL_UNSUPPORTED,
            0xC00D2905 => MEDIASERVER::NS_E_COMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
            0xC00D2906 => MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
            0xC00D2907 => MEDIASERVER::NS_E_ANALOG_VIDEO_PROTECTION_LEVEL_UNSUPPORTED,
            0xC00D2908 => MEDIASERVER::NS_E_COMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED,
            0xC00D2909 => MEDIASERVER::NS_E_UNCOMPRESSED_DIGITAL_AUDIO_PROTECTION_LEVEL_UNSUPPORTED,
            0xC00D290A => MEDIASERVER::NS_E_OUTPUT_PROTECTION_SCHEME_UNSUPPORTED,
            0xC00D2AFA => MEDIASERVER::NS_E_REBOOT_RECOMMENDED,
            0xC00D2AFB => MEDIASERVER::NS_E_REBOOT_REQUIRED,
            0xC00D2AFC => MEDIASERVER::NS_E_SETUP_INCOMPLETE,
            0xC00D2AFD => MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED,
            0xC00D2AFE => MEDIASERVER::NS_E_SETUP_IGNORABLE_FAILURE,
            0xC00D2AFF => MEDIASERVER::NS_E_SETUP_DRM_MIGRATION_FAILED_AND_IGNORABLE_FAILURE,
            0xC00D2B00 => MEDIASERVER::NS_E_SETUP_BLOCKED,
            0xC00D2EE0 => MEDIASERVER::NS_E_UNKNOWN_PROTOCOL,
            0xC00D2EE1 => MEDIASERVER::NS_E_REDIRECT_TO_PROXY,
            0xC00D2EE2 => MEDIASERVER::NS_E_INTERNAL_SERVER_ERROR,
            0xC00D2EE3 => MEDIASERVER::NS_E_BAD_REQUEST,
            0xC00D2EE4 => MEDIASERVER::NS_E_ERROR_FROM_PROXY,
            0xC00D2EE5 => MEDIASERVER::NS_E_PROXY_TIMEOUT,
            0xC00D2EE6 => MEDIASERVER::NS_E_SERVER_UNAVAILABLE,
            0xC00D2EE7 => MEDIASERVER::NS_E_REFUSED_BY_SERVER,
            0xC00D2EE8 => MEDIASERVER::NS_E_INCOMPATIBLE_SERVER,
            0xC00D2EE9 => MEDIASERVER::NS_E_MULTICAST_DISABLED,
            0xC00D2EEA => MEDIASERVER::NS_E_INVALID_REDIRECT,
            0xC00D2EEB => MEDIASERVER::NS_E_ALL_PROTOCOLS_DISABLED,
            0xC00D2EEC => MEDIASERVER::NS_E_MSBD_NO_LONGER_SUPPORTED,
            0xC00D2EED => MEDIASERVER::NS_E_PROXY_NOT_FOUND,
            0xC00D2EEE => MEDIASERVER::NS_E_CANNOT_CONNECT_TO_PROXY,
            0xC00D2EEF => MEDIASERVER::NS_E_SERVER_DNS_TIMEOUT,
            0xC00D2EF0 => MEDIASERVER::NS_E_PROXY_DNS_TIMEOUT,
            0xC00D2EF1 => MEDIASERVER::NS_E_CLOSED_ON_SUSPEND,
            0xC00D2EF2 => MEDIASERVER::NS_E_CANNOT_READ_PLAYLIST_FROM_MEDIASERVER,
            0xC00D2EF3 => MEDIASERVER::NS_E_SESSION_NOT_FOUND,
            0xC00D2EF4 => MEDIASERVER::NS_E_REQUIRE_STREAMING_CLIENT,
            0xC00D2EF5 => MEDIASERVER::NS_E_PLAYLIST_ENTRY_HAS_CHANGED,
            0xC00D2EF6 => MEDIASERVER::NS_E_PROXY_ACCESSDENIED,
            0xC00D2EF7 => MEDIASERVER::NS_E_PROXY_SOURCE_ACCESSDENIED,
            0xC00D2EF8 => MEDIASERVER::NS_E_NETWORK_SINK_WRITE,
            0xC00D2EF9 => MEDIASERVER::NS_E_FIREWALL,
            0xC00D2EFA => MEDIASERVER::NS_E_MMS_NOT_SUPPORTED,
            0xC00D2EFB => MEDIASERVER::NS_E_SERVER_ACCESSDENIED,
            0xC00D2EFC => MEDIASERVER::NS_E_RESOURCE_GONE,
            0xC00D2EFD => MEDIASERVER::NS_E_NO_EXISTING_PACKETIZER,
            0xC00D2EFE => MEDIASERVER::NS_E_BAD_SYNTAX_IN_SERVER_RESPONSE,
            0xC00D2F00 => MEDIASERVER::NS_E_RESET_SOCKET_CONNECTION,
            0xC00D2F02 => MEDIASERVER::NS_E_TOO_MANY_HOPS,
            0xC00D2F05 => MEDIASERVER::NS_E_TOO_MUCH_DATA_FROM_SERVER,
            0xC00D2F06 => MEDIASERVER::NS_E_CONNECT_TIMEOUT,
            0xC00D2F07 => MEDIASERVER::NS_E_PROXY_CONNECT_TIMEOUT,
            0xC00D2F08 => MEDIASERVER::NS_E_SESSION_INVALID,
            0xC00D2F0A => MEDIASERVER::NS_E_PACKETSINK_UNKNOWN_FEC_STREAM,
            0xC00D2F0B => MEDIASERVER::NS_E_PUSH_CANNOTCONNECT,
            0xC00D2F0C => MEDIASERVER::NS_E_INCOMPATIBLE_PUSH_SERVER,
            0xC00D32C8 => MEDIASERVER::NS_E_END_OF_PLAYLIST,
            0xC00D32C9 => MEDIASERVER::NS_E_USE_FILE_SOURCE,
            0xC00D32CA => MEDIASERVER::NS_E_PROPERTY_NOT_FOUND,
            0xC00D32CC => MEDIASERVER::NS_E_PROPERTY_READ_ONLY,
            0xC00D32CD => MEDIASERVER::NS_E_TABLE_KEY_NOT_FOUND,
            0xC00D32CF => MEDIASERVER::NS_E_INVALID_QUERY_OPERATOR,
            0xC00D32D0 => MEDIASERVER::NS_E_INVALID_QUERY_PROPERTY,
            0xC00D32D2 => MEDIASERVER::NS_E_PROPERTY_NOT_SUPPORTED,
            0xC00D32D4 => MEDIASERVER::NS_E_SCHEMA_CLASSIFY_FAILURE,
            0xC00D32D5 => MEDIASERVER::NS_E_METADATA_FORMAT_NOT_SUPPORTED,
            0xC00D32D6 => MEDIASERVER::NS_E_METADATA_NO_EDITING_CAPABILITY,
            0xC00D32D7 => MEDIASERVER::NS_E_METADATA_CANNOT_SET_LOCALE,
            0xC00D32D8 => MEDIASERVER::NS_E_METADATA_LANGUAGE_NOT_SUPORTED,
            0xC00D32D9 => MEDIASERVER::NS_E_METADATA_NO_RFC1766_NAME_FOR_LOCALE,
            0xC00D32DA => MEDIASERVER::NS_E_METADATA_NOT_AVAILABLE,
            0xC00D32DB => MEDIASERVER::NS_E_METADATA_CACHE_DATA_NOT_AVAILABLE,
            0xC00D32DC => MEDIASERVER::NS_E_METADATA_INVALID_DOCUMENT_TYPE,
            0xC00D32DD => MEDIASERVER::NS_E_METADATA_IDENTIFIER_NOT_AVAILABLE,
            0xC00D32DE => MEDIASERVER::NS_E_METADATA_CANNOT_RETRIEVE_FROM_OFFLINE_CACHE,
            0xC00D36B0 => MEDIASERVER::MF_E_PLATFORM_NOT_INITIALIZED,
            0xC00D36B1 => MEDIASERVER::MF_E_BUFFERTOOSMALL,
            0xC00D36B2 => MEDIASERVER::MF_E_INVALIDREQUEST,
            0xC00D36B3 => MEDIASERVER::MF_E_INVALIDSTREAMNUMBER,
            0xC00D36B4 => MEDIASERVER::MF_E_INVALIDMEDIATYPE,
            0xC00D36B5 => MEDIASERVER::MF_E_NOTACCEPTING,
            0xC00D36B6 => MEDIASERVER::MF_E_NOT_INITIALIZED,
            0xC00D36B7 => MEDIASERVER::MF_E_UNSUPPORTED_REPRESENTATION,
            0xC00D36B9 => MEDIASERVER::MF_E_NO_MORE_TYPES,
            0xC00D36BA => MEDIASERVER::MF_E_UNSUPPORTED_SERVICE,
            0xC00D36BB => MEDIASERVER::MF_E_UNEXPECTED,
            0xC00D36BC => MEDIASERVER::MF_E_INVALIDNAME,
            0xC00D36BD => MEDIASERVER::MF_E_INVALIDTYPE,
            0xC00D36BE => MEDIASERVER::MF_E_INVALID_FILE_FORMAT,
            0xC00D36BF => MEDIASERVER::MF_E_INVALIDINDEX,
            0xC00D36C0 => MEDIASERVER::MF_E_INVALID_TIMESTAMP,
            0xC00D36C3 => MEDIASERVER::MF_E_UNSUPPORTED_SCHEME,
            0xC00D36C4 => MEDIASERVER::MF_E_UNSUPPORTED_BYTESTREAM_TYPE,
            0xC00D36C5 => MEDIASERVER::MF_E_UNSUPPORTED_TIME_FORMAT,
            0xC00D36C8 => MEDIASERVER::MF_E_NO_SAMPLE_TIMESTAMP,
            0xC00D36C9 => MEDIASERVER::MF_E_NO_SAMPLE_DURATION,
            0xC00D36CB => MEDIASERVER::MF_E_INVALID_STREAM_DATA,
            0xC00D36CF => MEDIASERVER::MF_E_RT_UNAVAILABLE,
            0xC00D36D0 => MEDIASERVER::MF_E_UNSUPPORTED_RATE,
            0xC00D36D1 => MEDIASERVER::MF_E_THINNING_UNSUPPORTED,
            0xC00D36D2 => MEDIASERVER::MF_E_REVERSE_UNSUPPORTED,
            0xC00D36D3 => MEDIASERVER::MF_E_UNSUPPORTED_RATE_TRANSITION,
            0xC00D36D4 => MEDIASERVER::MF_E_RATE_CHANGE_PREEMPTED,
            0xC00D36D5 => MEDIASERVER::MF_E_NOT_FOUND,
            0xC00D36D6 => MEDIASERVER::MF_E_NOT_AVAILABLE,
            0xC00D36D7 => MEDIASERVER::MF_E_NO_CLOCK,
            0xC00D36D9 => MEDIASERVER::MF_E_MULTIPLE_BEGIN,
            0xC00D36DA => MEDIASERVER::MF_E_MULTIPLE_SUBSCRIBERS,
            0xC00D36DB => MEDIASERVER::MF_E_TIMER_ORPHANED,
            0xC00D36DC => MEDIASERVER::MF_E_STATE_TRANSITION_PENDING,
            0xC00D36DD => MEDIASERVER::MF_E_UNSUPPORTED_STATE_TRANSITION,
            0xC00D36DE => MEDIASERVER::MF_E_UNRECOVERABLE_ERROR_OCCURRED,
            0xC00D36DF => MEDIASERVER::MF_E_SAMPLE_HAS_TOO_MANY_BUFFERS,
            0xC00D36E0 => MEDIASERVER::MF_E_SAMPLE_NOT_WRITABLE,
            0xC00D36E2 => MEDIASERVER::MF_E_INVALID_KEY,
            0xC00D36E3 => MEDIASERVER::MF_E_BAD_STARTUP_VERSION,
            0xC00D36E4 => MEDIASERVER::MF_E_UNSUPPORTED_CAPTION,
            0xC00D36E5 => MEDIASERVER::MF_E_INVALID_POSITION,
            0xC00D36E6 => MEDIASERVER::MF_E_ATTRIBUTENOTFOUND,
            0xC00D36E7 => MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_ALLOWED,
            0xC00D36E8 => MEDIASERVER::MF_E_PROPERTY_TYPE_NOT_SUPPORTED,
            0xC00D36E9 => MEDIASERVER::MF_E_PROPERTY_EMPTY,
            0xC00D36EA => MEDIASERVER::MF_E_PROPERTY_NOT_EMPTY,
            0xC00D36EB => MEDIASERVER::MF_E_PROPERTY_VECTOR_NOT_ALLOWED,
            0xC00D36EC => MEDIASERVER::MF_E_PROPERTY_VECTOR_REQUIRED,
            0xC00D36ED => MEDIASERVER::MF_E_OPERATION_CANCELLED,
            0xC00D36EE => MEDIASERVER::MF_E_BYTESTREAM_NOT_SEEKABLE,
            0xC00D36EF => MEDIASERVER::MF_E_DISABLED_IN_SAFEMODE,
            0xC00D36F0 => MEDIASERVER::MF_E_CANNOT_PARSE_BYTESTREAM,
            0xC00D36F1 => MEDIASERVER::MF_E_SOURCERESOLVER_MUTUALLY_EXCLUSIVE_FLAGS,
            0xC00D36F2 => MEDIASERVER::MF_E_MEDIAPROC_WRONGSTATE,
            0xC00D36F3 => MEDIASERVER::MF_E_RT_THROUGHPUT_NOT_AVAILABLE,
            0xC00D36F4 => MEDIASERVER::MF_E_RT_TOO_MANY_CLASSES,
            0xC00D36F5 => MEDIASERVER::MF_E_RT_WOULDBLOCK,
            0xC00D36F6 => MEDIASERVER::MF_E_NO_BITPUMP,
            0xC00D36F7 => MEDIASERVER::MF_E_RT_OUTOFMEMORY,
            0xC00D36F8 => MEDIASERVER::MF_E_RT_WORKQUEUE_CLASS_NOT_SPECIFIED,
            0xC00D36FA => MEDIASERVER::MF_E_CANNOT_CREATE_SINK,
            0xC00D36FB => MEDIASERVER::MF_E_BYTESTREAM_UNKNOWN_LENGTH,
            0xC00D36FC => MEDIASERVER::MF_E_SESSION_PAUSEWHILESTOPPED,
            0xC00D36FE => MEDIASERVER::MF_E_FORMAT_CHANGE_NOT_SUPPORTED,
            0xC00D36FF => MEDIASERVER::MF_E_INVALID_WORKQUEUE,
            0xC00D3700 => MEDIASERVER::MF_E_DRM_UNSUPPORTED,
            0xC00D3701 => MEDIASERVER::MF_E_UNAUTHORIZED,
            0xC00D3702 => MEDIASERVER::MF_E_OUT_OF_RANGE,
            0xC00D3703 => MEDIASERVER::MF_E_INVALID_CODEC_MERIT,
            0xC00D3704 => MEDIASERVER::MF_E_HW_MFT_FAILED_START_STREAMING,
            0xC00D3A98 => MEDIASERVER::MF_E_ASF_PARSINGINCOMPLETE,
            0xC00D3A99 => MEDIASERVER::MF_E_ASF_MISSINGDATA,
            0xC00D3A9A => MEDIASERVER::MF_E_ASF_INVALIDDATA,
            0xC00D3A9B => MEDIASERVER::MF_E_ASF_OPAQUEPACKET,
            0xC00D3A9C => MEDIASERVER::MF_E_ASF_NOINDEX,
            0xC00D3A9D => MEDIASERVER::MF_E_ASF_OUTOFRANGE,
            0xC00D3A9E => MEDIASERVER::MF_E_ASF_INDEXNOTLOADED,
            0xC00D3A9F => MEDIASERVER::MF_E_ASF_TOO_MANY_PAYLOADS,
            0xC00D3AA0 => MEDIASERVER::MF_E_ASF_UNSUPPORTED_STREAM_TYPE,
            0xC00D3AA1 => MEDIASERVER::MF_E_ASF_DROPPED_PACKET,
            0xC00D3E80 => MEDIASERVER::MF_E_NO_EVENTS_AVAILABLE,
            0xC00D3E82 => MEDIASERVER::MF_E_INVALID_STATE_TRANSITION,
            0xC00D3E84 => MEDIASERVER::MF_E_END_OF_STREAM,
            0xC00D3E85 => MEDIASERVER::MF_E_SHUTDOWN,
            0xC00D3E86 => MEDIASERVER::MF_E_MP3_NOTFOUND,
            0xC00D3E87 => MEDIASERVER::MF_E_MP3_OUTOFDATA,
            0xC00D3E88 => MEDIASERVER::MF_E_MP3_NOTMP3,
            0xC00D3E89 => MEDIASERVER::MF_E_MP3_NOTSUPPORTED,
            0xC00D3E8A => MEDIASERVER::MF_E_NO_DURATION,
            0xC00D3E8C => MEDIASERVER::MF_E_INVALID_FORMAT,
            0xC00D3E8D => MEDIASERVER::MF_E_PROPERTY_NOT_FOUND,
            0xC00D3E8E => MEDIASERVER::MF_E_PROPERTY_READ_ONLY,
            0xC00D3E8F => MEDIASERVER::MF_E_PROPERTY_NOT_ALLOWED,
            0xC00D3E91 => MEDIASERVER::MF_E_MEDIA_SOURCE_NOT_STARTED,
            0xC00D3E98 => MEDIASERVER::MF_E_UNSUPPORTED_FORMAT,
            0xC00D3E99 => MEDIASERVER::MF_E_MP3_BAD_CRC,
            0xC00D3E9A => MEDIASERVER::MF_E_NOT_PROTECTED,
            0xC00D3E9B => MEDIASERVER::MF_E_MEDIA_SOURCE_WRONGSTATE,
            0xC00D3E9C => MEDIASERVER::MF_E_MEDIA_SOURCE_NO_STREAMS_SELECTED,
            0xC00D3E9D => MEDIASERVER::MF_E_CANNOT_FIND_KEYFRAME_SAMPLE,
            0xC00D4268 => MEDIASERVER::MF_E_NETWORK_RESOURCE_FAILURE,
            0xC00D4269 => MEDIASERVER::MF_E_NET_WRITE,
            0xC00D426A => MEDIASERVER::MF_E_NET_READ,
            0xC00D426B => MEDIASERVER::MF_E_NET_REQUIRE_NETWORK,
            0xC00D426C => MEDIASERVER::MF_E_NET_REQUIRE_ASYNC,
            0xC00D426D => MEDIASERVER::MF_E_NET_BWLEVEL_NOT_SUPPORTED,
            0xC00D426E => MEDIASERVER::MF_E_NET_STREAMGROUPS_NOT_SUPPORTED,
            0xC00D426F => MEDIASERVER::MF_E_NET_MANUALSS_NOT_SUPPORTED,
            0xC00D4270 => MEDIASERVER::MF_E_NET_INVALID_PRESENTATION_DESCRIPTOR,
            0xC00D4271 => MEDIASERVER::MF_E_NET_CACHESTREAM_NOT_FOUND,
            0xC00D4274 => MEDIASERVER::MF_E_NET_REQUIRE_INPUT,
            0xC00D4275 => MEDIASERVER::MF_E_NET_REDIRECT,
            0xC00D4276 => MEDIASERVER::MF_E_NET_REDIRECT_TO_PROXY,
            0xC00D4277 => MEDIASERVER::MF_E_NET_TOO_MANY_REDIRECTS,
            0xC00D4278 => MEDIASERVER::MF_E_NET_TIMEOUT,
            0xC00D4279 => MEDIASERVER::MF_E_NET_CLIENT_CLOSE,
            0xC00D427A => MEDIASERVER::MF_E_NET_BAD_CONTROL_DATA,
            0xC00D427B => MEDIASERVER::MF_E_NET_INCOMPATIBLE_SERVER,
            0xC00D427C => MEDIASERVER::MF_E_NET_UNSAFE_URL,
            0xC00D427D => MEDIASERVER::MF_E_NET_CACHE_NO_DATA,
            0xC00D427E => MEDIASERVER::MF_E_NET_EOL,
            0xC00D427F => MEDIASERVER::MF_E_NET_BAD_REQUEST,
            0xC00D4280 => MEDIASERVER::MF_E_NET_INTERNAL_SERVER_ERROR,
            0xC00D4281 => MEDIASERVER::MF_E_NET_SESSION_NOT_FOUND,
            0xC00D4282 => MEDIASERVER::MF_E_NET_NOCONNECTION,
            0xC00D4283 => MEDIASERVER::MF_E_NET_CONNECTION_FAILURE,
            0xC00D4284 => MEDIASERVER::MF_E_NET_INCOMPATIBLE_PUSHSERVER,
            0xC00D4285 => MEDIASERVER::MF_E_NET_SERVER_ACCESSDENIED,
            0xC00D4286 => MEDIASERVER::MF_E_NET_PROXY_ACCESSDENIED,
            0xC00D4287 => MEDIASERVER::MF_E_NET_CANNOTCONNECT,
            0xC00D4288 => MEDIASERVER::MF_E_NET_INVALID_PUSH_TEMPLATE,
            0xC00D4289 => MEDIASERVER::MF_E_NET_INVALID_PUSH_PUBLISHING_POINT,
            0xC00D428A => MEDIASERVER::MF_E_NET_BUSY,
            0xC00D428B => MEDIASERVER::MF_E_NET_RESOURCE_GONE,
            0xC00D428C => MEDIASERVER::MF_E_NET_ERROR_FROM_PROXY,
            0xC00D428D => MEDIASERVER::MF_E_NET_PROXY_TIMEOUT,
            0xC00D428E => MEDIASERVER::MF_E_NET_SERVER_UNAVAILABLE,
            0xC00D428F => MEDIASERVER::MF_E_NET_TOO_MUCH_DATA,
            0xC00D4290 => MEDIASERVER::MF_E_NET_SESSION_INVALID,
            0xC00D4291 => MEDIASERVER::MF_E_OFFLINE_MODE,
            0xC00D4292 => MEDIASERVER::MF_E_NET_UDP_BLOCKED,
            0xC00D4293 => MEDIASERVER::MF_E_NET_UNSUPPORTED_CONFIGURATION,
            0xC00D4294 => MEDIASERVER::MF_E_NET_PROTOCOL_DISABLED,
            0xC00D4650 => MEDIASERVER::MF_E_ALREADY_INITIALIZED,
            0xC00D4651 => MEDIASERVER::MF_E_BANDWIDTH_OVERRUN,
            0xC00D4652 => MEDIASERVER::MF_E_LATE_SAMPLE,
            0xC00D4653 => MEDIASERVER::MF_E_FLUSH_NEEDED,
            0xC00D4654 => MEDIASERVER::MF_E_INVALID_PROFILE,
            0xC00D4655 => MEDIASERVER::MF_E_INDEX_NOT_COMMITTED,
            0xC00D4656 => MEDIASERVER::MF_E_NO_INDEX,
            0xC00D4657 => MEDIASERVER::MF_E_CANNOT_INDEX_IN_PLACE,
            0xC00D4658 => MEDIASERVER::MF_E_MISSING_ASF_LEAKYBUCKET,
            0xC00D4659 => MEDIASERVER::MF_E_INVALID_ASF_STREAMID,
            0xC00D4A38 => MEDIASERVER::MF_E_STREAMSINK_REMOVED,
            0xC00D4A3A => MEDIASERVER::MF_E_STREAMSINKS_OUT_OF_SYNC,
            0xC00D4A3B => MEDIASERVER::MF_E_STREAMSINKS_FIXED,
            0xC00D4A3C => MEDIASERVER::MF_E_STREAMSINK_EXISTS,
            0xC00D4A3D => MEDIASERVER::MF_E_SAMPLEALLOCATOR_CANCELED,
            0xC00D4A3E => MEDIASERVER::MF_E_SAMPLEALLOCATOR_EMPTY,
            0xC00D4A3F => MEDIASERVER::MF_E_SINK_ALREADYSTOPPED,
            0xC00D4A40 => MEDIASERVER::MF_E_ASF_FILESINK_BITRATE_UNKNOWN,
            0xC00D4A41 => MEDIASERVER::MF_E_SINK_NO_STREAMS,
            0xC00D4A43 => MEDIASERVER::MF_E_METADATA_TOO_LONG,
            0xC00D4A44 => MEDIASERVER::MF_E_SINK_NO_SAMPLES_PROCESSED,
            0xC00D4E20 => MEDIASERVER::MF_E_VIDEO_REN_NO_PROCAMP_HW,
            0xC00D4E21 => MEDIASERVER::MF_E_VIDEO_REN_NO_DEINTERLACE_HW,
            0xC00D4E22 => MEDIASERVER::MF_E_VIDEO_REN_COPYPROT_FAILED,
            0xC00D4E23 => MEDIASERVER::MF_E_VIDEO_REN_SURFACE_NOT_SHARED,
            0xC00D4E24 => MEDIASERVER::MF_E_VIDEO_DEVICE_LOCKED,
            0xC00D4E25 => MEDIASERVER::MF_E_NEW_VIDEO_DEVICE,
            0xC00D4E26 => MEDIASERVER::MF_E_NO_VIDEO_SAMPLE_AVAILABLE,
            0xC00D4E84 => MEDIASERVER::MF_E_NO_AUDIO_PLAYBACK_DEVICE,
            0xC00D4E85 => MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_IN_USE,
            0xC00D4E86 => MEDIASERVER::MF_E_AUDIO_PLAYBACK_DEVICE_INVALIDATED,
            0xC00D4E87 => MEDIASERVER::MF_E_AUDIO_SERVICE_NOT_RUNNING,
            0xC00D520E => MEDIASERVER::MF_E_TOPO_INVALID_OPTIONAL_NODE,
            0xC00D5211 => MEDIASERVER::MF_E_TOPO_CANNOT_FIND_DECRYPTOR,
            0xC00D5212 => MEDIASERVER::MF_E_TOPO_CODEC_NOT_FOUND,
            0xC00D5213 => MEDIASERVER::MF_E_TOPO_CANNOT_CONNECT,
            0xC00D5214 => MEDIASERVER::MF_E_TOPO_UNSUPPORTED,
            0xC00D5215 => MEDIASERVER::MF_E_TOPO_INVALID_TIME_ATTRIBUTES,
            0xC00D5216 => MEDIASERVER::MF_E_TOPO_LOOPS_IN_TOPOLOGY,
            0xC00D5217 => MEDIASERVER::MF_E_TOPO_MISSING_PRESENTATION_DESCRIPTOR,
            0xC00D5218 => MEDIASERVER::MF_E_TOPO_MISSING_STREAM_DESCRIPTOR,
            0xC00D5219 => MEDIASERVER::MF_E_TOPO_STREAM_DESCRIPTOR_NOT_SELECTED,
            0xC00D521A => MEDIASERVER::MF_E_TOPO_MISSING_SOURCE,
            0xC00D521B => MEDIASERVER::MF_E_TOPO_SINK_ACTIVATES_UNSUPPORTED,
            0xC00D61AC => MEDIASERVER::MF_E_SEQUENCER_UNKNOWN_SEGMENT_ID,
            0xC00D61AE => MEDIASERVER::MF_E_NO_SOURCE_IN_CACHE,
            0xC00D6D60 => MEDIASERVER::MF_E_TRANSFORM_TYPE_NOT_SET,
            0xC00D6D61 => MEDIASERVER::MF_E_TRANSFORM_STREAM_CHANGE,
            0xC00D6D62 => MEDIASERVER::MF_E_TRANSFORM_INPUT_REMAINING,
            0xC00D6D63 => MEDIASERVER::MF_E_TRANSFORM_PROFILE_MISSING,
            0xC00D6D64 => MEDIASERVER::MF_E_TRANSFORM_PROFILE_INVALID_OR_CORRUPT,
            0xC00D6D65 => MEDIASERVER::MF_E_TRANSFORM_PROFILE_TRUNCATED,
            0xC00D6D66 => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_PID_NOT_RECOGNIZED,
            0xC00D6D67 => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VARIANT_TYPE_WRONG,
            0xC00D6D68 => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_NOT_WRITEABLE,
            0xC00D6D69 => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_ARRAY_VALUE_WRONG_NUM_DIM,
            0xC00D6D6A => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_SIZE_WRONG,
            0xC00D6D6B => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_OUT_OF_RANGE,
            0xC00D6D6C => MEDIASERVER::MF_E_TRANSFORM_PROPERTY_VALUE_INCOMPATIBLE,
            0xC00D6D6D => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_OUTPUT_MEDIATYPE,
            0xC00D6D6E => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_INPUT_MEDIATYPE,
            0xC00D6D6F => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_MEDIATYPE_COMBINATION,
            0xC00D6D70 => MEDIASERVER::MF_E_TRANSFORM_CONFLICTS_WITH_OTHER_CURRENTLY_ENABLED_FEATURES,
            0xC00D6D72 => MEDIASERVER::MF_E_TRANSFORM_NEED_MORE_INPUT,
            0xC00D6D73 => MEDIASERVER::MF_E_TRANSFORM_NOT_POSSIBLE_FOR_CURRENT_SPKR_CONFIG,
            0xC00D6D74 => MEDIASERVER::MF_E_TRANSFORM_CANNOT_CHANGE_MEDIATYPE_WHILE_PROCESSING,
            0xC00D6D76 => MEDIASERVER::MF_E_UNSUPPORTED_D3D_TYPE,
            0xC00D6D77 => MEDIASERVER::MF_E_TRANSFORM_ASYNC_LOCKED,
            0xC00D6D78 => MEDIASERVER::MF_E_TRANSFORM_CANNOT_INITIALIZE_ACM_DRIVER,
            0xC00D7148 => MEDIASERVER::MF_E_LICENSE_INCORRECT_RIGHTS,
            0xC00D7149 => MEDIASERVER::MF_E_LICENSE_OUTOFDATE,
            0xC00D714A => MEDIASERVER::MF_E_LICENSE_REQUIRED,
            0xC00D714B => MEDIASERVER::MF_E_DRM_HARDWARE_INCONSISTENT,
            0xC00D714C => MEDIASERVER::MF_E_NO_CONTENT_PROTECTION_MANAGER,
            0xC00D714D => MEDIASERVER::MF_E_LICENSE_RESTORE_NO_RIGHTS,
            0xC00D714E => MEDIASERVER::MF_E_BACKUP_RESTRICTED_LICENSE,
            0xC00D714F => MEDIASERVER::MF_E_LICENSE_RESTORE_NEEDS_INDIVIDUALIZATION,
            0xC00D7151 => MEDIASERVER::MF_E_COMPONENT_REVOKED,
            0xC00D7152 => MEDIASERVER::MF_E_TRUST_DISABLED,
            0xC00D7153 => MEDIASERVER::MF_E_WMDRMOTA_NO_ACTION,
            0xC00D7154 => MEDIASERVER::MF_E_WMDRMOTA_ACTION_ALREADY_SET,
            0xC00D7155 => MEDIASERVER::MF_E_WMDRMOTA_DRM_HEADER_NOT_AVAILABLE,
            0xC00D7156 => MEDIASERVER::MF_E_WMDRMOTA_DRM_ENCRYPTION_SCHEME_NOT_SUPPORTED,
            0xC00D7157 => MEDIASERVER::MF_E_WMDRMOTA_ACTION_MISMATCH,
            0xC00D7158 => MEDIASERVER::MF_E_WMDRMOTA_INVALID_POLICY,
            0xC00D7159 => MEDIASERVER::MF_E_POLICY_UNSUPPORTED,
            0xC00D715A => MEDIASERVER::MF_E_OPL_NOT_SUPPORTED,
            0xC00D715B => MEDIASERVER::MF_E_TOPOLOGY_VERIFICATION_FAILED,
            0xC00D715C => MEDIASERVER::MF_E_SIGNATURE_VERIFICATION_FAILED,
            0xC00D715D => MEDIASERVER::MF_E_DEBUGGING_NOT_ALLOWED,
            0xC00D715E => MEDIASERVER::MF_E_CODE_EXPIRED,
            0xC00D715F => MEDIASERVER::MF_E_GRL_VERSION_TOO_LOW,
            0xC00D7160 => MEDIASERVER::MF_E_GRL_RENEWAL_NOT_FOUND,
            0xC00D7161 => MEDIASERVER::MF_E_GRL_EXTENSIBLE_ENTRY_NOT_FOUND,
            0xC00D7162 => MEDIASERVER::MF_E_KERNEL_UNTRUSTED,
            0xC00D7163 => MEDIASERVER::MF_E_PEAUTH_UNTRUSTED,
            0xC00D7165 => MEDIASERVER::MF_E_NON_PE_PROCESS,
            0xC00D7167 => MEDIASERVER::MF_E_REBOOT_REQUIRED,
            0xC00D716A => MEDIASERVER::MF_E_GRL_INVALID_FORMAT,
            0xC00D716B => MEDIASERVER::MF_E_GRL_UNRECOGNIZED_FORMAT,
            0xC00D716C => MEDIASERVER::MF_E_ALL_PROCESS_RESTART_REQUIRED,
            0xC00D716D => MEDIASERVER::MF_E_PROCESS_RESTART_REQUIRED,
            0xC00D716E => MEDIASERVER::MF_E_USERMODE_UNTRUSTED,
            0xC00D716F => MEDIASERVER::MF_E_PEAUTH_SESSION_NOT_STARTED,
            0xC00D7170 => MEDIASERVER::MF_E_INSUFFICIENT_BUFFER,
            0xC00D7171 => MEDIASERVER::MF_E_PEAUTH_PUBLICKEY_REVOKED,
            0xC00D7172 => MEDIASERVER::MF_E_GRL_ABSENT,
            0xC00D7174 => MEDIASERVER::MF_E_PE_UNTRUSTED,
            0xC00D7175 => MEDIASERVER::MF_E_PEAUTH_NOT_STARTED,
            0xC00D7176 => MEDIASERVER::MF_E_INCOMPATIBLE_SAMPLE_PROTECTION,
            0xC00D7177 => MEDIASERVER::MF_E_PE_SESSIONS_MAXED,
            0xC00D7178 => MEDIASERVER::MF_E_HIGH_SECURITY_LEVEL_CONTENT_NOT_ALLOWED,
            0xC00D7179 => MEDIASERVER::MF_E_TEST_SIGNED_COMPONENTS_NOT_ALLOWED,
            0xC00D717A => MEDIASERVER::MF_E_ITA_UNSUPPORTED_ACTION,
            0xC00D717B => MEDIASERVER::MF_E_ITA_ERROR_PARSING_SAP_PARAMETERS,
            0xC00D717C => MEDIASERVER::MF_E_POLICY_MGR_ACTION_OUTOFBOUNDS,
            0xC00D717D => MEDIASERVER::MF_E_BAD_OPL_STRUCTURE_FORMAT,
            0xC00D717E => MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_PROTECTION_GUID,
            0xC00D717F => MEDIASERVER::MF_E_NO_PMP_HOST,
            0xC00D7180 => MEDIASERVER::MF_E_ITA_OPL_DATA_NOT_INITIALIZED,
            0xC00D7181 => MEDIASERVER::MF_E_ITA_UNRECOGNIZED_ANALOG_VIDEO_OUTPUT,
            0xC00D7182 => MEDIASERVER::MF_E_ITA_UNRECOGNIZED_DIGITAL_VIDEO_OUTPUT,
            0xC00D9C40 => MEDIASERVER::MF_E_CLOCK_INVALID_CONTINUITY_KEY,
            0xC00D9C41 => MEDIASERVER::MF_E_CLOCK_NO_TIME_SOURCE,
            0xC00D9C42 => MEDIASERVER::MF_E_CLOCK_STATE_ALREADY_SET,
            0xC00D9C43 => MEDIASERVER::MF_E_CLOCK_NOT_SIMPLE,
            0xC00DA028 => MEDIASERVER::MF_E_NO_MORE_DROP_MODES,
            0xC00DA029 => MEDIASERVER::MF_E_NO_MORE_QUALITY_LEVELS,
            0xC00DA02A => MEDIASERVER::MF_E_DROPTIME_NOT_SUPPORTED,
            0xC00DA02B => MEDIASERVER::MF_E_QUALITYKNOB_WAIT_LONGER,
            0xC00DA02C => MEDIASERVER::MF_E_QM_INVALIDSTATE,
            0xC00DA410 => MEDIASERVER::MF_E_TRANSCODE_NO_CONTAINERTYPE,
            0xC00DA411 => MEDIASERVER::MF_E_TRANSCODE_PROFILE_NO_MATCHING_STREAMS,
            0xC00DA412 => MEDIASERVER::MF_E_TRANSCODE_NO_MATCHING_ENCODER,
            0xC00DA7F8 => MEDIASERVER::MF_E_ALLOCATOR_NOT_INITIALIZED,
            0xC00DA7F9 => MEDIASERVER::MF_E_ALLOCATOR_NOT_COMMITED,
            0xC00DA7FA => MEDIASERVER::MF_E_ALLOCATOR_ALREADY_COMMITED,
            0xC00DA7FB => MEDIASERVER::MF_E_STREAM_ERROR,
            0xC00DA7FC => MEDIASERVER::MF_E_INVALID_STREAM_STATE,
            0xC00DA7FD => MEDIASERVER::MF_E_HW_STREAM_NOT_CONNECTED,
        }
    }
}
