/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WIN32 {
    ERROR_INVALID_FUNCTION,
    PDH_CSTATUS_NEW_DATA,
    ERROR_FILE_NOT_FOUND,
    ERROR_PATH_NOT_FOUND,
    E_PATH_NOT_FOUND,
    ERROR_TOO_MANY_OPEN_FILES,
    ERROR_ACCESS_DENIED,
    E_ACCESSDENIED,
    ERROR_INVALID_HANDLE,
    E_HANDLE,
    ERROR_ARENA_TRASHED,
    ERROR_NOT_ENOUGH_MEMORY,
    ERROR_INVALID_BLOCK,
    ERROR_BAD_ENVIRONMENT,
    ERROR_BAD_FORMAT,
    ERROR_INVALID_ACCESS,
    ERROR_INVALID_DATA,
    E_OUTOFMEMORY,
    ERROR_OUTOFMEMORY,
    DDERR_OUTOFMEMORY,
    ERROR_INVALID_DRIVE,
    ERROR_CURRENT_DIRECTORY,
    ERROR_NOT_SAME_DEVICE,
    ERROR_NO_MORE_FILES,
    ERROR_WRITE_PROTECT,
    ERROR_BAD_UNIT,
    ERROR_NOT_READY,
    ERROR_BAD_COMMAND,
    ERROR_CRC,
    ERROR_BAD_LENGTH,
    ERROR_SEEK,
    ERROR_NOT_DOS_DISK,
    ERROR_SECTOR_NOT_FOUND,
    ERROR_OUT_OF_PAPER,
    ERROR_WRITE_FAULT,
    ERROR_READ_FAULT,
    ERROR_GEN_FAILURE,
    ERROR_SHARING_VIOLATION,
    E_SHARING_VIOLATION,
    ERROR_LOCK_VIOLATION,
    ERROR_WRONG_DISK,
    ERROR_SHARING_BUFFER_EXCEEDED,
    ERROR_HANDLE_EOF,
    ERROR_HANDLE_DISK_FULL,
    ERROR_NOT_SUPPORTED,
    ERROR_REM_NOT_LIST,
    ERROR_DUP_NAME,
    ERROR_BAD_NETPATH,
    ERROR_NETWORK_BUSY,
    ERROR_DEV_NOT_EXIST,
    ERROR_TOO_MANY_CMDS,
    ERROR_ADAP_HDW_ERR,
    ERROR_BAD_NET_RESP,
    ERROR_UNEXP_NET_ERR,
    ERROR_BAD_REM_ADAP,
    ERROR_PRINTQ_FULL,
    ERROR_NO_SPOOL_SPACE,
    ERROR_PRINT_CANCELLED,
    ERROR_NETNAME_DELETED,
    ERROR_NETWORK_ACCESS_DENIED,
    ERROR_BAD_DEV_TYPE,
    ERROR_BAD_NET_NAME,
    ERROR_TOO_MANY_NAMES,
    ERROR_TOO_MANY_SESS,
    ERROR_SHARING_PAUSED,
    ERROR_REQ_NOT_ACCEP,
    ERROR_REDIR_PAUSED,
    ERROR_FILE_EXISTS,
    ERROR_CANNOT_MAKE,
    ERROR_FAIL_I24,
    ERROR_OUT_OF_STRUCTURES,
    ERROR_ALREADY_ASSIGNED,
    ERROR_INVALID_PASSWORD,
    ERROR_INVALID_PARAMETER,
    E_INVALIDARG,
    DDERR_INVALIDPARAMS,
    ERROR_NET_WRITE_FAULT,
    ERROR_NO_PROC_SLOTS,
    ERROR_TOO_MANY_SEMAPHORES,
    ERROR_EXCL_SEM_ALREADY_OWNED,
    ERROR_SEM_IS_SET,
    ERROR_TOO_MANY_SEM_REQUESTS,
    ERROR_INVALID_AT_INTERRUPT_TIME,
    ERROR_SEM_OWNER_DIED,
    ERROR_SEM_USER_LIMIT,
    ERROR_DISK_CHANGE,
    ERROR_DRIVE_LOCKED,
    ERROR_BROKEN_PIPE,
    ERROR_OPEN_FAILED,
    ERROR_BUFFER_OVERFLOW,
    ERROR_DISK_FULL,
    ERROR_NO_MORE_SEARCH_HANDLES,
    ERROR_INVALID_TARGET_HANDLE,
    ERROR_INVALID_CATEGORY,
    ERROR_INVALID_VERIFY_SWITCH,
    ERROR_BAD_DRIVER_LEVEL,
    ERROR_CALL_NOT_IMPLEMENTED,
    ERROR_SEM_TIMEOUT,
    ERROR_INSUFFICIENT_BUFFER,
    ERROR_INVALID_NAME,
    ERROR_INVALID_LEVEL,
    ERROR_NO_VOLUME_LABEL,
    ERROR_MOD_NOT_FOUND,
    ERROR_PROC_NOT_FOUND,
    ERROR_WAIT_NO_CHILDREN,
    ERROR_CHILD_NOT_COMPLETE,
    ERROR_DIRECT_ACCESS_HANDLE,
    ERROR_NEGATIVE_SEEK,
    ERROR_SEEK_ON_DEVICE,
    ERROR_IS_JOIN_TARGET,
    ERROR_IS_JOINED,
    ERROR_IS_SUBSTED,
    ERROR_NOT_JOINED,
    ERROR_NOT_SUBSTED,
    ERROR_JOIN_TO_JOIN,
    ERROR_SUBST_TO_SUBST,
    ERROR_JOIN_TO_SUBST,
    ERROR_SUBST_TO_JOIN,
    ERROR_BUSY_DRIVE,
    ERROR_SAME_DRIVE,
    ERROR_DIR_NOT_ROOT,
    ERROR_DIR_NOT_EMPTY,
    ERROR_IS_SUBST_PATH,
    ERROR_IS_JOIN_PATH,
    ERROR_PATH_BUSY,
    ERROR_IS_SUBST_TARGET,
    ERROR_SYSTEM_TRACE,
    ERROR_INVALID_EVENT_COUNT,
    ERROR_TOO_MANY_MUXWAITERS,
    ERROR_INVALID_LIST_FORMAT,
    ERROR_LABEL_TOO_LONG,
    ERROR_TOO_MANY_TCBS,
    ERROR_SIGNAL_REFUSED,
    ERROR_DISCARDED,
    ERROR_NOT_LOCKED,
    ERROR_BAD_THREADID_ADDR,
    ERROR_BAD_ARGUMENTS,
    ERROR_BAD_PATHNAME,
    ERROR_SIGNAL_PENDING,
    ERROR_MAX_THRDS_REACHED,
    ERROR_LOCK_FAILED,
    ERROR_BUSY,
    ERROR_DEVICE_SUPPORT_IN_PROGRESS,
    ERROR_CANCEL_VIOLATION,
    ERROR_ATOMIC_LOCKS_NOT_SUPPORTED,
    ERROR_INVALID_SEGMENT_NUMBER,
    ERROR_INVALID_ORDINAL,
    ERROR_ALREADY_EXISTS,
    ERROR_INVALID_FLAG_NUMBER,
    ERROR_SEM_NOT_FOUND,
    ERROR_INVALID_STARTING_CODESEG,
    ERROR_INVALID_STACKSEG,
    ERROR_INVALID_MODULETYPE,
    ERROR_INVALID_EXE_SIGNATURE,
    ERROR_EXE_MARKED_INVALID,
    ERROR_BAD_EXE_FORMAT,
    ERROR_ITERATED_DATA_EXCEEDS_64k,
    ERROR_INVALID_MINALLOCSIZE,
    ERROR_DYNLINK_FROM_INVALID_RING,
    ERROR_IOPL_NOT_ENABLED,
    ERROR_INVALID_SEGDPL,
    ERROR_AUTODATASEG_EXCEEDS_64k,
    ERROR_RING2SEG_MUST_BE_MOVABLE,
    ERROR_RELOC_CHAIN_XEEDS_SEGLIM,
    ERROR_INFLOOP_IN_RELOC_CHAIN,
    ERROR_ENVVAR_NOT_FOUND,
    ERROR_NO_SIGNAL_SENT,
    ERROR_FILENAME_EXCED_RANGE,
    ERROR_RING2_STACK_IN_USE,
    ERROR_META_EXPANSION_TOO_LONG,
    ERROR_INVALID_SIGNAL_NUMBER,
    ERROR_THREAD_1_INACTIVE,
    ERROR_LOCKED,
    ERROR_TOO_MANY_MODULES,
    ERROR_NESTING_NOT_ALLOWED,
    ERROR_EXE_MACHINE_TYPE_MISMATCH,
    ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY,
    ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY,
    ERROR_FILE_CHECKED_OUT,
    ERROR_CHECKOUT_REQUIRED,
    ERROR_BAD_FILE_TYPE,
    ERROR_FILE_TOO_LARGE,
    ERROR_FORMS_AUTH_REQUIRED,
    ERROR_VIRUS_INFECTED,
    ERROR_VIRUS_DELETED,
    ERROR_PIPE_LOCAL,
    ERROR_BAD_PIPE,
    ERROR_PIPE_BUSY,
    ERROR_NO_DATA,
    ERROR_PIPE_NOT_CONNECTED,
    ERROR_MORE_DATA,
    ERROR_NO_WORK_DONE,
    ERROR_VC_DISCONNECTED,
    ERROR_INVALID_EA_NAME,
    ERROR_EA_LIST_INCONSISTENT,
    WAIT_TIMEOUT,
    ERROR_NO_MORE_ITEMS,
    ERROR_CANNOT_COPY,
    ERROR_DIRECTORY,
    ERROR_EAS_DIDNT_FIT,
    ERROR_EA_FILE_CORRUPT,
    ERROR_EA_TABLE_FULL,
    ERROR_INVALID_EA_HANDLE,
    ERROR_EAS_NOT_SUPPORTED,
    ERROR_NOT_OWNER,
    ERROR_TOO_MANY_POSTS,
    ERROR_PARTIAL_COPY,
    ERROR_OPLOCK_NOT_GRANTED,
    ERROR_INVALID_OPLOCK_PROTOCOL,
    ERROR_DISK_TOO_FRAGMENTED,
    ERROR_DELETE_PENDING,
    ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING,
    ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME,
    ERROR_SECURITY_STREAM_IS_INCONSISTENT,
    ERROR_INVALID_LOCK_RANGE,
    ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT,
    ERROR_NOTIFICATION_GUID_ALREADY_DEFINED,
    ERROR_INVALID_EXCEPTION_HANDLER,
    ERROR_DUPLICATE_PRIVILEGES,
    ERROR_NO_RANGES_PROCESSED,
    ERROR_NOT_ALLOWED_ON_SYSTEM_FILE,
    ERROR_DISK_RESOURCES_EXHAUSTED,
    ERROR_INVALID_TOKEN,
    ERROR_DEVICE_FEATURE_NOT_SUPPORTED,
    ERROR_MR_MID_NOT_FOUND,
    ERROR_SCOPE_NOT_FOUND,
    ERROR_UNDEFINED_SCOPE,
    ERROR_INVALID_CAP,
    ERROR_DEVICE_UNREACHABLE,
    ERROR_DEVICE_NO_RESOURCES,
    ERROR_DATA_CHECKSUM_ERROR,
    ERROR_INTERMIXED_KERNEL_EA_OPERATION,
    ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED,
    ERROR_OFFSET_ALIGNMENT_VIOLATION,
    ERROR_INVALID_FIELD_IN_PARAMETER_LIST,
    ERROR_OPERATION_IN_PROGRESS,
    ERROR_BAD_DEVICE_PATH,
    ERROR_TOO_MANY_DESCRIPTORS,
    ERROR_SCRUB_DATA_DISABLED,
    ERROR_NOT_REDUNDANT_STORAGE,
    ERROR_RESIDENT_FILE_NOT_SUPPORTED,
    ERROR_COMPRESSED_FILE_NOT_SUPPORTED,
    ERROR_DIRECTORY_NOT_SUPPORTED,
    ERROR_NOT_READ_FROM_COPY,
    ERROR_FT_WRITE_FAILURE,
    ERROR_FT_DI_SCAN_REQUIRED,
    ERROR_INVALID_KERNEL_INFO_VERSION,
    ERROR_INVALID_PEP_INFO_VERSION,
    ERROR_OBJECT_NOT_EXTERNALLY_BACKED,
    ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN,
    ERROR_COMPRESSION_NOT_BENEFICIAL,
    ERROR_STORAGE_TOPOLOGY_ID_MISMATCH,
    ERROR_BLOCKED_BY_PARENTAL_CONTROLS,
    ERROR_BLOCK_TOO_MANY_REFERENCES,
    ERROR_MARKED_TO_DISALLOW_WRITES,
    ERROR_ENCLAVE_FAILURE,
    ERROR_FAIL_NOACTION_REBOOT,
    ERROR_FAIL_SHUTDOWN,
    ERROR_FAIL_RESTART,
    ERROR_MAX_SESSIONS_REACHED,
    ERROR_NETWORK_ACCESS_DENIED_EDP,
    ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL,
    ERROR_EDP_POLICY_DENIES_OPERATION,
    ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED,
    ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT,
    ERROR_CLOUD_FILE_PROVIDER_UNKNOWN,
    ERROR_DEVICE_IN_MAINTENANCE,
    ERROR_NOT_SUPPORTED_ON_DAX,
    ERROR_DAX_MAPPING_EXISTS,
    ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING,
    ERROR_CLOUD_FILE_METADATA_CORRUPT,
    ERROR_CLOUD_FILE_METADATA_TOO_LARGE,
    ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE,
    ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH,
    ERROR_CHILD_PROCESS_BLOCKED,
    ERROR_STORAGE_LOST_DATA_PERSISTENCE,
    ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE,
    ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT,
    ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY,
    ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN,
    ERROR_GDI_HANDLE_LEAK,
    ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS,
    ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED,
    ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED,
    ERROR_NOT_A_CLOUD_FILE,
    ERROR_CLOUD_FILE_NOT_IN_SYNC,
    ERROR_CLOUD_FILE_ALREADY_CONNECTED,
    ERROR_CLOUD_FILE_NOT_SUPPORTED,
    ERROR_CLOUD_FILE_INVALID_REQUEST,
    ERROR_CLOUD_FILE_READ_ONLY_VOLUME,
    ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY,
    ERROR_CLOUD_FILE_VALIDATION_FAILED,
    ERROR_SMB1_NOT_AVAILABLE,
    ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION,
    ERROR_CLOUD_FILE_AUTHENTICATION_FAILED,
    ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES,
    ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE,
    ERROR_CLOUD_FILE_UNSUCCESSFUL,
    ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT,
    ERROR_CLOUD_FILE_IN_USE,
    ERROR_CLOUD_FILE_PINNED,
    ERROR_CLOUD_FILE_REQUEST_ABORTED,
    ERROR_CLOUD_FILE_PROPERTY_CORRUPT,
    ERROR_CLOUD_FILE_ACCESS_DENIED,
    ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS,
    ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT,
    ERROR_CLOUD_FILE_REQUEST_CANCELED,
    ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED,
    ERROR_THREAD_MODE_ALREADY_BACKGROUND,
    ERROR_THREAD_MODE_NOT_BACKGROUND,
    ERROR_PROCESS_MODE_ALREADY_BACKGROUND,
    ERROR_PROCESS_MODE_NOT_BACKGROUND,
    ERROR_CLOUD_FILE_PROVIDER_TERMINATED,
    ERROR_NOT_A_CLOUD_SYNC_ROOT,
    ERROR_FILE_PROTECTED_UNDER_DPL,
    ERROR_VOLUME_NOT_CLUSTER_ALIGNED,
    ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND,
    ERROR_APPX_FILE_NOT_ENCRYPTED,
    ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED,
    ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET,
    ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE,
    ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER,
    ERROR_LINUX_SUBSYSTEM_NOT_PRESENT,
    ERROR_FT_READ_FAILURE,
    ERROR_STORAGE_RESERVE_ID_INVALID,
    ERROR_STORAGE_RESERVE_DOES_NOT_EXIST,
    ERROR_STORAGE_RESERVE_ALREADY_EXISTS,
    ERROR_STORAGE_RESERVE_NOT_EMPTY,
    ERROR_NOT_A_DAX_VOLUME,
    ERROR_NOT_DAX_MAPPABLE,
    ERROR_TIME_SENSITIVE_THREAD,
    ERROR_DPL_NOT_SUPPORTED_FOR_USER,
    ERROR_CASE_DIFFERING_NAMES_IN_DIR,
    ERROR_FILE_NOT_SUPPORTED,
    ERROR_CLOUD_FILE_REQUEST_TIMEOUT,
    ERROR_NO_TASK_QUEUE,
    ERROR_SRC_SRV_DLL_LOAD_FAILED,
    ERROR_NOT_SUPPORTED_WITH_BTT,
    ERROR_ENCRYPTION_DISABLED,
    ERROR_ENCRYPTING_METADATA_DISALLOWED,
    ERROR_CANT_CLEAR_ENCRYPTION_FLAG,
    ERROR_NO_SUCH_DEVICE,
    ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED,
    ERROR_FILE_SNAP_IN_PROGRESS,
    ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED,
    ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED,
    ERROR_FILE_SNAP_IO_NOT_COORDINATED,
    ERROR_FILE_SNAP_UNEXPECTED_ERROR,
    ERROR_FILE_SNAP_INVALID_PARAMETER,
    ERROR_UNSATISFIED_DEPENDENCIES,
    ERROR_CASE_SENSITIVE_PATH,
    ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR,
    ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED,
    ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION,
    ERROR_DLP_POLICY_DENIES_OPERATION,
    ERROR_SECURITY_DENIES_OPERATION,
    ERROR_UNTRUSTED_MOUNT_POINT,
    ERROR_DLP_POLICY_SILENTLY_FAIL,
    ERROR_CAPAUTHZ_NOT_DEVUNLOCKED,
    ERROR_CAPAUTHZ_CHANGE_TYPE,
    ERROR_CAPAUTHZ_NOT_PROVISIONED,
    ERROR_CAPAUTHZ_NOT_AUTHORIZED,
    ERROR_CAPAUTHZ_NO_POLICY,
    ERROR_CAPAUTHZ_DB_CORRUPTED,
    ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG,
    ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY,
    ERROR_CAPAUTHZ_SCCD_PARSE_ERROR,
    ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED,
    ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH,
    ERROR_CIMFS_IMAGE_CORRUPT,
    ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED,
    ERROR_STORAGE_STACK_ACCESS_DENIED,
    ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES,
    ERROR_INDEX_OUT_OF_BOUNDS,
    ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT,
    ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT,
    ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT,
    ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT,
    ERROR_DEVICE_HARDWARE_ERROR,
    ERROR_INVALID_ADDRESS,
    ERROR_HAS_SYSTEM_CRITICAL_FILES,
    ERROR_ENCRYPTED_FILE_NOT_SUPPORTED,
    ERROR_SPARSE_FILE_NOT_SUPPORTED,
    ERROR_PAGEFILE_NOT_SUPPORTED,
    ERROR_VOLUME_NOT_SUPPORTED,
    ERROR_NOT_SUPPORTED_WITH_BYPASSIO,
    ERROR_NO_BYPASSIO_DRIVER_SUPPORT,
    ERROR_NOT_SUPPORTED_WITH_ENCRYPTION,
    ERROR_NOT_SUPPORTED_WITH_COMPRESSION,
    ERROR_NOT_SUPPORTED_WITH_REPLICATION,
    ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION,
    ERROR_NOT_SUPPORTED_WITH_AUDITING,
    ERROR_USER_PROFILE_LOAD,
    ERROR_SESSION_KEY_TOO_SHORT,
    ERROR_ACCESS_DENIED_APPDATA,
    ERROR_NOT_SUPPORTED_WITH_MONITORING,
    ERROR_NOT_SUPPORTED_WITH_SNAPSHOT,
    ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION,
    ERROR_BYPASSIO_FLT_NOT_SUPPORTED,
    ERROR_DEVICE_RESET_REQUIRED,
    ERROR_VOLUME_WRITE_ACCESS_DENIED,
    ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE,
    ERROR_FS_METADATA_INCONSISTENT,
    ERROR_BLOCK_WEAK_REFERENCE_INVALID,
    ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID,
    ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID,
    ERROR_BLOCK_SHARED,
    ERROR_ARITHMETIC_OVERFLOW,
    ERROR_PIPE_CONNECTED,
    ERROR_PIPE_LISTENING,
    ERROR_VERIFIER_STOP,
    ERROR_ABIOS_ERROR,
    ERROR_WX86_WARNING,
    ERROR_WX86_ERROR,
    ERROR_TIMER_NOT_CANCELED,
    ERROR_UNWIND,
    ERROR_BAD_STACK,
    ERROR_INVALID_UNWIND_TARGET,
    ERROR_INVALID_PORT_ATTRIBUTES,
    ERROR_PORT_MESSAGE_TOO_LONG,
    ERROR_INVALID_QUOTA_LOWER,
    ERROR_DEVICE_ALREADY_ATTACHED,
    ERROR_INSTRUCTION_MISALIGNMENT,
    ERROR_PROFILING_NOT_STARTED,
    ERROR_PROFILING_NOT_STOPPED,
    ERROR_COULD_NOT_INTERPRET,
    ERROR_PROFILING_AT_LIMIT,
    ERROR_CANT_WAIT,
    ERROR_CANT_TERMINATE_SELF,
    ERROR_UNEXPECTED_MM_CREATE_ERR,
    ERROR_UNEXPECTED_MM_MAP_ERROR,
    ERROR_UNEXPECTED_MM_EXTEND_ERR,
    ERROR_BAD_FUNCTION_TABLE,
    ERROR_NO_GUID_TRANSLATION,
    ERROR_INVALID_LDT_SIZE,
    ERROR_INVALID_LDT_OFFSET,
    ERROR_INVALID_LDT_DESCRIPTOR,
    ERROR_TOO_MANY_THREADS,
    ERROR_THREAD_NOT_IN_PROCESS,
    ERROR_PAGEFILE_QUOTA_EXCEEDED,
    ERROR_LOGON_SERVER_CONFLICT,
    ERROR_SYNCHRONIZATION_REQUIRED,
    ERROR_NET_OPEN_FAILED,
    ERROR_IO_PRIVILEGE_FAILED,
    ERROR_CONTROL_C_EXIT,
    ERROR_MISSING_SYSTEMFILE,
    ERROR_UNHANDLED_EXCEPTION,
    ERROR_APP_INIT_FAILURE,
    ERROR_PAGEFILE_CREATE_FAILED,
    ERROR_INVALID_IMAGE_HASH,
    ERROR_NO_PAGEFILE,
    ERROR_ILLEGAL_FLOAT_CONTEXT,
    ERROR_NO_EVENT_PAIR,
    ERROR_DOMAIN_CTRLR_CONFIG_ERROR,
    ERROR_ILLEGAL_CHARACTER,
    ERROR_UNDEFINED_CHARACTER,
    ERROR_FLOPPY_VOLUME,
    ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT,
    ERROR_BACKUP_CONTROLLER,
    ERROR_MUTANT_LIMIT_EXCEEDED,
    ERROR_FS_DRIVER_REQUIRED,
    ERROR_CANNOT_LOAD_REGISTRY_FILE,
    ERROR_DEBUG_ATTACH_FAILED,
    ERROR_SYSTEM_PROCESS_TERMINATED,
    ERROR_DATA_NOT_ACCEPTED,
    ERROR_VDM_HARD_ERROR,
    ERROR_DRIVER_CANCEL_TIMEOUT,
    ERROR_REPLY_MESSAGE_MISMATCH,
    ERROR_LOST_WRITEBEHIND_DATA,
    ERROR_CLIENT_SERVER_PARAMETERS_INVALID,
    ERROR_NOT_TINY_STREAM,
    ERROR_STACK_OVERFLOW_READ,
    ERROR_CONVERT_TO_LARGE,
    ERROR_FOUND_OUT_OF_SCOPE,
    ERROR_ALLOCATE_BUCKET,
    ERROR_MARSHALL_OVERFLOW,
    ERROR_INVALID_VARIANT,
    ERROR_BAD_COMPRESSION_BUFFER,
    ERROR_AUDIT_FAILED,
    ERROR_TIMER_RESOLUTION_NOT_SET,
    ERROR_INSUFFICIENT_LOGON_INFO,
    ERROR_BAD_DLL_ENTRYPOINT,
    ERROR_BAD_SERVICE_ENTRYPOINT,
    ERROR_IP_ADDRESS_CONFLICT1,
    ERROR_IP_ADDRESS_CONFLICT2,
    ERROR_REGISTRY_QUOTA_LIMIT,
    ERROR_NO_CALLBACK_ACTIVE,
    ERROR_PWD_TOO_SHORT,
    ERROR_PWD_TOO_RECENT,
    ERROR_PWD_HISTORY_CONFLICT,
    ERROR_UNSUPPORTED_COMPRESSION,
    ERROR_INVALID_HW_PROFILE,
    ERROR_INVALID_PLUGPLAY_DEVICE_PATH,
    ERROR_QUOTA_LIST_INCONSISTENT,
    ERROR_EVALUATION_EXPIRATION,
    ERROR_ILLEGAL_DLL_RELOCATION,
    ERROR_DLL_INIT_FAILED_LOGOFF,
    ERROR_VALIDATE_CONTINUE,
    ERROR_NO_MORE_MATCHES,
    ERROR_RANGE_LIST_CONFLICT,
    ERROR_SERVER_SID_MISMATCH,
    ERROR_CANT_ENABLE_DENY_ONLY,
    ERROR_FLOAT_MULTIPLE_FAULTS,
    ERROR_FLOAT_MULTIPLE_TRAPS,
    ERROR_NOINTERFACE,
    ERROR_DRIVER_FAILED_SLEEP,
    ERROR_CORRUPT_SYSTEM_FILE,
    ERROR_COMMITMENT_MINIMUM,
    ERROR_PNP_RESTART_ENUMERATION,
    ERROR_SYSTEM_IMAGE_BAD_SIGNATURE,
    ERROR_PNP_REBOOT_REQUIRED,
    ERROR_INSUFFICIENT_POWER,
    ERROR_MULTIPLE_FAULT_VIOLATION,
    ERROR_SYSTEM_SHUTDOWN,
    ERROR_PORT_NOT_SET,
    ERROR_DS_VERSION_CHECK_FAILURE,
    ERROR_RANGE_NOT_FOUND,
    ERROR_NOT_SAFE_MODE_DRIVER,
    ERROR_FAILED_DRIVER_ENTRY,
    ERROR_DEVICE_ENUMERATION_ERROR,
    ERROR_MOUNT_POINT_NOT_RESOLVED,
    ERROR_INVALID_DEVICE_OBJECT_PARAMETER,
    ERROR_MCA_OCCURED,
    ERROR_DRIVER_DATABASE_ERROR,
    ERROR_SYSTEM_HIVE_TOO_LARGE,
    ERROR_DRIVER_FAILED_PRIOR_UNLOAD,
    ERROR_VOLSNAP_PREPARE_HIBERNATE,
    ERROR_HIBERNATION_FAILURE,
    ERROR_PWD_TOO_LONG,
    ERROR_FILE_SYSTEM_LIMITATION,
    ERROR_ASSERTION_FAILURE,
    ERROR_ACPI_ERROR,
    ERROR_WOW_ASSERTION,
    ERROR_PNP_BAD_MPS_TABLE,
    ERROR_PNP_TRANSLATION_FAILED,
    ERROR_PNP_IRQ_TRANSLATION_FAILED,
    ERROR_PNP_INVALID_ID,
    ERROR_WAKE_SYSTEM_DEBUGGER,
    ERROR_HANDLES_CLOSED,
    ERROR_EXTRANEOUS_INFORMATION,
    ERROR_RXACT_COMMIT_NECESSARY,
    ERROR_MEDIA_CHECK,
    ERROR_GUID_SUBSTITUTION_MADE,
    ERROR_STOPPED_ON_SYMLINK,
    ERROR_LONGJUMP,
    ERROR_PLUGPLAY_QUERY_VETOED,
    ERROR_UNWIND_CONSOLIDATE,
    ERROR_REGISTRY_HIVE_RECOVERED,
    ERROR_DLL_MIGHT_BE_INSECURE,
    ERROR_DLL_MIGHT_BE_INCOMPATIBLE,
    ERROR_DBG_EXCEPTION_NOT_HANDLED,
    ERROR_DBG_REPLY_LATER,
    ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE,
    ERROR_DBG_TERMINATE_THREAD,
    ERROR_DBG_TERMINATE_PROCESS,
    ERROR_DBG_CONTROL_C,
    ERROR_DBG_PRINTEXCEPTION_C,
    ERROR_DBG_RIPEXCEPTION,
    ERROR_DBG_CONTROL_BREAK,
    ERROR_DBG_COMMAND_EXCEPTION,
    ERROR_OBJECT_NAME_EXISTS,
    ERROR_THREAD_WAS_SUSPENDED,
    ERROR_IMAGE_NOT_AT_BASE,
    ERROR_RXACT_STATE_CREATED,
    ERROR_SEGMENT_NOTIFICATION,
    ERROR_BAD_CURRENT_DIRECTORY,
    ERROR_FT_READ_RECOVERY_FROM_BACKUP,
    ERROR_FT_WRITE_RECOVERY,
    ERROR_IMAGE_MACHINE_TYPE_MISMATCH,
    ERROR_RECEIVE_PARTIAL,
    ERROR_RECEIVE_EXPEDITED,
    ERROR_RECEIVE_PARTIAL_EXPEDITED,
    ERROR_EVENT_DONE,
    ERROR_EVENT_PENDING,
    ERROR_CHECKING_FILE_SYSTEM,
    ERROR_FATAL_APP_EXIT,
    ERROR_PREDEFINED_HANDLE,
    ERROR_WAS_UNLOCKED,
    ERROR_SERVICE_NOTIFICATION,
    ERROR_WAS_LOCKED,
    ERROR_LOG_HARD_ERROR,
    ERROR_ALREADY_WIN32,
    ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE,
    ERROR_NO_YIELD_PERFORMED,
    ERROR_TIMER_RESUME_IGNORED,
    ERROR_ARBITRATION_UNHANDLED,
    ERROR_CARDBUS_NOT_SUPPORTED,
    ERROR_MP_PROCESSOR_MISMATCH,
    ERROR_HIBERNATED,
    ERROR_RESUME_HIBERNATION,
    ERROR_FIRMWARE_UPDATED,
    ERROR_DRIVERS_LEAKING_LOCKED_PAGES,
    ERROR_WAKE_SYSTEM,
    ERROR_WAIT_1,
    ERROR_WAIT_2,
    ERROR_WAIT_3,
    ERROR_WAIT_63,
    ERROR_ABANDONED_WAIT_0,
    ERROR_ABANDONED_WAIT_63,
    ERROR_USER_APC,
    ERROR_KERNEL_APC,
    ERROR_ALERTED,
    ERROR_ELEVATION_REQUIRED,
    ERROR_REPARSE,
    ERROR_OPLOCK_BREAK_IN_PROGRESS,
    ERROR_VOLUME_MOUNTED,
    ERROR_RXACT_COMMITTED,
    ERROR_NOTIFY_CLEANUP,
    ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED,
    ERROR_PAGE_FAULT_TRANSITION,
    ERROR_PAGE_FAULT_DEMAND_ZERO,
    ERROR_PAGE_FAULT_COPY_ON_WRITE,
    ERROR_PAGE_FAULT_GUARD_PAGE,
    ERROR_PAGE_FAULT_PAGING_FILE,
    ERROR_CACHE_PAGE_LOCKED,
    ERROR_CRASH_DUMP,
    ERROR_BUFFER_ALL_ZEROS,
    ERROR_REPARSE_OBJECT,
    ERROR_RESOURCE_REQUIREMENTS_CHANGED,
    ERROR_TRANSLATION_COMPLETE,
    ERROR_NOTHING_TO_TERMINATE,
    ERROR_PROCESS_NOT_IN_JOB,
    ERROR_PROCESS_IN_JOB,
    ERROR_VOLSNAP_HIBERNATE_READY,
    ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY,
    ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED,
    ERROR_INTERRUPT_STILL_CONNECTED,
    ERROR_WAIT_FOR_OPLOCK,
    ERROR_DBG_EXCEPTION_HANDLED,
    ERROR_DBG_CONTINUE,
    ERROR_CALLBACK_POP_STACK,
    ERROR_COMPRESSION_DISABLED,
    ERROR_CANTFETCHBACKWARDS,
    ERROR_CANTSCROLLBACKWARDS,
    ERROR_ROWSNOTRELEASED,
    ERROR_BAD_ACCESSOR_FLAGS,
    ERROR_ERRORS_ENCOUNTERED,
    ERROR_NOT_CAPABLE,
    ERROR_REQUEST_OUT_OF_SEQUENCE,
    ERROR_VERSION_PARSE_ERROR,
    ERROR_BADSTARTPOSITION,
    ERROR_MEMORY_HARDWARE,
    ERROR_DISK_REPAIR_DISABLED,
    ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE,
    ERROR_SYSTEM_POWERSTATE_TRANSITION,
    ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION,
    ERROR_MCA_EXCEPTION,
    ERROR_ACCESS_AUDIT_BY_POLICY,
    ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY,
    ERROR_ABANDON_HIBERFILE,
    ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED,
    ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR,
    ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR,
    ERROR_BAD_MCFG_TABLE,
    ERROR_DISK_REPAIR_REDIRECTED,
    ERROR_DISK_REPAIR_UNSUCCESSFUL,
    ERROR_CORRUPT_LOG_OVERFULL,
    ERROR_CORRUPT_LOG_CORRUPTED,
    ERROR_CORRUPT_LOG_UNAVAILABLE,
    ERROR_CORRUPT_LOG_DELETED_FULL,
    ERROR_CORRUPT_LOG_CLEARED,
    ERROR_ORPHAN_NAME_EXHAUSTED,
    ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE,
    ERROR_CANNOT_GRANT_REQUESTED_OPLOCK,
    ERROR_CANNOT_BREAK_OPLOCK,
    ERROR_OPLOCK_HANDLE_CLOSED,
    ERROR_NO_ACE_CONDITION,
    ERROR_INVALID_ACE_CONDITION,
    ERROR_FILE_HANDLE_REVOKED,
    ERROR_IMAGE_AT_DIFFERENT_BASE,
    ERROR_ENCRYPTED_IO_NOT_POSSIBLE,
    ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS,
    ERROR_QUOTA_ACTIVITY,
    ERROR_HANDLE_REVOKED,
    ERROR_CALLBACK_INVOKE_INLINE,
    ERROR_CPU_SET_INVALID,
    ERROR_ENCLAVE_NOT_TERMINATED,
    ERROR_ENCLAVE_VIOLATION,
    ERROR_SERVER_TRANSPORT_CONFLICT,
    ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT,
    ERROR_FT_READ_FROM_COPY_FAILURE,
    ERROR_SECTION_DIRECT_MAP_ONLY,
    ERROR_EA_ACCESS_DENIED,
    ERROR_OPERATION_ABORTED,
    ERROR_IO_INCOMPLETE,
    ERROR_IO_PENDING,
    ERROR_NOACCESS,
    ERROR_SWAPERROR,
    ERROR_STACK_OVERFLOW,
    ERROR_INVALID_MESSAGE,
    ERROR_CAN_NOT_COMPLETE,
    ERROR_INVALID_FLAGS,
    ERROR_UNRECOGNIZED_VOLUME,
    ERROR_FILE_INVALID,
    ERROR_FULLSCREEN_MODE,
    ERROR_NO_TOKEN,
    ERROR_BADDB,
    ERROR_BADKEY,
    ERROR_CANTOPEN,
    ERROR_CANTREAD,
    ERROR_CANTWRITE,
    ERROR_REGISTRY_RECOVERED,
    ERROR_REGISTRY_CORRUPT,
    ERROR_REGISTRY_IO_FAILED,
    ERROR_NOT_REGISTRY_FILE,
    ERROR_KEY_DELETED,
    ERROR_NO_LOG_SPACE,
    ERROR_KEY_HAS_CHILDREN,
    ERROR_CHILD_MUST_BE_VOLATILE,
    ERROR_NOTIFY_ENUM_DIR,
    ERROR_DEPENDENT_SERVICES_RUNNING,
    ERROR_INVALID_SERVICE_CONTROL,
    ERROR_SERVICE_REQUEST_TIMEOUT,
    ERROR_SERVICE_NO_THREAD,
    ERROR_SERVICE_DATABASE_LOCKED,
    ERROR_SERVICE_ALREADY_RUNNING,
    ERROR_INVALID_SERVICE_ACCOUNT,
    ERROR_SERVICE_DISABLED,
    ERROR_CIRCULAR_DEPENDENCY,
    ERROR_SERVICE_DOES_NOT_EXIST,
    ERROR_SERVICE_CANNOT_ACCEPT_CTRL,
    ERROR_SERVICE_NOT_ACTIVE,
    ERROR_FAILED_SERVICE_CONTROLLER_CONNECT,
    ERROR_EXCEPTION_IN_SERVICE,
    ERROR_DATABASE_DOES_NOT_EXIST,
    ERROR_SERVICE_SPECIFIC_ERROR,
    ERROR_PROCESS_ABORTED,
    ERROR_SERVICE_DEPENDENCY_FAIL,
    ERROR_SERVICE_LOGON_FAILED,
    ERROR_SERVICE_START_HANG,
    ERROR_INVALID_SERVICE_LOCK,
    ERROR_SERVICE_MARKED_FOR_DELETE,
    ERROR_SERVICE_EXISTS,
    ERROR_ALREADY_RUNNING_LKG,
    ERROR_SERVICE_DEPENDENCY_DELETED,
    ERROR_BOOT_ALREADY_ACCEPTED,
    ERROR_SERVICE_NEVER_STARTED,
    ERROR_DUPLICATE_SERVICE_NAME,
    ERROR_DIFFERENT_SERVICE_ACCOUNT,
    ERROR_CANNOT_DETECT_DRIVER_FAILURE,
    ERROR_CANNOT_DETECT_PROCESS_ABORT,
    ERROR_NO_RECOVERY_PROGRAM,
    ERROR_SERVICE_NOT_IN_EXE,
    ERROR_NOT_SAFEBOOT_SERVICE,
    ERROR_END_OF_MEDIA,
    ERROR_FILEMARK_DETECTED,
    ERROR_BEGINNING_OF_MEDIA,
    ERROR_SETMARK_DETECTED,
    ERROR_NO_DATA_DETECTED,
    ERROR_PARTITION_FAILURE,
    ERROR_INVALID_BLOCK_LENGTH,
    ERROR_DEVICE_NOT_PARTITIONED,
    ERROR_UNABLE_TO_LOCK_MEDIA,
    ERROR_UNABLE_TO_UNLOAD_MEDIA,
    ERROR_MEDIA_CHANGED,
    ERROR_BUS_RESET,
    ERROR_NO_MEDIA_IN_DRIVE,
    ERROR_NO_UNICODE_TRANSLATION,
    ERROR_DLL_INIT_FAILED,
    ERROR_SHUTDOWN_IN_PROGRESS,
    ERROR_NO_SHUTDOWN_IN_PROGRESS,
    ERROR_IO_DEVICE,
    ERROR_SERIAL_NO_DEVICE,
    ERROR_IRQ_BUSY,
    ERROR_MORE_WRITES,
    ERROR_COUNTER_TIMEOUT,
    ERROR_FLOPPY_ID_MARK_NOT_FOUND,
    ERROR_FLOPPY_WRONG_CYLINDER,
    ERROR_FLOPPY_UNKNOWN_ERROR,
    ERROR_FLOPPY_BAD_REGISTERS,
    ERROR_DISK_RECALIBRATE_FAILED,
    ERROR_DISK_OPERATION_FAILED,
    ERROR_DISK_RESET_FAILED,
    ERROR_EOM_OVERFLOW,
    ERROR_NOT_ENOUGH_SERVER_MEMORY,
    ERROR_POSSIBLE_DEADLOCK,
    ERROR_MAPPED_ALIGNMENT,
    ERROR_SET_POWER_STATE_VETOED,
    ERROR_SET_POWER_STATE_FAILED,
    ERROR_TOO_MANY_LINKS,
    ERROR_OLD_WIN_VERSION,
    ERROR_APP_WRONG_OS,
    ERROR_SINGLE_INSTANCE_APP,
    ERROR_RMODE_APP,
    ERROR_INVALID_DLL,
    ERROR_NO_ASSOCIATION,
    ERROR_DDE_FAIL,
    ERROR_DLL_NOT_FOUND,
    ERROR_NO_MORE_USER_HANDLES,
    ERROR_MESSAGE_SYNC_ONLY,
    ERROR_SOURCE_ELEMENT_EMPTY,
    ERROR_DESTINATION_ELEMENT_FULL,
    ERROR_ILLEGAL_ELEMENT_ADDRESS,
    ERROR_MAGAZINE_NOT_PRESENT,
    ERROR_DEVICE_REINITIALIZATION_NEEDED,
    ERROR_DEVICE_REQUIRES_CLEANING,
    ERROR_DEVICE_DOOR_OPEN,
    ERROR_DEVICE_NOT_CONNECTED,
    ERROR_NOT_FOUND,
    E_PROP_ID_UNSUPPORTED,
    ERROR_NO_MATCH,
    ERROR_SET_NOT_FOUND,
    E_PROP_SET_UNSUPPORTED,
    ERROR_POINT_NOT_FOUND,
    ERROR_NO_TRACKING_SERVICE,
    ERROR_NO_VOLUME_ID,
    ERROR_UNABLE_TO_REMOVE_REPLACED,
    ERROR_UNABLE_TO_MOVE_REPLACEMENT,
    ERROR_UNABLE_TO_MOVE_REPLACEMENT_2,
    ERROR_JOURNAL_DELETE_IN_PROGRESS,
    ERROR_JOURNAL_NOT_ACTIVE,
    ERROR_POTENTIAL_FILE_FOUND,
    ERROR_JOURNAL_ENTRY_DELETED,
    ERROR_VRF_CFG_ENABLED,
    ERROR_PARTITION_TERMINATING,
    ERROR_SHUTDOWN_IS_SCHEDULED,
    ERROR_SHUTDOWN_USERS_LOGGED_ON,
    ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE,
    ERROR_BAD_DEVICE,
    ERROR_CONNECTION_UNAVAIL,
    ERROR_DEVICE_ALREADY_REMEMBERED,
    ERROR_NO_NET_OR_BAD_PATH,
    ERROR_BAD_PROVIDER,
    ERROR_CANNOT_OPEN_PROFILE,
    ERROR_BAD_PROFILE,
    ERROR_NOT_CONTAINER,
    ERROR_EXTENDED_ERROR,
    ERROR_INVALID_GROUPNAME,
    ERROR_INVALID_COMPUTERNAME,
    ERROR_INVALID_EVENTNAME,
    ERROR_INVALID_DOMAINNAME,
    ERROR_INVALID_SERVICENAME,
    ERROR_INVALID_NETNAME,
    ERROR_INVALID_SHARENAME,
    ERROR_INVALID_PASSWORDNAME,
    ERROR_INVALID_MESSAGENAME,
    ERROR_INVALID_MESSAGEDEST,
    ERROR_SESSION_CREDENTIAL_CONFLICT,
    ERROR_REMOTE_SESSION_LIMIT_EXCEEDED,
    ERROR_DUP_DOMAINNAME,
    ERROR_NO_NETWORK,
    ERROR_CANCELLED,
    ERROR_USER_MAPPED_FILE,
    ERROR_CONNECTION_REFUSED,
    ERROR_GRACEFUL_DISCONNECT,
    ERROR_ADDRESS_ALREADY_ASSOCIATED,
    ERROR_ADDRESS_NOT_ASSOCIATED,
    ERROR_CONNECTION_INVALID,
    ERROR_CONNECTION_ACTIVE,
    ERROR_NETWORK_UNREACHABLE,
    ERROR_HOST_UNREACHABLE,
    ERROR_PROTOCOL_UNREACHABLE,
    ERROR_PORT_UNREACHABLE,
    ERROR_REQUEST_ABORTED,
    ERROR_CONNECTION_ABORTED,
    ERROR_RETRY,
    ERROR_CONNECTION_COUNT_LIMIT,
    ERROR_LOGIN_TIME_RESTRICTION,
    ERROR_LOGIN_WKSTA_RESTRICTION,
    ERROR_INCORRECT_ADDRESS,
    ERROR_ALREADY_REGISTERED,
    ERROR_SERVICE_NOT_FOUND,
    ERROR_NOT_AUTHENTICATED,
    ERROR_NOT_LOGGED_ON,
    ERROR_CONTINUE,
    ERROR_ALREADY_INITIALIZED,
    ERROR_NO_MORE_DEVICES,
    ERROR_NO_SUCH_SITE,
    ERROR_DOMAIN_CONTROLLER_EXISTS,
    ERROR_ONLY_IF_CONNECTED,
    ERROR_OVERRIDE_NOCHANGES,
    ERROR_BAD_USER_PROFILE,
    ERROR_NOT_SUPPORTED_ON_SBS,
    ERROR_SERVER_SHUTDOWN_IN_PROGRESS,
    ERROR_HOST_DOWN,
    ERROR_NON_ACCOUNT_SID,
    ERROR_NON_DOMAIN_SID,
    ERROR_APPHELP_BLOCK,
    ERROR_ACCESS_DISABLED_BY_POLICY,
    ERROR_REG_NAT_CONSUMPTION,
    ERROR_CSCSHARE_OFFLINE,
    ERROR_PKINIT_FAILURE,
    ERROR_SMARTCARD_SUBSYSTEM_FAILURE,
    ERROR_DOWNGRADE_DETECTED,
    ERROR_MACHINE_LOCKED,
    ERROR_SMB_GUEST_LOGON_BLOCKED,
    ERROR_CALLBACK_SUPPLIED_INVALID_DATA,
    ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED,
    ERROR_DRIVER_BLOCKED,
    ERROR_INVALID_IMPORT_OF_NON_DLL,
    ERROR_ACCESS_DISABLED_WEBBLADE,
    ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER,
    ERROR_RECOVERY_FAILURE,
    ERROR_ALREADY_FIBER,
    ERROR_ALREADY_THREAD,
    ERROR_STACK_BUFFER_OVERRUN,
    ERROR_PARAMETER_QUOTA_EXCEEDED,
    ERROR_DEBUGGER_INACTIVE,
    ERROR_DELAY_LOAD_FAILED,
    ERROR_VDM_DISALLOWED,
    ERROR_UNIDENTIFIED_ERROR,
    ERROR_INVALID_CRUNTIME_PARAMETER,
    ERROR_BEYOND_VDL,
    ERROR_INCOMPATIBLE_SERVICE_SID_TYPE,
    ERROR_DRIVER_PROCESS_TERMINATED,
    ERROR_IMPLEMENTATION_LIMIT,
    ERROR_PROCESS_IS_PROTECTED,
    ERROR_SERVICE_NOTIFY_CLIENT_LAGGING,
    ERROR_DISK_QUOTA_EXCEEDED,
    ERROR_CONTENT_BLOCKED,
    ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE,
    ERROR_APP_HANG,
    ERROR_INVALID_LABEL,
    ERROR_NOT_ALL_ASSIGNED,
    ERROR_SOME_NOT_MAPPED,
    ERROR_NO_QUOTAS_FOR_ACCOUNT,
    ERROR_LOCAL_USER_SESSION_KEY,
    ERROR_NULL_LM_PASSWORD,
    ERROR_UNKNOWN_REVISION,
    ERROR_REVISION_MISMATCH,
    ERROR_INVALID_OWNER,
    ERROR_INVALID_PRIMARY_GROUP,
    ERROR_NO_IMPERSONATION_TOKEN,
    ERROR_CANT_DISABLE_MANDATORY,
    ERROR_NO_LOGON_SERVERS,
    ERROR_NO_SUCH_LOGON_SESSION,
    ERROR_NO_SUCH_PRIVILEGE,
    ERROR_PRIVILEGE_NOT_HELD,
    ERROR_INVALID_ACCOUNT_NAME,
    ERROR_USER_EXISTS,
    ERROR_NO_SUCH_USER,
    ERROR_GROUP_EXISTS,
    ERROR_NO_SUCH_GROUP,
    ERROR_MEMBER_IN_GROUP,
    ERROR_MEMBER_NOT_IN_GROUP,
    ERROR_LAST_ADMIN,
    ERROR_WRONG_PASSWORD,
    ERROR_ILL_FORMED_PASSWORD,
    ERROR_PASSWORD_RESTRICTION,
    ERROR_LOGON_FAILURE,
    ERROR_ACCOUNT_RESTRICTION,
    ERROR_INVALID_LOGON_HOURS,
    ERROR_INVALID_WORKSTATION,
    ERROR_PASSWORD_EXPIRED,
    ERROR_ACCOUNT_DISABLED,
    ERROR_NONE_MAPPED,
    ERROR_TOO_MANY_LUIDS_REQUESTED,
    ERROR_LUIDS_EXHAUSTED,
    ERROR_INVALID_SUB_AUTHORITY,
    ERROR_INVALID_ACL,
    ERROR_INVALID_SID,
    ERROR_INVALID_SECURITY_DESCR,
    ERROR_BAD_INHERITANCE_ACL,
    ERROR_SERVER_DISABLED,
    ERROR_SERVER_NOT_DISABLED,
    ERROR_INVALID_ID_AUTHORITY,
    ERROR_ALLOTTED_SPACE_EXCEEDED,
    ERROR_INVALID_GROUP_ATTRIBUTES,
    ERROR_BAD_IMPERSONATION_LEVEL,
    ERROR_CANT_OPEN_ANONYMOUS,
    ERROR_BAD_VALIDATION_CLASS,
    ERROR_BAD_TOKEN_TYPE,
    ERROR_NO_SECURITY_ON_OBJECT,
    ERROR_CANT_ACCESS_DOMAIN_INFO,
    ERROR_INVALID_SERVER_STATE,
    ERROR_INVALID_DOMAIN_STATE,
    ERROR_INVALID_DOMAIN_ROLE,
    ERROR_NO_SUCH_DOMAIN,
    ERROR_DOMAIN_EXISTS,
    ERROR_DOMAIN_LIMIT_EXCEEDED,
    ERROR_INTERNAL_DB_CORRUPTION,
    ERROR_INTERNAL_ERROR,
    ERROR_GENERIC_NOT_MAPPED,
    ERROR_BAD_DESCRIPTOR_FORMAT,
    ERROR_NOT_LOGON_PROCESS,
    ERROR_LOGON_SESSION_EXISTS,
    ERROR_NO_SUCH_PACKAGE,
    ERROR_BAD_LOGON_SESSION_STATE,
    ERROR_LOGON_SESSION_COLLISION,
    ERROR_INVALID_LOGON_TYPE,
    ERROR_CANNOT_IMPERSONATE,
    ERROR_RXACT_INVALID_STATE,
    ERROR_RXACT_COMMIT_FAILURE,
    ERROR_SPECIAL_ACCOUNT,
    ERROR_SPECIAL_GROUP,
    ERROR_SPECIAL_USER,
    ERROR_MEMBERS_PRIMARY_GROUP,
    ERROR_TOKEN_ALREADY_IN_USE,
    ERROR_NO_SUCH_ALIAS,
    ERROR_MEMBER_NOT_IN_ALIAS,
    ERROR_MEMBER_IN_ALIAS,
    ERROR_ALIAS_EXISTS,
    ERROR_LOGON_NOT_GRANTED,
    ERROR_TOO_MANY_SECRETS,
    ERROR_SECRET_TOO_LONG,
    ERROR_INTERNAL_DB_ERROR,
    ERROR_TOO_MANY_CONTEXT_IDS,
    ERROR_LOGON_TYPE_NOT_GRANTED,
    ERROR_NT_CROSS_ENCRYPTION_REQUIRED,
    ERROR_NO_SUCH_MEMBER,
    ERROR_INVALID_MEMBER,
    ERROR_TOO_MANY_SIDS,
    ERROR_LM_CROSS_ENCRYPTION_REQUIRED,
    ERROR_NO_INHERITANCE,
    ERROR_FILE_CORRUPT,
    ERROR_DISK_CORRUPT,
    ERROR_NO_USER_SESSION_KEY,
    ERROR_LICENSE_QUOTA_EXCEEDED,
    ERROR_WRONG_TARGET_NAME,
    ERROR_MUTUAL_AUTH_FAILED,
    ERROR_TIME_SKEW,
    ERROR_CURRENT_DOMAIN_NOT_ALLOWED,
    ERROR_INVALID_WINDOW_HANDLE,
    ERROR_INVALID_MENU_HANDLE,
    ERROR_INVALID_CURSOR_HANDLE,
    ERROR_INVALID_ACCEL_HANDLE,
    ERROR_INVALID_HOOK_HANDLE,
    ERROR_INVALID_DWP_HANDLE,
    ERROR_TLW_WITH_WSCHILD,
    ERROR_CANNOT_FIND_WND_CLASS,
    ERROR_WINDOW_OF_OTHER_THREAD,
    ERROR_HOTKEY_ALREADY_REGISTERED,
    ERROR_CLASS_ALREADY_EXISTS,
    ERROR_CLASS_DOES_NOT_EXIST,
    ERROR_CLASS_HAS_WINDOWS,
    ERROR_INVALID_INDEX,
    ERROR_INVALID_ICON_HANDLE,
    ERROR_PRIVATE_DIALOG_INDEX,
    ERROR_LISTBOX_ID_NOT_FOUND,
    ERROR_NO_WILDCARD_CHARACTERS,
    ERROR_CLIPBOARD_NOT_OPEN,
    ERROR_HOTKEY_NOT_REGISTERED,
    ERROR_WINDOW_NOT_DIALOG,
    ERROR_CONTROL_ID_NOT_FOUND,
    ERROR_INVALID_COMBOBOX_MESSAGE,
    ERROR_WINDOW_NOT_COMBOBOX,
    ERROR_INVALID_EDIT_HEIGHT,
    ERROR_DC_NOT_FOUND,
    ERROR_INVALID_HOOK_FILTER,
    ERROR_INVALID_FILTER_PROC,
    ERROR_HOOK_NEEDS_HMOD,
    ERROR_GLOBAL_ONLY_HOOK,
    ERROR_JOURNAL_HOOK_SET,
    ERROR_HOOK_NOT_INSTALLED,
    ERROR_INVALID_LB_MESSAGE,
    ERROR_SETCOUNT_ON_BAD_LB,
    ERROR_LB_WITHOUT_TABSTOPS,
    ERROR_DESTROY_OBJECT_OF_OTHER_THREAD,
    ERROR_CHILD_WINDOW_MENU,
    ERROR_NO_SYSTEM_MENU,
    ERROR_INVALID_MSGBOX_STYLE,
    ERROR_INVALID_SPI_VALUE,
    ERROR_SCREEN_ALREADY_LOCKED,
    ERROR_HWNDS_HAVE_DIFF_PARENT,
    ERROR_NOT_CHILD_WINDOW,
    ERROR_INVALID_GW_COMMAND,
    ERROR_INVALID_THREAD_ID,
    ERROR_NON_MDICHILD_WINDOW,
    ERROR_POPUP_ALREADY_ACTIVE,
    ERROR_NO_SCROLLBARS,
    ERROR_INVALID_SCROLLBAR_RANGE,
    ERROR_INVALID_SHOWWIN_COMMAND,
    ERROR_NO_SYSTEM_RESOURCES,
    ERROR_NONPAGED_SYSTEM_RESOURCES,
    ERROR_PAGED_SYSTEM_RESOURCES,
    ERROR_WORKING_SET_QUOTA,
    ERROR_PAGEFILE_QUOTA,
    ERROR_COMMITMENT_LIMIT,
    ERROR_MENU_ITEM_NOT_FOUND,
    ERROR_INVALID_KEYBOARD_HANDLE,
    ERROR_HOOK_TYPE_NOT_ALLOWED,
    ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION,
    ERROR_TIMEOUT,
    E_TIMEOUT,
    ERROR_INVALID_MONITOR_HANDLE,
    ERROR_INCORRECT_SIZE,
    ERROR_SYMLINK_CLASS_DISABLED,
    ERROR_SYMLINK_NOT_SUPPORTED,
    ERROR_XML_PARSE_ERROR,
    ERROR_XMLDSIG_ERROR,
    ERROR_RESTART_APPLICATION,
    ERROR_WRONG_COMPARTMENT,
    ERROR_AUTHIP_FAILURE,
    ERROR_NO_NVRAM_RESOURCES,
    ERROR_NOT_GUI_PROCESS,
    ERROR_EVENTLOG_FILE_CORRUPT,
    ERROR_EVENTLOG_CANT_START,
    ERROR_LOG_FILE_FULL,
    ERROR_EVENTLOG_FILE_CHANGED,
    ERROR_CONTAINER_ASSIGNED,
    ERROR_JOB_NO_CONTAINER,
    ERROR_INVALID_TASK_NAME,
    ERROR_INVALID_TASK_INDEX,
    ERROR_THREAD_ALREADY_IN_TASK,
    ERROR_INSTALL_SERVICE_FAILURE,
    ERROR_INSTALL_USEREXIT,
    ERROR_INSTALL_FAILURE,
    ERROR_INSTALL_SUSPEND,
    ERROR_UNKNOWN_PRODUCT,
    ERROR_UNKNOWN_FEATURE,
    ERROR_UNKNOWN_COMPONENT,
    ERROR_UNKNOWN_PROPERTY,
    ERROR_INVALID_HANDLE_STATE,
    ERROR_BAD_CONFIGURATION,
    ERROR_INDEX_ABSENT,
    ERROR_INSTALL_SOURCE_ABSENT,
    ERROR_INSTALL_PACKAGE_VERSION,
    ERROR_PRODUCT_UNINSTALLED,
    ERROR_BAD_QUERY_SYNTAX,
    ERROR_INVALID_FIELD,
    ERROR_DEVICE_REMOVED,
    ERROR_INSTALL_ALREADY_RUNNING,
    ERROR_INSTALL_PACKAGE_OPEN_FAILED,
    ERROR_INSTALL_PACKAGE_INVALID,
    ERROR_INSTALL_UI_FAILURE,
    ERROR_INSTALL_LOG_FAILURE,
    ERROR_INSTALL_LANGUAGE_UNSUPPORTED,
    ERROR_INSTALL_TRANSFORM_FAILURE,
    ERROR_INSTALL_PACKAGE_REJECTED,
    ERROR_FUNCTION_NOT_CALLED,
    ERROR_FUNCTION_FAILED,
    ERROR_INVALID_TABLE,
    ERROR_DATATYPE_MISMATCH,
    ERROR_UNSUPPORTED_TYPE,
    ERROR_CREATE_FAILED,
    ERROR_INSTALL_TEMP_UNWRITABLE,
    ERROR_INSTALL_PLATFORM_UNSUPPORTED,
    ERROR_INSTALL_NOTUSED,
    ERROR_PATCH_PACKAGE_OPEN_FAILED,
    ERROR_PATCH_PACKAGE_INVALID,
    ERROR_PATCH_PACKAGE_UNSUPPORTED,
    ERROR_PRODUCT_VERSION,
    ERROR_INVALID_COMMAND_LINE,
    ERROR_INSTALL_REMOTE_DISALLOWED,
    ERROR_SUCCESS_REBOOT_INITIATED,
    ERROR_PATCH_TARGET_NOT_FOUND,
    ERROR_PATCH_PACKAGE_REJECTED,
    ERROR_INSTALL_TRANSFORM_REJECTED,
    ERROR_INSTALL_REMOTE_PROHIBITED,
    ERROR_PATCH_REMOVAL_UNSUPPORTED,
    ERROR_UNKNOWN_PATCH,
    ERROR_PATCH_NO_SEQUENCE,
    ERROR_PATCH_REMOVAL_DISALLOWED,
    ERROR_INVALID_PATCH_XML,
    ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT,
    ERROR_INSTALL_SERVICE_SAFEBOOT,
    ERROR_FAIL_FAST_EXCEPTION,
    ERROR_INSTALL_REJECTED,
    ERROR_DYNAMIC_CODE_BLOCKED,
    ERROR_NOT_SAME_OBJECT,
    ERROR_STRICT_CFG_VIOLATION,
    ERROR_STRICT_RFG_VIOLATION,
    ERROR_RFG_ACCESS_VIOLATION,
    ERROR_SET_CONTEXT_DENIED,
    ERROR_CROSS_PARTITION_VIOLATION,
    ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT,
    RPC_S_INVALID_STRING_BINDING,
    RPC_S_WRONG_KIND_OF_BINDING,
    RPC_S_INVALID_BINDING,
    RPC_S_PROTSEQ_NOT_SUPPORTED,
    RPC_S_INVALID_RPC_PROTSEQ,
    RPC_S_INVALID_STRING_UUID,
    RPC_S_INVALID_ENDPOINT_FORMAT,
    RPC_S_INVALID_NET_ADDR,
    RPC_S_NO_ENDPOINT_FOUND,
    RPC_S_INVALID_TIMEOUT,
    RPC_S_OBJECT_NOT_FOUND,
    RPC_S_ALREADY_REGISTERED,
    RPC_S_TYPE_ALREADY_REGISTERED,
    RPC_S_ALREADY_LISTENING,
    RPC_S_NO_PROTSEQS_REGISTERED,
    RPC_S_NOT_LISTENING,
    RPC_S_UNKNOWN_MGR_TYPE,
    RPC_S_UNKNOWN_IF,
    RPC_S_NO_BINDINGS,
    RPC_S_NO_PROTSEQS,
    RPC_S_CANT_CREATE_ENDPOINT,
    RPC_S_OUT_OF_RESOURCES,
    RPC_S_SERVER_UNAVAILABLE,
    RPC_S_SERVER_TOO_BUSY,
    RPC_S_INVALID_NETWORK_OPTIONS,
    RPC_S_NO_CALL_ACTIVE,
    RPC_S_CALL_FAILED,
    RPC_S_CALL_FAILED_DNE,
    RPC_S_PROTOCOL_ERROR,
    RPC_S_PROXY_ACCESS_DENIED,
    RPC_S_UNSUPPORTED_TRANS_SYN,
    RPC_S_UNSUPPORTED_TYPE,
    RPC_S_INVALID_TAG,
    RPC_S_INVALID_BOUND,
    RPC_S_NO_ENTRY_NAME,
    RPC_S_INVALID_NAME_SYNTAX,
    RPC_S_UNSUPPORTED_NAME_SYNTAX,
    RPC_S_UUID_NO_ADDRESS,
    RPC_S_DUPLICATE_ENDPOINT,
    RPC_S_UNKNOWN_AUTHN_TYPE,
    RPC_S_MAX_CALLS_TOO_SMALL,
    RPC_S_STRING_TOO_LONG,
    RPC_S_PROTSEQ_NOT_FOUND,
    RPC_S_PROCNUM_OUT_OF_RANGE,
    RPC_S_BINDING_HAS_NO_AUTH,
    RPC_S_UNKNOWN_AUTHN_SERVICE,
    RPC_S_UNKNOWN_AUTHN_LEVEL,
    RPC_S_INVALID_AUTH_IDENTITY,
    RPC_S_UNKNOWN_AUTHZ_SERVICE,
    EPT_S_INVALID_ENTRY,
    EPT_S_CANT_PERFORM_OP,
    EPT_S_NOT_REGISTERED,
    RPC_S_NOTHING_TO_EXPORT,
    RPC_S_INCOMPLETE_NAME,
    RPC_S_INVALID_VERS_OPTION,
    RPC_S_NO_MORE_MEMBERS,
    RPC_S_NOT_ALL_OBJS_UNEXPORTED,
    RPC_S_INTERFACE_NOT_FOUND,
    RPC_S_ENTRY_ALREADY_EXISTS,
    RPC_S_ENTRY_NOT_FOUND,
    RPC_S_NAME_SERVICE_UNAVAILABLE,
    RPC_S_INVALID_NAF_ID,
    RPC_S_CANNOT_SUPPORT,
    RPC_S_NO_CONTEXT_AVAILABLE,
    RPC_S_INTERNAL_ERROR,
    RPC_S_ZERO_DIVIDE,
    RPC_S_ADDRESS_ERROR,
    RPC_S_FP_DIV_ZERO,
    RPC_S_FP_UNDERFLOW,
    RPC_S_FP_OVERFLOW,
    RPC_X_NO_MORE_ENTRIES,
    RPC_X_SS_CHAR_TRANS_OPEN_FAIL,
    RPC_X_SS_CHAR_TRANS_SHORT_FILE,
    RPC_X_SS_IN_NULL_CONTEXT,
    RPC_X_SS_CONTEXT_DAMAGED,
    RPC_X_SS_HANDLES_MISMATCH,
    RPC_X_SS_CANNOT_GET_CALL_HANDLE,
    RPC_X_NULL_REF_POINTER,
    RPC_X_ENUM_VALUE_OUT_OF_RANGE,
    RPC_X_BYTE_COUNT_TOO_SMALL,
    RPC_X_BAD_STUB_DATA,
    ERROR_INVALID_USER_BUFFER,
    ERROR_UNRECOGNIZED_MEDIA,
    ERROR_NO_TRUST_LSA_SECRET,
    ERROR_NO_TRUST_SAM_ACCOUNT,
    ERROR_TRUSTED_DOMAIN_FAILURE,
    ERROR_TRUSTED_RELATIONSHIP_FAILURE,
    ERROR_TRUST_FAILURE,
    RPC_S_CALL_IN_PROGRESS,
    ERROR_NETLOGON_NOT_STARTED,
    ERROR_ACCOUNT_EXPIRED,
    ERROR_REDIRECTOR_HAS_OPEN_HANDLES,
    ERROR_PRINTER_DRIVER_ALREADY_INSTALLED,
    ERROR_UNKNOWN_PORT,
    ERROR_UNKNOWN_PRINTER_DRIVER,
    ERROR_UNKNOWN_PRINTPROCESSOR,
    ERROR_INVALID_SEPARATOR_FILE,
    ERROR_INVALID_PRIORITY,
    ERROR_INVALID_PRINTER_NAME,
    ERROR_PRINTER_ALREADY_EXISTS,
    ERROR_INVALID_PRINTER_COMMAND,
    ERROR_INVALID_DATATYPE,
    ERROR_INVALID_ENVIRONMENT,
    RPC_S_NO_MORE_BINDINGS,
    ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT,
    ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT,
    ERROR_NOLOGON_SERVER_TRUST_ACCOUNT,
    ERROR_DOMAIN_TRUST_INCONSISTENT,
    ERROR_SERVER_HAS_OPEN_HANDLES,
    ERROR_RESOURCE_DATA_NOT_FOUND,
    ERROR_RESOURCE_TYPE_NOT_FOUND,
    ERROR_RESOURCE_NAME_NOT_FOUND,
    ERROR_RESOURCE_LANG_NOT_FOUND,
    ERROR_NOT_ENOUGH_QUOTA,
    RPC_S_NO_INTERFACES,
    RPC_S_CALL_CANCELLED,
    RPC_S_BINDING_INCOMPLETE,
    RPC_S_COMM_FAILURE,
    RPC_S_UNSUPPORTED_AUTHN_LEVEL,
    RPC_S_NO_PRINC_NAME,
    RPC_S_NOT_RPC_ERROR,
    RPC_S_UUID_LOCAL_ONLY,
    RPC_S_SEC_PKG_ERROR,
    RPC_S_NOT_CANCELLED,
    RPC_X_INVALID_ES_ACTION,
    RPC_X_WRONG_ES_VERSION,
    RPC_X_WRONG_STUB_VERSION,
    RPC_X_INVALID_PIPE_OBJECT,
    RPC_X_WRONG_PIPE_ORDER,
    RPC_X_WRONG_PIPE_VERSION,
    RPC_S_COOKIE_AUTH_FAILED,
    RPC_S_DO_NOT_DISTURB,
    RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED,
    RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH,
    RPC_S_GROUP_MEMBER_NOT_FOUND,
    EPT_S_CANT_CREATE,
    RPC_S_INVALID_OBJECT,
    ERROR_INVALID_TIME,
    ERROR_INVALID_FORM_NAME,
    ERROR_INVALID_FORM_SIZE,
    ERROR_ALREADY_WAITING,
    ERROR_PRINTER_DELETED,
    ERROR_INVALID_PRINTER_STATE,
    ERROR_PASSWORD_MUST_CHANGE,
    ERROR_DOMAIN_CONTROLLER_NOT_FOUND,
    ERROR_ACCOUNT_LOCKED_OUT,
    OR_INVALID_OXID,
    OR_INVALID_OID,
    OR_INVALID_SET,
    RPC_S_SEND_INCOMPLETE,
    RPC_S_INVALID_ASYNC_HANDLE,
    RPC_S_INVALID_ASYNC_CALL,
    RPC_X_PIPE_CLOSED,
    RPC_X_PIPE_DISCIPLINE_ERROR,
    RPC_X_PIPE_EMPTY,
    ERROR_NO_SITENAME,
    ERROR_CANT_ACCESS_FILE,
    ERROR_CANT_RESOLVE_FILENAME,
    RPC_S_ENTRY_TYPE_MISMATCH,
    RPC_S_NOT_ALL_OBJS_EXPORTED,
    RPC_S_INTERFACE_NOT_EXPORTED,
    RPC_S_PROFILE_NOT_ADDED,
    RPC_S_PRF_ELT_NOT_ADDED,
    RPC_S_PRF_ELT_NOT_REMOVED,
    RPC_S_GRP_ELT_NOT_ADDED,
    RPC_S_GRP_ELT_NOT_REMOVED,
    ERROR_KM_DRIVER_BLOCKED,
    ERROR_CONTEXT_EXPIRED,
    ERROR_PER_USER_TRUST_QUOTA_EXCEEDED,
    ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED,
    ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED,
    ERROR_AUTHENTICATION_FIREWALL_FAILED,
    ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED,
    ERROR_NTLM_BLOCKED,
    ERROR_PASSWORD_CHANGE_REQUIRED,
    ERROR_LOST_MODE_LOGON_RESTRICTION,
    ERROR_INVALID_PIXEL_FORMAT,
    ERROR_BAD_DRIVER,
    ERROR_INVALID_WINDOW_STYLE,
    ERROR_METAFILE_NOT_SUPPORTED,
    ERROR_TRANSFORM_NOT_SUPPORTED,
    ERROR_CLIPPING_NOT_SUPPORTED,
    ERROR_INVALID_CMM,
    ERROR_INVALID_PROFILE,
    ERROR_TAG_NOT_FOUND,
    ERROR_TAG_NOT_PRESENT,
    ERROR_DUPLICATE_TAG,
    ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE,
    ERROR_PROFILE_NOT_FOUND,
    ERROR_INVALID_COLORSPACE,
    ERROR_ICM_NOT_ENABLED,
    ERROR_DELETING_ICM_XFORM,
    ERROR_INVALID_TRANSFORM,
    ERROR_COLORSPACE_MISMATCH,
    ERROR_INVALID_COLORINDEX,
    ERROR_PROFILE_DOES_NOT_MATCH_DEVICE,
    NERR_NetNotStarted,
    NERR_UnknownServer,
    NERR_ShareMem,
    NERR_NoNetworkResource,
    NERR_RemoteOnly,
    NERR_DevNotRedirected,
    ERROR_CONNECTED_OTHER_PASSWORD,
    ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT,
    NERR_ServerNotStarted,
    NERR_ItemNotFound,
    NERR_UnknownDevDir,
    NERR_RedirectedPath,
    NERR_DuplicateShare,
    NERR_NoRoom,
    NERR_TooManyItems,
    NERR_InvalidMaxUsers,
    NERR_BufTooSmall,
    NERR_RemoteErr,
    NERR_LanmanIniError,
    NERR_NetworkError,
    NERR_WkstaInconsistentState,
    NERR_WkstaNotStarted,
    NERR_BrowserNotStarted,
    NERR_InternalError,
    NERR_BadTransactConfig,
    NERR_InvalidAPI,
    NERR_BadEventName,
    NERR_DupNameReboot,
    NERR_CfgCompNotFound,
    NERR_CfgParamNotFound,
    NERR_LineTooLong,
    NERR_QNotFound,
    NERR_JobNotFound,
    NERR_DestNotFound,
    NERR_DestExists,
    NERR_QExists,
    NERR_QNoRoom,
    NERR_JobNoRoom,
    NERR_DestNoRoom,
    NERR_DestIdle,
    NERR_DestInvalidOp,
    NERR_ProcNoRespond,
    NERR_SpoolerNotLoaded,
    NERR_DestInvalidState,
    NERR_QinvalidState,
    NERR_JobInvalidState,
    NERR_SpoolNoMemory,
    NERR_DriverNotFound,
    NERR_DataTypeInvalid,
    NERR_ProcNotFound,
    NERR_ServiceTableLocked,
    NERR_ServiceTableFull,
    NERR_ServiceInstalled,
    NERR_ServiceEntryLocked,
    NERR_ServiceNotInstalled,
    NERR_BadServiceName,
    NERR_ServiceCtlTimeout,
    NERR_ServiceCtlBusy,
    NERR_BadServiceProgName,
    NERR_ServiceNotCtrl,
    NERR_ServiceKillProc,
    NERR_ServiceCtlNotValid,
    NERR_NotInDispatchTbl,
    NERR_BadControlRecv,
    NERR_ServiceNotStarting,
    NERR_AlreadyLoggedOn,
    NERR_NotLoggedOn,
    ERROR_BAD_USERNAME,
    NERR_BadUsername,
    NERR_BadPassword,
    NERR_UnableToAddName_W,
    NERR_UnableToAddName_F,
    NERR_UnableToDelName_W,
    NERR_UnableToDelName_F,
    NERR_LogonsPaused,
    NERR_LogonServerConflict,
    NERR_LogonNoUserPath,
    NERR_LogonScriptError,
    NERR_StandaloneLogon,
    NERR_LogonServerNotFound,
    NERR_LogonDomainExists,
    NERR_NonValidatedLogon,
    NERR_ACFNotFound,
    NERR_GroupNotFound,
    NERR_UserNotFound,
    NERR_ResourceNotFound,
    NERR_GroupExists,
    NERR_UserExists,
    NERR_ResourceExists,
    NERR_NotPrimary,
    NERR_ACFNotLoaded,
    NERR_ACFNoRoom,
    NERR_ACFFileIOFail,
    NERR_ACFTooManyLists,
    NERR_UserLogon,
    NERR_ACFNoParent,
    NERR_CanNotGrowSegment,
    NERR_SpeGroupOp,
    NERR_NotInCache,
    NERR_UserInGroup,
    NERR_UserNotInGroup,
    NERR_AccountUndefined,
    NERR_AccountExpired,
    NERR_InvalidWorkstation,
    NERR_InvalidLogonHours,
    NERR_PasswordExpired,
    NERR_PasswordCantChange,
    NERR_PasswordHistConflict,
    NERR_PasswordTooShort,
    NERR_PasswordTooRecent,
    NERR_InvalidDatabase,
    NERR_DatabaseUpToDate,
    NERR_SyncRequired,
    ERROR_NOT_CONNECTED,
    NERR_UseNotFound,
    NERR_BadAsgType,
    NERR_DeviceIsShared,
    NERR_NoComputerName,
    NERR_MsgAlreadyStarted,
    NERR_MsgInitFailed,
    NERR_NameNotFound,
    NERR_AlreadyForwarded,
    NERR_AddForwarded,
    NERR_AlreadyExists,
    NERR_TooManyNames,
    NERR_DelComputerName,
    NERR_LocalForward,
    NERR_GrpMsgProcessor,
    NERR_PausedRemote,
    NERR_BadReceive,
    NERR_NameInUse,
    NERR_MsgNotStarted,
    NERR_NotLocalName,
    NERR_NoForwardName,
    NERR_RemoteFull,
    NERR_NameNotForwarded,
    NERR_TruncatedBroadcast,
    NERR_InvalidDevice,
    NERR_WriteFault,
    NERR_DuplicateName,
    NERR_DeleteLater,
    NERR_IncompleteDel,
    NERR_MultipleNets,
    NERR_NetNameNotFound,
    NERR_DeviceNotShared,
    NERR_ClientNameNotFound,
    NERR_FileIdNotFound,
    NERR_ExecFailure,
    NERR_TmpFile,
    NERR_TooMuchData,
    NERR_DeviceShareConflict,
    NERR_BrowserTableIncomplete,
    NERR_NotLocalDomain,
    NERR_IsDfsShare,
    NERR_DevInvalidOpCode,
    NERR_DevNotFound,
    NERR_DevNotOpen,
    NERR_BadQueueDevString,
    NERR_BadQueuePriority,
    NERR_NoCommDevs,
    NERR_QueueNotFound,
    NERR_BadDevString,
    NERR_BadDev,
    NERR_InUseBySpooler,
    NERR_CommDevInUse,
    NERR_InvalidComputer,
    NERR_MaxLenExceeded,
    NERR_BadComponent,
    NERR_CantType,
    NERR_TooManyEntries,
    NERR_ProfileFileTooBig,
    NERR_ProfileOffset,
    NERR_ProfileCleanup,
    NERR_ProfileUnknownCmd,
    NERR_ProfileLoadErr,
    NERR_ProfileSaveErr,
    NERR_LogOverflow,
    NERR_LogFileChanged,
    NERR_LogFileCorrupt,
    NERR_SourceIsDir,
    NERR_BadSource,
    NERR_BadDest,
    NERR_DifferentServers,
    NERR_RunSrvPaused,
    NERR_ErrCommRunSrv,
    NERR_ErrorExecingGhost,
    NERR_ShareNotFound,
    NERR_InvalidLana,
    ERROR_OPEN_FILES,
    NERR_OpenFiles,
    ERROR_ACTIVE_CONNECTIONS,
    NERR_ActiveConns,
    NERR_BadPasswordCore,
    ERROR_DEVICE_IN_USE,
    NERR_DevInUse,
    NERR_LocalDrive,
    NERR_AlertExists,
    NERR_TooManyAlerts,
    NERR_NoSuchAlert,
    NERR_BadRecipient,
    NERR_AcctLimitExceeded,
    NERR_InvalidLogSeek,
    NERR_BadUasConfig,
    NERR_InvalidUASOp,
    NERR_LastAdmin,
    NERR_DCNotFound,
    NERR_LogonTrackingError,
    NERR_NetlogonNotStarted,
    NERR_CanNotGrowUASFile,
    NERR_TimeDiffAtDC,
    NERR_PasswordMismatch,
    NERR_NoSuchServer,
    NERR_NoSuchSession,
    NERR_NoSuchConnection,
    NERR_TooManyServers,
    NERR_TooManySessions,
    NERR_TooManyConnections,
    NERR_TooManyFiles,
    NERR_NoAlternateServers,
    NERR_TryDownLevel,
    NERR_UPSDriverNotStarted,
    NERR_UPSInvalidConfig,
    NERR_UPSInvalidCommPort,
    NERR_UPSSignalAsserted,
    NERR_UPSShutdownFailed,
    NERR_BadDosRetCode,
    NERR_ProgNeedsExtraMem,
    NERR_BadDosFunction,
    NERR_RemoteBootFailed,
    NERR_BadFileCheckSum,
    NERR_NoRplBootSystem,
    NERR_RplLoadrNetBiosErr,
    NERR_RplLoadrDiskErr,
    NERR_ImageParamErr,
    NERR_TooManyImageParams,
    NERR_NonDosFloppyUsed,
    NERR_RplBootRestart,
    NERR_RplSrvrCallFailed,
    NERR_CantConnectRplSrvr,
    NERR_CantOpenImageFile,
    NERR_CallingRplSrvr,
    NERR_StartingRplBoot,
    NERR_RplBootServiceTerm,
    NERR_RplBootStartFailed,
    NERR_RPL_CONNECTED,
    NERR_BrowserConfiguredToNotRun,
    NERR_RplNoAdaptersStarted,
    NERR_RplBadRegistry,
    NERR_RplBadDatabase,
    NERR_RplRplfilesShare,
    NERR_RplNotRplServer,
    NERR_RplCannotEnum,
    NERR_RplWkstaInfoCorrupted,
    NERR_RplWkstaNotFound,
    NERR_RplWkstaNameUnavailable,
    NERR_RplProfileInfoCorrupted,
    NERR_RplProfileNotFound,
    NERR_RplProfileNameUnavailable,
    NERR_RplProfileNotEmpty,
    NERR_RplConfigInfoCorrupted,
    NERR_RplConfigNotFound,
    NERR_RplAdapterInfoCorrupted,
    NERR_RplInternal,
    NERR_RplVendorInfoCorrupted,
    NERR_RplBootInfoCorrupted,
    NERR_RplWkstaNeedsUserAcct,
    NERR_RplNeedsRPLUSERAcct,
    NERR_RplBootNotFound,
    NERR_RplIncompatibleProfile,
    NERR_RplAdapterNameUnavailable,
    NERR_RplConfigNotEmpty,
    NERR_RplBootInUse,
    NERR_RplBackupDatabase,
    NERR_RplAdapterNotFound,
    NERR_RplVendorNotFound,
    NERR_RplVendorNameUnavailable,
    NERR_RplBootNameUnavailable,
    NERR_RplConfigNameUnavailable,
    NERR_DfsInternalCorruption,
    NERR_DfsVolumeDataCorrupt,
    NERR_DfsNoSuchVolume,
    NERR_DfsVolumeAlreadyExists,
    NERR_DfsAlreadyShared,
    NERR_DfsNoSuchShare,
    NERR_DfsNotALeafVolume,
    NERR_DfsLeafVolume,
    NERR_DfsVolumeHasMultipleServers,
    NERR_DfsCantCreateJunctionPoint,
    NERR_DfsServerNotDfsAware,
    NERR_DfsBadRenamePath,
    NERR_DfsVolumeIsOffline,
    NERR_DfsNoSuchServer,
    NERR_DfsCyclicalName,
    NERR_DfsNotSupportedInServerDfs,
    NERR_DfsDuplicateService,
    NERR_DfsCantRemoveLastServerShare,
    NERR_DfsVolumeIsInterDfs,
    NERR_DfsInconsistent,
    NERR_DfsServerUpgraded,
    NERR_DfsDataIsIdentical,
    NERR_DfsCantRemoveDfsRoot,
    NERR_DfsChildOrParentInDfs,
    NERR_DfsInternalError,
    NERR_SetupAlreadyJoined,
    NERR_SetupNotJoined,
    NERR_SetupDomainController,
    NERR_DefaultJoinRequired,
    NERR_InvalidWorkgroupName,
    NERR_NameUsesIncompatibleCodePage,
    NERR_ComputerAccountNotFound,
    NERR_PersonalSku,
    NERR_PasswordMustChange,
    NERR_AccountLockedOut,
    NERR_PasswordTooLong,
    NERR_PasswordNotComplexEnough,
    NERR_PasswordFilterError,
    ERROR_UNKNOWN_PRINT_MONITOR,
    ERROR_PRINTER_DRIVER_IN_USE,
    ERROR_SPOOL_FILE_NOT_FOUND,
    ERROR_SPL_NO_STARTDOC,
    ERROR_SPL_NO_ADDJOB,
    ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED,
    ERROR_PRINT_MONITOR_ALREADY_INSTALLED,
    ERROR_INVALID_PRINT_MONITOR,
    ERROR_PRINT_MONITOR_IN_USE,
    ERROR_PRINTER_HAS_JOBS_QUEUED,
    ERROR_SUCCESS_REBOOT_REQUIRED,
    ERROR_SUCCESS_RESTART_REQUIRED,
    ERROR_PRINTER_NOT_FOUND,
    ERROR_PRINTER_DRIVER_WARNED,
    ERROR_PRINTER_DRIVER_BLOCKED,
    ERROR_PRINTER_DRIVER_PACKAGE_IN_USE,
    ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND,
    ERROR_FAIL_REBOOT_REQUIRED,
    ERROR_FAIL_REBOOT_INITIATED,
    ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED,
    ERROR_PRINT_JOB_RESTART_REQUIRED,
    ERROR_INVALID_PRINTER_DRIVER_MANIFEST,
    ERROR_PRINTER_NOT_SHAREABLE,
    ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1,
    ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED,
    ERROR_REQUEST_PAUSED,
    ERROR_APPEXEC_CONDITION_NOT_SATISFIED,
    ERROR_APPEXEC_HANDLE_INVALIDATED,
    ERROR_APPEXEC_INVALID_HOST_GENERATION,
    ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION,
    ERROR_APPEXEC_INVALID_HOST_STATE,
    ERROR_APPEXEC_NO_DONOR,
    ERROR_APPEXEC_HOST_ID_MISMATCH,
    ERROR_APPEXEC_UNKNOWN_USER,
    ERROR_APPEXEC_APP_COMPAT_BLOCK,
    ERROR_APPEXEC_CALLER_WAIT_TIMEOUT,
    ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION,
    ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING,
    ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES,
    ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED,
    ERROR_VRF_VOLATILE_NOT_STOPPABLE,
    ERROR_VRF_VOLATILE_SAFE_MODE,
    ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM,
    ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS,
    ERROR_VRF_VOLATILE_PROTECTED_DRIVER,
    ERROR_VRF_VOLATILE_NMI_REGISTERED,
    ERROR_VRF_VOLATILE_SETTINGS_CONFLICT,
    ERROR_DIF_IOCALLBACK_NOT_REPLACED,
    ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED,
    ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED,
    ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED,
    ERROR_DIF_VOLATILE_INVALID_INFO,
    ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING,
    ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING,
    ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED,
    ERROR_DIF_VOLATILE_NOT_ALLOWED,
    ERROR_DIF_BINDING_API_NOT_FOUND,
    ERROR_IO_REISSUE_AS_CACHED,
    ERROR_WINS_INTERNAL,
    ERROR_CAN_NOT_DEL_LOCAL_WINS,
    ERROR_STATIC_INIT,
    ERROR_INC_BACKUP,
    ERROR_FULL_BACKUP,
    ERROR_REC_NON_EXISTENT,
    ERROR_RPL_NOT_ALLOWED,
    PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED,
    PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO,
    PEERDIST_ERROR_MISSING_DATA,
    PEERDIST_ERROR_NO_MORE,
    PEERDIST_ERROR_NOT_INITIALIZED,
    PEERDIST_ERROR_ALREADY_INITIALIZED,
    PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS,
    PEERDIST_ERROR_INVALIDATED,
    PEERDIST_ERROR_ALREADY_EXISTS,
    PEERDIST_ERROR_OPERATION_NOTFOUND,
    PEERDIST_ERROR_ALREADY_COMPLETED,
    PEERDIST_ERROR_OUT_OF_BOUNDS,
    PEERDIST_ERROR_VERSION_UNSUPPORTED,
    PEERDIST_ERROR_INVALID_CONFIGURATION,
    PEERDIST_ERROR_NOT_LICENSED,
    PEERDIST_ERROR_SERVICE_UNAVAILABLE,
    PEERDIST_ERROR_TRUST_FAILURE,
    ERROR_DHCP_ADDRESS_CONFLICT,
    ERROR_WMI_GUID_NOT_FOUND,
    ERROR_WMI_INSTANCE_NOT_FOUND,
    ERROR_WMI_ITEMID_NOT_FOUND,
    ERROR_WMI_TRY_AGAIN,
    ERROR_WMI_DP_NOT_FOUND,
    ERROR_WMI_UNRESOLVED_INSTANCE_REF,
    ERROR_WMI_ALREADY_ENABLED,
    ERROR_WMI_GUID_DISCONNECTED,
    ERROR_WMI_SERVER_UNAVAILABLE,
    ERROR_WMI_DP_FAILED,
    ERROR_WMI_INVALID_MOF,
    ERROR_WMI_INVALID_REGINFO,
    ERROR_WMI_ALREADY_DISABLED,
    ERROR_WMI_READ_ONLY,
    ERROR_WMI_SET_FAILURE,
    ERROR_NOT_APPCONTAINER,
    ERROR_APPCONTAINER_REQUIRED,
    ERROR_NOT_SUPPORTED_IN_APPCONTAINER,
    ERROR_INVALID_PACKAGE_SID_LENGTH,
    ERROR_INVALID_MEDIA,
    ERROR_INVALID_LIBRARY,
    ERROR_INVALID_MEDIA_POOL,
    ERROR_DRIVE_MEDIA_MISMATCH,
    ERROR_MEDIA_OFFLINE,
    ERROR_LIBRARY_OFFLINE,
    ERROR_EMPTY,
    ERROR_NOT_EMPTY,
    ERROR_MEDIA_UNAVAILABLE,
    ERROR_RESOURCE_DISABLED,
    ERROR_INVALID_CLEANER,
    ERROR_UNABLE_TO_CLEAN,
    ERROR_OBJECT_NOT_FOUND,
    ERROR_DATABASE_FAILURE,
    ERROR_DATABASE_FULL,
    ERROR_MEDIA_INCOMPATIBLE,
    ERROR_RESOURCE_NOT_PRESENT,
    ERROR_INVALID_OPERATION,
    ERROR_MEDIA_NOT_AVAILABLE,
    ERROR_DEVICE_NOT_AVAILABLE,
    ERROR_REQUEST_REFUSED,
    ERROR_INVALID_DRIVE_OBJECT,
    ERROR_LIBRARY_FULL,
    ERROR_MEDIUM_NOT_ACCESSIBLE,
    ERROR_UNABLE_TO_LOAD_MEDIUM,
    ERROR_UNABLE_TO_INVENTORY_DRIVE,
    ERROR_UNABLE_TO_INVENTORY_SLOT,
    ERROR_UNABLE_TO_INVENTORY_TRANSPORT,
    ERROR_TRANSPORT_FULL,
    ERROR_CONTROLLING_IEPORT,
    ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA,
    ERROR_CLEANER_SLOT_SET,
    ERROR_CLEANER_SLOT_NOT_SET,
    ERROR_CLEANER_CARTRIDGE_SPENT,
    ERROR_UNEXPECTED_OMID,
    ERROR_CANT_DELETE_LAST_ITEM,
    ERROR_MESSAGE_EXCEEDS_MAX_SIZE,
    ERROR_VOLUME_CONTAINS_SYS_FILES,
    ERROR_INDIGENOUS_TYPE,
    ERROR_NO_SUPPORTING_DRIVES,
    ERROR_CLEANER_CARTRIDGE_INSTALLED,
    ERROR_IEPORT_FULL,
    ERROR_FILE_OFFLINE,
    ERROR_REMOTE_STORAGE_NOT_ACTIVE,
    ERROR_REMOTE_STORAGE_MEDIA_ERROR,
    ERROR_NOT_A_REPARSE_POINT,
    ERROR_REPARSE_ATTRIBUTE_CONFLICT,
    ERROR_INVALID_REPARSE_DATA,
    ERROR_REPARSE_TAG_INVALID,
    ERROR_REPARSE_TAG_MISMATCH,
    ERROR_REPARSE_POINT_ENCOUNTERED,
    ERROR_APP_DATA_NOT_FOUND,
    ERROR_APP_DATA_EXPIRED,
    ERROR_APP_DATA_CORRUPT,
    ERROR_APP_DATA_LIMIT_EXCEEDED,
    ERROR_APP_DATA_REBOOT_REQUIRED,
    ERROR_SECUREBOOT_ROLLBACK_DETECTED,
    ERROR_SECUREBOOT_POLICY_VIOLATION,
    ERROR_SECUREBOOT_INVALID_POLICY,
    ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND,
    ERROR_SECUREBOOT_POLICY_NOT_SIGNED,
    ERROR_SECUREBOOT_NOT_ENABLED,
    ERROR_SECUREBOOT_FILE_REPLACED,
    ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED,
    ERROR_SECUREBOOT_POLICY_UNKNOWN,
    ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION,
    ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH,
    ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED,
    ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH,
    ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING,
    ERROR_SECUREBOOT_NOT_BASE_POLICY,
    ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY,
    ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED,
    ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED,
    ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED,
    ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED,
    ERROR_ALREADY_HAS_STREAM_ID,
    ERROR_SMR_GARBAGE_COLLECTION_REQUIRED,
    ERROR_WOF_WIM_HEADER_CORRUPT,
    ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT,
    ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT,
    ERROR_OBJECT_IS_IMMUTABLE,
    ERROR_VOLUME_NOT_SIS_ENABLED,
    ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED,
    ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION,
    ERROR_SYSTEM_INTEGRITY_INVALID_POLICY,
    ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED,
    ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES,
    ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE,
    ERROR_VSM_NOT_INITIALIZED,
    ERROR_VSM_DMA_PROTECTION_NOT_IN_USE,
    ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED,
    ERROR_PLATFORM_MANIFEST_INVALID,
    ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED,
    ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED,
    ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND,
    ERROR_PLATFORM_MANIFEST_NOT_ACTIVE,
    ERROR_PLATFORM_MANIFEST_NOT_SIGNED,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE,
    ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE,
    ERROR_DEPENDENT_RESOURCE_EXISTS,
    ERROR_DEPENDENCY_NOT_FOUND,
    ERROR_DEPENDENCY_ALREADY_EXISTS,
    ERROR_RESOURCE_NOT_ONLINE,
    ERROR_HOST_NODE_NOT_AVAILABLE,
    ERROR_RESOURCE_NOT_AVAILABLE,
    ERROR_RESOURCE_NOT_FOUND,
    ERROR_SHUTDOWN_CLUSTER,
    ERROR_CANT_EVICT_ACTIVE_NODE,
    ERROR_OBJECT_ALREADY_EXISTS,
    ERROR_OBJECT_IN_LIST,
    ERROR_GROUP_NOT_AVAILABLE,
    ERROR_GROUP_NOT_FOUND,
    ERROR_GROUP_NOT_ONLINE,
    ERROR_HOST_NODE_NOT_RESOURCE_OWNER,
    ERROR_HOST_NODE_NOT_GROUP_OWNER,
    ERROR_RESMON_CREATE_FAILED,
    ERROR_RESMON_ONLINE_FAILED,
    ERROR_RESOURCE_ONLINE,
    ERROR_QUORUM_RESOURCE,
    ERROR_NOT_QUORUM_CAPABLE,
    ERROR_CLUSTER_SHUTTING_DOWN,
    ERROR_INVALID_STATE,
    ERROR_RESOURCE_PROPERTIES_STORED,
    ERROR_NOT_QUORUM_CLASS,
    ERROR_CORE_RESOURCE,
    ERROR_QUORUM_RESOURCE_ONLINE_FAILED,
    ERROR_QUORUMLOG_OPEN_FAILED,
    ERROR_CLUSTERLOG_CORRUPT,
    ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE,
    ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE,
    ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND,
    ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE,
    ERROR_QUORUM_OWNER_ALIVE,
    ERROR_NETWORK_NOT_AVAILABLE,
    ERROR_NODE_NOT_AVAILABLE,
    ERROR_ALL_NODES_NOT_AVAILABLE,
    ERROR_RESOURCE_FAILED,
    ERROR_CLUSTER_INVALID_NODE,
    ERROR_CLUSTER_NODE_EXISTS,
    ERROR_CLUSTER_JOIN_IN_PROGRESS,
    ERROR_CLUSTER_NODE_NOT_FOUND,
    ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND,
    ERROR_CLUSTER_NETWORK_EXISTS,
    ERROR_CLUSTER_NETWORK_NOT_FOUND,
    ERROR_CLUSTER_NETINTERFACE_EXISTS,
    ERROR_CLUSTER_NETINTERFACE_NOT_FOUND,
    ERROR_CLUSTER_INVALID_REQUEST,
    ERROR_CLUSTER_INVALID_NETWORK_PROVIDER,
    ERROR_CLUSTER_NODE_DOWN,
    ERROR_CLUSTER_NODE_UNREACHABLE,
    ERROR_CLUSTER_NODE_NOT_MEMBER,
    ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS,
    ERROR_CLUSTER_INVALID_NETWORK,
    ERROR_CLUSTER_NODE_UP,
    ERROR_CLUSTER_IPADDR_IN_USE,
    ERROR_CLUSTER_NODE_NOT_PAUSED,
    ERROR_CLUSTER_NO_SECURITY_CONTEXT,
    ERROR_CLUSTER_NETWORK_NOT_INTERNAL,
    ERROR_CLUSTER_NODE_ALREADY_UP,
    ERROR_CLUSTER_NODE_ALREADY_DOWN,
    ERROR_CLUSTER_NETWORK_ALREADY_ONLINE,
    ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE,
    ERROR_CLUSTER_NODE_ALREADY_MEMBER,
    ERROR_CLUSTER_LAST_INTERNAL_NETWORK,
    ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS,
    ERROR_INVALID_OPERATION_ON_QUORUM,
    ERROR_DEPENDENCY_NOT_ALLOWED,
    ERROR_CLUSTER_NODE_PAUSED,
    ERROR_NODE_CANT_HOST_RESOURCE,
    ERROR_CLUSTER_NODE_NOT_READY,
    ERROR_CLUSTER_NODE_SHUTTING_DOWN,
    ERROR_CLUSTER_JOIN_ABORTED,
    ERROR_CLUSTER_INCOMPATIBLE_VERSIONS,
    ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED,
    ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED,
    ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND,
    ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED,
    ERROR_CLUSTER_RESNAME_NOT_FOUND,
    ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED,
    ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST,
    ERROR_CLUSTER_DATABASE_SEQMISMATCH,
    ERROR_RESMON_INVALID_STATE,
    ERROR_CLUSTER_GUM_NOT_LOCKER,
    ERROR_QUORUM_DISK_NOT_FOUND,
    ERROR_DATABASE_BACKUP_CORRUPT,
    ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT,
    ERROR_RESOURCE_PROPERTY_UNCHANGEABLE,
    ERROR_NO_ADMIN_ACCESS_POINT,
    ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE,
    ERROR_CLUSTER_QUORUMLOG_NOT_FOUND,
    ERROR_CLUSTER_MEMBERSHIP_HALT,
    ERROR_CLUSTER_INSTANCE_ID_MISMATCH,
    ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP,
    ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH,
    ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP,
    ERROR_CLUSTER_PARAMETER_MISMATCH,
    ERROR_NODE_CANNOT_BE_CLUSTERED,
    ERROR_CLUSTER_WRONG_OS_VERSION,
    ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME,
    ERROR_CLUSCFG_ALREADY_COMMITTED,
    ERROR_CLUSCFG_ROLLBACK_FAILED,
    ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT,
    ERROR_CLUSTER_OLD_VERSION,
    ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME,
    ERROR_CLUSTER_NO_NET_ADAPTERS,
    ERROR_CLUSTER_POISONED,
    ERROR_CLUSTER_GROUP_MOVING,
    ERROR_CLUSTER_RESOURCE_TYPE_BUSY,
    ERROR_RESOURCE_CALL_TIMED_OUT,
    ERROR_INVALID_CLUSTER_IPV6_ADDRESS,
    ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION,
    ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS,
    ERROR_CLUSTER_PARTIAL_SEND,
    ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION,
    ERROR_CLUSTER_INVALID_STRING_TERMINATION,
    ERROR_CLUSTER_INVALID_STRING_FORMAT,
    ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS,
    ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS,
    ERROR_CLUSTER_NULL_DATA,
    ERROR_CLUSTER_PARTIAL_READ,
    ERROR_CLUSTER_PARTIAL_WRITE,
    ERROR_CLUSTER_CANT_DESERIALIZE_DATA,
    ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT,
    ERROR_CLUSTER_NO_QUORUM,
    ERROR_CLUSTER_INVALID_IPV6_NETWORK,
    ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK,
    ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP,
    ERROR_DEPENDENCY_TREE_TOO_COMPLEX,
    ERROR_EXCEPTION_IN_RESOURCE_CALL,
    ERROR_CLUSTER_RHS_FAILED_INITIALIZATION,
    ERROR_CLUSTER_NOT_INSTALLED,
    ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE,
    ERROR_CLUSTER_MAX_NODES_IN_CLUSTER,
    ERROR_CLUSTER_TOO_MANY_NODES,
    ERROR_CLUSTER_OBJECT_ALREADY_USED,
    ERROR_NONCORE_GROUPS_FOUND,
    ERROR_FILE_SHARE_RESOURCE_CONFLICT,
    ERROR_CLUSTER_EVICT_INVALID_REQUEST,
    ERROR_CLUSTER_SINGLETON_RESOURCE,
    ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE,
    ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED,
    ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR,
    ERROR_CLUSTER_GROUP_BUSY,
    ERROR_CLUSTER_NOT_SHARED_VOLUME,
    ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR,
    ERROR_CLUSTER_SHARED_VOLUMES_IN_USE,
    ERROR_CLUSTER_USE_SHARED_VOLUMES_API,
    ERROR_CLUSTER_BACKUP_IN_PROGRESS,
    ERROR_NON_CSV_PATH,
    ERROR_CSV_VOLUME_NOT_LOCAL,
    ERROR_CLUSTER_WATCHDOG_TERMINATING,
    ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES,
    ERROR_CLUSTER_INVALID_NODE_WEIGHT,
    ERROR_CLUSTER_RESOURCE_VETOED_CALL,
    ERROR_RESMON_SYSTEM_RESOURCES_LACKING,
    ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION,
    ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE,
    ERROR_CLUSTER_GROUP_QUEUED,
    ERROR_CLUSTER_RESOURCE_LOCKED_STATUS,
    ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED,
    ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS,
    ERROR_CLUSTER_DISK_NOT_CONNECTED,
    ERROR_DISK_NOT_CSV_CAPABLE,
    ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE,
    ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED,
    ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED,
    ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES,
    ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES,
    ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE,
    ERROR_CLUSTER_AFFINITY_CONFLICT,
    ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE,
    ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS,
    ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED,
    ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED,
    ERROR_CLUSTER_UPGRADE_IN_PROGRESS,
    ERROR_CLUSTER_UPGRADE_INCOMPLETE,
    ERROR_CLUSTER_NODE_IN_GRACE_PERIOD,
    ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT,
    ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER,
    ERROR_CLUSTER_RESOURCE_NOT_MONITORED,
    ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED,
    ERROR_CLUSTER_RESOURCE_IS_REPLICATED,
    ERROR_CLUSTER_NODE_ISOLATED,
    ERROR_CLUSTER_NODE_QUARANTINED,
    ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED,
    ERROR_CLUSTER_SPACE_DEGRADED,
    ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED,
    ERROR_CLUSTER_CSV_INVALID_HANDLE,
    ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR,
    ERROR_GROUPSET_NOT_AVAILABLE,
    ERROR_GROUPSET_NOT_FOUND,
    ERROR_GROUPSET_CANT_PROVIDE,
    ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND,
    ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY,
    ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION,
    ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS,
    ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME,
    ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE,
    ERROR_ENCRYPTION_FAILED,
    ERROR_DECRYPTION_FAILED,
    ERROR_FILE_ENCRYPTED,
    ERROR_NO_RECOVERY_POLICY,
    ERROR_NO_EFS,
    ERROR_WRONG_EFS,
    ERROR_NO_USER_KEYS,
    ERROR_FILE_NOT_ENCRYPTED,
    ERROR_NOT_EXPORT_FORMAT,
    ERROR_FILE_READ_ONLY,
    ERROR_DIR_EFS_DISALLOWED,
    ERROR_EFS_SERVER_NOT_TRUSTED,
    ERROR_BAD_RECOVERY_POLICY,
    ERROR_EFS_ALG_BLOB_TOO_BIG,
    ERROR_VOLUME_NOT_SUPPORT_EFS,
    ERROR_EFS_DISABLED,
    ERROR_EFS_VERSION_NOT_SUPPORT,
    ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE,
    ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER,
    ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE,
    ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE,
    ERROR_CS_ENCRYPTION_FILE_NOT_CSE,
    ERROR_ENCRYPTION_POLICY_DENIES_OPERATION,
    ERROR_WIP_ENCRYPTION_FAILED,
    ERROR_NO_BROWSER_SERVERS_FOUND,
    SCHED_E_SERVICE_NOT_LOCALSYSTEM,
    ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM,
    ERROR_LOG_SECTOR_INVALID,
    ERROR_LOG_SECTOR_PARITY_INVALID,
    ERROR_LOG_SECTOR_REMAPPED,
    ERROR_LOG_BLOCK_INCOMPLETE,
    ERROR_LOG_INVALID_RANGE,
    ERROR_LOG_BLOCKS_EXHAUSTED,
    ERROR_LOG_READ_CONTEXT_INVALID,
    ERROR_LOG_RESTART_INVALID,
    ERROR_LOG_BLOCK_VERSION,
    ERROR_LOG_BLOCK_INVALID,
    ERROR_LOG_READ_MODE_INVALID,
    ERROR_LOG_NO_RESTART,
    ERROR_LOG_METADATA_CORRUPT,
    ERROR_LOG_METADATA_INVALID,
    ERROR_LOG_METADATA_INCONSISTENT,
    ERROR_LOG_RESERVATION_INVALID,
    ERROR_LOG_CANT_DELETE,
    ERROR_LOG_CONTAINER_LIMIT_EXCEEDED,
    ERROR_LOG_START_OF_LOG,
    ERROR_LOG_POLICY_ALREADY_INSTALLED,
    ERROR_LOG_POLICY_NOT_INSTALLED,
    ERROR_LOG_POLICY_INVALID,
    ERROR_LOG_POLICY_CONFLICT,
    ERROR_LOG_PINNED_ARCHIVE_TAIL,
    ERROR_LOG_RECORD_NONEXISTENT,
    ERROR_LOG_RECORDS_RESERVED_INVALID,
    ERROR_LOG_SPACE_RESERVED_INVALID,
    ERROR_LOG_TAIL_INVALID,
    ERROR_LOG_FULL,
    ERROR_COULD_NOT_RESIZE_LOG,
    ERROR_LOG_MULTIPLEXED,
    ERROR_LOG_DEDICATED,
    ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS,
    ERROR_LOG_ARCHIVE_IN_PROGRESS,
    ERROR_LOG_EPHEMERAL,
    ERROR_LOG_NOT_ENOUGH_CONTAINERS,
    ERROR_LOG_CLIENT_ALREADY_REGISTERED,
    ERROR_LOG_CLIENT_NOT_REGISTERED,
    ERROR_LOG_FULL_HANDLER_IN_PROGRESS,
    ERROR_LOG_CONTAINER_READ_FAILED,
    ERROR_LOG_CONTAINER_WRITE_FAILED,
    ERROR_LOG_CONTAINER_OPEN_FAILED,
    ERROR_LOG_CONTAINER_STATE_INVALID,
    ERROR_LOG_STATE_INVALID,
    ERROR_LOG_PINNED,
    ERROR_LOG_METADATA_FLUSH_FAILED,
    ERROR_LOG_INCONSISTENT_SECURITY,
    ERROR_LOG_APPENDED_FLUSH_FAILED,
    ERROR_LOG_PINNED_RESERVATION,
    ERROR_INVALID_TRANSACTION,
    ERROR_TRANSACTION_NOT_ACTIVE,
    ERROR_TRANSACTION_REQUEST_NOT_VALID,
    ERROR_TRANSACTION_NOT_REQUESTED,
    ERROR_TRANSACTION_ALREADY_ABORTED,
    ERROR_TRANSACTION_ALREADY_COMMITTED,
    ERROR_TM_INITIALIZATION_FAILED,
    ERROR_RESOURCEMANAGER_READ_ONLY,
    ERROR_TRANSACTION_NOT_JOINED,
    ERROR_TRANSACTION_SUPERIOR_EXISTS,
    ERROR_CRM_PROTOCOL_ALREADY_EXISTS,
    ERROR_TRANSACTION_PROPAGATION_FAILED,
    ERROR_CRM_PROTOCOL_NOT_FOUND,
    ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER,
    ERROR_CURRENT_TRANSACTION_NOT_VALID,
    ERROR_TRANSACTION_NOT_FOUND,
    ERROR_RESOURCEMANAGER_NOT_FOUND,
    ERROR_ENLISTMENT_NOT_FOUND,
    ERROR_TRANSACTIONMANAGER_NOT_FOUND,
    ERROR_TRANSACTIONMANAGER_NOT_ONLINE,
    ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION,
    ERROR_TRANSACTION_NOT_ROOT,
    ERROR_TRANSACTION_OBJECT_EXPIRED,
    ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED,
    ERROR_TRANSACTION_RECORD_TOO_LONG,
    ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED,
    ERROR_TRANSACTION_INTEGRITY_VIOLATED,
    ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH,
    ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT,
    ERROR_TRANSACTION_MUST_WRITETHROUGH,
    ERROR_TRANSACTION_NO_SUPERIOR,
    ERROR_HEURISTIC_DAMAGE_POSSIBLE,
    ERROR_TRANSACTIONAL_CONFLICT,
    ERROR_RM_NOT_ACTIVE,
    ERROR_RM_METADATA_CORRUPT,
    ERROR_DIRECTORY_NOT_RM,
    ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE,
    ERROR_LOG_RESIZE_INVALID_SIZE,
    ERROR_OBJECT_NO_LONGER_EXISTS,
    ERROR_STREAM_MINIVERSION_NOT_FOUND,
    ERROR_STREAM_MINIVERSION_NOT_VALID,
    ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION,
    ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT,
    ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS,
    ERROR_REMOTE_FILE_VERSION_MISMATCH,
    ERROR_HANDLE_NO_LONGER_VALID,
    ERROR_NO_TXF_METADATA,
    ERROR_LOG_CORRUPTION_DETECTED,
    ERROR_CANT_RECOVER_WITH_HANDLE_OPEN,
    ERROR_RM_DISCONNECTED,
    ERROR_ENLISTMENT_NOT_SUPERIOR,
    ERROR_RECOVERY_NOT_NEEDED,
    ERROR_RM_ALREADY_STARTED,
    ERROR_FILE_IDENTITY_NOT_PERSISTENT,
    ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY,
    ERROR_CANT_CROSS_RM_BOUNDARY,
    ERROR_TXF_DIR_NOT_EMPTY,
    ERROR_INDOUBT_TRANSACTIONS_EXIST,
    ERROR_TM_VOLATILE,
    ERROR_ROLLBACK_TIMER_EXPIRED,
    ERROR_TXF_ATTRIBUTE_CORRUPT,
    ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION,
    ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED,
    ERROR_LOG_GROWTH_FAILED,
    ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE,
    ERROR_TXF_METADATA_ALREADY_PRESENT,
    ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET,
    ERROR_TRANSACTION_REQUIRED_PROMOTION,
    ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION,
    ERROR_TRANSACTIONS_NOT_FROZEN,
    ERROR_TRANSACTION_FREEZE_IN_PROGRESS,
    ERROR_NOT_SNAPSHOT_VOLUME,
    ERROR_NO_SAVEPOINT_WITH_OPEN_FILES,
    ERROR_DATA_LOST_REPAIR,
    ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION,
    ERROR_TM_IDENTITY_MISMATCH,
    ERROR_FLOATED_SECTION,
    ERROR_CANNOT_ACCEPT_TRANSACTED_WORK,
    ERROR_CANNOT_ABORT_TRANSACTIONS,
    ERROR_BAD_CLUSTERS,
    ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION,
    ERROR_VOLUME_DIRTY,
    ERROR_NO_LINK_TRACKING_IN_TRANSACTION,
    ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION,
    ERROR_EXPIRED_HANDLE,
    ERROR_TRANSACTION_NOT_ENLISTED,
    ERROR_CTX_WINSTATION_NAME_INVALID,
    ERROR_CTX_INVALID_PD,
    ERROR_CTX_PD_NOT_FOUND,
    ERROR_CTX_WD_NOT_FOUND,
    ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY,
    ERROR_CTX_SERVICE_NAME_COLLISION,
    ERROR_CTX_CLOSE_PENDING,
    ERROR_CTX_NO_OUTBUF,
    ERROR_CTX_MODEM_INF_NOT_FOUND,
    ERROR_CTX_INVALID_MODEMNAME,
    ERROR_CTX_MODEM_RESPONSE_ERROR,
    ERROR_CTX_MODEM_RESPONSE_TIMEOUT,
    ERROR_CTX_MODEM_RESPONSE_NO_CARRIER,
    ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE,
    ERROR_CTX_MODEM_RESPONSE_BUSY,
    ERROR_CTX_MODEM_RESPONSE_VOICE,
    ERROR_CTX_TD_ERROR,
    ERROR_CTX_WINSTATION_NOT_FOUND,
    ERROR_CTX_WINSTATION_ALREADY_EXISTS,
    ERROR_CTX_WINSTATION_BUSY,
    ERROR_CTX_BAD_VIDEO_MODE,
    ERROR_CTX_GRAPHICS_INVALID,
    ERROR_CTX_LOGON_DISABLED,
    ERROR_CTX_NOT_CONSOLE,
    ERROR_CTX_CLIENT_QUERY_TIMEOUT,
    ERROR_CTX_CONSOLE_DISCONNECT,
    ERROR_CTX_CONSOLE_CONNECT,
    ERROR_CTX_SHADOW_DENIED,
    ERROR_CTX_WINSTATION_ACCESS_DENIED,
    ERROR_CTX_INVALID_WD,
    ERROR_CTX_SHADOW_INVALID,
    ERROR_CTX_SHADOW_DISABLED,
    ERROR_CTX_CLIENT_LICENSE_IN_USE,
    ERROR_CTX_CLIENT_LICENSE_NOT_SET,
    ERROR_CTX_LICENSE_NOT_AVAILABLE,
    ERROR_CTX_LICENSE_CLIENT_INVALID,
    ERROR_CTX_LICENSE_EXPIRED,
    ERROR_CTX_SHADOW_NOT_RUNNING,
    ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE,
    ERROR_ACTIVATION_COUNT_EXCEEDED,
    ERROR_CTX_WINSTATIONS_DISABLED,
    ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED,
    ERROR_CTX_SESSION_IN_USE,
    ERROR_CTX_NO_FORCE_LOGOFF,
    ERROR_CTX_ACCOUNT_RESTRICTION,
    ERROR_RDP_PROTOCOL_ERROR,
    ERROR_CTX_CDM_CONNECT,
    ERROR_CTX_CDM_DISCONNECT,
    ERROR_CTX_SECURITY_LAYER_ERROR,
    ERROR_TS_INCOMPATIBLE_SESSIONS,
    ERROR_TS_VIDEO_SUBSYSTEM_ERROR,
    FRS_ERR_INVALID_API_SEQUENCE,
    FRS_ERR_STARTING_SERVICE,
    FRS_ERR_STOPPING_SERVICE,
    FRS_ERR_INTERNAL_API,
    FRS_ERR_INTERNAL,
    FRS_ERR_SERVICE_COMM,
    FRS_ERR_INSUFFICIENT_PRIV,
    FRS_ERR_AUTHENTICATION,
    FRS_ERR_PARENT_INSUFFICIENT_PRIV,
    FRS_ERR_PARENT_AUTHENTICATION,
    FRS_ERR_CHILD_TO_PARENT_COMM,
    FRS_ERR_PARENT_TO_CHILD_COMM,
    FRS_ERR_SYSVOL_POPULATE,
    FRS_ERR_SYSVOL_POPULATE_TIMEOUT,
    FRS_ERR_SYSVOL_IS_BUSY,
    FRS_ERR_SYSVOL_DEMOTE,
    FRS_ERR_INVALID_SERVICE_PARAMETER,
    ERROR_DS_NOT_INSTALLED,
    ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY,
    ERROR_DS_NO_ATTRIBUTE_OR_VALUE,
    ERROR_DS_INVALID_ATTRIBUTE_SYNTAX,
    ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED,
    ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS,
    ERROR_DS_BUSY,
    ERROR_DS_UNAVAILABLE,
    ERROR_DS_NO_RIDS_ALLOCATED,
    ERROR_DS_NO_MORE_RIDS,
    ERROR_DS_INCORRECT_ROLE_OWNER,
    ERROR_DS_RIDMGR_INIT_ERROR,
    ERROR_DS_OBJ_CLASS_VIOLATION,
    ERROR_DS_CANT_ON_NON_LEAF,
    ERROR_DS_CANT_ON_RDN,
    ERROR_DS_CANT_MOD_OBJ_CLASS,
    ERROR_DS_CROSS_DOM_MOVE_ERROR,
    ERROR_DS_GC_NOT_AVAILABLE,
    ERROR_SHARED_POLICY,
    ERROR_POLICY_OBJECT_NOT_FOUND,
    ERROR_POLICY_ONLY_IN_DS,
    ERROR_PROMOTION_ACTIVE,
    ERROR_NO_PROMOTION_ACTIVE,
    ERROR_DS_OPERATIONS_ERROR,
    ERROR_DS_PROTOCOL_ERROR,
    ERROR_DS_TIMELIMIT_EXCEEDED,
    ERROR_DS_SIZELIMIT_EXCEEDED,
    ERROR_DS_ADMIN_LIMIT_EXCEEDED,
    ERROR_DS_COMPARE_FALSE,
    ERROR_DS_COMPARE_TRUE,
    ERROR_DS_AUTH_METHOD_NOT_SUPPORTED,
    ERROR_DS_STRONG_AUTH_REQUIRED,
    ERROR_DS_INAPPROPRIATE_AUTH,
    ERROR_DS_AUTH_UNKNOWN,
    ERROR_DS_REFERRAL,
    ERROR_DS_UNAVAILABLE_CRIT_EXTENSION,
    ERROR_DS_CONFIDENTIALITY_REQUIRED,
    ERROR_DS_INAPPROPRIATE_MATCHING,
    ERROR_DS_CONSTRAINT_VIOLATION,
    ERROR_DS_NO_SUCH_OBJECT,
    ERROR_DS_ALIAS_PROBLEM,
    ERROR_DS_INVALID_DN_SYNTAX,
    ERROR_DS_IS_LEAF,
    ERROR_DS_ALIAS_DEREF_PROBLEM,
    ERROR_DS_UNWILLING_TO_PERFORM,
    ERROR_DS_LOOP_DETECT,
    ERROR_DS_NAMING_VIOLATION,
    ERROR_DS_OBJECT_RESULTS_TOO_LARGE,
    ERROR_DS_AFFECTS_MULTIPLE_DSAS,
    ERROR_DS_SERVER_DOWN,
    ERROR_DS_LOCAL_ERROR,
    ERROR_DS_ENCODING_ERROR,
    ERROR_DS_DECODING_ERROR,
    ERROR_DS_FILTER_UNKNOWN,
    ERROR_DS_PARAM_ERROR,
    ERROR_DS_NOT_SUPPORTED,
    ERROR_DS_NO_RESULTS_RETURNED,
    ERROR_DS_CONTROL_NOT_FOUND,
    ERROR_DS_CLIENT_LOOP,
    ERROR_DS_REFERRAL_LIMIT_EXCEEDED,
    ERROR_DS_SORT_CONTROL_MISSING,
    ERROR_DS_OFFSET_RANGE_ERROR,
    ERROR_DS_RIDMGR_DISABLED,
    ERROR_DS_ROOT_MUST_BE_NC,
    ERROR_DS_ADD_REPLICA_INHIBITED,
    ERROR_DS_ATT_NOT_DEF_IN_SCHEMA,
    ERROR_DS_MAX_OBJ_SIZE_EXCEEDED,
    ERROR_DS_OBJ_STRING_NAME_EXISTS,
    ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA,
    ERROR_DS_RDN_DOESNT_MATCH_SCHEMA,
    ERROR_DS_NO_REQUESTED_ATTS_FOUND,
    ERROR_DS_USER_BUFFER_TO_SMALL,
    ERROR_DS_ATT_IS_NOT_ON_OBJ,
    ERROR_DS_ILLEGAL_MOD_OPERATION,
    ERROR_DS_OBJ_TOO_LARGE,
    ERROR_DS_BAD_INSTANCE_TYPE,
    ERROR_DS_MASTERDSA_REQUIRED,
    ERROR_DS_OBJECT_CLASS_REQUIRED,
    ERROR_DS_MISSING_REQUIRED_ATT,
    ERROR_DS_ATT_NOT_DEF_FOR_CLASS,
    ERROR_DS_ATT_ALREADY_EXISTS,
    ERROR_DS_CANT_ADD_ATT_VALUES,
    ERROR_DS_SINGLE_VALUE_CONSTRAINT,
    ERROR_DS_RANGE_CONSTRAINT,
    ERROR_DS_ATT_VAL_ALREADY_EXISTS,
    ERROR_DS_CANT_REM_MISSING_ATT,
    ERROR_DS_CANT_REM_MISSING_ATT_VAL,
    ERROR_DS_ROOT_CANT_BE_SUBREF,
    ERROR_DS_NO_CHAINING,
    ERROR_DS_NO_CHAINED_EVAL,
    ERROR_DS_NO_PARENT_OBJECT,
    ERROR_DS_PARENT_IS_AN_ALIAS,
    ERROR_DS_CANT_MIX_MASTER_AND_REPS,
    ERROR_DS_CHILDREN_EXIST,
    ERROR_DS_OBJ_NOT_FOUND,
    ERROR_DS_ALIASED_OBJ_MISSING,
    ERROR_DS_BAD_NAME_SYNTAX,
    ERROR_DS_ALIAS_POINTS_TO_ALIAS,
    ERROR_DS_CANT_DEREF_ALIAS,
    ERROR_DS_OUT_OF_SCOPE,
    ERROR_DS_OBJECT_BEING_REMOVED,
    ERROR_DS_CANT_DELETE_DSA_OBJ,
    ERROR_DS_GENERIC_ERROR,
    ERROR_DS_DSA_MUST_BE_INT_MASTER,
    ERROR_DS_CLASS_NOT_DSA,
    ERROR_DS_INSUFF_ACCESS_RIGHTS,
    ERROR_DS_ILLEGAL_SUPERIOR,
    ERROR_DS_ATTRIBUTE_OWNED_BY_SAM,
    ERROR_DS_NAME_TOO_MANY_PARTS,
    ERROR_DS_NAME_TOO_LONG,
    ERROR_DS_NAME_VALUE_TOO_LONG,
    ERROR_DS_NAME_UNPARSEABLE,
    ERROR_DS_NAME_TYPE_UNKNOWN,
    ERROR_DS_NOT_AN_OBJECT,
    ERROR_DS_SEC_DESC_TOO_SHORT,
    ERROR_DS_SEC_DESC_INVALID,
    ERROR_DS_NO_DELETED_NAME,
    ERROR_DS_SUBREF_MUST_HAVE_PARENT,
    ERROR_DS_NCNAME_MUST_BE_NC,
    ERROR_DS_CANT_ADD_SYSTEM_ONLY,
    ERROR_DS_CLASS_MUST_BE_CONCRETE,
    ERROR_DS_INVALID_DMD,
    ERROR_DS_OBJ_GUID_EXISTS,
    ERROR_DS_NOT_ON_BACKLINK,
    ERROR_DS_NO_CROSSREF_FOR_NC,
    ERROR_DS_SHUTTING_DOWN,
    ERROR_DS_UNKNOWN_OPERATION,
    ERROR_DS_INVALID_ROLE_OWNER,
    ERROR_DS_COULDNT_CONTACT_FSMO,
    ERROR_DS_CROSS_NC_DN_RENAME,
    ERROR_DS_CANT_MOD_SYSTEM_ONLY,
    ERROR_DS_REPLICATOR_ONLY,
    ERROR_DS_OBJ_CLASS_NOT_DEFINED,
    ERROR_DS_OBJ_CLASS_NOT_SUBCLASS,
    ERROR_DS_NAME_REFERENCE_INVALID,
    ERROR_DS_CROSS_REF_EXISTS,
    ERROR_DS_CANT_DEL_MASTER_CROSSREF,
    ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD,
    ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX,
    ERROR_DS_DUP_RDN,
    ERROR_DS_DUP_OID,
    ERROR_DS_DUP_MAPI_ID,
    ERROR_DS_DUP_SCHEMA_ID_GUID,
    ERROR_DS_DUP_LDAP_DISPLAY_NAME,
    ERROR_DS_SEMANTIC_ATT_TEST,
    ERROR_DS_SYNTAX_MISMATCH,
    ERROR_DS_EXISTS_IN_MUST_HAVE,
    ERROR_DS_EXISTS_IN_MAY_HAVE,
    ERROR_DS_NONEXISTENT_MAY_HAVE,
    ERROR_DS_NONEXISTENT_MUST_HAVE,
    ERROR_DS_AUX_CLS_TEST_FAIL,
    ERROR_DS_NONEXISTENT_POSS_SUP,
    ERROR_DS_SUB_CLS_TEST_FAIL,
    ERROR_DS_BAD_RDN_ATT_ID_SYNTAX,
    ERROR_DS_EXISTS_IN_AUX_CLS,
    ERROR_DS_EXISTS_IN_SUB_CLS,
    ERROR_DS_EXISTS_IN_POSS_SUP,
    ERROR_DS_RECALCSCHEMA_FAILED,
    ERROR_DS_TREE_DELETE_NOT_FINISHED,
    ERROR_DS_CANT_DELETE,
    ERROR_DS_ATT_SCHEMA_REQ_ID,
    ERROR_DS_BAD_ATT_SCHEMA_SYNTAX,
    ERROR_DS_CANT_CACHE_ATT,
    ERROR_DS_CANT_CACHE_CLASS,
    ERROR_DS_CANT_REMOVE_ATT_CACHE,
    ERROR_DS_CANT_REMOVE_CLASS_CACHE,
    ERROR_DS_CANT_RETRIEVE_DN,
    ERROR_DS_MISSING_SUPREF,
    ERROR_DS_CANT_RETRIEVE_INSTANCE,
    ERROR_DS_CODE_INCONSISTENCY,
    ERROR_DS_DATABASE_ERROR,
    ERROR_DS_GOVERNSID_MISSING,
    ERROR_DS_MISSING_EXPECTED_ATT,
    ERROR_DS_NCNAME_MISSING_CR_REF,
    ERROR_DS_SECURITY_CHECKING_ERROR,
    ERROR_DS_SCHEMA_NOT_LOADED,
    ERROR_DS_SCHEMA_ALLOC_FAILED,
    ERROR_DS_ATT_SCHEMA_REQ_SYNTAX,
    ERROR_DS_GCVERIFY_ERROR,
    ERROR_DS_DRA_SCHEMA_MISMATCH,
    ERROR_DS_CANT_FIND_DSA_OBJ,
    ERROR_DS_CANT_FIND_EXPECTED_NC,
    ERROR_DS_CANT_FIND_NC_IN_CACHE,
    ERROR_DS_CANT_RETRIEVE_CHILD,
    ERROR_DS_SECURITY_ILLEGAL_MODIFY,
    ERROR_DS_CANT_REPLACE_HIDDEN_REC,
    ERROR_DS_BAD_HIERARCHY_FILE,
    ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED,
    ERROR_DS_CONFIG_PARAM_MISSING,
    ERROR_DS_COUNTING_AB_INDICES_FAILED,
    ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED,
    ERROR_DS_INTERNAL_FAILURE,
    ERROR_DS_UNKNOWN_ERROR,
    ERROR_DS_ROOT_REQUIRES_CLASS_TOP,
    ERROR_DS_REFUSING_FSMO_ROLES,
    ERROR_DS_MISSING_FSMO_SETTINGS,
    ERROR_DS_UNABLE_TO_SURRENDER_ROLES,
    ERROR_DS_DRA_GENERIC,
    ERROR_DS_DRA_INVALID_PARAMETER,
    ERROR_DS_DRA_BUSY,
    ERROR_DS_DRA_BAD_DN,
    ERROR_DS_DRA_BAD_NC,
    ERROR_DS_DRA_DN_EXISTS,
    ERROR_DS_DRA_INTERNAL_ERROR,
    ERROR_DS_DRA_INCONSISTENT_DIT,
    ERROR_DS_DRA_CONNECTION_FAILED,
    ERROR_DS_DRA_BAD_INSTANCE_TYPE,
    ERROR_DS_DRA_OUT_OF_MEM,
    ERROR_DS_DRA_MAIL_PROBLEM,
    ERROR_DS_DRA_REF_ALREADY_EXISTS,
    ERROR_DS_DRA_REF_NOT_FOUND,
    ERROR_DS_DRA_OBJ_IS_REP_SOURCE,
    ERROR_DS_DRA_DB_ERROR,
    ERROR_DS_DRA_NO_REPLICA,
    ERROR_DS_DRA_ACCESS_DENIED,
    ERROR_DS_DRA_NOT_SUPPORTED,
    ERROR_DS_DRA_RPC_CANCELLED,
    ERROR_DS_DRA_SOURCE_DISABLED,
    ERROR_DS_DRA_SINK_DISABLED,
    ERROR_DS_DRA_NAME_COLLISION,
    ERROR_DS_DRA_SOURCE_REINSTALLED,
    ERROR_DS_DRA_MISSING_PARENT,
    ERROR_DS_DRA_PREEMPTED,
    ERROR_DS_DRA_ABANDON_SYNC,
    ERROR_DS_DRA_SHUTDOWN,
    ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET,
    ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA,
    ERROR_DS_DRA_EXTN_CONNECTION_FAILED,
    ERROR_DS_INSTALL_SCHEMA_MISMATCH,
    ERROR_DS_DUP_LINK_ID,
    ERROR_DS_NAME_ERROR_RESOLVING,
    ERROR_DS_NAME_ERROR_NOT_FOUND,
    ERROR_DS_NAME_ERROR_NOT_UNIQUE,
    ERROR_DS_NAME_ERROR_NO_MAPPING,
    ERROR_DS_NAME_ERROR_DOMAIN_ONLY,
    ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING,
    ERROR_DS_CONSTRUCTED_ATT_MOD,
    ERROR_DS_WRONG_OM_OBJ_CLASS,
    ERROR_DS_DRA_REPL_PENDING,
    ERROR_DS_DS_REQUIRED,
    ERROR_DS_INVALID_LDAP_DISPLAY_NAME,
    ERROR_DS_NON_BASE_SEARCH,
    ERROR_DS_CANT_RETRIEVE_ATTS,
    ERROR_DS_BACKLINK_WITHOUT_LINK,
    ERROR_DS_EPOCH_MISMATCH,
    ERROR_DS_SRC_NAME_MISMATCH,
    ERROR_DS_SRC_AND_DST_NC_IDENTICAL,
    ERROR_DS_DST_NC_MISMATCH,
    ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC,
    ERROR_DS_SRC_GUID_MISMATCH,
    ERROR_DS_CANT_MOVE_DELETED_OBJECT,
    ERROR_DS_PDC_OPERATION_IN_PROGRESS,
    ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD,
    ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION,
    ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS,
    ERROR_DS_NC_MUST_HAVE_NC_PARENT,
    ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE,
    ERROR_DS_DST_DOMAIN_NOT_NATIVE,
    ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER,
    ERROR_DS_CANT_MOVE_ACCOUNT_GROUP,
    ERROR_DS_CANT_MOVE_RESOURCE_GROUP,
    ERROR_DS_INVALID_SEARCH_FLAG,
    ERROR_DS_NO_TREE_DELETE_ABOVE_NC,
    ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE,
    ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE,
    ERROR_DS_SAM_INIT_FAILURE,
    ERROR_DS_SENSITIVE_GROUP_VIOLATION,
    ERROR_DS_CANT_MOD_PRIMARYGROUPID,
    ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD,
    ERROR_DS_NONSAFE_SCHEMA_CHANGE,
    ERROR_DS_SCHEMA_UPDATE_DISALLOWED,
    ERROR_DS_CANT_CREATE_UNDER_SCHEMA,
    ERROR_DS_INSTALL_NO_SRC_SCH_VERSION,
    ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE,
    ERROR_DS_INVALID_GROUP_TYPE,
    ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN,
    ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN,
    ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER,
    ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER,
    ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER,
    ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER,
    ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER,
    ERROR_DS_HAVE_PRIMARY_MEMBERS,
    ERROR_DS_STRING_SD_CONVERSION_FAILED,
    ERROR_DS_NAMING_MASTER_GC,
    ERROR_DS_DNS_LOOKUP_FAILURE,
    ERROR_DS_COULDNT_UPDATE_SPNS,
    ERROR_DS_CANT_RETRIEVE_SD,
    ERROR_DS_KEY_NOT_UNIQUE,
    ERROR_DS_WRONG_LINKED_ATT_SYNTAX,
    ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD,
    ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY,
    ERROR_DS_CANT_START,
    ERROR_DS_INIT_FAILURE,
    ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION,
    ERROR_DS_SOURCE_DOMAIN_IN_FOREST,
    ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST,
    ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED,
    ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN,
    ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER,
    ERROR_DS_SRC_SID_EXISTS_IN_FOREST,
    ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH,
    ERROR_SAM_INIT_FAILURE,
    ERROR_DS_DRA_SCHEMA_INFO_SHIP,
    ERROR_DS_DRA_SCHEMA_CONFLICT,
    ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT,
    ERROR_DS_DRA_OBJ_NC_MISMATCH,
    ERROR_DS_NC_STILL_HAS_DSAS,
    ERROR_DS_GC_REQUIRED,
    ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY,
    ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS,
    ERROR_DS_CANT_ADD_TO_GC,
    ERROR_DS_NO_CHECKPOINT_WITH_PDC,
    ERROR_DS_SOURCE_AUDITING_NOT_ENABLED,
    ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC,
    ERROR_DS_INVALID_NAME_FOR_SPN,
    ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS,
    ERROR_DS_UNICODEPWD_NOT_IN_QUOTES,
    ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED,
    ERROR_DS_MUST_BE_RUN_ON_DST_DC,
    ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER,
    ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ,
    ERROR_DS_INIT_FAILURE_CONSOLE,
    ERROR_DS_SAM_INIT_FAILURE_CONSOLE,
    ERROR_DS_FOREST_VERSION_TOO_HIGH,
    ERROR_DS_DOMAIN_VERSION_TOO_HIGH,
    ERROR_DS_FOREST_VERSION_TOO_LOW,
    ERROR_DS_DOMAIN_VERSION_TOO_LOW,
    ERROR_DS_INCOMPATIBLE_VERSION,
    ERROR_DS_LOW_DSA_VERSION,
    ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN,
    ERROR_DS_NOT_SUPPORTED_SORT_ORDER,
    ERROR_DS_NAME_NOT_UNIQUE,
    ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4,
    ERROR_DS_OUT_OF_VERSION_STORE,
    ERROR_DS_INCOMPATIBLE_CONTROLS_USED,
    ERROR_DS_NO_REF_DOMAIN,
    ERROR_DS_RESERVED_LINK_ID,
    ERROR_DS_LINK_ID_NOT_AVAILABLE,
    ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER,
    ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE,
    ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC,
    ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG,
    ERROR_DS_MODIFYDN_WRONG_GRANDPARENT,
    ERROR_DS_NAME_ERROR_TRUST_REFERRAL,
    ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER,
    ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD,
    ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2,
    ERROR_DS_THREAD_LIMIT_EXCEEDED,
    ERROR_DS_NOT_CLOSEST,
    ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF,
    ERROR_DS_SINGLE_USER_MODE_FAILED,
    ERROR_DS_NTDSCRIPT_SYNTAX_ERROR,
    ERROR_DS_NTDSCRIPT_PROCESS_ERROR,
    ERROR_DS_DIFFERENT_REPL_EPOCHS,
    ERROR_DS_DRS_EXTENSIONS_CHANGED,
    ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR,
    ERROR_DS_NO_MSDS_INTID,
    ERROR_DS_DUP_MSDS_INTID,
    ERROR_DS_EXISTS_IN_RDNATTID,
    ERROR_DS_AUTHORIZATION_FAILED,
    ERROR_DS_INVALID_SCRIPT,
    ERROR_DS_REMOTE_CROSSREF_OP_FAILED,
    ERROR_DS_CROSS_REF_BUSY,
    ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN,
    ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC,
    ERROR_DS_DUPLICATE_ID_FOUND,
    ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT,
    ERROR_DS_GROUP_CONVERSION_ERROR,
    ERROR_DS_CANT_MOVE_APP_BASIC_GROUP,
    ERROR_DS_CANT_MOVE_APP_QUERY_GROUP,
    ERROR_DS_ROLE_NOT_VERIFIED,
    ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL,
    ERROR_DS_DOMAIN_RENAME_IN_PROGRESS,
    ERROR_DS_EXISTING_AD_CHILD_NC,
    ERROR_DS_REPL_LIFETIME_EXCEEDED,
    ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER,
    ERROR_DS_LDAP_SEND_QUEUE_FULL,
    ERROR_DS_DRA_OUT_SCHEDULE_WINDOW,
    ERROR_DS_POLICY_NOT_KNOWN,
    ERROR_NO_SITE_SETTINGS_OBJECT,
    ERROR_NO_SECRETS,
    ERROR_NO_WRITABLE_DC_FOUND,
    ERROR_DS_NO_SERVER_OBJECT,
    ERROR_DS_NO_NTDSA_OBJECT,
    ERROR_DS_NON_ASQ_SEARCH,
    ERROR_DS_AUDIT_FAILURE,
    ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE,
    ERROR_DS_INVALID_SEARCH_FLAG_TUPLE,
    ERROR_DS_HIERARCHY_TABLE_TOO_DEEP,
    ERROR_DS_DRA_CORRUPT_UTD_VECTOR,
    ERROR_DS_DRA_SECRETS_DENIED,
    ERROR_DS_RESERVED_MAPI_ID,
    ERROR_DS_MAPI_ID_NOT_AVAILABLE,
    ERROR_DS_DRA_MISSING_KRBTGT_SECRET,
    ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST,
    ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST,
    ERROR_INVALID_USER_PRINCIPAL_NAME,
    ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS,
    ERROR_DS_OID_NOT_FOUND,
    ERROR_DS_DRA_RECYCLED_TARGET,
    ERROR_DS_DISALLOWED_NC_REDIRECT,
    ERROR_DS_HIGH_ADLDS_FFL,
    ERROR_DS_HIGH_DSA_VERSION,
    ERROR_DS_LOW_ADLDS_FFL,
    ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION,
    ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED,
    ERROR_INCORRECT_ACCOUNT_TYPE,
    ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST,
    ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST,
    ERROR_DS_MISSING_FOREST_TRUST,
    ERROR_DS_VALUE_KEY_NOT_UNIQUE,
    ERROR_WEAK_WHFBKEY_BLOCKED,
    ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD,
    ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED,
    ERROR_POLICY_CONTROLLED_ACCOUNT,
    ERROR_LAPS_LEGACY_SCHEMA_MISSING,
    ERROR_LAPS_SCHEMA_MISSING,
    ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL,
    DNS_ERROR_RCODE_FORMAT_ERROR,
    DNS_ERROR_RCODE_SERVER_FAILURE,
    DNS_ERROR_RCODE_NAME_ERROR,
    DNS_ERROR_RCODE_NOT_IMPLEMENTED,
    DNS_ERROR_RCODE_REFUSED,
    DNS_ERROR_RCODE_YXDOMAIN,
    DNS_ERROR_RCODE_YXRRSET,
    DNS_ERROR_RCODE_NXRRSET,
    DNS_ERROR_RCODE_NOTAUTH,
    DNS_ERROR_RCODE_NOTZONE,
    DNS_ERROR_RCODE_BADSIG,
    DNS_ERROR_RCODE_BADKEY,
    DNS_ERROR_RCODE_BADTIME,
    DNS_ERROR_KEYMASTER_REQUIRED,
    DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE,
    DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1,
    DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS,
    DNS_ERROR_UNSUPPORTED_ALGORITHM,
    DNS_ERROR_INVALID_KEY_SIZE,
    DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE,
    DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION,
    DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR,
    DNS_ERROR_UNEXPECTED_CNG_ERROR,
    DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION,
    DNS_ERROR_KSP_NOT_ACCESSIBLE,
    DNS_ERROR_TOO_MANY_SKDS,
    DNS_ERROR_INVALID_ROLLOVER_PERIOD,
    DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET,
    DNS_ERROR_ROLLOVER_IN_PROGRESS,
    DNS_ERROR_STANDBY_KEY_NOT_PRESENT,
    DNS_ERROR_NOT_ALLOWED_ON_ZSK,
    DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD,
    DNS_ERROR_ROLLOVER_ALREADY_QUEUED,
    DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE,
    DNS_ERROR_BAD_KEYMASTER,
    DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD,
    DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT,
    DNS_ERROR_DNSSEC_IS_DISABLED,
    DNS_ERROR_INVALID_XML,
    DNS_ERROR_NO_VALID_TRUST_ANCHORS,
    DNS_ERROR_ROLLOVER_NOT_POKEABLE,
    DNS_ERROR_NSEC3_NAME_COLLISION,
    DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1,
    DNS_INFO_NO_RECORDS,
    DNS_ERROR_BAD_PACKET,
    DNS_ERROR_NO_PACKET,
    DNS_ERROR_RCODE,
    DNS_ERROR_UNSECURE_PACKET,
    DNS_REQUEST_PENDING,
    DNS_ERROR_INVALID_TYPE,
    DNS_ERROR_INVALID_IP_ADDRESS,
    DNS_ERROR_INVALID_PROPERTY,
    DNS_ERROR_TRY_AGAIN_LATER,
    DNS_ERROR_NOT_UNIQUE,
    DNS_ERROR_NON_RFC_NAME,
    DNS_STATUS_FQDN,
    DNS_STATUS_DOTTED_NAME,
    DNS_STATUS_SINGLE_PART_NAME,
    DNS_ERROR_INVALID_NAME_CHAR,
    DNS_ERROR_NUMERIC_NAME,
    DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER,
    DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION,
    DNS_ERROR_CANNOT_FIND_ROOT_HINTS,
    DNS_ERROR_INCONSISTENT_ROOT_HINTS,
    DNS_ERROR_DWORD_VALUE_TOO_SMALL,
    DNS_ERROR_DWORD_VALUE_TOO_LARGE,
    DNS_ERROR_BACKGROUND_LOADING,
    DNS_ERROR_NOT_ALLOWED_ON_RODC,
    DNS_ERROR_NOT_ALLOWED_UNDER_DNAME,
    DNS_ERROR_DELEGATION_REQUIRED,
    DNS_ERROR_INVALID_POLICY_TABLE,
    DNS_ERROR_ADDRESS_REQUIRED,
    DNS_ERROR_ZONE_DOES_NOT_EXIST,
    DNS_ERROR_NO_ZONE_INFO,
    DNS_ERROR_INVALID_ZONE_OPERATION,
    DNS_ERROR_ZONE_CONFIGURATION_ERROR,
    DNS_ERROR_ZONE_HAS_NO_SOA_RECORD,
    DNS_ERROR_ZONE_HAS_NO_NS_RECORDS,
    DNS_ERROR_ZONE_LOCKED,
    DNS_ERROR_ZONE_CREATION_FAILED,
    DNS_ERROR_ZONE_ALREADY_EXISTS,
    DNS_ERROR_AUTOZONE_ALREADY_EXISTS,
    DNS_ERROR_INVALID_ZONE_TYPE,
    DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP,
    DNS_ERROR_ZONE_NOT_SECONDARY,
    DNS_ERROR_NEED_SECONDARY_ADDRESSES,
    DNS_ERROR_WINS_INIT_FAILED,
    DNS_ERROR_NEED_WINS_SERVERS,
    DNS_ERROR_NBSTAT_INIT_FAILED,
    DNS_ERROR_SOA_DELETE_INVALID,
    DNS_ERROR_FORWARDER_ALREADY_EXISTS,
    DNS_ERROR_ZONE_REQUIRES_MASTER_IP,
    DNS_ERROR_ZONE_IS_SHUTDOWN,
    DNS_ERROR_ZONE_LOCKED_FOR_SIGNING,
    DNS_ERROR_PRIMARY_REQUIRES_DATAFILE,
    DNS_ERROR_INVALID_DATAFILE_NAME,
    DNS_ERROR_DATAFILE_OPEN_FAILURE,
    DNS_ERROR_FILE_WRITEBACK_FAILED,
    DNS_ERROR_DATAFILE_PARSING,
    DNS_ERROR_RECORD_DOES_NOT_EXIST,
    DNS_ERROR_RECORD_FORMAT,
    DNS_ERROR_NODE_CREATION_FAILED,
    DNS_ERROR_UNKNOWN_RECORD_TYPE,
    DNS_ERROR_RECORD_TIMED_OUT,
    DNS_ERROR_NAME_NOT_IN_ZONE,
    DNS_ERROR_CNAME_LOOP,
    DNS_ERROR_NODE_IS_CNAME,
    DNS_ERROR_CNAME_COLLISION,
    DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT,
    DNS_ERROR_RECORD_ALREADY_EXISTS,
    DNS_ERROR_SECONDARY_DATA,
    DNS_ERROR_NO_CREATE_CACHE_DATA,
    DNS_ERROR_NAME_DOES_NOT_EXIST,
    DNS_WARNING_PTR_CREATE_FAILED,
    DNS_WARNING_DOMAIN_UNDELETED,
    DNS_ERROR_DS_UNAVAILABLE,
    DNS_ERROR_DS_ZONE_ALREADY_EXISTS,
    DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE,
    DNS_ERROR_NODE_IS_DNAME,
    DNS_ERROR_DNAME_COLLISION,
    DNS_ERROR_ALIAS_LOOP,
    DNS_INFO_AXFR_COMPLETE,
    DNS_ERROR_AXFR,
    DNS_INFO_ADDED_LOCAL_WINS,
    DNS_STATUS_CONTINUE_NEEDED,
    DNS_ERROR_NO_TCPIP,
    DNS_ERROR_NO_DNS_SERVERS,
    DNS_ERROR_DP_DOES_NOT_EXIST,
    DNS_ERROR_DP_ALREADY_EXISTS,
    DNS_ERROR_DP_NOT_ENLISTED,
    DNS_ERROR_DP_ALREADY_ENLISTED,
    DNS_ERROR_DP_NOT_AVAILABLE,
    DNS_ERROR_DP_FSMO_ERROR,
    DNS_ERROR_RRL_NOT_ENABLED,
    DNS_ERROR_RRL_INVALID_WINDOW_SIZE,
    DNS_ERROR_RRL_INVALID_IPV4_PREFIX,
    DNS_ERROR_RRL_INVALID_IPV6_PREFIX,
    DNS_ERROR_RRL_INVALID_TC_RATE,
    DNS_ERROR_RRL_INVALID_LEAK_RATE,
    DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE,
    DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS,
    DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST,
    DNS_ERROR_VIRTUALIZATION_TREE_LOCKED,
    DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME,
    DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE,
    DNS_ERROR_ZONESCOPE_ALREADY_EXISTS,
    DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST,
    DNS_ERROR_DEFAULT_ZONESCOPE,
    DNS_ERROR_INVALID_ZONESCOPE_NAME,
    DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES,
    DNS_ERROR_LOAD_ZONESCOPE_FAILED,
    DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED,
    DNS_ERROR_INVALID_SCOPE_NAME,
    DNS_ERROR_SCOPE_DOES_NOT_EXIST,
    DNS_ERROR_DEFAULT_SCOPE,
    DNS_ERROR_INVALID_SCOPE_OPERATION,
    DNS_ERROR_SCOPE_LOCKED,
    DNS_ERROR_SCOPE_ALREADY_EXISTS,
    DNS_ERROR_POLICY_ALREADY_EXISTS,
    DNS_ERROR_POLICY_DOES_NOT_EXIST,
    DNS_ERROR_POLICY_INVALID_CRITERIA,
    DNS_ERROR_POLICY_INVALID_SETTINGS,
    DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED,
    DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST,
    DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS,
    DNS_ERROR_SUBNET_DOES_NOT_EXIST,
    DNS_ERROR_SUBNET_ALREADY_EXISTS,
    DNS_ERROR_POLICY_LOCKED,
    DNS_ERROR_POLICY_INVALID_WEIGHT,
    DNS_ERROR_POLICY_INVALID_NAME,
    DNS_ERROR_POLICY_MISSING_CRITERIA,
    DNS_ERROR_INVALID_CLIENT_SUBNET_NAME,
    DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID,
    DNS_ERROR_POLICY_SCOPE_MISSING,
    DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED,
    DNS_ERROR_SERVERSCOPE_IS_REFERENCED,
    DNS_ERROR_ZONESCOPE_IS_REFERENCED,
    DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET,
    DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL,
    DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL,
    DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE,
    DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN,
    DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE,
    DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY,
    WSAEINTR,
    WSAEBADF,
    WSAEACCES,
    WSAEFAULT,
    WSAEINVAL,
    WSAEMFILE,
    WSAEWOULDBLOCK,
    WSAEINPROGRESS,
    WSAEALREADY,
    WSAENOTSOCK,
    WSAEDESTADDRREQ,
    WSAEMSGSIZE,
    WSAEPROTOTYPE,
    WSAENOPROTOOPT,
    WSAEPROTONOSUPPORT,
    WSAESOCKTNOSUPPORT,
    WSAEOPNOTSUPP,
    WSAEPFNOSUPPORT,
    WSAEAFNOSUPPORT,
    WSAEADDRINUSE,
    WSAEADDRNOTAVAIL,
    WSAENETDOWN,
    WSAENETUNREACH,
    WSAENETRESET,
    WSAECONNABORTED,
    WSAECONNRESET,
    WSAENOBUFS,
    WSAEISCONN,
    WSAENOTCONN,
    WSAESHUTDOWN,
    WSAETOOMANYREFS,
    WSAETIMEDOUT,
    WSAECONNREFUSED,
    WSAELOOP,
    WSAENAMETOOLONG,
    WSAEHOSTDOWN,
    WSAEHOSTUNREACH,
    WSAENOTEMPTY,
    WSAEPROCLIM,
    WSAEUSERS,
    WSAEDQUOT,
    WSAESTALE,
    WSAEREMOTE,
    WSASYSNOTREADY,
    WSAVERNOTSUPPORTED,
    WSANOTINITIALISED,
    WSAEDISCON,
    WSAENOMORE,
    WSAECANCELLED,
    WSAEINVALIDPROCTABLE,
    WSAEINVALIDPROVIDER,
    WSAEPROVIDERFAILEDINIT,
    WSASYSCALLFAILURE,
    WSASERVICE_NOT_FOUND,
    WSATYPE_NOT_FOUND,
    WSA_E_NO_MORE,
    WSA_E_CANCELLED,
    WSAEREFUSED,
    WSAHOST_NOT_FOUND,
    WSATRY_AGAIN,
    WSANO_RECOVERY,
    WSANO_DATA,
    WSA_QOS_RECEIVERS,
    WSA_QOS_SENDERS,
    WSA_QOS_NO_SENDERS,
    WSA_QOS_NO_RECEIVERS,
    WSA_QOS_REQUEST_CONFIRMED,
    WSA_QOS_ADMISSION_FAILURE,
    WSA_QOS_POLICY_FAILURE,
    WSA_QOS_BAD_STYLE,
    WSA_QOS_BAD_OBJECT,
    WSA_QOS_TRAFFIC_CTRL_ERROR,
    WSA_QOS_GENERIC_ERROR,
    WSA_QOS_ESERVICETYPE,
    WSA_QOS_EFLOWSPEC,
    WSA_QOS_EPROVSPECBUF,
    WSA_QOS_EFILTERSTYLE,
    WSA_QOS_EFILTERTYPE,
    WSA_QOS_EFILTERCOUNT,
    WSA_QOS_EOBJLENGTH,
    WSA_QOS_EFLOWCOUNT,
    WSA_QOS_EUNKOWNPSOBJ,
    WSA_QOS_EPOLICYOBJ,
    WSA_QOS_EFLOWDESC,
    WSA_QOS_EPSFLOWSPEC,
    WSA_QOS_EPSFILTERSPEC,
    WSA_QOS_ESDMODEOBJ,
    WSA_QOS_ESHAPERATEOBJ,
    WSA_QOS_RESERVED_PETYPE,
    WSA_SECURE_HOST_NOT_FOUND,
    WSA_IPSEC_NAME_POLICY_ERROR,
    PEER_E_CLOUD_NOT_FOUND,
    PEER_E_CLOUD_DISABLED,
    PEER_E_INVALID_IDENTITY,
    PEER_E_TOO_MUCH_LOAD,
    PEER_E_CLOUD_IS_SEARCH_ONLY,
    PEER_E_CLIENT_INVALID_COMPARTMENT_ID,
    PEER_E_DUPLICATE_PEER_NAME,
    PEER_E_CLOUD_IS_DEAD,
    ERROR_INTERNET_,
    WININET_E_OUT_OF_HANDLES,
    ERROR_INTERNET_OUT_OF_HANDLES,
    WININET_E_TIMEOUT,
    ERROR_INTERNET_TIMEOUT,
    ERROR_WINHTTP_TIMEOUT,
    WININET_E_EXTENDED_ERROR,
    ERROR_INTERNET_EXTENDED_ERROR,
    WININET_E_INTERNAL_ERROR,
    ERROR_INTERNET_INTERNAL_ERROR,
    ERROR_WINHTTP_INTERNAL_ERROR,
    WININET_E_INVALID_URL,
    ERROR_INTERNET_INVALID_URL,
    ERROR_WINHTTP_INVALID_URL,
    WININET_E_UNRECOGNIZED_SCHEME,
    ERROR_INTERNET_UNRECOGNIZED_SCHEME,
    ERROR_WINHTTP_UNRECOGNIZED_SCHEME,
    WININET_E_NAME_NOT_RESOLVED,
    ERROR_INTERNET_NAME_NOT_RESOLVED,
    ERROR_WINHTTP_NAME_NOT_RESOLVED,
    WININET_E_PROTOCOL_NOT_FOUND,
    ERROR_INTERNET_PROTOCOL_NOT_FOUND,
    WININET_E_INVALID_OPTION,
    ERROR_INTERNET_INVALID_OPTION,
    ERROR_WINHTTP_INVALID_OPTION,
    WININET_E_BAD_OPTION_LENGTH,
    ERROR_INTERNET_BAD_OPTION_LENGTH,
    WININET_E_OPTION_NOT_SETTABLE,
    ERROR_INTERNET_OPTION_NOT_SETTABLE,
    WININET_E_SHUTDOWN,
    ERROR_INTERNET_SHUTDOWN,
    ERROR_WINHTTP_SHUTDOWN,
    WININET_E_INCORRECT_USER_NAME,
    ERROR_INTERNET_INCORRECT_USER_NAME,
    WININET_E_INCORRECT_PASSWORD,
    ERROR_INTERNET_INCORRECT_PASSWORD,
    WININET_E_LOGIN_FAILURE,
    ERROR_INTERNET_LOGIN_FAILURE,
    ERROR_WINHTTP_LOGIN_FAILURE,
    WININET_E_INVALID_OPERATION,
    ERROR_INTERNET_INVALID_OPERATION,
    WININET_E_OPERATION_CANCELLED,
    ERROR_INTERNET_OPERATION_CANCELLED,
    ERROR_WINHTTP_OPERATION_CANCELLED,
    WININET_E_INCORRECT_HANDLE_TYPE,
    ERROR_INTERNET_INCORRECT_HANDLE_TYPE,
    WININET_E_INCORRECT_HANDLE_STATE,
    ERROR_INTERNET_INCORRECT_HANDLE_STATE,
    ERROR_WINHTTP_INCORRECT_HANDLE_STATE,
    WININET_E_NOT_PROXY_REQUEST,
    ERROR_INTERNET_NOT_PROXY_REQUEST,
    WININET_E_REGISTRY_VALUE_NOT_FOUND,
    ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND,
    WININET_E_BAD_REGISTRY_PARAMETER,
    ERROR_INTERNET_BAD_REGISTRY_PARAMETER,
    WININET_E_NO_DIRECT_ACCESS,
    ERROR_INTERNET_NO_DIRECT_ACCESS,
    WININET_E_NO_CONTEXT,
    ERROR_INTERNET_NO_CONTEXT,
    WININET_E_NO_CALLBACK,
    ERROR_INTERNET_NO_CALLBACK,
    WININET_E_REQUEST_PENDING,
    ERROR_INTERNET_REQUEST_PENDING,
    WININET_E_INCORRECT_FORMAT,
    ERROR_INTERNET_INCORRECT_FORMAT,
    WININET_E_ITEM_NOT_FOUND,
    ERROR_INTERNET_ITEM_NOT_FOUND,
    WININET_E_CANNOT_CONNECT,
    ERROR_INTERNET_CANNOT_CONNECT,
    ERROR_WINHTTP_CANNOT_CONNECT,
    WININET_E_CONNECTION_ABORTED,
    ERROR_INTERNET_CONNECTION_ABORTED,
    ERROR_WINHTTP_CONNECTION_ABORTED,
    WININET_E_CONNECTION_RESET,
    ERROR_INTERNET_CONNECTION_RESET,
    ERROR_WINHTTP_CONNECTION_RESET,
    WININET_E_FORCE_RETRY,
    ERROR_INTERNET_FORCE_RETRY,
    WININET_E_INVALID_PROXY_REQUEST,
    ERROR_INTERNET_INVALID_PROXY_REQUEST,
    WININET_E_NEED_UI,
    ERROR_INTERNET_NEED_UI,
    WININET_E_HANDLE_EXISTS,
    ERROR_INTERNET_HANDLE_EXISTS,
    WININET_E_SEC_CERT_DATE_INVALID,
    ERROR_INTERNET_SEC_CERT_DATE_INVALID,
    ERROR_WINHTTP_SEC_CERT_DATE_INVALID,
    WININET_E_SEC_CERT_CN_INVALID,
    ERROR_INTERNET_SEC_CERT_CN_INVALID,
    ERROR_WINHTTP_SEC_CERT_CN_INVALID,
    WININET_E_HTTP_TO_HTTPS_ON_REDIR,
    ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR,
    WININET_E_HTTPS_TO_HTTP_ON_REDIR,
    ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR,
    WININET_E_MIXED_SECURITY,
    ERROR_INTERNET_MIXED_SECURITY,
    WININET_E_CHG_POST_IS_NON_SECURE,
    ERROR_INTERNET_CHG_POST_IS_NON_SECURE,
    WININET_E_POST_IS_NON_SECURE,
    ERROR_INTERNET_POST_IS_NON_SECURE,
    WININET_E_CLIENT_AUTH_CERT_NEEDED,
    ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED,
    ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED,
    WININET_E_INVALID_CA,
    ERROR_INTERNET_INVALID_CA,
    ERROR_WINHTTP_INVALID_CA,
    WININET_E_CLIENT_AUTH_NOT_SETUP,
    ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP,
    WININET_E_ASYNC_THREAD_FAILED,
    ERROR_INTERNET_ASYNC_THREAD_FAILED,
    WININET_E_REDIRECT_SCHEME_CHANGE,
    ERROR_INTERNET_REDIRECT_SCHEME_CHANGE,
    WININET_E_DIALOG_PENDING,
    ERROR_INTERNET_DIALOG_PENDING,
    WININET_E_RETRY_DIALOG,
    ERROR_INTERNET_RETRY_DIALOG,
    WININET_E_NO_NEW_CONTAINERS,
    WININET_E_HTTPS_HTTP_SUBMIT_REDIR,
    ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR,
    ERROR_INTERNET_INSERT_CDROM,
    ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED,
    WININET_E_SEC_CERT_ERRORS,
    ERROR_INTERNET_SEC_CERT_ERRORS,
    ERROR_INTERNET_SEC_CERT_NO_REV,
    WININET_E_SEC_CERT_REV_FAILED,
    ERROR_INTERNET_SEC_CERT_REV_FAILED,
    ERROR_WINHTTP_NO_CM_CONNECTION,
    ERROR_FTP_TRANSFER_IN_PROGRESS,
    ERROR_FTP_DROPPED,
    ERROR_FTP_NO_PASSIVE_MODE,
    ERROR_GOPHER_PROTOCOL_ERROR,
    ERROR_GOPHER_NOT_FILE,
    ERROR_GOPHER_DATA_ERROR,
    ERROR_GOPHER_END_OF_DATA,
    ERROR_GOPHER_INVALID_LOCATOR,
    ERROR_GOPHER_INCORRECT_LOCATOR_TYPE,
    ERROR_GOPHER_NOT_GOPHER_PLUS,
    ERROR_GOPHER_ATTRIBUTE_NOT_FOUND,
    ERROR_GOPHER_UNKNOWN_LOCATOR,
    WININET_E_HEADER_NOT_FOUND,
    ERROR_HTTP_HEADER_NOT_FOUND,
    ERROR_WINHTTP_HEADER_NOT_FOUND,
    WININET_E_DOWNLEVEL_SERVER,
    ERROR_HTTP_DOWNLEVEL_SERVER,
    WININET_E_INVALID_SERVER_RESPONSE,
    ERROR_HTTP_INVALID_SERVER_RESPONSE,
    ERROR_WINHTTP_INVALID_SERVER_RESPONSE,
    WININET_E_INVALID_HEADER,
    ERROR_HTTP_INVALID_HEADER,
    WININET_E_INVALID_QUERY_REQUEST,
    ERROR_HTTP_INVALID_QUERY_REQUEST,
    ERROR_WINHTTP_INVALID_QUERY_REQUEST,
    WININET_E_HEADER_ALREADY_EXISTS,
    ERROR_HTTP_HEADER_ALREADY_EXISTS,
    WININET_E_REDIRECT_FAILED,
    ERROR_HTTP_REDIRECT_FAILED,
    ERROR_WINHTTP_REDIRECT_FAILED,
    WININET_E_SECURITY_CHANNEL_ERROR,
    ERROR_INTERNET_SECURITY_CHANNEL_ERROR,
    ERROR_WINHTTP_SECURE_CHANNEL_ERROR,
    WININET_E_UNABLE_TO_CACHE_FILE,
    ERROR_INTERNET_UNABLE_TO_CACHE_FILE,
    WININET_E_TCPIP_NOT_INSTALLED,
    ERROR_INTERNET_TCPIP_NOT_INSTALLED,
    WININET_E_NOT_REDIRECTED,
    ERROR_HTTP_NOT_REDIRECTED,
    WININET_E_COOKIE_NEEDS_CONFIRMATION,
    ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION,
    WININET_E_COOKIE_DECLINED,
    ERROR_HTTP_COOKIE_DECLINED,
    WININET_E_DISCONNECTED,
    ERROR_INTERNET_DISCONNECTED,
    WININET_E_SERVER_UNREACHABLE,
    ERROR_INTERNET_SERVER_UNREACHABLE,
    WININET_E_PROXY_SERVER_UNREACHABLE,
    ERROR_INTERNET_PROXY_SERVER_UNREACHABLE,
    WININET_E_BAD_AUTO_PROXY_SCRIPT,
    ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT,
    WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT,
    ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT,
    WININET_E_REDIRECT_NEEDS_CONFIRMATION,
    ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION,
    WININET_E_SEC_INVALID_CERT,
    ERROR_INTERNET_SEC_INVALID_CERT,
    ERROR_WINHTTP_SECURE_INVALID_CERT,
    WININET_E_SEC_CERT_REVOKED,
    ERROR_INTERNET_SEC_CERT_REVOKED,
    WININET_E_FAILED_DUETOSECURITYCHECK,
    ERROR_INTERNET_FAILED_DUETOSECURITYCHECK,
    WININET_E_NOT_INITIALIZED,
    ERROR_INTERNET_NOT_INITIALIZED,
    ERROR_INTERNET_NEED_MSN_SSPI_PKG,
    WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY,
    ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY,
    WININET_E_DECODING_FAILED,
    ERROR_INTERNET_DECODING_FAILED,
    ERROR_WINHTTP_SECURE_FAILURE,
    ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW,
    ERROR_IPSEC_QM_POLICY_EXISTS,
    ERROR_IPSEC_QM_POLICY_NOT_FOUND,
    ERROR_IPSEC_QM_POLICY_IN_USE,
    ERROR_IPSEC_MM_POLICY_EXISTS,
    ERROR_IPSEC_MM_POLICY_NOT_FOUND,
    ERROR_IPSEC_MM_POLICY_IN_USE,
    ERROR_IPSEC_MM_FILTER_EXISTS,
    ERROR_IPSEC_MM_FILTER_NOT_FOUND,
    ERROR_IPSEC_TRANSPORT_FILTER_EXISTS,
    ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND,
    ERROR_IPSEC_MM_AUTH_EXISTS,
    ERROR_IPSEC_MM_AUTH_NOT_FOUND,
    ERROR_IPSEC_MM_AUTH_IN_USE,
    ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND,
    ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND,
    ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND,
    ERROR_IPSEC_TUNNEL_FILTER_EXISTS,
    ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND,
    ERROR_IPSEC_MM_FILTER_PENDING_DELETION,
    ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION,
    ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION,
    ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION,
    ERROR_IPSEC_MM_POLICY_PENDING_DELETION,
    ERROR_IPSEC_MM_POLICY_PENDING_ELETION,
    ERROR_IPSEC_MM_AUTH_PENDING_DELETION,
    ERROR_IPSEC_QM_POLICY_PENDING_DELETION,
    WARNING_IPSEC_MM_POLICY_PRUNED,
    WARNING_IPSEC_QM_POLICY_PRUNED,
    ERROR_IPSEC_IKE_NEG_STATUS_BEGIN,
    ERROR_IPSEC_IKE_AUTH_FAIL,
    ERROR_IPSEC_IKE_ATTRIB_FAIL,
    ERROR_IPSEC_IKE_NEGOTIATION_PENDING,
    ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR,
    ERROR_IPSEC_IKE_TIMED_OUT,
    ERROR_IPSEC_IKE_NO_CERT,
    ERROR_IPSEC_IKE_SA_DELETED,
    ERROR_IPSEC_IKE_SA_REAPED,
    ERROR_IPSEC_IKE_MM_ACQUIRE_DROP,
    ERROR_IPSEC_IKE_QM_ACQUIRE_DROP,
    ERROR_IPSEC_IKE_QUEUE_DROP_MM,
    ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM,
    ERROR_IPSEC_IKE_DROP_NO_RESPONSE,
    ERROR_IPSEC_IKE_MM_DELAY_DROP,
    ERROR_IPSEC_IKE_QM_DELAY_DROP,
    ERROR_IPSEC_IKE_ERROR,
    ERROR_IPSEC_IKE_CRL_FAILED,
    ERROR_IPSEC_IKE_INVALID_KEY_USAGE,
    ERROR_IPSEC_IKE_INVALID_CERT_TYPE,
    ERROR_IPSEC_IKE_NO_PRIVATE_KEY,
    ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY,
    ERROR_IPSEC_IKE_DH_FAIL,
    ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED,
    ERROR_IPSEC_IKE_INVALID_HEADER,
    ERROR_IPSEC_IKE_NO_POLICY,
    ERROR_IPSEC_IKE_INVALID_SIGNATURE,
    ERROR_IPSEC_IKE_KERBEROS_ERROR,
    ERROR_IPSEC_IKE_NO_PUBLIC_KEY,
    ERROR_IPSEC_IKE_PROCESS_ERR,
    ERROR_IPSEC_IKE_PROCESS_ERR_SA,
    ERROR_IPSEC_IKE_PROCESS_ERR_PROP,
    ERROR_IPSEC_IKE_PROCESS_ERR_TRANS,
    ERROR_IPSEC_IKE_PROCESS_ERR_KE,
    ERROR_IPSEC_IKE_PROCESS_ERR_ID,
    ERROR_IPSEC_IKE_PROCESS_ERR_CERT,
    ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ,
    ERROR_IPSEC_IKE_PROCESS_ERR_HASH,
    ERROR_IPSEC_IKE_PROCESS_ERR_SIG,
    ERROR_IPSEC_IKE_PROCESS_ERR_NONCE,
    ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY,
    ERROR_IPSEC_IKE_PROCESS_ERR_DELETE,
    ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR,
    ERROR_IPSEC_IKE_INVALID_PAYLOAD,
    ERROR_IPSEC_IKE_LOAD_SOFT_SA,
    ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN,
    ERROR_IPSEC_IKE_INVALID_COOKIE,
    ERROR_IPSEC_IKE_NO_PEER_CERT,
    ERROR_IPSEC_IKE_PEER_CRL_FAILED,
    ERROR_IPSEC_IKE_POLICY_CHANGE,
    ERROR_IPSEC_IKE_NO_MM_POLICY,
    ERROR_IPSEC_IKE_NOTCBPRIV,
    ERROR_IPSEC_IKE_SECLOADFAIL,
    ERROR_IPSEC_IKE_FAILSSPINIT,
    ERROR_IPSEC_IKE_FAILQUERYSSP,
    ERROR_IPSEC_IKE_SRVACQFAIL,
    ERROR_IPSEC_IKE_SRVQUERYCRED,
    ERROR_IPSEC_IKE_GETSPIFAIL,
    ERROR_IPSEC_IKE_INVALID_FILTER,
    ERROR_IPSEC_IKE_OUT_OF_MEMORY,
    ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED,
    ERROR_IPSEC_IKE_INVALID_POLICY,
    ERROR_IPSEC_IKE_UNKNOWN_DOI,
    ERROR_IPSEC_IKE_INVALID_SITUATION,
    ERROR_IPSEC_IKE_DH_FAILURE,
    ERROR_IPSEC_IKE_INVALID_GROUP,
    ERROR_IPSEC_IKE_ENCRYPT,
    ERROR_IPSEC_IKE_DECRYPT,
    ERROR_IPSEC_IKE_POLICY_MATCH,
    ERROR_IPSEC_IKE_UNSUPPORTED_ID,
    ERROR_IPSEC_IKE_INVALID_HASH,
    ERROR_IPSEC_IKE_INVALID_HASH_ALG,
    ERROR_IPSEC_IKE_INVALID_HASH_SIZE,
    ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG,
    ERROR_IPSEC_IKE_INVALID_AUTH_ALG,
    ERROR_IPSEC_IKE_INVALID_SIG,
    ERROR_IPSEC_IKE_LOAD_FAILED,
    ERROR_IPSEC_IKE_RPC_DELETE,
    ERROR_IPSEC_IKE_BENIGN_REINIT,
    ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY,
    ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION,
    ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN,
    ERROR_IPSEC_IKE_MM_LIMIT,
    ERROR_IPSEC_IKE_NEGOTIATION_DISABLED,
    ERROR_IPSEC_IKE_QM_LIMIT,
    ERROR_IPSEC_IKE_MM_EXPIRED,
    ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID,
    ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH,
    ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID,
    ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD,
    ERROR_IPSEC_IKE_INVALID_UMATTS,
    ERROR_IPSEC_IKE_DOS_COOKIE_SENT,
    ERROR_IPSEC_IKE_SHUTTING_DOWN,
    ERROR_IPSEC_IKE_CGA_AUTH_FAILED,
    ERROR_IPSEC_IKE_PROCESS_ERR_NATOA,
    ERROR_IPSEC_IKE_INVALID_MM_FOR_QM,
    ERROR_IPSEC_IKE_QM_EXPIRED,
    ERROR_IPSEC_IKE_TOO_MANY_FILTERS,
    ERROR_IPSEC_IKE_NEG_STATUS_END,
    ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL,
    ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE,
    ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING,
    ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING,
    ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS,
    ERROR_IPSEC_IKE_RATELIMIT_DROP,
    ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE,
    ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE,
    ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE,
    ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY,
    ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE,
    ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END,
    ERROR_IPSEC_BAD_SPI,
    ERROR_IPSEC_SA_LIFETIME_EXPIRED,
    ERROR_IPSEC_WRONG_SA,
    ERROR_IPSEC_REPLAY_CHECK_FAILED,
    ERROR_IPSEC_INVALID_PACKET,
    ERROR_IPSEC_INTEGRITY_CHECK_FAILED,
    ERROR_IPSEC_CLEAR_TEXT_DROP,
    ERROR_IPSEC_AUTH_FIREWALL_DROP,
    ERROR_IPSEC_THROTTLE_DROP,
    ERROR_IPSEC_DOSP_BLOCK,
    ERROR_IPSEC_DOSP_RECEIVED_MULTICAST,
    ERROR_IPSEC_DOSP_INVALID_PACKET,
    ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED,
    ERROR_IPSEC_DOSP_MAX_ENTRIES,
    ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED,
    ERROR_IPSEC_DOSP_NOT_INSTALLED,
    ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES,
    ERROR_SXS_SECTION_NOT_FOUND,
    ERROR_SXS_CANT_GEN_ACTCTX,
    ERROR_SXS_INVALID_ACTCTXDATA_FORMAT,
    ERROR_SXS_ASSEMBLY_NOT_FOUND,
    ERROR_SXS_MANIFEST_FORMAT_ERROR,
    ERROR_SXS_MANIFEST_PARSE_ERROR,
    ERROR_SXS_ACTIVATION_CONTEXT_DISABLED,
    ERROR_SXS_KEY_NOT_FOUND,
    ERROR_SXS_VERSION_CONFLICT,
    ERROR_SXS_WRONG_SECTION_TYPE,
    ERROR_SXS_THREAD_QUERIES_DISABLED,
    ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET,
    ERROR_SXS_UNKNOWN_ENCODING_GROUP,
    ERROR_SXS_UNKNOWN_ENCODING,
    ERROR_SXS_INVALID_XML_NAMESPACE_URI,
    ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED,
    ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED,
    ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED,
    ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE,
    ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE,
    ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE,
    ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT,
    ERROR_SXS_DUPLICATE_DLL_NAME,
    ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME,
    ERROR_SXS_DUPLICATE_CLSID,
    ERROR_SXS_DUPLICATE_IID,
    ERROR_SXS_DUPLICATE_TLBID,
    ERROR_SXS_DUPLICATE_PROGID,
    ERROR_SXS_DUPLICATE_ASSEMBLY_NAME,
    ERROR_SXS_FILE_HASH_MISMATCH,
    ERROR_SXS_POLICY_PARSE_ERROR,
    ERROR_SXS_XML_E_MISSINGQUOTE,
    ERROR_SXS_XML_E_COMMENTSYNTAX,
    ERROR_SXS_XML_E_BADSTARTNAMECHAR,
    ERROR_SXS_XML_E_BADNAMECHAR,
    ERROR_SXS_XML_E_BADCHARINSTRING,
    ERROR_SXS_XML_E_XMLDECLSYNTAX,
    ERROR_SXS_XML_E_BADCHARDATA,
    ERROR_SXS_XML_E_MISSINGWHITESPACE,
    ERROR_SXS_XML_E_EXPECTINGTAGEND,
    ERROR_SXS_XML_E_MISSINGSEMICOLON,
    ERROR_SXS_XML_E_UNBALANCEDPAREN,
    ERROR_SXS_XML_E_INTERNALERROR,
    ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE,
    ERROR_SXS_XML_E_INCOMPLETE_ENCODING,
    ERROR_SXS_XML_E_MISSING_PAREN,
    ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE,
    ERROR_SXS_XML_E_MULTIPLE_COLONS,
    ERROR_SXS_XML_E_INVALID_DECIMAL,
    ERROR_SXS_XML_E_INVALID_HEXIDECIMAL,
    ERROR_SXS_XML_E_INVALID_UNICODE,
    ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK,
    ERROR_SXS_XML_E_UNEXPECTEDENDTAG,
    ERROR_SXS_XML_E_UNCLOSEDTAG,
    ERROR_SXS_XML_E_DUPLICATEATTRIBUTE,
    ERROR_SXS_XML_E_MULTIPLEROOTS,
    ERROR_SXS_XML_E_INVALIDATROOTLEVEL,
    ERROR_SXS_XML_E_BADXMLDECL,
    ERROR_SXS_XML_E_MISSINGROOT,
    ERROR_SXS_XML_E_UNEXPECTEDEOF,
    ERROR_SXS_XML_E_BADPEREFINSUBSET,
    ERROR_SXS_XML_E_UNCLOSEDSTARTTAG,
    ERROR_SXS_XML_E_UNCLOSEDENDTAG,
    ERROR_SXS_XML_E_UNCLOSEDSTRING,
    ERROR_SXS_XML_E_UNCLOSEDCOMMENT,
    ERROR_SXS_XML_E_UNCLOSEDDECL,
    ERROR_SXS_XML_E_UNCLOSEDCDATA,
    ERROR_SXS_XML_E_RESERVEDNAMESPACE,
    ERROR_SXS_XML_E_INVALIDENCODING,
    ERROR_SXS_XML_E_INVALIDSWITCH,
    ERROR_SXS_XML_E_BADXMLCASE,
    ERROR_SXS_XML_E_INVALID_STANDALONE,
    ERROR_SXS_XML_E_UNEXPECTED_STANDALONE,
    ERROR_SXS_XML_E_INVALID_VERSION,
    ERROR_SXS_XML_E_MISSINGEQUALS,
    ERROR_SXS_PROTECTION_RECOVERY_FAILED,
    ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT,
    ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT,
    ERROR_SXS_PROTECTION_CATALOG_NOT_VALID,
    ERROR_SXS_UNTRANSLATABLE_HRESULT,
    ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING,
    ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE,
    ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME,
    ERROR_SXS_ASSEMBLY_MISSING,
    ERROR_SXS_CORRUPT_ACTIVATION_STACK,
    ERROR_SXS_CORRUPTION,
    ERROR_SXS_EARLY_DEACTIVATION,
    ERROR_SXS_INVALID_DEACTIVATION,
    ERROR_SXS_MULTIPLE_DEACTIVATION,
    ERROR_SXS_PROCESS_TERMINATION_REQUESTED,
    ERROR_SXS_RELEASE_ACTIVATION_CONTEXT,
    ERROR_SXS_RELEASE_ACTIVATION_ONTEXT,
    ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY,
    ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE,
    ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME,
    ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE,
    ERROR_SXS_IDENTITY_PARSE_ERROR,
    ERROR_MALFORMED_SUBSTITUTION_STRING,
    ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN,
    ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN,
    ERROR_UNMAPPED_SUBSTITUTION_STRING,
    ERROR_SXS_ASSEMBLY_NOT_LOCKED,
    ERROR_SXS_COMPONENT_STORE_CORRUPT,
    ERROR_ADVANCED_INSTALLER_FAILED,
    ERROR_XML_ENCODING_MISMATCH,
    ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT,
    ERROR_SXS_IDENTITIES_DIFFERENT,
    ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT,
    ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY,
    ERROR_SXS_MANIFEST_TOO_BIG,
    ERROR_SXS_SETTING_NOT_REGISTERED,
    ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE,
    ERROR_SMI_PRIMITIVE_INSTALLER_FAILED,
    ERROR_GENERIC_COMMAND_FAILED,
    ERROR_SXS_FILE_HASH_MISSING,
    ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS,
    ERROR_EVT_INVALID_CHANNEL_PATH,
    ERROR_EVT_INVALID_QUERY,
    ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND,
    ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND,
    ERROR_EVT_INVALID_PUBLISHER_NAME,
    ERROR_EVT_INVALID_EVENT_DATA,
    ERROR_EVT_CHANNEL_NOT_FOUND,
    ERROR_EVT_MALFORMED_XML_TEXT,
    ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL,
    ERROR_EVT_CONFIGURATION_ERROR,
    ERROR_EVT_QUERY_RESULT_STALE,
    ERROR_EVT_QUERY_RESULT_INVALID_POSITION,
    ERROR_EVT_NON_VALIDATING_MSXML,
    ERROR_EVT_FILTER_ALREADYSCOPED,
    ERROR_EVT_FILTER_NOTELTSET,
    ERROR_EVT_FILTER_INVARG,
    ERROR_EVT_FILTER_INVTEST,
    ERROR_EVT_FILTER_INVTYPE,
    ERROR_EVT_FILTER_PARSEERR,
    ERROR_EVT_FILTER_UNSUPPORTEDOP,
    ERROR_EVT_FILTER_UNEXPECTEDTOKEN,
    ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL,
    ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE,
    ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE,
    ERROR_EVT_CHANNEL_CANNOT_ACTIVATE,
    ERROR_EVT_FILTER_TOO_COMPLEX,
    ERROR_EVT_MESSAGE_NOT_FOUND,
    ERROR_EVT_MESSAGE_ID_NOT_FOUND,
    ERROR_EVT_UNRESOLVED_VALUE_INSERT,
    ERROR_EVT_UNRESOLVED_PARAMETER_INSERT,
    ERROR_EVT_MAX_INSERTS_REACHED,
    ERROR_EVT_EVENT_DEFINITION_NOT_FOUND,
    ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND,
    ERROR_EVT_VERSION_TOO_OLD,
    ERROR_EVT_VERSION_TOO_NEW,
    ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY,
    ERROR_EVT_PUBLISHER_DISABLED,
    ERROR_EVT_FILTER_OUT_OF_RANGE,
    ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE,
    ERROR_EC_LOG_DISABLED,
    ERROR_EC_CIRCULAR_FORWARDING,
    ERROR_EC_CREDSTORE_FULL,
    ERROR_EC_CRED_NOT_FOUND,
    ERROR_EC_NO_ACTIVE_CHANNEL,
    ERROR_MUI_FILE_NOT_FOUND,
    ERROR_MUI_INVALID_FILE,
    ERROR_MUI_INVALID_RC_CONFIG,
    ERROR_MUI_INVALID_LOCALE_NAME,
    ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME,
    ERROR_MUI_FILE_NOT_LOADED,
    ERROR_RESOURCE_ENUM_USER_STOP,
    ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED,
    ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME,
    ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE,
    ERROR_MRM_INVALID_PRICONFIG,
    ERROR_MRM_INVALID_FILE_TYPE,
    ERROR_MRM_UNKNOWN_QUALIFIER,
    ERROR_MRM_INVALID_QUALIFIER_VALUE,
    ERROR_MRM_NO_CANDIDATE,
    ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE,
    ERROR_MRM_RESOURCE_TYPE_MISMATCH,
    ERROR_MRM_DUPLICATE_MAP_NAME,
    ERROR_MRM_DUPLICATE_ENTRY,
    ERROR_MRM_INVALID_RESOURCE_IDENTIFIER,
    ERROR_MRM_FILEPATH_TOO_LONG,
    ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE,
    ERROR_MRM_INVALID_PRI_FILE,
    ERROR_MRM_NAMED_RESOURCE_NOT_FOUND,
    ERROR_MRM_MAP_NOT_FOUND,
    ERROR_MRM_UNSUPPORTED_PROFILE_TYPE,
    ERROR_MRM_INVALID_QUALIFIER_OPERATOR,
    ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE,
    ERROR_MRM_AUTOMERGE_ENABLED,
    ERROR_MRM_TOO_MANY_RESOURCES,
    ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE,
    ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE,
    ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD,
    ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST,
    ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT,
    ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE,
    ERROR_MRM_GENERATION_COUNT_MISMATCH,
    ERROR_PRI_MERGE_VERSION_MISMATCH,
    ERROR_PRI_MERGE_MISSING_SCHEMA,
    ERROR_PRI_MERGE_LOAD_FILE_FAILED,
    ERROR_PRI_MERGE_ADD_FILE_FAILED,
    ERROR_PRI_MERGE_WRITE_FILE_FAILED,
    ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED,
    ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED,
    ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED,
    ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED,
    ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED,
    ERROR_PRI_MERGE_INVALID_FILE_NAME,
    ERROR_MRM_PACKAGE_NOT_FOUND,
    ERROR_MRM_MISSING_DEFAULT_LANGUAGE,
    ERROR_MRM_SCOPE_ITEM_CONFLICT,
    ERROR_MCA_INVALID_CAPABILITIES_STRING,
    ERROR_MCA_INVALID_VCP_VERSION,
    ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION,
    ERROR_MCA_MCCS_VERSION_MISMATCH,
    ERROR_MCA_UNSUPPORTED_MCCS_VERSION,
    ERROR_MCA_INTERNAL_ERROR,
    ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED,
    ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE,
    ERROR_AMBIGUOUS_SYSTEM_DEVICE,
    ERROR_SYSTEM_DEVICE_NOT_FOUND,
    ERROR_HASH_NOT_SUPPORTED,
    ERROR_HASH_NOT_PRESENT,
    ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED,
    ERROR_GPIO_CLIENT_INFORMATION_INVALID,
    ERROR_GPIO_VERSION_NOT_SUPPORTED,
    ERROR_GPIO_INVALID_REGISTRATION_PACKET,
    ERROR_GPIO_OPERATION_DENIED,
    ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE,
    ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED,
    ERROR_CANNOT_SWITCH_RUNLEVEL,
    ERROR_INVALID_RUNLEVEL_SETTING,
    ERROR_RUNLEVEL_SWITCH_TIMEOUT,
    ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT,
    ERROR_RUNLEVEL_SWITCH_IN_PROGRESS,
    ERROR_SERVICES_FAILED_AUTOSTART,
    ERROR_COM_TASK_STOP_PENDING,
    ERROR_INSTALL_OPEN_PACKAGE_FAILED,
    ERROR_INSTALL_PACKAGE_NOT_FOUND,
    ERROR_INSTALL_INVALID_PACKAGE,
    ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED,
    ERROR_INSTALL_OUT_OF_DISK_SPACE,
    ERROR_INSTALL_NETWORK_FAILURE,
    ERROR_INSTALL_REGISTRATION_FAILURE,
    ERROR_INSTALL_DEREGISTRATION_FAILURE,
    ERROR_INSTALL_CANCEL,
    ERROR_INSTALL_FAILED,
    ERROR_REMOVE_FAILED,
    ERROR_PACKAGE_ALREADY_EXISTS,
    ERROR_NEEDS_REMEDIATION,
    ERROR_INSTALL_PREREQUISITE_FAILED,
    ERROR_PACKAGE_REPOSITORY_CORRUPTED,
    ERROR_INSTALL_POLICY_FAILURE,
    ERROR_PACKAGE_UPDATING,
    ERROR_DEPLOYMENT_BLOCKED_BY_POLICY,
    ERROR_PACKAGES_IN_USE,
    ERROR_RECOVERY_FILE_CORRUPT,
    ERROR_INVALID_STAGED_SIGNATURE,
    ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED,
    ERROR_INSTALL_PACKAGE_DOWNGRADE,
    ERROR_SYSTEM_NEEDS_REMEDIATION,
    ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN,
    ERROR_RESILIENCY_FILE_CORRUPT,
    ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING,
    ERROR_PACKAGE_MOVE_FAILED,
    ERROR_INSTALL_VOLUME_NOT_EMPTY,
    ERROR_INSTALL_VOLUME_OFFLINE,
    ERROR_INSTALL_VOLUME_CORRUPT,
    ERROR_NEEDS_REGISTRATION,
    ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE,
    ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED,
    ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE,
    ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM,
    ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING,
    ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE,
    ERROR_PACKAGE_STAGING_ONHOLD,
    ERROR_INSTALL_INVALID_RELATED_SET_UPDATE,
    ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY,
    ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF,
    ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED,
    ERROR_PACKAGES_REPUTATION_CHECK_FAILED,
    ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT,
    ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED,
    ERROR_APPINSTALLER_ACTIVATION_BLOCKED,
    ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED,
    ERROR_APPX_RAW_DATA_WRITE_FAILED,
    ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE,
    ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE,
    ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY,
    ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY,
    ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER,
    ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED,
    ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE,
    ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES,
    ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED,
    ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST,
    ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT,
    ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE,
    ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE,
    ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED,
    ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY,
    ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS,
    ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED,
    ERROR_MACHINE_SCOPE_NOT_ALLOWED,
    ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED,
    ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE,
    ERROR_PACKAGE_NOT_REGISTERED_FOR_USER,
    ERROR_PACKAGE_NAME_MISMATCH,
    ERROR_APPINSTALLER_URI_IN_USE,
    ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM,
    APPMODEL_ERROR_NO_PACKAGE,
    APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT,
    APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT,
    APPMODEL_ERROR_NO_APPLICATION,
    APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED,
    APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID,
    APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE,
    APPMODEL_ERROR_NO_MUTABLE_DIRECTORY,
    ERROR_STATE_LOAD_STORE_FAILED,
    ERROR_STATE_GET_VERSION_FAILED,
    ERROR_STATE_SET_VERSION_FAILED,
    ERROR_STATE_STRUCTURED_RESET_FAILED,
    ERROR_STATE_OPEN_CONTAINER_FAILED,
    ERROR_STATE_CREATE_CONTAINER_FAILED,
    ERROR_STATE_DELETE_CONTAINER_FAILED,
    ERROR_STATE_READ_SETTING_FAILED,
    ERROR_STATE_WRITE_SETTING_FAILED,
    ERROR_STATE_DELETE_SETTING_FAILED,
    ERROR_STATE_QUERY_SETTING_FAILED,
    ERROR_STATE_READ_COMPOSITE_SETTING_FAILED,
    ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED,
    ERROR_STATE_ENUMERATE_CONTAINER_FAILED,
    ERROR_STATE_ENUMERATE_SETTINGS_FAILED,
    ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED,
    ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED,
    ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED,
    ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED,
    ERROR_API_UNAVAILABLE,
    STORE_ERROR_UNLICENSED,
    STORE_ERROR_UNLICENSED_USER,
    STORE_ERROR_PENDING_COM_TRANSACTION,
    STORE_ERROR_LICENSE_REVOKED,
    ERROR_SUCCESS,
}

impl WIN32 {
    pub fn code(&self) -> u32 {
        return match self {
            WIN32::ERROR_INVALID_FUNCTION => 0x80070001 as u32,
            WIN32::PDH_CSTATUS_NEW_DATA => 0x80070001 as u32,
            WIN32::ERROR_FILE_NOT_FOUND => 0x80070002 as u32,
            WIN32::ERROR_PATH_NOT_FOUND => 0x80070003 as u32,
            WIN32::E_PATH_NOT_FOUND => 0x80070003 as u32,
            WIN32::ERROR_TOO_MANY_OPEN_FILES => 0x80070004 as u32,
            WIN32::ERROR_ACCESS_DENIED => 0x80070005 as u32,
            WIN32::E_ACCESSDENIED => 0x80070005 as u32,
            WIN32::ERROR_INVALID_HANDLE => 0x80070006 as u32,
            WIN32::E_HANDLE => 0x80070006 as u32,
            WIN32::ERROR_ARENA_TRASHED => 0x80070007 as u32,
            WIN32::ERROR_NOT_ENOUGH_MEMORY => 0x80070008 as u32,
            WIN32::ERROR_INVALID_BLOCK => 0x80070009 as u32,
            WIN32::ERROR_BAD_ENVIRONMENT => 0x8007000A as u32,
            WIN32::ERROR_BAD_FORMAT => 0x8007000B as u32,
            WIN32::ERROR_INVALID_ACCESS => 0x8007000C as u32,
            WIN32::ERROR_INVALID_DATA => 0x8007000D as u32,
            WIN32::E_OUTOFMEMORY => 0x8007000E as u32,
            WIN32::ERROR_OUTOFMEMORY => 0x8007000E as u32,
            WIN32::DDERR_OUTOFMEMORY => 0x8007000E as u32,
            WIN32::ERROR_INVALID_DRIVE => 0x8007000F as u32,
            WIN32::ERROR_CURRENT_DIRECTORY => 0x80070010 as u32,
            WIN32::ERROR_NOT_SAME_DEVICE => 0x80070011 as u32,
            WIN32::ERROR_NO_MORE_FILES => 0x80070012 as u32,
            WIN32::ERROR_WRITE_PROTECT => 0x80070013 as u32,
            WIN32::ERROR_BAD_UNIT => 0x80070014 as u32,
            WIN32::ERROR_NOT_READY => 0x80070015 as u32,
            WIN32::ERROR_BAD_COMMAND => 0x80070016 as u32,
            WIN32::ERROR_CRC => 0x80070017 as u32,
            WIN32::ERROR_BAD_LENGTH => 0x80070018 as u32,
            WIN32::ERROR_SEEK => 0x80070019 as u32,
            WIN32::ERROR_NOT_DOS_DISK => 0x8007001A as u32,
            WIN32::ERROR_SECTOR_NOT_FOUND => 0x8007001B as u32,
            WIN32::ERROR_OUT_OF_PAPER => 0x8007001C as u32,
            WIN32::ERROR_WRITE_FAULT => 0x8007001D as u32,
            WIN32::ERROR_READ_FAULT => 0x8007001E as u32,
            WIN32::ERROR_GEN_FAILURE => 0x8007001F as u32,
            WIN32::ERROR_SHARING_VIOLATION => 0x80070020 as u32,
            WIN32::E_SHARING_VIOLATION => 0x80070020 as u32,
            WIN32::ERROR_LOCK_VIOLATION => 0x80070021 as u32,
            WIN32::ERROR_WRONG_DISK => 0x80070022 as u32,
            WIN32::ERROR_SHARING_BUFFER_EXCEEDED => 0x80070024 as u32,
            WIN32::ERROR_HANDLE_EOF => 0x80070026 as u32,
            WIN32::ERROR_HANDLE_DISK_FULL => 0x80070027 as u32,
            WIN32::ERROR_NOT_SUPPORTED => 0x80070032 as u32,
            WIN32::ERROR_REM_NOT_LIST => 0x80070033 as u32,
            WIN32::ERROR_DUP_NAME => 0x80070034 as u32,
            WIN32::ERROR_BAD_NETPATH => 0x80070035 as u32,
            WIN32::ERROR_NETWORK_BUSY => 0x80070036 as u32,
            WIN32::ERROR_DEV_NOT_EXIST => 0x80070037 as u32,
            WIN32::ERROR_TOO_MANY_CMDS => 0x80070038 as u32,
            WIN32::ERROR_ADAP_HDW_ERR => 0x80070039 as u32,
            WIN32::ERROR_BAD_NET_RESP => 0x8007003A as u32,
            WIN32::ERROR_UNEXP_NET_ERR => 0x8007003B as u32,
            WIN32::ERROR_BAD_REM_ADAP => 0x8007003C as u32,
            WIN32::ERROR_PRINTQ_FULL => 0x8007003D as u32,
            WIN32::ERROR_NO_SPOOL_SPACE => 0x8007003E as u32,
            WIN32::ERROR_PRINT_CANCELLED => 0x8007003F as u32,
            WIN32::ERROR_NETNAME_DELETED => 0x80070040 as u32,
            WIN32::ERROR_NETWORK_ACCESS_DENIED => 0x80070041 as u32,
            WIN32::ERROR_BAD_DEV_TYPE => 0x80070042 as u32,
            WIN32::ERROR_BAD_NET_NAME => 0x80070043 as u32,
            WIN32::ERROR_TOO_MANY_NAMES => 0x80070044 as u32,
            WIN32::ERROR_TOO_MANY_SESS => 0x80070045 as u32,
            WIN32::ERROR_SHARING_PAUSED => 0x80070046 as u32,
            WIN32::ERROR_REQ_NOT_ACCEP => 0x80070047 as u32,
            WIN32::ERROR_REDIR_PAUSED => 0x80070048 as u32,
            WIN32::ERROR_FILE_EXISTS => 0x80070050 as u32,
            WIN32::ERROR_CANNOT_MAKE => 0x80070052 as u32,
            WIN32::ERROR_FAIL_I24 => 0x80070053 as u32,
            WIN32::ERROR_OUT_OF_STRUCTURES => 0x80070054 as u32,
            WIN32::ERROR_ALREADY_ASSIGNED => 0x80070055 as u32,
            WIN32::ERROR_INVALID_PASSWORD => 0x80070056 as u32,
            WIN32::ERROR_INVALID_PARAMETER => 0x80070057 as u32,
            WIN32::E_INVALIDARG => 0x80070057 as u32,
            WIN32::DDERR_INVALIDPARAMS => 0x80070057 as u32,
            WIN32::ERROR_NET_WRITE_FAULT => 0x80070058 as u32,
            WIN32::ERROR_NO_PROC_SLOTS => 0x80070059 as u32,
            WIN32::ERROR_TOO_MANY_SEMAPHORES => 0x80070064 as u32,
            WIN32::ERROR_EXCL_SEM_ALREADY_OWNED => 0x80070065 as u32,
            WIN32::ERROR_SEM_IS_SET => 0x80070066 as u32,
            WIN32::ERROR_TOO_MANY_SEM_REQUESTS => 0x80070067 as u32,
            WIN32::ERROR_INVALID_AT_INTERRUPT_TIME => 0x80070068 as u32,
            WIN32::ERROR_SEM_OWNER_DIED => 0x80070069 as u32,
            WIN32::ERROR_SEM_USER_LIMIT => 0x8007006A as u32,
            WIN32::ERROR_DISK_CHANGE => 0x8007006B as u32,
            WIN32::ERROR_DRIVE_LOCKED => 0x8007006C as u32,
            WIN32::ERROR_BROKEN_PIPE => 0x8007006D as u32,
            WIN32::ERROR_OPEN_FAILED => 0x8007006E as u32,
            WIN32::ERROR_BUFFER_OVERFLOW => 0x8007006F as u32,
            WIN32::ERROR_DISK_FULL => 0x80070070 as u32,
            WIN32::ERROR_NO_MORE_SEARCH_HANDLES => 0x80070071 as u32,
            WIN32::ERROR_INVALID_TARGET_HANDLE => 0x80070072 as u32,
            WIN32::ERROR_INVALID_CATEGORY => 0x80070075 as u32,
            WIN32::ERROR_INVALID_VERIFY_SWITCH => 0x80070076 as u32,
            WIN32::ERROR_BAD_DRIVER_LEVEL => 0x80070077 as u32,
            WIN32::ERROR_CALL_NOT_IMPLEMENTED => 0x80070078 as u32,
            WIN32::ERROR_SEM_TIMEOUT => 0x80070079 as u32,
            WIN32::ERROR_INSUFFICIENT_BUFFER => 0x8007007A as u32,
            WIN32::ERROR_INVALID_NAME => 0x8007007B as u32,
            WIN32::ERROR_INVALID_LEVEL => 0x8007007C as u32,
            WIN32::ERROR_NO_VOLUME_LABEL => 0x8007007D as u32,
            WIN32::ERROR_MOD_NOT_FOUND => 0x8007007E as u32,
            WIN32::ERROR_PROC_NOT_FOUND => 0x8007007F as u32,
            WIN32::ERROR_WAIT_NO_CHILDREN => 0x80070080 as u32,
            WIN32::ERROR_CHILD_NOT_COMPLETE => 0x80070081 as u32,
            WIN32::ERROR_DIRECT_ACCESS_HANDLE => 0x80070082 as u32,
            WIN32::ERROR_NEGATIVE_SEEK => 0x80070083 as u32,
            WIN32::ERROR_SEEK_ON_DEVICE => 0x80070084 as u32,
            WIN32::ERROR_IS_JOIN_TARGET => 0x80070085 as u32,
            WIN32::ERROR_IS_JOINED => 0x80070086 as u32,
            WIN32::ERROR_IS_SUBSTED => 0x80070087 as u32,
            WIN32::ERROR_NOT_JOINED => 0x80070088 as u32,
            WIN32::ERROR_NOT_SUBSTED => 0x80070089 as u32,
            WIN32::ERROR_JOIN_TO_JOIN => 0x8007008A as u32,
            WIN32::ERROR_SUBST_TO_SUBST => 0x8007008B as u32,
            WIN32::ERROR_JOIN_TO_SUBST => 0x8007008C as u32,
            WIN32::ERROR_SUBST_TO_JOIN => 0x8007008D as u32,
            WIN32::ERROR_BUSY_DRIVE => 0x8007008E as u32,
            WIN32::ERROR_SAME_DRIVE => 0x8007008F as u32,
            WIN32::ERROR_DIR_NOT_ROOT => 0x80070090 as u32,
            WIN32::ERROR_DIR_NOT_EMPTY => 0x80070091 as u32,
            WIN32::ERROR_IS_SUBST_PATH => 0x80070092 as u32,
            WIN32::ERROR_IS_JOIN_PATH => 0x80070093 as u32,
            WIN32::ERROR_PATH_BUSY => 0x80070094 as u32,
            WIN32::ERROR_IS_SUBST_TARGET => 0x80070095 as u32,
            WIN32::ERROR_SYSTEM_TRACE => 0x80070096 as u32,
            WIN32::ERROR_INVALID_EVENT_COUNT => 0x80070097 as u32,
            WIN32::ERROR_TOO_MANY_MUXWAITERS => 0x80070098 as u32,
            WIN32::ERROR_INVALID_LIST_FORMAT => 0x80070099 as u32,
            WIN32::ERROR_LABEL_TOO_LONG => 0x8007009A as u32,
            WIN32::ERROR_TOO_MANY_TCBS => 0x8007009B as u32,
            WIN32::ERROR_SIGNAL_REFUSED => 0x8007009C as u32,
            WIN32::ERROR_DISCARDED => 0x8007009D as u32,
            WIN32::ERROR_NOT_LOCKED => 0x8007009E as u32,
            WIN32::ERROR_BAD_THREADID_ADDR => 0x8007009F as u32,
            WIN32::ERROR_BAD_ARGUMENTS => 0x800700A0 as u32,
            WIN32::ERROR_BAD_PATHNAME => 0x800700A1 as u32,
            WIN32::ERROR_SIGNAL_PENDING => 0x800700A2 as u32,
            WIN32::ERROR_MAX_THRDS_REACHED => 0x800700A4 as u32,
            WIN32::ERROR_LOCK_FAILED => 0x800700A7 as u32,
            WIN32::ERROR_BUSY => 0x800700AA as u32,
            WIN32::ERROR_DEVICE_SUPPORT_IN_PROGRESS => 0x800700AB as u32,
            WIN32::ERROR_CANCEL_VIOLATION => 0x800700AD as u32,
            WIN32::ERROR_ATOMIC_LOCKS_NOT_SUPPORTED => 0x800700AE as u32,
            WIN32::ERROR_INVALID_SEGMENT_NUMBER => 0x800700B4 as u32,
            WIN32::ERROR_INVALID_ORDINAL => 0x800700B6 as u32,
            WIN32::ERROR_ALREADY_EXISTS => 0x800700B7 as u32,
            WIN32::ERROR_INVALID_FLAG_NUMBER => 0x800700BA as u32,
            WIN32::ERROR_SEM_NOT_FOUND => 0x800700BB as u32,
            WIN32::ERROR_INVALID_STARTING_CODESEG => 0x800700BC as u32,
            WIN32::ERROR_INVALID_STACKSEG => 0x800700BD as u32,
            WIN32::ERROR_INVALID_MODULETYPE => 0x800700BE as u32,
            WIN32::ERROR_INVALID_EXE_SIGNATURE => 0x800700BF as u32,
            WIN32::ERROR_EXE_MARKED_INVALID => 0x800700C0 as u32,
            WIN32::ERROR_BAD_EXE_FORMAT => 0x800700C1 as u32,
            WIN32::ERROR_ITERATED_DATA_EXCEEDS_64k => 0x800700C2 as u32,
            WIN32::ERROR_INVALID_MINALLOCSIZE => 0x800700C3 as u32,
            WIN32::ERROR_DYNLINK_FROM_INVALID_RING => 0x800700C4 as u32,
            WIN32::ERROR_IOPL_NOT_ENABLED => 0x800700C5 as u32,
            WIN32::ERROR_INVALID_SEGDPL => 0x800700C6 as u32,
            WIN32::ERROR_AUTODATASEG_EXCEEDS_64k => 0x800700C7 as u32,
            WIN32::ERROR_RING2SEG_MUST_BE_MOVABLE => 0x800700C8 as u32,
            WIN32::ERROR_RELOC_CHAIN_XEEDS_SEGLIM => 0x800700C9 as u32,
            WIN32::ERROR_INFLOOP_IN_RELOC_CHAIN => 0x800700CA as u32,
            WIN32::ERROR_ENVVAR_NOT_FOUND => 0x800700CB as u32,
            WIN32::ERROR_NO_SIGNAL_SENT => 0x800700CD as u32,
            WIN32::ERROR_FILENAME_EXCED_RANGE => 0x800700CE as u32,
            WIN32::ERROR_RING2_STACK_IN_USE => 0x800700CF as u32,
            WIN32::ERROR_META_EXPANSION_TOO_LONG => 0x800700D0 as u32,
            WIN32::ERROR_INVALID_SIGNAL_NUMBER => 0x800700D1 as u32,
            WIN32::ERROR_THREAD_1_INACTIVE => 0x800700D2 as u32,
            WIN32::ERROR_LOCKED => 0x800700D4 as u32,
            WIN32::ERROR_TOO_MANY_MODULES => 0x800700D6 as u32,
            WIN32::ERROR_NESTING_NOT_ALLOWED => 0x800700D7 as u32,
            WIN32::ERROR_EXE_MACHINE_TYPE_MISMATCH => 0x800700D8 as u32,
            WIN32::ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY => 0x800700D9 as u32,
            WIN32::ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY => 0x800700DA as u32,
            WIN32::ERROR_FILE_CHECKED_OUT => 0x800700DC as u32,
            WIN32::ERROR_CHECKOUT_REQUIRED => 0x800700DD as u32,
            WIN32::ERROR_BAD_FILE_TYPE => 0x800700DE as u32,
            WIN32::ERROR_FILE_TOO_LARGE => 0x800700DF as u32,
            WIN32::ERROR_FORMS_AUTH_REQUIRED => 0x800700E0 as u32,
            WIN32::ERROR_VIRUS_INFECTED => 0x800700E1 as u32,
            WIN32::ERROR_VIRUS_DELETED => 0x800700E2 as u32,
            WIN32::ERROR_PIPE_LOCAL => 0x800700E5 as u32,
            WIN32::ERROR_BAD_PIPE => 0x800700E6 as u32,
            WIN32::ERROR_PIPE_BUSY => 0x800700E7 as u32,
            WIN32::ERROR_NO_DATA => 0x800700E8 as u32,
            WIN32::ERROR_PIPE_NOT_CONNECTED => 0x800700E9 as u32,
            WIN32::ERROR_MORE_DATA => 0x800700EA as u32,
            WIN32::ERROR_NO_WORK_DONE => 0x800700EB as u32,
            WIN32::ERROR_VC_DISCONNECTED => 0x800700F0 as u32,
            WIN32::ERROR_INVALID_EA_NAME => 0x800700FE as u32,
            WIN32::ERROR_EA_LIST_INCONSISTENT => 0x800700FF as u32,
            WIN32::WAIT_TIMEOUT => 0x80070102 as u32,
            WIN32::ERROR_NO_MORE_ITEMS => 0x80070103 as u32,
            WIN32::ERROR_CANNOT_COPY => 0x8007010A as u32,
            WIN32::ERROR_DIRECTORY => 0x8007010B as u32,
            WIN32::ERROR_EAS_DIDNT_FIT => 0x80070113 as u32,
            WIN32::ERROR_EA_FILE_CORRUPT => 0x80070114 as u32,
            WIN32::ERROR_EA_TABLE_FULL => 0x80070115 as u32,
            WIN32::ERROR_INVALID_EA_HANDLE => 0x80070116 as u32,
            WIN32::ERROR_EAS_NOT_SUPPORTED => 0x8007011A as u32,
            WIN32::ERROR_NOT_OWNER => 0x80070120 as u32,
            WIN32::ERROR_TOO_MANY_POSTS => 0x8007012A as u32,
            WIN32::ERROR_PARTIAL_COPY => 0x8007012B as u32,
            WIN32::ERROR_OPLOCK_NOT_GRANTED => 0x8007012C as u32,
            WIN32::ERROR_INVALID_OPLOCK_PROTOCOL => 0x8007012D as u32,
            WIN32::ERROR_DISK_TOO_FRAGMENTED => 0x8007012E as u32,
            WIN32::ERROR_DELETE_PENDING => 0x8007012F as u32,
            WIN32::ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING => 0x80070130 as u32,
            WIN32::ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME => 0x80070131 as u32,
            WIN32::ERROR_SECURITY_STREAM_IS_INCONSISTENT => 0x80070132 as u32,
            WIN32::ERROR_INVALID_LOCK_RANGE => 0x80070133 as u32,
            WIN32::ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT => 0x80070134 as u32,
            WIN32::ERROR_NOTIFICATION_GUID_ALREADY_DEFINED => 0x80070135 as u32,
            WIN32::ERROR_INVALID_EXCEPTION_HANDLER => 0x80070136 as u32,
            WIN32::ERROR_DUPLICATE_PRIVILEGES => 0x80070137 as u32,
            WIN32::ERROR_NO_RANGES_PROCESSED => 0x80070138 as u32,
            WIN32::ERROR_NOT_ALLOWED_ON_SYSTEM_FILE => 0x80070139 as u32,
            WIN32::ERROR_DISK_RESOURCES_EXHAUSTED => 0x8007013A as u32,
            WIN32::ERROR_INVALID_TOKEN => 0x8007013B as u32,
            WIN32::ERROR_DEVICE_FEATURE_NOT_SUPPORTED => 0x8007013C as u32,
            WIN32::ERROR_MR_MID_NOT_FOUND => 0x8007013D as u32,
            WIN32::ERROR_SCOPE_NOT_FOUND => 0x8007013E as u32,
            WIN32::ERROR_UNDEFINED_SCOPE => 0x8007013F as u32,
            WIN32::ERROR_INVALID_CAP => 0x80070140 as u32,
            WIN32::ERROR_DEVICE_UNREACHABLE => 0x80070141 as u32,
            WIN32::ERROR_DEVICE_NO_RESOURCES => 0x80070142 as u32,
            WIN32::ERROR_DATA_CHECKSUM_ERROR => 0x80070143 as u32,
            WIN32::ERROR_INTERMIXED_KERNEL_EA_OPERATION => 0x80070144 as u32,
            WIN32::ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED => 0x80070146 as u32,
            WIN32::ERROR_OFFSET_ALIGNMENT_VIOLATION => 0x80070147 as u32,
            WIN32::ERROR_INVALID_FIELD_IN_PARAMETER_LIST => 0x80070148 as u32,
            WIN32::ERROR_OPERATION_IN_PROGRESS => 0x80070149 as u32,
            WIN32::ERROR_BAD_DEVICE_PATH => 0x8007014A as u32,
            WIN32::ERROR_TOO_MANY_DESCRIPTORS => 0x8007014B as u32,
            WIN32::ERROR_SCRUB_DATA_DISABLED => 0x8007014C as u32,
            WIN32::ERROR_NOT_REDUNDANT_STORAGE => 0x8007014D as u32,
            WIN32::ERROR_RESIDENT_FILE_NOT_SUPPORTED => 0x8007014E as u32,
            WIN32::ERROR_COMPRESSED_FILE_NOT_SUPPORTED => 0x8007014F as u32,
            WIN32::ERROR_DIRECTORY_NOT_SUPPORTED => 0x80070150 as u32,
            WIN32::ERROR_NOT_READ_FROM_COPY => 0x80070151 as u32,
            WIN32::ERROR_FT_WRITE_FAILURE => 0x80070152 as u32,
            WIN32::ERROR_FT_DI_SCAN_REQUIRED => 0x80070153 as u32,
            WIN32::ERROR_INVALID_KERNEL_INFO_VERSION => 0x80070154 as u32,
            WIN32::ERROR_INVALID_PEP_INFO_VERSION => 0x80070155 as u32,
            WIN32::ERROR_OBJECT_NOT_EXTERNALLY_BACKED => 0x80070156 as u32,
            WIN32::ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN => 0x80070157 as u32,
            WIN32::ERROR_COMPRESSION_NOT_BENEFICIAL => 0x80070158 as u32,
            WIN32::ERROR_STORAGE_TOPOLOGY_ID_MISMATCH => 0x80070159 as u32,
            WIN32::ERROR_BLOCKED_BY_PARENTAL_CONTROLS => 0x8007015A as u32,
            WIN32::ERROR_BLOCK_TOO_MANY_REFERENCES => 0x8007015B as u32,
            WIN32::ERROR_MARKED_TO_DISALLOW_WRITES => 0x8007015C as u32,
            WIN32::ERROR_ENCLAVE_FAILURE => 0x8007015D as u32,
            WIN32::ERROR_FAIL_NOACTION_REBOOT => 0x8007015E as u32,
            WIN32::ERROR_FAIL_SHUTDOWN => 0x8007015F as u32,
            WIN32::ERROR_FAIL_RESTART => 0x80070160 as u32,
            WIN32::ERROR_MAX_SESSIONS_REACHED => 0x80070161 as u32,
            WIN32::ERROR_NETWORK_ACCESS_DENIED_EDP => 0x80070162 as u32,
            WIN32::ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL => 0x80070163 as u32,
            WIN32::ERROR_EDP_POLICY_DENIES_OPERATION => 0x80070164 as u32,
            WIN32::ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED => 0x80070165 as u32,
            WIN32::ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT => 0x80070166 as u32,
            WIN32::ERROR_CLOUD_FILE_PROVIDER_UNKNOWN => 0x80070166 as u32,
            WIN32::ERROR_DEVICE_IN_MAINTENANCE => 0x80070167 as u32,
            WIN32::ERROR_NOT_SUPPORTED_ON_DAX => 0x80070168 as u32,
            WIN32::ERROR_DAX_MAPPING_EXISTS => 0x80070169 as u32,
            WIN32::ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING => 0x8007016A as u32,
            WIN32::ERROR_CLOUD_FILE_METADATA_CORRUPT => 0x8007016B as u32,
            WIN32::ERROR_CLOUD_FILE_METADATA_TOO_LARGE => 0x8007016C as u32,
            WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE => 0x8007016D as u32,
            WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH => 0x8007016E as u32,
            WIN32::ERROR_CHILD_PROCESS_BLOCKED => 0x8007016F as u32,
            WIN32::ERROR_STORAGE_LOST_DATA_PERSISTENCE => 0x80070170 as u32,
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE => 0x80070171 as u32,
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT => 0x80070172 as u32,
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY => 0x80070173 as u32,
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN => 0x80070174 as u32,
            WIN32::ERROR_GDI_HANDLE_LEAK => 0x80070175 as u32,
            WIN32::ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS => 0x80070176 as u32,
            WIN32::ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED => 0x80070177 as u32,
            WIN32::ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED => 0x80070177 as u32,
            WIN32::ERROR_NOT_A_CLOUD_FILE => 0x80070178 as u32,
            WIN32::ERROR_CLOUD_FILE_NOT_IN_SYNC => 0x80070179 as u32,
            WIN32::ERROR_CLOUD_FILE_ALREADY_CONNECTED => 0x8007017A as u32,
            WIN32::ERROR_CLOUD_FILE_NOT_SUPPORTED => 0x8007017B as u32,
            WIN32::ERROR_CLOUD_FILE_INVALID_REQUEST => 0x8007017C as u32,
            WIN32::ERROR_CLOUD_FILE_READ_ONLY_VOLUME => 0x8007017D as u32,
            WIN32::ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY => 0x8007017E as u32,
            WIN32::ERROR_CLOUD_FILE_VALIDATION_FAILED => 0x8007017F as u32,
            WIN32::ERROR_SMB1_NOT_AVAILABLE => 0x80070180 as u32,
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION => 0x80070181 as u32,
            WIN32::ERROR_CLOUD_FILE_AUTHENTICATION_FAILED => 0x80070182 as u32,
            WIN32::ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES => 0x80070183 as u32,
            WIN32::ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE => 0x80070184 as u32,
            WIN32::ERROR_CLOUD_FILE_UNSUCCESSFUL => 0x80070185 as u32,
            WIN32::ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT => 0x80070186 as u32,
            WIN32::ERROR_CLOUD_FILE_IN_USE => 0x80070187 as u32,
            WIN32::ERROR_CLOUD_FILE_PINNED => 0x80070188 as u32,
            WIN32::ERROR_CLOUD_FILE_REQUEST_ABORTED => 0x80070189 as u32,
            WIN32::ERROR_CLOUD_FILE_PROPERTY_CORRUPT => 0x8007018A as u32,
            WIN32::ERROR_CLOUD_FILE_ACCESS_DENIED => 0x8007018B as u32,
            WIN32::ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS => 0x8007018C as u32,
            WIN32::ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT => 0x8007018D as u32,
            WIN32::ERROR_CLOUD_FILE_REQUEST_CANCELED => 0x8007018E as u32,
            WIN32::ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED => 0x8007018F as u32,
            WIN32::ERROR_THREAD_MODE_ALREADY_BACKGROUND => 0x80070190 as u32,
            WIN32::ERROR_THREAD_MODE_NOT_BACKGROUND => 0x80070191 as u32,
            WIN32::ERROR_PROCESS_MODE_ALREADY_BACKGROUND => 0x80070192 as u32,
            WIN32::ERROR_PROCESS_MODE_NOT_BACKGROUND => 0x80070193 as u32,
            WIN32::ERROR_CLOUD_FILE_PROVIDER_TERMINATED => 0x80070194 as u32,
            WIN32::ERROR_NOT_A_CLOUD_SYNC_ROOT => 0x80070195 as u32,
            WIN32::ERROR_FILE_PROTECTED_UNDER_DPL => 0x80070196 as u32,
            WIN32::ERROR_VOLUME_NOT_CLUSTER_ALIGNED => 0x80070197 as u32,
            WIN32::ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND => 0x80070198 as u32,
            WIN32::ERROR_APPX_FILE_NOT_ENCRYPTED => 0x80070199 as u32,
            WIN32::ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED => 0x8007019A as u32,
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET => 0x8007019B as u32,
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE => 0x8007019C as u32,
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER => 0x8007019D as u32,
            WIN32::ERROR_LINUX_SUBSYSTEM_NOT_PRESENT => 0x8007019E as u32,
            WIN32::ERROR_FT_READ_FAILURE => 0x8007019F as u32,
            WIN32::ERROR_STORAGE_RESERVE_ID_INVALID => 0x800701A0 as u32,
            WIN32::ERROR_STORAGE_RESERVE_DOES_NOT_EXIST => 0x800701A1 as u32,
            WIN32::ERROR_STORAGE_RESERVE_ALREADY_EXISTS => 0x800701A2 as u32,
            WIN32::ERROR_STORAGE_RESERVE_NOT_EMPTY => 0x800701A3 as u32,
            WIN32::ERROR_NOT_A_DAX_VOLUME => 0x800701A4 as u32,
            WIN32::ERROR_NOT_DAX_MAPPABLE => 0x800701A5 as u32,
            WIN32::ERROR_TIME_SENSITIVE_THREAD => 0x800701A6 as u32,
            WIN32::ERROR_DPL_NOT_SUPPORTED_FOR_USER => 0x800701A7 as u32,
            WIN32::ERROR_CASE_DIFFERING_NAMES_IN_DIR => 0x800701A8 as u32,
            WIN32::ERROR_FILE_NOT_SUPPORTED => 0x800701A9 as u32,
            WIN32::ERROR_CLOUD_FILE_REQUEST_TIMEOUT => 0x800701AA as u32,
            WIN32::ERROR_NO_TASK_QUEUE => 0x800701AB as u32,
            WIN32::ERROR_SRC_SRV_DLL_LOAD_FAILED => 0x800701AC as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_BTT => 0x800701AD as u32,
            WIN32::ERROR_ENCRYPTION_DISABLED => 0x800701AE as u32,
            WIN32::ERROR_ENCRYPTING_METADATA_DISALLOWED => 0x800701AF as u32,
            WIN32::ERROR_CANT_CLEAR_ENCRYPTION_FLAG => 0x800701B0 as u32,
            WIN32::ERROR_NO_SUCH_DEVICE => 0x800701B1 as u32,
            WIN32::ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED => 0x800701B2 as u32,
            WIN32::ERROR_FILE_SNAP_IN_PROGRESS => 0x800701B3 as u32,
            WIN32::ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED => 0x800701B4 as u32,
            WIN32::ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED => 0x800701B5 as u32,
            WIN32::ERROR_FILE_SNAP_IO_NOT_COORDINATED => 0x800701B6 as u32,
            WIN32::ERROR_FILE_SNAP_UNEXPECTED_ERROR => 0x800701B7 as u32,
            WIN32::ERROR_FILE_SNAP_INVALID_PARAMETER => 0x800701B8 as u32,
            WIN32::ERROR_UNSATISFIED_DEPENDENCIES => 0x800701B9 as u32,
            WIN32::ERROR_CASE_SENSITIVE_PATH => 0x800701BA as u32,
            WIN32::ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR => 0x800701BB as u32,
            WIN32::ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED => 0x800701BC as u32,
            WIN32::ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION => 0x800701BD as u32,
            WIN32::ERROR_DLP_POLICY_DENIES_OPERATION => 0x800701BE as u32,
            WIN32::ERROR_SECURITY_DENIES_OPERATION => 0x800701BF as u32,
            WIN32::ERROR_UNTRUSTED_MOUNT_POINT => 0x800701C0 as u32,
            WIN32::ERROR_DLP_POLICY_SILENTLY_FAIL => 0x800701C1 as u32,
            WIN32::ERROR_CAPAUTHZ_NOT_DEVUNLOCKED => 0x800701C2 as u32,
            WIN32::ERROR_CAPAUTHZ_CHANGE_TYPE => 0x800701C3 as u32,
            WIN32::ERROR_CAPAUTHZ_NOT_PROVISIONED => 0x800701C4 as u32,
            WIN32::ERROR_CAPAUTHZ_NOT_AUTHORIZED => 0x800701C5 as u32,
            WIN32::ERROR_CAPAUTHZ_NO_POLICY => 0x800701C6 as u32,
            WIN32::ERROR_CAPAUTHZ_DB_CORRUPTED => 0x800701C7 as u32,
            WIN32::ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG => 0x800701C8 as u32,
            WIN32::ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY => 0x800701C9 as u32,
            WIN32::ERROR_CAPAUTHZ_SCCD_PARSE_ERROR => 0x800701CA as u32,
            WIN32::ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED => 0x800701CB as u32,
            WIN32::ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH => 0x800701CC as u32,
            WIN32::ERROR_CIMFS_IMAGE_CORRUPT => 0x800701D6 as u32,
            WIN32::ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED => 0x800701D7 as u32,
            WIN32::ERROR_STORAGE_STACK_ACCESS_DENIED => 0x800701D8 as u32,
            WIN32::ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES => 0x800701D9 as u32,
            WIN32::ERROR_INDEX_OUT_OF_BOUNDS => 0x800701DA as u32,
            WIN32::ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT => 0x800701DB as u32,
            WIN32::ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT => 0x800701E0 as u32,
            WIN32::ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT => 0x800701E1 as u32,
            WIN32::ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT => 0x800701E2 as u32,
            WIN32::ERROR_DEVICE_HARDWARE_ERROR => 0x800701E3 as u32,
            WIN32::ERROR_INVALID_ADDRESS => 0x800701E7 as u32,
            WIN32::ERROR_HAS_SYSTEM_CRITICAL_FILES => 0x800701E8 as u32,
            WIN32::ERROR_ENCRYPTED_FILE_NOT_SUPPORTED => 0x800701E9 as u32,
            WIN32::ERROR_SPARSE_FILE_NOT_SUPPORTED => 0x800701EA as u32,
            WIN32::ERROR_PAGEFILE_NOT_SUPPORTED => 0x800701EB as u32,
            WIN32::ERROR_VOLUME_NOT_SUPPORTED => 0x800701EC as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_BYPASSIO => 0x800701ED as u32,
            WIN32::ERROR_NO_BYPASSIO_DRIVER_SUPPORT => 0x800701EE as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_ENCRYPTION => 0x800701EF as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_COMPRESSION => 0x800701F0 as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_REPLICATION => 0x800701F1 as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION => 0x800701F2 as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_AUDITING => 0x800701F3 as u32,
            WIN32::ERROR_USER_PROFILE_LOAD => 0x800701F4 as u32,
            WIN32::ERROR_SESSION_KEY_TOO_SHORT => 0x800701F5 as u32,
            WIN32::ERROR_ACCESS_DENIED_APPDATA => 0x800701F6 as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_MONITORING => 0x800701F7 as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_SNAPSHOT => 0x800701F8 as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION => 0x800701F9 as u32,
            WIN32::ERROR_BYPASSIO_FLT_NOT_SUPPORTED => 0x800701FA as u32,
            WIN32::ERROR_DEVICE_RESET_REQUIRED => 0x800701FB as u32,
            WIN32::ERROR_VOLUME_WRITE_ACCESS_DENIED => 0x800701FC as u32,
            WIN32::ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE => 0x800701FD as u32,
            WIN32::ERROR_FS_METADATA_INCONSISTENT => 0x800701FE as u32,
            WIN32::ERROR_BLOCK_WEAK_REFERENCE_INVALID => 0x800701FF as u32,
            WIN32::ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID => 0x80070200 as u32,
            WIN32::ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID => 0x80070201 as u32,
            WIN32::ERROR_BLOCK_SHARED => 0x80070202 as u32,
            WIN32::ERROR_ARITHMETIC_OVERFLOW => 0x80070216 as u32,
            WIN32::ERROR_PIPE_CONNECTED => 0x80070217 as u32,
            WIN32::ERROR_PIPE_LISTENING => 0x80070218 as u32,
            WIN32::ERROR_VERIFIER_STOP => 0x80070219 as u32,
            WIN32::ERROR_ABIOS_ERROR => 0x8007021A as u32,
            WIN32::ERROR_WX86_WARNING => 0x8007021B as u32,
            WIN32::ERROR_WX86_ERROR => 0x8007021C as u32,
            WIN32::ERROR_TIMER_NOT_CANCELED => 0x8007021D as u32,
            WIN32::ERROR_UNWIND => 0x8007021E as u32,
            WIN32::ERROR_BAD_STACK => 0x8007021F as u32,
            WIN32::ERROR_INVALID_UNWIND_TARGET => 0x80070220 as u32,
            WIN32::ERROR_INVALID_PORT_ATTRIBUTES => 0x80070221 as u32,
            WIN32::ERROR_PORT_MESSAGE_TOO_LONG => 0x80070222 as u32,
            WIN32::ERROR_INVALID_QUOTA_LOWER => 0x80070223 as u32,
            WIN32::ERROR_DEVICE_ALREADY_ATTACHED => 0x80070224 as u32,
            WIN32::ERROR_INSTRUCTION_MISALIGNMENT => 0x80070225 as u32,
            WIN32::ERROR_PROFILING_NOT_STARTED => 0x80070226 as u32,
            WIN32::ERROR_PROFILING_NOT_STOPPED => 0x80070227 as u32,
            WIN32::ERROR_COULD_NOT_INTERPRET => 0x80070228 as u32,
            WIN32::ERROR_PROFILING_AT_LIMIT => 0x80070229 as u32,
            WIN32::ERROR_CANT_WAIT => 0x8007022A as u32,
            WIN32::ERROR_CANT_TERMINATE_SELF => 0x8007022B as u32,
            WIN32::ERROR_UNEXPECTED_MM_CREATE_ERR => 0x8007022C as u32,
            WIN32::ERROR_UNEXPECTED_MM_MAP_ERROR => 0x8007022D as u32,
            WIN32::ERROR_UNEXPECTED_MM_EXTEND_ERR => 0x8007022E as u32,
            WIN32::ERROR_BAD_FUNCTION_TABLE => 0x8007022F as u32,
            WIN32::ERROR_NO_GUID_TRANSLATION => 0x80070230 as u32,
            WIN32::ERROR_INVALID_LDT_SIZE => 0x80070231 as u32,
            WIN32::ERROR_INVALID_LDT_OFFSET => 0x80070233 as u32,
            WIN32::ERROR_INVALID_LDT_DESCRIPTOR => 0x80070234 as u32,
            WIN32::ERROR_TOO_MANY_THREADS => 0x80070235 as u32,
            WIN32::ERROR_THREAD_NOT_IN_PROCESS => 0x80070236 as u32,
            WIN32::ERROR_PAGEFILE_QUOTA_EXCEEDED => 0x80070237 as u32,
            WIN32::ERROR_LOGON_SERVER_CONFLICT => 0x80070238 as u32,
            WIN32::ERROR_SYNCHRONIZATION_REQUIRED => 0x80070239 as u32,
            WIN32::ERROR_NET_OPEN_FAILED => 0x8007023A as u32,
            WIN32::ERROR_IO_PRIVILEGE_FAILED => 0x8007023B as u32,
            WIN32::ERROR_CONTROL_C_EXIT => 0x8007023C as u32,
            WIN32::ERROR_MISSING_SYSTEMFILE => 0x8007023D as u32,
            WIN32::ERROR_UNHANDLED_EXCEPTION => 0x8007023E as u32,
            WIN32::ERROR_APP_INIT_FAILURE => 0x8007023F as u32,
            WIN32::ERROR_PAGEFILE_CREATE_FAILED => 0x80070240 as u32,
            WIN32::ERROR_INVALID_IMAGE_HASH => 0x80070241 as u32,
            WIN32::ERROR_NO_PAGEFILE => 0x80070242 as u32,
            WIN32::ERROR_ILLEGAL_FLOAT_CONTEXT => 0x80070243 as u32,
            WIN32::ERROR_NO_EVENT_PAIR => 0x80070244 as u32,
            WIN32::ERROR_DOMAIN_CTRLR_CONFIG_ERROR => 0x80070245 as u32,
            WIN32::ERROR_ILLEGAL_CHARACTER => 0x80070246 as u32,
            WIN32::ERROR_UNDEFINED_CHARACTER => 0x80070247 as u32,
            WIN32::ERROR_FLOPPY_VOLUME => 0x80070248 as u32,
            WIN32::ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT => 0x80070249 as u32,
            WIN32::ERROR_BACKUP_CONTROLLER => 0x8007024A as u32,
            WIN32::ERROR_MUTANT_LIMIT_EXCEEDED => 0x8007024B as u32,
            WIN32::ERROR_FS_DRIVER_REQUIRED => 0x8007024C as u32,
            WIN32::ERROR_CANNOT_LOAD_REGISTRY_FILE => 0x8007024D as u32,
            WIN32::ERROR_DEBUG_ATTACH_FAILED => 0x8007024E as u32,
            WIN32::ERROR_SYSTEM_PROCESS_TERMINATED => 0x8007024F as u32,
            WIN32::ERROR_DATA_NOT_ACCEPTED => 0x80070250 as u32,
            WIN32::ERROR_VDM_HARD_ERROR => 0x80070251 as u32,
            WIN32::ERROR_DRIVER_CANCEL_TIMEOUT => 0x80070252 as u32,
            WIN32::ERROR_REPLY_MESSAGE_MISMATCH => 0x80070253 as u32,
            WIN32::ERROR_LOST_WRITEBEHIND_DATA => 0x80070254 as u32,
            WIN32::ERROR_CLIENT_SERVER_PARAMETERS_INVALID => 0x80070255 as u32,
            WIN32::ERROR_NOT_TINY_STREAM => 0x80070256 as u32,
            WIN32::ERROR_STACK_OVERFLOW_READ => 0x80070257 as u32,
            WIN32::ERROR_CONVERT_TO_LARGE => 0x80070258 as u32,
            WIN32::ERROR_FOUND_OUT_OF_SCOPE => 0x80070259 as u32,
            WIN32::ERROR_ALLOCATE_BUCKET => 0x8007025A as u32,
            WIN32::ERROR_MARSHALL_OVERFLOW => 0x8007025B as u32,
            WIN32::ERROR_INVALID_VARIANT => 0x8007025C as u32,
            WIN32::ERROR_BAD_COMPRESSION_BUFFER => 0x8007025D as u32,
            WIN32::ERROR_AUDIT_FAILED => 0x8007025E as u32,
            WIN32::ERROR_TIMER_RESOLUTION_NOT_SET => 0x8007025F as u32,
            WIN32::ERROR_INSUFFICIENT_LOGON_INFO => 0x80070260 as u32,
            WIN32::ERROR_BAD_DLL_ENTRYPOINT => 0x80070261 as u32,
            WIN32::ERROR_BAD_SERVICE_ENTRYPOINT => 0x80070262 as u32,
            WIN32::ERROR_IP_ADDRESS_CONFLICT1 => 0x80070263 as u32,
            WIN32::ERROR_IP_ADDRESS_CONFLICT2 => 0x80070264 as u32,
            WIN32::ERROR_REGISTRY_QUOTA_LIMIT => 0x80070265 as u32,
            WIN32::ERROR_NO_CALLBACK_ACTIVE => 0x80070266 as u32,
            WIN32::ERROR_PWD_TOO_SHORT => 0x80070267 as u32,
            WIN32::ERROR_PWD_TOO_RECENT => 0x80070268 as u32,
            WIN32::ERROR_PWD_HISTORY_CONFLICT => 0x80070269 as u32,
            WIN32::ERROR_UNSUPPORTED_COMPRESSION => 0x8007026A as u32,
            WIN32::ERROR_INVALID_HW_PROFILE => 0x8007026B as u32,
            WIN32::ERROR_INVALID_PLUGPLAY_DEVICE_PATH => 0x8007026C as u32,
            WIN32::ERROR_QUOTA_LIST_INCONSISTENT => 0x8007026D as u32,
            WIN32::ERROR_EVALUATION_EXPIRATION => 0x8007026E as u32,
            WIN32::ERROR_ILLEGAL_DLL_RELOCATION => 0x8007026F as u32,
            WIN32::ERROR_DLL_INIT_FAILED_LOGOFF => 0x80070270 as u32,
            WIN32::ERROR_VALIDATE_CONTINUE => 0x80070271 as u32,
            WIN32::ERROR_NO_MORE_MATCHES => 0x80070272 as u32,
            WIN32::ERROR_RANGE_LIST_CONFLICT => 0x80070273 as u32,
            WIN32::ERROR_SERVER_SID_MISMATCH => 0x80070274 as u32,
            WIN32::ERROR_CANT_ENABLE_DENY_ONLY => 0x80070275 as u32,
            WIN32::ERROR_FLOAT_MULTIPLE_FAULTS => 0x80070276 as u32,
            WIN32::ERROR_FLOAT_MULTIPLE_TRAPS => 0x80070277 as u32,
            WIN32::ERROR_NOINTERFACE => 0x80070278 as u32,
            WIN32::ERROR_DRIVER_FAILED_SLEEP => 0x80070279 as u32,
            WIN32::ERROR_CORRUPT_SYSTEM_FILE => 0x8007027A as u32,
            WIN32::ERROR_COMMITMENT_MINIMUM => 0x8007027B as u32,
            WIN32::ERROR_PNP_RESTART_ENUMERATION => 0x8007027C as u32,
            WIN32::ERROR_SYSTEM_IMAGE_BAD_SIGNATURE => 0x8007027D as u32,
            WIN32::ERROR_PNP_REBOOT_REQUIRED => 0x8007027E as u32,
            WIN32::ERROR_INSUFFICIENT_POWER => 0x8007027F as u32,
            WIN32::ERROR_MULTIPLE_FAULT_VIOLATION => 0x80070280 as u32,
            WIN32::ERROR_SYSTEM_SHUTDOWN => 0x80070281 as u32,
            WIN32::ERROR_PORT_NOT_SET => 0x80070282 as u32,
            WIN32::ERROR_DS_VERSION_CHECK_FAILURE => 0x80070283 as u32,
            WIN32::ERROR_RANGE_NOT_FOUND => 0x80070284 as u32,
            WIN32::ERROR_NOT_SAFE_MODE_DRIVER => 0x80070286 as u32,
            WIN32::ERROR_FAILED_DRIVER_ENTRY => 0x80070287 as u32,
            WIN32::ERROR_DEVICE_ENUMERATION_ERROR => 0x80070288 as u32,
            WIN32::ERROR_MOUNT_POINT_NOT_RESOLVED => 0x80070289 as u32,
            WIN32::ERROR_INVALID_DEVICE_OBJECT_PARAMETER => 0x8007028A as u32,
            WIN32::ERROR_MCA_OCCURED => 0x8007028B as u32,
            WIN32::ERROR_DRIVER_DATABASE_ERROR => 0x8007028C as u32,
            WIN32::ERROR_SYSTEM_HIVE_TOO_LARGE => 0x8007028D as u32,
            WIN32::ERROR_DRIVER_FAILED_PRIOR_UNLOAD => 0x8007028E as u32,
            WIN32::ERROR_VOLSNAP_PREPARE_HIBERNATE => 0x8007028F as u32,
            WIN32::ERROR_HIBERNATION_FAILURE => 0x80070290 as u32,
            WIN32::ERROR_PWD_TOO_LONG => 0x80070291 as u32,
            WIN32::ERROR_FILE_SYSTEM_LIMITATION => 0x80070299 as u32,
            WIN32::ERROR_ASSERTION_FAILURE => 0x8007029C as u32,
            WIN32::ERROR_ACPI_ERROR => 0x8007029D as u32,
            WIN32::ERROR_WOW_ASSERTION => 0x8007029E as u32,
            WIN32::ERROR_PNP_BAD_MPS_TABLE => 0x8007029F as u32,
            WIN32::ERROR_PNP_TRANSLATION_FAILED => 0x800702A0 as u32,
            WIN32::ERROR_PNP_IRQ_TRANSLATION_FAILED => 0x800702A1 as u32,
            WIN32::ERROR_PNP_INVALID_ID => 0x800702A2 as u32,
            WIN32::ERROR_WAKE_SYSTEM_DEBUGGER => 0x800702A3 as u32,
            WIN32::ERROR_HANDLES_CLOSED => 0x800702A4 as u32,
            WIN32::ERROR_EXTRANEOUS_INFORMATION => 0x800702A5 as u32,
            WIN32::ERROR_RXACT_COMMIT_NECESSARY => 0x800702A6 as u32,
            WIN32::ERROR_MEDIA_CHECK => 0x800702A7 as u32,
            WIN32::ERROR_GUID_SUBSTITUTION_MADE => 0x800702A8 as u32,
            WIN32::ERROR_STOPPED_ON_SYMLINK => 0x800702A9 as u32,
            WIN32::ERROR_LONGJUMP => 0x800702AA as u32,
            WIN32::ERROR_PLUGPLAY_QUERY_VETOED => 0x800702AB as u32,
            WIN32::ERROR_UNWIND_CONSOLIDATE => 0x800702AC as u32,
            WIN32::ERROR_REGISTRY_HIVE_RECOVERED => 0x800702AD as u32,
            WIN32::ERROR_DLL_MIGHT_BE_INSECURE => 0x800702AE as u32,
            WIN32::ERROR_DLL_MIGHT_BE_INCOMPATIBLE => 0x800702AF as u32,
            WIN32::ERROR_DBG_EXCEPTION_NOT_HANDLED => 0x800702B0 as u32,
            WIN32::ERROR_DBG_REPLY_LATER => 0x800702B1 as u32,
            WIN32::ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE => 0x800702B2 as u32,
            WIN32::ERROR_DBG_TERMINATE_THREAD => 0x800702B3 as u32,
            WIN32::ERROR_DBG_TERMINATE_PROCESS => 0x800702B4 as u32,
            WIN32::ERROR_DBG_CONTROL_C => 0x800702B5 as u32,
            WIN32::ERROR_DBG_PRINTEXCEPTION_C => 0x800702B6 as u32,
            WIN32::ERROR_DBG_RIPEXCEPTION => 0x800702B7 as u32,
            WIN32::ERROR_DBG_CONTROL_BREAK => 0x800702B8 as u32,
            WIN32::ERROR_DBG_COMMAND_EXCEPTION => 0x800702B9 as u32,
            WIN32::ERROR_OBJECT_NAME_EXISTS => 0x800702BA as u32,
            WIN32::ERROR_THREAD_WAS_SUSPENDED => 0x800702BB as u32,
            WIN32::ERROR_IMAGE_NOT_AT_BASE => 0x800702BC as u32,
            WIN32::ERROR_RXACT_STATE_CREATED => 0x800702BD as u32,
            WIN32::ERROR_SEGMENT_NOTIFICATION => 0x800702BE as u32,
            WIN32::ERROR_BAD_CURRENT_DIRECTORY => 0x800702BF as u32,
            WIN32::ERROR_FT_READ_RECOVERY_FROM_BACKUP => 0x800702C0 as u32,
            WIN32::ERROR_FT_WRITE_RECOVERY => 0x800702C1 as u32,
            WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH => 0x800702C2 as u32,
            WIN32::ERROR_RECEIVE_PARTIAL => 0x800702C3 as u32,
            WIN32::ERROR_RECEIVE_EXPEDITED => 0x800702C4 as u32,
            WIN32::ERROR_RECEIVE_PARTIAL_EXPEDITED => 0x800702C5 as u32,
            WIN32::ERROR_EVENT_DONE => 0x800702C6 as u32,
            WIN32::ERROR_EVENT_PENDING => 0x800702C7 as u32,
            WIN32::ERROR_CHECKING_FILE_SYSTEM => 0x800702C8 as u32,
            WIN32::ERROR_FATAL_APP_EXIT => 0x800702C9 as u32,
            WIN32::ERROR_PREDEFINED_HANDLE => 0x800702CA as u32,
            WIN32::ERROR_WAS_UNLOCKED => 0x800702CB as u32,
            WIN32::ERROR_SERVICE_NOTIFICATION => 0x800702CC as u32,
            WIN32::ERROR_WAS_LOCKED => 0x800702CD as u32,
            WIN32::ERROR_LOG_HARD_ERROR => 0x800702CE as u32,
            WIN32::ERROR_ALREADY_WIN32 => 0x800702CF as u32,
            WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE => 0x800702D0 as u32,
            WIN32::ERROR_NO_YIELD_PERFORMED => 0x800702D1 as u32,
            WIN32::ERROR_TIMER_RESUME_IGNORED => 0x800702D2 as u32,
            WIN32::ERROR_ARBITRATION_UNHANDLED => 0x800702D3 as u32,
            WIN32::ERROR_CARDBUS_NOT_SUPPORTED => 0x800702D4 as u32,
            WIN32::ERROR_MP_PROCESSOR_MISMATCH => 0x800702D5 as u32,
            WIN32::ERROR_HIBERNATED => 0x800702D6 as u32,
            WIN32::ERROR_RESUME_HIBERNATION => 0x800702D7 as u32,
            WIN32::ERROR_FIRMWARE_UPDATED => 0x800702D8 as u32,
            WIN32::ERROR_DRIVERS_LEAKING_LOCKED_PAGES => 0x800702D9 as u32,
            WIN32::ERROR_WAKE_SYSTEM => 0x800702DA as u32,
            WIN32::ERROR_WAIT_1 => 0x800702DB as u32,
            WIN32::ERROR_WAIT_2 => 0x800702DC as u32,
            WIN32::ERROR_WAIT_3 => 0x800702DD as u32,
            WIN32::ERROR_WAIT_63 => 0x800702DE as u32,
            WIN32::ERROR_ABANDONED_WAIT_0 => 0x800702DF as u32,
            WIN32::ERROR_ABANDONED_WAIT_63 => 0x800702E0 as u32,
            WIN32::ERROR_USER_APC => 0x800702E1 as u32,
            WIN32::ERROR_KERNEL_APC => 0x800702E2 as u32,
            WIN32::ERROR_ALERTED => 0x800702E3 as u32,
            WIN32::ERROR_ELEVATION_REQUIRED => 0x800702E4 as u32,
            WIN32::ERROR_REPARSE => 0x800702E5 as u32,
            WIN32::ERROR_OPLOCK_BREAK_IN_PROGRESS => 0x800702E6 as u32,
            WIN32::ERROR_VOLUME_MOUNTED => 0x800702E7 as u32,
            WIN32::ERROR_RXACT_COMMITTED => 0x800702E8 as u32,
            WIN32::ERROR_NOTIFY_CLEANUP => 0x800702E9 as u32,
            WIN32::ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED => 0x800702EA as u32,
            WIN32::ERROR_PAGE_FAULT_TRANSITION => 0x800702EB as u32,
            WIN32::ERROR_PAGE_FAULT_DEMAND_ZERO => 0x800702EC as u32,
            WIN32::ERROR_PAGE_FAULT_COPY_ON_WRITE => 0x800702ED as u32,
            WIN32::ERROR_PAGE_FAULT_GUARD_PAGE => 0x800702EE as u32,
            WIN32::ERROR_PAGE_FAULT_PAGING_FILE => 0x800702EF as u32,
            WIN32::ERROR_CACHE_PAGE_LOCKED => 0x800702F0 as u32,
            WIN32::ERROR_CRASH_DUMP => 0x800702F1 as u32,
            WIN32::ERROR_BUFFER_ALL_ZEROS => 0x800702F2 as u32,
            WIN32::ERROR_REPARSE_OBJECT => 0x800702F3 as u32,
            WIN32::ERROR_RESOURCE_REQUIREMENTS_CHANGED => 0x800702F4 as u32,
            WIN32::ERROR_TRANSLATION_COMPLETE => 0x800702F5 as u32,
            WIN32::ERROR_NOTHING_TO_TERMINATE => 0x800702F6 as u32,
            WIN32::ERROR_PROCESS_NOT_IN_JOB => 0x800702F7 as u32,
            WIN32::ERROR_PROCESS_IN_JOB => 0x800702F8 as u32,
            WIN32::ERROR_VOLSNAP_HIBERNATE_READY => 0x800702F9 as u32,
            WIN32::ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY => 0x800702FA as u32,
            WIN32::ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED => 0x800702FB as u32,
            WIN32::ERROR_INTERRUPT_STILL_CONNECTED => 0x800702FC as u32,
            WIN32::ERROR_WAIT_FOR_OPLOCK => 0x800702FD as u32,
            WIN32::ERROR_DBG_EXCEPTION_HANDLED => 0x800702FE as u32,
            WIN32::ERROR_DBG_CONTINUE => 0x800702FF as u32,
            WIN32::ERROR_CALLBACK_POP_STACK => 0x80070300 as u32,
            WIN32::ERROR_COMPRESSION_DISABLED => 0x80070301 as u32,
            WIN32::ERROR_CANTFETCHBACKWARDS => 0x80070302 as u32,
            WIN32::ERROR_CANTSCROLLBACKWARDS => 0x80070303 as u32,
            WIN32::ERROR_ROWSNOTRELEASED => 0x80070304 as u32,
            WIN32::ERROR_BAD_ACCESSOR_FLAGS => 0x80070305 as u32,
            WIN32::ERROR_ERRORS_ENCOUNTERED => 0x80070306 as u32,
            WIN32::ERROR_NOT_CAPABLE => 0x80070307 as u32,
            WIN32::ERROR_REQUEST_OUT_OF_SEQUENCE => 0x80070308 as u32,
            WIN32::ERROR_VERSION_PARSE_ERROR => 0x80070309 as u32,
            WIN32::ERROR_BADSTARTPOSITION => 0x8007030A as u32,
            WIN32::ERROR_MEMORY_HARDWARE => 0x8007030B as u32,
            WIN32::ERROR_DISK_REPAIR_DISABLED => 0x8007030C as u32,
            WIN32::ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE => 0x8007030D as u32,
            WIN32::ERROR_SYSTEM_POWERSTATE_TRANSITION => 0x8007030E as u32,
            WIN32::ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION => 0x8007030F as u32,
            WIN32::ERROR_MCA_EXCEPTION => 0x80070310 as u32,
            WIN32::ERROR_ACCESS_AUDIT_BY_POLICY => 0x80070311 as u32,
            WIN32::ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY => 0x80070312 as u32,
            WIN32::ERROR_ABANDON_HIBERFILE => 0x80070313 as u32,
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED => 0x80070314 as u32,
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR => 0x80070315 as u32,
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR => 0x80070316 as u32,
            WIN32::ERROR_BAD_MCFG_TABLE => 0x80070317 as u32,
            WIN32::ERROR_DISK_REPAIR_REDIRECTED => 0x80070318 as u32,
            WIN32::ERROR_DISK_REPAIR_UNSUCCESSFUL => 0x80070319 as u32,
            WIN32::ERROR_CORRUPT_LOG_OVERFULL => 0x8007031A as u32,
            WIN32::ERROR_CORRUPT_LOG_CORRUPTED => 0x8007031B as u32,
            WIN32::ERROR_CORRUPT_LOG_UNAVAILABLE => 0x8007031C as u32,
            WIN32::ERROR_CORRUPT_LOG_DELETED_FULL => 0x8007031D as u32,
            WIN32::ERROR_CORRUPT_LOG_CLEARED => 0x8007031E as u32,
            WIN32::ERROR_ORPHAN_NAME_EXHAUSTED => 0x8007031F as u32,
            WIN32::ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE => 0x80070320 as u32,
            WIN32::ERROR_CANNOT_GRANT_REQUESTED_OPLOCK => 0x80070321 as u32,
            WIN32::ERROR_CANNOT_BREAK_OPLOCK => 0x80070322 as u32,
            WIN32::ERROR_OPLOCK_HANDLE_CLOSED => 0x80070323 as u32,
            WIN32::ERROR_NO_ACE_CONDITION => 0x80070324 as u32,
            WIN32::ERROR_INVALID_ACE_CONDITION => 0x80070325 as u32,
            WIN32::ERROR_FILE_HANDLE_REVOKED => 0x80070326 as u32,
            WIN32::ERROR_IMAGE_AT_DIFFERENT_BASE => 0x80070327 as u32,
            WIN32::ERROR_ENCRYPTED_IO_NOT_POSSIBLE => 0x80070328 as u32,
            WIN32::ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS => 0x80070329 as u32,
            WIN32::ERROR_QUOTA_ACTIVITY => 0x8007032A as u32,
            WIN32::ERROR_HANDLE_REVOKED => 0x8007032B as u32,
            WIN32::ERROR_CALLBACK_INVOKE_INLINE => 0x8007032C as u32,
            WIN32::ERROR_CPU_SET_INVALID => 0x8007032D as u32,
            WIN32::ERROR_ENCLAVE_NOT_TERMINATED => 0x8007032E as u32,
            WIN32::ERROR_ENCLAVE_VIOLATION => 0x8007032F as u32,
            WIN32::ERROR_SERVER_TRANSPORT_CONFLICT => 0x80070330 as u32,
            WIN32::ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT => 0x80070331 as u32,
            WIN32::ERROR_FT_READ_FROM_COPY_FAILURE => 0x80070332 as u32,
            WIN32::ERROR_SECTION_DIRECT_MAP_ONLY => 0x80070333 as u32,
            WIN32::ERROR_EA_ACCESS_DENIED => 0x800703E2 as u32,
            WIN32::ERROR_OPERATION_ABORTED => 0x800703E3 as u32,
            WIN32::ERROR_IO_INCOMPLETE => 0x800703E4 as u32,
            WIN32::ERROR_IO_PENDING => 0x800703E5 as u32,
            WIN32::ERROR_NOACCESS => 0x800703E6 as u32,
            WIN32::ERROR_SWAPERROR => 0x800703E7 as u32,
            WIN32::ERROR_STACK_OVERFLOW => 0x800703E9 as u32,
            WIN32::ERROR_INVALID_MESSAGE => 0x800703EA as u32,
            WIN32::ERROR_CAN_NOT_COMPLETE => 0x800703EB as u32,
            WIN32::ERROR_INVALID_FLAGS => 0x800703EC as u32,
            WIN32::ERROR_UNRECOGNIZED_VOLUME => 0x800703ED as u32,
            WIN32::ERROR_FILE_INVALID => 0x800703EE as u32,
            WIN32::ERROR_FULLSCREEN_MODE => 0x800703EF as u32,
            WIN32::ERROR_NO_TOKEN => 0x800703F0 as u32,
            WIN32::ERROR_BADDB => 0x800703F1 as u32,
            WIN32::ERROR_BADKEY => 0x800703F2 as u32,
            WIN32::ERROR_CANTOPEN => 0x800703F3 as u32,
            WIN32::ERROR_CANTREAD => 0x800703F4 as u32,
            WIN32::ERROR_CANTWRITE => 0x800703F5 as u32,
            WIN32::ERROR_REGISTRY_RECOVERED => 0x800703F6 as u32,
            WIN32::ERROR_REGISTRY_CORRUPT => 0x800703F7 as u32,
            WIN32::ERROR_REGISTRY_IO_FAILED => 0x800703F8 as u32,
            WIN32::ERROR_NOT_REGISTRY_FILE => 0x800703F9 as u32,
            WIN32::ERROR_KEY_DELETED => 0x800703FA as u32,
            WIN32::ERROR_NO_LOG_SPACE => 0x800703FB as u32,
            WIN32::ERROR_KEY_HAS_CHILDREN => 0x800703FC as u32,
            WIN32::ERROR_CHILD_MUST_BE_VOLATILE => 0x800703FD as u32,
            WIN32::ERROR_NOTIFY_ENUM_DIR => 0x800703FE as u32,
            WIN32::ERROR_DEPENDENT_SERVICES_RUNNING => 0x8007041B as u32,
            WIN32::ERROR_INVALID_SERVICE_CONTROL => 0x8007041C as u32,
            WIN32::ERROR_SERVICE_REQUEST_TIMEOUT => 0x8007041D as u32,
            WIN32::ERROR_SERVICE_NO_THREAD => 0x8007041E as u32,
            WIN32::ERROR_SERVICE_DATABASE_LOCKED => 0x8007041F as u32,
            WIN32::ERROR_SERVICE_ALREADY_RUNNING => 0x80070420 as u32,
            WIN32::ERROR_INVALID_SERVICE_ACCOUNT => 0x80070421 as u32,
            WIN32::ERROR_SERVICE_DISABLED => 0x80070422 as u32,
            WIN32::ERROR_CIRCULAR_DEPENDENCY => 0x80070423 as u32,
            WIN32::ERROR_SERVICE_DOES_NOT_EXIST => 0x80070424 as u32,
            WIN32::ERROR_SERVICE_CANNOT_ACCEPT_CTRL => 0x80070425 as u32,
            WIN32::ERROR_SERVICE_NOT_ACTIVE => 0x80070426 as u32,
            WIN32::ERROR_FAILED_SERVICE_CONTROLLER_CONNECT => 0x80070427 as u32,
            WIN32::ERROR_EXCEPTION_IN_SERVICE => 0x80070428 as u32,
            WIN32::ERROR_DATABASE_DOES_NOT_EXIST => 0x80070429 as u32,
            WIN32::ERROR_SERVICE_SPECIFIC_ERROR => 0x8007042A as u32,
            WIN32::ERROR_PROCESS_ABORTED => 0x8007042B as u32,
            WIN32::ERROR_SERVICE_DEPENDENCY_FAIL => 0x8007042C as u32,
            WIN32::ERROR_SERVICE_LOGON_FAILED => 0x8007042D as u32,
            WIN32::ERROR_SERVICE_START_HANG => 0x8007042E as u32,
            WIN32::ERROR_INVALID_SERVICE_LOCK => 0x8007042F as u32,
            WIN32::ERROR_SERVICE_MARKED_FOR_DELETE => 0x80070430 as u32,
            WIN32::ERROR_SERVICE_EXISTS => 0x80070431 as u32,
            WIN32::ERROR_ALREADY_RUNNING_LKG => 0x80070432 as u32,
            WIN32::ERROR_SERVICE_DEPENDENCY_DELETED => 0x80070433 as u32,
            WIN32::ERROR_BOOT_ALREADY_ACCEPTED => 0x80070434 as u32,
            WIN32::ERROR_SERVICE_NEVER_STARTED => 0x80070435 as u32,
            WIN32::ERROR_DUPLICATE_SERVICE_NAME => 0x80070436 as u32,
            WIN32::ERROR_DIFFERENT_SERVICE_ACCOUNT => 0x80070437 as u32,
            WIN32::ERROR_CANNOT_DETECT_DRIVER_FAILURE => 0x80070438 as u32,
            WIN32::ERROR_CANNOT_DETECT_PROCESS_ABORT => 0x80070439 as u32,
            WIN32::ERROR_NO_RECOVERY_PROGRAM => 0x8007043A as u32,
            WIN32::ERROR_SERVICE_NOT_IN_EXE => 0x8007043B as u32,
            WIN32::ERROR_NOT_SAFEBOOT_SERVICE => 0x8007043C as u32,
            WIN32::ERROR_END_OF_MEDIA => 0x8007044C as u32,
            WIN32::ERROR_FILEMARK_DETECTED => 0x8007044D as u32,
            WIN32::ERROR_BEGINNING_OF_MEDIA => 0x8007044E as u32,
            WIN32::ERROR_SETMARK_DETECTED => 0x8007044F as u32,
            WIN32::ERROR_NO_DATA_DETECTED => 0x80070450 as u32,
            WIN32::ERROR_PARTITION_FAILURE => 0x80070451 as u32,
            WIN32::ERROR_INVALID_BLOCK_LENGTH => 0x80070452 as u32,
            WIN32::ERROR_DEVICE_NOT_PARTITIONED => 0x80070453 as u32,
            WIN32::ERROR_UNABLE_TO_LOCK_MEDIA => 0x80070454 as u32,
            WIN32::ERROR_UNABLE_TO_UNLOAD_MEDIA => 0x80070455 as u32,
            WIN32::ERROR_MEDIA_CHANGED => 0x80070456 as u32,
            WIN32::ERROR_BUS_RESET => 0x80070457 as u32,
            WIN32::ERROR_NO_MEDIA_IN_DRIVE => 0x80070458 as u32,
            WIN32::ERROR_NO_UNICODE_TRANSLATION => 0x80070459 as u32,
            WIN32::ERROR_DLL_INIT_FAILED => 0x8007045A as u32,
            WIN32::ERROR_SHUTDOWN_IN_PROGRESS => 0x8007045B as u32,
            WIN32::ERROR_NO_SHUTDOWN_IN_PROGRESS => 0x8007045C as u32,
            WIN32::ERROR_IO_DEVICE => 0x8007045D as u32,
            WIN32::ERROR_SERIAL_NO_DEVICE => 0x8007045E as u32,
            WIN32::ERROR_IRQ_BUSY => 0x8007045F as u32,
            WIN32::ERROR_MORE_WRITES => 0x80070460 as u32,
            WIN32::ERROR_COUNTER_TIMEOUT => 0x80070461 as u32,
            WIN32::ERROR_FLOPPY_ID_MARK_NOT_FOUND => 0x80070462 as u32,
            WIN32::ERROR_FLOPPY_WRONG_CYLINDER => 0x80070463 as u32,
            WIN32::ERROR_FLOPPY_UNKNOWN_ERROR => 0x80070464 as u32,
            WIN32::ERROR_FLOPPY_BAD_REGISTERS => 0x80070465 as u32,
            WIN32::ERROR_DISK_RECALIBRATE_FAILED => 0x80070466 as u32,
            WIN32::ERROR_DISK_OPERATION_FAILED => 0x80070467 as u32,
            WIN32::ERROR_DISK_RESET_FAILED => 0x80070468 as u32,
            WIN32::ERROR_EOM_OVERFLOW => 0x80070469 as u32,
            WIN32::ERROR_NOT_ENOUGH_SERVER_MEMORY => 0x8007046A as u32,
            WIN32::ERROR_POSSIBLE_DEADLOCK => 0x8007046B as u32,
            WIN32::ERROR_MAPPED_ALIGNMENT => 0x8007046C as u32,
            WIN32::ERROR_SET_POWER_STATE_VETOED => 0x80070474 as u32,
            WIN32::ERROR_SET_POWER_STATE_FAILED => 0x80070475 as u32,
            WIN32::ERROR_TOO_MANY_LINKS => 0x80070476 as u32,
            WIN32::ERROR_OLD_WIN_VERSION => 0x8007047E as u32,
            WIN32::ERROR_APP_WRONG_OS => 0x8007047F as u32,
            WIN32::ERROR_SINGLE_INSTANCE_APP => 0x80070480 as u32,
            WIN32::ERROR_RMODE_APP => 0x80070481 as u32,
            WIN32::ERROR_INVALID_DLL => 0x80070482 as u32,
            WIN32::ERROR_NO_ASSOCIATION => 0x80070483 as u32,
            WIN32::ERROR_DDE_FAIL => 0x80070484 as u32,
            WIN32::ERROR_DLL_NOT_FOUND => 0x80070485 as u32,
            WIN32::ERROR_NO_MORE_USER_HANDLES => 0x80070486 as u32,
            WIN32::ERROR_MESSAGE_SYNC_ONLY => 0x80070487 as u32,
            WIN32::ERROR_SOURCE_ELEMENT_EMPTY => 0x80070488 as u32,
            WIN32::ERROR_DESTINATION_ELEMENT_FULL => 0x80070489 as u32,
            WIN32::ERROR_ILLEGAL_ELEMENT_ADDRESS => 0x8007048A as u32,
            WIN32::ERROR_MAGAZINE_NOT_PRESENT => 0x8007048B as u32,
            WIN32::ERROR_DEVICE_REINITIALIZATION_NEEDED => 0x8007048C as u32,
            WIN32::ERROR_DEVICE_REQUIRES_CLEANING => 0x8007048D as u32,
            WIN32::ERROR_DEVICE_DOOR_OPEN => 0x8007048E as u32,
            WIN32::ERROR_DEVICE_NOT_CONNECTED => 0x8007048F as u32,
            WIN32::ERROR_NOT_FOUND => 0x80070490 as u32,
            WIN32::E_PROP_ID_UNSUPPORTED => 0x80070490 as u32,
            WIN32::ERROR_NO_MATCH => 0x80070491 as u32,
            WIN32::ERROR_SET_NOT_FOUND => 0x80070492 as u32,
            WIN32::E_PROP_SET_UNSUPPORTED => 0x80070492 as u32,
            WIN32::ERROR_POINT_NOT_FOUND => 0x80070493 as u32,
            WIN32::ERROR_NO_TRACKING_SERVICE => 0x80070494 as u32,
            WIN32::ERROR_NO_VOLUME_ID => 0x80070495 as u32,
            WIN32::ERROR_UNABLE_TO_REMOVE_REPLACED => 0x80070497 as u32,
            WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT => 0x80070498 as u32,
            WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT_2 => 0x80070499 as u32,
            WIN32::ERROR_JOURNAL_DELETE_IN_PROGRESS => 0x8007049A as u32,
            WIN32::ERROR_JOURNAL_NOT_ACTIVE => 0x8007049B as u32,
            WIN32::ERROR_POTENTIAL_FILE_FOUND => 0x8007049C as u32,
            WIN32::ERROR_JOURNAL_ENTRY_DELETED => 0x8007049D as u32,
            WIN32::ERROR_VRF_CFG_ENABLED => 0x8007049F as u32,
            WIN32::ERROR_PARTITION_TERMINATING => 0x800704A0 as u32,
            WIN32::ERROR_SHUTDOWN_IS_SCHEDULED => 0x800704A6 as u32,
            WIN32::ERROR_SHUTDOWN_USERS_LOGGED_ON => 0x800704A7 as u32,
            WIN32::ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE => 0x800704A8 as u32,
            WIN32::ERROR_BAD_DEVICE => 0x800704B0 as u32,
            WIN32::ERROR_CONNECTION_UNAVAIL => 0x800704B1 as u32,
            WIN32::ERROR_DEVICE_ALREADY_REMEMBERED => 0x800704B2 as u32,
            WIN32::ERROR_NO_NET_OR_BAD_PATH => 0x800704B3 as u32,
            WIN32::ERROR_BAD_PROVIDER => 0x800704B4 as u32,
            WIN32::ERROR_CANNOT_OPEN_PROFILE => 0x800704B5 as u32,
            WIN32::ERROR_BAD_PROFILE => 0x800704B6 as u32,
            WIN32::ERROR_NOT_CONTAINER => 0x800704B7 as u32,
            WIN32::ERROR_EXTENDED_ERROR => 0x800704B8 as u32,
            WIN32::ERROR_INVALID_GROUPNAME => 0x800704B9 as u32,
            WIN32::ERROR_INVALID_COMPUTERNAME => 0x800704BA as u32,
            WIN32::ERROR_INVALID_EVENTNAME => 0x800704BB as u32,
            WIN32::ERROR_INVALID_DOMAINNAME => 0x800704BC as u32,
            WIN32::ERROR_INVALID_SERVICENAME => 0x800704BD as u32,
            WIN32::ERROR_INVALID_NETNAME => 0x800704BE as u32,
            WIN32::ERROR_INVALID_SHARENAME => 0x800704BF as u32,
            WIN32::ERROR_INVALID_PASSWORDNAME => 0x800704C0 as u32,
            WIN32::ERROR_INVALID_MESSAGENAME => 0x800704C1 as u32,
            WIN32::ERROR_INVALID_MESSAGEDEST => 0x800704C2 as u32,
            WIN32::ERROR_SESSION_CREDENTIAL_CONFLICT => 0x800704C3 as u32,
            WIN32::ERROR_REMOTE_SESSION_LIMIT_EXCEEDED => 0x800704C4 as u32,
            WIN32::ERROR_DUP_DOMAINNAME => 0x800704C5 as u32,
            WIN32::ERROR_NO_NETWORK => 0x800704C6 as u32,
            WIN32::ERROR_CANCELLED => 0x800704C7 as u32,
            WIN32::ERROR_USER_MAPPED_FILE => 0x800704C8 as u32,
            WIN32::ERROR_CONNECTION_REFUSED => 0x800704C9 as u32,
            WIN32::ERROR_GRACEFUL_DISCONNECT => 0x800704CA as u32,
            WIN32::ERROR_ADDRESS_ALREADY_ASSOCIATED => 0x800704CB as u32,
            WIN32::ERROR_ADDRESS_NOT_ASSOCIATED => 0x800704CC as u32,
            WIN32::ERROR_CONNECTION_INVALID => 0x800704CD as u32,
            WIN32::ERROR_CONNECTION_ACTIVE => 0x800704CE as u32,
            WIN32::ERROR_NETWORK_UNREACHABLE => 0x800704CF as u32,
            WIN32::ERROR_HOST_UNREACHABLE => 0x800704D0 as u32,
            WIN32::ERROR_PROTOCOL_UNREACHABLE => 0x800704D1 as u32,
            WIN32::ERROR_PORT_UNREACHABLE => 0x800704D2 as u32,
            WIN32::ERROR_REQUEST_ABORTED => 0x800704D3 as u32,
            WIN32::ERROR_CONNECTION_ABORTED => 0x800704D4 as u32,
            WIN32::ERROR_RETRY => 0x800704D5 as u32,
            WIN32::ERROR_CONNECTION_COUNT_LIMIT => 0x800704D6 as u32,
            WIN32::ERROR_LOGIN_TIME_RESTRICTION => 0x800704D7 as u32,
            WIN32::ERROR_LOGIN_WKSTA_RESTRICTION => 0x800704D8 as u32,
            WIN32::ERROR_INCORRECT_ADDRESS => 0x800704D9 as u32,
            WIN32::ERROR_ALREADY_REGISTERED => 0x800704DA as u32,
            WIN32::ERROR_SERVICE_NOT_FOUND => 0x800704DB as u32,
            WIN32::ERROR_NOT_AUTHENTICATED => 0x800704DC as u32,
            WIN32::ERROR_NOT_LOGGED_ON => 0x800704DD as u32,
            WIN32::ERROR_CONTINUE => 0x800704DE as u32,
            WIN32::ERROR_ALREADY_INITIALIZED => 0x800704DF as u32,
            WIN32::ERROR_NO_MORE_DEVICES => 0x800704E0 as u32,
            WIN32::ERROR_NO_SUCH_SITE => 0x800704E1 as u32,
            WIN32::ERROR_DOMAIN_CONTROLLER_EXISTS => 0x800704E2 as u32,
            WIN32::ERROR_ONLY_IF_CONNECTED => 0x800704E3 as u32,
            WIN32::ERROR_OVERRIDE_NOCHANGES => 0x800704E4 as u32,
            WIN32::ERROR_BAD_USER_PROFILE => 0x800704E5 as u32,
            WIN32::ERROR_NOT_SUPPORTED_ON_SBS => 0x800704E6 as u32,
            WIN32::ERROR_SERVER_SHUTDOWN_IN_PROGRESS => 0x800704E7 as u32,
            WIN32::ERROR_HOST_DOWN => 0x800704E8 as u32,
            WIN32::ERROR_NON_ACCOUNT_SID => 0x800704E9 as u32,
            WIN32::ERROR_NON_DOMAIN_SID => 0x800704EA as u32,
            WIN32::ERROR_APPHELP_BLOCK => 0x800704EB as u32,
            WIN32::ERROR_ACCESS_DISABLED_BY_POLICY => 0x800704EC as u32,
            WIN32::ERROR_REG_NAT_CONSUMPTION => 0x800704ED as u32,
            WIN32::ERROR_CSCSHARE_OFFLINE => 0x800704EE as u32,
            WIN32::ERROR_PKINIT_FAILURE => 0x800704EF as u32,
            WIN32::ERROR_SMARTCARD_SUBSYSTEM_FAILURE => 0x800704F0 as u32,
            WIN32::ERROR_DOWNGRADE_DETECTED => 0x800704F1 as u32,
            WIN32::ERROR_MACHINE_LOCKED => 0x800704F7 as u32,
            WIN32::ERROR_SMB_GUEST_LOGON_BLOCKED => 0x800704F8 as u32,
            WIN32::ERROR_CALLBACK_SUPPLIED_INVALID_DATA => 0x800704F9 as u32,
            WIN32::ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED => 0x800704FA as u32,
            WIN32::ERROR_DRIVER_BLOCKED => 0x800704FB as u32,
            WIN32::ERROR_INVALID_IMPORT_OF_NON_DLL => 0x800704FC as u32,
            WIN32::ERROR_ACCESS_DISABLED_WEBBLADE => 0x800704FD as u32,
            WIN32::ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER => 0x800704FE as u32,
            WIN32::ERROR_RECOVERY_FAILURE => 0x800704FF as u32,
            WIN32::ERROR_ALREADY_FIBER => 0x80070500 as u32,
            WIN32::ERROR_ALREADY_THREAD => 0x80070501 as u32,
            WIN32::ERROR_STACK_BUFFER_OVERRUN => 0x80070502 as u32,
            WIN32::ERROR_PARAMETER_QUOTA_EXCEEDED => 0x80070503 as u32,
            WIN32::ERROR_DEBUGGER_INACTIVE => 0x80070504 as u32,
            WIN32::ERROR_DELAY_LOAD_FAILED => 0x80070505 as u32,
            WIN32::ERROR_VDM_DISALLOWED => 0x80070506 as u32,
            WIN32::ERROR_UNIDENTIFIED_ERROR => 0x80070507 as u32,
            WIN32::ERROR_INVALID_CRUNTIME_PARAMETER => 0x80070508 as u32,
            WIN32::ERROR_BEYOND_VDL => 0x80070509 as u32,
            WIN32::ERROR_INCOMPATIBLE_SERVICE_SID_TYPE => 0x8007050A as u32,
            WIN32::ERROR_DRIVER_PROCESS_TERMINATED => 0x8007050B as u32,
            WIN32::ERROR_IMPLEMENTATION_LIMIT => 0x8007050C as u32,
            WIN32::ERROR_PROCESS_IS_PROTECTED => 0x8007050D as u32,
            WIN32::ERROR_SERVICE_NOTIFY_CLIENT_LAGGING => 0x8007050E as u32,
            WIN32::ERROR_DISK_QUOTA_EXCEEDED => 0x8007050F as u32,
            WIN32::ERROR_CONTENT_BLOCKED => 0x80070510 as u32,
            WIN32::ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE => 0x80070511 as u32,
            WIN32::ERROR_APP_HANG => 0x80070512 as u32,
            WIN32::ERROR_INVALID_LABEL => 0x80070513 as u32,
            WIN32::ERROR_NOT_ALL_ASSIGNED => 0x80070514 as u32,
            WIN32::ERROR_SOME_NOT_MAPPED => 0x80070515 as u32,
            WIN32::ERROR_NO_QUOTAS_FOR_ACCOUNT => 0x80070516 as u32,
            WIN32::ERROR_LOCAL_USER_SESSION_KEY => 0x80070517 as u32,
            WIN32::ERROR_NULL_LM_PASSWORD => 0x80070518 as u32,
            WIN32::ERROR_UNKNOWN_REVISION => 0x80070519 as u32,
            WIN32::ERROR_REVISION_MISMATCH => 0x8007051A as u32,
            WIN32::ERROR_INVALID_OWNER => 0x8007051B as u32,
            WIN32::ERROR_INVALID_PRIMARY_GROUP => 0x8007051C as u32,
            WIN32::ERROR_NO_IMPERSONATION_TOKEN => 0x8007051D as u32,
            WIN32::ERROR_CANT_DISABLE_MANDATORY => 0x8007051E as u32,
            WIN32::ERROR_NO_LOGON_SERVERS => 0x8007051F as u32,
            WIN32::ERROR_NO_SUCH_LOGON_SESSION => 0x80070520 as u32,
            WIN32::ERROR_NO_SUCH_PRIVILEGE => 0x80070521 as u32,
            WIN32::ERROR_PRIVILEGE_NOT_HELD => 0x80070522 as u32,
            WIN32::ERROR_INVALID_ACCOUNT_NAME => 0x80070523 as u32,
            WIN32::ERROR_USER_EXISTS => 0x80070524 as u32,
            WIN32::ERROR_NO_SUCH_USER => 0x80070525 as u32,
            WIN32::ERROR_GROUP_EXISTS => 0x80070526 as u32,
            WIN32::ERROR_NO_SUCH_GROUP => 0x80070527 as u32,
            WIN32::ERROR_MEMBER_IN_GROUP => 0x80070528 as u32,
            WIN32::ERROR_MEMBER_NOT_IN_GROUP => 0x80070529 as u32,
            WIN32::ERROR_LAST_ADMIN => 0x8007052A as u32,
            WIN32::ERROR_WRONG_PASSWORD => 0x8007052B as u32,
            WIN32::ERROR_ILL_FORMED_PASSWORD => 0x8007052C as u32,
            WIN32::ERROR_PASSWORD_RESTRICTION => 0x8007052D as u32,
            WIN32::ERROR_LOGON_FAILURE => 0x8007052E as u32,
            WIN32::ERROR_ACCOUNT_RESTRICTION => 0x8007052F as u32,
            WIN32::ERROR_INVALID_LOGON_HOURS => 0x80070530 as u32,
            WIN32::ERROR_INVALID_WORKSTATION => 0x80070531 as u32,
            WIN32::ERROR_PASSWORD_EXPIRED => 0x80070532 as u32,
            WIN32::ERROR_ACCOUNT_DISABLED => 0x80070533 as u32,
            WIN32::ERROR_NONE_MAPPED => 0x80070534 as u32,
            WIN32::ERROR_TOO_MANY_LUIDS_REQUESTED => 0x80070535 as u32,
            WIN32::ERROR_LUIDS_EXHAUSTED => 0x80070536 as u32,
            WIN32::ERROR_INVALID_SUB_AUTHORITY => 0x80070537 as u32,
            WIN32::ERROR_INVALID_ACL => 0x80070538 as u32,
            WIN32::ERROR_INVALID_SID => 0x80070539 as u32,
            WIN32::ERROR_INVALID_SECURITY_DESCR => 0x8007053A as u32,
            WIN32::ERROR_BAD_INHERITANCE_ACL => 0x8007053C as u32,
            WIN32::ERROR_SERVER_DISABLED => 0x8007053D as u32,
            WIN32::ERROR_SERVER_NOT_DISABLED => 0x8007053E as u32,
            WIN32::ERROR_INVALID_ID_AUTHORITY => 0x8007053F as u32,
            WIN32::ERROR_ALLOTTED_SPACE_EXCEEDED => 0x80070540 as u32,
            WIN32::ERROR_INVALID_GROUP_ATTRIBUTES => 0x80070541 as u32,
            WIN32::ERROR_BAD_IMPERSONATION_LEVEL => 0x80070542 as u32,
            WIN32::ERROR_CANT_OPEN_ANONYMOUS => 0x80070543 as u32,
            WIN32::ERROR_BAD_VALIDATION_CLASS => 0x80070544 as u32,
            WIN32::ERROR_BAD_TOKEN_TYPE => 0x80070545 as u32,
            WIN32::ERROR_NO_SECURITY_ON_OBJECT => 0x80070546 as u32,
            WIN32::ERROR_CANT_ACCESS_DOMAIN_INFO => 0x80070547 as u32,
            WIN32::ERROR_INVALID_SERVER_STATE => 0x80070548 as u32,
            WIN32::ERROR_INVALID_DOMAIN_STATE => 0x80070549 as u32,
            WIN32::ERROR_INVALID_DOMAIN_ROLE => 0x8007054A as u32,
            WIN32::ERROR_NO_SUCH_DOMAIN => 0x8007054B as u32,
            WIN32::ERROR_DOMAIN_EXISTS => 0x8007054C as u32,
            WIN32::ERROR_DOMAIN_LIMIT_EXCEEDED => 0x8007054D as u32,
            WIN32::ERROR_INTERNAL_DB_CORRUPTION => 0x8007054E as u32,
            WIN32::ERROR_INTERNAL_ERROR => 0x8007054F as u32,
            WIN32::ERROR_GENERIC_NOT_MAPPED => 0x80070550 as u32,
            WIN32::ERROR_BAD_DESCRIPTOR_FORMAT => 0x80070551 as u32,
            WIN32::ERROR_NOT_LOGON_PROCESS => 0x80070552 as u32,
            WIN32::ERROR_LOGON_SESSION_EXISTS => 0x80070553 as u32,
            WIN32::ERROR_NO_SUCH_PACKAGE => 0x80070554 as u32,
            WIN32::ERROR_BAD_LOGON_SESSION_STATE => 0x80070555 as u32,
            WIN32::ERROR_LOGON_SESSION_COLLISION => 0x80070556 as u32,
            WIN32::ERROR_INVALID_LOGON_TYPE => 0x80070557 as u32,
            WIN32::ERROR_CANNOT_IMPERSONATE => 0x80070558 as u32,
            WIN32::ERROR_RXACT_INVALID_STATE => 0x80070559 as u32,
            WIN32::ERROR_RXACT_COMMIT_FAILURE => 0x8007055A as u32,
            WIN32::ERROR_SPECIAL_ACCOUNT => 0x8007055B as u32,
            WIN32::ERROR_SPECIAL_GROUP => 0x8007055C as u32,
            WIN32::ERROR_SPECIAL_USER => 0x8007055D as u32,
            WIN32::ERROR_MEMBERS_PRIMARY_GROUP => 0x8007055E as u32,
            WIN32::ERROR_TOKEN_ALREADY_IN_USE => 0x8007055F as u32,
            WIN32::ERROR_NO_SUCH_ALIAS => 0x80070560 as u32,
            WIN32::ERROR_MEMBER_NOT_IN_ALIAS => 0x80070561 as u32,
            WIN32::ERROR_MEMBER_IN_ALIAS => 0x80070562 as u32,
            WIN32::ERROR_ALIAS_EXISTS => 0x80070563 as u32,
            WIN32::ERROR_LOGON_NOT_GRANTED => 0x80070564 as u32,
            WIN32::ERROR_TOO_MANY_SECRETS => 0x80070565 as u32,
            WIN32::ERROR_SECRET_TOO_LONG => 0x80070566 as u32,
            WIN32::ERROR_INTERNAL_DB_ERROR => 0x80070567 as u32,
            WIN32::ERROR_TOO_MANY_CONTEXT_IDS => 0x80070568 as u32,
            WIN32::ERROR_LOGON_TYPE_NOT_GRANTED => 0x80070569 as u32,
            WIN32::ERROR_NT_CROSS_ENCRYPTION_REQUIRED => 0x8007056A as u32,
            WIN32::ERROR_NO_SUCH_MEMBER => 0x8007056B as u32,
            WIN32::ERROR_INVALID_MEMBER => 0x8007056C as u32,
            WIN32::ERROR_TOO_MANY_SIDS => 0x8007056D as u32,
            WIN32::ERROR_LM_CROSS_ENCRYPTION_REQUIRED => 0x8007056E as u32,
            WIN32::ERROR_NO_INHERITANCE => 0x8007056F as u32,
            WIN32::ERROR_FILE_CORRUPT => 0x80070570 as u32,
            WIN32::ERROR_DISK_CORRUPT => 0x80070571 as u32,
            WIN32::ERROR_NO_USER_SESSION_KEY => 0x80070572 as u32,
            WIN32::ERROR_LICENSE_QUOTA_EXCEEDED => 0x80070573 as u32,
            WIN32::ERROR_WRONG_TARGET_NAME => 0x80070574 as u32,
            WIN32::ERROR_MUTUAL_AUTH_FAILED => 0x80070575 as u32,
            WIN32::ERROR_TIME_SKEW => 0x80070576 as u32,
            WIN32::ERROR_CURRENT_DOMAIN_NOT_ALLOWED => 0x80070577 as u32,
            WIN32::ERROR_INVALID_WINDOW_HANDLE => 0x80070578 as u32,
            WIN32::ERROR_INVALID_MENU_HANDLE => 0x80070579 as u32,
            WIN32::ERROR_INVALID_CURSOR_HANDLE => 0x8007057A as u32,
            WIN32::ERROR_INVALID_ACCEL_HANDLE => 0x8007057B as u32,
            WIN32::ERROR_INVALID_HOOK_HANDLE => 0x8007057C as u32,
            WIN32::ERROR_INVALID_DWP_HANDLE => 0x8007057D as u32,
            WIN32::ERROR_TLW_WITH_WSCHILD => 0x8007057E as u32,
            WIN32::ERROR_CANNOT_FIND_WND_CLASS => 0x8007057F as u32,
            WIN32::ERROR_WINDOW_OF_OTHER_THREAD => 0x80070580 as u32,
            WIN32::ERROR_HOTKEY_ALREADY_REGISTERED => 0x80070581 as u32,
            WIN32::ERROR_CLASS_ALREADY_EXISTS => 0x80070582 as u32,
            WIN32::ERROR_CLASS_DOES_NOT_EXIST => 0x80070583 as u32,
            WIN32::ERROR_CLASS_HAS_WINDOWS => 0x80070584 as u32,
            WIN32::ERROR_INVALID_INDEX => 0x80070585 as u32,
            WIN32::ERROR_INVALID_ICON_HANDLE => 0x80070586 as u32,
            WIN32::ERROR_PRIVATE_DIALOG_INDEX => 0x80070587 as u32,
            WIN32::ERROR_LISTBOX_ID_NOT_FOUND => 0x80070588 as u32,
            WIN32::ERROR_NO_WILDCARD_CHARACTERS => 0x80070589 as u32,
            WIN32::ERROR_CLIPBOARD_NOT_OPEN => 0x8007058A as u32,
            WIN32::ERROR_HOTKEY_NOT_REGISTERED => 0x8007058B as u32,
            WIN32::ERROR_WINDOW_NOT_DIALOG => 0x8007058C as u32,
            WIN32::ERROR_CONTROL_ID_NOT_FOUND => 0x8007058D as u32,
            WIN32::ERROR_INVALID_COMBOBOX_MESSAGE => 0x8007058E as u32,
            WIN32::ERROR_WINDOW_NOT_COMBOBOX => 0x8007058F as u32,
            WIN32::ERROR_INVALID_EDIT_HEIGHT => 0x80070590 as u32,
            WIN32::ERROR_DC_NOT_FOUND => 0x80070591 as u32,
            WIN32::ERROR_INVALID_HOOK_FILTER => 0x80070592 as u32,
            WIN32::ERROR_INVALID_FILTER_PROC => 0x80070593 as u32,
            WIN32::ERROR_HOOK_NEEDS_HMOD => 0x80070594 as u32,
            WIN32::ERROR_GLOBAL_ONLY_HOOK => 0x80070595 as u32,
            WIN32::ERROR_JOURNAL_HOOK_SET => 0x80070596 as u32,
            WIN32::ERROR_HOOK_NOT_INSTALLED => 0x80070597 as u32,
            WIN32::ERROR_INVALID_LB_MESSAGE => 0x80070598 as u32,
            WIN32::ERROR_SETCOUNT_ON_BAD_LB => 0x80070599 as u32,
            WIN32::ERROR_LB_WITHOUT_TABSTOPS => 0x8007059A as u32,
            WIN32::ERROR_DESTROY_OBJECT_OF_OTHER_THREAD => 0x8007059B as u32,
            WIN32::ERROR_CHILD_WINDOW_MENU => 0x8007059C as u32,
            WIN32::ERROR_NO_SYSTEM_MENU => 0x8007059D as u32,
            WIN32::ERROR_INVALID_MSGBOX_STYLE => 0x8007059E as u32,
            WIN32::ERROR_INVALID_SPI_VALUE => 0x8007059F as u32,
            WIN32::ERROR_SCREEN_ALREADY_LOCKED => 0x800705A0 as u32,
            WIN32::ERROR_HWNDS_HAVE_DIFF_PARENT => 0x800705A1 as u32,
            WIN32::ERROR_NOT_CHILD_WINDOW => 0x800705A2 as u32,
            WIN32::ERROR_INVALID_GW_COMMAND => 0x800705A3 as u32,
            WIN32::ERROR_INVALID_THREAD_ID => 0x800705A4 as u32,
            WIN32::ERROR_NON_MDICHILD_WINDOW => 0x800705A5 as u32,
            WIN32::ERROR_POPUP_ALREADY_ACTIVE => 0x800705A6 as u32,
            WIN32::ERROR_NO_SCROLLBARS => 0x800705A7 as u32,
            WIN32::ERROR_INVALID_SCROLLBAR_RANGE => 0x800705A8 as u32,
            WIN32::ERROR_INVALID_SHOWWIN_COMMAND => 0x800705A9 as u32,
            WIN32::ERROR_NO_SYSTEM_RESOURCES => 0x800705AA as u32,
            WIN32::ERROR_NONPAGED_SYSTEM_RESOURCES => 0x800705AB as u32,
            WIN32::ERROR_PAGED_SYSTEM_RESOURCES => 0x800705AC as u32,
            WIN32::ERROR_WORKING_SET_QUOTA => 0x800705AD as u32,
            WIN32::ERROR_PAGEFILE_QUOTA => 0x800705AE as u32,
            WIN32::ERROR_COMMITMENT_LIMIT => 0x800705AF as u32,
            WIN32::ERROR_MENU_ITEM_NOT_FOUND => 0x800705B0 as u32,
            WIN32::ERROR_INVALID_KEYBOARD_HANDLE => 0x800705B1 as u32,
            WIN32::ERROR_HOOK_TYPE_NOT_ALLOWED => 0x800705B2 as u32,
            WIN32::ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION => 0x800705B3 as u32,
            WIN32::ERROR_TIMEOUT => 0x800705B4 as u32,
            WIN32::E_TIMEOUT => 0x800705B4 as u32,
            WIN32::ERROR_INVALID_MONITOR_HANDLE => 0x800705B5 as u32,
            WIN32::ERROR_INCORRECT_SIZE => 0x800705B6 as u32,
            WIN32::ERROR_SYMLINK_CLASS_DISABLED => 0x800705B7 as u32,
            WIN32::ERROR_SYMLINK_NOT_SUPPORTED => 0x800705B8 as u32,
            WIN32::ERROR_XML_PARSE_ERROR => 0x800705B9 as u32,
            WIN32::ERROR_XMLDSIG_ERROR => 0x800705BA as u32,
            WIN32::ERROR_RESTART_APPLICATION => 0x800705BB as u32,
            WIN32::ERROR_WRONG_COMPARTMENT => 0x800705BC as u32,
            WIN32::ERROR_AUTHIP_FAILURE => 0x800705BD as u32,
            WIN32::ERROR_NO_NVRAM_RESOURCES => 0x800705BE as u32,
            WIN32::ERROR_NOT_GUI_PROCESS => 0x800705BF as u32,
            WIN32::ERROR_EVENTLOG_FILE_CORRUPT => 0x800705DC as u32,
            WIN32::ERROR_EVENTLOG_CANT_START => 0x800705DD as u32,
            WIN32::ERROR_LOG_FILE_FULL => 0x800705DE as u32,
            WIN32::ERROR_EVENTLOG_FILE_CHANGED => 0x800705DF as u32,
            WIN32::ERROR_CONTAINER_ASSIGNED => 0x800705E0 as u32,
            WIN32::ERROR_JOB_NO_CONTAINER => 0x800705E1 as u32,
            WIN32::ERROR_INVALID_TASK_NAME => 0x8007060E as u32,
            WIN32::ERROR_INVALID_TASK_INDEX => 0x8007060F as u32,
            WIN32::ERROR_THREAD_ALREADY_IN_TASK => 0x80070610 as u32,
            WIN32::ERROR_INSTALL_SERVICE_FAILURE => 0x80070641 as u32,
            WIN32::ERROR_INSTALL_USEREXIT => 0x80070642 as u32,
            WIN32::ERROR_INSTALL_FAILURE => 0x80070643 as u32,
            WIN32::ERROR_INSTALL_SUSPEND => 0x80070644 as u32,
            WIN32::ERROR_UNKNOWN_PRODUCT => 0x80070645 as u32,
            WIN32::ERROR_UNKNOWN_FEATURE => 0x80070646 as u32,
            WIN32::ERROR_UNKNOWN_COMPONENT => 0x80070647 as u32,
            WIN32::ERROR_UNKNOWN_PROPERTY => 0x80070648 as u32,
            WIN32::ERROR_INVALID_HANDLE_STATE => 0x80070649 as u32,
            WIN32::ERROR_BAD_CONFIGURATION => 0x8007064A as u32,
            WIN32::ERROR_INDEX_ABSENT => 0x8007064B as u32,
            WIN32::ERROR_INSTALL_SOURCE_ABSENT => 0x8007064C as u32,
            WIN32::ERROR_INSTALL_PACKAGE_VERSION => 0x8007064D as u32,
            WIN32::ERROR_PRODUCT_UNINSTALLED => 0x8007064E as u32,
            WIN32::ERROR_BAD_QUERY_SYNTAX => 0x8007064F as u32,
            WIN32::ERROR_INVALID_FIELD => 0x80070650 as u32,
            WIN32::ERROR_DEVICE_REMOVED => 0x80070651 as u32,
            WIN32::ERROR_INSTALL_ALREADY_RUNNING => 0x80070652 as u32,
            WIN32::ERROR_INSTALL_PACKAGE_OPEN_FAILED => 0x80070653 as u32,
            WIN32::ERROR_INSTALL_PACKAGE_INVALID => 0x80070654 as u32,
            WIN32::ERROR_INSTALL_UI_FAILURE => 0x80070655 as u32,
            WIN32::ERROR_INSTALL_LOG_FAILURE => 0x80070656 as u32,
            WIN32::ERROR_INSTALL_LANGUAGE_UNSUPPORTED => 0x80070657 as u32,
            WIN32::ERROR_INSTALL_TRANSFORM_FAILURE => 0x80070658 as u32,
            WIN32::ERROR_INSTALL_PACKAGE_REJECTED => 0x80070659 as u32,
            WIN32::ERROR_FUNCTION_NOT_CALLED => 0x8007065A as u32,
            WIN32::ERROR_FUNCTION_FAILED => 0x8007065B as u32,
            WIN32::ERROR_INVALID_TABLE => 0x8007065C as u32,
            WIN32::ERROR_DATATYPE_MISMATCH => 0x8007065D as u32,
            WIN32::ERROR_UNSUPPORTED_TYPE => 0x8007065E as u32,
            WIN32::ERROR_CREATE_FAILED => 0x8007065F as u32,
            WIN32::ERROR_INSTALL_TEMP_UNWRITABLE => 0x80070660 as u32,
            WIN32::ERROR_INSTALL_PLATFORM_UNSUPPORTED => 0x80070661 as u32,
            WIN32::ERROR_INSTALL_NOTUSED => 0x80070662 as u32,
            WIN32::ERROR_PATCH_PACKAGE_OPEN_FAILED => 0x80070663 as u32,
            WIN32::ERROR_PATCH_PACKAGE_INVALID => 0x80070664 as u32,
            WIN32::ERROR_PATCH_PACKAGE_UNSUPPORTED => 0x80070665 as u32,
            WIN32::ERROR_PRODUCT_VERSION => 0x80070666 as u32,
            WIN32::ERROR_INVALID_COMMAND_LINE => 0x80070667 as u32,
            WIN32::ERROR_INSTALL_REMOTE_DISALLOWED => 0x80070668 as u32,
            WIN32::ERROR_SUCCESS_REBOOT_INITIATED => 0x80070669 as u32,
            WIN32::ERROR_PATCH_TARGET_NOT_FOUND => 0x8007066A as u32,
            WIN32::ERROR_PATCH_PACKAGE_REJECTED => 0x8007066B as u32,
            WIN32::ERROR_INSTALL_TRANSFORM_REJECTED => 0x8007066C as u32,
            WIN32::ERROR_INSTALL_REMOTE_PROHIBITED => 0x8007066D as u32,
            WIN32::ERROR_PATCH_REMOVAL_UNSUPPORTED => 0x8007066E as u32,
            WIN32::ERROR_UNKNOWN_PATCH => 0x8007066F as u32,
            WIN32::ERROR_PATCH_NO_SEQUENCE => 0x80070670 as u32,
            WIN32::ERROR_PATCH_REMOVAL_DISALLOWED => 0x80070671 as u32,
            WIN32::ERROR_INVALID_PATCH_XML => 0x80070672 as u32,
            WIN32::ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT => 0x80070673 as u32,
            WIN32::ERROR_INSTALL_SERVICE_SAFEBOOT => 0x80070674 as u32,
            WIN32::ERROR_FAIL_FAST_EXCEPTION => 0x80070675 as u32,
            WIN32::ERROR_INSTALL_REJECTED => 0x80070676 as u32,
            WIN32::ERROR_DYNAMIC_CODE_BLOCKED => 0x80070677 as u32,
            WIN32::ERROR_NOT_SAME_OBJECT => 0x80070678 as u32,
            WIN32::ERROR_STRICT_CFG_VIOLATION => 0x80070679 as u32,
            WIN32::ERROR_STRICT_RFG_VIOLATION => 0x8007067A as u32,
            WIN32::ERROR_RFG_ACCESS_VIOLATION => 0x8007067B as u32,
            WIN32::ERROR_SET_CONTEXT_DENIED => 0x8007067C as u32,
            WIN32::ERROR_CROSS_PARTITION_VIOLATION => 0x8007067D as u32,
            WIN32::ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT => 0x8007067E as u32,
            WIN32::RPC_S_INVALID_STRING_BINDING => 0x800706A4 as u32,
            WIN32::RPC_S_WRONG_KIND_OF_BINDING => 0x800706A5 as u32,
            WIN32::RPC_S_INVALID_BINDING => 0x800706A6 as u32,
            WIN32::RPC_S_PROTSEQ_NOT_SUPPORTED => 0x800706A7 as u32,
            WIN32::RPC_S_INVALID_RPC_PROTSEQ => 0x800706A8 as u32,
            WIN32::RPC_S_INVALID_STRING_UUID => 0x800706A9 as u32,
            WIN32::RPC_S_INVALID_ENDPOINT_FORMAT => 0x800706AA as u32,
            WIN32::RPC_S_INVALID_NET_ADDR => 0x800706AB as u32,
            WIN32::RPC_S_NO_ENDPOINT_FOUND => 0x800706AC as u32,
            WIN32::RPC_S_INVALID_TIMEOUT => 0x800706AD as u32,
            WIN32::RPC_S_OBJECT_NOT_FOUND => 0x800706AE as u32,
            WIN32::RPC_S_ALREADY_REGISTERED => 0x800706AF as u32,
            WIN32::RPC_S_TYPE_ALREADY_REGISTERED => 0x800706B0 as u32,
            WIN32::RPC_S_ALREADY_LISTENING => 0x800706B1 as u32,
            WIN32::RPC_S_NO_PROTSEQS_REGISTERED => 0x800706B2 as u32,
            WIN32::RPC_S_NOT_LISTENING => 0x800706B3 as u32,
            WIN32::RPC_S_UNKNOWN_MGR_TYPE => 0x800706B4 as u32,
            WIN32::RPC_S_UNKNOWN_IF => 0x800706B5 as u32,
            WIN32::RPC_S_NO_BINDINGS => 0x800706B6 as u32,
            WIN32::RPC_S_NO_PROTSEQS => 0x800706B7 as u32,
            WIN32::RPC_S_CANT_CREATE_ENDPOINT => 0x800706B8 as u32,
            WIN32::RPC_S_OUT_OF_RESOURCES => 0x800706B9 as u32,
            WIN32::RPC_S_SERVER_UNAVAILABLE => 0x800706BA as u32,
            WIN32::RPC_S_SERVER_TOO_BUSY => 0x800706BB as u32,
            WIN32::RPC_S_INVALID_NETWORK_OPTIONS => 0x800706BC as u32,
            WIN32::RPC_S_NO_CALL_ACTIVE => 0x800706BD as u32,
            WIN32::RPC_S_CALL_FAILED => 0x800706BE as u32,
            WIN32::RPC_S_CALL_FAILED_DNE => 0x800706BF as u32,
            WIN32::RPC_S_PROTOCOL_ERROR => 0x800706C0 as u32,
            WIN32::RPC_S_PROXY_ACCESS_DENIED => 0x800706C1 as u32,
            WIN32::RPC_S_UNSUPPORTED_TRANS_SYN => 0x800706C2 as u32,
            WIN32::RPC_S_UNSUPPORTED_TYPE => 0x800706C4 as u32,
            WIN32::RPC_S_INVALID_TAG => 0x800706C5 as u32,
            WIN32::RPC_S_INVALID_BOUND => 0x800706C6 as u32,
            WIN32::RPC_S_NO_ENTRY_NAME => 0x800706C7 as u32,
            WIN32::RPC_S_INVALID_NAME_SYNTAX => 0x800706C8 as u32,
            WIN32::RPC_S_UNSUPPORTED_NAME_SYNTAX => 0x800706C9 as u32,
            WIN32::RPC_S_UUID_NO_ADDRESS => 0x800706CB as u32,
            WIN32::RPC_S_DUPLICATE_ENDPOINT => 0x800706CC as u32,
            WIN32::RPC_S_UNKNOWN_AUTHN_TYPE => 0x800706CD as u32,
            WIN32::RPC_S_MAX_CALLS_TOO_SMALL => 0x800706CE as u32,
            WIN32::RPC_S_STRING_TOO_LONG => 0x800706CF as u32,
            WIN32::RPC_S_PROTSEQ_NOT_FOUND => 0x800706D0 as u32,
            WIN32::RPC_S_PROCNUM_OUT_OF_RANGE => 0x800706D1 as u32,
            WIN32::RPC_S_BINDING_HAS_NO_AUTH => 0x800706D2 as u32,
            WIN32::RPC_S_UNKNOWN_AUTHN_SERVICE => 0x800706D3 as u32,
            WIN32::RPC_S_UNKNOWN_AUTHN_LEVEL => 0x800706D4 as u32,
            WIN32::RPC_S_INVALID_AUTH_IDENTITY => 0x800706D5 as u32,
            WIN32::RPC_S_UNKNOWN_AUTHZ_SERVICE => 0x800706D6 as u32,
            WIN32::EPT_S_INVALID_ENTRY => 0x800706D7 as u32,
            WIN32::EPT_S_CANT_PERFORM_OP => 0x800706D8 as u32,
            WIN32::EPT_S_NOT_REGISTERED => 0x800706D9 as u32,
            WIN32::RPC_S_NOTHING_TO_EXPORT => 0x800706DA as u32,
            WIN32::RPC_S_INCOMPLETE_NAME => 0x800706DB as u32,
            WIN32::RPC_S_INVALID_VERS_OPTION => 0x800706DC as u32,
            WIN32::RPC_S_NO_MORE_MEMBERS => 0x800706DD as u32,
            WIN32::RPC_S_NOT_ALL_OBJS_UNEXPORTED => 0x800706DE as u32,
            WIN32::RPC_S_INTERFACE_NOT_FOUND => 0x800706DF as u32,
            WIN32::RPC_S_ENTRY_ALREADY_EXISTS => 0x800706E0 as u32,
            WIN32::RPC_S_ENTRY_NOT_FOUND => 0x800706E1 as u32,
            WIN32::RPC_S_NAME_SERVICE_UNAVAILABLE => 0x800706E2 as u32,
            WIN32::RPC_S_INVALID_NAF_ID => 0x800706E3 as u32,
            WIN32::RPC_S_CANNOT_SUPPORT => 0x800706E4 as u32,
            WIN32::RPC_S_NO_CONTEXT_AVAILABLE => 0x800706E5 as u32,
            WIN32::RPC_S_INTERNAL_ERROR => 0x800706E6 as u32,
            WIN32::RPC_S_ZERO_DIVIDE => 0x800706E7 as u32,
            WIN32::RPC_S_ADDRESS_ERROR => 0x800706E8 as u32,
            WIN32::RPC_S_FP_DIV_ZERO => 0x800706E9 as u32,
            WIN32::RPC_S_FP_UNDERFLOW => 0x800706EA as u32,
            WIN32::RPC_S_FP_OVERFLOW => 0x800706EB as u32,
            WIN32::RPC_X_NO_MORE_ENTRIES => 0x800706EC as u32,
            WIN32::RPC_X_SS_CHAR_TRANS_OPEN_FAIL => 0x800706ED as u32,
            WIN32::RPC_X_SS_CHAR_TRANS_SHORT_FILE => 0x800706EE as u32,
            WIN32::RPC_X_SS_IN_NULL_CONTEXT => 0x800706EF as u32,
            WIN32::RPC_X_SS_CONTEXT_DAMAGED => 0x800706F1 as u32,
            WIN32::RPC_X_SS_HANDLES_MISMATCH => 0x800706F2 as u32,
            WIN32::RPC_X_SS_CANNOT_GET_CALL_HANDLE => 0x800706F3 as u32,
            WIN32::RPC_X_NULL_REF_POINTER => 0x800706F4 as u32,
            WIN32::RPC_X_ENUM_VALUE_OUT_OF_RANGE => 0x800706F5 as u32,
            WIN32::RPC_X_BYTE_COUNT_TOO_SMALL => 0x800706F6 as u32,
            WIN32::RPC_X_BAD_STUB_DATA => 0x800706F7 as u32,
            WIN32::ERROR_INVALID_USER_BUFFER => 0x800706F8 as u32,
            WIN32::ERROR_UNRECOGNIZED_MEDIA => 0x800706F9 as u32,
            WIN32::ERROR_NO_TRUST_LSA_SECRET => 0x800706FA as u32,
            WIN32::ERROR_NO_TRUST_SAM_ACCOUNT => 0x800706FB as u32,
            WIN32::ERROR_TRUSTED_DOMAIN_FAILURE => 0x800706FC as u32,
            WIN32::ERROR_TRUSTED_RELATIONSHIP_FAILURE => 0x800706FD as u32,
            WIN32::ERROR_TRUST_FAILURE => 0x800706FE as u32,
            WIN32::RPC_S_CALL_IN_PROGRESS => 0x800706FF as u32,
            WIN32::ERROR_NETLOGON_NOT_STARTED => 0x80070700 as u32,
            WIN32::ERROR_ACCOUNT_EXPIRED => 0x80070701 as u32,
            WIN32::ERROR_REDIRECTOR_HAS_OPEN_HANDLES => 0x80070702 as u32,
            WIN32::ERROR_PRINTER_DRIVER_ALREADY_INSTALLED => 0x80070703 as u32,
            WIN32::ERROR_UNKNOWN_PORT => 0x80070704 as u32,
            WIN32::ERROR_UNKNOWN_PRINTER_DRIVER => 0x80070705 as u32,
            WIN32::ERROR_UNKNOWN_PRINTPROCESSOR => 0x80070706 as u32,
            WIN32::ERROR_INVALID_SEPARATOR_FILE => 0x80070707 as u32,
            WIN32::ERROR_INVALID_PRIORITY => 0x80070708 as u32,
            WIN32::ERROR_INVALID_PRINTER_NAME => 0x80070709 as u32,
            WIN32::ERROR_PRINTER_ALREADY_EXISTS => 0x8007070A as u32,
            WIN32::ERROR_INVALID_PRINTER_COMMAND => 0x8007070B as u32,
            WIN32::ERROR_INVALID_DATATYPE => 0x8007070C as u32,
            WIN32::ERROR_INVALID_ENVIRONMENT => 0x8007070D as u32,
            WIN32::RPC_S_NO_MORE_BINDINGS => 0x8007070E as u32,
            WIN32::ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT => 0x8007070F as u32,
            WIN32::ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT => 0x80070710 as u32,
            WIN32::ERROR_NOLOGON_SERVER_TRUST_ACCOUNT => 0x80070711 as u32,
            WIN32::ERROR_DOMAIN_TRUST_INCONSISTENT => 0x80070712 as u32,
            WIN32::ERROR_SERVER_HAS_OPEN_HANDLES => 0x80070713 as u32,
            WIN32::ERROR_RESOURCE_DATA_NOT_FOUND => 0x80070714 as u32,
            WIN32::ERROR_RESOURCE_TYPE_NOT_FOUND => 0x80070715 as u32,
            WIN32::ERROR_RESOURCE_NAME_NOT_FOUND => 0x80070716 as u32,
            WIN32::ERROR_RESOURCE_LANG_NOT_FOUND => 0x80070717 as u32,
            WIN32::ERROR_NOT_ENOUGH_QUOTA => 0x80070718 as u32,
            WIN32::RPC_S_NO_INTERFACES => 0x80070719 as u32,
            WIN32::RPC_S_CALL_CANCELLED => 0x8007071A as u32,
            WIN32::RPC_S_BINDING_INCOMPLETE => 0x8007071B as u32,
            WIN32::RPC_S_COMM_FAILURE => 0x8007071C as u32,
            WIN32::RPC_S_UNSUPPORTED_AUTHN_LEVEL => 0x8007071D as u32,
            WIN32::RPC_S_NO_PRINC_NAME => 0x8007071E as u32,
            WIN32::RPC_S_NOT_RPC_ERROR => 0x8007071F as u32,
            WIN32::RPC_S_UUID_LOCAL_ONLY => 0x80070720 as u32,
            WIN32::RPC_S_SEC_PKG_ERROR => 0x80070721 as u32,
            WIN32::RPC_S_NOT_CANCELLED => 0x80070722 as u32,
            WIN32::RPC_X_INVALID_ES_ACTION => 0x80070723 as u32,
            WIN32::RPC_X_WRONG_ES_VERSION => 0x80070724 as u32,
            WIN32::RPC_X_WRONG_STUB_VERSION => 0x80070725 as u32,
            WIN32::RPC_X_INVALID_PIPE_OBJECT => 0x80070726 as u32,
            WIN32::RPC_X_WRONG_PIPE_ORDER => 0x80070727 as u32,
            WIN32::RPC_X_WRONG_PIPE_VERSION => 0x80070728 as u32,
            WIN32::RPC_S_COOKIE_AUTH_FAILED => 0x80070729 as u32,
            WIN32::RPC_S_DO_NOT_DISTURB => 0x8007072A as u32,
            WIN32::RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED => 0x8007072B as u32,
            WIN32::RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH => 0x8007072C as u32,
            WIN32::RPC_S_GROUP_MEMBER_NOT_FOUND => 0x8007076A as u32,
            WIN32::EPT_S_CANT_CREATE => 0x8007076B as u32,
            WIN32::RPC_S_INVALID_OBJECT => 0x8007076C as u32,
            WIN32::ERROR_INVALID_TIME => 0x8007076D as u32,
            WIN32::ERROR_INVALID_FORM_NAME => 0x8007076E as u32,
            WIN32::ERROR_INVALID_FORM_SIZE => 0x8007076F as u32,
            WIN32::ERROR_ALREADY_WAITING => 0x80070770 as u32,
            WIN32::ERROR_PRINTER_DELETED => 0x80070771 as u32,
            WIN32::ERROR_INVALID_PRINTER_STATE => 0x80070772 as u32,
            WIN32::ERROR_PASSWORD_MUST_CHANGE => 0x80070773 as u32,
            WIN32::ERROR_DOMAIN_CONTROLLER_NOT_FOUND => 0x80070774 as u32,
            WIN32::ERROR_ACCOUNT_LOCKED_OUT => 0x80070775 as u32,
            WIN32::OR_INVALID_OXID => 0x80070776 as u32,
            WIN32::OR_INVALID_OID => 0x80070777 as u32,
            WIN32::OR_INVALID_SET => 0x80070778 as u32,
            WIN32::RPC_S_SEND_INCOMPLETE => 0x80070779 as u32,
            WIN32::RPC_S_INVALID_ASYNC_HANDLE => 0x8007077A as u32,
            WIN32::RPC_S_INVALID_ASYNC_CALL => 0x8007077B as u32,
            WIN32::RPC_X_PIPE_CLOSED => 0x8007077C as u32,
            WIN32::RPC_X_PIPE_DISCIPLINE_ERROR => 0x8007077D as u32,
            WIN32::RPC_X_PIPE_EMPTY => 0x8007077E as u32,
            WIN32::ERROR_NO_SITENAME => 0x8007077F as u32,
            WIN32::ERROR_CANT_ACCESS_FILE => 0x80070780 as u32,
            WIN32::ERROR_CANT_RESOLVE_FILENAME => 0x80070781 as u32,
            WIN32::RPC_S_ENTRY_TYPE_MISMATCH => 0x80070782 as u32,
            WIN32::RPC_S_NOT_ALL_OBJS_EXPORTED => 0x80070783 as u32,
            WIN32::RPC_S_INTERFACE_NOT_EXPORTED => 0x80070784 as u32,
            WIN32::RPC_S_PROFILE_NOT_ADDED => 0x80070785 as u32,
            WIN32::RPC_S_PRF_ELT_NOT_ADDED => 0x80070786 as u32,
            WIN32::RPC_S_PRF_ELT_NOT_REMOVED => 0x80070787 as u32,
            WIN32::RPC_S_GRP_ELT_NOT_ADDED => 0x80070788 as u32,
            WIN32::RPC_S_GRP_ELT_NOT_REMOVED => 0x80070789 as u32,
            WIN32::ERROR_KM_DRIVER_BLOCKED => 0x8007078A as u32,
            WIN32::ERROR_CONTEXT_EXPIRED => 0x8007078B as u32,
            WIN32::ERROR_PER_USER_TRUST_QUOTA_EXCEEDED => 0x8007078C as u32,
            WIN32::ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED => 0x8007078D as u32,
            WIN32::ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED => 0x8007078E as u32,
            WIN32::ERROR_AUTHENTICATION_FIREWALL_FAILED => 0x8007078F as u32,
            WIN32::ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED => 0x80070790 as u32,
            WIN32::ERROR_NTLM_BLOCKED => 0x80070791 as u32,
            WIN32::ERROR_PASSWORD_CHANGE_REQUIRED => 0x80070792 as u32,
            WIN32::ERROR_LOST_MODE_LOGON_RESTRICTION => 0x80070793 as u32,
            WIN32::ERROR_INVALID_PIXEL_FORMAT => 0x800707D0 as u32,
            WIN32::ERROR_BAD_DRIVER => 0x800707D1 as u32,
            WIN32::ERROR_INVALID_WINDOW_STYLE => 0x800707D2 as u32,
            WIN32::ERROR_METAFILE_NOT_SUPPORTED => 0x800707D3 as u32,
            WIN32::ERROR_TRANSFORM_NOT_SUPPORTED => 0x800707D4 as u32,
            WIN32::ERROR_CLIPPING_NOT_SUPPORTED => 0x800707D5 as u32,
            WIN32::ERROR_INVALID_CMM => 0x800707DA as u32,
            WIN32::ERROR_INVALID_PROFILE => 0x800707DB as u32,
            WIN32::ERROR_TAG_NOT_FOUND => 0x800707DC as u32,
            WIN32::ERROR_TAG_NOT_PRESENT => 0x800707DD as u32,
            WIN32::ERROR_DUPLICATE_TAG => 0x800707DE as u32,
            WIN32::ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE => 0x800707DF as u32,
            WIN32::ERROR_PROFILE_NOT_FOUND => 0x800707E0 as u32,
            WIN32::ERROR_INVALID_COLORSPACE => 0x800707E1 as u32,
            WIN32::ERROR_ICM_NOT_ENABLED => 0x800707E2 as u32,
            WIN32::ERROR_DELETING_ICM_XFORM => 0x800707E3 as u32,
            WIN32::ERROR_INVALID_TRANSFORM => 0x800707E4 as u32,
            WIN32::ERROR_COLORSPACE_MISMATCH => 0x800707E5 as u32,
            WIN32::ERROR_INVALID_COLORINDEX => 0x800707E6 as u32,
            WIN32::ERROR_PROFILE_DOES_NOT_MATCH_DEVICE => 0x800707E7 as u32,
            WIN32::NERR_NetNotStarted => 0x80070836 as u32,
            WIN32::NERR_UnknownServer => 0x80070837 as u32,
            WIN32::NERR_ShareMem => 0x80070838 as u32,
            WIN32::NERR_NoNetworkResource => 0x80070839 as u32,
            WIN32::NERR_RemoteOnly => 0x8007083A as u32,
            WIN32::NERR_DevNotRedirected => 0x8007083B as u32,
            WIN32::ERROR_CONNECTED_OTHER_PASSWORD => 0x8007083C as u32,
            WIN32::ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT => 0x8007083D as u32,
            WIN32::NERR_ServerNotStarted => 0x80070842 as u32,
            WIN32::NERR_ItemNotFound => 0x80070843 as u32,
            WIN32::NERR_UnknownDevDir => 0x80070844 as u32,
            WIN32::NERR_RedirectedPath => 0x80070845 as u32,
            WIN32::NERR_DuplicateShare => 0x80070846 as u32,
            WIN32::NERR_NoRoom => 0x80070847 as u32,
            WIN32::NERR_TooManyItems => 0x80070849 as u32,
            WIN32::NERR_InvalidMaxUsers => 0x8007084A as u32,
            WIN32::NERR_BufTooSmall => 0x8007084B as u32,
            WIN32::NERR_RemoteErr => 0x8007084F as u32,
            WIN32::NERR_LanmanIniError => 0x80070853 as u32,
            WIN32::NERR_NetworkError => 0x80070858 as u32,
            WIN32::NERR_WkstaInconsistentState => 0x80070859 as u32,
            WIN32::NERR_WkstaNotStarted => 0x8007085A as u32,
            WIN32::NERR_BrowserNotStarted => 0x8007085B as u32,
            WIN32::NERR_InternalError => 0x8007085C as u32,
            WIN32::NERR_BadTransactConfig => 0x8007085D as u32,
            WIN32::NERR_InvalidAPI => 0x8007085E as u32,
            WIN32::NERR_BadEventName => 0x8007085F as u32,
            WIN32::NERR_DupNameReboot => 0x80070860 as u32,
            WIN32::NERR_CfgCompNotFound => 0x80070862 as u32,
            WIN32::NERR_CfgParamNotFound => 0x80070863 as u32,
            WIN32::NERR_LineTooLong => 0x80070865 as u32,
            WIN32::NERR_QNotFound => 0x80070866 as u32,
            WIN32::NERR_JobNotFound => 0x80070867 as u32,
            WIN32::NERR_DestNotFound => 0x80070868 as u32,
            WIN32::NERR_DestExists => 0x80070869 as u32,
            WIN32::NERR_QExists => 0x8007086A as u32,
            WIN32::NERR_QNoRoom => 0x8007086B as u32,
            WIN32::NERR_JobNoRoom => 0x8007086C as u32,
            WIN32::NERR_DestNoRoom => 0x8007086D as u32,
            WIN32::NERR_DestIdle => 0x8007086E as u32,
            WIN32::NERR_DestInvalidOp => 0x8007086F as u32,
            WIN32::NERR_ProcNoRespond => 0x80070870 as u32,
            WIN32::NERR_SpoolerNotLoaded => 0x80070871 as u32,
            WIN32::NERR_DestInvalidState => 0x80070872 as u32,
            WIN32::NERR_QinvalidState => 0x80070873 as u32,
            WIN32::NERR_JobInvalidState => 0x80070874 as u32,
            WIN32::NERR_SpoolNoMemory => 0x80070875 as u32,
            WIN32::NERR_DriverNotFound => 0x80070876 as u32,
            WIN32::NERR_DataTypeInvalid => 0x80070877 as u32,
            WIN32::NERR_ProcNotFound => 0x80070878 as u32,
            WIN32::NERR_ServiceTableLocked => 0x80070884 as u32,
            WIN32::NERR_ServiceTableFull => 0x80070885 as u32,
            WIN32::NERR_ServiceInstalled => 0x80070886 as u32,
            WIN32::NERR_ServiceEntryLocked => 0x80070887 as u32,
            WIN32::NERR_ServiceNotInstalled => 0x80070888 as u32,
            WIN32::NERR_BadServiceName => 0x80070889 as u32,
            WIN32::NERR_ServiceCtlTimeout => 0x8007088A as u32,
            WIN32::NERR_ServiceCtlBusy => 0x8007088B as u32,
            WIN32::NERR_BadServiceProgName => 0x8007088C as u32,
            WIN32::NERR_ServiceNotCtrl => 0x8007088D as u32,
            WIN32::NERR_ServiceKillProc => 0x8007088E as u32,
            WIN32::NERR_ServiceCtlNotValid => 0x8007088F as u32,
            WIN32::NERR_NotInDispatchTbl => 0x80070890 as u32,
            WIN32::NERR_BadControlRecv => 0x80070891 as u32,
            WIN32::NERR_ServiceNotStarting => 0x80070892 as u32,
            WIN32::NERR_AlreadyLoggedOn => 0x80070898 as u32,
            WIN32::NERR_NotLoggedOn => 0x80070899 as u32,
            WIN32::ERROR_BAD_USERNAME => 0x8007089A as u32,
            WIN32::NERR_BadUsername => 0x8007089A as u32,
            WIN32::NERR_BadPassword => 0x8007089B as u32,
            WIN32::NERR_UnableToAddName_W => 0x8007089C as u32,
            WIN32::NERR_UnableToAddName_F => 0x8007089D as u32,
            WIN32::NERR_UnableToDelName_W => 0x8007089E as u32,
            WIN32::NERR_UnableToDelName_F => 0x8007089F as u32,
            WIN32::NERR_LogonsPaused => 0x800708A1 as u32,
            WIN32::NERR_LogonServerConflict => 0x800708A2 as u32,
            WIN32::NERR_LogonNoUserPath => 0x800708A3 as u32,
            WIN32::NERR_LogonScriptError => 0x800708A4 as u32,
            WIN32::NERR_StandaloneLogon => 0x800708A6 as u32,
            WIN32::NERR_LogonServerNotFound => 0x800708A7 as u32,
            WIN32::NERR_LogonDomainExists => 0x800708A8 as u32,
            WIN32::NERR_NonValidatedLogon => 0x800708A9 as u32,
            WIN32::NERR_ACFNotFound => 0x800708AB as u32,
            WIN32::NERR_GroupNotFound => 0x800708AC as u32,
            WIN32::NERR_UserNotFound => 0x800708AD as u32,
            WIN32::NERR_ResourceNotFound => 0x800708AE as u32,
            WIN32::NERR_GroupExists => 0x800708AF as u32,
            WIN32::NERR_UserExists => 0x800708B0 as u32,
            WIN32::NERR_ResourceExists => 0x800708B1 as u32,
            WIN32::NERR_NotPrimary => 0x800708B2 as u32,
            WIN32::NERR_ACFNotLoaded => 0x800708B3 as u32,
            WIN32::NERR_ACFNoRoom => 0x800708B4 as u32,
            WIN32::NERR_ACFFileIOFail => 0x800708B5 as u32,
            WIN32::NERR_ACFTooManyLists => 0x800708B6 as u32,
            WIN32::NERR_UserLogon => 0x800708B7 as u32,
            WIN32::NERR_ACFNoParent => 0x800708B8 as u32,
            WIN32::NERR_CanNotGrowSegment => 0x800708B9 as u32,
            WIN32::NERR_SpeGroupOp => 0x800708BA as u32,
            WIN32::NERR_NotInCache => 0x800708BB as u32,
            WIN32::NERR_UserInGroup => 0x800708BC as u32,
            WIN32::NERR_UserNotInGroup => 0x800708BD as u32,
            WIN32::NERR_AccountUndefined => 0x800708BE as u32,
            WIN32::NERR_AccountExpired => 0x800708BF as u32,
            WIN32::NERR_InvalidWorkstation => 0x800708C0 as u32,
            WIN32::NERR_InvalidLogonHours => 0x800708C1 as u32,
            WIN32::NERR_PasswordExpired => 0x800708C2 as u32,
            WIN32::NERR_PasswordCantChange => 0x800708C3 as u32,
            WIN32::NERR_PasswordHistConflict => 0x800708C4 as u32,
            WIN32::NERR_PasswordTooShort => 0x800708C5 as u32,
            WIN32::NERR_PasswordTooRecent => 0x800708C6 as u32,
            WIN32::NERR_InvalidDatabase => 0x800708C7 as u32,
            WIN32::NERR_DatabaseUpToDate => 0x800708C8 as u32,
            WIN32::NERR_SyncRequired => 0x800708C9 as u32,
            WIN32::ERROR_NOT_CONNECTED => 0x800708CA as u32,
            WIN32::NERR_UseNotFound => 0x800708CA as u32,
            WIN32::NERR_BadAsgType => 0x800708CB as u32,
            WIN32::NERR_DeviceIsShared => 0x800708CC as u32,
            WIN32::NERR_NoComputerName => 0x800708DE as u32,
            WIN32::NERR_MsgAlreadyStarted => 0x800708DF as u32,
            WIN32::NERR_MsgInitFailed => 0x800708E0 as u32,
            WIN32::NERR_NameNotFound => 0x800708E1 as u32,
            WIN32::NERR_AlreadyForwarded => 0x800708E2 as u32,
            WIN32::NERR_AddForwarded => 0x800708E3 as u32,
            WIN32::NERR_AlreadyExists => 0x800708E4 as u32,
            WIN32::NERR_TooManyNames => 0x800708E5 as u32,
            WIN32::NERR_DelComputerName => 0x800708E6 as u32,
            WIN32::NERR_LocalForward => 0x800708E7 as u32,
            WIN32::NERR_GrpMsgProcessor => 0x800708E8 as u32,
            WIN32::NERR_PausedRemote => 0x800708E9 as u32,
            WIN32::NERR_BadReceive => 0x800708EA as u32,
            WIN32::NERR_NameInUse => 0x800708EB as u32,
            WIN32::NERR_MsgNotStarted => 0x800708EC as u32,
            WIN32::NERR_NotLocalName => 0x800708ED as u32,
            WIN32::NERR_NoForwardName => 0x800708EE as u32,
            WIN32::NERR_RemoteFull => 0x800708EF as u32,
            WIN32::NERR_NameNotForwarded => 0x800708F0 as u32,
            WIN32::NERR_TruncatedBroadcast => 0x800708F1 as u32,
            WIN32::NERR_InvalidDevice => 0x800708F6 as u32,
            WIN32::NERR_WriteFault => 0x800708F7 as u32,
            WIN32::NERR_DuplicateName => 0x800708F9 as u32,
            WIN32::NERR_DeleteLater => 0x800708FA as u32,
            WIN32::NERR_IncompleteDel => 0x800708FB as u32,
            WIN32::NERR_MultipleNets => 0x800708FC as u32,
            WIN32::NERR_NetNameNotFound => 0x80070906 as u32,
            WIN32::NERR_DeviceNotShared => 0x80070907 as u32,
            WIN32::NERR_ClientNameNotFound => 0x80070908 as u32,
            WIN32::NERR_FileIdNotFound => 0x8007090A as u32,
            WIN32::NERR_ExecFailure => 0x8007090B as u32,
            WIN32::NERR_TmpFile => 0x8007090C as u32,
            WIN32::NERR_TooMuchData => 0x8007090D as u32,
            WIN32::NERR_DeviceShareConflict => 0x8007090E as u32,
            WIN32::NERR_BrowserTableIncomplete => 0x8007090F as u32,
            WIN32::NERR_NotLocalDomain => 0x80070910 as u32,
            WIN32::NERR_IsDfsShare => 0x80070911 as u32,
            WIN32::NERR_DevInvalidOpCode => 0x8007091B as u32,
            WIN32::NERR_DevNotFound => 0x8007091C as u32,
            WIN32::NERR_DevNotOpen => 0x8007091D as u32,
            WIN32::NERR_BadQueueDevString => 0x8007091E as u32,
            WIN32::NERR_BadQueuePriority => 0x8007091F as u32,
            WIN32::NERR_NoCommDevs => 0x80070921 as u32,
            WIN32::NERR_QueueNotFound => 0x80070922 as u32,
            WIN32::NERR_BadDevString => 0x80070924 as u32,
            WIN32::NERR_BadDev => 0x80070925 as u32,
            WIN32::NERR_InUseBySpooler => 0x80070926 as u32,
            WIN32::NERR_CommDevInUse => 0x80070927 as u32,
            WIN32::NERR_InvalidComputer => 0x8007092F as u32,
            WIN32::NERR_MaxLenExceeded => 0x80070932 as u32,
            WIN32::NERR_BadComponent => 0x80070934 as u32,
            WIN32::NERR_CantType => 0x80070935 as u32,
            WIN32::NERR_TooManyEntries => 0x8007093A as u32,
            WIN32::NERR_ProfileFileTooBig => 0x80070942 as u32,
            WIN32::NERR_ProfileOffset => 0x80070943 as u32,
            WIN32::NERR_ProfileCleanup => 0x80070944 as u32,
            WIN32::NERR_ProfileUnknownCmd => 0x80070945 as u32,
            WIN32::NERR_ProfileLoadErr => 0x80070946 as u32,
            WIN32::NERR_ProfileSaveErr => 0x80070947 as u32,
            WIN32::NERR_LogOverflow => 0x80070949 as u32,
            WIN32::NERR_LogFileChanged => 0x8007094A as u32,
            WIN32::NERR_LogFileCorrupt => 0x8007094B as u32,
            WIN32::NERR_SourceIsDir => 0x8007094C as u32,
            WIN32::NERR_BadSource => 0x8007094D as u32,
            WIN32::NERR_BadDest => 0x8007094E as u32,
            WIN32::NERR_DifferentServers => 0x8007094F as u32,
            WIN32::NERR_RunSrvPaused => 0x80070951 as u32,
            WIN32::NERR_ErrCommRunSrv => 0x80070955 as u32,
            WIN32::NERR_ErrorExecingGhost => 0x80070957 as u32,
            WIN32::NERR_ShareNotFound => 0x80070958 as u32,
            WIN32::NERR_InvalidLana => 0x80070960 as u32,
            WIN32::ERROR_OPEN_FILES => 0x80070961 as u32,
            WIN32::NERR_OpenFiles => 0x80070961 as u32,
            WIN32::ERROR_ACTIVE_CONNECTIONS => 0x80070962 as u32,
            WIN32::NERR_ActiveConns => 0x80070962 as u32,
            WIN32::NERR_BadPasswordCore => 0x80070963 as u32,
            WIN32::ERROR_DEVICE_IN_USE => 0x80070964 as u32,
            WIN32::NERR_DevInUse => 0x80070964 as u32,
            WIN32::NERR_LocalDrive => 0x80070965 as u32,
            WIN32::NERR_AlertExists => 0x8007097E as u32,
            WIN32::NERR_TooManyAlerts => 0x8007097F as u32,
            WIN32::NERR_NoSuchAlert => 0x80070980 as u32,
            WIN32::NERR_BadRecipient => 0x80070981 as u32,
            WIN32::NERR_AcctLimitExceeded => 0x80070982 as u32,
            WIN32::NERR_InvalidLogSeek => 0x80070988 as u32,
            WIN32::NERR_BadUasConfig => 0x80070992 as u32,
            WIN32::NERR_InvalidUASOp => 0x80070993 as u32,
            WIN32::NERR_LastAdmin => 0x80070994 as u32,
            WIN32::NERR_DCNotFound => 0x80070995 as u32,
            WIN32::NERR_LogonTrackingError => 0x80070996 as u32,
            WIN32::NERR_NetlogonNotStarted => 0x80070997 as u32,
            WIN32::NERR_CanNotGrowUASFile => 0x80070998 as u32,
            WIN32::NERR_TimeDiffAtDC => 0x80070999 as u32,
            WIN32::NERR_PasswordMismatch => 0x8007099A as u32,
            WIN32::NERR_NoSuchServer => 0x8007099C as u32,
            WIN32::NERR_NoSuchSession => 0x8007099D as u32,
            WIN32::NERR_NoSuchConnection => 0x8007099E as u32,
            WIN32::NERR_TooManyServers => 0x8007099F as u32,
            WIN32::NERR_TooManySessions => 0x800709A0 as u32,
            WIN32::NERR_TooManyConnections => 0x800709A1 as u32,
            WIN32::NERR_TooManyFiles => 0x800709A2 as u32,
            WIN32::NERR_NoAlternateServers => 0x800709A3 as u32,
            WIN32::NERR_TryDownLevel => 0x800709A6 as u32,
            WIN32::NERR_UPSDriverNotStarted => 0x800709B0 as u32,
            WIN32::NERR_UPSInvalidConfig => 0x800709B1 as u32,
            WIN32::NERR_UPSInvalidCommPort => 0x800709B2 as u32,
            WIN32::NERR_UPSSignalAsserted => 0x800709B3 as u32,
            WIN32::NERR_UPSShutdownFailed => 0x800709B4 as u32,
            WIN32::NERR_BadDosRetCode => 0x800709C4 as u32,
            WIN32::NERR_ProgNeedsExtraMem => 0x800709C5 as u32,
            WIN32::NERR_BadDosFunction => 0x800709C6 as u32,
            WIN32::NERR_RemoteBootFailed => 0x800709C7 as u32,
            WIN32::NERR_BadFileCheckSum => 0x800709C8 as u32,
            WIN32::NERR_NoRplBootSystem => 0x800709C9 as u32,
            WIN32::NERR_RplLoadrNetBiosErr => 0x800709CA as u32,
            WIN32::NERR_RplLoadrDiskErr => 0x800709CB as u32,
            WIN32::NERR_ImageParamErr => 0x800709CC as u32,
            WIN32::NERR_TooManyImageParams => 0x800709CD as u32,
            WIN32::NERR_NonDosFloppyUsed => 0x800709CE as u32,
            WIN32::NERR_RplBootRestart => 0x800709CF as u32,
            WIN32::NERR_RplSrvrCallFailed => 0x800709D0 as u32,
            WIN32::NERR_CantConnectRplSrvr => 0x800709D1 as u32,
            WIN32::NERR_CantOpenImageFile => 0x800709D2 as u32,
            WIN32::NERR_CallingRplSrvr => 0x800709D3 as u32,
            WIN32::NERR_StartingRplBoot => 0x800709D4 as u32,
            WIN32::NERR_RplBootServiceTerm => 0x800709D5 as u32,
            WIN32::NERR_RplBootStartFailed => 0x800709D6 as u32,
            WIN32::NERR_RPL_CONNECTED => 0x800709D7 as u32,
            WIN32::NERR_BrowserConfiguredToNotRun => 0x800709F6 as u32,
            WIN32::NERR_RplNoAdaptersStarted => 0x80070A32 as u32,
            WIN32::NERR_RplBadRegistry => 0x80070A33 as u32,
            WIN32::NERR_RplBadDatabase => 0x80070A34 as u32,
            WIN32::NERR_RplRplfilesShare => 0x80070A35 as u32,
            WIN32::NERR_RplNotRplServer => 0x80070A36 as u32,
            WIN32::NERR_RplCannotEnum => 0x80070A37 as u32,
            WIN32::NERR_RplWkstaInfoCorrupted => 0x80070A38 as u32,
            WIN32::NERR_RplWkstaNotFound => 0x80070A39 as u32,
            WIN32::NERR_RplWkstaNameUnavailable => 0x80070A3A as u32,
            WIN32::NERR_RplProfileInfoCorrupted => 0x80070A3B as u32,
            WIN32::NERR_RplProfileNotFound => 0x80070A3C as u32,
            WIN32::NERR_RplProfileNameUnavailable => 0x80070A3D as u32,
            WIN32::NERR_RplProfileNotEmpty => 0x80070A3E as u32,
            WIN32::NERR_RplConfigInfoCorrupted => 0x80070A3F as u32,
            WIN32::NERR_RplConfigNotFound => 0x80070A40 as u32,
            WIN32::NERR_RplAdapterInfoCorrupted => 0x80070A41 as u32,
            WIN32::NERR_RplInternal => 0x80070A42 as u32,
            WIN32::NERR_RplVendorInfoCorrupted => 0x80070A43 as u32,
            WIN32::NERR_RplBootInfoCorrupted => 0x80070A44 as u32,
            WIN32::NERR_RplWkstaNeedsUserAcct => 0x80070A45 as u32,
            WIN32::NERR_RplNeedsRPLUSERAcct => 0x80070A46 as u32,
            WIN32::NERR_RplBootNotFound => 0x80070A47 as u32,
            WIN32::NERR_RplIncompatibleProfile => 0x80070A48 as u32,
            WIN32::NERR_RplAdapterNameUnavailable => 0x80070A49 as u32,
            WIN32::NERR_RplConfigNotEmpty => 0x80070A4A as u32,
            WIN32::NERR_RplBootInUse => 0x80070A4B as u32,
            WIN32::NERR_RplBackupDatabase => 0x80070A4C as u32,
            WIN32::NERR_RplAdapterNotFound => 0x80070A4D as u32,
            WIN32::NERR_RplVendorNotFound => 0x80070A4E as u32,
            WIN32::NERR_RplVendorNameUnavailable => 0x80070A4F as u32,
            WIN32::NERR_RplBootNameUnavailable => 0x80070A50 as u32,
            WIN32::NERR_RplConfigNameUnavailable => 0x80070A51 as u32,
            WIN32::NERR_DfsInternalCorruption => 0x80070A64 as u32,
            WIN32::NERR_DfsVolumeDataCorrupt => 0x80070A65 as u32,
            WIN32::NERR_DfsNoSuchVolume => 0x80070A66 as u32,
            WIN32::NERR_DfsVolumeAlreadyExists => 0x80070A67 as u32,
            WIN32::NERR_DfsAlreadyShared => 0x80070A68 as u32,
            WIN32::NERR_DfsNoSuchShare => 0x80070A69 as u32,
            WIN32::NERR_DfsNotALeafVolume => 0x80070A6A as u32,
            WIN32::NERR_DfsLeafVolume => 0x80070A6B as u32,
            WIN32::NERR_DfsVolumeHasMultipleServers => 0x80070A6C as u32,
            WIN32::NERR_DfsCantCreateJunctionPoint => 0x80070A6D as u32,
            WIN32::NERR_DfsServerNotDfsAware => 0x80070A6E as u32,
            WIN32::NERR_DfsBadRenamePath => 0x80070A6F as u32,
            WIN32::NERR_DfsVolumeIsOffline => 0x80070A70 as u32,
            WIN32::NERR_DfsNoSuchServer => 0x80070A71 as u32,
            WIN32::NERR_DfsCyclicalName => 0x80070A72 as u32,
            WIN32::NERR_DfsNotSupportedInServerDfs => 0x80070A73 as u32,
            WIN32::NERR_DfsDuplicateService => 0x80070A74 as u32,
            WIN32::NERR_DfsCantRemoveLastServerShare => 0x80070A75 as u32,
            WIN32::NERR_DfsVolumeIsInterDfs => 0x80070A76 as u32,
            WIN32::NERR_DfsInconsistent => 0x80070A77 as u32,
            WIN32::NERR_DfsServerUpgraded => 0x80070A78 as u32,
            WIN32::NERR_DfsDataIsIdentical => 0x80070A79 as u32,
            WIN32::NERR_DfsCantRemoveDfsRoot => 0x80070A7A as u32,
            WIN32::NERR_DfsChildOrParentInDfs => 0x80070A7B as u32,
            WIN32::NERR_DfsInternalError => 0x80070A82 as u32,
            WIN32::NERR_SetupAlreadyJoined => 0x80070A83 as u32,
            WIN32::NERR_SetupNotJoined => 0x80070A84 as u32,
            WIN32::NERR_SetupDomainController => 0x80070A85 as u32,
            WIN32::NERR_DefaultJoinRequired => 0x80070A86 as u32,
            WIN32::NERR_InvalidWorkgroupName => 0x80070A87 as u32,
            WIN32::NERR_NameUsesIncompatibleCodePage => 0x80070A88 as u32,
            WIN32::NERR_ComputerAccountNotFound => 0x80070A89 as u32,
            WIN32::NERR_PersonalSku => 0x80070A8A as u32,
            WIN32::NERR_PasswordMustChange => 0x80070A8D as u32,
            WIN32::NERR_AccountLockedOut => 0x80070A8E as u32,
            WIN32::NERR_PasswordTooLong => 0x80070A8F as u32,
            WIN32::NERR_PasswordNotComplexEnough => 0x80070A90 as u32,
            WIN32::NERR_PasswordFilterError => 0x80070A91 as u32,
            WIN32::ERROR_UNKNOWN_PRINT_MONITOR => 0x80070BB8 as u32,
            WIN32::ERROR_PRINTER_DRIVER_IN_USE => 0x80070BB9 as u32,
            WIN32::ERROR_SPOOL_FILE_NOT_FOUND => 0x80070BBA as u32,
            WIN32::ERROR_SPL_NO_STARTDOC => 0x80070BBB as u32,
            WIN32::ERROR_SPL_NO_ADDJOB => 0x80070BBC as u32,
            WIN32::ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED => 0x80070BBD as u32,
            WIN32::ERROR_PRINT_MONITOR_ALREADY_INSTALLED => 0x80070BBE as u32,
            WIN32::ERROR_INVALID_PRINT_MONITOR => 0x80070BBF as u32,
            WIN32::ERROR_PRINT_MONITOR_IN_USE => 0x80070BC0 as u32,
            WIN32::ERROR_PRINTER_HAS_JOBS_QUEUED => 0x80070BC1 as u32,
            WIN32::ERROR_SUCCESS_REBOOT_REQUIRED => 0x80070BC2 as u32,
            WIN32::ERROR_SUCCESS_RESTART_REQUIRED => 0x80070BC3 as u32,
            WIN32::ERROR_PRINTER_NOT_FOUND => 0x80070BC4 as u32,
            WIN32::ERROR_PRINTER_DRIVER_WARNED => 0x80070BC5 as u32,
            WIN32::ERROR_PRINTER_DRIVER_BLOCKED => 0x80070BC6 as u32,
            WIN32::ERROR_PRINTER_DRIVER_PACKAGE_IN_USE => 0x80070BC7 as u32,
            WIN32::ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND => 0x80070BC8 as u32,
            WIN32::ERROR_FAIL_REBOOT_REQUIRED => 0x80070BC9 as u32,
            WIN32::ERROR_FAIL_REBOOT_INITIATED => 0x80070BCA as u32,
            WIN32::ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED => 0x80070BCB as u32,
            WIN32::ERROR_PRINT_JOB_RESTART_REQUIRED => 0x80070BCC as u32,
            WIN32::ERROR_INVALID_PRINTER_DRIVER_MANIFEST => 0x80070BCD as u32,
            WIN32::ERROR_PRINTER_NOT_SHAREABLE => 0x80070BCE as u32,
            WIN32::ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1 => 0x80070BCF as u32,
            WIN32::ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED => 0x80070BD0 as u32,
            WIN32::ERROR_REQUEST_PAUSED => 0x80070BEA as u32,
            WIN32::ERROR_APPEXEC_CONDITION_NOT_SATISFIED => 0x80070BF4 as u32,
            WIN32::ERROR_APPEXEC_HANDLE_INVALIDATED => 0x80070BF5 as u32,
            WIN32::ERROR_APPEXEC_INVALID_HOST_GENERATION => 0x80070BF6 as u32,
            WIN32::ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION => 0x80070BF7 as u32,
            WIN32::ERROR_APPEXEC_INVALID_HOST_STATE => 0x80070BF8 as u32,
            WIN32::ERROR_APPEXEC_NO_DONOR => 0x80070BF9 as u32,
            WIN32::ERROR_APPEXEC_HOST_ID_MISMATCH => 0x80070BFA as u32,
            WIN32::ERROR_APPEXEC_UNKNOWN_USER => 0x80070BFB as u32,
            WIN32::ERROR_APPEXEC_APP_COMPAT_BLOCK => 0x80070BFC as u32,
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT => 0x80070BFD as u32,
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION => 0x80070BFE as u32,
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING => 0x80070BFF as u32,
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES => 0x80070C00 as u32,
            WIN32::ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED => 0x80070C08 as u32,
            WIN32::ERROR_VRF_VOLATILE_NOT_STOPPABLE => 0x80070C09 as u32,
            WIN32::ERROR_VRF_VOLATILE_SAFE_MODE => 0x80070C0A as u32,
            WIN32::ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM => 0x80070C0B as u32,
            WIN32::ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS => 0x80070C0C as u32,
            WIN32::ERROR_VRF_VOLATILE_PROTECTED_DRIVER => 0x80070C0D as u32,
            WIN32::ERROR_VRF_VOLATILE_NMI_REGISTERED => 0x80070C0E as u32,
            WIN32::ERROR_VRF_VOLATILE_SETTINGS_CONFLICT => 0x80070C0F as u32,
            WIN32::ERROR_DIF_IOCALLBACK_NOT_REPLACED => 0x80070C76 as u32,
            WIN32::ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED => 0x80070C77 as u32,
            WIN32::ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED => 0x80070C78 as u32,
            WIN32::ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED => 0x80070C79 as u32,
            WIN32::ERROR_DIF_VOLATILE_INVALID_INFO => 0x80070C7A as u32,
            WIN32::ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING => 0x80070C7B as u32,
            WIN32::ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING => 0x80070C7C as u32,
            WIN32::ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED => 0x80070C7D as u32,
            WIN32::ERROR_DIF_VOLATILE_NOT_ALLOWED => 0x80070C7E as u32,
            WIN32::ERROR_DIF_BINDING_API_NOT_FOUND => 0x80070C7F as u32,
            WIN32::ERROR_IO_REISSUE_AS_CACHED => 0x80070F6E as u32,
            WIN32::ERROR_WINS_INTERNAL => 0x80070FA0 as u32,
            WIN32::ERROR_CAN_NOT_DEL_LOCAL_WINS => 0x80070FA1 as u32,
            WIN32::ERROR_STATIC_INIT => 0x80070FA2 as u32,
            WIN32::ERROR_INC_BACKUP => 0x80070FA3 as u32,
            WIN32::ERROR_FULL_BACKUP => 0x80070FA4 as u32,
            WIN32::ERROR_REC_NON_EXISTENT => 0x80070FA5 as u32,
            WIN32::ERROR_RPL_NOT_ALLOWED => 0x80070FA6 as u32,
            WIN32::PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED => 0x80070FD2 as u32,
            WIN32::PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO => 0x80070FD3 as u32,
            WIN32::PEERDIST_ERROR_MISSING_DATA => 0x80070FD4 as u32,
            WIN32::PEERDIST_ERROR_NO_MORE => 0x80070FD5 as u32,
            WIN32::PEERDIST_ERROR_NOT_INITIALIZED => 0x80070FD6 as u32,
            WIN32::PEERDIST_ERROR_ALREADY_INITIALIZED => 0x80070FD7 as u32,
            WIN32::PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS => 0x80070FD8 as u32,
            WIN32::PEERDIST_ERROR_INVALIDATED => 0x80070FD9 as u32,
            WIN32::PEERDIST_ERROR_ALREADY_EXISTS => 0x80070FDA as u32,
            WIN32::PEERDIST_ERROR_OPERATION_NOTFOUND => 0x80070FDB as u32,
            WIN32::PEERDIST_ERROR_ALREADY_COMPLETED => 0x80070FDC as u32,
            WIN32::PEERDIST_ERROR_OUT_OF_BOUNDS => 0x80070FDD as u32,
            WIN32::PEERDIST_ERROR_VERSION_UNSUPPORTED => 0x80070FDE as u32,
            WIN32::PEERDIST_ERROR_INVALID_CONFIGURATION => 0x80070FDF as u32,
            WIN32::PEERDIST_ERROR_NOT_LICENSED => 0x80070FE0 as u32,
            WIN32::PEERDIST_ERROR_SERVICE_UNAVAILABLE => 0x80070FE1 as u32,
            WIN32::PEERDIST_ERROR_TRUST_FAILURE => 0x80070FE2 as u32,
            WIN32::ERROR_DHCP_ADDRESS_CONFLICT => 0x80071004 as u32,
            WIN32::ERROR_WMI_GUID_NOT_FOUND => 0x80071068 as u32,
            WIN32::ERROR_WMI_INSTANCE_NOT_FOUND => 0x80071069 as u32,
            WIN32::ERROR_WMI_ITEMID_NOT_FOUND => 0x8007106A as u32,
            WIN32::ERROR_WMI_TRY_AGAIN => 0x8007106B as u32,
            WIN32::ERROR_WMI_DP_NOT_FOUND => 0x8007106C as u32,
            WIN32::ERROR_WMI_UNRESOLVED_INSTANCE_REF => 0x8007106D as u32,
            WIN32::ERROR_WMI_ALREADY_ENABLED => 0x8007106E as u32,
            WIN32::ERROR_WMI_GUID_DISCONNECTED => 0x8007106F as u32,
            WIN32::ERROR_WMI_SERVER_UNAVAILABLE => 0x80071070 as u32,
            WIN32::ERROR_WMI_DP_FAILED => 0x80071071 as u32,
            WIN32::ERROR_WMI_INVALID_MOF => 0x80071072 as u32,
            WIN32::ERROR_WMI_INVALID_REGINFO => 0x80071073 as u32,
            WIN32::ERROR_WMI_ALREADY_DISABLED => 0x80071074 as u32,
            WIN32::ERROR_WMI_READ_ONLY => 0x80071075 as u32,
            WIN32::ERROR_WMI_SET_FAILURE => 0x80071076 as u32,
            WIN32::ERROR_NOT_APPCONTAINER => 0x8007109A as u32,
            WIN32::ERROR_APPCONTAINER_REQUIRED => 0x8007109B as u32,
            WIN32::ERROR_NOT_SUPPORTED_IN_APPCONTAINER => 0x8007109C as u32,
            WIN32::ERROR_INVALID_PACKAGE_SID_LENGTH => 0x8007109D as u32,
            WIN32::ERROR_INVALID_MEDIA => 0x800710CC as u32,
            WIN32::ERROR_INVALID_LIBRARY => 0x800710CD as u32,
            WIN32::ERROR_INVALID_MEDIA_POOL => 0x800710CE as u32,
            WIN32::ERROR_DRIVE_MEDIA_MISMATCH => 0x800710CF as u32,
            WIN32::ERROR_MEDIA_OFFLINE => 0x800710D0 as u32,
            WIN32::ERROR_LIBRARY_OFFLINE => 0x800710D1 as u32,
            WIN32::ERROR_EMPTY => 0x800710D2 as u32,
            WIN32::ERROR_NOT_EMPTY => 0x800710D3 as u32,
            WIN32::ERROR_MEDIA_UNAVAILABLE => 0x800710D4 as u32,
            WIN32::ERROR_RESOURCE_DISABLED => 0x800710D5 as u32,
            WIN32::ERROR_INVALID_CLEANER => 0x800710D6 as u32,
            WIN32::ERROR_UNABLE_TO_CLEAN => 0x800710D7 as u32,
            WIN32::ERROR_OBJECT_NOT_FOUND => 0x800710D8 as u32,
            WIN32::ERROR_DATABASE_FAILURE => 0x800710D9 as u32,
            WIN32::ERROR_DATABASE_FULL => 0x800710DA as u32,
            WIN32::ERROR_MEDIA_INCOMPATIBLE => 0x800710DB as u32,
            WIN32::ERROR_RESOURCE_NOT_PRESENT => 0x800710DC as u32,
            WIN32::ERROR_INVALID_OPERATION => 0x800710DD as u32,
            WIN32::ERROR_MEDIA_NOT_AVAILABLE => 0x800710DE as u32,
            WIN32::ERROR_DEVICE_NOT_AVAILABLE => 0x800710DF as u32,
            WIN32::ERROR_REQUEST_REFUSED => 0x800710E0 as u32,
            WIN32::ERROR_INVALID_DRIVE_OBJECT => 0x800710E1 as u32,
            WIN32::ERROR_LIBRARY_FULL => 0x800710E2 as u32,
            WIN32::ERROR_MEDIUM_NOT_ACCESSIBLE => 0x800710E3 as u32,
            WIN32::ERROR_UNABLE_TO_LOAD_MEDIUM => 0x800710E4 as u32,
            WIN32::ERROR_UNABLE_TO_INVENTORY_DRIVE => 0x800710E5 as u32,
            WIN32::ERROR_UNABLE_TO_INVENTORY_SLOT => 0x800710E6 as u32,
            WIN32::ERROR_UNABLE_TO_INVENTORY_TRANSPORT => 0x800710E7 as u32,
            WIN32::ERROR_TRANSPORT_FULL => 0x800710E8 as u32,
            WIN32::ERROR_CONTROLLING_IEPORT => 0x800710E9 as u32,
            WIN32::ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA => 0x800710EA as u32,
            WIN32::ERROR_CLEANER_SLOT_SET => 0x800710EB as u32,
            WIN32::ERROR_CLEANER_SLOT_NOT_SET => 0x800710EC as u32,
            WIN32::ERROR_CLEANER_CARTRIDGE_SPENT => 0x800710ED as u32,
            WIN32::ERROR_UNEXPECTED_OMID => 0x800710EE as u32,
            WIN32::ERROR_CANT_DELETE_LAST_ITEM => 0x800710EF as u32,
            WIN32::ERROR_MESSAGE_EXCEEDS_MAX_SIZE => 0x800710F0 as u32,
            WIN32::ERROR_VOLUME_CONTAINS_SYS_FILES => 0x800710F1 as u32,
            WIN32::ERROR_INDIGENOUS_TYPE => 0x800710F2 as u32,
            WIN32::ERROR_NO_SUPPORTING_DRIVES => 0x800710F3 as u32,
            WIN32::ERROR_CLEANER_CARTRIDGE_INSTALLED => 0x800710F4 as u32,
            WIN32::ERROR_IEPORT_FULL => 0x800710F5 as u32,
            WIN32::ERROR_FILE_OFFLINE => 0x800710FE as u32,
            WIN32::ERROR_REMOTE_STORAGE_NOT_ACTIVE => 0x800710FF as u32,
            WIN32::ERROR_REMOTE_STORAGE_MEDIA_ERROR => 0x80071100 as u32,
            WIN32::ERROR_NOT_A_REPARSE_POINT => 0x80071126 as u32,
            WIN32::ERROR_REPARSE_ATTRIBUTE_CONFLICT => 0x80071127 as u32,
            WIN32::ERROR_INVALID_REPARSE_DATA => 0x80071128 as u32,
            WIN32::ERROR_REPARSE_TAG_INVALID => 0x80071129 as u32,
            WIN32::ERROR_REPARSE_TAG_MISMATCH => 0x8007112A as u32,
            WIN32::ERROR_REPARSE_POINT_ENCOUNTERED => 0x8007112B as u32,
            WIN32::ERROR_APP_DATA_NOT_FOUND => 0x80071130 as u32,
            WIN32::ERROR_APP_DATA_EXPIRED => 0x80071131 as u32,
            WIN32::ERROR_APP_DATA_CORRUPT => 0x80071132 as u32,
            WIN32::ERROR_APP_DATA_LIMIT_EXCEEDED => 0x80071133 as u32,
            WIN32::ERROR_APP_DATA_REBOOT_REQUIRED => 0x80071134 as u32,
            WIN32::ERROR_SECUREBOOT_ROLLBACK_DETECTED => 0x80071144 as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_VIOLATION => 0x80071145 as u32,
            WIN32::ERROR_SECUREBOOT_INVALID_POLICY => 0x80071146 as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND => 0x80071147 as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_NOT_SIGNED => 0x80071148 as u32,
            WIN32::ERROR_SECUREBOOT_NOT_ENABLED => 0x80071149 as u32,
            WIN32::ERROR_SECUREBOOT_FILE_REPLACED => 0x8007114A as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED => 0x8007114B as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_UNKNOWN => 0x8007114C as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION => 0x8007114D as u32,
            WIN32::ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH => 0x8007114E as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED => 0x8007114F as u32,
            WIN32::ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH => 0x80071150 as u32,
            WIN32::ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING => 0x80071151 as u32,
            WIN32::ERROR_SECUREBOOT_NOT_BASE_POLICY => 0x80071152 as u32,
            WIN32::ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY => 0x80071153 as u32,
            WIN32::ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED => 0x80071158 as u32,
            WIN32::ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED => 0x80071159 as u32,
            WIN32::ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED => 0x8007115A as u32,
            WIN32::ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED => 0x8007115B as u32,
            WIN32::ERROR_ALREADY_HAS_STREAM_ID => 0x8007115C as u32,
            WIN32::ERROR_SMR_GARBAGE_COLLECTION_REQUIRED => 0x8007115D as u32,
            WIN32::ERROR_WOF_WIM_HEADER_CORRUPT => 0x8007115E as u32,
            WIN32::ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT => 0x8007115F as u32,
            WIN32::ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT => 0x80071160 as u32,
            WIN32::ERROR_OBJECT_IS_IMMUTABLE => 0x80071161 as u32,
            WIN32::ERROR_VOLUME_NOT_SIS_ENABLED => 0x80071194 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED => 0x800711C6 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION => 0x800711C7 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_INVALID_POLICY => 0x800711C8 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED => 0x800711C9 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES => 0x800711CA as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED => 0x800711CB as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS => 0x800711CC as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA => 0x800711CD as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT => 0x800711CE as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE => 0x800711CF as u32,
            WIN32::ERROR_VSM_NOT_INITIALIZED => 0x800711D0 as u32,
            WIN32::ERROR_VSM_DMA_PROTECTION_NOT_IN_USE => 0x800711D1 as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED => 0x800711DA as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_INVALID => 0x800711DB as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED => 0x800711DC as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED => 0x800711DD as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND => 0x800711DE as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_ACTIVE => 0x800711DF as u32,
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_SIGNED => 0x800711E0 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE => 0x800711E4 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE => 0x800711E5 as u32,
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE => 0x800711E6 as u32,
            WIN32::ERROR_DEPENDENT_RESOURCE_EXISTS => 0x80071389 as u32,
            WIN32::ERROR_DEPENDENCY_NOT_FOUND => 0x8007138A as u32,
            WIN32::ERROR_DEPENDENCY_ALREADY_EXISTS => 0x8007138B as u32,
            WIN32::ERROR_RESOURCE_NOT_ONLINE => 0x8007138C as u32,
            WIN32::ERROR_HOST_NODE_NOT_AVAILABLE => 0x8007138D as u32,
            WIN32::ERROR_RESOURCE_NOT_AVAILABLE => 0x8007138E as u32,
            WIN32::ERROR_RESOURCE_NOT_FOUND => 0x8007138F as u32,
            WIN32::ERROR_SHUTDOWN_CLUSTER => 0x80071390 as u32,
            WIN32::ERROR_CANT_EVICT_ACTIVE_NODE => 0x80071391 as u32,
            WIN32::ERROR_OBJECT_ALREADY_EXISTS => 0x80071392 as u32,
            WIN32::ERROR_OBJECT_IN_LIST => 0x80071393 as u32,
            WIN32::ERROR_GROUP_NOT_AVAILABLE => 0x80071394 as u32,
            WIN32::ERROR_GROUP_NOT_FOUND => 0x80071395 as u32,
            WIN32::ERROR_GROUP_NOT_ONLINE => 0x80071396 as u32,
            WIN32::ERROR_HOST_NODE_NOT_RESOURCE_OWNER => 0x80071397 as u32,
            WIN32::ERROR_HOST_NODE_NOT_GROUP_OWNER => 0x80071398 as u32,
            WIN32::ERROR_RESMON_CREATE_FAILED => 0x80071399 as u32,
            WIN32::ERROR_RESMON_ONLINE_FAILED => 0x8007139A as u32,
            WIN32::ERROR_RESOURCE_ONLINE => 0x8007139B as u32,
            WIN32::ERROR_QUORUM_RESOURCE => 0x8007139C as u32,
            WIN32::ERROR_NOT_QUORUM_CAPABLE => 0x8007139D as u32,
            WIN32::ERROR_CLUSTER_SHUTTING_DOWN => 0x8007139E as u32,
            WIN32::ERROR_INVALID_STATE => 0x8007139F as u32,
            WIN32::ERROR_RESOURCE_PROPERTIES_STORED => 0x800713A0 as u32,
            WIN32::ERROR_NOT_QUORUM_CLASS => 0x800713A1 as u32,
            WIN32::ERROR_CORE_RESOURCE => 0x800713A2 as u32,
            WIN32::ERROR_QUORUM_RESOURCE_ONLINE_FAILED => 0x800713A3 as u32,
            WIN32::ERROR_QUORUMLOG_OPEN_FAILED => 0x800713A4 as u32,
            WIN32::ERROR_CLUSTERLOG_CORRUPT => 0x800713A5 as u32,
            WIN32::ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE => 0x800713A6 as u32,
            WIN32::ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE => 0x800713A7 as u32,
            WIN32::ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND => 0x800713A8 as u32,
            WIN32::ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE => 0x800713A9 as u32,
            WIN32::ERROR_QUORUM_OWNER_ALIVE => 0x800713AA as u32,
            WIN32::ERROR_NETWORK_NOT_AVAILABLE => 0x800713AB as u32,
            WIN32::ERROR_NODE_NOT_AVAILABLE => 0x800713AC as u32,
            WIN32::ERROR_ALL_NODES_NOT_AVAILABLE => 0x800713AD as u32,
            WIN32::ERROR_RESOURCE_FAILED => 0x800713AE as u32,
            WIN32::ERROR_CLUSTER_INVALID_NODE => 0x800713AF as u32,
            WIN32::ERROR_CLUSTER_NODE_EXISTS => 0x800713B0 as u32,
            WIN32::ERROR_CLUSTER_JOIN_IN_PROGRESS => 0x800713B1 as u32,
            WIN32::ERROR_CLUSTER_NODE_NOT_FOUND => 0x800713B2 as u32,
            WIN32::ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND => 0x800713B3 as u32,
            WIN32::ERROR_CLUSTER_NETWORK_EXISTS => 0x800713B4 as u32,
            WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND => 0x800713B5 as u32,
            WIN32::ERROR_CLUSTER_NETINTERFACE_EXISTS => 0x800713B6 as u32,
            WIN32::ERROR_CLUSTER_NETINTERFACE_NOT_FOUND => 0x800713B7 as u32,
            WIN32::ERROR_CLUSTER_INVALID_REQUEST => 0x800713B8 as u32,
            WIN32::ERROR_CLUSTER_INVALID_NETWORK_PROVIDER => 0x800713B9 as u32,
            WIN32::ERROR_CLUSTER_NODE_DOWN => 0x800713BA as u32,
            WIN32::ERROR_CLUSTER_NODE_UNREACHABLE => 0x800713BB as u32,
            WIN32::ERROR_CLUSTER_NODE_NOT_MEMBER => 0x800713BC as u32,
            WIN32::ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS => 0x800713BD as u32,
            WIN32::ERROR_CLUSTER_INVALID_NETWORK => 0x800713BE as u32,
            WIN32::ERROR_CLUSTER_NODE_UP => 0x800713C0 as u32,
            WIN32::ERROR_CLUSTER_IPADDR_IN_USE => 0x800713C1 as u32,
            WIN32::ERROR_CLUSTER_NODE_NOT_PAUSED => 0x800713C2 as u32,
            WIN32::ERROR_CLUSTER_NO_SECURITY_CONTEXT => 0x800713C3 as u32,
            WIN32::ERROR_CLUSTER_NETWORK_NOT_INTERNAL => 0x800713C4 as u32,
            WIN32::ERROR_CLUSTER_NODE_ALREADY_UP => 0x800713C5 as u32,
            WIN32::ERROR_CLUSTER_NODE_ALREADY_DOWN => 0x800713C6 as u32,
            WIN32::ERROR_CLUSTER_NETWORK_ALREADY_ONLINE => 0x800713C7 as u32,
            WIN32::ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE => 0x800713C8 as u32,
            WIN32::ERROR_CLUSTER_NODE_ALREADY_MEMBER => 0x800713C9 as u32,
            WIN32::ERROR_CLUSTER_LAST_INTERNAL_NETWORK => 0x800713CA as u32,
            WIN32::ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS => 0x800713CB as u32,
            WIN32::ERROR_INVALID_OPERATION_ON_QUORUM => 0x800713CC as u32,
            WIN32::ERROR_DEPENDENCY_NOT_ALLOWED => 0x800713CD as u32,
            WIN32::ERROR_CLUSTER_NODE_PAUSED => 0x800713CE as u32,
            WIN32::ERROR_NODE_CANT_HOST_RESOURCE => 0x800713CF as u32,
            WIN32::ERROR_CLUSTER_NODE_NOT_READY => 0x800713D0 as u32,
            WIN32::ERROR_CLUSTER_NODE_SHUTTING_DOWN => 0x800713D1 as u32,
            WIN32::ERROR_CLUSTER_JOIN_ABORTED => 0x800713D2 as u32,
            WIN32::ERROR_CLUSTER_INCOMPATIBLE_VERSIONS => 0x800713D3 as u32,
            WIN32::ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED => 0x800713D4 as u32,
            WIN32::ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED => 0x800713D5 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND => 0x800713D6 as u32,
            WIN32::ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED => 0x800713D7 as u32,
            WIN32::ERROR_CLUSTER_RESNAME_NOT_FOUND => 0x800713D8 as u32,
            WIN32::ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED => 0x800713D9 as u32,
            WIN32::ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST => 0x800713DA as u32,
            WIN32::ERROR_CLUSTER_DATABASE_SEQMISMATCH => 0x800713DB as u32,
            WIN32::ERROR_RESMON_INVALID_STATE => 0x800713DC as u32,
            WIN32::ERROR_CLUSTER_GUM_NOT_LOCKER => 0x800713DD as u32,
            WIN32::ERROR_QUORUM_DISK_NOT_FOUND => 0x800713DE as u32,
            WIN32::ERROR_DATABASE_BACKUP_CORRUPT => 0x800713DF as u32,
            WIN32::ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT => 0x800713E0 as u32,
            WIN32::ERROR_RESOURCE_PROPERTY_UNCHANGEABLE => 0x800713E1 as u32,
            WIN32::ERROR_NO_ADMIN_ACCESS_POINT => 0x800713E2 as u32,
            WIN32::ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE => 0x80071702 as u32,
            WIN32::ERROR_CLUSTER_QUORUMLOG_NOT_FOUND => 0x80071703 as u32,
            WIN32::ERROR_CLUSTER_MEMBERSHIP_HALT => 0x80071704 as u32,
            WIN32::ERROR_CLUSTER_INSTANCE_ID_MISMATCH => 0x80071705 as u32,
            WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP => 0x80071706 as u32,
            WIN32::ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH => 0x80071707 as u32,
            WIN32::ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP => 0x80071708 as u32,
            WIN32::ERROR_CLUSTER_PARAMETER_MISMATCH => 0x80071709 as u32,
            WIN32::ERROR_NODE_CANNOT_BE_CLUSTERED => 0x8007170A as u32,
            WIN32::ERROR_CLUSTER_WRONG_OS_VERSION => 0x8007170B as u32,
            WIN32::ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME => 0x8007170C as u32,
            WIN32::ERROR_CLUSCFG_ALREADY_COMMITTED => 0x8007170D as u32,
            WIN32::ERROR_CLUSCFG_ROLLBACK_FAILED => 0x8007170E as u32,
            WIN32::ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT => 0x8007170F as u32,
            WIN32::ERROR_CLUSTER_OLD_VERSION => 0x80071710 as u32,
            WIN32::ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME => 0x80071711 as u32,
            WIN32::ERROR_CLUSTER_NO_NET_ADAPTERS => 0x80071712 as u32,
            WIN32::ERROR_CLUSTER_POISONED => 0x80071713 as u32,
            WIN32::ERROR_CLUSTER_GROUP_MOVING => 0x80071714 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_TYPE_BUSY => 0x80071715 as u32,
            WIN32::ERROR_RESOURCE_CALL_TIMED_OUT => 0x80071716 as u32,
            WIN32::ERROR_INVALID_CLUSTER_IPV6_ADDRESS => 0x80071717 as u32,
            WIN32::ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION => 0x80071718 as u32,
            WIN32::ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS => 0x80071719 as u32,
            WIN32::ERROR_CLUSTER_PARTIAL_SEND => 0x8007171A as u32,
            WIN32::ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION => 0x8007171B as u32,
            WIN32::ERROR_CLUSTER_INVALID_STRING_TERMINATION => 0x8007171C as u32,
            WIN32::ERROR_CLUSTER_INVALID_STRING_FORMAT => 0x8007171D as u32,
            WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS => 0x8007171E as u32,
            WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS => 0x8007171F as u32,
            WIN32::ERROR_CLUSTER_NULL_DATA => 0x80071720 as u32,
            WIN32::ERROR_CLUSTER_PARTIAL_READ => 0x80071721 as u32,
            WIN32::ERROR_CLUSTER_PARTIAL_WRITE => 0x80071722 as u32,
            WIN32::ERROR_CLUSTER_CANT_DESERIALIZE_DATA => 0x80071723 as u32,
            WIN32::ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT => 0x80071724 as u32,
            WIN32::ERROR_CLUSTER_NO_QUORUM => 0x80071725 as u32,
            WIN32::ERROR_CLUSTER_INVALID_IPV6_NETWORK => 0x80071726 as u32,
            WIN32::ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK => 0x80071727 as u32,
            WIN32::ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP => 0x80071728 as u32,
            WIN32::ERROR_DEPENDENCY_TREE_TOO_COMPLEX => 0x80071729 as u32,
            WIN32::ERROR_EXCEPTION_IN_RESOURCE_CALL => 0x8007172A as u32,
            WIN32::ERROR_CLUSTER_RHS_FAILED_INITIALIZATION => 0x8007172B as u32,
            WIN32::ERROR_CLUSTER_NOT_INSTALLED => 0x8007172C as u32,
            WIN32::ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE => 0x8007172D as u32,
            WIN32::ERROR_CLUSTER_MAX_NODES_IN_CLUSTER => 0x8007172E as u32,
            WIN32::ERROR_CLUSTER_TOO_MANY_NODES => 0x8007172F as u32,
            WIN32::ERROR_CLUSTER_OBJECT_ALREADY_USED => 0x80071730 as u32,
            WIN32::ERROR_NONCORE_GROUPS_FOUND => 0x80071731 as u32,
            WIN32::ERROR_FILE_SHARE_RESOURCE_CONFLICT => 0x80071732 as u32,
            WIN32::ERROR_CLUSTER_EVICT_INVALID_REQUEST => 0x80071733 as u32,
            WIN32::ERROR_CLUSTER_SINGLETON_RESOURCE => 0x80071734 as u32,
            WIN32::ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE => 0x80071735 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED => 0x80071736 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR => 0x80071737 as u32,
            WIN32::ERROR_CLUSTER_GROUP_BUSY => 0x80071738 as u32,
            WIN32::ERROR_CLUSTER_NOT_SHARED_VOLUME => 0x80071739 as u32,
            WIN32::ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR => 0x8007173A as u32,
            WIN32::ERROR_CLUSTER_SHARED_VOLUMES_IN_USE => 0x8007173B as u32,
            WIN32::ERROR_CLUSTER_USE_SHARED_VOLUMES_API => 0x8007173C as u32,
            WIN32::ERROR_CLUSTER_BACKUP_IN_PROGRESS => 0x8007173D as u32,
            WIN32::ERROR_NON_CSV_PATH => 0x8007173E as u32,
            WIN32::ERROR_CSV_VOLUME_NOT_LOCAL => 0x8007173F as u32,
            WIN32::ERROR_CLUSTER_WATCHDOG_TERMINATING => 0x80071740 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES => 0x80071741 as u32,
            WIN32::ERROR_CLUSTER_INVALID_NODE_WEIGHT => 0x80071742 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_CALL => 0x80071743 as u32,
            WIN32::ERROR_RESMON_SYSTEM_RESOURCES_LACKING => 0x80071744 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION => 0x80071745 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE => 0x80071746 as u32,
            WIN32::ERROR_CLUSTER_GROUP_QUEUED => 0x80071747 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_LOCKED_STATUS => 0x80071748 as u32,
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED => 0x80071749 as u32,
            WIN32::ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS => 0x8007174A as u32,
            WIN32::ERROR_CLUSTER_DISK_NOT_CONNECTED => 0x8007174B as u32,
            WIN32::ERROR_DISK_NOT_CSV_CAPABLE => 0x8007174C as u32,
            WIN32::ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE => 0x8007174D as u32,
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED => 0x8007174E as u32,
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED => 0x8007174F as u32,
            WIN32::ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES => 0x80071750 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES => 0x80071751 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE => 0x80071752 as u32,
            WIN32::ERROR_CLUSTER_AFFINITY_CONFLICT => 0x80071753 as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE => 0x80071754 as u32,
            WIN32::ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS => 0x80071755 as u32,
            WIN32::ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED => 0x80071756 as u32,
            WIN32::ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED => 0x80071757 as u32,
            WIN32::ERROR_CLUSTER_UPGRADE_IN_PROGRESS => 0x80071758 as u32,
            WIN32::ERROR_CLUSTER_UPGRADE_INCOMPLETE => 0x80071759 as u32,
            WIN32::ERROR_CLUSTER_NODE_IN_GRACE_PERIOD => 0x8007175A as u32,
            WIN32::ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT => 0x8007175B as u32,
            WIN32::ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER => 0x8007175C as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_NOT_MONITORED => 0x8007175D as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED => 0x8007175E as u32,
            WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICATED => 0x8007175F as u32,
            WIN32::ERROR_CLUSTER_NODE_ISOLATED => 0x80071760 as u32,
            WIN32::ERROR_CLUSTER_NODE_QUARANTINED => 0x80071761 as u32,
            WIN32::ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED => 0x80071762 as u32,
            WIN32::ERROR_CLUSTER_SPACE_DEGRADED => 0x80071763 as u32,
            WIN32::ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED => 0x80071764 as u32,
            WIN32::ERROR_CLUSTER_CSV_INVALID_HANDLE => 0x80071765 as u32,
            WIN32::ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR => 0x80071766 as u32,
            WIN32::ERROR_GROUPSET_NOT_AVAILABLE => 0x80071767 as u32,
            WIN32::ERROR_GROUPSET_NOT_FOUND => 0x80071768 as u32,
            WIN32::ERROR_GROUPSET_CANT_PROVIDE => 0x80071769 as u32,
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND => 0x8007176A as u32,
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY => 0x8007176B as u32,
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION => 0x8007176C as u32,
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS => 0x8007176D as u32,
            WIN32::ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME => 0x8007176E as u32,
            WIN32::ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE => 0x8007176F as u32,
            WIN32::ERROR_ENCRYPTION_FAILED => 0x80071770 as u32,
            WIN32::ERROR_DECRYPTION_FAILED => 0x80071771 as u32,
            WIN32::ERROR_FILE_ENCRYPTED => 0x80071772 as u32,
            WIN32::ERROR_NO_RECOVERY_POLICY => 0x80071773 as u32,
            WIN32::ERROR_NO_EFS => 0x80071774 as u32,
            WIN32::ERROR_WRONG_EFS => 0x80071775 as u32,
            WIN32::ERROR_NO_USER_KEYS => 0x80071776 as u32,
            WIN32::ERROR_FILE_NOT_ENCRYPTED => 0x80071777 as u32,
            WIN32::ERROR_NOT_EXPORT_FORMAT => 0x80071778 as u32,
            WIN32::ERROR_FILE_READ_ONLY => 0x80071779 as u32,
            WIN32::ERROR_DIR_EFS_DISALLOWED => 0x8007177A as u32,
            WIN32::ERROR_EFS_SERVER_NOT_TRUSTED => 0x8007177B as u32,
            WIN32::ERROR_BAD_RECOVERY_POLICY => 0x8007177C as u32,
            WIN32::ERROR_EFS_ALG_BLOB_TOO_BIG => 0x8007177D as u32,
            WIN32::ERROR_VOLUME_NOT_SUPPORT_EFS => 0x8007177E as u32,
            WIN32::ERROR_EFS_DISABLED => 0x8007177F as u32,
            WIN32::ERROR_EFS_VERSION_NOT_SUPPORT => 0x80071780 as u32,
            WIN32::ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE => 0x80071781 as u32,
            WIN32::ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER => 0x80071782 as u32,
            WIN32::ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE => 0x80071783 as u32,
            WIN32::ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE => 0x80071784 as u32,
            WIN32::ERROR_CS_ENCRYPTION_FILE_NOT_CSE => 0x80071785 as u32,
            WIN32::ERROR_ENCRYPTION_POLICY_DENIES_OPERATION => 0x80071786 as u32,
            WIN32::ERROR_WIP_ENCRYPTION_FAILED => 0x80071787 as u32,
            WIN32::ERROR_NO_BROWSER_SERVERS_FOUND => 0x800717E6 as u32,
            WIN32::SCHED_E_SERVICE_NOT_LOCALSYSTEM => 0x80071838 as u32,
            WIN32::ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM => 0x8007186A as u32,
            WIN32::ERROR_LOG_SECTOR_INVALID => 0x800719C8 as u32,
            WIN32::ERROR_LOG_SECTOR_PARITY_INVALID => 0x800719C9 as u32,
            WIN32::ERROR_LOG_SECTOR_REMAPPED => 0x800719CA as u32,
            WIN32::ERROR_LOG_BLOCK_INCOMPLETE => 0x800719CB as u32,
            WIN32::ERROR_LOG_INVALID_RANGE => 0x800719CC as u32,
            WIN32::ERROR_LOG_BLOCKS_EXHAUSTED => 0x800719CD as u32,
            WIN32::ERROR_LOG_READ_CONTEXT_INVALID => 0x800719CE as u32,
            WIN32::ERROR_LOG_RESTART_INVALID => 0x800719CF as u32,
            WIN32::ERROR_LOG_BLOCK_VERSION => 0x800719D0 as u32,
            WIN32::ERROR_LOG_BLOCK_INVALID => 0x800719D1 as u32,
            WIN32::ERROR_LOG_READ_MODE_INVALID => 0x800719D2 as u32,
            WIN32::ERROR_LOG_NO_RESTART => 0x800719D3 as u32,
            WIN32::ERROR_LOG_METADATA_CORRUPT => 0x800719D4 as u32,
            WIN32::ERROR_LOG_METADATA_INVALID => 0x800719D5 as u32,
            WIN32::ERROR_LOG_METADATA_INCONSISTENT => 0x800719D6 as u32,
            WIN32::ERROR_LOG_RESERVATION_INVALID => 0x800719D7 as u32,
            WIN32::ERROR_LOG_CANT_DELETE => 0x800719D8 as u32,
            WIN32::ERROR_LOG_CONTAINER_LIMIT_EXCEEDED => 0x800719D9 as u32,
            WIN32::ERROR_LOG_START_OF_LOG => 0x800719DA as u32,
            WIN32::ERROR_LOG_POLICY_ALREADY_INSTALLED => 0x800719DB as u32,
            WIN32::ERROR_LOG_POLICY_NOT_INSTALLED => 0x800719DC as u32,
            WIN32::ERROR_LOG_POLICY_INVALID => 0x800719DD as u32,
            WIN32::ERROR_LOG_POLICY_CONFLICT => 0x800719DE as u32,
            WIN32::ERROR_LOG_PINNED_ARCHIVE_TAIL => 0x800719DF as u32,
            WIN32::ERROR_LOG_RECORD_NONEXISTENT => 0x800719E0 as u32,
            WIN32::ERROR_LOG_RECORDS_RESERVED_INVALID => 0x800719E1 as u32,
            WIN32::ERROR_LOG_SPACE_RESERVED_INVALID => 0x800719E2 as u32,
            WIN32::ERROR_LOG_TAIL_INVALID => 0x800719E3 as u32,
            WIN32::ERROR_LOG_FULL => 0x800719E4 as u32,
            WIN32::ERROR_COULD_NOT_RESIZE_LOG => 0x800719E5 as u32,
            WIN32::ERROR_LOG_MULTIPLEXED => 0x800719E6 as u32,
            WIN32::ERROR_LOG_DEDICATED => 0x800719E7 as u32,
            WIN32::ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS => 0x800719E8 as u32,
            WIN32::ERROR_LOG_ARCHIVE_IN_PROGRESS => 0x800719E9 as u32,
            WIN32::ERROR_LOG_EPHEMERAL => 0x800719EA as u32,
            WIN32::ERROR_LOG_NOT_ENOUGH_CONTAINERS => 0x800719EB as u32,
            WIN32::ERROR_LOG_CLIENT_ALREADY_REGISTERED => 0x800719EC as u32,
            WIN32::ERROR_LOG_CLIENT_NOT_REGISTERED => 0x800719ED as u32,
            WIN32::ERROR_LOG_FULL_HANDLER_IN_PROGRESS => 0x800719EE as u32,
            WIN32::ERROR_LOG_CONTAINER_READ_FAILED => 0x800719EF as u32,
            WIN32::ERROR_LOG_CONTAINER_WRITE_FAILED => 0x800719F0 as u32,
            WIN32::ERROR_LOG_CONTAINER_OPEN_FAILED => 0x800719F1 as u32,
            WIN32::ERROR_LOG_CONTAINER_STATE_INVALID => 0x800719F2 as u32,
            WIN32::ERROR_LOG_STATE_INVALID => 0x800719F3 as u32,
            WIN32::ERROR_LOG_PINNED => 0x800719F4 as u32,
            WIN32::ERROR_LOG_METADATA_FLUSH_FAILED => 0x800719F5 as u32,
            WIN32::ERROR_LOG_INCONSISTENT_SECURITY => 0x800719F6 as u32,
            WIN32::ERROR_LOG_APPENDED_FLUSH_FAILED => 0x800719F7 as u32,
            WIN32::ERROR_LOG_PINNED_RESERVATION => 0x800719F8 as u32,
            WIN32::ERROR_INVALID_TRANSACTION => 0x80071A2C as u32,
            WIN32::ERROR_TRANSACTION_NOT_ACTIVE => 0x80071A2D as u32,
            WIN32::ERROR_TRANSACTION_REQUEST_NOT_VALID => 0x80071A2E as u32,
            WIN32::ERROR_TRANSACTION_NOT_REQUESTED => 0x80071A2F as u32,
            WIN32::ERROR_TRANSACTION_ALREADY_ABORTED => 0x80071A30 as u32,
            WIN32::ERROR_TRANSACTION_ALREADY_COMMITTED => 0x80071A31 as u32,
            WIN32::ERROR_TM_INITIALIZATION_FAILED => 0x80071A32 as u32,
            WIN32::ERROR_RESOURCEMANAGER_READ_ONLY => 0x80071A33 as u32,
            WIN32::ERROR_TRANSACTION_NOT_JOINED => 0x80071A34 as u32,
            WIN32::ERROR_TRANSACTION_SUPERIOR_EXISTS => 0x80071A35 as u32,
            WIN32::ERROR_CRM_PROTOCOL_ALREADY_EXISTS => 0x80071A36 as u32,
            WIN32::ERROR_TRANSACTION_PROPAGATION_FAILED => 0x80071A37 as u32,
            WIN32::ERROR_CRM_PROTOCOL_NOT_FOUND => 0x80071A38 as u32,
            WIN32::ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER => 0x80071A39 as u32,
            WIN32::ERROR_CURRENT_TRANSACTION_NOT_VALID => 0x80071A3A as u32,
            WIN32::ERROR_TRANSACTION_NOT_FOUND => 0x80071A3B as u32,
            WIN32::ERROR_RESOURCEMANAGER_NOT_FOUND => 0x80071A3C as u32,
            WIN32::ERROR_ENLISTMENT_NOT_FOUND => 0x80071A3D as u32,
            WIN32::ERROR_TRANSACTIONMANAGER_NOT_FOUND => 0x80071A3E as u32,
            WIN32::ERROR_TRANSACTIONMANAGER_NOT_ONLINE => 0x80071A3F as u32,
            WIN32::ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION => 0x80071A40 as u32,
            WIN32::ERROR_TRANSACTION_NOT_ROOT => 0x80071A41 as u32,
            WIN32::ERROR_TRANSACTION_OBJECT_EXPIRED => 0x80071A42 as u32,
            WIN32::ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED => 0x80071A43 as u32,
            WIN32::ERROR_TRANSACTION_RECORD_TOO_LONG => 0x80071A44 as u32,
            WIN32::ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED => 0x80071A45 as u32,
            WIN32::ERROR_TRANSACTION_INTEGRITY_VIOLATED => 0x80071A46 as u32,
            WIN32::ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH => 0x80071A47 as u32,
            WIN32::ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT => 0x80071A48 as u32,
            WIN32::ERROR_TRANSACTION_MUST_WRITETHROUGH => 0x80071A49 as u32,
            WIN32::ERROR_TRANSACTION_NO_SUPERIOR => 0x80071A4A as u32,
            WIN32::ERROR_HEURISTIC_DAMAGE_POSSIBLE => 0x80071A4B as u32,
            WIN32::ERROR_TRANSACTIONAL_CONFLICT => 0x80071A90 as u32,
            WIN32::ERROR_RM_NOT_ACTIVE => 0x80071A91 as u32,
            WIN32::ERROR_RM_METADATA_CORRUPT => 0x80071A92 as u32,
            WIN32::ERROR_DIRECTORY_NOT_RM => 0x80071A93 as u32,
            WIN32::ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE => 0x80071A95 as u32,
            WIN32::ERROR_LOG_RESIZE_INVALID_SIZE => 0x80071A96 as u32,
            WIN32::ERROR_OBJECT_NO_LONGER_EXISTS => 0x80071A97 as u32,
            WIN32::ERROR_STREAM_MINIVERSION_NOT_FOUND => 0x80071A98 as u32,
            WIN32::ERROR_STREAM_MINIVERSION_NOT_VALID => 0x80071A99 as u32,
            WIN32::ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION => 0x80071A9A as u32,
            WIN32::ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT => 0x80071A9B as u32,
            WIN32::ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS => 0x80071A9C as u32,
            WIN32::ERROR_REMOTE_FILE_VERSION_MISMATCH => 0x80071A9E as u32,
            WIN32::ERROR_HANDLE_NO_LONGER_VALID => 0x80071A9F as u32,
            WIN32::ERROR_NO_TXF_METADATA => 0x80071AA0 as u32,
            WIN32::ERROR_LOG_CORRUPTION_DETECTED => 0x80071AA1 as u32,
            WIN32::ERROR_CANT_RECOVER_WITH_HANDLE_OPEN => 0x80071AA2 as u32,
            WIN32::ERROR_RM_DISCONNECTED => 0x80071AA3 as u32,
            WIN32::ERROR_ENLISTMENT_NOT_SUPERIOR => 0x80071AA4 as u32,
            WIN32::ERROR_RECOVERY_NOT_NEEDED => 0x80071AA5 as u32,
            WIN32::ERROR_RM_ALREADY_STARTED => 0x80071AA6 as u32,
            WIN32::ERROR_FILE_IDENTITY_NOT_PERSISTENT => 0x80071AA7 as u32,
            WIN32::ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY => 0x80071AA8 as u32,
            WIN32::ERROR_CANT_CROSS_RM_BOUNDARY => 0x80071AA9 as u32,
            WIN32::ERROR_TXF_DIR_NOT_EMPTY => 0x80071AAA as u32,
            WIN32::ERROR_INDOUBT_TRANSACTIONS_EXIST => 0x80071AAB as u32,
            WIN32::ERROR_TM_VOLATILE => 0x80071AAC as u32,
            WIN32::ERROR_ROLLBACK_TIMER_EXPIRED => 0x80071AAD as u32,
            WIN32::ERROR_TXF_ATTRIBUTE_CORRUPT => 0x80071AAE as u32,
            WIN32::ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION => 0x80071AAF as u32,
            WIN32::ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED => 0x80071AB0 as u32,
            WIN32::ERROR_LOG_GROWTH_FAILED => 0x80071AB1 as u32,
            WIN32::ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE => 0x80071AB2 as u32,
            WIN32::ERROR_TXF_METADATA_ALREADY_PRESENT => 0x80071AB3 as u32,
            WIN32::ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET => 0x80071AB4 as u32,
            WIN32::ERROR_TRANSACTION_REQUIRED_PROMOTION => 0x80071AB5 as u32,
            WIN32::ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION => 0x80071AB6 as u32,
            WIN32::ERROR_TRANSACTIONS_NOT_FROZEN => 0x80071AB7 as u32,
            WIN32::ERROR_TRANSACTION_FREEZE_IN_PROGRESS => 0x80071AB8 as u32,
            WIN32::ERROR_NOT_SNAPSHOT_VOLUME => 0x80071AB9 as u32,
            WIN32::ERROR_NO_SAVEPOINT_WITH_OPEN_FILES => 0x80071ABA as u32,
            WIN32::ERROR_DATA_LOST_REPAIR => 0x80071ABB as u32,
            WIN32::ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION => 0x80071ABC as u32,
            WIN32::ERROR_TM_IDENTITY_MISMATCH => 0x80071ABD as u32,
            WIN32::ERROR_FLOATED_SECTION => 0x80071ABE as u32,
            WIN32::ERROR_CANNOT_ACCEPT_TRANSACTED_WORK => 0x80071ABF as u32,
            WIN32::ERROR_CANNOT_ABORT_TRANSACTIONS => 0x80071AC0 as u32,
            WIN32::ERROR_BAD_CLUSTERS => 0x80071AC1 as u32,
            WIN32::ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION => 0x80071AC2 as u32,
            WIN32::ERROR_VOLUME_DIRTY => 0x80071AC3 as u32,
            WIN32::ERROR_NO_LINK_TRACKING_IN_TRANSACTION => 0x80071AC4 as u32,
            WIN32::ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION => 0x80071AC5 as u32,
            WIN32::ERROR_EXPIRED_HANDLE => 0x80071AC6 as u32,
            WIN32::ERROR_TRANSACTION_NOT_ENLISTED => 0x80071AC7 as u32,
            WIN32::ERROR_CTX_WINSTATION_NAME_INVALID => 0x80071B59 as u32,
            WIN32::ERROR_CTX_INVALID_PD => 0x80071B5A as u32,
            WIN32::ERROR_CTX_PD_NOT_FOUND => 0x80071B5B as u32,
            WIN32::ERROR_CTX_WD_NOT_FOUND => 0x80071B5C as u32,
            WIN32::ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY => 0x80071B5D as u32,
            WIN32::ERROR_CTX_SERVICE_NAME_COLLISION => 0x80071B5E as u32,
            WIN32::ERROR_CTX_CLOSE_PENDING => 0x80071B5F as u32,
            WIN32::ERROR_CTX_NO_OUTBUF => 0x80071B60 as u32,
            WIN32::ERROR_CTX_MODEM_INF_NOT_FOUND => 0x80071B61 as u32,
            WIN32::ERROR_CTX_INVALID_MODEMNAME => 0x80071B62 as u32,
            WIN32::ERROR_CTX_MODEM_RESPONSE_ERROR => 0x80071B63 as u32,
            WIN32::ERROR_CTX_MODEM_RESPONSE_TIMEOUT => 0x80071B64 as u32,
            WIN32::ERROR_CTX_MODEM_RESPONSE_NO_CARRIER => 0x80071B65 as u32,
            WIN32::ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE => 0x80071B66 as u32,
            WIN32::ERROR_CTX_MODEM_RESPONSE_BUSY => 0x80071B67 as u32,
            WIN32::ERROR_CTX_MODEM_RESPONSE_VOICE => 0x80071B68 as u32,
            WIN32::ERROR_CTX_TD_ERROR => 0x80071B69 as u32,
            WIN32::ERROR_CTX_WINSTATION_NOT_FOUND => 0x80071B6E as u32,
            WIN32::ERROR_CTX_WINSTATION_ALREADY_EXISTS => 0x80071B6F as u32,
            WIN32::ERROR_CTX_WINSTATION_BUSY => 0x80071B70 as u32,
            WIN32::ERROR_CTX_BAD_VIDEO_MODE => 0x80071B71 as u32,
            WIN32::ERROR_CTX_GRAPHICS_INVALID => 0x80071B7B as u32,
            WIN32::ERROR_CTX_LOGON_DISABLED => 0x80071B7D as u32,
            WIN32::ERROR_CTX_NOT_CONSOLE => 0x80071B7E as u32,
            WIN32::ERROR_CTX_CLIENT_QUERY_TIMEOUT => 0x80071B80 as u32,
            WIN32::ERROR_CTX_CONSOLE_DISCONNECT => 0x80071B81 as u32,
            WIN32::ERROR_CTX_CONSOLE_CONNECT => 0x80071B82 as u32,
            WIN32::ERROR_CTX_SHADOW_DENIED => 0x80071B84 as u32,
            WIN32::ERROR_CTX_WINSTATION_ACCESS_DENIED => 0x80071B85 as u32,
            WIN32::ERROR_CTX_INVALID_WD => 0x80071B89 as u32,
            WIN32::ERROR_CTX_SHADOW_INVALID => 0x80071B8A as u32,
            WIN32::ERROR_CTX_SHADOW_DISABLED => 0x80071B8B as u32,
            WIN32::ERROR_CTX_CLIENT_LICENSE_IN_USE => 0x80071B8C as u32,
            WIN32::ERROR_CTX_CLIENT_LICENSE_NOT_SET => 0x80071B8D as u32,
            WIN32::ERROR_CTX_LICENSE_NOT_AVAILABLE => 0x80071B8E as u32,
            WIN32::ERROR_CTX_LICENSE_CLIENT_INVALID => 0x80071B8F as u32,
            WIN32::ERROR_CTX_LICENSE_EXPIRED => 0x80071B90 as u32,
            WIN32::ERROR_CTX_SHADOW_NOT_RUNNING => 0x80071B91 as u32,
            WIN32::ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE => 0x80071B92 as u32,
            WIN32::ERROR_ACTIVATION_COUNT_EXCEEDED => 0x80071B93 as u32,
            WIN32::ERROR_CTX_WINSTATIONS_DISABLED => 0x80071B94 as u32,
            WIN32::ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED => 0x80071B95 as u32,
            WIN32::ERROR_CTX_SESSION_IN_USE => 0x80071B96 as u32,
            WIN32::ERROR_CTX_NO_FORCE_LOGOFF => 0x80071B97 as u32,
            WIN32::ERROR_CTX_ACCOUNT_RESTRICTION => 0x80071B98 as u32,
            WIN32::ERROR_RDP_PROTOCOL_ERROR => 0x80071B99 as u32,
            WIN32::ERROR_CTX_CDM_CONNECT => 0x80071B9A as u32,
            WIN32::ERROR_CTX_CDM_DISCONNECT => 0x80071B9B as u32,
            WIN32::ERROR_CTX_SECURITY_LAYER_ERROR => 0x80071B9C as u32,
            WIN32::ERROR_TS_INCOMPATIBLE_SESSIONS => 0x80071B9D as u32,
            WIN32::ERROR_TS_VIDEO_SUBSYSTEM_ERROR => 0x80071B9E as u32,
            WIN32::FRS_ERR_INVALID_API_SEQUENCE => 0x80071F41 as u32,
            WIN32::FRS_ERR_STARTING_SERVICE => 0x80071F42 as u32,
            WIN32::FRS_ERR_STOPPING_SERVICE => 0x80071F43 as u32,
            WIN32::FRS_ERR_INTERNAL_API => 0x80071F44 as u32,
            WIN32::FRS_ERR_INTERNAL => 0x80071F45 as u32,
            WIN32::FRS_ERR_SERVICE_COMM => 0x80071F46 as u32,
            WIN32::FRS_ERR_INSUFFICIENT_PRIV => 0x80071F47 as u32,
            WIN32::FRS_ERR_AUTHENTICATION => 0x80071F48 as u32,
            WIN32::FRS_ERR_PARENT_INSUFFICIENT_PRIV => 0x80071F49 as u32,
            WIN32::FRS_ERR_PARENT_AUTHENTICATION => 0x80071F4A as u32,
            WIN32::FRS_ERR_CHILD_TO_PARENT_COMM => 0x80071F4B as u32,
            WIN32::FRS_ERR_PARENT_TO_CHILD_COMM => 0x80071F4C as u32,
            WIN32::FRS_ERR_SYSVOL_POPULATE => 0x80071F4D as u32,
            WIN32::FRS_ERR_SYSVOL_POPULATE_TIMEOUT => 0x80071F4E as u32,
            WIN32::FRS_ERR_SYSVOL_IS_BUSY => 0x80071F4F as u32,
            WIN32::FRS_ERR_SYSVOL_DEMOTE => 0x80071F50 as u32,
            WIN32::FRS_ERR_INVALID_SERVICE_PARAMETER => 0x80071F51 as u32,
            WIN32::ERROR_DS_NOT_INSTALLED => 0x80072008 as u32,
            WIN32::ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY => 0x80072009 as u32,
            WIN32::ERROR_DS_NO_ATTRIBUTE_OR_VALUE => 0x8007200A as u32,
            WIN32::ERROR_DS_INVALID_ATTRIBUTE_SYNTAX => 0x8007200B as u32,
            WIN32::ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED => 0x8007200C as u32,
            WIN32::ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS => 0x8007200D as u32,
            WIN32::ERROR_DS_BUSY => 0x8007200E as u32,
            WIN32::ERROR_DS_UNAVAILABLE => 0x8007200F as u32,
            WIN32::ERROR_DS_NO_RIDS_ALLOCATED => 0x80072010 as u32,
            WIN32::ERROR_DS_NO_MORE_RIDS => 0x80072011 as u32,
            WIN32::ERROR_DS_INCORRECT_ROLE_OWNER => 0x80072012 as u32,
            WIN32::ERROR_DS_RIDMGR_INIT_ERROR => 0x80072013 as u32,
            WIN32::ERROR_DS_OBJ_CLASS_VIOLATION => 0x80072014 as u32,
            WIN32::ERROR_DS_CANT_ON_NON_LEAF => 0x80072015 as u32,
            WIN32::ERROR_DS_CANT_ON_RDN => 0x80072016 as u32,
            WIN32::ERROR_DS_CANT_MOD_OBJ_CLASS => 0x80072017 as u32,
            WIN32::ERROR_DS_CROSS_DOM_MOVE_ERROR => 0x80072018 as u32,
            WIN32::ERROR_DS_GC_NOT_AVAILABLE => 0x80072019 as u32,
            WIN32::ERROR_SHARED_POLICY => 0x8007201A as u32,
            WIN32::ERROR_POLICY_OBJECT_NOT_FOUND => 0x8007201B as u32,
            WIN32::ERROR_POLICY_ONLY_IN_DS => 0x8007201C as u32,
            WIN32::ERROR_PROMOTION_ACTIVE => 0x8007201D as u32,
            WIN32::ERROR_NO_PROMOTION_ACTIVE => 0x8007201E as u32,
            WIN32::ERROR_DS_OPERATIONS_ERROR => 0x80072020 as u32,
            WIN32::ERROR_DS_PROTOCOL_ERROR => 0x80072021 as u32,
            WIN32::ERROR_DS_TIMELIMIT_EXCEEDED => 0x80072022 as u32,
            WIN32::ERROR_DS_SIZELIMIT_EXCEEDED => 0x80072023 as u32,
            WIN32::ERROR_DS_ADMIN_LIMIT_EXCEEDED => 0x80072024 as u32,
            WIN32::ERROR_DS_COMPARE_FALSE => 0x80072025 as u32,
            WIN32::ERROR_DS_COMPARE_TRUE => 0x80072026 as u32,
            WIN32::ERROR_DS_AUTH_METHOD_NOT_SUPPORTED => 0x80072027 as u32,
            WIN32::ERROR_DS_STRONG_AUTH_REQUIRED => 0x80072028 as u32,
            WIN32::ERROR_DS_INAPPROPRIATE_AUTH => 0x80072029 as u32,
            WIN32::ERROR_DS_AUTH_UNKNOWN => 0x8007202A as u32,
            WIN32::ERROR_DS_REFERRAL => 0x8007202B as u32,
            WIN32::ERROR_DS_UNAVAILABLE_CRIT_EXTENSION => 0x8007202C as u32,
            WIN32::ERROR_DS_CONFIDENTIALITY_REQUIRED => 0x8007202D as u32,
            WIN32::ERROR_DS_INAPPROPRIATE_MATCHING => 0x8007202E as u32,
            WIN32::ERROR_DS_CONSTRAINT_VIOLATION => 0x8007202F as u32,
            WIN32::ERROR_DS_NO_SUCH_OBJECT => 0x80072030 as u32,
            WIN32::ERROR_DS_ALIAS_PROBLEM => 0x80072031 as u32,
            WIN32::ERROR_DS_INVALID_DN_SYNTAX => 0x80072032 as u32,
            WIN32::ERROR_DS_IS_LEAF => 0x80072033 as u32,
            WIN32::ERROR_DS_ALIAS_DEREF_PROBLEM => 0x80072034 as u32,
            WIN32::ERROR_DS_UNWILLING_TO_PERFORM => 0x80072035 as u32,
            WIN32::ERROR_DS_LOOP_DETECT => 0x80072036 as u32,
            WIN32::ERROR_DS_NAMING_VIOLATION => 0x80072037 as u32,
            WIN32::ERROR_DS_OBJECT_RESULTS_TOO_LARGE => 0x80072038 as u32,
            WIN32::ERROR_DS_AFFECTS_MULTIPLE_DSAS => 0x80072039 as u32,
            WIN32::ERROR_DS_SERVER_DOWN => 0x8007203A as u32,
            WIN32::ERROR_DS_LOCAL_ERROR => 0x8007203B as u32,
            WIN32::ERROR_DS_ENCODING_ERROR => 0x8007203C as u32,
            WIN32::ERROR_DS_DECODING_ERROR => 0x8007203D as u32,
            WIN32::ERROR_DS_FILTER_UNKNOWN => 0x8007203E as u32,
            WIN32::ERROR_DS_PARAM_ERROR => 0x8007203F as u32,
            WIN32::ERROR_DS_NOT_SUPPORTED => 0x80072040 as u32,
            WIN32::ERROR_DS_NO_RESULTS_RETURNED => 0x80072041 as u32,
            WIN32::ERROR_DS_CONTROL_NOT_FOUND => 0x80072042 as u32,
            WIN32::ERROR_DS_CLIENT_LOOP => 0x80072043 as u32,
            WIN32::ERROR_DS_REFERRAL_LIMIT_EXCEEDED => 0x80072044 as u32,
            WIN32::ERROR_DS_SORT_CONTROL_MISSING => 0x80072045 as u32,
            WIN32::ERROR_DS_OFFSET_RANGE_ERROR => 0x80072046 as u32,
            WIN32::ERROR_DS_RIDMGR_DISABLED => 0x80072047 as u32,
            WIN32::ERROR_DS_ROOT_MUST_BE_NC => 0x8007206D as u32,
            WIN32::ERROR_DS_ADD_REPLICA_INHIBITED => 0x8007206E as u32,
            WIN32::ERROR_DS_ATT_NOT_DEF_IN_SCHEMA => 0x8007206F as u32,
            WIN32::ERROR_DS_MAX_OBJ_SIZE_EXCEEDED => 0x80072070 as u32,
            WIN32::ERROR_DS_OBJ_STRING_NAME_EXISTS => 0x80072071 as u32,
            WIN32::ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA => 0x80072072 as u32,
            WIN32::ERROR_DS_RDN_DOESNT_MATCH_SCHEMA => 0x80072073 as u32,
            WIN32::ERROR_DS_NO_REQUESTED_ATTS_FOUND => 0x80072074 as u32,
            WIN32::ERROR_DS_USER_BUFFER_TO_SMALL => 0x80072075 as u32,
            WIN32::ERROR_DS_ATT_IS_NOT_ON_OBJ => 0x80072076 as u32,
            WIN32::ERROR_DS_ILLEGAL_MOD_OPERATION => 0x80072077 as u32,
            WIN32::ERROR_DS_OBJ_TOO_LARGE => 0x80072078 as u32,
            WIN32::ERROR_DS_BAD_INSTANCE_TYPE => 0x80072079 as u32,
            WIN32::ERROR_DS_MASTERDSA_REQUIRED => 0x8007207A as u32,
            WIN32::ERROR_DS_OBJECT_CLASS_REQUIRED => 0x8007207B as u32,
            WIN32::ERROR_DS_MISSING_REQUIRED_ATT => 0x8007207C as u32,
            WIN32::ERROR_DS_ATT_NOT_DEF_FOR_CLASS => 0x8007207D as u32,
            WIN32::ERROR_DS_ATT_ALREADY_EXISTS => 0x8007207E as u32,
            WIN32::ERROR_DS_CANT_ADD_ATT_VALUES => 0x80072080 as u32,
            WIN32::ERROR_DS_SINGLE_VALUE_CONSTRAINT => 0x80072081 as u32,
            WIN32::ERROR_DS_RANGE_CONSTRAINT => 0x80072082 as u32,
            WIN32::ERROR_DS_ATT_VAL_ALREADY_EXISTS => 0x80072083 as u32,
            WIN32::ERROR_DS_CANT_REM_MISSING_ATT => 0x80072084 as u32,
            WIN32::ERROR_DS_CANT_REM_MISSING_ATT_VAL => 0x80072085 as u32,
            WIN32::ERROR_DS_ROOT_CANT_BE_SUBREF => 0x80072086 as u32,
            WIN32::ERROR_DS_NO_CHAINING => 0x80072087 as u32,
            WIN32::ERROR_DS_NO_CHAINED_EVAL => 0x80072088 as u32,
            WIN32::ERROR_DS_NO_PARENT_OBJECT => 0x80072089 as u32,
            WIN32::ERROR_DS_PARENT_IS_AN_ALIAS => 0x8007208A as u32,
            WIN32::ERROR_DS_CANT_MIX_MASTER_AND_REPS => 0x8007208B as u32,
            WIN32::ERROR_DS_CHILDREN_EXIST => 0x8007208C as u32,
            WIN32::ERROR_DS_OBJ_NOT_FOUND => 0x8007208D as u32,
            WIN32::ERROR_DS_ALIASED_OBJ_MISSING => 0x8007208E as u32,
            WIN32::ERROR_DS_BAD_NAME_SYNTAX => 0x8007208F as u32,
            WIN32::ERROR_DS_ALIAS_POINTS_TO_ALIAS => 0x80072090 as u32,
            WIN32::ERROR_DS_CANT_DEREF_ALIAS => 0x80072091 as u32,
            WIN32::ERROR_DS_OUT_OF_SCOPE => 0x80072092 as u32,
            WIN32::ERROR_DS_OBJECT_BEING_REMOVED => 0x80072093 as u32,
            WIN32::ERROR_DS_CANT_DELETE_DSA_OBJ => 0x80072094 as u32,
            WIN32::ERROR_DS_GENERIC_ERROR => 0x80072095 as u32,
            WIN32::ERROR_DS_DSA_MUST_BE_INT_MASTER => 0x80072096 as u32,
            WIN32::ERROR_DS_CLASS_NOT_DSA => 0x80072097 as u32,
            WIN32::ERROR_DS_INSUFF_ACCESS_RIGHTS => 0x80072098 as u32,
            WIN32::ERROR_DS_ILLEGAL_SUPERIOR => 0x80072099 as u32,
            WIN32::ERROR_DS_ATTRIBUTE_OWNED_BY_SAM => 0x8007209A as u32,
            WIN32::ERROR_DS_NAME_TOO_MANY_PARTS => 0x8007209B as u32,
            WIN32::ERROR_DS_NAME_TOO_LONG => 0x8007209C as u32,
            WIN32::ERROR_DS_NAME_VALUE_TOO_LONG => 0x8007209D as u32,
            WIN32::ERROR_DS_NAME_UNPARSEABLE => 0x8007209E as u32,
            WIN32::ERROR_DS_NAME_TYPE_UNKNOWN => 0x8007209F as u32,
            WIN32::ERROR_DS_NOT_AN_OBJECT => 0x800720A0 as u32,
            WIN32::ERROR_DS_SEC_DESC_TOO_SHORT => 0x800720A1 as u32,
            WIN32::ERROR_DS_SEC_DESC_INVALID => 0x800720A2 as u32,
            WIN32::ERROR_DS_NO_DELETED_NAME => 0x800720A3 as u32,
            WIN32::ERROR_DS_SUBREF_MUST_HAVE_PARENT => 0x800720A4 as u32,
            WIN32::ERROR_DS_NCNAME_MUST_BE_NC => 0x800720A5 as u32,
            WIN32::ERROR_DS_CANT_ADD_SYSTEM_ONLY => 0x800720A6 as u32,
            WIN32::ERROR_DS_CLASS_MUST_BE_CONCRETE => 0x800720A7 as u32,
            WIN32::ERROR_DS_INVALID_DMD => 0x800720A8 as u32,
            WIN32::ERROR_DS_OBJ_GUID_EXISTS => 0x800720A9 as u32,
            WIN32::ERROR_DS_NOT_ON_BACKLINK => 0x800720AA as u32,
            WIN32::ERROR_DS_NO_CROSSREF_FOR_NC => 0x800720AB as u32,
            WIN32::ERROR_DS_SHUTTING_DOWN => 0x800720AC as u32,
            WIN32::ERROR_DS_UNKNOWN_OPERATION => 0x800720AD as u32,
            WIN32::ERROR_DS_INVALID_ROLE_OWNER => 0x800720AE as u32,
            WIN32::ERROR_DS_COULDNT_CONTACT_FSMO => 0x800720AF as u32,
            WIN32::ERROR_DS_CROSS_NC_DN_RENAME => 0x800720B0 as u32,
            WIN32::ERROR_DS_CANT_MOD_SYSTEM_ONLY => 0x800720B1 as u32,
            WIN32::ERROR_DS_REPLICATOR_ONLY => 0x800720B2 as u32,
            WIN32::ERROR_DS_OBJ_CLASS_NOT_DEFINED => 0x800720B3 as u32,
            WIN32::ERROR_DS_OBJ_CLASS_NOT_SUBCLASS => 0x800720B4 as u32,
            WIN32::ERROR_DS_NAME_REFERENCE_INVALID => 0x800720B5 as u32,
            WIN32::ERROR_DS_CROSS_REF_EXISTS => 0x800720B6 as u32,
            WIN32::ERROR_DS_CANT_DEL_MASTER_CROSSREF => 0x800720B7 as u32,
            WIN32::ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD => 0x800720B8 as u32,
            WIN32::ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX => 0x800720B9 as u32,
            WIN32::ERROR_DS_DUP_RDN => 0x800720BA as u32,
            WIN32::ERROR_DS_DUP_OID => 0x800720BB as u32,
            WIN32::ERROR_DS_DUP_MAPI_ID => 0x800720BC as u32,
            WIN32::ERROR_DS_DUP_SCHEMA_ID_GUID => 0x800720BD as u32,
            WIN32::ERROR_DS_DUP_LDAP_DISPLAY_NAME => 0x800720BE as u32,
            WIN32::ERROR_DS_SEMANTIC_ATT_TEST => 0x800720BF as u32,
            WIN32::ERROR_DS_SYNTAX_MISMATCH => 0x800720C0 as u32,
            WIN32::ERROR_DS_EXISTS_IN_MUST_HAVE => 0x800720C1 as u32,
            WIN32::ERROR_DS_EXISTS_IN_MAY_HAVE => 0x800720C2 as u32,
            WIN32::ERROR_DS_NONEXISTENT_MAY_HAVE => 0x800720C3 as u32,
            WIN32::ERROR_DS_NONEXISTENT_MUST_HAVE => 0x800720C4 as u32,
            WIN32::ERROR_DS_AUX_CLS_TEST_FAIL => 0x800720C5 as u32,
            WIN32::ERROR_DS_NONEXISTENT_POSS_SUP => 0x800720C6 as u32,
            WIN32::ERROR_DS_SUB_CLS_TEST_FAIL => 0x800720C7 as u32,
            WIN32::ERROR_DS_BAD_RDN_ATT_ID_SYNTAX => 0x800720C8 as u32,
            WIN32::ERROR_DS_EXISTS_IN_AUX_CLS => 0x800720C9 as u32,
            WIN32::ERROR_DS_EXISTS_IN_SUB_CLS => 0x800720CA as u32,
            WIN32::ERROR_DS_EXISTS_IN_POSS_SUP => 0x800720CB as u32,
            WIN32::ERROR_DS_RECALCSCHEMA_FAILED => 0x800720CC as u32,
            WIN32::ERROR_DS_TREE_DELETE_NOT_FINISHED => 0x800720CD as u32,
            WIN32::ERROR_DS_CANT_DELETE => 0x800720CE as u32,
            WIN32::ERROR_DS_ATT_SCHEMA_REQ_ID => 0x800720CF as u32,
            WIN32::ERROR_DS_BAD_ATT_SCHEMA_SYNTAX => 0x800720D0 as u32,
            WIN32::ERROR_DS_CANT_CACHE_ATT => 0x800720D1 as u32,
            WIN32::ERROR_DS_CANT_CACHE_CLASS => 0x800720D2 as u32,
            WIN32::ERROR_DS_CANT_REMOVE_ATT_CACHE => 0x800720D3 as u32,
            WIN32::ERROR_DS_CANT_REMOVE_CLASS_CACHE => 0x800720D4 as u32,
            WIN32::ERROR_DS_CANT_RETRIEVE_DN => 0x800720D5 as u32,
            WIN32::ERROR_DS_MISSING_SUPREF => 0x800720D6 as u32,
            WIN32::ERROR_DS_CANT_RETRIEVE_INSTANCE => 0x800720D7 as u32,
            WIN32::ERROR_DS_CODE_INCONSISTENCY => 0x800720D8 as u32,
            WIN32::ERROR_DS_DATABASE_ERROR => 0x800720D9 as u32,
            WIN32::ERROR_DS_GOVERNSID_MISSING => 0x800720DA as u32,
            WIN32::ERROR_DS_MISSING_EXPECTED_ATT => 0x800720DB as u32,
            WIN32::ERROR_DS_NCNAME_MISSING_CR_REF => 0x800720DC as u32,
            WIN32::ERROR_DS_SECURITY_CHECKING_ERROR => 0x800720DD as u32,
            WIN32::ERROR_DS_SCHEMA_NOT_LOADED => 0x800720DE as u32,
            WIN32::ERROR_DS_SCHEMA_ALLOC_FAILED => 0x800720DF as u32,
            WIN32::ERROR_DS_ATT_SCHEMA_REQ_SYNTAX => 0x800720E0 as u32,
            WIN32::ERROR_DS_GCVERIFY_ERROR => 0x800720E1 as u32,
            WIN32::ERROR_DS_DRA_SCHEMA_MISMATCH => 0x800720E2 as u32,
            WIN32::ERROR_DS_CANT_FIND_DSA_OBJ => 0x800720E3 as u32,
            WIN32::ERROR_DS_CANT_FIND_EXPECTED_NC => 0x800720E4 as u32,
            WIN32::ERROR_DS_CANT_FIND_NC_IN_CACHE => 0x800720E5 as u32,
            WIN32::ERROR_DS_CANT_RETRIEVE_CHILD => 0x800720E6 as u32,
            WIN32::ERROR_DS_SECURITY_ILLEGAL_MODIFY => 0x800720E7 as u32,
            WIN32::ERROR_DS_CANT_REPLACE_HIDDEN_REC => 0x800720E8 as u32,
            WIN32::ERROR_DS_BAD_HIERARCHY_FILE => 0x800720E9 as u32,
            WIN32::ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED => 0x800720EA as u32,
            WIN32::ERROR_DS_CONFIG_PARAM_MISSING => 0x800720EB as u32,
            WIN32::ERROR_DS_COUNTING_AB_INDICES_FAILED => 0x800720EC as u32,
            WIN32::ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED => 0x800720ED as u32,
            WIN32::ERROR_DS_INTERNAL_FAILURE => 0x800720EE as u32,
            WIN32::ERROR_DS_UNKNOWN_ERROR => 0x800720EF as u32,
            WIN32::ERROR_DS_ROOT_REQUIRES_CLASS_TOP => 0x800720F0 as u32,
            WIN32::ERROR_DS_REFUSING_FSMO_ROLES => 0x800720F1 as u32,
            WIN32::ERROR_DS_MISSING_FSMO_SETTINGS => 0x800720F2 as u32,
            WIN32::ERROR_DS_UNABLE_TO_SURRENDER_ROLES => 0x800720F3 as u32,
            WIN32::ERROR_DS_DRA_GENERIC => 0x800720F4 as u32,
            WIN32::ERROR_DS_DRA_INVALID_PARAMETER => 0x800720F5 as u32,
            WIN32::ERROR_DS_DRA_BUSY => 0x800720F6 as u32,
            WIN32::ERROR_DS_DRA_BAD_DN => 0x800720F7 as u32,
            WIN32::ERROR_DS_DRA_BAD_NC => 0x800720F8 as u32,
            WIN32::ERROR_DS_DRA_DN_EXISTS => 0x800720F9 as u32,
            WIN32::ERROR_DS_DRA_INTERNAL_ERROR => 0x800720FA as u32,
            WIN32::ERROR_DS_DRA_INCONSISTENT_DIT => 0x800720FB as u32,
            WIN32::ERROR_DS_DRA_CONNECTION_FAILED => 0x800720FC as u32,
            WIN32::ERROR_DS_DRA_BAD_INSTANCE_TYPE => 0x800720FD as u32,
            WIN32::ERROR_DS_DRA_OUT_OF_MEM => 0x800720FE as u32,
            WIN32::ERROR_DS_DRA_MAIL_PROBLEM => 0x800720FF as u32,
            WIN32::ERROR_DS_DRA_REF_ALREADY_EXISTS => 0x80072100 as u32,
            WIN32::ERROR_DS_DRA_REF_NOT_FOUND => 0x80072101 as u32,
            WIN32::ERROR_DS_DRA_OBJ_IS_REP_SOURCE => 0x80072102 as u32,
            WIN32::ERROR_DS_DRA_DB_ERROR => 0x80072103 as u32,
            WIN32::ERROR_DS_DRA_NO_REPLICA => 0x80072104 as u32,
            WIN32::ERROR_DS_DRA_ACCESS_DENIED => 0x80072105 as u32,
            WIN32::ERROR_DS_DRA_NOT_SUPPORTED => 0x80072106 as u32,
            WIN32::ERROR_DS_DRA_RPC_CANCELLED => 0x80072107 as u32,
            WIN32::ERROR_DS_DRA_SOURCE_DISABLED => 0x80072108 as u32,
            WIN32::ERROR_DS_DRA_SINK_DISABLED => 0x80072109 as u32,
            WIN32::ERROR_DS_DRA_NAME_COLLISION => 0x8007210A as u32,
            WIN32::ERROR_DS_DRA_SOURCE_REINSTALLED => 0x8007210B as u32,
            WIN32::ERROR_DS_DRA_MISSING_PARENT => 0x8007210C as u32,
            WIN32::ERROR_DS_DRA_PREEMPTED => 0x8007210D as u32,
            WIN32::ERROR_DS_DRA_ABANDON_SYNC => 0x8007210E as u32,
            WIN32::ERROR_DS_DRA_SHUTDOWN => 0x8007210F as u32,
            WIN32::ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET => 0x80072110 as u32,
            WIN32::ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA => 0x80072111 as u32,
            WIN32::ERROR_DS_DRA_EXTN_CONNECTION_FAILED => 0x80072112 as u32,
            WIN32::ERROR_DS_INSTALL_SCHEMA_MISMATCH => 0x80072113 as u32,
            WIN32::ERROR_DS_DUP_LINK_ID => 0x80072114 as u32,
            WIN32::ERROR_DS_NAME_ERROR_RESOLVING => 0x80072115 as u32,
            WIN32::ERROR_DS_NAME_ERROR_NOT_FOUND => 0x80072116 as u32,
            WIN32::ERROR_DS_NAME_ERROR_NOT_UNIQUE => 0x80072117 as u32,
            WIN32::ERROR_DS_NAME_ERROR_NO_MAPPING => 0x80072118 as u32,
            WIN32::ERROR_DS_NAME_ERROR_DOMAIN_ONLY => 0x80072119 as u32,
            WIN32::ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING => 0x8007211A as u32,
            WIN32::ERROR_DS_CONSTRUCTED_ATT_MOD => 0x8007211B as u32,
            WIN32::ERROR_DS_WRONG_OM_OBJ_CLASS => 0x8007211C as u32,
            WIN32::ERROR_DS_DRA_REPL_PENDING => 0x8007211D as u32,
            WIN32::ERROR_DS_DS_REQUIRED => 0x8007211E as u32,
            WIN32::ERROR_DS_INVALID_LDAP_DISPLAY_NAME => 0x8007211F as u32,
            WIN32::ERROR_DS_NON_BASE_SEARCH => 0x80072120 as u32,
            WIN32::ERROR_DS_CANT_RETRIEVE_ATTS => 0x80072121 as u32,
            WIN32::ERROR_DS_BACKLINK_WITHOUT_LINK => 0x80072122 as u32,
            WIN32::ERROR_DS_EPOCH_MISMATCH => 0x80072123 as u32,
            WIN32::ERROR_DS_SRC_NAME_MISMATCH => 0x80072124 as u32,
            WIN32::ERROR_DS_SRC_AND_DST_NC_IDENTICAL => 0x80072125 as u32,
            WIN32::ERROR_DS_DST_NC_MISMATCH => 0x80072126 as u32,
            WIN32::ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC => 0x80072127 as u32,
            WIN32::ERROR_DS_SRC_GUID_MISMATCH => 0x80072128 as u32,
            WIN32::ERROR_DS_CANT_MOVE_DELETED_OBJECT => 0x80072129 as u32,
            WIN32::ERROR_DS_PDC_OPERATION_IN_PROGRESS => 0x8007212A as u32,
            WIN32::ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD => 0x8007212B as u32,
            WIN32::ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION => 0x8007212C as u32,
            WIN32::ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS => 0x8007212D as u32,
            WIN32::ERROR_DS_NC_MUST_HAVE_NC_PARENT => 0x8007212E as u32,
            WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE => 0x8007212F as u32,
            WIN32::ERROR_DS_DST_DOMAIN_NOT_NATIVE => 0x80072130 as u32,
            WIN32::ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER => 0x80072131 as u32,
            WIN32::ERROR_DS_CANT_MOVE_ACCOUNT_GROUP => 0x80072132 as u32,
            WIN32::ERROR_DS_CANT_MOVE_RESOURCE_GROUP => 0x80072133 as u32,
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG => 0x80072134 as u32,
            WIN32::ERROR_DS_NO_TREE_DELETE_ABOVE_NC => 0x80072135 as u32,
            WIN32::ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE => 0x80072136 as u32,
            WIN32::ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE => 0x80072137 as u32,
            WIN32::ERROR_DS_SAM_INIT_FAILURE => 0x80072138 as u32,
            WIN32::ERROR_DS_SENSITIVE_GROUP_VIOLATION => 0x80072139 as u32,
            WIN32::ERROR_DS_CANT_MOD_PRIMARYGROUPID => 0x8007213A as u32,
            WIN32::ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD => 0x8007213B as u32,
            WIN32::ERROR_DS_NONSAFE_SCHEMA_CHANGE => 0x8007213C as u32,
            WIN32::ERROR_DS_SCHEMA_UPDATE_DISALLOWED => 0x8007213D as u32,
            WIN32::ERROR_DS_CANT_CREATE_UNDER_SCHEMA => 0x8007213E as u32,
            WIN32::ERROR_DS_INSTALL_NO_SRC_SCH_VERSION => 0x8007213F as u32,
            WIN32::ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE => 0x80072140 as u32,
            WIN32::ERROR_DS_INVALID_GROUP_TYPE => 0x80072141 as u32,
            WIN32::ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN => 0x80072142 as u32,
            WIN32::ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN => 0x80072143 as u32,
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER => 0x80072144 as u32,
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER => 0x80072145 as u32,
            WIN32::ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER => 0x80072146 as u32,
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER => 0x80072147 as u32,
            WIN32::ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER => 0x80072148 as u32,
            WIN32::ERROR_DS_HAVE_PRIMARY_MEMBERS => 0x80072149 as u32,
            WIN32::ERROR_DS_STRING_SD_CONVERSION_FAILED => 0x8007214A as u32,
            WIN32::ERROR_DS_NAMING_MASTER_GC => 0x8007214B as u32,
            WIN32::ERROR_DS_DNS_LOOKUP_FAILURE => 0x8007214C as u32,
            WIN32::ERROR_DS_COULDNT_UPDATE_SPNS => 0x8007214D as u32,
            WIN32::ERROR_DS_CANT_RETRIEVE_SD => 0x8007214E as u32,
            WIN32::ERROR_DS_KEY_NOT_UNIQUE => 0x8007214F as u32,
            WIN32::ERROR_DS_WRONG_LINKED_ATT_SYNTAX => 0x80072150 as u32,
            WIN32::ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD => 0x80072151 as u32,
            WIN32::ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY => 0x80072152 as u32,
            WIN32::ERROR_DS_CANT_START => 0x80072153 as u32,
            WIN32::ERROR_DS_INIT_FAILURE => 0x80072154 as u32,
            WIN32::ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION => 0x80072155 as u32,
            WIN32::ERROR_DS_SOURCE_DOMAIN_IN_FOREST => 0x80072156 as u32,
            WIN32::ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST => 0x80072157 as u32,
            WIN32::ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED => 0x80072158 as u32,
            WIN32::ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN => 0x80072159 as u32,
            WIN32::ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER => 0x8007215A as u32,
            WIN32::ERROR_DS_SRC_SID_EXISTS_IN_FOREST => 0x8007215B as u32,
            WIN32::ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH => 0x8007215C as u32,
            WIN32::ERROR_SAM_INIT_FAILURE => 0x8007215D as u32,
            WIN32::ERROR_DS_DRA_SCHEMA_INFO_SHIP => 0x8007215E as u32,
            WIN32::ERROR_DS_DRA_SCHEMA_CONFLICT => 0x8007215F as u32,
            WIN32::ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT => 0x80072160 as u32,
            WIN32::ERROR_DS_DRA_OBJ_NC_MISMATCH => 0x80072161 as u32,
            WIN32::ERROR_DS_NC_STILL_HAS_DSAS => 0x80072162 as u32,
            WIN32::ERROR_DS_GC_REQUIRED => 0x80072163 as u32,
            WIN32::ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY => 0x80072164 as u32,
            WIN32::ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS => 0x80072165 as u32,
            WIN32::ERROR_DS_CANT_ADD_TO_GC => 0x80072166 as u32,
            WIN32::ERROR_DS_NO_CHECKPOINT_WITH_PDC => 0x80072167 as u32,
            WIN32::ERROR_DS_SOURCE_AUDITING_NOT_ENABLED => 0x80072168 as u32,
            WIN32::ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC => 0x80072169 as u32,
            WIN32::ERROR_DS_INVALID_NAME_FOR_SPN => 0x8007216A as u32,
            WIN32::ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS => 0x8007216B as u32,
            WIN32::ERROR_DS_UNICODEPWD_NOT_IN_QUOTES => 0x8007216C as u32,
            WIN32::ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED => 0x8007216D as u32,
            WIN32::ERROR_DS_MUST_BE_RUN_ON_DST_DC => 0x8007216E as u32,
            WIN32::ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER => 0x8007216F as u32,
            WIN32::ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ => 0x80072170 as u32,
            WIN32::ERROR_DS_INIT_FAILURE_CONSOLE => 0x80072171 as u32,
            WIN32::ERROR_DS_SAM_INIT_FAILURE_CONSOLE => 0x80072172 as u32,
            WIN32::ERROR_DS_FOREST_VERSION_TOO_HIGH => 0x80072173 as u32,
            WIN32::ERROR_DS_DOMAIN_VERSION_TOO_HIGH => 0x80072174 as u32,
            WIN32::ERROR_DS_FOREST_VERSION_TOO_LOW => 0x80072175 as u32,
            WIN32::ERROR_DS_DOMAIN_VERSION_TOO_LOW => 0x80072176 as u32,
            WIN32::ERROR_DS_INCOMPATIBLE_VERSION => 0x80072177 as u32,
            WIN32::ERROR_DS_LOW_DSA_VERSION => 0x80072178 as u32,
            WIN32::ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN => 0x80072179 as u32,
            WIN32::ERROR_DS_NOT_SUPPORTED_SORT_ORDER => 0x8007217A as u32,
            WIN32::ERROR_DS_NAME_NOT_UNIQUE => 0x8007217B as u32,
            WIN32::ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4 => 0x8007217C as u32,
            WIN32::ERROR_DS_OUT_OF_VERSION_STORE => 0x8007217D as u32,
            WIN32::ERROR_DS_INCOMPATIBLE_CONTROLS_USED => 0x8007217E as u32,
            WIN32::ERROR_DS_NO_REF_DOMAIN => 0x8007217F as u32,
            WIN32::ERROR_DS_RESERVED_LINK_ID => 0x80072180 as u32,
            WIN32::ERROR_DS_LINK_ID_NOT_AVAILABLE => 0x80072181 as u32,
            WIN32::ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER => 0x80072182 as u32,
            WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE => 0x80072183 as u32,
            WIN32::ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC => 0x80072184 as u32,
            WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG => 0x80072185 as u32,
            WIN32::ERROR_DS_MODIFYDN_WRONG_GRANDPARENT => 0x80072186 as u32,
            WIN32::ERROR_DS_NAME_ERROR_TRUST_REFERRAL => 0x80072187 as u32,
            WIN32::ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER => 0x80072188 as u32,
            WIN32::ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD => 0x80072189 as u32,
            WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2 => 0x8007218A as u32,
            WIN32::ERROR_DS_THREAD_LIMIT_EXCEEDED => 0x8007218B as u32,
            WIN32::ERROR_DS_NOT_CLOSEST => 0x8007218C as u32,
            WIN32::ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF => 0x8007218D as u32,
            WIN32::ERROR_DS_SINGLE_USER_MODE_FAILED => 0x8007218E as u32,
            WIN32::ERROR_DS_NTDSCRIPT_SYNTAX_ERROR => 0x8007218F as u32,
            WIN32::ERROR_DS_NTDSCRIPT_PROCESS_ERROR => 0x80072190 as u32,
            WIN32::ERROR_DS_DIFFERENT_REPL_EPOCHS => 0x80072191 as u32,
            WIN32::ERROR_DS_DRS_EXTENSIONS_CHANGED => 0x80072192 as u32,
            WIN32::ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR => 0x80072193 as u32,
            WIN32::ERROR_DS_NO_MSDS_INTID => 0x80072194 as u32,
            WIN32::ERROR_DS_DUP_MSDS_INTID => 0x80072195 as u32,
            WIN32::ERROR_DS_EXISTS_IN_RDNATTID => 0x80072196 as u32,
            WIN32::ERROR_DS_AUTHORIZATION_FAILED => 0x80072197 as u32,
            WIN32::ERROR_DS_INVALID_SCRIPT => 0x80072198 as u32,
            WIN32::ERROR_DS_REMOTE_CROSSREF_OP_FAILED => 0x80072199 as u32,
            WIN32::ERROR_DS_CROSS_REF_BUSY => 0x8007219A as u32,
            WIN32::ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN => 0x8007219B as u32,
            WIN32::ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC => 0x8007219C as u32,
            WIN32::ERROR_DS_DUPLICATE_ID_FOUND => 0x8007219D as u32,
            WIN32::ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT => 0x8007219E as u32,
            WIN32::ERROR_DS_GROUP_CONVERSION_ERROR => 0x8007219F as u32,
            WIN32::ERROR_DS_CANT_MOVE_APP_BASIC_GROUP => 0x800721A0 as u32,
            WIN32::ERROR_DS_CANT_MOVE_APP_QUERY_GROUP => 0x800721A1 as u32,
            WIN32::ERROR_DS_ROLE_NOT_VERIFIED => 0x800721A2 as u32,
            WIN32::ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL => 0x800721A3 as u32,
            WIN32::ERROR_DS_DOMAIN_RENAME_IN_PROGRESS => 0x800721A4 as u32,
            WIN32::ERROR_DS_EXISTING_AD_CHILD_NC => 0x800721A5 as u32,
            WIN32::ERROR_DS_REPL_LIFETIME_EXCEEDED => 0x800721A6 as u32,
            WIN32::ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER => 0x800721A7 as u32,
            WIN32::ERROR_DS_LDAP_SEND_QUEUE_FULL => 0x800721A8 as u32,
            WIN32::ERROR_DS_DRA_OUT_SCHEDULE_WINDOW => 0x800721A9 as u32,
            WIN32::ERROR_DS_POLICY_NOT_KNOWN => 0x800721AA as u32,
            WIN32::ERROR_NO_SITE_SETTINGS_OBJECT => 0x800721AB as u32,
            WIN32::ERROR_NO_SECRETS => 0x800721AC as u32,
            WIN32::ERROR_NO_WRITABLE_DC_FOUND => 0x800721AD as u32,
            WIN32::ERROR_DS_NO_SERVER_OBJECT => 0x800721AE as u32,
            WIN32::ERROR_DS_NO_NTDSA_OBJECT => 0x800721AF as u32,
            WIN32::ERROR_DS_NON_ASQ_SEARCH => 0x800721B0 as u32,
            WIN32::ERROR_DS_AUDIT_FAILURE => 0x800721B1 as u32,
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE => 0x800721B2 as u32,
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG_TUPLE => 0x800721B3 as u32,
            WIN32::ERROR_DS_HIERARCHY_TABLE_TOO_DEEP => 0x800721B4 as u32,
            WIN32::ERROR_DS_DRA_CORRUPT_UTD_VECTOR => 0x800721B5 as u32,
            WIN32::ERROR_DS_DRA_SECRETS_DENIED => 0x800721B6 as u32,
            WIN32::ERROR_DS_RESERVED_MAPI_ID => 0x800721B7 as u32,
            WIN32::ERROR_DS_MAPI_ID_NOT_AVAILABLE => 0x800721B8 as u32,
            WIN32::ERROR_DS_DRA_MISSING_KRBTGT_SECRET => 0x800721B9 as u32,
            WIN32::ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST => 0x800721BA as u32,
            WIN32::ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST => 0x800721BB as u32,
            WIN32::ERROR_INVALID_USER_PRINCIPAL_NAME => 0x800721BC as u32,
            WIN32::ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS => 0x800721BD as u32,
            WIN32::ERROR_DS_OID_NOT_FOUND => 0x800721BE as u32,
            WIN32::ERROR_DS_DRA_RECYCLED_TARGET => 0x800721BF as u32,
            WIN32::ERROR_DS_DISALLOWED_NC_REDIRECT => 0x800721C0 as u32,
            WIN32::ERROR_DS_HIGH_ADLDS_FFL => 0x800721C1 as u32,
            WIN32::ERROR_DS_HIGH_DSA_VERSION => 0x800721C2 as u32,
            WIN32::ERROR_DS_LOW_ADLDS_FFL => 0x800721C3 as u32,
            WIN32::ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION => 0x800721C4 as u32,
            WIN32::ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED => 0x800721C5 as u32,
            WIN32::ERROR_INCORRECT_ACCOUNT_TYPE => 0x800721C6 as u32,
            WIN32::ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST => 0x800721C7 as u32,
            WIN32::ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST => 0x800721C8 as u32,
            WIN32::ERROR_DS_MISSING_FOREST_TRUST => 0x800721C9 as u32,
            WIN32::ERROR_DS_VALUE_KEY_NOT_UNIQUE => 0x800721CA as u32,
            WIN32::ERROR_WEAK_WHFBKEY_BLOCKED => 0x800721CB as u32,
            WIN32::ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD => 0x800721CC as u32,
            WIN32::ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED => 0x800721CD as u32,
            WIN32::ERROR_POLICY_CONTROLLED_ACCOUNT => 0x800721CE as u32,
            WIN32::ERROR_LAPS_LEGACY_SCHEMA_MISSING => 0x800721CF as u32,
            WIN32::ERROR_LAPS_SCHEMA_MISSING => 0x800721D0 as u32,
            WIN32::ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL => 0x800721D1 as u32,
            WIN32::DNS_ERROR_RCODE_FORMAT_ERROR => 0x80072329 as u32,
            WIN32::DNS_ERROR_RCODE_SERVER_FAILURE => 0x8007232A as u32,
            WIN32::DNS_ERROR_RCODE_NAME_ERROR => 0x8007232B as u32,
            WIN32::DNS_ERROR_RCODE_NOT_IMPLEMENTED => 0x8007232C as u32,
            WIN32::DNS_ERROR_RCODE_REFUSED => 0x8007232D as u32,
            WIN32::DNS_ERROR_RCODE_YXDOMAIN => 0x8007232E as u32,
            WIN32::DNS_ERROR_RCODE_YXRRSET => 0x8007232F as u32,
            WIN32::DNS_ERROR_RCODE_NXRRSET => 0x80072330 as u32,
            WIN32::DNS_ERROR_RCODE_NOTAUTH => 0x80072331 as u32,
            WIN32::DNS_ERROR_RCODE_NOTZONE => 0x80072332 as u32,
            WIN32::DNS_ERROR_RCODE_BADSIG => 0x80072338 as u32,
            WIN32::DNS_ERROR_RCODE_BADKEY => 0x80072339 as u32,
            WIN32::DNS_ERROR_RCODE_BADTIME => 0x8007233A as u32,
            WIN32::DNS_ERROR_KEYMASTER_REQUIRED => 0x8007238D as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE => 0x8007238E as u32,
            WIN32::DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1 => 0x8007238F as u32,
            WIN32::DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS => 0x80072390 as u32,
            WIN32::DNS_ERROR_UNSUPPORTED_ALGORITHM => 0x80072391 as u32,
            WIN32::DNS_ERROR_INVALID_KEY_SIZE => 0x80072392 as u32,
            WIN32::DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE => 0x80072393 as u32,
            WIN32::DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION => 0x80072394 as u32,
            WIN32::DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR => 0x80072395 as u32,
            WIN32::DNS_ERROR_UNEXPECTED_CNG_ERROR => 0x80072396 as u32,
            WIN32::DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION => 0x80072397 as u32,
            WIN32::DNS_ERROR_KSP_NOT_ACCESSIBLE => 0x80072398 as u32,
            WIN32::DNS_ERROR_TOO_MANY_SKDS => 0x80072399 as u32,
            WIN32::DNS_ERROR_INVALID_ROLLOVER_PERIOD => 0x8007239A as u32,
            WIN32::DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET => 0x8007239B as u32,
            WIN32::DNS_ERROR_ROLLOVER_IN_PROGRESS => 0x8007239C as u32,
            WIN32::DNS_ERROR_STANDBY_KEY_NOT_PRESENT => 0x8007239D as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ZSK => 0x8007239E as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD => 0x8007239F as u32,
            WIN32::DNS_ERROR_ROLLOVER_ALREADY_QUEUED => 0x800723A0 as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE => 0x800723A1 as u32,
            WIN32::DNS_ERROR_BAD_KEYMASTER => 0x800723A2 as u32,
            WIN32::DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD => 0x800723A3 as u32,
            WIN32::DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT => 0x800723A4 as u32,
            WIN32::DNS_ERROR_DNSSEC_IS_DISABLED => 0x800723A5 as u32,
            WIN32::DNS_ERROR_INVALID_XML => 0x800723A6 as u32,
            WIN32::DNS_ERROR_NO_VALID_TRUST_ANCHORS => 0x800723A7 as u32,
            WIN32::DNS_ERROR_ROLLOVER_NOT_POKEABLE => 0x800723A8 as u32,
            WIN32::DNS_ERROR_NSEC3_NAME_COLLISION => 0x800723A9 as u32,
            WIN32::DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1 => 0x800723AA as u32,
            WIN32::DNS_INFO_NO_RECORDS => 0x8007251D as u32,
            WIN32::DNS_ERROR_BAD_PACKET => 0x8007251E as u32,
            WIN32::DNS_ERROR_NO_PACKET => 0x8007251F as u32,
            WIN32::DNS_ERROR_RCODE => 0x80072520 as u32,
            WIN32::DNS_ERROR_UNSECURE_PACKET => 0x80072521 as u32,
            WIN32::DNS_REQUEST_PENDING => 0x80072522 as u32,
            WIN32::DNS_ERROR_INVALID_TYPE => 0x8007254F as u32,
            WIN32::DNS_ERROR_INVALID_IP_ADDRESS => 0x80072550 as u32,
            WIN32::DNS_ERROR_INVALID_PROPERTY => 0x80072551 as u32,
            WIN32::DNS_ERROR_TRY_AGAIN_LATER => 0x80072552 as u32,
            WIN32::DNS_ERROR_NOT_UNIQUE => 0x80072553 as u32,
            WIN32::DNS_ERROR_NON_RFC_NAME => 0x80072554 as u32,
            WIN32::DNS_STATUS_FQDN => 0x80072555 as u32,
            WIN32::DNS_STATUS_DOTTED_NAME => 0x80072556 as u32,
            WIN32::DNS_STATUS_SINGLE_PART_NAME => 0x80072557 as u32,
            WIN32::DNS_ERROR_INVALID_NAME_CHAR => 0x80072558 as u32,
            WIN32::DNS_ERROR_NUMERIC_NAME => 0x80072559 as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER => 0x8007255A as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION => 0x8007255B as u32,
            WIN32::DNS_ERROR_CANNOT_FIND_ROOT_HINTS => 0x8007255C as u32,
            WIN32::DNS_ERROR_INCONSISTENT_ROOT_HINTS => 0x8007255D as u32,
            WIN32::DNS_ERROR_DWORD_VALUE_TOO_SMALL => 0x8007255E as u32,
            WIN32::DNS_ERROR_DWORD_VALUE_TOO_LARGE => 0x8007255F as u32,
            WIN32::DNS_ERROR_BACKGROUND_LOADING => 0x80072560 as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_RODC => 0x80072561 as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DNAME => 0x80072562 as u32,
            WIN32::DNS_ERROR_DELEGATION_REQUIRED => 0x80072563 as u32,
            WIN32::DNS_ERROR_INVALID_POLICY_TABLE => 0x80072564 as u32,
            WIN32::DNS_ERROR_ADDRESS_REQUIRED => 0x80072565 as u32,
            WIN32::DNS_ERROR_ZONE_DOES_NOT_EXIST => 0x80072581 as u32,
            WIN32::DNS_ERROR_NO_ZONE_INFO => 0x80072582 as u32,
            WIN32::DNS_ERROR_INVALID_ZONE_OPERATION => 0x80072583 as u32,
            WIN32::DNS_ERROR_ZONE_CONFIGURATION_ERROR => 0x80072584 as u32,
            WIN32::DNS_ERROR_ZONE_HAS_NO_SOA_RECORD => 0x80072585 as u32,
            WIN32::DNS_ERROR_ZONE_HAS_NO_NS_RECORDS => 0x80072586 as u32,
            WIN32::DNS_ERROR_ZONE_LOCKED => 0x80072587 as u32,
            WIN32::DNS_ERROR_ZONE_CREATION_FAILED => 0x80072588 as u32,
            WIN32::DNS_ERROR_ZONE_ALREADY_EXISTS => 0x80072589 as u32,
            WIN32::DNS_ERROR_AUTOZONE_ALREADY_EXISTS => 0x8007258A as u32,
            WIN32::DNS_ERROR_INVALID_ZONE_TYPE => 0x8007258B as u32,
            WIN32::DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP => 0x8007258C as u32,
            WIN32::DNS_ERROR_ZONE_NOT_SECONDARY => 0x8007258D as u32,
            WIN32::DNS_ERROR_NEED_SECONDARY_ADDRESSES => 0x8007258E as u32,
            WIN32::DNS_ERROR_WINS_INIT_FAILED => 0x8007258F as u32,
            WIN32::DNS_ERROR_NEED_WINS_SERVERS => 0x80072590 as u32,
            WIN32::DNS_ERROR_NBSTAT_INIT_FAILED => 0x80072591 as u32,
            WIN32::DNS_ERROR_SOA_DELETE_INVALID => 0x80072592 as u32,
            WIN32::DNS_ERROR_FORWARDER_ALREADY_EXISTS => 0x80072593 as u32,
            WIN32::DNS_ERROR_ZONE_REQUIRES_MASTER_IP => 0x80072594 as u32,
            WIN32::DNS_ERROR_ZONE_IS_SHUTDOWN => 0x80072595 as u32,
            WIN32::DNS_ERROR_ZONE_LOCKED_FOR_SIGNING => 0x80072596 as u32,
            WIN32::DNS_ERROR_PRIMARY_REQUIRES_DATAFILE => 0x800725B3 as u32,
            WIN32::DNS_ERROR_INVALID_DATAFILE_NAME => 0x800725B4 as u32,
            WIN32::DNS_ERROR_DATAFILE_OPEN_FAILURE => 0x800725B5 as u32,
            WIN32::DNS_ERROR_FILE_WRITEBACK_FAILED => 0x800725B6 as u32,
            WIN32::DNS_ERROR_DATAFILE_PARSING => 0x800725B7 as u32,
            WIN32::DNS_ERROR_RECORD_DOES_NOT_EXIST => 0x800725E5 as u32,
            WIN32::DNS_ERROR_RECORD_FORMAT => 0x800725E6 as u32,
            WIN32::DNS_ERROR_NODE_CREATION_FAILED => 0x800725E7 as u32,
            WIN32::DNS_ERROR_UNKNOWN_RECORD_TYPE => 0x800725E8 as u32,
            WIN32::DNS_ERROR_RECORD_TIMED_OUT => 0x800725E9 as u32,
            WIN32::DNS_ERROR_NAME_NOT_IN_ZONE => 0x800725EA as u32,
            WIN32::DNS_ERROR_CNAME_LOOP => 0x800725EB as u32,
            WIN32::DNS_ERROR_NODE_IS_CNAME => 0x800725EC as u32,
            WIN32::DNS_ERROR_CNAME_COLLISION => 0x800725ED as u32,
            WIN32::DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT => 0x800725EE as u32,
            WIN32::DNS_ERROR_RECORD_ALREADY_EXISTS => 0x800725EF as u32,
            WIN32::DNS_ERROR_SECONDARY_DATA => 0x800725F0 as u32,
            WIN32::DNS_ERROR_NO_CREATE_CACHE_DATA => 0x800725F1 as u32,
            WIN32::DNS_ERROR_NAME_DOES_NOT_EXIST => 0x800725F2 as u32,
            WIN32::DNS_WARNING_PTR_CREATE_FAILED => 0x800725F3 as u32,
            WIN32::DNS_WARNING_DOMAIN_UNDELETED => 0x800725F4 as u32,
            WIN32::DNS_ERROR_DS_UNAVAILABLE => 0x800725F5 as u32,
            WIN32::DNS_ERROR_DS_ZONE_ALREADY_EXISTS => 0x800725F6 as u32,
            WIN32::DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE => 0x800725F7 as u32,
            WIN32::DNS_ERROR_NODE_IS_DNAME => 0x800725F8 as u32,
            WIN32::DNS_ERROR_DNAME_COLLISION => 0x800725F9 as u32,
            WIN32::DNS_ERROR_ALIAS_LOOP => 0x800725FA as u32,
            WIN32::DNS_INFO_AXFR_COMPLETE => 0x80072617 as u32,
            WIN32::DNS_ERROR_AXFR => 0x80072618 as u32,
            WIN32::DNS_INFO_ADDED_LOCAL_WINS => 0x80072619 as u32,
            WIN32::DNS_STATUS_CONTINUE_NEEDED => 0x80072649 as u32,
            WIN32::DNS_ERROR_NO_TCPIP => 0x8007267B as u32,
            WIN32::DNS_ERROR_NO_DNS_SERVERS => 0x8007267C as u32,
            WIN32::DNS_ERROR_DP_DOES_NOT_EXIST => 0x800726AD as u32,
            WIN32::DNS_ERROR_DP_ALREADY_EXISTS => 0x800726AE as u32,
            WIN32::DNS_ERROR_DP_NOT_ENLISTED => 0x800726AF as u32,
            WIN32::DNS_ERROR_DP_ALREADY_ENLISTED => 0x800726B0 as u32,
            WIN32::DNS_ERROR_DP_NOT_AVAILABLE => 0x800726B1 as u32,
            WIN32::DNS_ERROR_DP_FSMO_ERROR => 0x800726B2 as u32,
            WIN32::DNS_ERROR_RRL_NOT_ENABLED => 0x800726B7 as u32,
            WIN32::DNS_ERROR_RRL_INVALID_WINDOW_SIZE => 0x800726B8 as u32,
            WIN32::DNS_ERROR_RRL_INVALID_IPV4_PREFIX => 0x800726B9 as u32,
            WIN32::DNS_ERROR_RRL_INVALID_IPV6_PREFIX => 0x800726BA as u32,
            WIN32::DNS_ERROR_RRL_INVALID_TC_RATE => 0x800726BB as u32,
            WIN32::DNS_ERROR_RRL_INVALID_LEAK_RATE => 0x800726BC as u32,
            WIN32::DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE => 0x800726BD as u32,
            WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS => 0x800726C1 as u32,
            WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST => 0x800726C2 as u32,
            WIN32::DNS_ERROR_VIRTUALIZATION_TREE_LOCKED => 0x800726C3 as u32,
            WIN32::DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME => 0x800726C4 as u32,
            WIN32::DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE => 0x800726C5 as u32,
            WIN32::DNS_ERROR_ZONESCOPE_ALREADY_EXISTS => 0x800726DF as u32,
            WIN32::DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST => 0x800726E0 as u32,
            WIN32::DNS_ERROR_DEFAULT_ZONESCOPE => 0x800726E1 as u32,
            WIN32::DNS_ERROR_INVALID_ZONESCOPE_NAME => 0x800726E2 as u32,
            WIN32::DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES => 0x800726E3 as u32,
            WIN32::DNS_ERROR_LOAD_ZONESCOPE_FAILED => 0x800726E4 as u32,
            WIN32::DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED => 0x800726E5 as u32,
            WIN32::DNS_ERROR_INVALID_SCOPE_NAME => 0x800726E6 as u32,
            WIN32::DNS_ERROR_SCOPE_DOES_NOT_EXIST => 0x800726E7 as u32,
            WIN32::DNS_ERROR_DEFAULT_SCOPE => 0x800726E8 as u32,
            WIN32::DNS_ERROR_INVALID_SCOPE_OPERATION => 0x800726E9 as u32,
            WIN32::DNS_ERROR_SCOPE_LOCKED => 0x800726EA as u32,
            WIN32::DNS_ERROR_SCOPE_ALREADY_EXISTS => 0x800726EB as u32,
            WIN32::DNS_ERROR_POLICY_ALREADY_EXISTS => 0x800726F3 as u32,
            WIN32::DNS_ERROR_POLICY_DOES_NOT_EXIST => 0x800726F4 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA => 0x800726F5 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_SETTINGS => 0x800726F6 as u32,
            WIN32::DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED => 0x800726F7 as u32,
            WIN32::DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST => 0x800726F8 as u32,
            WIN32::DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS => 0x800726F9 as u32,
            WIN32::DNS_ERROR_SUBNET_DOES_NOT_EXIST => 0x800726FA as u32,
            WIN32::DNS_ERROR_SUBNET_ALREADY_EXISTS => 0x800726FB as u32,
            WIN32::DNS_ERROR_POLICY_LOCKED => 0x800726FC as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_WEIGHT => 0x800726FD as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_NAME => 0x800726FE as u32,
            WIN32::DNS_ERROR_POLICY_MISSING_CRITERIA => 0x800726FF as u32,
            WIN32::DNS_ERROR_INVALID_CLIENT_SUBNET_NAME => 0x80072700 as u32,
            WIN32::DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID => 0x80072701 as u32,
            WIN32::DNS_ERROR_POLICY_SCOPE_MISSING => 0x80072702 as u32,
            WIN32::DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED => 0x80072703 as u32,
            WIN32::DNS_ERROR_SERVERSCOPE_IS_REFERENCED => 0x80072704 as u32,
            WIN32::DNS_ERROR_ZONESCOPE_IS_REFERENCED => 0x80072705 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET => 0x80072706 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL => 0x80072707 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL => 0x80072708 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE => 0x80072709 as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN => 0x8007270A as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE => 0x8007270B as u32,
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY => 0x8007270C as u32,
            WIN32::WSAEINTR => 0x80072714 as u32,
            WIN32::WSAEBADF => 0x80072719 as u32,
            WIN32::WSAEACCES => 0x8007271D as u32,
            WIN32::WSAEFAULT => 0x8007271E as u32,
            WIN32::WSAEINVAL => 0x80072726 as u32,
            WIN32::WSAEMFILE => 0x80072728 as u32,
            WIN32::WSAEWOULDBLOCK => 0x80072733 as u32,
            WIN32::WSAEINPROGRESS => 0x80072734 as u32,
            WIN32::WSAEALREADY => 0x80072735 as u32,
            WIN32::WSAENOTSOCK => 0x80072736 as u32,
            WIN32::WSAEDESTADDRREQ => 0x80072737 as u32,
            WIN32::WSAEMSGSIZE => 0x80072738 as u32,
            WIN32::WSAEPROTOTYPE => 0x80072739 as u32,
            WIN32::WSAENOPROTOOPT => 0x8007273A as u32,
            WIN32::WSAEPROTONOSUPPORT => 0x8007273B as u32,
            WIN32::WSAESOCKTNOSUPPORT => 0x8007273C as u32,
            WIN32::WSAEOPNOTSUPP => 0x8007273D as u32,
            WIN32::WSAEPFNOSUPPORT => 0x8007273E as u32,
            WIN32::WSAEAFNOSUPPORT => 0x8007273F as u32,
            WIN32::WSAEADDRINUSE => 0x80072740 as u32,
            WIN32::WSAEADDRNOTAVAIL => 0x80072741 as u32,
            WIN32::WSAENETDOWN => 0x80072742 as u32,
            WIN32::WSAENETUNREACH => 0x80072743 as u32,
            WIN32::WSAENETRESET => 0x80072744 as u32,
            WIN32::WSAECONNABORTED => 0x80072745 as u32,
            WIN32::WSAECONNRESET => 0x80072746 as u32,
            WIN32::WSAENOBUFS => 0x80072747 as u32,
            WIN32::WSAEISCONN => 0x80072748 as u32,
            WIN32::WSAENOTCONN => 0x80072749 as u32,
            WIN32::WSAESHUTDOWN => 0x8007274A as u32,
            WIN32::WSAETOOMANYREFS => 0x8007274B as u32,
            WIN32::WSAETIMEDOUT => 0x8007274C as u32,
            WIN32::WSAECONNREFUSED => 0x8007274D as u32,
            WIN32::WSAELOOP => 0x8007274E as u32,
            WIN32::WSAENAMETOOLONG => 0x8007274F as u32,
            WIN32::WSAEHOSTDOWN => 0x80072750 as u32,
            WIN32::WSAEHOSTUNREACH => 0x80072751 as u32,
            WIN32::WSAENOTEMPTY => 0x80072752 as u32,
            WIN32::WSAEPROCLIM => 0x80072753 as u32,
            WIN32::WSAEUSERS => 0x80072754 as u32,
            WIN32::WSAEDQUOT => 0x80072755 as u32,
            WIN32::WSAESTALE => 0x80072756 as u32,
            WIN32::WSAEREMOTE => 0x80072757 as u32,
            WIN32::WSASYSNOTREADY => 0x8007276B as u32,
            WIN32::WSAVERNOTSUPPORTED => 0x8007276C as u32,
            WIN32::WSANOTINITIALISED => 0x8007276D as u32,
            WIN32::WSAEDISCON => 0x80072775 as u32,
            WIN32::WSAENOMORE => 0x80072776 as u32,
            WIN32::WSAECANCELLED => 0x80072777 as u32,
            WIN32::WSAEINVALIDPROCTABLE => 0x80072778 as u32,
            WIN32::WSAEINVALIDPROVIDER => 0x80072779 as u32,
            WIN32::WSAEPROVIDERFAILEDINIT => 0x8007277A as u32,
            WIN32::WSASYSCALLFAILURE => 0x8007277B as u32,
            WIN32::WSASERVICE_NOT_FOUND => 0x8007277C as u32,
            WIN32::WSATYPE_NOT_FOUND => 0x8007277D as u32,
            WIN32::WSA_E_NO_MORE => 0x8007277E as u32,
            WIN32::WSA_E_CANCELLED => 0x8007277F as u32,
            WIN32::WSAEREFUSED => 0x80072780 as u32,
            WIN32::WSAHOST_NOT_FOUND => 0x80072AF9 as u32,
            WIN32::WSATRY_AGAIN => 0x80072AFA as u32,
            WIN32::WSANO_RECOVERY => 0x80072AFB as u32,
            WIN32::WSANO_DATA => 0x80072AFC as u32,
            WIN32::WSA_QOS_RECEIVERS => 0x80072AFD as u32,
            WIN32::WSA_QOS_SENDERS => 0x80072AFE as u32,
            WIN32::WSA_QOS_NO_SENDERS => 0x80072AFF as u32,
            WIN32::WSA_QOS_NO_RECEIVERS => 0x80072B00 as u32,
            WIN32::WSA_QOS_REQUEST_CONFIRMED => 0x80072B01 as u32,
            WIN32::WSA_QOS_ADMISSION_FAILURE => 0x80072B02 as u32,
            WIN32::WSA_QOS_POLICY_FAILURE => 0x80072B03 as u32,
            WIN32::WSA_QOS_BAD_STYLE => 0x80072B04 as u32,
            WIN32::WSA_QOS_BAD_OBJECT => 0x80072B05 as u32,
            WIN32::WSA_QOS_TRAFFIC_CTRL_ERROR => 0x80072B06 as u32,
            WIN32::WSA_QOS_GENERIC_ERROR => 0x80072B07 as u32,
            WIN32::WSA_QOS_ESERVICETYPE => 0x80072B08 as u32,
            WIN32::WSA_QOS_EFLOWSPEC => 0x80072B09 as u32,
            WIN32::WSA_QOS_EPROVSPECBUF => 0x80072B0A as u32,
            WIN32::WSA_QOS_EFILTERSTYLE => 0x80072B0B as u32,
            WIN32::WSA_QOS_EFILTERTYPE => 0x80072B0C as u32,
            WIN32::WSA_QOS_EFILTERCOUNT => 0x80072B0D as u32,
            WIN32::WSA_QOS_EOBJLENGTH => 0x80072B0E as u32,
            WIN32::WSA_QOS_EFLOWCOUNT => 0x80072B0F as u32,
            WIN32::WSA_QOS_EUNKOWNPSOBJ => 0x80072B10 as u32,
            WIN32::WSA_QOS_EPOLICYOBJ => 0x80072B11 as u32,
            WIN32::WSA_QOS_EFLOWDESC => 0x80072B12 as u32,
            WIN32::WSA_QOS_EPSFLOWSPEC => 0x80072B13 as u32,
            WIN32::WSA_QOS_EPSFILTERSPEC => 0x80072B14 as u32,
            WIN32::WSA_QOS_ESDMODEOBJ => 0x80072B15 as u32,
            WIN32::WSA_QOS_ESHAPERATEOBJ => 0x80072B16 as u32,
            WIN32::WSA_QOS_RESERVED_PETYPE => 0x80072B17 as u32,
            WIN32::WSA_SECURE_HOST_NOT_FOUND => 0x80072B18 as u32,
            WIN32::WSA_IPSEC_NAME_POLICY_ERROR => 0x80072B19 as u32,
            WIN32::PEER_E_CLOUD_NOT_FOUND => 0x80072CF1 as u32,
            WIN32::PEER_E_CLOUD_DISABLED => 0x80072CF2 as u32,
            WIN32::PEER_E_INVALID_IDENTITY => 0x80072CF3 as u32,
            WIN32::PEER_E_TOO_MUCH_LOAD => 0x80072CF4 as u32,
            WIN32::PEER_E_CLOUD_IS_SEARCH_ONLY => 0x80072CF5 as u32,
            WIN32::PEER_E_CLIENT_INVALID_COMPARTMENT_ID => 0x80072CF6 as u32,
            WIN32::PEER_E_DUPLICATE_PEER_NAME => 0x80072CF8 as u32,
            WIN32::PEER_E_CLOUD_IS_DEAD => 0x80072CF9 as u32,
            WIN32::ERROR_INTERNET_ => 0x80072EE0 as u32,
            WIN32::WININET_E_OUT_OF_HANDLES => 0x80072EE1 as u32,
            WIN32::ERROR_INTERNET_OUT_OF_HANDLES => 0x80072EE1 as u32,
            WIN32::WININET_E_TIMEOUT => 0x80072EE2 as u32,
            WIN32::ERROR_INTERNET_TIMEOUT => 0x80072EE2 as u32,
            WIN32::ERROR_WINHTTP_TIMEOUT => 0x80072EE2 as u32,
            WIN32::WININET_E_EXTENDED_ERROR => 0x80072EE3 as u32,
            WIN32::ERROR_INTERNET_EXTENDED_ERROR => 0x80072EE3 as u32,
            WIN32::WININET_E_INTERNAL_ERROR => 0x80072EE4 as u32,
            WIN32::ERROR_INTERNET_INTERNAL_ERROR => 0x80072EE4 as u32,
            WIN32::ERROR_WINHTTP_INTERNAL_ERROR => 0x80072EE4 as u32,
            WIN32::WININET_E_INVALID_URL => 0x80072EE5 as u32,
            WIN32::ERROR_INTERNET_INVALID_URL => 0x80072EE5 as u32,
            WIN32::ERROR_WINHTTP_INVALID_URL => 0x80072EE5 as u32,
            WIN32::WININET_E_UNRECOGNIZED_SCHEME => 0x80072EE6 as u32,
            WIN32::ERROR_INTERNET_UNRECOGNIZED_SCHEME => 0x80072EE6 as u32,
            WIN32::ERROR_WINHTTP_UNRECOGNIZED_SCHEME => 0x80072EE6 as u32,
            WIN32::WININET_E_NAME_NOT_RESOLVED => 0x80072EE7 as u32,
            WIN32::ERROR_INTERNET_NAME_NOT_RESOLVED => 0x80072EE7 as u32,
            WIN32::ERROR_WINHTTP_NAME_NOT_RESOLVED => 0x80072EE7 as u32,
            WIN32::WININET_E_PROTOCOL_NOT_FOUND => 0x80072EE8 as u32,
            WIN32::ERROR_INTERNET_PROTOCOL_NOT_FOUND => 0x80072EE8 as u32,
            WIN32::WININET_E_INVALID_OPTION => 0x80072EE9 as u32,
            WIN32::ERROR_INTERNET_INVALID_OPTION => 0x80072EE9 as u32,
            WIN32::ERROR_WINHTTP_INVALID_OPTION => 0x80072EE9 as u32,
            WIN32::WININET_E_BAD_OPTION_LENGTH => 0x80072EEA as u32,
            WIN32::ERROR_INTERNET_BAD_OPTION_LENGTH => 0x80072EEA as u32,
            WIN32::WININET_E_OPTION_NOT_SETTABLE => 0x80072EEB as u32,
            WIN32::ERROR_INTERNET_OPTION_NOT_SETTABLE => 0x80072EEB as u32,
            WIN32::WININET_E_SHUTDOWN => 0x80072EEC as u32,
            WIN32::ERROR_INTERNET_SHUTDOWN => 0x80072EEC as u32,
            WIN32::ERROR_WINHTTP_SHUTDOWN => 0x80072EEC as u32,
            WIN32::WININET_E_INCORRECT_USER_NAME => 0x80072EED as u32,
            WIN32::ERROR_INTERNET_INCORRECT_USER_NAME => 0x80072EED as u32,
            WIN32::WININET_E_INCORRECT_PASSWORD => 0x80072EEE as u32,
            WIN32::ERROR_INTERNET_INCORRECT_PASSWORD => 0x80072EEE as u32,
            WIN32::WININET_E_LOGIN_FAILURE => 0x80072EEF as u32,
            WIN32::ERROR_INTERNET_LOGIN_FAILURE => 0x80072EEF as u32,
            WIN32::ERROR_WINHTTP_LOGIN_FAILURE => 0x80072EEF as u32,
            WIN32::WININET_E_INVALID_OPERATION => 0x80072EF0 as u32,
            WIN32::ERROR_INTERNET_INVALID_OPERATION => 0x80072EF0 as u32,
            WIN32::WININET_E_OPERATION_CANCELLED => 0x80072EF1 as u32,
            WIN32::ERROR_INTERNET_OPERATION_CANCELLED => 0x80072EF1 as u32,
            WIN32::ERROR_WINHTTP_OPERATION_CANCELLED => 0x80072EF1 as u32,
            WIN32::WININET_E_INCORRECT_HANDLE_TYPE => 0x80072EF2 as u32,
            WIN32::ERROR_INTERNET_INCORRECT_HANDLE_TYPE => 0x80072EF2 as u32,
            WIN32::WININET_E_INCORRECT_HANDLE_STATE => 0x80072EF3 as u32,
            WIN32::ERROR_INTERNET_INCORRECT_HANDLE_STATE => 0x80072EF3 as u32,
            WIN32::ERROR_WINHTTP_INCORRECT_HANDLE_STATE => 0x80072EF3 as u32,
            WIN32::WININET_E_NOT_PROXY_REQUEST => 0x80072EF4 as u32,
            WIN32::ERROR_INTERNET_NOT_PROXY_REQUEST => 0x80072EF4 as u32,
            WIN32::WININET_E_REGISTRY_VALUE_NOT_FOUND => 0x80072EF5 as u32,
            WIN32::ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND => 0x80072EF5 as u32,
            WIN32::WININET_E_BAD_REGISTRY_PARAMETER => 0x80072EF6 as u32,
            WIN32::ERROR_INTERNET_BAD_REGISTRY_PARAMETER => 0x80072EF6 as u32,
            WIN32::WININET_E_NO_DIRECT_ACCESS => 0x80072EF7 as u32,
            WIN32::ERROR_INTERNET_NO_DIRECT_ACCESS => 0x80072EF7 as u32,
            WIN32::WININET_E_NO_CONTEXT => 0x80072EF8 as u32,
            WIN32::ERROR_INTERNET_NO_CONTEXT => 0x80072EF8 as u32,
            WIN32::WININET_E_NO_CALLBACK => 0x80072EF9 as u32,
            WIN32::ERROR_INTERNET_NO_CALLBACK => 0x80072EF9 as u32,
            WIN32::WININET_E_REQUEST_PENDING => 0x80072EFA as u32,
            WIN32::ERROR_INTERNET_REQUEST_PENDING => 0x80072EFA as u32,
            WIN32::WININET_E_INCORRECT_FORMAT => 0x80072EFB as u32,
            WIN32::ERROR_INTERNET_INCORRECT_FORMAT => 0x80072EFB as u32,
            WIN32::WININET_E_ITEM_NOT_FOUND => 0x80072EFC as u32,
            WIN32::ERROR_INTERNET_ITEM_NOT_FOUND => 0x80072EFC as u32,
            WIN32::WININET_E_CANNOT_CONNECT => 0x80072EFD as u32,
            WIN32::ERROR_INTERNET_CANNOT_CONNECT => 0x80072EFD as u32,
            WIN32::ERROR_WINHTTP_CANNOT_CONNECT => 0x80072EFD as u32,
            WIN32::WININET_E_CONNECTION_ABORTED => 0x80072EFE as u32,
            WIN32::ERROR_INTERNET_CONNECTION_ABORTED => 0x80072EFE as u32,
            WIN32::ERROR_WINHTTP_CONNECTION_ABORTED => 0x80072EFE as u32,
            WIN32::WININET_E_CONNECTION_RESET => 0x80072EFF as u32,
            WIN32::ERROR_INTERNET_CONNECTION_RESET => 0x80072EFF as u32,
            WIN32::ERROR_WINHTTP_CONNECTION_RESET => 0x80072EFF as u32,
            WIN32::WININET_E_FORCE_RETRY => 0x80072F00 as u32,
            WIN32::ERROR_INTERNET_FORCE_RETRY => 0x80072F00 as u32,
            WIN32::WININET_E_INVALID_PROXY_REQUEST => 0x80072F01 as u32,
            WIN32::ERROR_INTERNET_INVALID_PROXY_REQUEST => 0x80072F01 as u32,
            WIN32::WININET_E_NEED_UI => 0x80072F02 as u32,
            WIN32::ERROR_INTERNET_NEED_UI => 0x80072F02 as u32,
            WIN32::WININET_E_HANDLE_EXISTS => 0x80072F04 as u32,
            WIN32::ERROR_INTERNET_HANDLE_EXISTS => 0x80072F04 as u32,
            WIN32::WININET_E_SEC_CERT_DATE_INVALID => 0x80072F05 as u32,
            WIN32::ERROR_INTERNET_SEC_CERT_DATE_INVALID => 0x80072F05 as u32,
            WIN32::ERROR_WINHTTP_SEC_CERT_DATE_INVALID => 0x80072F05 as u32,
            WIN32::WININET_E_SEC_CERT_CN_INVALID => 0x80072F06 as u32,
            WIN32::ERROR_INTERNET_SEC_CERT_CN_INVALID => 0x80072F06 as u32,
            WIN32::ERROR_WINHTTP_SEC_CERT_CN_INVALID => 0x80072F06 as u32,
            WIN32::WININET_E_HTTP_TO_HTTPS_ON_REDIR => 0x80072F07 as u32,
            WIN32::ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR => 0x80072F07 as u32,
            WIN32::WININET_E_HTTPS_TO_HTTP_ON_REDIR => 0x80072F08 as u32,
            WIN32::ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR => 0x80072F08 as u32,
            WIN32::WININET_E_MIXED_SECURITY => 0x80072F09 as u32,
            WIN32::ERROR_INTERNET_MIXED_SECURITY => 0x80072F09 as u32,
            WIN32::WININET_E_CHG_POST_IS_NON_SECURE => 0x80072F0A as u32,
            WIN32::ERROR_INTERNET_CHG_POST_IS_NON_SECURE => 0x80072F0A as u32,
            WIN32::WININET_E_POST_IS_NON_SECURE => 0x80072F0B as u32,
            WIN32::ERROR_INTERNET_POST_IS_NON_SECURE => 0x80072F0B as u32,
            WIN32::WININET_E_CLIENT_AUTH_CERT_NEEDED => 0x80072F0C as u32,
            WIN32::ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED => 0x80072F0C as u32,
            WIN32::ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED => 0x80072F0C as u32,
            WIN32::WININET_E_INVALID_CA => 0x80072F0D as u32,
            WIN32::ERROR_INTERNET_INVALID_CA => 0x80072F0D as u32,
            WIN32::ERROR_WINHTTP_INVALID_CA => 0x80072F0D as u32,
            WIN32::WININET_E_CLIENT_AUTH_NOT_SETUP => 0x80072F0E as u32,
            WIN32::ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP => 0x80072F0E as u32,
            WIN32::WININET_E_ASYNC_THREAD_FAILED => 0x80072F0F as u32,
            WIN32::ERROR_INTERNET_ASYNC_THREAD_FAILED => 0x80072F0F as u32,
            WIN32::WININET_E_REDIRECT_SCHEME_CHANGE => 0x80072F10 as u32,
            WIN32::ERROR_INTERNET_REDIRECT_SCHEME_CHANGE => 0x80072F10 as u32,
            WIN32::WININET_E_DIALOG_PENDING => 0x80072F11 as u32,
            WIN32::ERROR_INTERNET_DIALOG_PENDING => 0x80072F11 as u32,
            WIN32::WININET_E_RETRY_DIALOG => 0x80072F12 as u32,
            WIN32::ERROR_INTERNET_RETRY_DIALOG => 0x80072F12 as u32,
            WIN32::WININET_E_NO_NEW_CONTAINERS => 0x80072F13 as u32,
            WIN32::WININET_E_HTTPS_HTTP_SUBMIT_REDIR => 0x80072F14 as u32,
            WIN32::ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR => 0x80072F14 as u32,
            WIN32::ERROR_INTERNET_INSERT_CDROM => 0x80072F15 as u32,
            WIN32::ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED => 0x80072F16 as u32,
            WIN32::WININET_E_SEC_CERT_ERRORS => 0x80072F17 as u32,
            WIN32::ERROR_INTERNET_SEC_CERT_ERRORS => 0x80072F17 as u32,
            WIN32::ERROR_INTERNET_SEC_CERT_NO_REV => 0x80072F18 as u32,
            WIN32::WININET_E_SEC_CERT_REV_FAILED => 0x80072F19 as u32,
            WIN32::ERROR_INTERNET_SEC_CERT_REV_FAILED => 0x80072F19 as u32,
            WIN32::ERROR_WINHTTP_NO_CM_CONNECTION => 0x80072F30 as u32,
            WIN32::ERROR_FTP_TRANSFER_IN_PROGRESS => 0x80072F4E as u32,
            WIN32::ERROR_FTP_DROPPED => 0x80072F4F as u32,
            WIN32::ERROR_FTP_NO_PASSIVE_MODE => 0x80072F50 as u32,
            WIN32::ERROR_GOPHER_PROTOCOL_ERROR => 0x80072F62 as u32,
            WIN32::ERROR_GOPHER_NOT_FILE => 0x80072F63 as u32,
            WIN32::ERROR_GOPHER_DATA_ERROR => 0x80072F64 as u32,
            WIN32::ERROR_GOPHER_END_OF_DATA => 0x80072F65 as u32,
            WIN32::ERROR_GOPHER_INVALID_LOCATOR => 0x80072F66 as u32,
            WIN32::ERROR_GOPHER_INCORRECT_LOCATOR_TYPE => 0x80072F67 as u32,
            WIN32::ERROR_GOPHER_NOT_GOPHER_PLUS => 0x80072F68 as u32,
            WIN32::ERROR_GOPHER_ATTRIBUTE_NOT_FOUND => 0x80072F69 as u32,
            WIN32::ERROR_GOPHER_UNKNOWN_LOCATOR => 0x80072F6A as u32,
            WIN32::WININET_E_HEADER_NOT_FOUND => 0x80072F76 as u32,
            WIN32::ERROR_HTTP_HEADER_NOT_FOUND => 0x80072F76 as u32,
            WIN32::ERROR_WINHTTP_HEADER_NOT_FOUND => 0x80072F76 as u32,
            WIN32::WININET_E_DOWNLEVEL_SERVER => 0x80072F77 as u32,
            WIN32::ERROR_HTTP_DOWNLEVEL_SERVER => 0x80072F77 as u32,
            WIN32::WININET_E_INVALID_SERVER_RESPONSE => 0x80072F78 as u32,
            WIN32::ERROR_HTTP_INVALID_SERVER_RESPONSE => 0x80072F78 as u32,
            WIN32::ERROR_WINHTTP_INVALID_SERVER_RESPONSE => 0x80072F78 as u32,
            WIN32::WININET_E_INVALID_HEADER => 0x80072F79 as u32,
            WIN32::ERROR_HTTP_INVALID_HEADER => 0x80072F79 as u32,
            WIN32::WININET_E_INVALID_QUERY_REQUEST => 0x80072F7A as u32,
            WIN32::ERROR_HTTP_INVALID_QUERY_REQUEST => 0x80072F7A as u32,
            WIN32::ERROR_WINHTTP_INVALID_QUERY_REQUEST => 0x80072F7A as u32,
            WIN32::WININET_E_HEADER_ALREADY_EXISTS => 0x80072F7B as u32,
            WIN32::ERROR_HTTP_HEADER_ALREADY_EXISTS => 0x80072F7B as u32,
            WIN32::WININET_E_REDIRECT_FAILED => 0x80072F7C as u32,
            WIN32::ERROR_HTTP_REDIRECT_FAILED => 0x80072F7C as u32,
            WIN32::ERROR_WINHTTP_REDIRECT_FAILED => 0x80072F7C as u32,
            WIN32::WININET_E_SECURITY_CHANNEL_ERROR => 0x80072F7D as u32,
            WIN32::ERROR_INTERNET_SECURITY_CHANNEL_ERROR => 0x80072F7D as u32,
            WIN32::ERROR_WINHTTP_SECURE_CHANNEL_ERROR => 0x80072F7D as u32,
            WIN32::WININET_E_UNABLE_TO_CACHE_FILE => 0x80072F7E as u32,
            WIN32::ERROR_INTERNET_UNABLE_TO_CACHE_FILE => 0x80072F7E as u32,
            WIN32::WININET_E_TCPIP_NOT_INSTALLED => 0x80072F7F as u32,
            WIN32::ERROR_INTERNET_TCPIP_NOT_INSTALLED => 0x80072F7F as u32,
            WIN32::WININET_E_NOT_REDIRECTED => 0x80072F80 as u32,
            WIN32::ERROR_HTTP_NOT_REDIRECTED => 0x80072F80 as u32,
            WIN32::WININET_E_COOKIE_NEEDS_CONFIRMATION => 0x80072F81 as u32,
            WIN32::ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION => 0x80072F81 as u32,
            WIN32::WININET_E_COOKIE_DECLINED => 0x80072F82 as u32,
            WIN32::ERROR_HTTP_COOKIE_DECLINED => 0x80072F82 as u32,
            WIN32::WININET_E_DISCONNECTED => 0x80072F83 as u32,
            WIN32::ERROR_INTERNET_DISCONNECTED => 0x80072F83 as u32,
            WIN32::WININET_E_SERVER_UNREACHABLE => 0x80072F84 as u32,
            WIN32::ERROR_INTERNET_SERVER_UNREACHABLE => 0x80072F84 as u32,
            WIN32::WININET_E_PROXY_SERVER_UNREACHABLE => 0x80072F85 as u32,
            WIN32::ERROR_INTERNET_PROXY_SERVER_UNREACHABLE => 0x80072F85 as u32,
            WIN32::WININET_E_BAD_AUTO_PROXY_SCRIPT => 0x80072F86 as u32,
            WIN32::ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT => 0x80072F86 as u32,
            WIN32::WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT => 0x80072F87 as u32,
            WIN32::ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT => 0x80072F87 as u32,
            WIN32::WININET_E_REDIRECT_NEEDS_CONFIRMATION => 0x80072F88 as u32,
            WIN32::ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION => 0x80072F88 as u32,
            WIN32::WININET_E_SEC_INVALID_CERT => 0x80072F89 as u32,
            WIN32::ERROR_INTERNET_SEC_INVALID_CERT => 0x80072F89 as u32,
            WIN32::ERROR_WINHTTP_SECURE_INVALID_CERT => 0x80072F89 as u32,
            WIN32::WININET_E_SEC_CERT_REVOKED => 0x80072F8A as u32,
            WIN32::ERROR_INTERNET_SEC_CERT_REVOKED => 0x80072F8A as u32,
            WIN32::WININET_E_FAILED_DUETOSECURITYCHECK => 0x80072F8B as u32,
            WIN32::ERROR_INTERNET_FAILED_DUETOSECURITYCHECK => 0x80072F8B as u32,
            WIN32::WININET_E_NOT_INITIALIZED => 0x80072F8C as u32,
            WIN32::ERROR_INTERNET_NOT_INITIALIZED => 0x80072F8C as u32,
            WIN32::ERROR_INTERNET_NEED_MSN_SSPI_PKG => 0x80072F8D as u32,
            WIN32::WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY => 0x80072F8E as u32,
            WIN32::ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY => 0x80072F8E as u32,
            WIN32::WININET_E_DECODING_FAILED => 0x80072F8F as u32,
            WIN32::ERROR_INTERNET_DECODING_FAILED => 0x80072F8F as u32,
            WIN32::ERROR_WINHTTP_SECURE_FAILURE => 0x80072F8F as u32,
            WIN32::ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW => 0x80072F98 as u32,
            WIN32::ERROR_IPSEC_QM_POLICY_EXISTS => 0x800732C8 as u32,
            WIN32::ERROR_IPSEC_QM_POLICY_NOT_FOUND => 0x800732C9 as u32,
            WIN32::ERROR_IPSEC_QM_POLICY_IN_USE => 0x800732CA as u32,
            WIN32::ERROR_IPSEC_MM_POLICY_EXISTS => 0x800732CB as u32,
            WIN32::ERROR_IPSEC_MM_POLICY_NOT_FOUND => 0x800732CC as u32,
            WIN32::ERROR_IPSEC_MM_POLICY_IN_USE => 0x800732CD as u32,
            WIN32::ERROR_IPSEC_MM_FILTER_EXISTS => 0x800732CE as u32,
            WIN32::ERROR_IPSEC_MM_FILTER_NOT_FOUND => 0x800732CF as u32,
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_EXISTS => 0x800732D0 as u32,
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND => 0x800732D1 as u32,
            WIN32::ERROR_IPSEC_MM_AUTH_EXISTS => 0x800732D2 as u32,
            WIN32::ERROR_IPSEC_MM_AUTH_NOT_FOUND => 0x800732D3 as u32,
            WIN32::ERROR_IPSEC_MM_AUTH_IN_USE => 0x800732D4 as u32,
            WIN32::ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND => 0x800732D5 as u32,
            WIN32::ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND => 0x800732D6 as u32,
            WIN32::ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND => 0x800732D7 as u32,
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_EXISTS => 0x800732D8 as u32,
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND => 0x800732D9 as u32,
            WIN32::ERROR_IPSEC_MM_FILTER_PENDING_DELETION => 0x800732DA as u32,
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION => 0x800732DB as u32,
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION => 0x800732DB as u32,
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION => 0x800732DC as u32,
            WIN32::ERROR_IPSEC_MM_POLICY_PENDING_DELETION => 0x800732DD as u32,
            WIN32::ERROR_IPSEC_MM_POLICY_PENDING_ELETION => 0x800732DD as u32,
            WIN32::ERROR_IPSEC_MM_AUTH_PENDING_DELETION => 0x800732DE as u32,
            WIN32::ERROR_IPSEC_QM_POLICY_PENDING_DELETION => 0x800732DF as u32,
            WIN32::WARNING_IPSEC_MM_POLICY_PRUNED => 0x800732E0 as u32,
            WIN32::WARNING_IPSEC_QM_POLICY_PRUNED => 0x800732E1 as u32,
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_BEGIN => 0x800735E8 as u32,
            WIN32::ERROR_IPSEC_IKE_AUTH_FAIL => 0x800735E9 as u32,
            WIN32::ERROR_IPSEC_IKE_ATTRIB_FAIL => 0x800735EA as u32,
            WIN32::ERROR_IPSEC_IKE_NEGOTIATION_PENDING => 0x800735EB as u32,
            WIN32::ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR => 0x800735EC as u32,
            WIN32::ERROR_IPSEC_IKE_TIMED_OUT => 0x800735ED as u32,
            WIN32::ERROR_IPSEC_IKE_NO_CERT => 0x800735EE as u32,
            WIN32::ERROR_IPSEC_IKE_SA_DELETED => 0x800735EF as u32,
            WIN32::ERROR_IPSEC_IKE_SA_REAPED => 0x800735F0 as u32,
            WIN32::ERROR_IPSEC_IKE_MM_ACQUIRE_DROP => 0x800735F1 as u32,
            WIN32::ERROR_IPSEC_IKE_QM_ACQUIRE_DROP => 0x800735F2 as u32,
            WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_MM => 0x800735F3 as u32,
            WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM => 0x800735F4 as u32,
            WIN32::ERROR_IPSEC_IKE_DROP_NO_RESPONSE => 0x800735F5 as u32,
            WIN32::ERROR_IPSEC_IKE_MM_DELAY_DROP => 0x800735F6 as u32,
            WIN32::ERROR_IPSEC_IKE_QM_DELAY_DROP => 0x800735F7 as u32,
            WIN32::ERROR_IPSEC_IKE_ERROR => 0x800735F8 as u32,
            WIN32::ERROR_IPSEC_IKE_CRL_FAILED => 0x800735F9 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_KEY_USAGE => 0x800735FA as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_CERT_TYPE => 0x800735FB as u32,
            WIN32::ERROR_IPSEC_IKE_NO_PRIVATE_KEY => 0x800735FC as u32,
            WIN32::ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY => 0x800735FD as u32,
            WIN32::ERROR_IPSEC_IKE_DH_FAIL => 0x800735FE as u32,
            WIN32::ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED => 0x800735FF as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_HEADER => 0x80073600 as u32,
            WIN32::ERROR_IPSEC_IKE_NO_POLICY => 0x80073601 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_SIGNATURE => 0x80073602 as u32,
            WIN32::ERROR_IPSEC_IKE_KERBEROS_ERROR => 0x80073603 as u32,
            WIN32::ERROR_IPSEC_IKE_NO_PUBLIC_KEY => 0x80073604 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR => 0x80073605 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SA => 0x80073606 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_PROP => 0x80073607 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_TRANS => 0x80073608 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_KE => 0x80073609 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_ID => 0x8007360A as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT => 0x8007360B as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ => 0x8007360C as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_HASH => 0x8007360D as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SIG => 0x8007360E as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NONCE => 0x8007360F as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY => 0x80073610 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_DELETE => 0x80073611 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR => 0x80073612 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_PAYLOAD => 0x80073613 as u32,
            WIN32::ERROR_IPSEC_IKE_LOAD_SOFT_SA => 0x80073614 as u32,
            WIN32::ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN => 0x80073615 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_COOKIE => 0x80073616 as u32,
            WIN32::ERROR_IPSEC_IKE_NO_PEER_CERT => 0x80073617 as u32,
            WIN32::ERROR_IPSEC_IKE_PEER_CRL_FAILED => 0x80073618 as u32,
            WIN32::ERROR_IPSEC_IKE_POLICY_CHANGE => 0x80073619 as u32,
            WIN32::ERROR_IPSEC_IKE_NO_MM_POLICY => 0x8007361A as u32,
            WIN32::ERROR_IPSEC_IKE_NOTCBPRIV => 0x8007361B as u32,
            WIN32::ERROR_IPSEC_IKE_SECLOADFAIL => 0x8007361C as u32,
            WIN32::ERROR_IPSEC_IKE_FAILSSPINIT => 0x8007361D as u32,
            WIN32::ERROR_IPSEC_IKE_FAILQUERYSSP => 0x8007361E as u32,
            WIN32::ERROR_IPSEC_IKE_SRVACQFAIL => 0x8007361F as u32,
            WIN32::ERROR_IPSEC_IKE_SRVQUERYCRED => 0x80073620 as u32,
            WIN32::ERROR_IPSEC_IKE_GETSPIFAIL => 0x80073621 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_FILTER => 0x80073622 as u32,
            WIN32::ERROR_IPSEC_IKE_OUT_OF_MEMORY => 0x80073623 as u32,
            WIN32::ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED => 0x80073624 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_POLICY => 0x80073625 as u32,
            WIN32::ERROR_IPSEC_IKE_UNKNOWN_DOI => 0x80073626 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_SITUATION => 0x80073627 as u32,
            WIN32::ERROR_IPSEC_IKE_DH_FAILURE => 0x80073628 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_GROUP => 0x80073629 as u32,
            WIN32::ERROR_IPSEC_IKE_ENCRYPT => 0x8007362A as u32,
            WIN32::ERROR_IPSEC_IKE_DECRYPT => 0x8007362B as u32,
            WIN32::ERROR_IPSEC_IKE_POLICY_MATCH => 0x8007362C as u32,
            WIN32::ERROR_IPSEC_IKE_UNSUPPORTED_ID => 0x8007362D as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH => 0x8007362E as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH_ALG => 0x8007362F as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH_SIZE => 0x80073630 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG => 0x80073631 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_ALG => 0x80073632 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_SIG => 0x80073633 as u32,
            WIN32::ERROR_IPSEC_IKE_LOAD_FAILED => 0x80073634 as u32,
            WIN32::ERROR_IPSEC_IKE_RPC_DELETE => 0x80073635 as u32,
            WIN32::ERROR_IPSEC_IKE_BENIGN_REINIT => 0x80073636 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY => 0x80073637 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION => 0x80073638 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN => 0x80073639 as u32,
            WIN32::ERROR_IPSEC_IKE_MM_LIMIT => 0x8007363A as u32,
            WIN32::ERROR_IPSEC_IKE_NEGOTIATION_DISABLED => 0x8007363B as u32,
            WIN32::ERROR_IPSEC_IKE_QM_LIMIT => 0x8007363C as u32,
            WIN32::ERROR_IPSEC_IKE_MM_EXPIRED => 0x8007363D as u32,
            WIN32::ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID => 0x8007363E as u32,
            WIN32::ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH => 0x8007363F as u32,
            WIN32::ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID => 0x80073640 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD => 0x80073641 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_UMATTS => 0x80073641 as u32,
            WIN32::ERROR_IPSEC_IKE_DOS_COOKIE_SENT => 0x80073642 as u32,
            WIN32::ERROR_IPSEC_IKE_SHUTTING_DOWN => 0x80073643 as u32,
            WIN32::ERROR_IPSEC_IKE_CGA_AUTH_FAILED => 0x80073644 as u32,
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NATOA => 0x80073645 as u32,
            WIN32::ERROR_IPSEC_IKE_INVALID_MM_FOR_QM => 0x80073646 as u32,
            WIN32::ERROR_IPSEC_IKE_QM_EXPIRED => 0x80073647 as u32,
            WIN32::ERROR_IPSEC_IKE_TOO_MANY_FILTERS => 0x80073648 as u32,
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_END => 0x80073649 as u32,
            WIN32::ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL => 0x8007364A as u32,
            WIN32::ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE => 0x8007364B as u32,
            WIN32::ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING => 0x8007364C as u32,
            WIN32::ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING => 0x8007364D as u32,
            WIN32::ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS => 0x8007364E as u32,
            WIN32::ERROR_IPSEC_IKE_RATELIMIT_DROP => 0x8007364F as u32,
            WIN32::ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE => 0x80073650 as u32,
            WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE => 0x80073651 as u32,
            WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE => 0x80073652 as u32,
            WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY => 0x80073653 as u32,
            WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE => 0x80073654 as u32,
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END => 0x80073655 as u32,
            WIN32::ERROR_IPSEC_BAD_SPI => 0x80073656 as u32,
            WIN32::ERROR_IPSEC_SA_LIFETIME_EXPIRED => 0x80073657 as u32,
            WIN32::ERROR_IPSEC_WRONG_SA => 0x80073658 as u32,
            WIN32::ERROR_IPSEC_REPLAY_CHECK_FAILED => 0x80073659 as u32,
            WIN32::ERROR_IPSEC_INVALID_PACKET => 0x8007365A as u32,
            WIN32::ERROR_IPSEC_INTEGRITY_CHECK_FAILED => 0x8007365B as u32,
            WIN32::ERROR_IPSEC_CLEAR_TEXT_DROP => 0x8007365C as u32,
            WIN32::ERROR_IPSEC_AUTH_FIREWALL_DROP => 0x8007365D as u32,
            WIN32::ERROR_IPSEC_THROTTLE_DROP => 0x8007365E as u32,
            WIN32::ERROR_IPSEC_DOSP_BLOCK => 0x80073665 as u32,
            WIN32::ERROR_IPSEC_DOSP_RECEIVED_MULTICAST => 0x80073666 as u32,
            WIN32::ERROR_IPSEC_DOSP_INVALID_PACKET => 0x80073667 as u32,
            WIN32::ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED => 0x80073668 as u32,
            WIN32::ERROR_IPSEC_DOSP_MAX_ENTRIES => 0x80073669 as u32,
            WIN32::ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED => 0x8007366A as u32,
            WIN32::ERROR_IPSEC_DOSP_NOT_INSTALLED => 0x8007366B as u32,
            WIN32::ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES => 0x8007366C as u32,
            WIN32::ERROR_SXS_SECTION_NOT_FOUND => 0x800736B0 as u32,
            WIN32::ERROR_SXS_CANT_GEN_ACTCTX => 0x800736B1 as u32,
            WIN32::ERROR_SXS_INVALID_ACTCTXDATA_FORMAT => 0x800736B2 as u32,
            WIN32::ERROR_SXS_ASSEMBLY_NOT_FOUND => 0x800736B3 as u32,
            WIN32::ERROR_SXS_MANIFEST_FORMAT_ERROR => 0x800736B4 as u32,
            WIN32::ERROR_SXS_MANIFEST_PARSE_ERROR => 0x800736B5 as u32,
            WIN32::ERROR_SXS_ACTIVATION_CONTEXT_DISABLED => 0x800736B6 as u32,
            WIN32::ERROR_SXS_KEY_NOT_FOUND => 0x800736B7 as u32,
            WIN32::ERROR_SXS_VERSION_CONFLICT => 0x800736B8 as u32,
            WIN32::ERROR_SXS_WRONG_SECTION_TYPE => 0x800736B9 as u32,
            WIN32::ERROR_SXS_THREAD_QUERIES_DISABLED => 0x800736BA as u32,
            WIN32::ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET => 0x800736BB as u32,
            WIN32::ERROR_SXS_UNKNOWN_ENCODING_GROUP => 0x800736BC as u32,
            WIN32::ERROR_SXS_UNKNOWN_ENCODING => 0x800736BD as u32,
            WIN32::ERROR_SXS_INVALID_XML_NAMESPACE_URI => 0x800736BE as u32,
            WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED => 0x800736BF as u32,
            WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED => 0x800736BF as u32,
            WIN32::ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED => 0x800736C0 as u32,
            WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE => 0x800736C1 as u32,
            WIN32::ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE => 0x800736C2 as u32,
            WIN32::ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE => 0x800736C3 as u32,
            WIN32::ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT => 0x800736C4 as u32,
            WIN32::ERROR_SXS_DUPLICATE_DLL_NAME => 0x800736C5 as u32,
            WIN32::ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME => 0x800736C6 as u32,
            WIN32::ERROR_SXS_DUPLICATE_CLSID => 0x800736C7 as u32,
            WIN32::ERROR_SXS_DUPLICATE_IID => 0x800736C8 as u32,
            WIN32::ERROR_SXS_DUPLICATE_TLBID => 0x800736C9 as u32,
            WIN32::ERROR_SXS_DUPLICATE_PROGID => 0x800736CA as u32,
            WIN32::ERROR_SXS_DUPLICATE_ASSEMBLY_NAME => 0x800736CB as u32,
            WIN32::ERROR_SXS_FILE_HASH_MISMATCH => 0x800736CC as u32,
            WIN32::ERROR_SXS_POLICY_PARSE_ERROR => 0x800736CD as u32,
            WIN32::ERROR_SXS_XML_E_MISSINGQUOTE => 0x800736CE as u32,
            WIN32::ERROR_SXS_XML_E_COMMENTSYNTAX => 0x800736CF as u32,
            WIN32::ERROR_SXS_XML_E_BADSTARTNAMECHAR => 0x800736D0 as u32,
            WIN32::ERROR_SXS_XML_E_BADNAMECHAR => 0x800736D1 as u32,
            WIN32::ERROR_SXS_XML_E_BADCHARINSTRING => 0x800736D2 as u32,
            WIN32::ERROR_SXS_XML_E_XMLDECLSYNTAX => 0x800736D3 as u32,
            WIN32::ERROR_SXS_XML_E_BADCHARDATA => 0x800736D4 as u32,
            WIN32::ERROR_SXS_XML_E_MISSINGWHITESPACE => 0x800736D5 as u32,
            WIN32::ERROR_SXS_XML_E_EXPECTINGTAGEND => 0x800736D6 as u32,
            WIN32::ERROR_SXS_XML_E_MISSINGSEMICOLON => 0x800736D7 as u32,
            WIN32::ERROR_SXS_XML_E_UNBALANCEDPAREN => 0x800736D8 as u32,
            WIN32::ERROR_SXS_XML_E_INTERNALERROR => 0x800736D9 as u32,
            WIN32::ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE => 0x800736DA as u32,
            WIN32::ERROR_SXS_XML_E_INCOMPLETE_ENCODING => 0x800736DB as u32,
            WIN32::ERROR_SXS_XML_E_MISSING_PAREN => 0x800736DC as u32,
            WIN32::ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE => 0x800736DD as u32,
            WIN32::ERROR_SXS_XML_E_MULTIPLE_COLONS => 0x800736DE as u32,
            WIN32::ERROR_SXS_XML_E_INVALID_DECIMAL => 0x800736DF as u32,
            WIN32::ERROR_SXS_XML_E_INVALID_HEXIDECIMAL => 0x800736E0 as u32,
            WIN32::ERROR_SXS_XML_E_INVALID_UNICODE => 0x800736E1 as u32,
            WIN32::ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK => 0x800736E2 as u32,
            WIN32::ERROR_SXS_XML_E_UNEXPECTEDENDTAG => 0x800736E3 as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDTAG => 0x800736E4 as u32,
            WIN32::ERROR_SXS_XML_E_DUPLICATEATTRIBUTE => 0x800736E5 as u32,
            WIN32::ERROR_SXS_XML_E_MULTIPLEROOTS => 0x800736E6 as u32,
            WIN32::ERROR_SXS_XML_E_INVALIDATROOTLEVEL => 0x800736E7 as u32,
            WIN32::ERROR_SXS_XML_E_BADXMLDECL => 0x800736E8 as u32,
            WIN32::ERROR_SXS_XML_E_MISSINGROOT => 0x800736E9 as u32,
            WIN32::ERROR_SXS_XML_E_UNEXPECTEDEOF => 0x800736EA as u32,
            WIN32::ERROR_SXS_XML_E_BADPEREFINSUBSET => 0x800736EB as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDSTARTTAG => 0x800736EC as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDENDTAG => 0x800736ED as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDSTRING => 0x800736EE as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDCOMMENT => 0x800736EF as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDDECL => 0x800736F0 as u32,
            WIN32::ERROR_SXS_XML_E_UNCLOSEDCDATA => 0x800736F1 as u32,
            WIN32::ERROR_SXS_XML_E_RESERVEDNAMESPACE => 0x800736F2 as u32,
            WIN32::ERROR_SXS_XML_E_INVALIDENCODING => 0x800736F3 as u32,
            WIN32::ERROR_SXS_XML_E_INVALIDSWITCH => 0x800736F4 as u32,
            WIN32::ERROR_SXS_XML_E_BADXMLCASE => 0x800736F5 as u32,
            WIN32::ERROR_SXS_XML_E_INVALID_STANDALONE => 0x800736F6 as u32,
            WIN32::ERROR_SXS_XML_E_UNEXPECTED_STANDALONE => 0x800736F7 as u32,
            WIN32::ERROR_SXS_XML_E_INVALID_VERSION => 0x800736F8 as u32,
            WIN32::ERROR_SXS_XML_E_MISSINGEQUALS => 0x800736F9 as u32,
            WIN32::ERROR_SXS_PROTECTION_RECOVERY_FAILED => 0x800736FA as u32,
            WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT => 0x800736FB as u32,
            WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT => 0x800736FB as u32,
            WIN32::ERROR_SXS_PROTECTION_CATALOG_NOT_VALID => 0x800736FC as u32,
            WIN32::ERROR_SXS_UNTRANSLATABLE_HRESULT => 0x800736FD as u32,
            WIN32::ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING => 0x800736FE as u32,
            WIN32::ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE => 0x800736FF as u32,
            WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME => 0x80073700 as u32,
            WIN32::ERROR_SXS_ASSEMBLY_MISSING => 0x80073701 as u32,
            WIN32::ERROR_SXS_CORRUPT_ACTIVATION_STACK => 0x80073702 as u32,
            WIN32::ERROR_SXS_CORRUPTION => 0x80073703 as u32,
            WIN32::ERROR_SXS_EARLY_DEACTIVATION => 0x80073704 as u32,
            WIN32::ERROR_SXS_INVALID_DEACTIVATION => 0x80073705 as u32,
            WIN32::ERROR_SXS_MULTIPLE_DEACTIVATION => 0x80073706 as u32,
            WIN32::ERROR_SXS_PROCESS_TERMINATION_REQUESTED => 0x80073707 as u32,
            WIN32::ERROR_SXS_RELEASE_ACTIVATION_CONTEXT => 0x80073708 as u32,
            WIN32::ERROR_SXS_RELEASE_ACTIVATION_ONTEXT => 0x80073708 as u32,
            WIN32::ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY => 0x80073709 as u32,
            WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE => 0x8007370A as u32,
            WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME => 0x8007370B as u32,
            WIN32::ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE => 0x8007370C as u32,
            WIN32::ERROR_SXS_IDENTITY_PARSE_ERROR => 0x8007370D as u32,
            WIN32::ERROR_MALFORMED_SUBSTITUTION_STRING => 0x8007370E as u32,
            WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN => 0x8007370F as u32,
            WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN => 0x8007370F as u32,
            WIN32::ERROR_UNMAPPED_SUBSTITUTION_STRING => 0x80073710 as u32,
            WIN32::ERROR_SXS_ASSEMBLY_NOT_LOCKED => 0x80073711 as u32,
            WIN32::ERROR_SXS_COMPONENT_STORE_CORRUPT => 0x80073712 as u32,
            WIN32::ERROR_ADVANCED_INSTALLER_FAILED => 0x80073713 as u32,
            WIN32::ERROR_XML_ENCODING_MISMATCH => 0x80073714 as u32,
            WIN32::ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT => 0x80073715 as u32,
            WIN32::ERROR_SXS_IDENTITIES_DIFFERENT => 0x80073716 as u32,
            WIN32::ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT => 0x80073717 as u32,
            WIN32::ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY => 0x80073718 as u32,
            WIN32::ERROR_SXS_MANIFEST_TOO_BIG => 0x80073719 as u32,
            WIN32::ERROR_SXS_SETTING_NOT_REGISTERED => 0x8007371A as u32,
            WIN32::ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE => 0x8007371B as u32,
            WIN32::ERROR_SMI_PRIMITIVE_INSTALLER_FAILED => 0x8007371C as u32,
            WIN32::ERROR_GENERIC_COMMAND_FAILED => 0x8007371D as u32,
            WIN32::ERROR_SXS_FILE_HASH_MISSING => 0x8007371E as u32,
            WIN32::ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS => 0x8007371F as u32,
            WIN32::ERROR_EVT_INVALID_CHANNEL_PATH => 0x80073A98 as u32,
            WIN32::ERROR_EVT_INVALID_QUERY => 0x80073A99 as u32,
            WIN32::ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND => 0x80073A9A as u32,
            WIN32::ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND => 0x80073A9B as u32,
            WIN32::ERROR_EVT_INVALID_PUBLISHER_NAME => 0x80073A9C as u32,
            WIN32::ERROR_EVT_INVALID_EVENT_DATA => 0x80073A9D as u32,
            WIN32::ERROR_EVT_CHANNEL_NOT_FOUND => 0x80073A9F as u32,
            WIN32::ERROR_EVT_MALFORMED_XML_TEXT => 0x80073AA0 as u32,
            WIN32::ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL => 0x80073AA1 as u32,
            WIN32::ERROR_EVT_CONFIGURATION_ERROR => 0x80073AA2 as u32,
            WIN32::ERROR_EVT_QUERY_RESULT_STALE => 0x80073AA3 as u32,
            WIN32::ERROR_EVT_QUERY_RESULT_INVALID_POSITION => 0x80073AA4 as u32,
            WIN32::ERROR_EVT_NON_VALIDATING_MSXML => 0x80073AA5 as u32,
            WIN32::ERROR_EVT_FILTER_ALREADYSCOPED => 0x80073AA6 as u32,
            WIN32::ERROR_EVT_FILTER_NOTELTSET => 0x80073AA7 as u32,
            WIN32::ERROR_EVT_FILTER_INVARG => 0x80073AA8 as u32,
            WIN32::ERROR_EVT_FILTER_INVTEST => 0x80073AA9 as u32,
            WIN32::ERROR_EVT_FILTER_INVTYPE => 0x80073AAA as u32,
            WIN32::ERROR_EVT_FILTER_PARSEERR => 0x80073AAB as u32,
            WIN32::ERROR_EVT_FILTER_UNSUPPORTEDOP => 0x80073AAC as u32,
            WIN32::ERROR_EVT_FILTER_UNEXPECTEDTOKEN => 0x80073AAD as u32,
            WIN32::ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL => 0x80073AAE as u32,
            WIN32::ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE => 0x80073AAF as u32,
            WIN32::ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE => 0x80073AB0 as u32,
            WIN32::ERROR_EVT_CHANNEL_CANNOT_ACTIVATE => 0x80073AB1 as u32,
            WIN32::ERROR_EVT_FILTER_TOO_COMPLEX => 0x80073AB2 as u32,
            WIN32::ERROR_EVT_MESSAGE_NOT_FOUND => 0x80073AB3 as u32,
            WIN32::ERROR_EVT_MESSAGE_ID_NOT_FOUND => 0x80073AB4 as u32,
            WIN32::ERROR_EVT_UNRESOLVED_VALUE_INSERT => 0x80073AB5 as u32,
            WIN32::ERROR_EVT_UNRESOLVED_PARAMETER_INSERT => 0x80073AB6 as u32,
            WIN32::ERROR_EVT_MAX_INSERTS_REACHED => 0x80073AB7 as u32,
            WIN32::ERROR_EVT_EVENT_DEFINITION_NOT_FOUND => 0x80073AB8 as u32,
            WIN32::ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND => 0x80073AB9 as u32,
            WIN32::ERROR_EVT_VERSION_TOO_OLD => 0x80073ABA as u32,
            WIN32::ERROR_EVT_VERSION_TOO_NEW => 0x80073ABB as u32,
            WIN32::ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY => 0x80073ABC as u32,
            WIN32::ERROR_EVT_PUBLISHER_DISABLED => 0x80073ABD as u32,
            WIN32::ERROR_EVT_FILTER_OUT_OF_RANGE => 0x80073ABE as u32,
            WIN32::ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE => 0x80073AE8 as u32,
            WIN32::ERROR_EC_LOG_DISABLED => 0x80073AE9 as u32,
            WIN32::ERROR_EC_CIRCULAR_FORWARDING => 0x80073AEA as u32,
            WIN32::ERROR_EC_CREDSTORE_FULL => 0x80073AEB as u32,
            WIN32::ERROR_EC_CRED_NOT_FOUND => 0x80073AEC as u32,
            WIN32::ERROR_EC_NO_ACTIVE_CHANNEL => 0x80073AED as u32,
            WIN32::ERROR_MUI_FILE_NOT_FOUND => 0x80073AFC as u32,
            WIN32::ERROR_MUI_INVALID_FILE => 0x80073AFD as u32,
            WIN32::ERROR_MUI_INVALID_RC_CONFIG => 0x80073AFE as u32,
            WIN32::ERROR_MUI_INVALID_LOCALE_NAME => 0x80073AFF as u32,
            WIN32::ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME => 0x80073B00 as u32,
            WIN32::ERROR_MUI_FILE_NOT_LOADED => 0x80073B01 as u32,
            WIN32::ERROR_RESOURCE_ENUM_USER_STOP => 0x80073B02 as u32,
            WIN32::ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED => 0x80073B03 as u32,
            WIN32::ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME => 0x80073B04 as u32,
            WIN32::ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE => 0x80073B06 as u32,
            WIN32::ERROR_MRM_INVALID_PRICONFIG => 0x80073B07 as u32,
            WIN32::ERROR_MRM_INVALID_FILE_TYPE => 0x80073B08 as u32,
            WIN32::ERROR_MRM_UNKNOWN_QUALIFIER => 0x80073B09 as u32,
            WIN32::ERROR_MRM_INVALID_QUALIFIER_VALUE => 0x80073B0A as u32,
            WIN32::ERROR_MRM_NO_CANDIDATE => 0x80073B0B as u32,
            WIN32::ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE => 0x80073B0C as u32,
            WIN32::ERROR_MRM_RESOURCE_TYPE_MISMATCH => 0x80073B0D as u32,
            WIN32::ERROR_MRM_DUPLICATE_MAP_NAME => 0x80073B0E as u32,
            WIN32::ERROR_MRM_DUPLICATE_ENTRY => 0x80073B0F as u32,
            WIN32::ERROR_MRM_INVALID_RESOURCE_IDENTIFIER => 0x80073B10 as u32,
            WIN32::ERROR_MRM_FILEPATH_TOO_LONG => 0x80073B11 as u32,
            WIN32::ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE => 0x80073B12 as u32,
            WIN32::ERROR_MRM_INVALID_PRI_FILE => 0x80073B16 as u32,
            WIN32::ERROR_MRM_NAMED_RESOURCE_NOT_FOUND => 0x80073B17 as u32,
            WIN32::ERROR_MRM_MAP_NOT_FOUND => 0x80073B1F as u32,
            WIN32::ERROR_MRM_UNSUPPORTED_PROFILE_TYPE => 0x80073B20 as u32,
            WIN32::ERROR_MRM_INVALID_QUALIFIER_OPERATOR => 0x80073B21 as u32,
            WIN32::ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE => 0x80073B22 as u32,
            WIN32::ERROR_MRM_AUTOMERGE_ENABLED => 0x80073B23 as u32,
            WIN32::ERROR_MRM_TOO_MANY_RESOURCES => 0x80073B24 as u32,
            WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE => 0x80073B25 as u32,
            WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE => 0x80073B26 as u32,
            WIN32::ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD => 0x80073B27 as u32,
            WIN32::ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST => 0x80073B28 as u32,
            WIN32::ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT => 0x80073B29 as u32,
            WIN32::ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE => 0x80073B2A as u32,
            WIN32::ERROR_MRM_GENERATION_COUNT_MISMATCH => 0x80073B2B as u32,
            WIN32::ERROR_PRI_MERGE_VERSION_MISMATCH => 0x80073B2C as u32,
            WIN32::ERROR_PRI_MERGE_MISSING_SCHEMA => 0x80073B2D as u32,
            WIN32::ERROR_PRI_MERGE_LOAD_FILE_FAILED => 0x80073B2E as u32,
            WIN32::ERROR_PRI_MERGE_ADD_FILE_FAILED => 0x80073B2F as u32,
            WIN32::ERROR_PRI_MERGE_WRITE_FILE_FAILED => 0x80073B30 as u32,
            WIN32::ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED => 0x80073B31 as u32,
            WIN32::ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED => 0x80073B32 as u32,
            WIN32::ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED => 0x80073B33 as u32,
            WIN32::ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED => 0x80073B34 as u32,
            WIN32::ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED => 0x80073B35 as u32,
            WIN32::ERROR_PRI_MERGE_INVALID_FILE_NAME => 0x80073B36 as u32,
            WIN32::ERROR_MRM_PACKAGE_NOT_FOUND => 0x80073B37 as u32,
            WIN32::ERROR_MRM_MISSING_DEFAULT_LANGUAGE => 0x80073B38 as u32,
            WIN32::ERROR_MRM_SCOPE_ITEM_CONFLICT => 0x80073B39 as u32,
            WIN32::ERROR_MCA_INVALID_CAPABILITIES_STRING => 0x80073B60 as u32,
            WIN32::ERROR_MCA_INVALID_VCP_VERSION => 0x80073B61 as u32,
            WIN32::ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION => 0x80073B62 as u32,
            WIN32::ERROR_MCA_MCCS_VERSION_MISMATCH => 0x80073B63 as u32,
            WIN32::ERROR_MCA_UNSUPPORTED_MCCS_VERSION => 0x80073B64 as u32,
            WIN32::ERROR_MCA_INTERNAL_ERROR => 0x80073B65 as u32,
            WIN32::ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED => 0x80073B66 as u32,
            WIN32::ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE => 0x80073B67 as u32,
            WIN32::ERROR_AMBIGUOUS_SYSTEM_DEVICE => 0x80073B92 as u32,
            WIN32::ERROR_SYSTEM_DEVICE_NOT_FOUND => 0x80073BC3 as u32,
            WIN32::ERROR_HASH_NOT_SUPPORTED => 0x80073BC4 as u32,
            WIN32::ERROR_HASH_NOT_PRESENT => 0x80073BC5 as u32,
            WIN32::ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED => 0x80073BD9 as u32,
            WIN32::ERROR_GPIO_CLIENT_INFORMATION_INVALID => 0x80073BDA as u32,
            WIN32::ERROR_GPIO_VERSION_NOT_SUPPORTED => 0x80073BDB as u32,
            WIN32::ERROR_GPIO_INVALID_REGISTRATION_PACKET => 0x80073BDC as u32,
            WIN32::ERROR_GPIO_OPERATION_DENIED => 0x80073BDD as u32,
            WIN32::ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE => 0x80073BDE as u32,
            WIN32::ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED => 0x80073BDF as u32,
            WIN32::ERROR_CANNOT_SWITCH_RUNLEVEL => 0x80073C28 as u32,
            WIN32::ERROR_INVALID_RUNLEVEL_SETTING => 0x80073C29 as u32,
            WIN32::ERROR_RUNLEVEL_SWITCH_TIMEOUT => 0x80073C2A as u32,
            WIN32::ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT => 0x80073C2B as u32,
            WIN32::ERROR_RUNLEVEL_SWITCH_IN_PROGRESS => 0x80073C2C as u32,
            WIN32::ERROR_SERVICES_FAILED_AUTOSTART => 0x80073C2D as u32,
            WIN32::ERROR_COM_TASK_STOP_PENDING => 0x80073C8D as u32,
            WIN32::ERROR_INSTALL_OPEN_PACKAGE_FAILED => 0x80073CF0 as u32,
            WIN32::ERROR_INSTALL_PACKAGE_NOT_FOUND => 0x80073CF1 as u32,
            WIN32::ERROR_INSTALL_INVALID_PACKAGE => 0x80073CF2 as u32,
            WIN32::ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED => 0x80073CF3 as u32,
            WIN32::ERROR_INSTALL_OUT_OF_DISK_SPACE => 0x80073CF4 as u32,
            WIN32::ERROR_INSTALL_NETWORK_FAILURE => 0x80073CF5 as u32,
            WIN32::ERROR_INSTALL_REGISTRATION_FAILURE => 0x80073CF6 as u32,
            WIN32::ERROR_INSTALL_DEREGISTRATION_FAILURE => 0x80073CF7 as u32,
            WIN32::ERROR_INSTALL_CANCEL => 0x80073CF8 as u32,
            WIN32::ERROR_INSTALL_FAILED => 0x80073CF9 as u32,
            WIN32::ERROR_REMOVE_FAILED => 0x80073CFA as u32,
            WIN32::ERROR_PACKAGE_ALREADY_EXISTS => 0x80073CFB as u32,
            WIN32::ERROR_NEEDS_REMEDIATION => 0x80073CFC as u32,
            WIN32::ERROR_INSTALL_PREREQUISITE_FAILED => 0x80073CFD as u32,
            WIN32::ERROR_PACKAGE_REPOSITORY_CORRUPTED => 0x80073CFE as u32,
            WIN32::ERROR_INSTALL_POLICY_FAILURE => 0x80073CFF as u32,
            WIN32::ERROR_PACKAGE_UPDATING => 0x80073D00 as u32,
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_POLICY => 0x80073D01 as u32,
            WIN32::ERROR_PACKAGES_IN_USE => 0x80073D02 as u32,
            WIN32::ERROR_RECOVERY_FILE_CORRUPT => 0x80073D03 as u32,
            WIN32::ERROR_INVALID_STAGED_SIGNATURE => 0x80073D04 as u32,
            WIN32::ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED => 0x80073D05 as u32,
            WIN32::ERROR_INSTALL_PACKAGE_DOWNGRADE => 0x80073D06 as u32,
            WIN32::ERROR_SYSTEM_NEEDS_REMEDIATION => 0x80073D07 as u32,
            WIN32::ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN => 0x80073D08 as u32,
            WIN32::ERROR_RESILIENCY_FILE_CORRUPT => 0x80073D09 as u32,
            WIN32::ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING => 0x80073D0A as u32,
            WIN32::ERROR_PACKAGE_MOVE_FAILED => 0x80073D0B as u32,
            WIN32::ERROR_INSTALL_VOLUME_NOT_EMPTY => 0x80073D0C as u32,
            WIN32::ERROR_INSTALL_VOLUME_OFFLINE => 0x80073D0D as u32,
            WIN32::ERROR_INSTALL_VOLUME_CORRUPT => 0x80073D0E as u32,
            WIN32::ERROR_NEEDS_REGISTRATION => 0x80073D0F as u32,
            WIN32::ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE => 0x80073D10 as u32,
            WIN32::ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED => 0x80073D11 as u32,
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE => 0x80073D12 as u32,
            WIN32::ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM => 0x80073D13 as u32,
            WIN32::ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING => 0x80073D14 as u32,
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE => 0x80073D15 as u32,
            WIN32::ERROR_PACKAGE_STAGING_ONHOLD => 0x80073D16 as u32,
            WIN32::ERROR_INSTALL_INVALID_RELATED_SET_UPDATE => 0x80073D17 as u32,
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY => 0x80073D18 as u32,
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF => 0x80073D19 as u32,
            WIN32::ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED => 0x80073D1A as u32,
            WIN32::ERROR_PACKAGES_REPUTATION_CHECK_FAILED => 0x80073D1B as u32,
            WIN32::ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT => 0x80073D1C as u32,
            WIN32::ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED => 0x80073D1D as u32,
            WIN32::ERROR_APPINSTALLER_ACTIVATION_BLOCKED => 0x80073D1E as u32,
            WIN32::ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED => 0x80073D1F as u32,
            WIN32::ERROR_APPX_RAW_DATA_WRITE_FAILED => 0x80073D20 as u32,
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE => 0x80073D21 as u32,
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE => 0x80073D22 as u32,
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY => 0x80073D23 as u32,
            WIN32::ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY => 0x80073D24 as u32,
            WIN32::ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER => 0x80073D25 as u32,
            WIN32::ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED => 0x80073D26 as u32,
            WIN32::ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE => 0x80073D27 as u32,
            WIN32::ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES => 0x80073D28 as u32,
            WIN32::ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED => 0x80073D29 as u32,
            WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST => 0x80073D2A as u32,
            WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT => 0x80073D2B as u32,
            WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE => 0x80073D2C as u32,
            WIN32::ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE => 0x80073D2D as u32,
            WIN32::ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED => 0x80073D2E as u32,
            WIN32::ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY => 0x80073D2F as u32,
            WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS => 0x80073D30 as u32,
            WIN32::ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED => 0x80073D31 as u32,
            WIN32::ERROR_MACHINE_SCOPE_NOT_ALLOWED => 0x80073D32 as u32,
            WIN32::ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED => 0x80073D33 as u32,
            WIN32::ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE => 0x80073D34 as u32,
            WIN32::ERROR_PACKAGE_NOT_REGISTERED_FOR_USER => 0x80073D35 as u32,
            WIN32::ERROR_PACKAGE_NAME_MISMATCH => 0x80073D36 as u32,
            WIN32::ERROR_APPINSTALLER_URI_IN_USE => 0x80073D37 as u32,
            WIN32::ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM => 0x80073D38 as u32,
            WIN32::APPMODEL_ERROR_NO_PACKAGE => 0x80073D54 as u32,
            WIN32::APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT => 0x80073D55 as u32,
            WIN32::APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT => 0x80073D56 as u32,
            WIN32::APPMODEL_ERROR_NO_APPLICATION => 0x80073D57 as u32,
            WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED => 0x80073D58 as u32,
            WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID => 0x80073D59 as u32,
            WIN32::APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE => 0x80073D5A as u32,
            WIN32::APPMODEL_ERROR_NO_MUTABLE_DIRECTORY => 0x80073D5B as u32,
            WIN32::ERROR_STATE_LOAD_STORE_FAILED => 0x80073DB8 as u32,
            WIN32::ERROR_STATE_GET_VERSION_FAILED => 0x80073DB9 as u32,
            WIN32::ERROR_STATE_SET_VERSION_FAILED => 0x80073DBA as u32,
            WIN32::ERROR_STATE_STRUCTURED_RESET_FAILED => 0x80073DBB as u32,
            WIN32::ERROR_STATE_OPEN_CONTAINER_FAILED => 0x80073DBC as u32,
            WIN32::ERROR_STATE_CREATE_CONTAINER_FAILED => 0x80073DBD as u32,
            WIN32::ERROR_STATE_DELETE_CONTAINER_FAILED => 0x80073DBE as u32,
            WIN32::ERROR_STATE_READ_SETTING_FAILED => 0x80073DBF as u32,
            WIN32::ERROR_STATE_WRITE_SETTING_FAILED => 0x80073DC0 as u32,
            WIN32::ERROR_STATE_DELETE_SETTING_FAILED => 0x80073DC1 as u32,
            WIN32::ERROR_STATE_QUERY_SETTING_FAILED => 0x80073DC2 as u32,
            WIN32::ERROR_STATE_READ_COMPOSITE_SETTING_FAILED => 0x80073DC3 as u32,
            WIN32::ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED => 0x80073DC4 as u32,
            WIN32::ERROR_STATE_ENUMERATE_CONTAINER_FAILED => 0x80073DC5 as u32,
            WIN32::ERROR_STATE_ENUMERATE_SETTINGS_FAILED => 0x80073DC6 as u32,
            WIN32::ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED => 0x80073DC7 as u32,
            WIN32::ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED => 0x80073DC8 as u32,
            WIN32::ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED => 0x80073DC9 as u32,
            WIN32::ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED => 0x80073DCA as u32,
            WIN32::ERROR_API_UNAVAILABLE => 0x80073DE1 as u32,
            WIN32::STORE_ERROR_UNLICENSED => 0x80073DF5 as u32,
            WIN32::STORE_ERROR_UNLICENSED_USER => 0x80073DF6 as u32,
            WIN32::STORE_ERROR_PENDING_COM_TRANSACTION => 0x80073DF7 as u32,
            WIN32::STORE_ERROR_LICENSE_REVOKED => 0x80073DF8 as u32,
            WIN32::ERROR_SUCCESS => 0x80078007 as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WIN32::ERROR_INVALID_FUNCTION => RawError::Kind(WIN32::ERROR_INVALID_FUNCTION),
            WIN32::PDH_CSTATUS_NEW_DATA => RawError::Kind(WIN32::PDH_CSTATUS_NEW_DATA),
            WIN32::ERROR_FILE_NOT_FOUND => RawError::Kind(WIN32::ERROR_FILE_NOT_FOUND),
            WIN32::ERROR_PATH_NOT_FOUND => RawError::Kind(WIN32::ERROR_PATH_NOT_FOUND),
            WIN32::E_PATH_NOT_FOUND => RawError::Kind(WIN32::E_PATH_NOT_FOUND),
            WIN32::ERROR_TOO_MANY_OPEN_FILES => RawError::Kind(WIN32::ERROR_TOO_MANY_OPEN_FILES),
            WIN32::ERROR_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_ACCESS_DENIED),
            WIN32::E_ACCESSDENIED => RawError::Kind(WIN32::E_ACCESSDENIED),
            WIN32::ERROR_INVALID_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_HANDLE),
            WIN32::E_HANDLE => RawError::Kind(WIN32::E_HANDLE),
            WIN32::ERROR_ARENA_TRASHED => RawError::Kind(WIN32::ERROR_ARENA_TRASHED),
            WIN32::ERROR_NOT_ENOUGH_MEMORY => RawError::Kind(WIN32::ERROR_NOT_ENOUGH_MEMORY),
            WIN32::ERROR_INVALID_BLOCK => RawError::Kind(WIN32::ERROR_INVALID_BLOCK),
            WIN32::ERROR_BAD_ENVIRONMENT => RawError::Kind(WIN32::ERROR_BAD_ENVIRONMENT),
            WIN32::ERROR_BAD_FORMAT => RawError::Kind(WIN32::ERROR_BAD_FORMAT),
            WIN32::ERROR_INVALID_ACCESS => RawError::Kind(WIN32::ERROR_INVALID_ACCESS),
            WIN32::ERROR_INVALID_DATA => RawError::Kind(WIN32::ERROR_INVALID_DATA),
            WIN32::E_OUTOFMEMORY => RawError::Kind(WIN32::E_OUTOFMEMORY),
            WIN32::ERROR_OUTOFMEMORY => RawError::Kind(WIN32::ERROR_OUTOFMEMORY),
            WIN32::DDERR_OUTOFMEMORY => RawError::Kind(WIN32::DDERR_OUTOFMEMORY),
            WIN32::ERROR_INVALID_DRIVE => RawError::Kind(WIN32::ERROR_INVALID_DRIVE),
            WIN32::ERROR_CURRENT_DIRECTORY => RawError::Kind(WIN32::ERROR_CURRENT_DIRECTORY),
            WIN32::ERROR_NOT_SAME_DEVICE => RawError::Kind(WIN32::ERROR_NOT_SAME_DEVICE),
            WIN32::ERROR_NO_MORE_FILES => RawError::Kind(WIN32::ERROR_NO_MORE_FILES),
            WIN32::ERROR_WRITE_PROTECT => RawError::Kind(WIN32::ERROR_WRITE_PROTECT),
            WIN32::ERROR_BAD_UNIT => RawError::Kind(WIN32::ERROR_BAD_UNIT),
            WIN32::ERROR_NOT_READY => RawError::Kind(WIN32::ERROR_NOT_READY),
            WIN32::ERROR_BAD_COMMAND => RawError::Kind(WIN32::ERROR_BAD_COMMAND),
            WIN32::ERROR_CRC => RawError::Kind(WIN32::ERROR_CRC),
            WIN32::ERROR_BAD_LENGTH => RawError::Kind(WIN32::ERROR_BAD_LENGTH),
            WIN32::ERROR_SEEK => RawError::Kind(WIN32::ERROR_SEEK),
            WIN32::ERROR_NOT_DOS_DISK => RawError::Kind(WIN32::ERROR_NOT_DOS_DISK),
            WIN32::ERROR_SECTOR_NOT_FOUND => RawError::Kind(WIN32::ERROR_SECTOR_NOT_FOUND),
            WIN32::ERROR_OUT_OF_PAPER => RawError::Kind(WIN32::ERROR_OUT_OF_PAPER),
            WIN32::ERROR_WRITE_FAULT => RawError::Kind(WIN32::ERROR_WRITE_FAULT),
            WIN32::ERROR_READ_FAULT => RawError::Kind(WIN32::ERROR_READ_FAULT),
            WIN32::ERROR_GEN_FAILURE => RawError::Kind(WIN32::ERROR_GEN_FAILURE),
            WIN32::ERROR_SHARING_VIOLATION => RawError::Kind(WIN32::ERROR_SHARING_VIOLATION),
            WIN32::E_SHARING_VIOLATION => RawError::Kind(WIN32::E_SHARING_VIOLATION),
            WIN32::ERROR_LOCK_VIOLATION => RawError::Kind(WIN32::ERROR_LOCK_VIOLATION),
            WIN32::ERROR_WRONG_DISK => RawError::Kind(WIN32::ERROR_WRONG_DISK),
            WIN32::ERROR_SHARING_BUFFER_EXCEEDED => RawError::Kind(WIN32::ERROR_SHARING_BUFFER_EXCEEDED),
            WIN32::ERROR_HANDLE_EOF => RawError::Kind(WIN32::ERROR_HANDLE_EOF),
            WIN32::ERROR_HANDLE_DISK_FULL => RawError::Kind(WIN32::ERROR_HANDLE_DISK_FULL),
            WIN32::ERROR_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED),
            WIN32::ERROR_REM_NOT_LIST => RawError::Kind(WIN32::ERROR_REM_NOT_LIST),
            WIN32::ERROR_DUP_NAME => RawError::Kind(WIN32::ERROR_DUP_NAME),
            WIN32::ERROR_BAD_NETPATH => RawError::Kind(WIN32::ERROR_BAD_NETPATH),
            WIN32::ERROR_NETWORK_BUSY => RawError::Kind(WIN32::ERROR_NETWORK_BUSY),
            WIN32::ERROR_DEV_NOT_EXIST => RawError::Kind(WIN32::ERROR_DEV_NOT_EXIST),
            WIN32::ERROR_TOO_MANY_CMDS => RawError::Kind(WIN32::ERROR_TOO_MANY_CMDS),
            WIN32::ERROR_ADAP_HDW_ERR => RawError::Kind(WIN32::ERROR_ADAP_HDW_ERR),
            WIN32::ERROR_BAD_NET_RESP => RawError::Kind(WIN32::ERROR_BAD_NET_RESP),
            WIN32::ERROR_UNEXP_NET_ERR => RawError::Kind(WIN32::ERROR_UNEXP_NET_ERR),
            WIN32::ERROR_BAD_REM_ADAP => RawError::Kind(WIN32::ERROR_BAD_REM_ADAP),
            WIN32::ERROR_PRINTQ_FULL => RawError::Kind(WIN32::ERROR_PRINTQ_FULL),
            WIN32::ERROR_NO_SPOOL_SPACE => RawError::Kind(WIN32::ERROR_NO_SPOOL_SPACE),
            WIN32::ERROR_PRINT_CANCELLED => RawError::Kind(WIN32::ERROR_PRINT_CANCELLED),
            WIN32::ERROR_NETNAME_DELETED => RawError::Kind(WIN32::ERROR_NETNAME_DELETED),
            WIN32::ERROR_NETWORK_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_NETWORK_ACCESS_DENIED),
            WIN32::ERROR_BAD_DEV_TYPE => RawError::Kind(WIN32::ERROR_BAD_DEV_TYPE),
            WIN32::ERROR_BAD_NET_NAME => RawError::Kind(WIN32::ERROR_BAD_NET_NAME),
            WIN32::ERROR_TOO_MANY_NAMES => RawError::Kind(WIN32::ERROR_TOO_MANY_NAMES),
            WIN32::ERROR_TOO_MANY_SESS => RawError::Kind(WIN32::ERROR_TOO_MANY_SESS),
            WIN32::ERROR_SHARING_PAUSED => RawError::Kind(WIN32::ERROR_SHARING_PAUSED),
            WIN32::ERROR_REQ_NOT_ACCEP => RawError::Kind(WIN32::ERROR_REQ_NOT_ACCEP),
            WIN32::ERROR_REDIR_PAUSED => RawError::Kind(WIN32::ERROR_REDIR_PAUSED),
            WIN32::ERROR_FILE_EXISTS => RawError::Kind(WIN32::ERROR_FILE_EXISTS),
            WIN32::ERROR_CANNOT_MAKE => RawError::Kind(WIN32::ERROR_CANNOT_MAKE),
            WIN32::ERROR_FAIL_I24 => RawError::Kind(WIN32::ERROR_FAIL_I24),
            WIN32::ERROR_OUT_OF_STRUCTURES => RawError::Kind(WIN32::ERROR_OUT_OF_STRUCTURES),
            WIN32::ERROR_ALREADY_ASSIGNED => RawError::Kind(WIN32::ERROR_ALREADY_ASSIGNED),
            WIN32::ERROR_INVALID_PASSWORD => RawError::Kind(WIN32::ERROR_INVALID_PASSWORD),
            WIN32::ERROR_INVALID_PARAMETER => RawError::Kind(WIN32::ERROR_INVALID_PARAMETER),
            WIN32::E_INVALIDARG => RawError::Kind(WIN32::E_INVALIDARG),
            WIN32::DDERR_INVALIDPARAMS => RawError::Kind(WIN32::DDERR_INVALIDPARAMS),
            WIN32::ERROR_NET_WRITE_FAULT => RawError::Kind(WIN32::ERROR_NET_WRITE_FAULT),
            WIN32::ERROR_NO_PROC_SLOTS => RawError::Kind(WIN32::ERROR_NO_PROC_SLOTS),
            WIN32::ERROR_TOO_MANY_SEMAPHORES => RawError::Kind(WIN32::ERROR_TOO_MANY_SEMAPHORES),
            WIN32::ERROR_EXCL_SEM_ALREADY_OWNED => RawError::Kind(WIN32::ERROR_EXCL_SEM_ALREADY_OWNED),
            WIN32::ERROR_SEM_IS_SET => RawError::Kind(WIN32::ERROR_SEM_IS_SET),
            WIN32::ERROR_TOO_MANY_SEM_REQUESTS => RawError::Kind(WIN32::ERROR_TOO_MANY_SEM_REQUESTS),
            WIN32::ERROR_INVALID_AT_INTERRUPT_TIME => RawError::Kind(WIN32::ERROR_INVALID_AT_INTERRUPT_TIME),
            WIN32::ERROR_SEM_OWNER_DIED => RawError::Kind(WIN32::ERROR_SEM_OWNER_DIED),
            WIN32::ERROR_SEM_USER_LIMIT => RawError::Kind(WIN32::ERROR_SEM_USER_LIMIT),
            WIN32::ERROR_DISK_CHANGE => RawError::Kind(WIN32::ERROR_DISK_CHANGE),
            WIN32::ERROR_DRIVE_LOCKED => RawError::Kind(WIN32::ERROR_DRIVE_LOCKED),
            WIN32::ERROR_BROKEN_PIPE => RawError::Kind(WIN32::ERROR_BROKEN_PIPE),
            WIN32::ERROR_OPEN_FAILED => RawError::Kind(WIN32::ERROR_OPEN_FAILED),
            WIN32::ERROR_BUFFER_OVERFLOW => RawError::Kind(WIN32::ERROR_BUFFER_OVERFLOW),
            WIN32::ERROR_DISK_FULL => RawError::Kind(WIN32::ERROR_DISK_FULL),
            WIN32::ERROR_NO_MORE_SEARCH_HANDLES => RawError::Kind(WIN32::ERROR_NO_MORE_SEARCH_HANDLES),
            WIN32::ERROR_INVALID_TARGET_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_TARGET_HANDLE),
            WIN32::ERROR_INVALID_CATEGORY => RawError::Kind(WIN32::ERROR_INVALID_CATEGORY),
            WIN32::ERROR_INVALID_VERIFY_SWITCH => RawError::Kind(WIN32::ERROR_INVALID_VERIFY_SWITCH),
            WIN32::ERROR_BAD_DRIVER_LEVEL => RawError::Kind(WIN32::ERROR_BAD_DRIVER_LEVEL),
            WIN32::ERROR_CALL_NOT_IMPLEMENTED => RawError::Kind(WIN32::ERROR_CALL_NOT_IMPLEMENTED),
            WIN32::ERROR_SEM_TIMEOUT => RawError::Kind(WIN32::ERROR_SEM_TIMEOUT),
            WIN32::ERROR_INSUFFICIENT_BUFFER => RawError::Kind(WIN32::ERROR_INSUFFICIENT_BUFFER),
            WIN32::ERROR_INVALID_NAME => RawError::Kind(WIN32::ERROR_INVALID_NAME),
            WIN32::ERROR_INVALID_LEVEL => RawError::Kind(WIN32::ERROR_INVALID_LEVEL),
            WIN32::ERROR_NO_VOLUME_LABEL => RawError::Kind(WIN32::ERROR_NO_VOLUME_LABEL),
            WIN32::ERROR_MOD_NOT_FOUND => RawError::Kind(WIN32::ERROR_MOD_NOT_FOUND),
            WIN32::ERROR_PROC_NOT_FOUND => RawError::Kind(WIN32::ERROR_PROC_NOT_FOUND),
            WIN32::ERROR_WAIT_NO_CHILDREN => RawError::Kind(WIN32::ERROR_WAIT_NO_CHILDREN),
            WIN32::ERROR_CHILD_NOT_COMPLETE => RawError::Kind(WIN32::ERROR_CHILD_NOT_COMPLETE),
            WIN32::ERROR_DIRECT_ACCESS_HANDLE => RawError::Kind(WIN32::ERROR_DIRECT_ACCESS_HANDLE),
            WIN32::ERROR_NEGATIVE_SEEK => RawError::Kind(WIN32::ERROR_NEGATIVE_SEEK),
            WIN32::ERROR_SEEK_ON_DEVICE => RawError::Kind(WIN32::ERROR_SEEK_ON_DEVICE),
            WIN32::ERROR_IS_JOIN_TARGET => RawError::Kind(WIN32::ERROR_IS_JOIN_TARGET),
            WIN32::ERROR_IS_JOINED => RawError::Kind(WIN32::ERROR_IS_JOINED),
            WIN32::ERROR_IS_SUBSTED => RawError::Kind(WIN32::ERROR_IS_SUBSTED),
            WIN32::ERROR_NOT_JOINED => RawError::Kind(WIN32::ERROR_NOT_JOINED),
            WIN32::ERROR_NOT_SUBSTED => RawError::Kind(WIN32::ERROR_NOT_SUBSTED),
            WIN32::ERROR_JOIN_TO_JOIN => RawError::Kind(WIN32::ERROR_JOIN_TO_JOIN),
            WIN32::ERROR_SUBST_TO_SUBST => RawError::Kind(WIN32::ERROR_SUBST_TO_SUBST),
            WIN32::ERROR_JOIN_TO_SUBST => RawError::Kind(WIN32::ERROR_JOIN_TO_SUBST),
            WIN32::ERROR_SUBST_TO_JOIN => RawError::Kind(WIN32::ERROR_SUBST_TO_JOIN),
            WIN32::ERROR_BUSY_DRIVE => RawError::Kind(WIN32::ERROR_BUSY_DRIVE),
            WIN32::ERROR_SAME_DRIVE => RawError::Kind(WIN32::ERROR_SAME_DRIVE),
            WIN32::ERROR_DIR_NOT_ROOT => RawError::Kind(WIN32::ERROR_DIR_NOT_ROOT),
            WIN32::ERROR_DIR_NOT_EMPTY => RawError::Kind(WIN32::ERROR_DIR_NOT_EMPTY),
            WIN32::ERROR_IS_SUBST_PATH => RawError::Kind(WIN32::ERROR_IS_SUBST_PATH),
            WIN32::ERROR_IS_JOIN_PATH => RawError::Kind(WIN32::ERROR_IS_JOIN_PATH),
            WIN32::ERROR_PATH_BUSY => RawError::Kind(WIN32::ERROR_PATH_BUSY),
            WIN32::ERROR_IS_SUBST_TARGET => RawError::Kind(WIN32::ERROR_IS_SUBST_TARGET),
            WIN32::ERROR_SYSTEM_TRACE => RawError::Kind(WIN32::ERROR_SYSTEM_TRACE),
            WIN32::ERROR_INVALID_EVENT_COUNT => RawError::Kind(WIN32::ERROR_INVALID_EVENT_COUNT),
            WIN32::ERROR_TOO_MANY_MUXWAITERS => RawError::Kind(WIN32::ERROR_TOO_MANY_MUXWAITERS),
            WIN32::ERROR_INVALID_LIST_FORMAT => RawError::Kind(WIN32::ERROR_INVALID_LIST_FORMAT),
            WIN32::ERROR_LABEL_TOO_LONG => RawError::Kind(WIN32::ERROR_LABEL_TOO_LONG),
            WIN32::ERROR_TOO_MANY_TCBS => RawError::Kind(WIN32::ERROR_TOO_MANY_TCBS),
            WIN32::ERROR_SIGNAL_REFUSED => RawError::Kind(WIN32::ERROR_SIGNAL_REFUSED),
            WIN32::ERROR_DISCARDED => RawError::Kind(WIN32::ERROR_DISCARDED),
            WIN32::ERROR_NOT_LOCKED => RawError::Kind(WIN32::ERROR_NOT_LOCKED),
            WIN32::ERROR_BAD_THREADID_ADDR => RawError::Kind(WIN32::ERROR_BAD_THREADID_ADDR),
            WIN32::ERROR_BAD_ARGUMENTS => RawError::Kind(WIN32::ERROR_BAD_ARGUMENTS),
            WIN32::ERROR_BAD_PATHNAME => RawError::Kind(WIN32::ERROR_BAD_PATHNAME),
            WIN32::ERROR_SIGNAL_PENDING => RawError::Kind(WIN32::ERROR_SIGNAL_PENDING),
            WIN32::ERROR_MAX_THRDS_REACHED => RawError::Kind(WIN32::ERROR_MAX_THRDS_REACHED),
            WIN32::ERROR_LOCK_FAILED => RawError::Kind(WIN32::ERROR_LOCK_FAILED),
            WIN32::ERROR_BUSY => RawError::Kind(WIN32::ERROR_BUSY),
            WIN32::ERROR_DEVICE_SUPPORT_IN_PROGRESS => RawError::Kind(WIN32::ERROR_DEVICE_SUPPORT_IN_PROGRESS),
            WIN32::ERROR_CANCEL_VIOLATION => RawError::Kind(WIN32::ERROR_CANCEL_VIOLATION),
            WIN32::ERROR_ATOMIC_LOCKS_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_ATOMIC_LOCKS_NOT_SUPPORTED),
            WIN32::ERROR_INVALID_SEGMENT_NUMBER => RawError::Kind(WIN32::ERROR_INVALID_SEGMENT_NUMBER),
            WIN32::ERROR_INVALID_ORDINAL => RawError::Kind(WIN32::ERROR_INVALID_ORDINAL),
            WIN32::ERROR_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_ALREADY_EXISTS),
            WIN32::ERROR_INVALID_FLAG_NUMBER => RawError::Kind(WIN32::ERROR_INVALID_FLAG_NUMBER),
            WIN32::ERROR_SEM_NOT_FOUND => RawError::Kind(WIN32::ERROR_SEM_NOT_FOUND),
            WIN32::ERROR_INVALID_STARTING_CODESEG => RawError::Kind(WIN32::ERROR_INVALID_STARTING_CODESEG),
            WIN32::ERROR_INVALID_STACKSEG => RawError::Kind(WIN32::ERROR_INVALID_STACKSEG),
            WIN32::ERROR_INVALID_MODULETYPE => RawError::Kind(WIN32::ERROR_INVALID_MODULETYPE),
            WIN32::ERROR_INVALID_EXE_SIGNATURE => RawError::Kind(WIN32::ERROR_INVALID_EXE_SIGNATURE),
            WIN32::ERROR_EXE_MARKED_INVALID => RawError::Kind(WIN32::ERROR_EXE_MARKED_INVALID),
            WIN32::ERROR_BAD_EXE_FORMAT => RawError::Kind(WIN32::ERROR_BAD_EXE_FORMAT),
            WIN32::ERROR_ITERATED_DATA_EXCEEDS_64k => RawError::Kind(WIN32::ERROR_ITERATED_DATA_EXCEEDS_64k),
            WIN32::ERROR_INVALID_MINALLOCSIZE => RawError::Kind(WIN32::ERROR_INVALID_MINALLOCSIZE),
            WIN32::ERROR_DYNLINK_FROM_INVALID_RING => RawError::Kind(WIN32::ERROR_DYNLINK_FROM_INVALID_RING),
            WIN32::ERROR_IOPL_NOT_ENABLED => RawError::Kind(WIN32::ERROR_IOPL_NOT_ENABLED),
            WIN32::ERROR_INVALID_SEGDPL => RawError::Kind(WIN32::ERROR_INVALID_SEGDPL),
            WIN32::ERROR_AUTODATASEG_EXCEEDS_64k => RawError::Kind(WIN32::ERROR_AUTODATASEG_EXCEEDS_64k),
            WIN32::ERROR_RING2SEG_MUST_BE_MOVABLE => RawError::Kind(WIN32::ERROR_RING2SEG_MUST_BE_MOVABLE),
            WIN32::ERROR_RELOC_CHAIN_XEEDS_SEGLIM => RawError::Kind(WIN32::ERROR_RELOC_CHAIN_XEEDS_SEGLIM),
            WIN32::ERROR_INFLOOP_IN_RELOC_CHAIN => RawError::Kind(WIN32::ERROR_INFLOOP_IN_RELOC_CHAIN),
            WIN32::ERROR_ENVVAR_NOT_FOUND => RawError::Kind(WIN32::ERROR_ENVVAR_NOT_FOUND),
            WIN32::ERROR_NO_SIGNAL_SENT => RawError::Kind(WIN32::ERROR_NO_SIGNAL_SENT),
            WIN32::ERROR_FILENAME_EXCED_RANGE => RawError::Kind(WIN32::ERROR_FILENAME_EXCED_RANGE),
            WIN32::ERROR_RING2_STACK_IN_USE => RawError::Kind(WIN32::ERROR_RING2_STACK_IN_USE),
            WIN32::ERROR_META_EXPANSION_TOO_LONG => RawError::Kind(WIN32::ERROR_META_EXPANSION_TOO_LONG),
            WIN32::ERROR_INVALID_SIGNAL_NUMBER => RawError::Kind(WIN32::ERROR_INVALID_SIGNAL_NUMBER),
            WIN32::ERROR_THREAD_1_INACTIVE => RawError::Kind(WIN32::ERROR_THREAD_1_INACTIVE),
            WIN32::ERROR_LOCKED => RawError::Kind(WIN32::ERROR_LOCKED),
            WIN32::ERROR_TOO_MANY_MODULES => RawError::Kind(WIN32::ERROR_TOO_MANY_MODULES),
            WIN32::ERROR_NESTING_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_NESTING_NOT_ALLOWED),
            WIN32::ERROR_EXE_MACHINE_TYPE_MISMATCH => RawError::Kind(WIN32::ERROR_EXE_MACHINE_TYPE_MISMATCH),
            WIN32::ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY => RawError::Kind(WIN32::ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY),
            WIN32::ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY => RawError::Kind(WIN32::ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY),
            WIN32::ERROR_FILE_CHECKED_OUT => RawError::Kind(WIN32::ERROR_FILE_CHECKED_OUT),
            WIN32::ERROR_CHECKOUT_REQUIRED => RawError::Kind(WIN32::ERROR_CHECKOUT_REQUIRED),
            WIN32::ERROR_BAD_FILE_TYPE => RawError::Kind(WIN32::ERROR_BAD_FILE_TYPE),
            WIN32::ERROR_FILE_TOO_LARGE => RawError::Kind(WIN32::ERROR_FILE_TOO_LARGE),
            WIN32::ERROR_FORMS_AUTH_REQUIRED => RawError::Kind(WIN32::ERROR_FORMS_AUTH_REQUIRED),
            WIN32::ERROR_VIRUS_INFECTED => RawError::Kind(WIN32::ERROR_VIRUS_INFECTED),
            WIN32::ERROR_VIRUS_DELETED => RawError::Kind(WIN32::ERROR_VIRUS_DELETED),
            WIN32::ERROR_PIPE_LOCAL => RawError::Kind(WIN32::ERROR_PIPE_LOCAL),
            WIN32::ERROR_BAD_PIPE => RawError::Kind(WIN32::ERROR_BAD_PIPE),
            WIN32::ERROR_PIPE_BUSY => RawError::Kind(WIN32::ERROR_PIPE_BUSY),
            WIN32::ERROR_NO_DATA => RawError::Kind(WIN32::ERROR_NO_DATA),
            WIN32::ERROR_PIPE_NOT_CONNECTED => RawError::Kind(WIN32::ERROR_PIPE_NOT_CONNECTED),
            WIN32::ERROR_MORE_DATA => RawError::Kind(WIN32::ERROR_MORE_DATA),
            WIN32::ERROR_NO_WORK_DONE => RawError::Kind(WIN32::ERROR_NO_WORK_DONE),
            WIN32::ERROR_VC_DISCONNECTED => RawError::Kind(WIN32::ERROR_VC_DISCONNECTED),
            WIN32::ERROR_INVALID_EA_NAME => RawError::Kind(WIN32::ERROR_INVALID_EA_NAME),
            WIN32::ERROR_EA_LIST_INCONSISTENT => RawError::Kind(WIN32::ERROR_EA_LIST_INCONSISTENT),
            WIN32::WAIT_TIMEOUT => RawError::Kind(WIN32::WAIT_TIMEOUT),
            WIN32::ERROR_NO_MORE_ITEMS => RawError::Kind(WIN32::ERROR_NO_MORE_ITEMS),
            WIN32::ERROR_CANNOT_COPY => RawError::Kind(WIN32::ERROR_CANNOT_COPY),
            WIN32::ERROR_DIRECTORY => RawError::Kind(WIN32::ERROR_DIRECTORY),
            WIN32::ERROR_EAS_DIDNT_FIT => RawError::Kind(WIN32::ERROR_EAS_DIDNT_FIT),
            WIN32::ERROR_EA_FILE_CORRUPT => RawError::Kind(WIN32::ERROR_EA_FILE_CORRUPT),
            WIN32::ERROR_EA_TABLE_FULL => RawError::Kind(WIN32::ERROR_EA_TABLE_FULL),
            WIN32::ERROR_INVALID_EA_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_EA_HANDLE),
            WIN32::ERROR_EAS_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_EAS_NOT_SUPPORTED),
            WIN32::ERROR_NOT_OWNER => RawError::Kind(WIN32::ERROR_NOT_OWNER),
            WIN32::ERROR_TOO_MANY_POSTS => RawError::Kind(WIN32::ERROR_TOO_MANY_POSTS),
            WIN32::ERROR_PARTIAL_COPY => RawError::Kind(WIN32::ERROR_PARTIAL_COPY),
            WIN32::ERROR_OPLOCK_NOT_GRANTED => RawError::Kind(WIN32::ERROR_OPLOCK_NOT_GRANTED),
            WIN32::ERROR_INVALID_OPLOCK_PROTOCOL => RawError::Kind(WIN32::ERROR_INVALID_OPLOCK_PROTOCOL),
            WIN32::ERROR_DISK_TOO_FRAGMENTED => RawError::Kind(WIN32::ERROR_DISK_TOO_FRAGMENTED),
            WIN32::ERROR_DELETE_PENDING => RawError::Kind(WIN32::ERROR_DELETE_PENDING),
            WIN32::ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING => RawError::Kind(WIN32::ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING),
            WIN32::ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME => RawError::Kind(WIN32::ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME),
            WIN32::ERROR_SECURITY_STREAM_IS_INCONSISTENT => RawError::Kind(WIN32::ERROR_SECURITY_STREAM_IS_INCONSISTENT),
            WIN32::ERROR_INVALID_LOCK_RANGE => RawError::Kind(WIN32::ERROR_INVALID_LOCK_RANGE),
            WIN32::ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT => RawError::Kind(WIN32::ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT),
            WIN32::ERROR_NOTIFICATION_GUID_ALREADY_DEFINED => RawError::Kind(WIN32::ERROR_NOTIFICATION_GUID_ALREADY_DEFINED),
            WIN32::ERROR_INVALID_EXCEPTION_HANDLER => RawError::Kind(WIN32::ERROR_INVALID_EXCEPTION_HANDLER),
            WIN32::ERROR_DUPLICATE_PRIVILEGES => RawError::Kind(WIN32::ERROR_DUPLICATE_PRIVILEGES),
            WIN32::ERROR_NO_RANGES_PROCESSED => RawError::Kind(WIN32::ERROR_NO_RANGES_PROCESSED),
            WIN32::ERROR_NOT_ALLOWED_ON_SYSTEM_FILE => RawError::Kind(WIN32::ERROR_NOT_ALLOWED_ON_SYSTEM_FILE),
            WIN32::ERROR_DISK_RESOURCES_EXHAUSTED => RawError::Kind(WIN32::ERROR_DISK_RESOURCES_EXHAUSTED),
            WIN32::ERROR_INVALID_TOKEN => RawError::Kind(WIN32::ERROR_INVALID_TOKEN),
            WIN32::ERROR_DEVICE_FEATURE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_DEVICE_FEATURE_NOT_SUPPORTED),
            WIN32::ERROR_MR_MID_NOT_FOUND => RawError::Kind(WIN32::ERROR_MR_MID_NOT_FOUND),
            WIN32::ERROR_SCOPE_NOT_FOUND => RawError::Kind(WIN32::ERROR_SCOPE_NOT_FOUND),
            WIN32::ERROR_UNDEFINED_SCOPE => RawError::Kind(WIN32::ERROR_UNDEFINED_SCOPE),
            WIN32::ERROR_INVALID_CAP => RawError::Kind(WIN32::ERROR_INVALID_CAP),
            WIN32::ERROR_DEVICE_UNREACHABLE => RawError::Kind(WIN32::ERROR_DEVICE_UNREACHABLE),
            WIN32::ERROR_DEVICE_NO_RESOURCES => RawError::Kind(WIN32::ERROR_DEVICE_NO_RESOURCES),
            WIN32::ERROR_DATA_CHECKSUM_ERROR => RawError::Kind(WIN32::ERROR_DATA_CHECKSUM_ERROR),
            WIN32::ERROR_INTERMIXED_KERNEL_EA_OPERATION => RawError::Kind(WIN32::ERROR_INTERMIXED_KERNEL_EA_OPERATION),
            WIN32::ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED),
            WIN32::ERROR_OFFSET_ALIGNMENT_VIOLATION => RawError::Kind(WIN32::ERROR_OFFSET_ALIGNMENT_VIOLATION),
            WIN32::ERROR_INVALID_FIELD_IN_PARAMETER_LIST => RawError::Kind(WIN32::ERROR_INVALID_FIELD_IN_PARAMETER_LIST),
            WIN32::ERROR_OPERATION_IN_PROGRESS => RawError::Kind(WIN32::ERROR_OPERATION_IN_PROGRESS),
            WIN32::ERROR_BAD_DEVICE_PATH => RawError::Kind(WIN32::ERROR_BAD_DEVICE_PATH),
            WIN32::ERROR_TOO_MANY_DESCRIPTORS => RawError::Kind(WIN32::ERROR_TOO_MANY_DESCRIPTORS),
            WIN32::ERROR_SCRUB_DATA_DISABLED => RawError::Kind(WIN32::ERROR_SCRUB_DATA_DISABLED),
            WIN32::ERROR_NOT_REDUNDANT_STORAGE => RawError::Kind(WIN32::ERROR_NOT_REDUNDANT_STORAGE),
            WIN32::ERROR_RESIDENT_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_RESIDENT_FILE_NOT_SUPPORTED),
            WIN32::ERROR_COMPRESSED_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_COMPRESSED_FILE_NOT_SUPPORTED),
            WIN32::ERROR_DIRECTORY_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_DIRECTORY_NOT_SUPPORTED),
            WIN32::ERROR_NOT_READ_FROM_COPY => RawError::Kind(WIN32::ERROR_NOT_READ_FROM_COPY),
            WIN32::ERROR_FT_WRITE_FAILURE => RawError::Kind(WIN32::ERROR_FT_WRITE_FAILURE),
            WIN32::ERROR_FT_DI_SCAN_REQUIRED => RawError::Kind(WIN32::ERROR_FT_DI_SCAN_REQUIRED),
            WIN32::ERROR_INVALID_KERNEL_INFO_VERSION => RawError::Kind(WIN32::ERROR_INVALID_KERNEL_INFO_VERSION),
            WIN32::ERROR_INVALID_PEP_INFO_VERSION => RawError::Kind(WIN32::ERROR_INVALID_PEP_INFO_VERSION),
            WIN32::ERROR_OBJECT_NOT_EXTERNALLY_BACKED => RawError::Kind(WIN32::ERROR_OBJECT_NOT_EXTERNALLY_BACKED),
            WIN32::ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN => RawError::Kind(WIN32::ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN),
            WIN32::ERROR_COMPRESSION_NOT_BENEFICIAL => RawError::Kind(WIN32::ERROR_COMPRESSION_NOT_BENEFICIAL),
            WIN32::ERROR_STORAGE_TOPOLOGY_ID_MISMATCH => RawError::Kind(WIN32::ERROR_STORAGE_TOPOLOGY_ID_MISMATCH),
            WIN32::ERROR_BLOCKED_BY_PARENTAL_CONTROLS => RawError::Kind(WIN32::ERROR_BLOCKED_BY_PARENTAL_CONTROLS),
            WIN32::ERROR_BLOCK_TOO_MANY_REFERENCES => RawError::Kind(WIN32::ERROR_BLOCK_TOO_MANY_REFERENCES),
            WIN32::ERROR_MARKED_TO_DISALLOW_WRITES => RawError::Kind(WIN32::ERROR_MARKED_TO_DISALLOW_WRITES),
            WIN32::ERROR_ENCLAVE_FAILURE => RawError::Kind(WIN32::ERROR_ENCLAVE_FAILURE),
            WIN32::ERROR_FAIL_NOACTION_REBOOT => RawError::Kind(WIN32::ERROR_FAIL_NOACTION_REBOOT),
            WIN32::ERROR_FAIL_SHUTDOWN => RawError::Kind(WIN32::ERROR_FAIL_SHUTDOWN),
            WIN32::ERROR_FAIL_RESTART => RawError::Kind(WIN32::ERROR_FAIL_RESTART),
            WIN32::ERROR_MAX_SESSIONS_REACHED => RawError::Kind(WIN32::ERROR_MAX_SESSIONS_REACHED),
            WIN32::ERROR_NETWORK_ACCESS_DENIED_EDP => RawError::Kind(WIN32::ERROR_NETWORK_ACCESS_DENIED_EDP),
            WIN32::ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL => RawError::Kind(WIN32::ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL),
            WIN32::ERROR_EDP_POLICY_DENIES_OPERATION => RawError::Kind(WIN32::ERROR_EDP_POLICY_DENIES_OPERATION),
            WIN32::ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED => RawError::Kind(WIN32::ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED),
            WIN32::ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT),
            WIN32::ERROR_CLOUD_FILE_PROVIDER_UNKNOWN => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROVIDER_UNKNOWN),
            WIN32::ERROR_DEVICE_IN_MAINTENANCE => RawError::Kind(WIN32::ERROR_DEVICE_IN_MAINTENANCE),
            WIN32::ERROR_NOT_SUPPORTED_ON_DAX => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_ON_DAX),
            WIN32::ERROR_DAX_MAPPING_EXISTS => RawError::Kind(WIN32::ERROR_DAX_MAPPING_EXISTS),
            WIN32::ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING),
            WIN32::ERROR_CLOUD_FILE_METADATA_CORRUPT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_METADATA_CORRUPT),
            WIN32::ERROR_CLOUD_FILE_METADATA_TOO_LARGE => RawError::Kind(WIN32::ERROR_CLOUD_FILE_METADATA_TOO_LARGE),
            WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE),
            WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH),
            WIN32::ERROR_CHILD_PROCESS_BLOCKED => RawError::Kind(WIN32::ERROR_CHILD_PROCESS_BLOCKED),
            WIN32::ERROR_STORAGE_LOST_DATA_PERSISTENCE => RawError::Kind(WIN32::ERROR_STORAGE_LOST_DATA_PERSISTENCE),
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE => RawError::Kind(WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE),
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT => RawError::Kind(WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT),
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY => RawError::Kind(WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY),
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN => RawError::Kind(WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN),
            WIN32::ERROR_GDI_HANDLE_LEAK => RawError::Kind(WIN32::ERROR_GDI_HANDLE_LEAK),
            WIN32::ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS => RawError::Kind(WIN32::ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS),
            WIN32::ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED),
            WIN32::ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED),
            WIN32::ERROR_NOT_A_CLOUD_FILE => RawError::Kind(WIN32::ERROR_NOT_A_CLOUD_FILE),
            WIN32::ERROR_CLOUD_FILE_NOT_IN_SYNC => RawError::Kind(WIN32::ERROR_CLOUD_FILE_NOT_IN_SYNC),
            WIN32::ERROR_CLOUD_FILE_ALREADY_CONNECTED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_ALREADY_CONNECTED),
            WIN32::ERROR_CLOUD_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_NOT_SUPPORTED),
            WIN32::ERROR_CLOUD_FILE_INVALID_REQUEST => RawError::Kind(WIN32::ERROR_CLOUD_FILE_INVALID_REQUEST),
            WIN32::ERROR_CLOUD_FILE_READ_ONLY_VOLUME => RawError::Kind(WIN32::ERROR_CLOUD_FILE_READ_ONLY_VOLUME),
            WIN32::ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY => RawError::Kind(WIN32::ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY),
            WIN32::ERROR_CLOUD_FILE_VALIDATION_FAILED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_VALIDATION_FAILED),
            WIN32::ERROR_SMB1_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_SMB1_NOT_AVAILABLE),
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION => RawError::Kind(WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION),
            WIN32::ERROR_CLOUD_FILE_AUTHENTICATION_FAILED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_AUTHENTICATION_FAILED),
            WIN32::ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES => RawError::Kind(WIN32::ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES),
            WIN32::ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE => RawError::Kind(WIN32::ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE),
            WIN32::ERROR_CLOUD_FILE_UNSUCCESSFUL => RawError::Kind(WIN32::ERROR_CLOUD_FILE_UNSUCCESSFUL),
            WIN32::ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT),
            WIN32::ERROR_CLOUD_FILE_IN_USE => RawError::Kind(WIN32::ERROR_CLOUD_FILE_IN_USE),
            WIN32::ERROR_CLOUD_FILE_PINNED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PINNED),
            WIN32::ERROR_CLOUD_FILE_REQUEST_ABORTED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_REQUEST_ABORTED),
            WIN32::ERROR_CLOUD_FILE_PROPERTY_CORRUPT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROPERTY_CORRUPT),
            WIN32::ERROR_CLOUD_FILE_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_ACCESS_DENIED),
            WIN32::ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS => RawError::Kind(WIN32::ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS),
            WIN32::ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT),
            WIN32::ERROR_CLOUD_FILE_REQUEST_CANCELED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_REQUEST_CANCELED),
            WIN32::ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED),
            WIN32::ERROR_THREAD_MODE_ALREADY_BACKGROUND => RawError::Kind(WIN32::ERROR_THREAD_MODE_ALREADY_BACKGROUND),
            WIN32::ERROR_THREAD_MODE_NOT_BACKGROUND => RawError::Kind(WIN32::ERROR_THREAD_MODE_NOT_BACKGROUND),
            WIN32::ERROR_PROCESS_MODE_ALREADY_BACKGROUND => RawError::Kind(WIN32::ERROR_PROCESS_MODE_ALREADY_BACKGROUND),
            WIN32::ERROR_PROCESS_MODE_NOT_BACKGROUND => RawError::Kind(WIN32::ERROR_PROCESS_MODE_NOT_BACKGROUND),
            WIN32::ERROR_CLOUD_FILE_PROVIDER_TERMINATED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_PROVIDER_TERMINATED),
            WIN32::ERROR_NOT_A_CLOUD_SYNC_ROOT => RawError::Kind(WIN32::ERROR_NOT_A_CLOUD_SYNC_ROOT),
            WIN32::ERROR_FILE_PROTECTED_UNDER_DPL => RawError::Kind(WIN32::ERROR_FILE_PROTECTED_UNDER_DPL),
            WIN32::ERROR_VOLUME_NOT_CLUSTER_ALIGNED => RawError::Kind(WIN32::ERROR_VOLUME_NOT_CLUSTER_ALIGNED),
            WIN32::ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND => RawError::Kind(WIN32::ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND),
            WIN32::ERROR_APPX_FILE_NOT_ENCRYPTED => RawError::Kind(WIN32::ERROR_APPX_FILE_NOT_ENCRYPTED),
            WIN32::ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED => RawError::Kind(WIN32::ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED),
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET => RawError::Kind(WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET),
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE => RawError::Kind(WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE),
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER => RawError::Kind(WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER),
            WIN32::ERROR_LINUX_SUBSYSTEM_NOT_PRESENT => RawError::Kind(WIN32::ERROR_LINUX_SUBSYSTEM_NOT_PRESENT),
            WIN32::ERROR_FT_READ_FAILURE => RawError::Kind(WIN32::ERROR_FT_READ_FAILURE),
            WIN32::ERROR_STORAGE_RESERVE_ID_INVALID => RawError::Kind(WIN32::ERROR_STORAGE_RESERVE_ID_INVALID),
            WIN32::ERROR_STORAGE_RESERVE_DOES_NOT_EXIST => RawError::Kind(WIN32::ERROR_STORAGE_RESERVE_DOES_NOT_EXIST),
            WIN32::ERROR_STORAGE_RESERVE_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_STORAGE_RESERVE_ALREADY_EXISTS),
            WIN32::ERROR_STORAGE_RESERVE_NOT_EMPTY => RawError::Kind(WIN32::ERROR_STORAGE_RESERVE_NOT_EMPTY),
            WIN32::ERROR_NOT_A_DAX_VOLUME => RawError::Kind(WIN32::ERROR_NOT_A_DAX_VOLUME),
            WIN32::ERROR_NOT_DAX_MAPPABLE => RawError::Kind(WIN32::ERROR_NOT_DAX_MAPPABLE),
            WIN32::ERROR_TIME_SENSITIVE_THREAD => RawError::Kind(WIN32::ERROR_TIME_SENSITIVE_THREAD),
            WIN32::ERROR_DPL_NOT_SUPPORTED_FOR_USER => RawError::Kind(WIN32::ERROR_DPL_NOT_SUPPORTED_FOR_USER),
            WIN32::ERROR_CASE_DIFFERING_NAMES_IN_DIR => RawError::Kind(WIN32::ERROR_CASE_DIFFERING_NAMES_IN_DIR),
            WIN32::ERROR_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_FILE_NOT_SUPPORTED),
            WIN32::ERROR_CLOUD_FILE_REQUEST_TIMEOUT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_REQUEST_TIMEOUT),
            WIN32::ERROR_NO_TASK_QUEUE => RawError::Kind(WIN32::ERROR_NO_TASK_QUEUE),
            WIN32::ERROR_SRC_SRV_DLL_LOAD_FAILED => RawError::Kind(WIN32::ERROR_SRC_SRV_DLL_LOAD_FAILED),
            WIN32::ERROR_NOT_SUPPORTED_WITH_BTT => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_BTT),
            WIN32::ERROR_ENCRYPTION_DISABLED => RawError::Kind(WIN32::ERROR_ENCRYPTION_DISABLED),
            WIN32::ERROR_ENCRYPTING_METADATA_DISALLOWED => RawError::Kind(WIN32::ERROR_ENCRYPTING_METADATA_DISALLOWED),
            WIN32::ERROR_CANT_CLEAR_ENCRYPTION_FLAG => RawError::Kind(WIN32::ERROR_CANT_CLEAR_ENCRYPTION_FLAG),
            WIN32::ERROR_NO_SUCH_DEVICE => RawError::Kind(WIN32::ERROR_NO_SUCH_DEVICE),
            WIN32::ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED => RawError::Kind(WIN32::ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED),
            WIN32::ERROR_FILE_SNAP_IN_PROGRESS => RawError::Kind(WIN32::ERROR_FILE_SNAP_IN_PROGRESS),
            WIN32::ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED),
            WIN32::ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED),
            WIN32::ERROR_FILE_SNAP_IO_NOT_COORDINATED => RawError::Kind(WIN32::ERROR_FILE_SNAP_IO_NOT_COORDINATED),
            WIN32::ERROR_FILE_SNAP_UNEXPECTED_ERROR => RawError::Kind(WIN32::ERROR_FILE_SNAP_UNEXPECTED_ERROR),
            WIN32::ERROR_FILE_SNAP_INVALID_PARAMETER => RawError::Kind(WIN32::ERROR_FILE_SNAP_INVALID_PARAMETER),
            WIN32::ERROR_UNSATISFIED_DEPENDENCIES => RawError::Kind(WIN32::ERROR_UNSATISFIED_DEPENDENCIES),
            WIN32::ERROR_CASE_SENSITIVE_PATH => RawError::Kind(WIN32::ERROR_CASE_SENSITIVE_PATH),
            WIN32::ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR => RawError::Kind(WIN32::ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR),
            WIN32::ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED => RawError::Kind(WIN32::ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED),
            WIN32::ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION => RawError::Kind(WIN32::ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION),
            WIN32::ERROR_DLP_POLICY_DENIES_OPERATION => RawError::Kind(WIN32::ERROR_DLP_POLICY_DENIES_OPERATION),
            WIN32::ERROR_SECURITY_DENIES_OPERATION => RawError::Kind(WIN32::ERROR_SECURITY_DENIES_OPERATION),
            WIN32::ERROR_UNTRUSTED_MOUNT_POINT => RawError::Kind(WIN32::ERROR_UNTRUSTED_MOUNT_POINT),
            WIN32::ERROR_DLP_POLICY_SILENTLY_FAIL => RawError::Kind(WIN32::ERROR_DLP_POLICY_SILENTLY_FAIL),
            WIN32::ERROR_CAPAUTHZ_NOT_DEVUNLOCKED => RawError::Kind(WIN32::ERROR_CAPAUTHZ_NOT_DEVUNLOCKED),
            WIN32::ERROR_CAPAUTHZ_CHANGE_TYPE => RawError::Kind(WIN32::ERROR_CAPAUTHZ_CHANGE_TYPE),
            WIN32::ERROR_CAPAUTHZ_NOT_PROVISIONED => RawError::Kind(WIN32::ERROR_CAPAUTHZ_NOT_PROVISIONED),
            WIN32::ERROR_CAPAUTHZ_NOT_AUTHORIZED => RawError::Kind(WIN32::ERROR_CAPAUTHZ_NOT_AUTHORIZED),
            WIN32::ERROR_CAPAUTHZ_NO_POLICY => RawError::Kind(WIN32::ERROR_CAPAUTHZ_NO_POLICY),
            WIN32::ERROR_CAPAUTHZ_DB_CORRUPTED => RawError::Kind(WIN32::ERROR_CAPAUTHZ_DB_CORRUPTED),
            WIN32::ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG => RawError::Kind(WIN32::ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG),
            WIN32::ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY => RawError::Kind(WIN32::ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY),
            WIN32::ERROR_CAPAUTHZ_SCCD_PARSE_ERROR => RawError::Kind(WIN32::ERROR_CAPAUTHZ_SCCD_PARSE_ERROR),
            WIN32::ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED => RawError::Kind(WIN32::ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED),
            WIN32::ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH => RawError::Kind(WIN32::ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH),
            WIN32::ERROR_CIMFS_IMAGE_CORRUPT => RawError::Kind(WIN32::ERROR_CIMFS_IMAGE_CORRUPT),
            WIN32::ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED),
            WIN32::ERROR_STORAGE_STACK_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_STORAGE_STACK_ACCESS_DENIED),
            WIN32::ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES => RawError::Kind(WIN32::ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES),
            WIN32::ERROR_INDEX_OUT_OF_BOUNDS => RawError::Kind(WIN32::ERROR_INDEX_OUT_OF_BOUNDS),
            WIN32::ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT => RawError::Kind(WIN32::ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT),
            WIN32::ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT => RawError::Kind(WIN32::ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT),
            WIN32::ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT => RawError::Kind(WIN32::ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT),
            WIN32::ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT => RawError::Kind(WIN32::ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT),
            WIN32::ERROR_DEVICE_HARDWARE_ERROR => RawError::Kind(WIN32::ERROR_DEVICE_HARDWARE_ERROR),
            WIN32::ERROR_INVALID_ADDRESS => RawError::Kind(WIN32::ERROR_INVALID_ADDRESS),
            WIN32::ERROR_HAS_SYSTEM_CRITICAL_FILES => RawError::Kind(WIN32::ERROR_HAS_SYSTEM_CRITICAL_FILES),
            WIN32::ERROR_ENCRYPTED_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_ENCRYPTED_FILE_NOT_SUPPORTED),
            WIN32::ERROR_SPARSE_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_SPARSE_FILE_NOT_SUPPORTED),
            WIN32::ERROR_PAGEFILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_PAGEFILE_NOT_SUPPORTED),
            WIN32::ERROR_VOLUME_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_VOLUME_NOT_SUPPORTED),
            WIN32::ERROR_NOT_SUPPORTED_WITH_BYPASSIO => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_BYPASSIO),
            WIN32::ERROR_NO_BYPASSIO_DRIVER_SUPPORT => RawError::Kind(WIN32::ERROR_NO_BYPASSIO_DRIVER_SUPPORT),
            WIN32::ERROR_NOT_SUPPORTED_WITH_ENCRYPTION => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_ENCRYPTION),
            WIN32::ERROR_NOT_SUPPORTED_WITH_COMPRESSION => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_COMPRESSION),
            WIN32::ERROR_NOT_SUPPORTED_WITH_REPLICATION => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_REPLICATION),
            WIN32::ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION),
            WIN32::ERROR_NOT_SUPPORTED_WITH_AUDITING => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_AUDITING),
            WIN32::ERROR_USER_PROFILE_LOAD => RawError::Kind(WIN32::ERROR_USER_PROFILE_LOAD),
            WIN32::ERROR_SESSION_KEY_TOO_SHORT => RawError::Kind(WIN32::ERROR_SESSION_KEY_TOO_SHORT),
            WIN32::ERROR_ACCESS_DENIED_APPDATA => RawError::Kind(WIN32::ERROR_ACCESS_DENIED_APPDATA),
            WIN32::ERROR_NOT_SUPPORTED_WITH_MONITORING => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_MONITORING),
            WIN32::ERROR_NOT_SUPPORTED_WITH_SNAPSHOT => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_SNAPSHOT),
            WIN32::ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION),
            WIN32::ERROR_BYPASSIO_FLT_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_BYPASSIO_FLT_NOT_SUPPORTED),
            WIN32::ERROR_DEVICE_RESET_REQUIRED => RawError::Kind(WIN32::ERROR_DEVICE_RESET_REQUIRED),
            WIN32::ERROR_VOLUME_WRITE_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_VOLUME_WRITE_ACCESS_DENIED),
            WIN32::ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE),
            WIN32::ERROR_FS_METADATA_INCONSISTENT => RawError::Kind(WIN32::ERROR_FS_METADATA_INCONSISTENT),
            WIN32::ERROR_BLOCK_WEAK_REFERENCE_INVALID => RawError::Kind(WIN32::ERROR_BLOCK_WEAK_REFERENCE_INVALID),
            WIN32::ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID => RawError::Kind(WIN32::ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID),
            WIN32::ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID => RawError::Kind(WIN32::ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID),
            WIN32::ERROR_BLOCK_SHARED => RawError::Kind(WIN32::ERROR_BLOCK_SHARED),
            WIN32::ERROR_ARITHMETIC_OVERFLOW => RawError::Kind(WIN32::ERROR_ARITHMETIC_OVERFLOW),
            WIN32::ERROR_PIPE_CONNECTED => RawError::Kind(WIN32::ERROR_PIPE_CONNECTED),
            WIN32::ERROR_PIPE_LISTENING => RawError::Kind(WIN32::ERROR_PIPE_LISTENING),
            WIN32::ERROR_VERIFIER_STOP => RawError::Kind(WIN32::ERROR_VERIFIER_STOP),
            WIN32::ERROR_ABIOS_ERROR => RawError::Kind(WIN32::ERROR_ABIOS_ERROR),
            WIN32::ERROR_WX86_WARNING => RawError::Kind(WIN32::ERROR_WX86_WARNING),
            WIN32::ERROR_WX86_ERROR => RawError::Kind(WIN32::ERROR_WX86_ERROR),
            WIN32::ERROR_TIMER_NOT_CANCELED => RawError::Kind(WIN32::ERROR_TIMER_NOT_CANCELED),
            WIN32::ERROR_UNWIND => RawError::Kind(WIN32::ERROR_UNWIND),
            WIN32::ERROR_BAD_STACK => RawError::Kind(WIN32::ERROR_BAD_STACK),
            WIN32::ERROR_INVALID_UNWIND_TARGET => RawError::Kind(WIN32::ERROR_INVALID_UNWIND_TARGET),
            WIN32::ERROR_INVALID_PORT_ATTRIBUTES => RawError::Kind(WIN32::ERROR_INVALID_PORT_ATTRIBUTES),
            WIN32::ERROR_PORT_MESSAGE_TOO_LONG => RawError::Kind(WIN32::ERROR_PORT_MESSAGE_TOO_LONG),
            WIN32::ERROR_INVALID_QUOTA_LOWER => RawError::Kind(WIN32::ERROR_INVALID_QUOTA_LOWER),
            WIN32::ERROR_DEVICE_ALREADY_ATTACHED => RawError::Kind(WIN32::ERROR_DEVICE_ALREADY_ATTACHED),
            WIN32::ERROR_INSTRUCTION_MISALIGNMENT => RawError::Kind(WIN32::ERROR_INSTRUCTION_MISALIGNMENT),
            WIN32::ERROR_PROFILING_NOT_STARTED => RawError::Kind(WIN32::ERROR_PROFILING_NOT_STARTED),
            WIN32::ERROR_PROFILING_NOT_STOPPED => RawError::Kind(WIN32::ERROR_PROFILING_NOT_STOPPED),
            WIN32::ERROR_COULD_NOT_INTERPRET => RawError::Kind(WIN32::ERROR_COULD_NOT_INTERPRET),
            WIN32::ERROR_PROFILING_AT_LIMIT => RawError::Kind(WIN32::ERROR_PROFILING_AT_LIMIT),
            WIN32::ERROR_CANT_WAIT => RawError::Kind(WIN32::ERROR_CANT_WAIT),
            WIN32::ERROR_CANT_TERMINATE_SELF => RawError::Kind(WIN32::ERROR_CANT_TERMINATE_SELF),
            WIN32::ERROR_UNEXPECTED_MM_CREATE_ERR => RawError::Kind(WIN32::ERROR_UNEXPECTED_MM_CREATE_ERR),
            WIN32::ERROR_UNEXPECTED_MM_MAP_ERROR => RawError::Kind(WIN32::ERROR_UNEXPECTED_MM_MAP_ERROR),
            WIN32::ERROR_UNEXPECTED_MM_EXTEND_ERR => RawError::Kind(WIN32::ERROR_UNEXPECTED_MM_EXTEND_ERR),
            WIN32::ERROR_BAD_FUNCTION_TABLE => RawError::Kind(WIN32::ERROR_BAD_FUNCTION_TABLE),
            WIN32::ERROR_NO_GUID_TRANSLATION => RawError::Kind(WIN32::ERROR_NO_GUID_TRANSLATION),
            WIN32::ERROR_INVALID_LDT_SIZE => RawError::Kind(WIN32::ERROR_INVALID_LDT_SIZE),
            WIN32::ERROR_INVALID_LDT_OFFSET => RawError::Kind(WIN32::ERROR_INVALID_LDT_OFFSET),
            WIN32::ERROR_INVALID_LDT_DESCRIPTOR => RawError::Kind(WIN32::ERROR_INVALID_LDT_DESCRIPTOR),
            WIN32::ERROR_TOO_MANY_THREADS => RawError::Kind(WIN32::ERROR_TOO_MANY_THREADS),
            WIN32::ERROR_THREAD_NOT_IN_PROCESS => RawError::Kind(WIN32::ERROR_THREAD_NOT_IN_PROCESS),
            WIN32::ERROR_PAGEFILE_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_PAGEFILE_QUOTA_EXCEEDED),
            WIN32::ERROR_LOGON_SERVER_CONFLICT => RawError::Kind(WIN32::ERROR_LOGON_SERVER_CONFLICT),
            WIN32::ERROR_SYNCHRONIZATION_REQUIRED => RawError::Kind(WIN32::ERROR_SYNCHRONIZATION_REQUIRED),
            WIN32::ERROR_NET_OPEN_FAILED => RawError::Kind(WIN32::ERROR_NET_OPEN_FAILED),
            WIN32::ERROR_IO_PRIVILEGE_FAILED => RawError::Kind(WIN32::ERROR_IO_PRIVILEGE_FAILED),
            WIN32::ERROR_CONTROL_C_EXIT => RawError::Kind(WIN32::ERROR_CONTROL_C_EXIT),
            WIN32::ERROR_MISSING_SYSTEMFILE => RawError::Kind(WIN32::ERROR_MISSING_SYSTEMFILE),
            WIN32::ERROR_UNHANDLED_EXCEPTION => RawError::Kind(WIN32::ERROR_UNHANDLED_EXCEPTION),
            WIN32::ERROR_APP_INIT_FAILURE => RawError::Kind(WIN32::ERROR_APP_INIT_FAILURE),
            WIN32::ERROR_PAGEFILE_CREATE_FAILED => RawError::Kind(WIN32::ERROR_PAGEFILE_CREATE_FAILED),
            WIN32::ERROR_INVALID_IMAGE_HASH => RawError::Kind(WIN32::ERROR_INVALID_IMAGE_HASH),
            WIN32::ERROR_NO_PAGEFILE => RawError::Kind(WIN32::ERROR_NO_PAGEFILE),
            WIN32::ERROR_ILLEGAL_FLOAT_CONTEXT => RawError::Kind(WIN32::ERROR_ILLEGAL_FLOAT_CONTEXT),
            WIN32::ERROR_NO_EVENT_PAIR => RawError::Kind(WIN32::ERROR_NO_EVENT_PAIR),
            WIN32::ERROR_DOMAIN_CTRLR_CONFIG_ERROR => RawError::Kind(WIN32::ERROR_DOMAIN_CTRLR_CONFIG_ERROR),
            WIN32::ERROR_ILLEGAL_CHARACTER => RawError::Kind(WIN32::ERROR_ILLEGAL_CHARACTER),
            WIN32::ERROR_UNDEFINED_CHARACTER => RawError::Kind(WIN32::ERROR_UNDEFINED_CHARACTER),
            WIN32::ERROR_FLOPPY_VOLUME => RawError::Kind(WIN32::ERROR_FLOPPY_VOLUME),
            WIN32::ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT => RawError::Kind(WIN32::ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT),
            WIN32::ERROR_BACKUP_CONTROLLER => RawError::Kind(WIN32::ERROR_BACKUP_CONTROLLER),
            WIN32::ERROR_MUTANT_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_MUTANT_LIMIT_EXCEEDED),
            WIN32::ERROR_FS_DRIVER_REQUIRED => RawError::Kind(WIN32::ERROR_FS_DRIVER_REQUIRED),
            WIN32::ERROR_CANNOT_LOAD_REGISTRY_FILE => RawError::Kind(WIN32::ERROR_CANNOT_LOAD_REGISTRY_FILE),
            WIN32::ERROR_DEBUG_ATTACH_FAILED => RawError::Kind(WIN32::ERROR_DEBUG_ATTACH_FAILED),
            WIN32::ERROR_SYSTEM_PROCESS_TERMINATED => RawError::Kind(WIN32::ERROR_SYSTEM_PROCESS_TERMINATED),
            WIN32::ERROR_DATA_NOT_ACCEPTED => RawError::Kind(WIN32::ERROR_DATA_NOT_ACCEPTED),
            WIN32::ERROR_VDM_HARD_ERROR => RawError::Kind(WIN32::ERROR_VDM_HARD_ERROR),
            WIN32::ERROR_DRIVER_CANCEL_TIMEOUT => RawError::Kind(WIN32::ERROR_DRIVER_CANCEL_TIMEOUT),
            WIN32::ERROR_REPLY_MESSAGE_MISMATCH => RawError::Kind(WIN32::ERROR_REPLY_MESSAGE_MISMATCH),
            WIN32::ERROR_LOST_WRITEBEHIND_DATA => RawError::Kind(WIN32::ERROR_LOST_WRITEBEHIND_DATA),
            WIN32::ERROR_CLIENT_SERVER_PARAMETERS_INVALID => RawError::Kind(WIN32::ERROR_CLIENT_SERVER_PARAMETERS_INVALID),
            WIN32::ERROR_NOT_TINY_STREAM => RawError::Kind(WIN32::ERROR_NOT_TINY_STREAM),
            WIN32::ERROR_STACK_OVERFLOW_READ => RawError::Kind(WIN32::ERROR_STACK_OVERFLOW_READ),
            WIN32::ERROR_CONVERT_TO_LARGE => RawError::Kind(WIN32::ERROR_CONVERT_TO_LARGE),
            WIN32::ERROR_FOUND_OUT_OF_SCOPE => RawError::Kind(WIN32::ERROR_FOUND_OUT_OF_SCOPE),
            WIN32::ERROR_ALLOCATE_BUCKET => RawError::Kind(WIN32::ERROR_ALLOCATE_BUCKET),
            WIN32::ERROR_MARSHALL_OVERFLOW => RawError::Kind(WIN32::ERROR_MARSHALL_OVERFLOW),
            WIN32::ERROR_INVALID_VARIANT => RawError::Kind(WIN32::ERROR_INVALID_VARIANT),
            WIN32::ERROR_BAD_COMPRESSION_BUFFER => RawError::Kind(WIN32::ERROR_BAD_COMPRESSION_BUFFER),
            WIN32::ERROR_AUDIT_FAILED => RawError::Kind(WIN32::ERROR_AUDIT_FAILED),
            WIN32::ERROR_TIMER_RESOLUTION_NOT_SET => RawError::Kind(WIN32::ERROR_TIMER_RESOLUTION_NOT_SET),
            WIN32::ERROR_INSUFFICIENT_LOGON_INFO => RawError::Kind(WIN32::ERROR_INSUFFICIENT_LOGON_INFO),
            WIN32::ERROR_BAD_DLL_ENTRYPOINT => RawError::Kind(WIN32::ERROR_BAD_DLL_ENTRYPOINT),
            WIN32::ERROR_BAD_SERVICE_ENTRYPOINT => RawError::Kind(WIN32::ERROR_BAD_SERVICE_ENTRYPOINT),
            WIN32::ERROR_IP_ADDRESS_CONFLICT1 => RawError::Kind(WIN32::ERROR_IP_ADDRESS_CONFLICT1),
            WIN32::ERROR_IP_ADDRESS_CONFLICT2 => RawError::Kind(WIN32::ERROR_IP_ADDRESS_CONFLICT2),
            WIN32::ERROR_REGISTRY_QUOTA_LIMIT => RawError::Kind(WIN32::ERROR_REGISTRY_QUOTA_LIMIT),
            WIN32::ERROR_NO_CALLBACK_ACTIVE => RawError::Kind(WIN32::ERROR_NO_CALLBACK_ACTIVE),
            WIN32::ERROR_PWD_TOO_SHORT => RawError::Kind(WIN32::ERROR_PWD_TOO_SHORT),
            WIN32::ERROR_PWD_TOO_RECENT => RawError::Kind(WIN32::ERROR_PWD_TOO_RECENT),
            WIN32::ERROR_PWD_HISTORY_CONFLICT => RawError::Kind(WIN32::ERROR_PWD_HISTORY_CONFLICT),
            WIN32::ERROR_UNSUPPORTED_COMPRESSION => RawError::Kind(WIN32::ERROR_UNSUPPORTED_COMPRESSION),
            WIN32::ERROR_INVALID_HW_PROFILE => RawError::Kind(WIN32::ERROR_INVALID_HW_PROFILE),
            WIN32::ERROR_INVALID_PLUGPLAY_DEVICE_PATH => RawError::Kind(WIN32::ERROR_INVALID_PLUGPLAY_DEVICE_PATH),
            WIN32::ERROR_QUOTA_LIST_INCONSISTENT => RawError::Kind(WIN32::ERROR_QUOTA_LIST_INCONSISTENT),
            WIN32::ERROR_EVALUATION_EXPIRATION => RawError::Kind(WIN32::ERROR_EVALUATION_EXPIRATION),
            WIN32::ERROR_ILLEGAL_DLL_RELOCATION => RawError::Kind(WIN32::ERROR_ILLEGAL_DLL_RELOCATION),
            WIN32::ERROR_DLL_INIT_FAILED_LOGOFF => RawError::Kind(WIN32::ERROR_DLL_INIT_FAILED_LOGOFF),
            WIN32::ERROR_VALIDATE_CONTINUE => RawError::Kind(WIN32::ERROR_VALIDATE_CONTINUE),
            WIN32::ERROR_NO_MORE_MATCHES => RawError::Kind(WIN32::ERROR_NO_MORE_MATCHES),
            WIN32::ERROR_RANGE_LIST_CONFLICT => RawError::Kind(WIN32::ERROR_RANGE_LIST_CONFLICT),
            WIN32::ERROR_SERVER_SID_MISMATCH => RawError::Kind(WIN32::ERROR_SERVER_SID_MISMATCH),
            WIN32::ERROR_CANT_ENABLE_DENY_ONLY => RawError::Kind(WIN32::ERROR_CANT_ENABLE_DENY_ONLY),
            WIN32::ERROR_FLOAT_MULTIPLE_FAULTS => RawError::Kind(WIN32::ERROR_FLOAT_MULTIPLE_FAULTS),
            WIN32::ERROR_FLOAT_MULTIPLE_TRAPS => RawError::Kind(WIN32::ERROR_FLOAT_MULTIPLE_TRAPS),
            WIN32::ERROR_NOINTERFACE => RawError::Kind(WIN32::ERROR_NOINTERFACE),
            WIN32::ERROR_DRIVER_FAILED_SLEEP => RawError::Kind(WIN32::ERROR_DRIVER_FAILED_SLEEP),
            WIN32::ERROR_CORRUPT_SYSTEM_FILE => RawError::Kind(WIN32::ERROR_CORRUPT_SYSTEM_FILE),
            WIN32::ERROR_COMMITMENT_MINIMUM => RawError::Kind(WIN32::ERROR_COMMITMENT_MINIMUM),
            WIN32::ERROR_PNP_RESTART_ENUMERATION => RawError::Kind(WIN32::ERROR_PNP_RESTART_ENUMERATION),
            WIN32::ERROR_SYSTEM_IMAGE_BAD_SIGNATURE => RawError::Kind(WIN32::ERROR_SYSTEM_IMAGE_BAD_SIGNATURE),
            WIN32::ERROR_PNP_REBOOT_REQUIRED => RawError::Kind(WIN32::ERROR_PNP_REBOOT_REQUIRED),
            WIN32::ERROR_INSUFFICIENT_POWER => RawError::Kind(WIN32::ERROR_INSUFFICIENT_POWER),
            WIN32::ERROR_MULTIPLE_FAULT_VIOLATION => RawError::Kind(WIN32::ERROR_MULTIPLE_FAULT_VIOLATION),
            WIN32::ERROR_SYSTEM_SHUTDOWN => RawError::Kind(WIN32::ERROR_SYSTEM_SHUTDOWN),
            WIN32::ERROR_PORT_NOT_SET => RawError::Kind(WIN32::ERROR_PORT_NOT_SET),
            WIN32::ERROR_DS_VERSION_CHECK_FAILURE => RawError::Kind(WIN32::ERROR_DS_VERSION_CHECK_FAILURE),
            WIN32::ERROR_RANGE_NOT_FOUND => RawError::Kind(WIN32::ERROR_RANGE_NOT_FOUND),
            WIN32::ERROR_NOT_SAFE_MODE_DRIVER => RawError::Kind(WIN32::ERROR_NOT_SAFE_MODE_DRIVER),
            WIN32::ERROR_FAILED_DRIVER_ENTRY => RawError::Kind(WIN32::ERROR_FAILED_DRIVER_ENTRY),
            WIN32::ERROR_DEVICE_ENUMERATION_ERROR => RawError::Kind(WIN32::ERROR_DEVICE_ENUMERATION_ERROR),
            WIN32::ERROR_MOUNT_POINT_NOT_RESOLVED => RawError::Kind(WIN32::ERROR_MOUNT_POINT_NOT_RESOLVED),
            WIN32::ERROR_INVALID_DEVICE_OBJECT_PARAMETER => RawError::Kind(WIN32::ERROR_INVALID_DEVICE_OBJECT_PARAMETER),
            WIN32::ERROR_MCA_OCCURED => RawError::Kind(WIN32::ERROR_MCA_OCCURED),
            WIN32::ERROR_DRIVER_DATABASE_ERROR => RawError::Kind(WIN32::ERROR_DRIVER_DATABASE_ERROR),
            WIN32::ERROR_SYSTEM_HIVE_TOO_LARGE => RawError::Kind(WIN32::ERROR_SYSTEM_HIVE_TOO_LARGE),
            WIN32::ERROR_DRIVER_FAILED_PRIOR_UNLOAD => RawError::Kind(WIN32::ERROR_DRIVER_FAILED_PRIOR_UNLOAD),
            WIN32::ERROR_VOLSNAP_PREPARE_HIBERNATE => RawError::Kind(WIN32::ERROR_VOLSNAP_PREPARE_HIBERNATE),
            WIN32::ERROR_HIBERNATION_FAILURE => RawError::Kind(WIN32::ERROR_HIBERNATION_FAILURE),
            WIN32::ERROR_PWD_TOO_LONG => RawError::Kind(WIN32::ERROR_PWD_TOO_LONG),
            WIN32::ERROR_FILE_SYSTEM_LIMITATION => RawError::Kind(WIN32::ERROR_FILE_SYSTEM_LIMITATION),
            WIN32::ERROR_ASSERTION_FAILURE => RawError::Kind(WIN32::ERROR_ASSERTION_FAILURE),
            WIN32::ERROR_ACPI_ERROR => RawError::Kind(WIN32::ERROR_ACPI_ERROR),
            WIN32::ERROR_WOW_ASSERTION => RawError::Kind(WIN32::ERROR_WOW_ASSERTION),
            WIN32::ERROR_PNP_BAD_MPS_TABLE => RawError::Kind(WIN32::ERROR_PNP_BAD_MPS_TABLE),
            WIN32::ERROR_PNP_TRANSLATION_FAILED => RawError::Kind(WIN32::ERROR_PNP_TRANSLATION_FAILED),
            WIN32::ERROR_PNP_IRQ_TRANSLATION_FAILED => RawError::Kind(WIN32::ERROR_PNP_IRQ_TRANSLATION_FAILED),
            WIN32::ERROR_PNP_INVALID_ID => RawError::Kind(WIN32::ERROR_PNP_INVALID_ID),
            WIN32::ERROR_WAKE_SYSTEM_DEBUGGER => RawError::Kind(WIN32::ERROR_WAKE_SYSTEM_DEBUGGER),
            WIN32::ERROR_HANDLES_CLOSED => RawError::Kind(WIN32::ERROR_HANDLES_CLOSED),
            WIN32::ERROR_EXTRANEOUS_INFORMATION => RawError::Kind(WIN32::ERROR_EXTRANEOUS_INFORMATION),
            WIN32::ERROR_RXACT_COMMIT_NECESSARY => RawError::Kind(WIN32::ERROR_RXACT_COMMIT_NECESSARY),
            WIN32::ERROR_MEDIA_CHECK => RawError::Kind(WIN32::ERROR_MEDIA_CHECK),
            WIN32::ERROR_GUID_SUBSTITUTION_MADE => RawError::Kind(WIN32::ERROR_GUID_SUBSTITUTION_MADE),
            WIN32::ERROR_STOPPED_ON_SYMLINK => RawError::Kind(WIN32::ERROR_STOPPED_ON_SYMLINK),
            WIN32::ERROR_LONGJUMP => RawError::Kind(WIN32::ERROR_LONGJUMP),
            WIN32::ERROR_PLUGPLAY_QUERY_VETOED => RawError::Kind(WIN32::ERROR_PLUGPLAY_QUERY_VETOED),
            WIN32::ERROR_UNWIND_CONSOLIDATE => RawError::Kind(WIN32::ERROR_UNWIND_CONSOLIDATE),
            WIN32::ERROR_REGISTRY_HIVE_RECOVERED => RawError::Kind(WIN32::ERROR_REGISTRY_HIVE_RECOVERED),
            WIN32::ERROR_DLL_MIGHT_BE_INSECURE => RawError::Kind(WIN32::ERROR_DLL_MIGHT_BE_INSECURE),
            WIN32::ERROR_DLL_MIGHT_BE_INCOMPATIBLE => RawError::Kind(WIN32::ERROR_DLL_MIGHT_BE_INCOMPATIBLE),
            WIN32::ERROR_DBG_EXCEPTION_NOT_HANDLED => RawError::Kind(WIN32::ERROR_DBG_EXCEPTION_NOT_HANDLED),
            WIN32::ERROR_DBG_REPLY_LATER => RawError::Kind(WIN32::ERROR_DBG_REPLY_LATER),
            WIN32::ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE => RawError::Kind(WIN32::ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE),
            WIN32::ERROR_DBG_TERMINATE_THREAD => RawError::Kind(WIN32::ERROR_DBG_TERMINATE_THREAD),
            WIN32::ERROR_DBG_TERMINATE_PROCESS => RawError::Kind(WIN32::ERROR_DBG_TERMINATE_PROCESS),
            WIN32::ERROR_DBG_CONTROL_C => RawError::Kind(WIN32::ERROR_DBG_CONTROL_C),
            WIN32::ERROR_DBG_PRINTEXCEPTION_C => RawError::Kind(WIN32::ERROR_DBG_PRINTEXCEPTION_C),
            WIN32::ERROR_DBG_RIPEXCEPTION => RawError::Kind(WIN32::ERROR_DBG_RIPEXCEPTION),
            WIN32::ERROR_DBG_CONTROL_BREAK => RawError::Kind(WIN32::ERROR_DBG_CONTROL_BREAK),
            WIN32::ERROR_DBG_COMMAND_EXCEPTION => RawError::Kind(WIN32::ERROR_DBG_COMMAND_EXCEPTION),
            WIN32::ERROR_OBJECT_NAME_EXISTS => RawError::Kind(WIN32::ERROR_OBJECT_NAME_EXISTS),
            WIN32::ERROR_THREAD_WAS_SUSPENDED => RawError::Kind(WIN32::ERROR_THREAD_WAS_SUSPENDED),
            WIN32::ERROR_IMAGE_NOT_AT_BASE => RawError::Kind(WIN32::ERROR_IMAGE_NOT_AT_BASE),
            WIN32::ERROR_RXACT_STATE_CREATED => RawError::Kind(WIN32::ERROR_RXACT_STATE_CREATED),
            WIN32::ERROR_SEGMENT_NOTIFICATION => RawError::Kind(WIN32::ERROR_SEGMENT_NOTIFICATION),
            WIN32::ERROR_BAD_CURRENT_DIRECTORY => RawError::Kind(WIN32::ERROR_BAD_CURRENT_DIRECTORY),
            WIN32::ERROR_FT_READ_RECOVERY_FROM_BACKUP => RawError::Kind(WIN32::ERROR_FT_READ_RECOVERY_FROM_BACKUP),
            WIN32::ERROR_FT_WRITE_RECOVERY => RawError::Kind(WIN32::ERROR_FT_WRITE_RECOVERY),
            WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH => RawError::Kind(WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH),
            WIN32::ERROR_RECEIVE_PARTIAL => RawError::Kind(WIN32::ERROR_RECEIVE_PARTIAL),
            WIN32::ERROR_RECEIVE_EXPEDITED => RawError::Kind(WIN32::ERROR_RECEIVE_EXPEDITED),
            WIN32::ERROR_RECEIVE_PARTIAL_EXPEDITED => RawError::Kind(WIN32::ERROR_RECEIVE_PARTIAL_EXPEDITED),
            WIN32::ERROR_EVENT_DONE => RawError::Kind(WIN32::ERROR_EVENT_DONE),
            WIN32::ERROR_EVENT_PENDING => RawError::Kind(WIN32::ERROR_EVENT_PENDING),
            WIN32::ERROR_CHECKING_FILE_SYSTEM => RawError::Kind(WIN32::ERROR_CHECKING_FILE_SYSTEM),
            WIN32::ERROR_FATAL_APP_EXIT => RawError::Kind(WIN32::ERROR_FATAL_APP_EXIT),
            WIN32::ERROR_PREDEFINED_HANDLE => RawError::Kind(WIN32::ERROR_PREDEFINED_HANDLE),
            WIN32::ERROR_WAS_UNLOCKED => RawError::Kind(WIN32::ERROR_WAS_UNLOCKED),
            WIN32::ERROR_SERVICE_NOTIFICATION => RawError::Kind(WIN32::ERROR_SERVICE_NOTIFICATION),
            WIN32::ERROR_WAS_LOCKED => RawError::Kind(WIN32::ERROR_WAS_LOCKED),
            WIN32::ERROR_LOG_HARD_ERROR => RawError::Kind(WIN32::ERROR_LOG_HARD_ERROR),
            WIN32::ERROR_ALREADY_WIN32 => RawError::Kind(WIN32::ERROR_ALREADY_WIN32),
            WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE => RawError::Kind(WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE),
            WIN32::ERROR_NO_YIELD_PERFORMED => RawError::Kind(WIN32::ERROR_NO_YIELD_PERFORMED),
            WIN32::ERROR_TIMER_RESUME_IGNORED => RawError::Kind(WIN32::ERROR_TIMER_RESUME_IGNORED),
            WIN32::ERROR_ARBITRATION_UNHANDLED => RawError::Kind(WIN32::ERROR_ARBITRATION_UNHANDLED),
            WIN32::ERROR_CARDBUS_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CARDBUS_NOT_SUPPORTED),
            WIN32::ERROR_MP_PROCESSOR_MISMATCH => RawError::Kind(WIN32::ERROR_MP_PROCESSOR_MISMATCH),
            WIN32::ERROR_HIBERNATED => RawError::Kind(WIN32::ERROR_HIBERNATED),
            WIN32::ERROR_RESUME_HIBERNATION => RawError::Kind(WIN32::ERROR_RESUME_HIBERNATION),
            WIN32::ERROR_FIRMWARE_UPDATED => RawError::Kind(WIN32::ERROR_FIRMWARE_UPDATED),
            WIN32::ERROR_DRIVERS_LEAKING_LOCKED_PAGES => RawError::Kind(WIN32::ERROR_DRIVERS_LEAKING_LOCKED_PAGES),
            WIN32::ERROR_WAKE_SYSTEM => RawError::Kind(WIN32::ERROR_WAKE_SYSTEM),
            WIN32::ERROR_WAIT_1 => RawError::Kind(WIN32::ERROR_WAIT_1),
            WIN32::ERROR_WAIT_2 => RawError::Kind(WIN32::ERROR_WAIT_2),
            WIN32::ERROR_WAIT_3 => RawError::Kind(WIN32::ERROR_WAIT_3),
            WIN32::ERROR_WAIT_63 => RawError::Kind(WIN32::ERROR_WAIT_63),
            WIN32::ERROR_ABANDONED_WAIT_0 => RawError::Kind(WIN32::ERROR_ABANDONED_WAIT_0),
            WIN32::ERROR_ABANDONED_WAIT_63 => RawError::Kind(WIN32::ERROR_ABANDONED_WAIT_63),
            WIN32::ERROR_USER_APC => RawError::Kind(WIN32::ERROR_USER_APC),
            WIN32::ERROR_KERNEL_APC => RawError::Kind(WIN32::ERROR_KERNEL_APC),
            WIN32::ERROR_ALERTED => RawError::Kind(WIN32::ERROR_ALERTED),
            WIN32::ERROR_ELEVATION_REQUIRED => RawError::Kind(WIN32::ERROR_ELEVATION_REQUIRED),
            WIN32::ERROR_REPARSE => RawError::Kind(WIN32::ERROR_REPARSE),
            WIN32::ERROR_OPLOCK_BREAK_IN_PROGRESS => RawError::Kind(WIN32::ERROR_OPLOCK_BREAK_IN_PROGRESS),
            WIN32::ERROR_VOLUME_MOUNTED => RawError::Kind(WIN32::ERROR_VOLUME_MOUNTED),
            WIN32::ERROR_RXACT_COMMITTED => RawError::Kind(WIN32::ERROR_RXACT_COMMITTED),
            WIN32::ERROR_NOTIFY_CLEANUP => RawError::Kind(WIN32::ERROR_NOTIFY_CLEANUP),
            WIN32::ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED => RawError::Kind(WIN32::ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED),
            WIN32::ERROR_PAGE_FAULT_TRANSITION => RawError::Kind(WIN32::ERROR_PAGE_FAULT_TRANSITION),
            WIN32::ERROR_PAGE_FAULT_DEMAND_ZERO => RawError::Kind(WIN32::ERROR_PAGE_FAULT_DEMAND_ZERO),
            WIN32::ERROR_PAGE_FAULT_COPY_ON_WRITE => RawError::Kind(WIN32::ERROR_PAGE_FAULT_COPY_ON_WRITE),
            WIN32::ERROR_PAGE_FAULT_GUARD_PAGE => RawError::Kind(WIN32::ERROR_PAGE_FAULT_GUARD_PAGE),
            WIN32::ERROR_PAGE_FAULT_PAGING_FILE => RawError::Kind(WIN32::ERROR_PAGE_FAULT_PAGING_FILE),
            WIN32::ERROR_CACHE_PAGE_LOCKED => RawError::Kind(WIN32::ERROR_CACHE_PAGE_LOCKED),
            WIN32::ERROR_CRASH_DUMP => RawError::Kind(WIN32::ERROR_CRASH_DUMP),
            WIN32::ERROR_BUFFER_ALL_ZEROS => RawError::Kind(WIN32::ERROR_BUFFER_ALL_ZEROS),
            WIN32::ERROR_REPARSE_OBJECT => RawError::Kind(WIN32::ERROR_REPARSE_OBJECT),
            WIN32::ERROR_RESOURCE_REQUIREMENTS_CHANGED => RawError::Kind(WIN32::ERROR_RESOURCE_REQUIREMENTS_CHANGED),
            WIN32::ERROR_TRANSLATION_COMPLETE => RawError::Kind(WIN32::ERROR_TRANSLATION_COMPLETE),
            WIN32::ERROR_NOTHING_TO_TERMINATE => RawError::Kind(WIN32::ERROR_NOTHING_TO_TERMINATE),
            WIN32::ERROR_PROCESS_NOT_IN_JOB => RawError::Kind(WIN32::ERROR_PROCESS_NOT_IN_JOB),
            WIN32::ERROR_PROCESS_IN_JOB => RawError::Kind(WIN32::ERROR_PROCESS_IN_JOB),
            WIN32::ERROR_VOLSNAP_HIBERNATE_READY => RawError::Kind(WIN32::ERROR_VOLSNAP_HIBERNATE_READY),
            WIN32::ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY => RawError::Kind(WIN32::ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY),
            WIN32::ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED => RawError::Kind(WIN32::ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED),
            WIN32::ERROR_INTERRUPT_STILL_CONNECTED => RawError::Kind(WIN32::ERROR_INTERRUPT_STILL_CONNECTED),
            WIN32::ERROR_WAIT_FOR_OPLOCK => RawError::Kind(WIN32::ERROR_WAIT_FOR_OPLOCK),
            WIN32::ERROR_DBG_EXCEPTION_HANDLED => RawError::Kind(WIN32::ERROR_DBG_EXCEPTION_HANDLED),
            WIN32::ERROR_DBG_CONTINUE => RawError::Kind(WIN32::ERROR_DBG_CONTINUE),
            WIN32::ERROR_CALLBACK_POP_STACK => RawError::Kind(WIN32::ERROR_CALLBACK_POP_STACK),
            WIN32::ERROR_COMPRESSION_DISABLED => RawError::Kind(WIN32::ERROR_COMPRESSION_DISABLED),
            WIN32::ERROR_CANTFETCHBACKWARDS => RawError::Kind(WIN32::ERROR_CANTFETCHBACKWARDS),
            WIN32::ERROR_CANTSCROLLBACKWARDS => RawError::Kind(WIN32::ERROR_CANTSCROLLBACKWARDS),
            WIN32::ERROR_ROWSNOTRELEASED => RawError::Kind(WIN32::ERROR_ROWSNOTRELEASED),
            WIN32::ERROR_BAD_ACCESSOR_FLAGS => RawError::Kind(WIN32::ERROR_BAD_ACCESSOR_FLAGS),
            WIN32::ERROR_ERRORS_ENCOUNTERED => RawError::Kind(WIN32::ERROR_ERRORS_ENCOUNTERED),
            WIN32::ERROR_NOT_CAPABLE => RawError::Kind(WIN32::ERROR_NOT_CAPABLE),
            WIN32::ERROR_REQUEST_OUT_OF_SEQUENCE => RawError::Kind(WIN32::ERROR_REQUEST_OUT_OF_SEQUENCE),
            WIN32::ERROR_VERSION_PARSE_ERROR => RawError::Kind(WIN32::ERROR_VERSION_PARSE_ERROR),
            WIN32::ERROR_BADSTARTPOSITION => RawError::Kind(WIN32::ERROR_BADSTARTPOSITION),
            WIN32::ERROR_MEMORY_HARDWARE => RawError::Kind(WIN32::ERROR_MEMORY_HARDWARE),
            WIN32::ERROR_DISK_REPAIR_DISABLED => RawError::Kind(WIN32::ERROR_DISK_REPAIR_DISABLED),
            WIN32::ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE => RawError::Kind(WIN32::ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE),
            WIN32::ERROR_SYSTEM_POWERSTATE_TRANSITION => RawError::Kind(WIN32::ERROR_SYSTEM_POWERSTATE_TRANSITION),
            WIN32::ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION => RawError::Kind(WIN32::ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION),
            WIN32::ERROR_MCA_EXCEPTION => RawError::Kind(WIN32::ERROR_MCA_EXCEPTION),
            WIN32::ERROR_ACCESS_AUDIT_BY_POLICY => RawError::Kind(WIN32::ERROR_ACCESS_AUDIT_BY_POLICY),
            WIN32::ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY => RawError::Kind(WIN32::ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY),
            WIN32::ERROR_ABANDON_HIBERFILE => RawError::Kind(WIN32::ERROR_ABANDON_HIBERFILE),
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED => RawError::Kind(WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED),
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR => RawError::Kind(WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR),
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR => RawError::Kind(WIN32::ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR),
            WIN32::ERROR_BAD_MCFG_TABLE => RawError::Kind(WIN32::ERROR_BAD_MCFG_TABLE),
            WIN32::ERROR_DISK_REPAIR_REDIRECTED => RawError::Kind(WIN32::ERROR_DISK_REPAIR_REDIRECTED),
            WIN32::ERROR_DISK_REPAIR_UNSUCCESSFUL => RawError::Kind(WIN32::ERROR_DISK_REPAIR_UNSUCCESSFUL),
            WIN32::ERROR_CORRUPT_LOG_OVERFULL => RawError::Kind(WIN32::ERROR_CORRUPT_LOG_OVERFULL),
            WIN32::ERROR_CORRUPT_LOG_CORRUPTED => RawError::Kind(WIN32::ERROR_CORRUPT_LOG_CORRUPTED),
            WIN32::ERROR_CORRUPT_LOG_UNAVAILABLE => RawError::Kind(WIN32::ERROR_CORRUPT_LOG_UNAVAILABLE),
            WIN32::ERROR_CORRUPT_LOG_DELETED_FULL => RawError::Kind(WIN32::ERROR_CORRUPT_LOG_DELETED_FULL),
            WIN32::ERROR_CORRUPT_LOG_CLEARED => RawError::Kind(WIN32::ERROR_CORRUPT_LOG_CLEARED),
            WIN32::ERROR_ORPHAN_NAME_EXHAUSTED => RawError::Kind(WIN32::ERROR_ORPHAN_NAME_EXHAUSTED),
            WIN32::ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE => RawError::Kind(WIN32::ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE),
            WIN32::ERROR_CANNOT_GRANT_REQUESTED_OPLOCK => RawError::Kind(WIN32::ERROR_CANNOT_GRANT_REQUESTED_OPLOCK),
            WIN32::ERROR_CANNOT_BREAK_OPLOCK => RawError::Kind(WIN32::ERROR_CANNOT_BREAK_OPLOCK),
            WIN32::ERROR_OPLOCK_HANDLE_CLOSED => RawError::Kind(WIN32::ERROR_OPLOCK_HANDLE_CLOSED),
            WIN32::ERROR_NO_ACE_CONDITION => RawError::Kind(WIN32::ERROR_NO_ACE_CONDITION),
            WIN32::ERROR_INVALID_ACE_CONDITION => RawError::Kind(WIN32::ERROR_INVALID_ACE_CONDITION),
            WIN32::ERROR_FILE_HANDLE_REVOKED => RawError::Kind(WIN32::ERROR_FILE_HANDLE_REVOKED),
            WIN32::ERROR_IMAGE_AT_DIFFERENT_BASE => RawError::Kind(WIN32::ERROR_IMAGE_AT_DIFFERENT_BASE),
            WIN32::ERROR_ENCRYPTED_IO_NOT_POSSIBLE => RawError::Kind(WIN32::ERROR_ENCRYPTED_IO_NOT_POSSIBLE),
            WIN32::ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS => RawError::Kind(WIN32::ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS),
            WIN32::ERROR_QUOTA_ACTIVITY => RawError::Kind(WIN32::ERROR_QUOTA_ACTIVITY),
            WIN32::ERROR_HANDLE_REVOKED => RawError::Kind(WIN32::ERROR_HANDLE_REVOKED),
            WIN32::ERROR_CALLBACK_INVOKE_INLINE => RawError::Kind(WIN32::ERROR_CALLBACK_INVOKE_INLINE),
            WIN32::ERROR_CPU_SET_INVALID => RawError::Kind(WIN32::ERROR_CPU_SET_INVALID),
            WIN32::ERROR_ENCLAVE_NOT_TERMINATED => RawError::Kind(WIN32::ERROR_ENCLAVE_NOT_TERMINATED),
            WIN32::ERROR_ENCLAVE_VIOLATION => RawError::Kind(WIN32::ERROR_ENCLAVE_VIOLATION),
            WIN32::ERROR_SERVER_TRANSPORT_CONFLICT => RawError::Kind(WIN32::ERROR_SERVER_TRANSPORT_CONFLICT),
            WIN32::ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT => RawError::Kind(WIN32::ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT),
            WIN32::ERROR_FT_READ_FROM_COPY_FAILURE => RawError::Kind(WIN32::ERROR_FT_READ_FROM_COPY_FAILURE),
            WIN32::ERROR_SECTION_DIRECT_MAP_ONLY => RawError::Kind(WIN32::ERROR_SECTION_DIRECT_MAP_ONLY),
            WIN32::ERROR_EA_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_EA_ACCESS_DENIED),
            WIN32::ERROR_OPERATION_ABORTED => RawError::Kind(WIN32::ERROR_OPERATION_ABORTED),
            WIN32::ERROR_IO_INCOMPLETE => RawError::Kind(WIN32::ERROR_IO_INCOMPLETE),
            WIN32::ERROR_IO_PENDING => RawError::Kind(WIN32::ERROR_IO_PENDING),
            WIN32::ERROR_NOACCESS => RawError::Kind(WIN32::ERROR_NOACCESS),
            WIN32::ERROR_SWAPERROR => RawError::Kind(WIN32::ERROR_SWAPERROR),
            WIN32::ERROR_STACK_OVERFLOW => RawError::Kind(WIN32::ERROR_STACK_OVERFLOW),
            WIN32::ERROR_INVALID_MESSAGE => RawError::Kind(WIN32::ERROR_INVALID_MESSAGE),
            WIN32::ERROR_CAN_NOT_COMPLETE => RawError::Kind(WIN32::ERROR_CAN_NOT_COMPLETE),
            WIN32::ERROR_INVALID_FLAGS => RawError::Kind(WIN32::ERROR_INVALID_FLAGS),
            WIN32::ERROR_UNRECOGNIZED_VOLUME => RawError::Kind(WIN32::ERROR_UNRECOGNIZED_VOLUME),
            WIN32::ERROR_FILE_INVALID => RawError::Kind(WIN32::ERROR_FILE_INVALID),
            WIN32::ERROR_FULLSCREEN_MODE => RawError::Kind(WIN32::ERROR_FULLSCREEN_MODE),
            WIN32::ERROR_NO_TOKEN => RawError::Kind(WIN32::ERROR_NO_TOKEN),
            WIN32::ERROR_BADDB => RawError::Kind(WIN32::ERROR_BADDB),
            WIN32::ERROR_BADKEY => RawError::Kind(WIN32::ERROR_BADKEY),
            WIN32::ERROR_CANTOPEN => RawError::Kind(WIN32::ERROR_CANTOPEN),
            WIN32::ERROR_CANTREAD => RawError::Kind(WIN32::ERROR_CANTREAD),
            WIN32::ERROR_CANTWRITE => RawError::Kind(WIN32::ERROR_CANTWRITE),
            WIN32::ERROR_REGISTRY_RECOVERED => RawError::Kind(WIN32::ERROR_REGISTRY_RECOVERED),
            WIN32::ERROR_REGISTRY_CORRUPT => RawError::Kind(WIN32::ERROR_REGISTRY_CORRUPT),
            WIN32::ERROR_REGISTRY_IO_FAILED => RawError::Kind(WIN32::ERROR_REGISTRY_IO_FAILED),
            WIN32::ERROR_NOT_REGISTRY_FILE => RawError::Kind(WIN32::ERROR_NOT_REGISTRY_FILE),
            WIN32::ERROR_KEY_DELETED => RawError::Kind(WIN32::ERROR_KEY_DELETED),
            WIN32::ERROR_NO_LOG_SPACE => RawError::Kind(WIN32::ERROR_NO_LOG_SPACE),
            WIN32::ERROR_KEY_HAS_CHILDREN => RawError::Kind(WIN32::ERROR_KEY_HAS_CHILDREN),
            WIN32::ERROR_CHILD_MUST_BE_VOLATILE => RawError::Kind(WIN32::ERROR_CHILD_MUST_BE_VOLATILE),
            WIN32::ERROR_NOTIFY_ENUM_DIR => RawError::Kind(WIN32::ERROR_NOTIFY_ENUM_DIR),
            WIN32::ERROR_DEPENDENT_SERVICES_RUNNING => RawError::Kind(WIN32::ERROR_DEPENDENT_SERVICES_RUNNING),
            WIN32::ERROR_INVALID_SERVICE_CONTROL => RawError::Kind(WIN32::ERROR_INVALID_SERVICE_CONTROL),
            WIN32::ERROR_SERVICE_REQUEST_TIMEOUT => RawError::Kind(WIN32::ERROR_SERVICE_REQUEST_TIMEOUT),
            WIN32::ERROR_SERVICE_NO_THREAD => RawError::Kind(WIN32::ERROR_SERVICE_NO_THREAD),
            WIN32::ERROR_SERVICE_DATABASE_LOCKED => RawError::Kind(WIN32::ERROR_SERVICE_DATABASE_LOCKED),
            WIN32::ERROR_SERVICE_ALREADY_RUNNING => RawError::Kind(WIN32::ERROR_SERVICE_ALREADY_RUNNING),
            WIN32::ERROR_INVALID_SERVICE_ACCOUNT => RawError::Kind(WIN32::ERROR_INVALID_SERVICE_ACCOUNT),
            WIN32::ERROR_SERVICE_DISABLED => RawError::Kind(WIN32::ERROR_SERVICE_DISABLED),
            WIN32::ERROR_CIRCULAR_DEPENDENCY => RawError::Kind(WIN32::ERROR_CIRCULAR_DEPENDENCY),
            WIN32::ERROR_SERVICE_DOES_NOT_EXIST => RawError::Kind(WIN32::ERROR_SERVICE_DOES_NOT_EXIST),
            WIN32::ERROR_SERVICE_CANNOT_ACCEPT_CTRL => RawError::Kind(WIN32::ERROR_SERVICE_CANNOT_ACCEPT_CTRL),
            WIN32::ERROR_SERVICE_NOT_ACTIVE => RawError::Kind(WIN32::ERROR_SERVICE_NOT_ACTIVE),
            WIN32::ERROR_FAILED_SERVICE_CONTROLLER_CONNECT => RawError::Kind(WIN32::ERROR_FAILED_SERVICE_CONTROLLER_CONNECT),
            WIN32::ERROR_EXCEPTION_IN_SERVICE => RawError::Kind(WIN32::ERROR_EXCEPTION_IN_SERVICE),
            WIN32::ERROR_DATABASE_DOES_NOT_EXIST => RawError::Kind(WIN32::ERROR_DATABASE_DOES_NOT_EXIST),
            WIN32::ERROR_SERVICE_SPECIFIC_ERROR => RawError::Kind(WIN32::ERROR_SERVICE_SPECIFIC_ERROR),
            WIN32::ERROR_PROCESS_ABORTED => RawError::Kind(WIN32::ERROR_PROCESS_ABORTED),
            WIN32::ERROR_SERVICE_DEPENDENCY_FAIL => RawError::Kind(WIN32::ERROR_SERVICE_DEPENDENCY_FAIL),
            WIN32::ERROR_SERVICE_LOGON_FAILED => RawError::Kind(WIN32::ERROR_SERVICE_LOGON_FAILED),
            WIN32::ERROR_SERVICE_START_HANG => RawError::Kind(WIN32::ERROR_SERVICE_START_HANG),
            WIN32::ERROR_INVALID_SERVICE_LOCK => RawError::Kind(WIN32::ERROR_INVALID_SERVICE_LOCK),
            WIN32::ERROR_SERVICE_MARKED_FOR_DELETE => RawError::Kind(WIN32::ERROR_SERVICE_MARKED_FOR_DELETE),
            WIN32::ERROR_SERVICE_EXISTS => RawError::Kind(WIN32::ERROR_SERVICE_EXISTS),
            WIN32::ERROR_ALREADY_RUNNING_LKG => RawError::Kind(WIN32::ERROR_ALREADY_RUNNING_LKG),
            WIN32::ERROR_SERVICE_DEPENDENCY_DELETED => RawError::Kind(WIN32::ERROR_SERVICE_DEPENDENCY_DELETED),
            WIN32::ERROR_BOOT_ALREADY_ACCEPTED => RawError::Kind(WIN32::ERROR_BOOT_ALREADY_ACCEPTED),
            WIN32::ERROR_SERVICE_NEVER_STARTED => RawError::Kind(WIN32::ERROR_SERVICE_NEVER_STARTED),
            WIN32::ERROR_DUPLICATE_SERVICE_NAME => RawError::Kind(WIN32::ERROR_DUPLICATE_SERVICE_NAME),
            WIN32::ERROR_DIFFERENT_SERVICE_ACCOUNT => RawError::Kind(WIN32::ERROR_DIFFERENT_SERVICE_ACCOUNT),
            WIN32::ERROR_CANNOT_DETECT_DRIVER_FAILURE => RawError::Kind(WIN32::ERROR_CANNOT_DETECT_DRIVER_FAILURE),
            WIN32::ERROR_CANNOT_DETECT_PROCESS_ABORT => RawError::Kind(WIN32::ERROR_CANNOT_DETECT_PROCESS_ABORT),
            WIN32::ERROR_NO_RECOVERY_PROGRAM => RawError::Kind(WIN32::ERROR_NO_RECOVERY_PROGRAM),
            WIN32::ERROR_SERVICE_NOT_IN_EXE => RawError::Kind(WIN32::ERROR_SERVICE_NOT_IN_EXE),
            WIN32::ERROR_NOT_SAFEBOOT_SERVICE => RawError::Kind(WIN32::ERROR_NOT_SAFEBOOT_SERVICE),
            WIN32::ERROR_END_OF_MEDIA => RawError::Kind(WIN32::ERROR_END_OF_MEDIA),
            WIN32::ERROR_FILEMARK_DETECTED => RawError::Kind(WIN32::ERROR_FILEMARK_DETECTED),
            WIN32::ERROR_BEGINNING_OF_MEDIA => RawError::Kind(WIN32::ERROR_BEGINNING_OF_MEDIA),
            WIN32::ERROR_SETMARK_DETECTED => RawError::Kind(WIN32::ERROR_SETMARK_DETECTED),
            WIN32::ERROR_NO_DATA_DETECTED => RawError::Kind(WIN32::ERROR_NO_DATA_DETECTED),
            WIN32::ERROR_PARTITION_FAILURE => RawError::Kind(WIN32::ERROR_PARTITION_FAILURE),
            WIN32::ERROR_INVALID_BLOCK_LENGTH => RawError::Kind(WIN32::ERROR_INVALID_BLOCK_LENGTH),
            WIN32::ERROR_DEVICE_NOT_PARTITIONED => RawError::Kind(WIN32::ERROR_DEVICE_NOT_PARTITIONED),
            WIN32::ERROR_UNABLE_TO_LOCK_MEDIA => RawError::Kind(WIN32::ERROR_UNABLE_TO_LOCK_MEDIA),
            WIN32::ERROR_UNABLE_TO_UNLOAD_MEDIA => RawError::Kind(WIN32::ERROR_UNABLE_TO_UNLOAD_MEDIA),
            WIN32::ERROR_MEDIA_CHANGED => RawError::Kind(WIN32::ERROR_MEDIA_CHANGED),
            WIN32::ERROR_BUS_RESET => RawError::Kind(WIN32::ERROR_BUS_RESET),
            WIN32::ERROR_NO_MEDIA_IN_DRIVE => RawError::Kind(WIN32::ERROR_NO_MEDIA_IN_DRIVE),
            WIN32::ERROR_NO_UNICODE_TRANSLATION => RawError::Kind(WIN32::ERROR_NO_UNICODE_TRANSLATION),
            WIN32::ERROR_DLL_INIT_FAILED => RawError::Kind(WIN32::ERROR_DLL_INIT_FAILED),
            WIN32::ERROR_SHUTDOWN_IN_PROGRESS => RawError::Kind(WIN32::ERROR_SHUTDOWN_IN_PROGRESS),
            WIN32::ERROR_NO_SHUTDOWN_IN_PROGRESS => RawError::Kind(WIN32::ERROR_NO_SHUTDOWN_IN_PROGRESS),
            WIN32::ERROR_IO_DEVICE => RawError::Kind(WIN32::ERROR_IO_DEVICE),
            WIN32::ERROR_SERIAL_NO_DEVICE => RawError::Kind(WIN32::ERROR_SERIAL_NO_DEVICE),
            WIN32::ERROR_IRQ_BUSY => RawError::Kind(WIN32::ERROR_IRQ_BUSY),
            WIN32::ERROR_MORE_WRITES => RawError::Kind(WIN32::ERROR_MORE_WRITES),
            WIN32::ERROR_COUNTER_TIMEOUT => RawError::Kind(WIN32::ERROR_COUNTER_TIMEOUT),
            WIN32::ERROR_FLOPPY_ID_MARK_NOT_FOUND => RawError::Kind(WIN32::ERROR_FLOPPY_ID_MARK_NOT_FOUND),
            WIN32::ERROR_FLOPPY_WRONG_CYLINDER => RawError::Kind(WIN32::ERROR_FLOPPY_WRONG_CYLINDER),
            WIN32::ERROR_FLOPPY_UNKNOWN_ERROR => RawError::Kind(WIN32::ERROR_FLOPPY_UNKNOWN_ERROR),
            WIN32::ERROR_FLOPPY_BAD_REGISTERS => RawError::Kind(WIN32::ERROR_FLOPPY_BAD_REGISTERS),
            WIN32::ERROR_DISK_RECALIBRATE_FAILED => RawError::Kind(WIN32::ERROR_DISK_RECALIBRATE_FAILED),
            WIN32::ERROR_DISK_OPERATION_FAILED => RawError::Kind(WIN32::ERROR_DISK_OPERATION_FAILED),
            WIN32::ERROR_DISK_RESET_FAILED => RawError::Kind(WIN32::ERROR_DISK_RESET_FAILED),
            WIN32::ERROR_EOM_OVERFLOW => RawError::Kind(WIN32::ERROR_EOM_OVERFLOW),
            WIN32::ERROR_NOT_ENOUGH_SERVER_MEMORY => RawError::Kind(WIN32::ERROR_NOT_ENOUGH_SERVER_MEMORY),
            WIN32::ERROR_POSSIBLE_DEADLOCK => RawError::Kind(WIN32::ERROR_POSSIBLE_DEADLOCK),
            WIN32::ERROR_MAPPED_ALIGNMENT => RawError::Kind(WIN32::ERROR_MAPPED_ALIGNMENT),
            WIN32::ERROR_SET_POWER_STATE_VETOED => RawError::Kind(WIN32::ERROR_SET_POWER_STATE_VETOED),
            WIN32::ERROR_SET_POWER_STATE_FAILED => RawError::Kind(WIN32::ERROR_SET_POWER_STATE_FAILED),
            WIN32::ERROR_TOO_MANY_LINKS => RawError::Kind(WIN32::ERROR_TOO_MANY_LINKS),
            WIN32::ERROR_OLD_WIN_VERSION => RawError::Kind(WIN32::ERROR_OLD_WIN_VERSION),
            WIN32::ERROR_APP_WRONG_OS => RawError::Kind(WIN32::ERROR_APP_WRONG_OS),
            WIN32::ERROR_SINGLE_INSTANCE_APP => RawError::Kind(WIN32::ERROR_SINGLE_INSTANCE_APP),
            WIN32::ERROR_RMODE_APP => RawError::Kind(WIN32::ERROR_RMODE_APP),
            WIN32::ERROR_INVALID_DLL => RawError::Kind(WIN32::ERROR_INVALID_DLL),
            WIN32::ERROR_NO_ASSOCIATION => RawError::Kind(WIN32::ERROR_NO_ASSOCIATION),
            WIN32::ERROR_DDE_FAIL => RawError::Kind(WIN32::ERROR_DDE_FAIL),
            WIN32::ERROR_DLL_NOT_FOUND => RawError::Kind(WIN32::ERROR_DLL_NOT_FOUND),
            WIN32::ERROR_NO_MORE_USER_HANDLES => RawError::Kind(WIN32::ERROR_NO_MORE_USER_HANDLES),
            WIN32::ERROR_MESSAGE_SYNC_ONLY => RawError::Kind(WIN32::ERROR_MESSAGE_SYNC_ONLY),
            WIN32::ERROR_SOURCE_ELEMENT_EMPTY => RawError::Kind(WIN32::ERROR_SOURCE_ELEMENT_EMPTY),
            WIN32::ERROR_DESTINATION_ELEMENT_FULL => RawError::Kind(WIN32::ERROR_DESTINATION_ELEMENT_FULL),
            WIN32::ERROR_ILLEGAL_ELEMENT_ADDRESS => RawError::Kind(WIN32::ERROR_ILLEGAL_ELEMENT_ADDRESS),
            WIN32::ERROR_MAGAZINE_NOT_PRESENT => RawError::Kind(WIN32::ERROR_MAGAZINE_NOT_PRESENT),
            WIN32::ERROR_DEVICE_REINITIALIZATION_NEEDED => RawError::Kind(WIN32::ERROR_DEVICE_REINITIALIZATION_NEEDED),
            WIN32::ERROR_DEVICE_REQUIRES_CLEANING => RawError::Kind(WIN32::ERROR_DEVICE_REQUIRES_CLEANING),
            WIN32::ERROR_DEVICE_DOOR_OPEN => RawError::Kind(WIN32::ERROR_DEVICE_DOOR_OPEN),
            WIN32::ERROR_DEVICE_NOT_CONNECTED => RawError::Kind(WIN32::ERROR_DEVICE_NOT_CONNECTED),
            WIN32::ERROR_NOT_FOUND => RawError::Kind(WIN32::ERROR_NOT_FOUND),
            WIN32::E_PROP_ID_UNSUPPORTED => RawError::Kind(WIN32::E_PROP_ID_UNSUPPORTED),
            WIN32::ERROR_NO_MATCH => RawError::Kind(WIN32::ERROR_NO_MATCH),
            WIN32::ERROR_SET_NOT_FOUND => RawError::Kind(WIN32::ERROR_SET_NOT_FOUND),
            WIN32::E_PROP_SET_UNSUPPORTED => RawError::Kind(WIN32::E_PROP_SET_UNSUPPORTED),
            WIN32::ERROR_POINT_NOT_FOUND => RawError::Kind(WIN32::ERROR_POINT_NOT_FOUND),
            WIN32::ERROR_NO_TRACKING_SERVICE => RawError::Kind(WIN32::ERROR_NO_TRACKING_SERVICE),
            WIN32::ERROR_NO_VOLUME_ID => RawError::Kind(WIN32::ERROR_NO_VOLUME_ID),
            WIN32::ERROR_UNABLE_TO_REMOVE_REPLACED => RawError::Kind(WIN32::ERROR_UNABLE_TO_REMOVE_REPLACED),
            WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT => RawError::Kind(WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT),
            WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT_2 => RawError::Kind(WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT_2),
            WIN32::ERROR_JOURNAL_DELETE_IN_PROGRESS => RawError::Kind(WIN32::ERROR_JOURNAL_DELETE_IN_PROGRESS),
            WIN32::ERROR_JOURNAL_NOT_ACTIVE => RawError::Kind(WIN32::ERROR_JOURNAL_NOT_ACTIVE),
            WIN32::ERROR_POTENTIAL_FILE_FOUND => RawError::Kind(WIN32::ERROR_POTENTIAL_FILE_FOUND),
            WIN32::ERROR_JOURNAL_ENTRY_DELETED => RawError::Kind(WIN32::ERROR_JOURNAL_ENTRY_DELETED),
            WIN32::ERROR_VRF_CFG_ENABLED => RawError::Kind(WIN32::ERROR_VRF_CFG_ENABLED),
            WIN32::ERROR_PARTITION_TERMINATING => RawError::Kind(WIN32::ERROR_PARTITION_TERMINATING),
            WIN32::ERROR_SHUTDOWN_IS_SCHEDULED => RawError::Kind(WIN32::ERROR_SHUTDOWN_IS_SCHEDULED),
            WIN32::ERROR_SHUTDOWN_USERS_LOGGED_ON => RawError::Kind(WIN32::ERROR_SHUTDOWN_USERS_LOGGED_ON),
            WIN32::ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE => RawError::Kind(WIN32::ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE),
            WIN32::ERROR_BAD_DEVICE => RawError::Kind(WIN32::ERROR_BAD_DEVICE),
            WIN32::ERROR_CONNECTION_UNAVAIL => RawError::Kind(WIN32::ERROR_CONNECTION_UNAVAIL),
            WIN32::ERROR_DEVICE_ALREADY_REMEMBERED => RawError::Kind(WIN32::ERROR_DEVICE_ALREADY_REMEMBERED),
            WIN32::ERROR_NO_NET_OR_BAD_PATH => RawError::Kind(WIN32::ERROR_NO_NET_OR_BAD_PATH),
            WIN32::ERROR_BAD_PROVIDER => RawError::Kind(WIN32::ERROR_BAD_PROVIDER),
            WIN32::ERROR_CANNOT_OPEN_PROFILE => RawError::Kind(WIN32::ERROR_CANNOT_OPEN_PROFILE),
            WIN32::ERROR_BAD_PROFILE => RawError::Kind(WIN32::ERROR_BAD_PROFILE),
            WIN32::ERROR_NOT_CONTAINER => RawError::Kind(WIN32::ERROR_NOT_CONTAINER),
            WIN32::ERROR_EXTENDED_ERROR => RawError::Kind(WIN32::ERROR_EXTENDED_ERROR),
            WIN32::ERROR_INVALID_GROUPNAME => RawError::Kind(WIN32::ERROR_INVALID_GROUPNAME),
            WIN32::ERROR_INVALID_COMPUTERNAME => RawError::Kind(WIN32::ERROR_INVALID_COMPUTERNAME),
            WIN32::ERROR_INVALID_EVENTNAME => RawError::Kind(WIN32::ERROR_INVALID_EVENTNAME),
            WIN32::ERROR_INVALID_DOMAINNAME => RawError::Kind(WIN32::ERROR_INVALID_DOMAINNAME),
            WIN32::ERROR_INVALID_SERVICENAME => RawError::Kind(WIN32::ERROR_INVALID_SERVICENAME),
            WIN32::ERROR_INVALID_NETNAME => RawError::Kind(WIN32::ERROR_INVALID_NETNAME),
            WIN32::ERROR_INVALID_SHARENAME => RawError::Kind(WIN32::ERROR_INVALID_SHARENAME),
            WIN32::ERROR_INVALID_PASSWORDNAME => RawError::Kind(WIN32::ERROR_INVALID_PASSWORDNAME),
            WIN32::ERROR_INVALID_MESSAGENAME => RawError::Kind(WIN32::ERROR_INVALID_MESSAGENAME),
            WIN32::ERROR_INVALID_MESSAGEDEST => RawError::Kind(WIN32::ERROR_INVALID_MESSAGEDEST),
            WIN32::ERROR_SESSION_CREDENTIAL_CONFLICT => RawError::Kind(WIN32::ERROR_SESSION_CREDENTIAL_CONFLICT),
            WIN32::ERROR_REMOTE_SESSION_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_REMOTE_SESSION_LIMIT_EXCEEDED),
            WIN32::ERROR_DUP_DOMAINNAME => RawError::Kind(WIN32::ERROR_DUP_DOMAINNAME),
            WIN32::ERROR_NO_NETWORK => RawError::Kind(WIN32::ERROR_NO_NETWORK),
            WIN32::ERROR_CANCELLED => RawError::Kind(WIN32::ERROR_CANCELLED),
            WIN32::ERROR_USER_MAPPED_FILE => RawError::Kind(WIN32::ERROR_USER_MAPPED_FILE),
            WIN32::ERROR_CONNECTION_REFUSED => RawError::Kind(WIN32::ERROR_CONNECTION_REFUSED),
            WIN32::ERROR_GRACEFUL_DISCONNECT => RawError::Kind(WIN32::ERROR_GRACEFUL_DISCONNECT),
            WIN32::ERROR_ADDRESS_ALREADY_ASSOCIATED => RawError::Kind(WIN32::ERROR_ADDRESS_ALREADY_ASSOCIATED),
            WIN32::ERROR_ADDRESS_NOT_ASSOCIATED => RawError::Kind(WIN32::ERROR_ADDRESS_NOT_ASSOCIATED),
            WIN32::ERROR_CONNECTION_INVALID => RawError::Kind(WIN32::ERROR_CONNECTION_INVALID),
            WIN32::ERROR_CONNECTION_ACTIVE => RawError::Kind(WIN32::ERROR_CONNECTION_ACTIVE),
            WIN32::ERROR_NETWORK_UNREACHABLE => RawError::Kind(WIN32::ERROR_NETWORK_UNREACHABLE),
            WIN32::ERROR_HOST_UNREACHABLE => RawError::Kind(WIN32::ERROR_HOST_UNREACHABLE),
            WIN32::ERROR_PROTOCOL_UNREACHABLE => RawError::Kind(WIN32::ERROR_PROTOCOL_UNREACHABLE),
            WIN32::ERROR_PORT_UNREACHABLE => RawError::Kind(WIN32::ERROR_PORT_UNREACHABLE),
            WIN32::ERROR_REQUEST_ABORTED => RawError::Kind(WIN32::ERROR_REQUEST_ABORTED),
            WIN32::ERROR_CONNECTION_ABORTED => RawError::Kind(WIN32::ERROR_CONNECTION_ABORTED),
            WIN32::ERROR_RETRY => RawError::Kind(WIN32::ERROR_RETRY),
            WIN32::ERROR_CONNECTION_COUNT_LIMIT => RawError::Kind(WIN32::ERROR_CONNECTION_COUNT_LIMIT),
            WIN32::ERROR_LOGIN_TIME_RESTRICTION => RawError::Kind(WIN32::ERROR_LOGIN_TIME_RESTRICTION),
            WIN32::ERROR_LOGIN_WKSTA_RESTRICTION => RawError::Kind(WIN32::ERROR_LOGIN_WKSTA_RESTRICTION),
            WIN32::ERROR_INCORRECT_ADDRESS => RawError::Kind(WIN32::ERROR_INCORRECT_ADDRESS),
            WIN32::ERROR_ALREADY_REGISTERED => RawError::Kind(WIN32::ERROR_ALREADY_REGISTERED),
            WIN32::ERROR_SERVICE_NOT_FOUND => RawError::Kind(WIN32::ERROR_SERVICE_NOT_FOUND),
            WIN32::ERROR_NOT_AUTHENTICATED => RawError::Kind(WIN32::ERROR_NOT_AUTHENTICATED),
            WIN32::ERROR_NOT_LOGGED_ON => RawError::Kind(WIN32::ERROR_NOT_LOGGED_ON),
            WIN32::ERROR_CONTINUE => RawError::Kind(WIN32::ERROR_CONTINUE),
            WIN32::ERROR_ALREADY_INITIALIZED => RawError::Kind(WIN32::ERROR_ALREADY_INITIALIZED),
            WIN32::ERROR_NO_MORE_DEVICES => RawError::Kind(WIN32::ERROR_NO_MORE_DEVICES),
            WIN32::ERROR_NO_SUCH_SITE => RawError::Kind(WIN32::ERROR_NO_SUCH_SITE),
            WIN32::ERROR_DOMAIN_CONTROLLER_EXISTS => RawError::Kind(WIN32::ERROR_DOMAIN_CONTROLLER_EXISTS),
            WIN32::ERROR_ONLY_IF_CONNECTED => RawError::Kind(WIN32::ERROR_ONLY_IF_CONNECTED),
            WIN32::ERROR_OVERRIDE_NOCHANGES => RawError::Kind(WIN32::ERROR_OVERRIDE_NOCHANGES),
            WIN32::ERROR_BAD_USER_PROFILE => RawError::Kind(WIN32::ERROR_BAD_USER_PROFILE),
            WIN32::ERROR_NOT_SUPPORTED_ON_SBS => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_ON_SBS),
            WIN32::ERROR_SERVER_SHUTDOWN_IN_PROGRESS => RawError::Kind(WIN32::ERROR_SERVER_SHUTDOWN_IN_PROGRESS),
            WIN32::ERROR_HOST_DOWN => RawError::Kind(WIN32::ERROR_HOST_DOWN),
            WIN32::ERROR_NON_ACCOUNT_SID => RawError::Kind(WIN32::ERROR_NON_ACCOUNT_SID),
            WIN32::ERROR_NON_DOMAIN_SID => RawError::Kind(WIN32::ERROR_NON_DOMAIN_SID),
            WIN32::ERROR_APPHELP_BLOCK => RawError::Kind(WIN32::ERROR_APPHELP_BLOCK),
            WIN32::ERROR_ACCESS_DISABLED_BY_POLICY => RawError::Kind(WIN32::ERROR_ACCESS_DISABLED_BY_POLICY),
            WIN32::ERROR_REG_NAT_CONSUMPTION => RawError::Kind(WIN32::ERROR_REG_NAT_CONSUMPTION),
            WIN32::ERROR_CSCSHARE_OFFLINE => RawError::Kind(WIN32::ERROR_CSCSHARE_OFFLINE),
            WIN32::ERROR_PKINIT_FAILURE => RawError::Kind(WIN32::ERROR_PKINIT_FAILURE),
            WIN32::ERROR_SMARTCARD_SUBSYSTEM_FAILURE => RawError::Kind(WIN32::ERROR_SMARTCARD_SUBSYSTEM_FAILURE),
            WIN32::ERROR_DOWNGRADE_DETECTED => RawError::Kind(WIN32::ERROR_DOWNGRADE_DETECTED),
            WIN32::ERROR_MACHINE_LOCKED => RawError::Kind(WIN32::ERROR_MACHINE_LOCKED),
            WIN32::ERROR_SMB_GUEST_LOGON_BLOCKED => RawError::Kind(WIN32::ERROR_SMB_GUEST_LOGON_BLOCKED),
            WIN32::ERROR_CALLBACK_SUPPLIED_INVALID_DATA => RawError::Kind(WIN32::ERROR_CALLBACK_SUPPLIED_INVALID_DATA),
            WIN32::ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED => RawError::Kind(WIN32::ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED),
            WIN32::ERROR_DRIVER_BLOCKED => RawError::Kind(WIN32::ERROR_DRIVER_BLOCKED),
            WIN32::ERROR_INVALID_IMPORT_OF_NON_DLL => RawError::Kind(WIN32::ERROR_INVALID_IMPORT_OF_NON_DLL),
            WIN32::ERROR_ACCESS_DISABLED_WEBBLADE => RawError::Kind(WIN32::ERROR_ACCESS_DISABLED_WEBBLADE),
            WIN32::ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER => RawError::Kind(WIN32::ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER),
            WIN32::ERROR_RECOVERY_FAILURE => RawError::Kind(WIN32::ERROR_RECOVERY_FAILURE),
            WIN32::ERROR_ALREADY_FIBER => RawError::Kind(WIN32::ERROR_ALREADY_FIBER),
            WIN32::ERROR_ALREADY_THREAD => RawError::Kind(WIN32::ERROR_ALREADY_THREAD),
            WIN32::ERROR_STACK_BUFFER_OVERRUN => RawError::Kind(WIN32::ERROR_STACK_BUFFER_OVERRUN),
            WIN32::ERROR_PARAMETER_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_PARAMETER_QUOTA_EXCEEDED),
            WIN32::ERROR_DEBUGGER_INACTIVE => RawError::Kind(WIN32::ERROR_DEBUGGER_INACTIVE),
            WIN32::ERROR_DELAY_LOAD_FAILED => RawError::Kind(WIN32::ERROR_DELAY_LOAD_FAILED),
            WIN32::ERROR_VDM_DISALLOWED => RawError::Kind(WIN32::ERROR_VDM_DISALLOWED),
            WIN32::ERROR_UNIDENTIFIED_ERROR => RawError::Kind(WIN32::ERROR_UNIDENTIFIED_ERROR),
            WIN32::ERROR_INVALID_CRUNTIME_PARAMETER => RawError::Kind(WIN32::ERROR_INVALID_CRUNTIME_PARAMETER),
            WIN32::ERROR_BEYOND_VDL => RawError::Kind(WIN32::ERROR_BEYOND_VDL),
            WIN32::ERROR_INCOMPATIBLE_SERVICE_SID_TYPE => RawError::Kind(WIN32::ERROR_INCOMPATIBLE_SERVICE_SID_TYPE),
            WIN32::ERROR_DRIVER_PROCESS_TERMINATED => RawError::Kind(WIN32::ERROR_DRIVER_PROCESS_TERMINATED),
            WIN32::ERROR_IMPLEMENTATION_LIMIT => RawError::Kind(WIN32::ERROR_IMPLEMENTATION_LIMIT),
            WIN32::ERROR_PROCESS_IS_PROTECTED => RawError::Kind(WIN32::ERROR_PROCESS_IS_PROTECTED),
            WIN32::ERROR_SERVICE_NOTIFY_CLIENT_LAGGING => RawError::Kind(WIN32::ERROR_SERVICE_NOTIFY_CLIENT_LAGGING),
            WIN32::ERROR_DISK_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_DISK_QUOTA_EXCEEDED),
            WIN32::ERROR_CONTENT_BLOCKED => RawError::Kind(WIN32::ERROR_CONTENT_BLOCKED),
            WIN32::ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE => RawError::Kind(WIN32::ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE),
            WIN32::ERROR_APP_HANG => RawError::Kind(WIN32::ERROR_APP_HANG),
            WIN32::ERROR_INVALID_LABEL => RawError::Kind(WIN32::ERROR_INVALID_LABEL),
            WIN32::ERROR_NOT_ALL_ASSIGNED => RawError::Kind(WIN32::ERROR_NOT_ALL_ASSIGNED),
            WIN32::ERROR_SOME_NOT_MAPPED => RawError::Kind(WIN32::ERROR_SOME_NOT_MAPPED),
            WIN32::ERROR_NO_QUOTAS_FOR_ACCOUNT => RawError::Kind(WIN32::ERROR_NO_QUOTAS_FOR_ACCOUNT),
            WIN32::ERROR_LOCAL_USER_SESSION_KEY => RawError::Kind(WIN32::ERROR_LOCAL_USER_SESSION_KEY),
            WIN32::ERROR_NULL_LM_PASSWORD => RawError::Kind(WIN32::ERROR_NULL_LM_PASSWORD),
            WIN32::ERROR_UNKNOWN_REVISION => RawError::Kind(WIN32::ERROR_UNKNOWN_REVISION),
            WIN32::ERROR_REVISION_MISMATCH => RawError::Kind(WIN32::ERROR_REVISION_MISMATCH),
            WIN32::ERROR_INVALID_OWNER => RawError::Kind(WIN32::ERROR_INVALID_OWNER),
            WIN32::ERROR_INVALID_PRIMARY_GROUP => RawError::Kind(WIN32::ERROR_INVALID_PRIMARY_GROUP),
            WIN32::ERROR_NO_IMPERSONATION_TOKEN => RawError::Kind(WIN32::ERROR_NO_IMPERSONATION_TOKEN),
            WIN32::ERROR_CANT_DISABLE_MANDATORY => RawError::Kind(WIN32::ERROR_CANT_DISABLE_MANDATORY),
            WIN32::ERROR_NO_LOGON_SERVERS => RawError::Kind(WIN32::ERROR_NO_LOGON_SERVERS),
            WIN32::ERROR_NO_SUCH_LOGON_SESSION => RawError::Kind(WIN32::ERROR_NO_SUCH_LOGON_SESSION),
            WIN32::ERROR_NO_SUCH_PRIVILEGE => RawError::Kind(WIN32::ERROR_NO_SUCH_PRIVILEGE),
            WIN32::ERROR_PRIVILEGE_NOT_HELD => RawError::Kind(WIN32::ERROR_PRIVILEGE_NOT_HELD),
            WIN32::ERROR_INVALID_ACCOUNT_NAME => RawError::Kind(WIN32::ERROR_INVALID_ACCOUNT_NAME),
            WIN32::ERROR_USER_EXISTS => RawError::Kind(WIN32::ERROR_USER_EXISTS),
            WIN32::ERROR_NO_SUCH_USER => RawError::Kind(WIN32::ERROR_NO_SUCH_USER),
            WIN32::ERROR_GROUP_EXISTS => RawError::Kind(WIN32::ERROR_GROUP_EXISTS),
            WIN32::ERROR_NO_SUCH_GROUP => RawError::Kind(WIN32::ERROR_NO_SUCH_GROUP),
            WIN32::ERROR_MEMBER_IN_GROUP => RawError::Kind(WIN32::ERROR_MEMBER_IN_GROUP),
            WIN32::ERROR_MEMBER_NOT_IN_GROUP => RawError::Kind(WIN32::ERROR_MEMBER_NOT_IN_GROUP),
            WIN32::ERROR_LAST_ADMIN => RawError::Kind(WIN32::ERROR_LAST_ADMIN),
            WIN32::ERROR_WRONG_PASSWORD => RawError::Kind(WIN32::ERROR_WRONG_PASSWORD),
            WIN32::ERROR_ILL_FORMED_PASSWORD => RawError::Kind(WIN32::ERROR_ILL_FORMED_PASSWORD),
            WIN32::ERROR_PASSWORD_RESTRICTION => RawError::Kind(WIN32::ERROR_PASSWORD_RESTRICTION),
            WIN32::ERROR_LOGON_FAILURE => RawError::Kind(WIN32::ERROR_LOGON_FAILURE),
            WIN32::ERROR_ACCOUNT_RESTRICTION => RawError::Kind(WIN32::ERROR_ACCOUNT_RESTRICTION),
            WIN32::ERROR_INVALID_LOGON_HOURS => RawError::Kind(WIN32::ERROR_INVALID_LOGON_HOURS),
            WIN32::ERROR_INVALID_WORKSTATION => RawError::Kind(WIN32::ERROR_INVALID_WORKSTATION),
            WIN32::ERROR_PASSWORD_EXPIRED => RawError::Kind(WIN32::ERROR_PASSWORD_EXPIRED),
            WIN32::ERROR_ACCOUNT_DISABLED => RawError::Kind(WIN32::ERROR_ACCOUNT_DISABLED),
            WIN32::ERROR_NONE_MAPPED => RawError::Kind(WIN32::ERROR_NONE_MAPPED),
            WIN32::ERROR_TOO_MANY_LUIDS_REQUESTED => RawError::Kind(WIN32::ERROR_TOO_MANY_LUIDS_REQUESTED),
            WIN32::ERROR_LUIDS_EXHAUSTED => RawError::Kind(WIN32::ERROR_LUIDS_EXHAUSTED),
            WIN32::ERROR_INVALID_SUB_AUTHORITY => RawError::Kind(WIN32::ERROR_INVALID_SUB_AUTHORITY),
            WIN32::ERROR_INVALID_ACL => RawError::Kind(WIN32::ERROR_INVALID_ACL),
            WIN32::ERROR_INVALID_SID => RawError::Kind(WIN32::ERROR_INVALID_SID),
            WIN32::ERROR_INVALID_SECURITY_DESCR => RawError::Kind(WIN32::ERROR_INVALID_SECURITY_DESCR),
            WIN32::ERROR_BAD_INHERITANCE_ACL => RawError::Kind(WIN32::ERROR_BAD_INHERITANCE_ACL),
            WIN32::ERROR_SERVER_DISABLED => RawError::Kind(WIN32::ERROR_SERVER_DISABLED),
            WIN32::ERROR_SERVER_NOT_DISABLED => RawError::Kind(WIN32::ERROR_SERVER_NOT_DISABLED),
            WIN32::ERROR_INVALID_ID_AUTHORITY => RawError::Kind(WIN32::ERROR_INVALID_ID_AUTHORITY),
            WIN32::ERROR_ALLOTTED_SPACE_EXCEEDED => RawError::Kind(WIN32::ERROR_ALLOTTED_SPACE_EXCEEDED),
            WIN32::ERROR_INVALID_GROUP_ATTRIBUTES => RawError::Kind(WIN32::ERROR_INVALID_GROUP_ATTRIBUTES),
            WIN32::ERROR_BAD_IMPERSONATION_LEVEL => RawError::Kind(WIN32::ERROR_BAD_IMPERSONATION_LEVEL),
            WIN32::ERROR_CANT_OPEN_ANONYMOUS => RawError::Kind(WIN32::ERROR_CANT_OPEN_ANONYMOUS),
            WIN32::ERROR_BAD_VALIDATION_CLASS => RawError::Kind(WIN32::ERROR_BAD_VALIDATION_CLASS),
            WIN32::ERROR_BAD_TOKEN_TYPE => RawError::Kind(WIN32::ERROR_BAD_TOKEN_TYPE),
            WIN32::ERROR_NO_SECURITY_ON_OBJECT => RawError::Kind(WIN32::ERROR_NO_SECURITY_ON_OBJECT),
            WIN32::ERROR_CANT_ACCESS_DOMAIN_INFO => RawError::Kind(WIN32::ERROR_CANT_ACCESS_DOMAIN_INFO),
            WIN32::ERROR_INVALID_SERVER_STATE => RawError::Kind(WIN32::ERROR_INVALID_SERVER_STATE),
            WIN32::ERROR_INVALID_DOMAIN_STATE => RawError::Kind(WIN32::ERROR_INVALID_DOMAIN_STATE),
            WIN32::ERROR_INVALID_DOMAIN_ROLE => RawError::Kind(WIN32::ERROR_INVALID_DOMAIN_ROLE),
            WIN32::ERROR_NO_SUCH_DOMAIN => RawError::Kind(WIN32::ERROR_NO_SUCH_DOMAIN),
            WIN32::ERROR_DOMAIN_EXISTS => RawError::Kind(WIN32::ERROR_DOMAIN_EXISTS),
            WIN32::ERROR_DOMAIN_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DOMAIN_LIMIT_EXCEEDED),
            WIN32::ERROR_INTERNAL_DB_CORRUPTION => RawError::Kind(WIN32::ERROR_INTERNAL_DB_CORRUPTION),
            WIN32::ERROR_INTERNAL_ERROR => RawError::Kind(WIN32::ERROR_INTERNAL_ERROR),
            WIN32::ERROR_GENERIC_NOT_MAPPED => RawError::Kind(WIN32::ERROR_GENERIC_NOT_MAPPED),
            WIN32::ERROR_BAD_DESCRIPTOR_FORMAT => RawError::Kind(WIN32::ERROR_BAD_DESCRIPTOR_FORMAT),
            WIN32::ERROR_NOT_LOGON_PROCESS => RawError::Kind(WIN32::ERROR_NOT_LOGON_PROCESS),
            WIN32::ERROR_LOGON_SESSION_EXISTS => RawError::Kind(WIN32::ERROR_LOGON_SESSION_EXISTS),
            WIN32::ERROR_NO_SUCH_PACKAGE => RawError::Kind(WIN32::ERROR_NO_SUCH_PACKAGE),
            WIN32::ERROR_BAD_LOGON_SESSION_STATE => RawError::Kind(WIN32::ERROR_BAD_LOGON_SESSION_STATE),
            WIN32::ERROR_LOGON_SESSION_COLLISION => RawError::Kind(WIN32::ERROR_LOGON_SESSION_COLLISION),
            WIN32::ERROR_INVALID_LOGON_TYPE => RawError::Kind(WIN32::ERROR_INVALID_LOGON_TYPE),
            WIN32::ERROR_CANNOT_IMPERSONATE => RawError::Kind(WIN32::ERROR_CANNOT_IMPERSONATE),
            WIN32::ERROR_RXACT_INVALID_STATE => RawError::Kind(WIN32::ERROR_RXACT_INVALID_STATE),
            WIN32::ERROR_RXACT_COMMIT_FAILURE => RawError::Kind(WIN32::ERROR_RXACT_COMMIT_FAILURE),
            WIN32::ERROR_SPECIAL_ACCOUNT => RawError::Kind(WIN32::ERROR_SPECIAL_ACCOUNT),
            WIN32::ERROR_SPECIAL_GROUP => RawError::Kind(WIN32::ERROR_SPECIAL_GROUP),
            WIN32::ERROR_SPECIAL_USER => RawError::Kind(WIN32::ERROR_SPECIAL_USER),
            WIN32::ERROR_MEMBERS_PRIMARY_GROUP => RawError::Kind(WIN32::ERROR_MEMBERS_PRIMARY_GROUP),
            WIN32::ERROR_TOKEN_ALREADY_IN_USE => RawError::Kind(WIN32::ERROR_TOKEN_ALREADY_IN_USE),
            WIN32::ERROR_NO_SUCH_ALIAS => RawError::Kind(WIN32::ERROR_NO_SUCH_ALIAS),
            WIN32::ERROR_MEMBER_NOT_IN_ALIAS => RawError::Kind(WIN32::ERROR_MEMBER_NOT_IN_ALIAS),
            WIN32::ERROR_MEMBER_IN_ALIAS => RawError::Kind(WIN32::ERROR_MEMBER_IN_ALIAS),
            WIN32::ERROR_ALIAS_EXISTS => RawError::Kind(WIN32::ERROR_ALIAS_EXISTS),
            WIN32::ERROR_LOGON_NOT_GRANTED => RawError::Kind(WIN32::ERROR_LOGON_NOT_GRANTED),
            WIN32::ERROR_TOO_MANY_SECRETS => RawError::Kind(WIN32::ERROR_TOO_MANY_SECRETS),
            WIN32::ERROR_SECRET_TOO_LONG => RawError::Kind(WIN32::ERROR_SECRET_TOO_LONG),
            WIN32::ERROR_INTERNAL_DB_ERROR => RawError::Kind(WIN32::ERROR_INTERNAL_DB_ERROR),
            WIN32::ERROR_TOO_MANY_CONTEXT_IDS => RawError::Kind(WIN32::ERROR_TOO_MANY_CONTEXT_IDS),
            WIN32::ERROR_LOGON_TYPE_NOT_GRANTED => RawError::Kind(WIN32::ERROR_LOGON_TYPE_NOT_GRANTED),
            WIN32::ERROR_NT_CROSS_ENCRYPTION_REQUIRED => RawError::Kind(WIN32::ERROR_NT_CROSS_ENCRYPTION_REQUIRED),
            WIN32::ERROR_NO_SUCH_MEMBER => RawError::Kind(WIN32::ERROR_NO_SUCH_MEMBER),
            WIN32::ERROR_INVALID_MEMBER => RawError::Kind(WIN32::ERROR_INVALID_MEMBER),
            WIN32::ERROR_TOO_MANY_SIDS => RawError::Kind(WIN32::ERROR_TOO_MANY_SIDS),
            WIN32::ERROR_LM_CROSS_ENCRYPTION_REQUIRED => RawError::Kind(WIN32::ERROR_LM_CROSS_ENCRYPTION_REQUIRED),
            WIN32::ERROR_NO_INHERITANCE => RawError::Kind(WIN32::ERROR_NO_INHERITANCE),
            WIN32::ERROR_FILE_CORRUPT => RawError::Kind(WIN32::ERROR_FILE_CORRUPT),
            WIN32::ERROR_DISK_CORRUPT => RawError::Kind(WIN32::ERROR_DISK_CORRUPT),
            WIN32::ERROR_NO_USER_SESSION_KEY => RawError::Kind(WIN32::ERROR_NO_USER_SESSION_KEY),
            WIN32::ERROR_LICENSE_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_LICENSE_QUOTA_EXCEEDED),
            WIN32::ERROR_WRONG_TARGET_NAME => RawError::Kind(WIN32::ERROR_WRONG_TARGET_NAME),
            WIN32::ERROR_MUTUAL_AUTH_FAILED => RawError::Kind(WIN32::ERROR_MUTUAL_AUTH_FAILED),
            WIN32::ERROR_TIME_SKEW => RawError::Kind(WIN32::ERROR_TIME_SKEW),
            WIN32::ERROR_CURRENT_DOMAIN_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_CURRENT_DOMAIN_NOT_ALLOWED),
            WIN32::ERROR_INVALID_WINDOW_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_WINDOW_HANDLE),
            WIN32::ERROR_INVALID_MENU_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_MENU_HANDLE),
            WIN32::ERROR_INVALID_CURSOR_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_CURSOR_HANDLE),
            WIN32::ERROR_INVALID_ACCEL_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_ACCEL_HANDLE),
            WIN32::ERROR_INVALID_HOOK_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_HOOK_HANDLE),
            WIN32::ERROR_INVALID_DWP_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_DWP_HANDLE),
            WIN32::ERROR_TLW_WITH_WSCHILD => RawError::Kind(WIN32::ERROR_TLW_WITH_WSCHILD),
            WIN32::ERROR_CANNOT_FIND_WND_CLASS => RawError::Kind(WIN32::ERROR_CANNOT_FIND_WND_CLASS),
            WIN32::ERROR_WINDOW_OF_OTHER_THREAD => RawError::Kind(WIN32::ERROR_WINDOW_OF_OTHER_THREAD),
            WIN32::ERROR_HOTKEY_ALREADY_REGISTERED => RawError::Kind(WIN32::ERROR_HOTKEY_ALREADY_REGISTERED),
            WIN32::ERROR_CLASS_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_CLASS_ALREADY_EXISTS),
            WIN32::ERROR_CLASS_DOES_NOT_EXIST => RawError::Kind(WIN32::ERROR_CLASS_DOES_NOT_EXIST),
            WIN32::ERROR_CLASS_HAS_WINDOWS => RawError::Kind(WIN32::ERROR_CLASS_HAS_WINDOWS),
            WIN32::ERROR_INVALID_INDEX => RawError::Kind(WIN32::ERROR_INVALID_INDEX),
            WIN32::ERROR_INVALID_ICON_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_ICON_HANDLE),
            WIN32::ERROR_PRIVATE_DIALOG_INDEX => RawError::Kind(WIN32::ERROR_PRIVATE_DIALOG_INDEX),
            WIN32::ERROR_LISTBOX_ID_NOT_FOUND => RawError::Kind(WIN32::ERROR_LISTBOX_ID_NOT_FOUND),
            WIN32::ERROR_NO_WILDCARD_CHARACTERS => RawError::Kind(WIN32::ERROR_NO_WILDCARD_CHARACTERS),
            WIN32::ERROR_CLIPBOARD_NOT_OPEN => RawError::Kind(WIN32::ERROR_CLIPBOARD_NOT_OPEN),
            WIN32::ERROR_HOTKEY_NOT_REGISTERED => RawError::Kind(WIN32::ERROR_HOTKEY_NOT_REGISTERED),
            WIN32::ERROR_WINDOW_NOT_DIALOG => RawError::Kind(WIN32::ERROR_WINDOW_NOT_DIALOG),
            WIN32::ERROR_CONTROL_ID_NOT_FOUND => RawError::Kind(WIN32::ERROR_CONTROL_ID_NOT_FOUND),
            WIN32::ERROR_INVALID_COMBOBOX_MESSAGE => RawError::Kind(WIN32::ERROR_INVALID_COMBOBOX_MESSAGE),
            WIN32::ERROR_WINDOW_NOT_COMBOBOX => RawError::Kind(WIN32::ERROR_WINDOW_NOT_COMBOBOX),
            WIN32::ERROR_INVALID_EDIT_HEIGHT => RawError::Kind(WIN32::ERROR_INVALID_EDIT_HEIGHT),
            WIN32::ERROR_DC_NOT_FOUND => RawError::Kind(WIN32::ERROR_DC_NOT_FOUND),
            WIN32::ERROR_INVALID_HOOK_FILTER => RawError::Kind(WIN32::ERROR_INVALID_HOOK_FILTER),
            WIN32::ERROR_INVALID_FILTER_PROC => RawError::Kind(WIN32::ERROR_INVALID_FILTER_PROC),
            WIN32::ERROR_HOOK_NEEDS_HMOD => RawError::Kind(WIN32::ERROR_HOOK_NEEDS_HMOD),
            WIN32::ERROR_GLOBAL_ONLY_HOOK => RawError::Kind(WIN32::ERROR_GLOBAL_ONLY_HOOK),
            WIN32::ERROR_JOURNAL_HOOK_SET => RawError::Kind(WIN32::ERROR_JOURNAL_HOOK_SET),
            WIN32::ERROR_HOOK_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_HOOK_NOT_INSTALLED),
            WIN32::ERROR_INVALID_LB_MESSAGE => RawError::Kind(WIN32::ERROR_INVALID_LB_MESSAGE),
            WIN32::ERROR_SETCOUNT_ON_BAD_LB => RawError::Kind(WIN32::ERROR_SETCOUNT_ON_BAD_LB),
            WIN32::ERROR_LB_WITHOUT_TABSTOPS => RawError::Kind(WIN32::ERROR_LB_WITHOUT_TABSTOPS),
            WIN32::ERROR_DESTROY_OBJECT_OF_OTHER_THREAD => RawError::Kind(WIN32::ERROR_DESTROY_OBJECT_OF_OTHER_THREAD),
            WIN32::ERROR_CHILD_WINDOW_MENU => RawError::Kind(WIN32::ERROR_CHILD_WINDOW_MENU),
            WIN32::ERROR_NO_SYSTEM_MENU => RawError::Kind(WIN32::ERROR_NO_SYSTEM_MENU),
            WIN32::ERROR_INVALID_MSGBOX_STYLE => RawError::Kind(WIN32::ERROR_INVALID_MSGBOX_STYLE),
            WIN32::ERROR_INVALID_SPI_VALUE => RawError::Kind(WIN32::ERROR_INVALID_SPI_VALUE),
            WIN32::ERROR_SCREEN_ALREADY_LOCKED => RawError::Kind(WIN32::ERROR_SCREEN_ALREADY_LOCKED),
            WIN32::ERROR_HWNDS_HAVE_DIFF_PARENT => RawError::Kind(WIN32::ERROR_HWNDS_HAVE_DIFF_PARENT),
            WIN32::ERROR_NOT_CHILD_WINDOW => RawError::Kind(WIN32::ERROR_NOT_CHILD_WINDOW),
            WIN32::ERROR_INVALID_GW_COMMAND => RawError::Kind(WIN32::ERROR_INVALID_GW_COMMAND),
            WIN32::ERROR_INVALID_THREAD_ID => RawError::Kind(WIN32::ERROR_INVALID_THREAD_ID),
            WIN32::ERROR_NON_MDICHILD_WINDOW => RawError::Kind(WIN32::ERROR_NON_MDICHILD_WINDOW),
            WIN32::ERROR_POPUP_ALREADY_ACTIVE => RawError::Kind(WIN32::ERROR_POPUP_ALREADY_ACTIVE),
            WIN32::ERROR_NO_SCROLLBARS => RawError::Kind(WIN32::ERROR_NO_SCROLLBARS),
            WIN32::ERROR_INVALID_SCROLLBAR_RANGE => RawError::Kind(WIN32::ERROR_INVALID_SCROLLBAR_RANGE),
            WIN32::ERROR_INVALID_SHOWWIN_COMMAND => RawError::Kind(WIN32::ERROR_INVALID_SHOWWIN_COMMAND),
            WIN32::ERROR_NO_SYSTEM_RESOURCES => RawError::Kind(WIN32::ERROR_NO_SYSTEM_RESOURCES),
            WIN32::ERROR_NONPAGED_SYSTEM_RESOURCES => RawError::Kind(WIN32::ERROR_NONPAGED_SYSTEM_RESOURCES),
            WIN32::ERROR_PAGED_SYSTEM_RESOURCES => RawError::Kind(WIN32::ERROR_PAGED_SYSTEM_RESOURCES),
            WIN32::ERROR_WORKING_SET_QUOTA => RawError::Kind(WIN32::ERROR_WORKING_SET_QUOTA),
            WIN32::ERROR_PAGEFILE_QUOTA => RawError::Kind(WIN32::ERROR_PAGEFILE_QUOTA),
            WIN32::ERROR_COMMITMENT_LIMIT => RawError::Kind(WIN32::ERROR_COMMITMENT_LIMIT),
            WIN32::ERROR_MENU_ITEM_NOT_FOUND => RawError::Kind(WIN32::ERROR_MENU_ITEM_NOT_FOUND),
            WIN32::ERROR_INVALID_KEYBOARD_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_KEYBOARD_HANDLE),
            WIN32::ERROR_HOOK_TYPE_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_HOOK_TYPE_NOT_ALLOWED),
            WIN32::ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION => RawError::Kind(WIN32::ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION),
            WIN32::ERROR_TIMEOUT => RawError::Kind(WIN32::ERROR_TIMEOUT),
            WIN32::E_TIMEOUT => RawError::Kind(WIN32::E_TIMEOUT),
            WIN32::ERROR_INVALID_MONITOR_HANDLE => RawError::Kind(WIN32::ERROR_INVALID_MONITOR_HANDLE),
            WIN32::ERROR_INCORRECT_SIZE => RawError::Kind(WIN32::ERROR_INCORRECT_SIZE),
            WIN32::ERROR_SYMLINK_CLASS_DISABLED => RawError::Kind(WIN32::ERROR_SYMLINK_CLASS_DISABLED),
            WIN32::ERROR_SYMLINK_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_SYMLINK_NOT_SUPPORTED),
            WIN32::ERROR_XML_PARSE_ERROR => RawError::Kind(WIN32::ERROR_XML_PARSE_ERROR),
            WIN32::ERROR_XMLDSIG_ERROR => RawError::Kind(WIN32::ERROR_XMLDSIG_ERROR),
            WIN32::ERROR_RESTART_APPLICATION => RawError::Kind(WIN32::ERROR_RESTART_APPLICATION),
            WIN32::ERROR_WRONG_COMPARTMENT => RawError::Kind(WIN32::ERROR_WRONG_COMPARTMENT),
            WIN32::ERROR_AUTHIP_FAILURE => RawError::Kind(WIN32::ERROR_AUTHIP_FAILURE),
            WIN32::ERROR_NO_NVRAM_RESOURCES => RawError::Kind(WIN32::ERROR_NO_NVRAM_RESOURCES),
            WIN32::ERROR_NOT_GUI_PROCESS => RawError::Kind(WIN32::ERROR_NOT_GUI_PROCESS),
            WIN32::ERROR_EVENTLOG_FILE_CORRUPT => RawError::Kind(WIN32::ERROR_EVENTLOG_FILE_CORRUPT),
            WIN32::ERROR_EVENTLOG_CANT_START => RawError::Kind(WIN32::ERROR_EVENTLOG_CANT_START),
            WIN32::ERROR_LOG_FILE_FULL => RawError::Kind(WIN32::ERROR_LOG_FILE_FULL),
            WIN32::ERROR_EVENTLOG_FILE_CHANGED => RawError::Kind(WIN32::ERROR_EVENTLOG_FILE_CHANGED),
            WIN32::ERROR_CONTAINER_ASSIGNED => RawError::Kind(WIN32::ERROR_CONTAINER_ASSIGNED),
            WIN32::ERROR_JOB_NO_CONTAINER => RawError::Kind(WIN32::ERROR_JOB_NO_CONTAINER),
            WIN32::ERROR_INVALID_TASK_NAME => RawError::Kind(WIN32::ERROR_INVALID_TASK_NAME),
            WIN32::ERROR_INVALID_TASK_INDEX => RawError::Kind(WIN32::ERROR_INVALID_TASK_INDEX),
            WIN32::ERROR_THREAD_ALREADY_IN_TASK => RawError::Kind(WIN32::ERROR_THREAD_ALREADY_IN_TASK),
            WIN32::ERROR_INSTALL_SERVICE_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_SERVICE_FAILURE),
            WIN32::ERROR_INSTALL_USEREXIT => RawError::Kind(WIN32::ERROR_INSTALL_USEREXIT),
            WIN32::ERROR_INSTALL_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_FAILURE),
            WIN32::ERROR_INSTALL_SUSPEND => RawError::Kind(WIN32::ERROR_INSTALL_SUSPEND),
            WIN32::ERROR_UNKNOWN_PRODUCT => RawError::Kind(WIN32::ERROR_UNKNOWN_PRODUCT),
            WIN32::ERROR_UNKNOWN_FEATURE => RawError::Kind(WIN32::ERROR_UNKNOWN_FEATURE),
            WIN32::ERROR_UNKNOWN_COMPONENT => RawError::Kind(WIN32::ERROR_UNKNOWN_COMPONENT),
            WIN32::ERROR_UNKNOWN_PROPERTY => RawError::Kind(WIN32::ERROR_UNKNOWN_PROPERTY),
            WIN32::ERROR_INVALID_HANDLE_STATE => RawError::Kind(WIN32::ERROR_INVALID_HANDLE_STATE),
            WIN32::ERROR_BAD_CONFIGURATION => RawError::Kind(WIN32::ERROR_BAD_CONFIGURATION),
            WIN32::ERROR_INDEX_ABSENT => RawError::Kind(WIN32::ERROR_INDEX_ABSENT),
            WIN32::ERROR_INSTALL_SOURCE_ABSENT => RawError::Kind(WIN32::ERROR_INSTALL_SOURCE_ABSENT),
            WIN32::ERROR_INSTALL_PACKAGE_VERSION => RawError::Kind(WIN32::ERROR_INSTALL_PACKAGE_VERSION),
            WIN32::ERROR_PRODUCT_UNINSTALLED => RawError::Kind(WIN32::ERROR_PRODUCT_UNINSTALLED),
            WIN32::ERROR_BAD_QUERY_SYNTAX => RawError::Kind(WIN32::ERROR_BAD_QUERY_SYNTAX),
            WIN32::ERROR_INVALID_FIELD => RawError::Kind(WIN32::ERROR_INVALID_FIELD),
            WIN32::ERROR_DEVICE_REMOVED => RawError::Kind(WIN32::ERROR_DEVICE_REMOVED),
            WIN32::ERROR_INSTALL_ALREADY_RUNNING => RawError::Kind(WIN32::ERROR_INSTALL_ALREADY_RUNNING),
            WIN32::ERROR_INSTALL_PACKAGE_OPEN_FAILED => RawError::Kind(WIN32::ERROR_INSTALL_PACKAGE_OPEN_FAILED),
            WIN32::ERROR_INSTALL_PACKAGE_INVALID => RawError::Kind(WIN32::ERROR_INSTALL_PACKAGE_INVALID),
            WIN32::ERROR_INSTALL_UI_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_UI_FAILURE),
            WIN32::ERROR_INSTALL_LOG_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_LOG_FAILURE),
            WIN32::ERROR_INSTALL_LANGUAGE_UNSUPPORTED => RawError::Kind(WIN32::ERROR_INSTALL_LANGUAGE_UNSUPPORTED),
            WIN32::ERROR_INSTALL_TRANSFORM_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_TRANSFORM_FAILURE),
            WIN32::ERROR_INSTALL_PACKAGE_REJECTED => RawError::Kind(WIN32::ERROR_INSTALL_PACKAGE_REJECTED),
            WIN32::ERROR_FUNCTION_NOT_CALLED => RawError::Kind(WIN32::ERROR_FUNCTION_NOT_CALLED),
            WIN32::ERROR_FUNCTION_FAILED => RawError::Kind(WIN32::ERROR_FUNCTION_FAILED),
            WIN32::ERROR_INVALID_TABLE => RawError::Kind(WIN32::ERROR_INVALID_TABLE),
            WIN32::ERROR_DATATYPE_MISMATCH => RawError::Kind(WIN32::ERROR_DATATYPE_MISMATCH),
            WIN32::ERROR_UNSUPPORTED_TYPE => RawError::Kind(WIN32::ERROR_UNSUPPORTED_TYPE),
            WIN32::ERROR_CREATE_FAILED => RawError::Kind(WIN32::ERROR_CREATE_FAILED),
            WIN32::ERROR_INSTALL_TEMP_UNWRITABLE => RawError::Kind(WIN32::ERROR_INSTALL_TEMP_UNWRITABLE),
            WIN32::ERROR_INSTALL_PLATFORM_UNSUPPORTED => RawError::Kind(WIN32::ERROR_INSTALL_PLATFORM_UNSUPPORTED),
            WIN32::ERROR_INSTALL_NOTUSED => RawError::Kind(WIN32::ERROR_INSTALL_NOTUSED),
            WIN32::ERROR_PATCH_PACKAGE_OPEN_FAILED => RawError::Kind(WIN32::ERROR_PATCH_PACKAGE_OPEN_FAILED),
            WIN32::ERROR_PATCH_PACKAGE_INVALID => RawError::Kind(WIN32::ERROR_PATCH_PACKAGE_INVALID),
            WIN32::ERROR_PATCH_PACKAGE_UNSUPPORTED => RawError::Kind(WIN32::ERROR_PATCH_PACKAGE_UNSUPPORTED),
            WIN32::ERROR_PRODUCT_VERSION => RawError::Kind(WIN32::ERROR_PRODUCT_VERSION),
            WIN32::ERROR_INVALID_COMMAND_LINE => RawError::Kind(WIN32::ERROR_INVALID_COMMAND_LINE),
            WIN32::ERROR_INSTALL_REMOTE_DISALLOWED => RawError::Kind(WIN32::ERROR_INSTALL_REMOTE_DISALLOWED),
            WIN32::ERROR_SUCCESS_REBOOT_INITIATED => RawError::Kind(WIN32::ERROR_SUCCESS_REBOOT_INITIATED),
            WIN32::ERROR_PATCH_TARGET_NOT_FOUND => RawError::Kind(WIN32::ERROR_PATCH_TARGET_NOT_FOUND),
            WIN32::ERROR_PATCH_PACKAGE_REJECTED => RawError::Kind(WIN32::ERROR_PATCH_PACKAGE_REJECTED),
            WIN32::ERROR_INSTALL_TRANSFORM_REJECTED => RawError::Kind(WIN32::ERROR_INSTALL_TRANSFORM_REJECTED),
            WIN32::ERROR_INSTALL_REMOTE_PROHIBITED => RawError::Kind(WIN32::ERROR_INSTALL_REMOTE_PROHIBITED),
            WIN32::ERROR_PATCH_REMOVAL_UNSUPPORTED => RawError::Kind(WIN32::ERROR_PATCH_REMOVAL_UNSUPPORTED),
            WIN32::ERROR_UNKNOWN_PATCH => RawError::Kind(WIN32::ERROR_UNKNOWN_PATCH),
            WIN32::ERROR_PATCH_NO_SEQUENCE => RawError::Kind(WIN32::ERROR_PATCH_NO_SEQUENCE),
            WIN32::ERROR_PATCH_REMOVAL_DISALLOWED => RawError::Kind(WIN32::ERROR_PATCH_REMOVAL_DISALLOWED),
            WIN32::ERROR_INVALID_PATCH_XML => RawError::Kind(WIN32::ERROR_INVALID_PATCH_XML),
            WIN32::ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT => RawError::Kind(WIN32::ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT),
            WIN32::ERROR_INSTALL_SERVICE_SAFEBOOT => RawError::Kind(WIN32::ERROR_INSTALL_SERVICE_SAFEBOOT),
            WIN32::ERROR_FAIL_FAST_EXCEPTION => RawError::Kind(WIN32::ERROR_FAIL_FAST_EXCEPTION),
            WIN32::ERROR_INSTALL_REJECTED => RawError::Kind(WIN32::ERROR_INSTALL_REJECTED),
            WIN32::ERROR_DYNAMIC_CODE_BLOCKED => RawError::Kind(WIN32::ERROR_DYNAMIC_CODE_BLOCKED),
            WIN32::ERROR_NOT_SAME_OBJECT => RawError::Kind(WIN32::ERROR_NOT_SAME_OBJECT),
            WIN32::ERROR_STRICT_CFG_VIOLATION => RawError::Kind(WIN32::ERROR_STRICT_CFG_VIOLATION),
            WIN32::ERROR_STRICT_RFG_VIOLATION => RawError::Kind(WIN32::ERROR_STRICT_RFG_VIOLATION),
            WIN32::ERROR_RFG_ACCESS_VIOLATION => RawError::Kind(WIN32::ERROR_RFG_ACCESS_VIOLATION),
            WIN32::ERROR_SET_CONTEXT_DENIED => RawError::Kind(WIN32::ERROR_SET_CONTEXT_DENIED),
            WIN32::ERROR_CROSS_PARTITION_VIOLATION => RawError::Kind(WIN32::ERROR_CROSS_PARTITION_VIOLATION),
            WIN32::ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT => RawError::Kind(WIN32::ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT),
            WIN32::RPC_S_INVALID_STRING_BINDING => RawError::Kind(WIN32::RPC_S_INVALID_STRING_BINDING),
            WIN32::RPC_S_WRONG_KIND_OF_BINDING => RawError::Kind(WIN32::RPC_S_WRONG_KIND_OF_BINDING),
            WIN32::RPC_S_INVALID_BINDING => RawError::Kind(WIN32::RPC_S_INVALID_BINDING),
            WIN32::RPC_S_PROTSEQ_NOT_SUPPORTED => RawError::Kind(WIN32::RPC_S_PROTSEQ_NOT_SUPPORTED),
            WIN32::RPC_S_INVALID_RPC_PROTSEQ => RawError::Kind(WIN32::RPC_S_INVALID_RPC_PROTSEQ),
            WIN32::RPC_S_INVALID_STRING_UUID => RawError::Kind(WIN32::RPC_S_INVALID_STRING_UUID),
            WIN32::RPC_S_INVALID_ENDPOINT_FORMAT => RawError::Kind(WIN32::RPC_S_INVALID_ENDPOINT_FORMAT),
            WIN32::RPC_S_INVALID_NET_ADDR => RawError::Kind(WIN32::RPC_S_INVALID_NET_ADDR),
            WIN32::RPC_S_NO_ENDPOINT_FOUND => RawError::Kind(WIN32::RPC_S_NO_ENDPOINT_FOUND),
            WIN32::RPC_S_INVALID_TIMEOUT => RawError::Kind(WIN32::RPC_S_INVALID_TIMEOUT),
            WIN32::RPC_S_OBJECT_NOT_FOUND => RawError::Kind(WIN32::RPC_S_OBJECT_NOT_FOUND),
            WIN32::RPC_S_ALREADY_REGISTERED => RawError::Kind(WIN32::RPC_S_ALREADY_REGISTERED),
            WIN32::RPC_S_TYPE_ALREADY_REGISTERED => RawError::Kind(WIN32::RPC_S_TYPE_ALREADY_REGISTERED),
            WIN32::RPC_S_ALREADY_LISTENING => RawError::Kind(WIN32::RPC_S_ALREADY_LISTENING),
            WIN32::RPC_S_NO_PROTSEQS_REGISTERED => RawError::Kind(WIN32::RPC_S_NO_PROTSEQS_REGISTERED),
            WIN32::RPC_S_NOT_LISTENING => RawError::Kind(WIN32::RPC_S_NOT_LISTENING),
            WIN32::RPC_S_UNKNOWN_MGR_TYPE => RawError::Kind(WIN32::RPC_S_UNKNOWN_MGR_TYPE),
            WIN32::RPC_S_UNKNOWN_IF => RawError::Kind(WIN32::RPC_S_UNKNOWN_IF),
            WIN32::RPC_S_NO_BINDINGS => RawError::Kind(WIN32::RPC_S_NO_BINDINGS),
            WIN32::RPC_S_NO_PROTSEQS => RawError::Kind(WIN32::RPC_S_NO_PROTSEQS),
            WIN32::RPC_S_CANT_CREATE_ENDPOINT => RawError::Kind(WIN32::RPC_S_CANT_CREATE_ENDPOINT),
            WIN32::RPC_S_OUT_OF_RESOURCES => RawError::Kind(WIN32::RPC_S_OUT_OF_RESOURCES),
            WIN32::RPC_S_SERVER_UNAVAILABLE => RawError::Kind(WIN32::RPC_S_SERVER_UNAVAILABLE),
            WIN32::RPC_S_SERVER_TOO_BUSY => RawError::Kind(WIN32::RPC_S_SERVER_TOO_BUSY),
            WIN32::RPC_S_INVALID_NETWORK_OPTIONS => RawError::Kind(WIN32::RPC_S_INVALID_NETWORK_OPTIONS),
            WIN32::RPC_S_NO_CALL_ACTIVE => RawError::Kind(WIN32::RPC_S_NO_CALL_ACTIVE),
            WIN32::RPC_S_CALL_FAILED => RawError::Kind(WIN32::RPC_S_CALL_FAILED),
            WIN32::RPC_S_CALL_FAILED_DNE => RawError::Kind(WIN32::RPC_S_CALL_FAILED_DNE),
            WIN32::RPC_S_PROTOCOL_ERROR => RawError::Kind(WIN32::RPC_S_PROTOCOL_ERROR),
            WIN32::RPC_S_PROXY_ACCESS_DENIED => RawError::Kind(WIN32::RPC_S_PROXY_ACCESS_DENIED),
            WIN32::RPC_S_UNSUPPORTED_TRANS_SYN => RawError::Kind(WIN32::RPC_S_UNSUPPORTED_TRANS_SYN),
            WIN32::RPC_S_UNSUPPORTED_TYPE => RawError::Kind(WIN32::RPC_S_UNSUPPORTED_TYPE),
            WIN32::RPC_S_INVALID_TAG => RawError::Kind(WIN32::RPC_S_INVALID_TAG),
            WIN32::RPC_S_INVALID_BOUND => RawError::Kind(WIN32::RPC_S_INVALID_BOUND),
            WIN32::RPC_S_NO_ENTRY_NAME => RawError::Kind(WIN32::RPC_S_NO_ENTRY_NAME),
            WIN32::RPC_S_INVALID_NAME_SYNTAX => RawError::Kind(WIN32::RPC_S_INVALID_NAME_SYNTAX),
            WIN32::RPC_S_UNSUPPORTED_NAME_SYNTAX => RawError::Kind(WIN32::RPC_S_UNSUPPORTED_NAME_SYNTAX),
            WIN32::RPC_S_UUID_NO_ADDRESS => RawError::Kind(WIN32::RPC_S_UUID_NO_ADDRESS),
            WIN32::RPC_S_DUPLICATE_ENDPOINT => RawError::Kind(WIN32::RPC_S_DUPLICATE_ENDPOINT),
            WIN32::RPC_S_UNKNOWN_AUTHN_TYPE => RawError::Kind(WIN32::RPC_S_UNKNOWN_AUTHN_TYPE),
            WIN32::RPC_S_MAX_CALLS_TOO_SMALL => RawError::Kind(WIN32::RPC_S_MAX_CALLS_TOO_SMALL),
            WIN32::RPC_S_STRING_TOO_LONG => RawError::Kind(WIN32::RPC_S_STRING_TOO_LONG),
            WIN32::RPC_S_PROTSEQ_NOT_FOUND => RawError::Kind(WIN32::RPC_S_PROTSEQ_NOT_FOUND),
            WIN32::RPC_S_PROCNUM_OUT_OF_RANGE => RawError::Kind(WIN32::RPC_S_PROCNUM_OUT_OF_RANGE),
            WIN32::RPC_S_BINDING_HAS_NO_AUTH => RawError::Kind(WIN32::RPC_S_BINDING_HAS_NO_AUTH),
            WIN32::RPC_S_UNKNOWN_AUTHN_SERVICE => RawError::Kind(WIN32::RPC_S_UNKNOWN_AUTHN_SERVICE),
            WIN32::RPC_S_UNKNOWN_AUTHN_LEVEL => RawError::Kind(WIN32::RPC_S_UNKNOWN_AUTHN_LEVEL),
            WIN32::RPC_S_INVALID_AUTH_IDENTITY => RawError::Kind(WIN32::RPC_S_INVALID_AUTH_IDENTITY),
            WIN32::RPC_S_UNKNOWN_AUTHZ_SERVICE => RawError::Kind(WIN32::RPC_S_UNKNOWN_AUTHZ_SERVICE),
            WIN32::EPT_S_INVALID_ENTRY => RawError::Kind(WIN32::EPT_S_INVALID_ENTRY),
            WIN32::EPT_S_CANT_PERFORM_OP => RawError::Kind(WIN32::EPT_S_CANT_PERFORM_OP),
            WIN32::EPT_S_NOT_REGISTERED => RawError::Kind(WIN32::EPT_S_NOT_REGISTERED),
            WIN32::RPC_S_NOTHING_TO_EXPORT => RawError::Kind(WIN32::RPC_S_NOTHING_TO_EXPORT),
            WIN32::RPC_S_INCOMPLETE_NAME => RawError::Kind(WIN32::RPC_S_INCOMPLETE_NAME),
            WIN32::RPC_S_INVALID_VERS_OPTION => RawError::Kind(WIN32::RPC_S_INVALID_VERS_OPTION),
            WIN32::RPC_S_NO_MORE_MEMBERS => RawError::Kind(WIN32::RPC_S_NO_MORE_MEMBERS),
            WIN32::RPC_S_NOT_ALL_OBJS_UNEXPORTED => RawError::Kind(WIN32::RPC_S_NOT_ALL_OBJS_UNEXPORTED),
            WIN32::RPC_S_INTERFACE_NOT_FOUND => RawError::Kind(WIN32::RPC_S_INTERFACE_NOT_FOUND),
            WIN32::RPC_S_ENTRY_ALREADY_EXISTS => RawError::Kind(WIN32::RPC_S_ENTRY_ALREADY_EXISTS),
            WIN32::RPC_S_ENTRY_NOT_FOUND => RawError::Kind(WIN32::RPC_S_ENTRY_NOT_FOUND),
            WIN32::RPC_S_NAME_SERVICE_UNAVAILABLE => RawError::Kind(WIN32::RPC_S_NAME_SERVICE_UNAVAILABLE),
            WIN32::RPC_S_INVALID_NAF_ID => RawError::Kind(WIN32::RPC_S_INVALID_NAF_ID),
            WIN32::RPC_S_CANNOT_SUPPORT => RawError::Kind(WIN32::RPC_S_CANNOT_SUPPORT),
            WIN32::RPC_S_NO_CONTEXT_AVAILABLE => RawError::Kind(WIN32::RPC_S_NO_CONTEXT_AVAILABLE),
            WIN32::RPC_S_INTERNAL_ERROR => RawError::Kind(WIN32::RPC_S_INTERNAL_ERROR),
            WIN32::RPC_S_ZERO_DIVIDE => RawError::Kind(WIN32::RPC_S_ZERO_DIVIDE),
            WIN32::RPC_S_ADDRESS_ERROR => RawError::Kind(WIN32::RPC_S_ADDRESS_ERROR),
            WIN32::RPC_S_FP_DIV_ZERO => RawError::Kind(WIN32::RPC_S_FP_DIV_ZERO),
            WIN32::RPC_S_FP_UNDERFLOW => RawError::Kind(WIN32::RPC_S_FP_UNDERFLOW),
            WIN32::RPC_S_FP_OVERFLOW => RawError::Kind(WIN32::RPC_S_FP_OVERFLOW),
            WIN32::RPC_X_NO_MORE_ENTRIES => RawError::Kind(WIN32::RPC_X_NO_MORE_ENTRIES),
            WIN32::RPC_X_SS_CHAR_TRANS_OPEN_FAIL => RawError::Kind(WIN32::RPC_X_SS_CHAR_TRANS_OPEN_FAIL),
            WIN32::RPC_X_SS_CHAR_TRANS_SHORT_FILE => RawError::Kind(WIN32::RPC_X_SS_CHAR_TRANS_SHORT_FILE),
            WIN32::RPC_X_SS_IN_NULL_CONTEXT => RawError::Kind(WIN32::RPC_X_SS_IN_NULL_CONTEXT),
            WIN32::RPC_X_SS_CONTEXT_DAMAGED => RawError::Kind(WIN32::RPC_X_SS_CONTEXT_DAMAGED),
            WIN32::RPC_X_SS_HANDLES_MISMATCH => RawError::Kind(WIN32::RPC_X_SS_HANDLES_MISMATCH),
            WIN32::RPC_X_SS_CANNOT_GET_CALL_HANDLE => RawError::Kind(WIN32::RPC_X_SS_CANNOT_GET_CALL_HANDLE),
            WIN32::RPC_X_NULL_REF_POINTER => RawError::Kind(WIN32::RPC_X_NULL_REF_POINTER),
            WIN32::RPC_X_ENUM_VALUE_OUT_OF_RANGE => RawError::Kind(WIN32::RPC_X_ENUM_VALUE_OUT_OF_RANGE),
            WIN32::RPC_X_BYTE_COUNT_TOO_SMALL => RawError::Kind(WIN32::RPC_X_BYTE_COUNT_TOO_SMALL),
            WIN32::RPC_X_BAD_STUB_DATA => RawError::Kind(WIN32::RPC_X_BAD_STUB_DATA),
            WIN32::ERROR_INVALID_USER_BUFFER => RawError::Kind(WIN32::ERROR_INVALID_USER_BUFFER),
            WIN32::ERROR_UNRECOGNIZED_MEDIA => RawError::Kind(WIN32::ERROR_UNRECOGNIZED_MEDIA),
            WIN32::ERROR_NO_TRUST_LSA_SECRET => RawError::Kind(WIN32::ERROR_NO_TRUST_LSA_SECRET),
            WIN32::ERROR_NO_TRUST_SAM_ACCOUNT => RawError::Kind(WIN32::ERROR_NO_TRUST_SAM_ACCOUNT),
            WIN32::ERROR_TRUSTED_DOMAIN_FAILURE => RawError::Kind(WIN32::ERROR_TRUSTED_DOMAIN_FAILURE),
            WIN32::ERROR_TRUSTED_RELATIONSHIP_FAILURE => RawError::Kind(WIN32::ERROR_TRUSTED_RELATIONSHIP_FAILURE),
            WIN32::ERROR_TRUST_FAILURE => RawError::Kind(WIN32::ERROR_TRUST_FAILURE),
            WIN32::RPC_S_CALL_IN_PROGRESS => RawError::Kind(WIN32::RPC_S_CALL_IN_PROGRESS),
            WIN32::ERROR_NETLOGON_NOT_STARTED => RawError::Kind(WIN32::ERROR_NETLOGON_NOT_STARTED),
            WIN32::ERROR_ACCOUNT_EXPIRED => RawError::Kind(WIN32::ERROR_ACCOUNT_EXPIRED),
            WIN32::ERROR_REDIRECTOR_HAS_OPEN_HANDLES => RawError::Kind(WIN32::ERROR_REDIRECTOR_HAS_OPEN_HANDLES),
            WIN32::ERROR_PRINTER_DRIVER_ALREADY_INSTALLED => RawError::Kind(WIN32::ERROR_PRINTER_DRIVER_ALREADY_INSTALLED),
            WIN32::ERROR_UNKNOWN_PORT => RawError::Kind(WIN32::ERROR_UNKNOWN_PORT),
            WIN32::ERROR_UNKNOWN_PRINTER_DRIVER => RawError::Kind(WIN32::ERROR_UNKNOWN_PRINTER_DRIVER),
            WIN32::ERROR_UNKNOWN_PRINTPROCESSOR => RawError::Kind(WIN32::ERROR_UNKNOWN_PRINTPROCESSOR),
            WIN32::ERROR_INVALID_SEPARATOR_FILE => RawError::Kind(WIN32::ERROR_INVALID_SEPARATOR_FILE),
            WIN32::ERROR_INVALID_PRIORITY => RawError::Kind(WIN32::ERROR_INVALID_PRIORITY),
            WIN32::ERROR_INVALID_PRINTER_NAME => RawError::Kind(WIN32::ERROR_INVALID_PRINTER_NAME),
            WIN32::ERROR_PRINTER_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_PRINTER_ALREADY_EXISTS),
            WIN32::ERROR_INVALID_PRINTER_COMMAND => RawError::Kind(WIN32::ERROR_INVALID_PRINTER_COMMAND),
            WIN32::ERROR_INVALID_DATATYPE => RawError::Kind(WIN32::ERROR_INVALID_DATATYPE),
            WIN32::ERROR_INVALID_ENVIRONMENT => RawError::Kind(WIN32::ERROR_INVALID_ENVIRONMENT),
            WIN32::RPC_S_NO_MORE_BINDINGS => RawError::Kind(WIN32::RPC_S_NO_MORE_BINDINGS),
            WIN32::ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT => RawError::Kind(WIN32::ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT),
            WIN32::ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT => RawError::Kind(WIN32::ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT),
            WIN32::ERROR_NOLOGON_SERVER_TRUST_ACCOUNT => RawError::Kind(WIN32::ERROR_NOLOGON_SERVER_TRUST_ACCOUNT),
            WIN32::ERROR_DOMAIN_TRUST_INCONSISTENT => RawError::Kind(WIN32::ERROR_DOMAIN_TRUST_INCONSISTENT),
            WIN32::ERROR_SERVER_HAS_OPEN_HANDLES => RawError::Kind(WIN32::ERROR_SERVER_HAS_OPEN_HANDLES),
            WIN32::ERROR_RESOURCE_DATA_NOT_FOUND => RawError::Kind(WIN32::ERROR_RESOURCE_DATA_NOT_FOUND),
            WIN32::ERROR_RESOURCE_TYPE_NOT_FOUND => RawError::Kind(WIN32::ERROR_RESOURCE_TYPE_NOT_FOUND),
            WIN32::ERROR_RESOURCE_NAME_NOT_FOUND => RawError::Kind(WIN32::ERROR_RESOURCE_NAME_NOT_FOUND),
            WIN32::ERROR_RESOURCE_LANG_NOT_FOUND => RawError::Kind(WIN32::ERROR_RESOURCE_LANG_NOT_FOUND),
            WIN32::ERROR_NOT_ENOUGH_QUOTA => RawError::Kind(WIN32::ERROR_NOT_ENOUGH_QUOTA),
            WIN32::RPC_S_NO_INTERFACES => RawError::Kind(WIN32::RPC_S_NO_INTERFACES),
            WIN32::RPC_S_CALL_CANCELLED => RawError::Kind(WIN32::RPC_S_CALL_CANCELLED),
            WIN32::RPC_S_BINDING_INCOMPLETE => RawError::Kind(WIN32::RPC_S_BINDING_INCOMPLETE),
            WIN32::RPC_S_COMM_FAILURE => RawError::Kind(WIN32::RPC_S_COMM_FAILURE),
            WIN32::RPC_S_UNSUPPORTED_AUTHN_LEVEL => RawError::Kind(WIN32::RPC_S_UNSUPPORTED_AUTHN_LEVEL),
            WIN32::RPC_S_NO_PRINC_NAME => RawError::Kind(WIN32::RPC_S_NO_PRINC_NAME),
            WIN32::RPC_S_NOT_RPC_ERROR => RawError::Kind(WIN32::RPC_S_NOT_RPC_ERROR),
            WIN32::RPC_S_UUID_LOCAL_ONLY => RawError::Kind(WIN32::RPC_S_UUID_LOCAL_ONLY),
            WIN32::RPC_S_SEC_PKG_ERROR => RawError::Kind(WIN32::RPC_S_SEC_PKG_ERROR),
            WIN32::RPC_S_NOT_CANCELLED => RawError::Kind(WIN32::RPC_S_NOT_CANCELLED),
            WIN32::RPC_X_INVALID_ES_ACTION => RawError::Kind(WIN32::RPC_X_INVALID_ES_ACTION),
            WIN32::RPC_X_WRONG_ES_VERSION => RawError::Kind(WIN32::RPC_X_WRONG_ES_VERSION),
            WIN32::RPC_X_WRONG_STUB_VERSION => RawError::Kind(WIN32::RPC_X_WRONG_STUB_VERSION),
            WIN32::RPC_X_INVALID_PIPE_OBJECT => RawError::Kind(WIN32::RPC_X_INVALID_PIPE_OBJECT),
            WIN32::RPC_X_WRONG_PIPE_ORDER => RawError::Kind(WIN32::RPC_X_WRONG_PIPE_ORDER),
            WIN32::RPC_X_WRONG_PIPE_VERSION => RawError::Kind(WIN32::RPC_X_WRONG_PIPE_VERSION),
            WIN32::RPC_S_COOKIE_AUTH_FAILED => RawError::Kind(WIN32::RPC_S_COOKIE_AUTH_FAILED),
            WIN32::RPC_S_DO_NOT_DISTURB => RawError::Kind(WIN32::RPC_S_DO_NOT_DISTURB),
            WIN32::RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED => RawError::Kind(WIN32::RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED),
            WIN32::RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH => RawError::Kind(WIN32::RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH),
            WIN32::RPC_S_GROUP_MEMBER_NOT_FOUND => RawError::Kind(WIN32::RPC_S_GROUP_MEMBER_NOT_FOUND),
            WIN32::EPT_S_CANT_CREATE => RawError::Kind(WIN32::EPT_S_CANT_CREATE),
            WIN32::RPC_S_INVALID_OBJECT => RawError::Kind(WIN32::RPC_S_INVALID_OBJECT),
            WIN32::ERROR_INVALID_TIME => RawError::Kind(WIN32::ERROR_INVALID_TIME),
            WIN32::ERROR_INVALID_FORM_NAME => RawError::Kind(WIN32::ERROR_INVALID_FORM_NAME),
            WIN32::ERROR_INVALID_FORM_SIZE => RawError::Kind(WIN32::ERROR_INVALID_FORM_SIZE),
            WIN32::ERROR_ALREADY_WAITING => RawError::Kind(WIN32::ERROR_ALREADY_WAITING),
            WIN32::ERROR_PRINTER_DELETED => RawError::Kind(WIN32::ERROR_PRINTER_DELETED),
            WIN32::ERROR_INVALID_PRINTER_STATE => RawError::Kind(WIN32::ERROR_INVALID_PRINTER_STATE),
            WIN32::ERROR_PASSWORD_MUST_CHANGE => RawError::Kind(WIN32::ERROR_PASSWORD_MUST_CHANGE),
            WIN32::ERROR_DOMAIN_CONTROLLER_NOT_FOUND => RawError::Kind(WIN32::ERROR_DOMAIN_CONTROLLER_NOT_FOUND),
            WIN32::ERROR_ACCOUNT_LOCKED_OUT => RawError::Kind(WIN32::ERROR_ACCOUNT_LOCKED_OUT),
            WIN32::OR_INVALID_OXID => RawError::Kind(WIN32::OR_INVALID_OXID),
            WIN32::OR_INVALID_OID => RawError::Kind(WIN32::OR_INVALID_OID),
            WIN32::OR_INVALID_SET => RawError::Kind(WIN32::OR_INVALID_SET),
            WIN32::RPC_S_SEND_INCOMPLETE => RawError::Kind(WIN32::RPC_S_SEND_INCOMPLETE),
            WIN32::RPC_S_INVALID_ASYNC_HANDLE => RawError::Kind(WIN32::RPC_S_INVALID_ASYNC_HANDLE),
            WIN32::RPC_S_INVALID_ASYNC_CALL => RawError::Kind(WIN32::RPC_S_INVALID_ASYNC_CALL),
            WIN32::RPC_X_PIPE_CLOSED => RawError::Kind(WIN32::RPC_X_PIPE_CLOSED),
            WIN32::RPC_X_PIPE_DISCIPLINE_ERROR => RawError::Kind(WIN32::RPC_X_PIPE_DISCIPLINE_ERROR),
            WIN32::RPC_X_PIPE_EMPTY => RawError::Kind(WIN32::RPC_X_PIPE_EMPTY),
            WIN32::ERROR_NO_SITENAME => RawError::Kind(WIN32::ERROR_NO_SITENAME),
            WIN32::ERROR_CANT_ACCESS_FILE => RawError::Kind(WIN32::ERROR_CANT_ACCESS_FILE),
            WIN32::ERROR_CANT_RESOLVE_FILENAME => RawError::Kind(WIN32::ERROR_CANT_RESOLVE_FILENAME),
            WIN32::RPC_S_ENTRY_TYPE_MISMATCH => RawError::Kind(WIN32::RPC_S_ENTRY_TYPE_MISMATCH),
            WIN32::RPC_S_NOT_ALL_OBJS_EXPORTED => RawError::Kind(WIN32::RPC_S_NOT_ALL_OBJS_EXPORTED),
            WIN32::RPC_S_INTERFACE_NOT_EXPORTED => RawError::Kind(WIN32::RPC_S_INTERFACE_NOT_EXPORTED),
            WIN32::RPC_S_PROFILE_NOT_ADDED => RawError::Kind(WIN32::RPC_S_PROFILE_NOT_ADDED),
            WIN32::RPC_S_PRF_ELT_NOT_ADDED => RawError::Kind(WIN32::RPC_S_PRF_ELT_NOT_ADDED),
            WIN32::RPC_S_PRF_ELT_NOT_REMOVED => RawError::Kind(WIN32::RPC_S_PRF_ELT_NOT_REMOVED),
            WIN32::RPC_S_GRP_ELT_NOT_ADDED => RawError::Kind(WIN32::RPC_S_GRP_ELT_NOT_ADDED),
            WIN32::RPC_S_GRP_ELT_NOT_REMOVED => RawError::Kind(WIN32::RPC_S_GRP_ELT_NOT_REMOVED),
            WIN32::ERROR_KM_DRIVER_BLOCKED => RawError::Kind(WIN32::ERROR_KM_DRIVER_BLOCKED),
            WIN32::ERROR_CONTEXT_EXPIRED => RawError::Kind(WIN32::ERROR_CONTEXT_EXPIRED),
            WIN32::ERROR_PER_USER_TRUST_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_PER_USER_TRUST_QUOTA_EXCEEDED),
            WIN32::ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED),
            WIN32::ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED),
            WIN32::ERROR_AUTHENTICATION_FIREWALL_FAILED => RawError::Kind(WIN32::ERROR_AUTHENTICATION_FIREWALL_FAILED),
            WIN32::ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED => RawError::Kind(WIN32::ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED),
            WIN32::ERROR_NTLM_BLOCKED => RawError::Kind(WIN32::ERROR_NTLM_BLOCKED),
            WIN32::ERROR_PASSWORD_CHANGE_REQUIRED => RawError::Kind(WIN32::ERROR_PASSWORD_CHANGE_REQUIRED),
            WIN32::ERROR_LOST_MODE_LOGON_RESTRICTION => RawError::Kind(WIN32::ERROR_LOST_MODE_LOGON_RESTRICTION),
            WIN32::ERROR_INVALID_PIXEL_FORMAT => RawError::Kind(WIN32::ERROR_INVALID_PIXEL_FORMAT),
            WIN32::ERROR_BAD_DRIVER => RawError::Kind(WIN32::ERROR_BAD_DRIVER),
            WIN32::ERROR_INVALID_WINDOW_STYLE => RawError::Kind(WIN32::ERROR_INVALID_WINDOW_STYLE),
            WIN32::ERROR_METAFILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_METAFILE_NOT_SUPPORTED),
            WIN32::ERROR_TRANSFORM_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_TRANSFORM_NOT_SUPPORTED),
            WIN32::ERROR_CLIPPING_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLIPPING_NOT_SUPPORTED),
            WIN32::ERROR_INVALID_CMM => RawError::Kind(WIN32::ERROR_INVALID_CMM),
            WIN32::ERROR_INVALID_PROFILE => RawError::Kind(WIN32::ERROR_INVALID_PROFILE),
            WIN32::ERROR_TAG_NOT_FOUND => RawError::Kind(WIN32::ERROR_TAG_NOT_FOUND),
            WIN32::ERROR_TAG_NOT_PRESENT => RawError::Kind(WIN32::ERROR_TAG_NOT_PRESENT),
            WIN32::ERROR_DUPLICATE_TAG => RawError::Kind(WIN32::ERROR_DUPLICATE_TAG),
            WIN32::ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE => RawError::Kind(WIN32::ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE),
            WIN32::ERROR_PROFILE_NOT_FOUND => RawError::Kind(WIN32::ERROR_PROFILE_NOT_FOUND),
            WIN32::ERROR_INVALID_COLORSPACE => RawError::Kind(WIN32::ERROR_INVALID_COLORSPACE),
            WIN32::ERROR_ICM_NOT_ENABLED => RawError::Kind(WIN32::ERROR_ICM_NOT_ENABLED),
            WIN32::ERROR_DELETING_ICM_XFORM => RawError::Kind(WIN32::ERROR_DELETING_ICM_XFORM),
            WIN32::ERROR_INVALID_TRANSFORM => RawError::Kind(WIN32::ERROR_INVALID_TRANSFORM),
            WIN32::ERROR_COLORSPACE_MISMATCH => RawError::Kind(WIN32::ERROR_COLORSPACE_MISMATCH),
            WIN32::ERROR_INVALID_COLORINDEX => RawError::Kind(WIN32::ERROR_INVALID_COLORINDEX),
            WIN32::ERROR_PROFILE_DOES_NOT_MATCH_DEVICE => RawError::Kind(WIN32::ERROR_PROFILE_DOES_NOT_MATCH_DEVICE),
            WIN32::NERR_NetNotStarted => RawError::Kind(WIN32::NERR_NetNotStarted),
            WIN32::NERR_UnknownServer => RawError::Kind(WIN32::NERR_UnknownServer),
            WIN32::NERR_ShareMem => RawError::Kind(WIN32::NERR_ShareMem),
            WIN32::NERR_NoNetworkResource => RawError::Kind(WIN32::NERR_NoNetworkResource),
            WIN32::NERR_RemoteOnly => RawError::Kind(WIN32::NERR_RemoteOnly),
            WIN32::NERR_DevNotRedirected => RawError::Kind(WIN32::NERR_DevNotRedirected),
            WIN32::ERROR_CONNECTED_OTHER_PASSWORD => RawError::Kind(WIN32::ERROR_CONNECTED_OTHER_PASSWORD),
            WIN32::ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT => RawError::Kind(WIN32::ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT),
            WIN32::NERR_ServerNotStarted => RawError::Kind(WIN32::NERR_ServerNotStarted),
            WIN32::NERR_ItemNotFound => RawError::Kind(WIN32::NERR_ItemNotFound),
            WIN32::NERR_UnknownDevDir => RawError::Kind(WIN32::NERR_UnknownDevDir),
            WIN32::NERR_RedirectedPath => RawError::Kind(WIN32::NERR_RedirectedPath),
            WIN32::NERR_DuplicateShare => RawError::Kind(WIN32::NERR_DuplicateShare),
            WIN32::NERR_NoRoom => RawError::Kind(WIN32::NERR_NoRoom),
            WIN32::NERR_TooManyItems => RawError::Kind(WIN32::NERR_TooManyItems),
            WIN32::NERR_InvalidMaxUsers => RawError::Kind(WIN32::NERR_InvalidMaxUsers),
            WIN32::NERR_BufTooSmall => RawError::Kind(WIN32::NERR_BufTooSmall),
            WIN32::NERR_RemoteErr => RawError::Kind(WIN32::NERR_RemoteErr),
            WIN32::NERR_LanmanIniError => RawError::Kind(WIN32::NERR_LanmanIniError),
            WIN32::NERR_NetworkError => RawError::Kind(WIN32::NERR_NetworkError),
            WIN32::NERR_WkstaInconsistentState => RawError::Kind(WIN32::NERR_WkstaInconsistentState),
            WIN32::NERR_WkstaNotStarted => RawError::Kind(WIN32::NERR_WkstaNotStarted),
            WIN32::NERR_BrowserNotStarted => RawError::Kind(WIN32::NERR_BrowserNotStarted),
            WIN32::NERR_InternalError => RawError::Kind(WIN32::NERR_InternalError),
            WIN32::NERR_BadTransactConfig => RawError::Kind(WIN32::NERR_BadTransactConfig),
            WIN32::NERR_InvalidAPI => RawError::Kind(WIN32::NERR_InvalidAPI),
            WIN32::NERR_BadEventName => RawError::Kind(WIN32::NERR_BadEventName),
            WIN32::NERR_DupNameReboot => RawError::Kind(WIN32::NERR_DupNameReboot),
            WIN32::NERR_CfgCompNotFound => RawError::Kind(WIN32::NERR_CfgCompNotFound),
            WIN32::NERR_CfgParamNotFound => RawError::Kind(WIN32::NERR_CfgParamNotFound),
            WIN32::NERR_LineTooLong => RawError::Kind(WIN32::NERR_LineTooLong),
            WIN32::NERR_QNotFound => RawError::Kind(WIN32::NERR_QNotFound),
            WIN32::NERR_JobNotFound => RawError::Kind(WIN32::NERR_JobNotFound),
            WIN32::NERR_DestNotFound => RawError::Kind(WIN32::NERR_DestNotFound),
            WIN32::NERR_DestExists => RawError::Kind(WIN32::NERR_DestExists),
            WIN32::NERR_QExists => RawError::Kind(WIN32::NERR_QExists),
            WIN32::NERR_QNoRoom => RawError::Kind(WIN32::NERR_QNoRoom),
            WIN32::NERR_JobNoRoom => RawError::Kind(WIN32::NERR_JobNoRoom),
            WIN32::NERR_DestNoRoom => RawError::Kind(WIN32::NERR_DestNoRoom),
            WIN32::NERR_DestIdle => RawError::Kind(WIN32::NERR_DestIdle),
            WIN32::NERR_DestInvalidOp => RawError::Kind(WIN32::NERR_DestInvalidOp),
            WIN32::NERR_ProcNoRespond => RawError::Kind(WIN32::NERR_ProcNoRespond),
            WIN32::NERR_SpoolerNotLoaded => RawError::Kind(WIN32::NERR_SpoolerNotLoaded),
            WIN32::NERR_DestInvalidState => RawError::Kind(WIN32::NERR_DestInvalidState),
            WIN32::NERR_QinvalidState => RawError::Kind(WIN32::NERR_QinvalidState),
            WIN32::NERR_JobInvalidState => RawError::Kind(WIN32::NERR_JobInvalidState),
            WIN32::NERR_SpoolNoMemory => RawError::Kind(WIN32::NERR_SpoolNoMemory),
            WIN32::NERR_DriverNotFound => RawError::Kind(WIN32::NERR_DriverNotFound),
            WIN32::NERR_DataTypeInvalid => RawError::Kind(WIN32::NERR_DataTypeInvalid),
            WIN32::NERR_ProcNotFound => RawError::Kind(WIN32::NERR_ProcNotFound),
            WIN32::NERR_ServiceTableLocked => RawError::Kind(WIN32::NERR_ServiceTableLocked),
            WIN32::NERR_ServiceTableFull => RawError::Kind(WIN32::NERR_ServiceTableFull),
            WIN32::NERR_ServiceInstalled => RawError::Kind(WIN32::NERR_ServiceInstalled),
            WIN32::NERR_ServiceEntryLocked => RawError::Kind(WIN32::NERR_ServiceEntryLocked),
            WIN32::NERR_ServiceNotInstalled => RawError::Kind(WIN32::NERR_ServiceNotInstalled),
            WIN32::NERR_BadServiceName => RawError::Kind(WIN32::NERR_BadServiceName),
            WIN32::NERR_ServiceCtlTimeout => RawError::Kind(WIN32::NERR_ServiceCtlTimeout),
            WIN32::NERR_ServiceCtlBusy => RawError::Kind(WIN32::NERR_ServiceCtlBusy),
            WIN32::NERR_BadServiceProgName => RawError::Kind(WIN32::NERR_BadServiceProgName),
            WIN32::NERR_ServiceNotCtrl => RawError::Kind(WIN32::NERR_ServiceNotCtrl),
            WIN32::NERR_ServiceKillProc => RawError::Kind(WIN32::NERR_ServiceKillProc),
            WIN32::NERR_ServiceCtlNotValid => RawError::Kind(WIN32::NERR_ServiceCtlNotValid),
            WIN32::NERR_NotInDispatchTbl => RawError::Kind(WIN32::NERR_NotInDispatchTbl),
            WIN32::NERR_BadControlRecv => RawError::Kind(WIN32::NERR_BadControlRecv),
            WIN32::NERR_ServiceNotStarting => RawError::Kind(WIN32::NERR_ServiceNotStarting),
            WIN32::NERR_AlreadyLoggedOn => RawError::Kind(WIN32::NERR_AlreadyLoggedOn),
            WIN32::NERR_NotLoggedOn => RawError::Kind(WIN32::NERR_NotLoggedOn),
            WIN32::ERROR_BAD_USERNAME => RawError::Kind(WIN32::ERROR_BAD_USERNAME),
            WIN32::NERR_BadUsername => RawError::Kind(WIN32::NERR_BadUsername),
            WIN32::NERR_BadPassword => RawError::Kind(WIN32::NERR_BadPassword),
            WIN32::NERR_UnableToAddName_W => RawError::Kind(WIN32::NERR_UnableToAddName_W),
            WIN32::NERR_UnableToAddName_F => RawError::Kind(WIN32::NERR_UnableToAddName_F),
            WIN32::NERR_UnableToDelName_W => RawError::Kind(WIN32::NERR_UnableToDelName_W),
            WIN32::NERR_UnableToDelName_F => RawError::Kind(WIN32::NERR_UnableToDelName_F),
            WIN32::NERR_LogonsPaused => RawError::Kind(WIN32::NERR_LogonsPaused),
            WIN32::NERR_LogonServerConflict => RawError::Kind(WIN32::NERR_LogonServerConflict),
            WIN32::NERR_LogonNoUserPath => RawError::Kind(WIN32::NERR_LogonNoUserPath),
            WIN32::NERR_LogonScriptError => RawError::Kind(WIN32::NERR_LogonScriptError),
            WIN32::NERR_StandaloneLogon => RawError::Kind(WIN32::NERR_StandaloneLogon),
            WIN32::NERR_LogonServerNotFound => RawError::Kind(WIN32::NERR_LogonServerNotFound),
            WIN32::NERR_LogonDomainExists => RawError::Kind(WIN32::NERR_LogonDomainExists),
            WIN32::NERR_NonValidatedLogon => RawError::Kind(WIN32::NERR_NonValidatedLogon),
            WIN32::NERR_ACFNotFound => RawError::Kind(WIN32::NERR_ACFNotFound),
            WIN32::NERR_GroupNotFound => RawError::Kind(WIN32::NERR_GroupNotFound),
            WIN32::NERR_UserNotFound => RawError::Kind(WIN32::NERR_UserNotFound),
            WIN32::NERR_ResourceNotFound => RawError::Kind(WIN32::NERR_ResourceNotFound),
            WIN32::NERR_GroupExists => RawError::Kind(WIN32::NERR_GroupExists),
            WIN32::NERR_UserExists => RawError::Kind(WIN32::NERR_UserExists),
            WIN32::NERR_ResourceExists => RawError::Kind(WIN32::NERR_ResourceExists),
            WIN32::NERR_NotPrimary => RawError::Kind(WIN32::NERR_NotPrimary),
            WIN32::NERR_ACFNotLoaded => RawError::Kind(WIN32::NERR_ACFNotLoaded),
            WIN32::NERR_ACFNoRoom => RawError::Kind(WIN32::NERR_ACFNoRoom),
            WIN32::NERR_ACFFileIOFail => RawError::Kind(WIN32::NERR_ACFFileIOFail),
            WIN32::NERR_ACFTooManyLists => RawError::Kind(WIN32::NERR_ACFTooManyLists),
            WIN32::NERR_UserLogon => RawError::Kind(WIN32::NERR_UserLogon),
            WIN32::NERR_ACFNoParent => RawError::Kind(WIN32::NERR_ACFNoParent),
            WIN32::NERR_CanNotGrowSegment => RawError::Kind(WIN32::NERR_CanNotGrowSegment),
            WIN32::NERR_SpeGroupOp => RawError::Kind(WIN32::NERR_SpeGroupOp),
            WIN32::NERR_NotInCache => RawError::Kind(WIN32::NERR_NotInCache),
            WIN32::NERR_UserInGroup => RawError::Kind(WIN32::NERR_UserInGroup),
            WIN32::NERR_UserNotInGroup => RawError::Kind(WIN32::NERR_UserNotInGroup),
            WIN32::NERR_AccountUndefined => RawError::Kind(WIN32::NERR_AccountUndefined),
            WIN32::NERR_AccountExpired => RawError::Kind(WIN32::NERR_AccountExpired),
            WIN32::NERR_InvalidWorkstation => RawError::Kind(WIN32::NERR_InvalidWorkstation),
            WIN32::NERR_InvalidLogonHours => RawError::Kind(WIN32::NERR_InvalidLogonHours),
            WIN32::NERR_PasswordExpired => RawError::Kind(WIN32::NERR_PasswordExpired),
            WIN32::NERR_PasswordCantChange => RawError::Kind(WIN32::NERR_PasswordCantChange),
            WIN32::NERR_PasswordHistConflict => RawError::Kind(WIN32::NERR_PasswordHistConflict),
            WIN32::NERR_PasswordTooShort => RawError::Kind(WIN32::NERR_PasswordTooShort),
            WIN32::NERR_PasswordTooRecent => RawError::Kind(WIN32::NERR_PasswordTooRecent),
            WIN32::NERR_InvalidDatabase => RawError::Kind(WIN32::NERR_InvalidDatabase),
            WIN32::NERR_DatabaseUpToDate => RawError::Kind(WIN32::NERR_DatabaseUpToDate),
            WIN32::NERR_SyncRequired => RawError::Kind(WIN32::NERR_SyncRequired),
            WIN32::ERROR_NOT_CONNECTED => RawError::Kind(WIN32::ERROR_NOT_CONNECTED),
            WIN32::NERR_UseNotFound => RawError::Kind(WIN32::NERR_UseNotFound),
            WIN32::NERR_BadAsgType => RawError::Kind(WIN32::NERR_BadAsgType),
            WIN32::NERR_DeviceIsShared => RawError::Kind(WIN32::NERR_DeviceIsShared),
            WIN32::NERR_NoComputerName => RawError::Kind(WIN32::NERR_NoComputerName),
            WIN32::NERR_MsgAlreadyStarted => RawError::Kind(WIN32::NERR_MsgAlreadyStarted),
            WIN32::NERR_MsgInitFailed => RawError::Kind(WIN32::NERR_MsgInitFailed),
            WIN32::NERR_NameNotFound => RawError::Kind(WIN32::NERR_NameNotFound),
            WIN32::NERR_AlreadyForwarded => RawError::Kind(WIN32::NERR_AlreadyForwarded),
            WIN32::NERR_AddForwarded => RawError::Kind(WIN32::NERR_AddForwarded),
            WIN32::NERR_AlreadyExists => RawError::Kind(WIN32::NERR_AlreadyExists),
            WIN32::NERR_TooManyNames => RawError::Kind(WIN32::NERR_TooManyNames),
            WIN32::NERR_DelComputerName => RawError::Kind(WIN32::NERR_DelComputerName),
            WIN32::NERR_LocalForward => RawError::Kind(WIN32::NERR_LocalForward),
            WIN32::NERR_GrpMsgProcessor => RawError::Kind(WIN32::NERR_GrpMsgProcessor),
            WIN32::NERR_PausedRemote => RawError::Kind(WIN32::NERR_PausedRemote),
            WIN32::NERR_BadReceive => RawError::Kind(WIN32::NERR_BadReceive),
            WIN32::NERR_NameInUse => RawError::Kind(WIN32::NERR_NameInUse),
            WIN32::NERR_MsgNotStarted => RawError::Kind(WIN32::NERR_MsgNotStarted),
            WIN32::NERR_NotLocalName => RawError::Kind(WIN32::NERR_NotLocalName),
            WIN32::NERR_NoForwardName => RawError::Kind(WIN32::NERR_NoForwardName),
            WIN32::NERR_RemoteFull => RawError::Kind(WIN32::NERR_RemoteFull),
            WIN32::NERR_NameNotForwarded => RawError::Kind(WIN32::NERR_NameNotForwarded),
            WIN32::NERR_TruncatedBroadcast => RawError::Kind(WIN32::NERR_TruncatedBroadcast),
            WIN32::NERR_InvalidDevice => RawError::Kind(WIN32::NERR_InvalidDevice),
            WIN32::NERR_WriteFault => RawError::Kind(WIN32::NERR_WriteFault),
            WIN32::NERR_DuplicateName => RawError::Kind(WIN32::NERR_DuplicateName),
            WIN32::NERR_DeleteLater => RawError::Kind(WIN32::NERR_DeleteLater),
            WIN32::NERR_IncompleteDel => RawError::Kind(WIN32::NERR_IncompleteDel),
            WIN32::NERR_MultipleNets => RawError::Kind(WIN32::NERR_MultipleNets),
            WIN32::NERR_NetNameNotFound => RawError::Kind(WIN32::NERR_NetNameNotFound),
            WIN32::NERR_DeviceNotShared => RawError::Kind(WIN32::NERR_DeviceNotShared),
            WIN32::NERR_ClientNameNotFound => RawError::Kind(WIN32::NERR_ClientNameNotFound),
            WIN32::NERR_FileIdNotFound => RawError::Kind(WIN32::NERR_FileIdNotFound),
            WIN32::NERR_ExecFailure => RawError::Kind(WIN32::NERR_ExecFailure),
            WIN32::NERR_TmpFile => RawError::Kind(WIN32::NERR_TmpFile),
            WIN32::NERR_TooMuchData => RawError::Kind(WIN32::NERR_TooMuchData),
            WIN32::NERR_DeviceShareConflict => RawError::Kind(WIN32::NERR_DeviceShareConflict),
            WIN32::NERR_BrowserTableIncomplete => RawError::Kind(WIN32::NERR_BrowserTableIncomplete),
            WIN32::NERR_NotLocalDomain => RawError::Kind(WIN32::NERR_NotLocalDomain),
            WIN32::NERR_IsDfsShare => RawError::Kind(WIN32::NERR_IsDfsShare),
            WIN32::NERR_DevInvalidOpCode => RawError::Kind(WIN32::NERR_DevInvalidOpCode),
            WIN32::NERR_DevNotFound => RawError::Kind(WIN32::NERR_DevNotFound),
            WIN32::NERR_DevNotOpen => RawError::Kind(WIN32::NERR_DevNotOpen),
            WIN32::NERR_BadQueueDevString => RawError::Kind(WIN32::NERR_BadQueueDevString),
            WIN32::NERR_BadQueuePriority => RawError::Kind(WIN32::NERR_BadQueuePriority),
            WIN32::NERR_NoCommDevs => RawError::Kind(WIN32::NERR_NoCommDevs),
            WIN32::NERR_QueueNotFound => RawError::Kind(WIN32::NERR_QueueNotFound),
            WIN32::NERR_BadDevString => RawError::Kind(WIN32::NERR_BadDevString),
            WIN32::NERR_BadDev => RawError::Kind(WIN32::NERR_BadDev),
            WIN32::NERR_InUseBySpooler => RawError::Kind(WIN32::NERR_InUseBySpooler),
            WIN32::NERR_CommDevInUse => RawError::Kind(WIN32::NERR_CommDevInUse),
            WIN32::NERR_InvalidComputer => RawError::Kind(WIN32::NERR_InvalidComputer),
            WIN32::NERR_MaxLenExceeded => RawError::Kind(WIN32::NERR_MaxLenExceeded),
            WIN32::NERR_BadComponent => RawError::Kind(WIN32::NERR_BadComponent),
            WIN32::NERR_CantType => RawError::Kind(WIN32::NERR_CantType),
            WIN32::NERR_TooManyEntries => RawError::Kind(WIN32::NERR_TooManyEntries),
            WIN32::NERR_ProfileFileTooBig => RawError::Kind(WIN32::NERR_ProfileFileTooBig),
            WIN32::NERR_ProfileOffset => RawError::Kind(WIN32::NERR_ProfileOffset),
            WIN32::NERR_ProfileCleanup => RawError::Kind(WIN32::NERR_ProfileCleanup),
            WIN32::NERR_ProfileUnknownCmd => RawError::Kind(WIN32::NERR_ProfileUnknownCmd),
            WIN32::NERR_ProfileLoadErr => RawError::Kind(WIN32::NERR_ProfileLoadErr),
            WIN32::NERR_ProfileSaveErr => RawError::Kind(WIN32::NERR_ProfileSaveErr),
            WIN32::NERR_LogOverflow => RawError::Kind(WIN32::NERR_LogOverflow),
            WIN32::NERR_LogFileChanged => RawError::Kind(WIN32::NERR_LogFileChanged),
            WIN32::NERR_LogFileCorrupt => RawError::Kind(WIN32::NERR_LogFileCorrupt),
            WIN32::NERR_SourceIsDir => RawError::Kind(WIN32::NERR_SourceIsDir),
            WIN32::NERR_BadSource => RawError::Kind(WIN32::NERR_BadSource),
            WIN32::NERR_BadDest => RawError::Kind(WIN32::NERR_BadDest),
            WIN32::NERR_DifferentServers => RawError::Kind(WIN32::NERR_DifferentServers),
            WIN32::NERR_RunSrvPaused => RawError::Kind(WIN32::NERR_RunSrvPaused),
            WIN32::NERR_ErrCommRunSrv => RawError::Kind(WIN32::NERR_ErrCommRunSrv),
            WIN32::NERR_ErrorExecingGhost => RawError::Kind(WIN32::NERR_ErrorExecingGhost),
            WIN32::NERR_ShareNotFound => RawError::Kind(WIN32::NERR_ShareNotFound),
            WIN32::NERR_InvalidLana => RawError::Kind(WIN32::NERR_InvalidLana),
            WIN32::ERROR_OPEN_FILES => RawError::Kind(WIN32::ERROR_OPEN_FILES),
            WIN32::NERR_OpenFiles => RawError::Kind(WIN32::NERR_OpenFiles),
            WIN32::ERROR_ACTIVE_CONNECTIONS => RawError::Kind(WIN32::ERROR_ACTIVE_CONNECTIONS),
            WIN32::NERR_ActiveConns => RawError::Kind(WIN32::NERR_ActiveConns),
            WIN32::NERR_BadPasswordCore => RawError::Kind(WIN32::NERR_BadPasswordCore),
            WIN32::ERROR_DEVICE_IN_USE => RawError::Kind(WIN32::ERROR_DEVICE_IN_USE),
            WIN32::NERR_DevInUse => RawError::Kind(WIN32::NERR_DevInUse),
            WIN32::NERR_LocalDrive => RawError::Kind(WIN32::NERR_LocalDrive),
            WIN32::NERR_AlertExists => RawError::Kind(WIN32::NERR_AlertExists),
            WIN32::NERR_TooManyAlerts => RawError::Kind(WIN32::NERR_TooManyAlerts),
            WIN32::NERR_NoSuchAlert => RawError::Kind(WIN32::NERR_NoSuchAlert),
            WIN32::NERR_BadRecipient => RawError::Kind(WIN32::NERR_BadRecipient),
            WIN32::NERR_AcctLimitExceeded => RawError::Kind(WIN32::NERR_AcctLimitExceeded),
            WIN32::NERR_InvalidLogSeek => RawError::Kind(WIN32::NERR_InvalidLogSeek),
            WIN32::NERR_BadUasConfig => RawError::Kind(WIN32::NERR_BadUasConfig),
            WIN32::NERR_InvalidUASOp => RawError::Kind(WIN32::NERR_InvalidUASOp),
            WIN32::NERR_LastAdmin => RawError::Kind(WIN32::NERR_LastAdmin),
            WIN32::NERR_DCNotFound => RawError::Kind(WIN32::NERR_DCNotFound),
            WIN32::NERR_LogonTrackingError => RawError::Kind(WIN32::NERR_LogonTrackingError),
            WIN32::NERR_NetlogonNotStarted => RawError::Kind(WIN32::NERR_NetlogonNotStarted),
            WIN32::NERR_CanNotGrowUASFile => RawError::Kind(WIN32::NERR_CanNotGrowUASFile),
            WIN32::NERR_TimeDiffAtDC => RawError::Kind(WIN32::NERR_TimeDiffAtDC),
            WIN32::NERR_PasswordMismatch => RawError::Kind(WIN32::NERR_PasswordMismatch),
            WIN32::NERR_NoSuchServer => RawError::Kind(WIN32::NERR_NoSuchServer),
            WIN32::NERR_NoSuchSession => RawError::Kind(WIN32::NERR_NoSuchSession),
            WIN32::NERR_NoSuchConnection => RawError::Kind(WIN32::NERR_NoSuchConnection),
            WIN32::NERR_TooManyServers => RawError::Kind(WIN32::NERR_TooManyServers),
            WIN32::NERR_TooManySessions => RawError::Kind(WIN32::NERR_TooManySessions),
            WIN32::NERR_TooManyConnections => RawError::Kind(WIN32::NERR_TooManyConnections),
            WIN32::NERR_TooManyFiles => RawError::Kind(WIN32::NERR_TooManyFiles),
            WIN32::NERR_NoAlternateServers => RawError::Kind(WIN32::NERR_NoAlternateServers),
            WIN32::NERR_TryDownLevel => RawError::Kind(WIN32::NERR_TryDownLevel),
            WIN32::NERR_UPSDriverNotStarted => RawError::Kind(WIN32::NERR_UPSDriverNotStarted),
            WIN32::NERR_UPSInvalidConfig => RawError::Kind(WIN32::NERR_UPSInvalidConfig),
            WIN32::NERR_UPSInvalidCommPort => RawError::Kind(WIN32::NERR_UPSInvalidCommPort),
            WIN32::NERR_UPSSignalAsserted => RawError::Kind(WIN32::NERR_UPSSignalAsserted),
            WIN32::NERR_UPSShutdownFailed => RawError::Kind(WIN32::NERR_UPSShutdownFailed),
            WIN32::NERR_BadDosRetCode => RawError::Kind(WIN32::NERR_BadDosRetCode),
            WIN32::NERR_ProgNeedsExtraMem => RawError::Kind(WIN32::NERR_ProgNeedsExtraMem),
            WIN32::NERR_BadDosFunction => RawError::Kind(WIN32::NERR_BadDosFunction),
            WIN32::NERR_RemoteBootFailed => RawError::Kind(WIN32::NERR_RemoteBootFailed),
            WIN32::NERR_BadFileCheckSum => RawError::Kind(WIN32::NERR_BadFileCheckSum),
            WIN32::NERR_NoRplBootSystem => RawError::Kind(WIN32::NERR_NoRplBootSystem),
            WIN32::NERR_RplLoadrNetBiosErr => RawError::Kind(WIN32::NERR_RplLoadrNetBiosErr),
            WIN32::NERR_RplLoadrDiskErr => RawError::Kind(WIN32::NERR_RplLoadrDiskErr),
            WIN32::NERR_ImageParamErr => RawError::Kind(WIN32::NERR_ImageParamErr),
            WIN32::NERR_TooManyImageParams => RawError::Kind(WIN32::NERR_TooManyImageParams),
            WIN32::NERR_NonDosFloppyUsed => RawError::Kind(WIN32::NERR_NonDosFloppyUsed),
            WIN32::NERR_RplBootRestart => RawError::Kind(WIN32::NERR_RplBootRestart),
            WIN32::NERR_RplSrvrCallFailed => RawError::Kind(WIN32::NERR_RplSrvrCallFailed),
            WIN32::NERR_CantConnectRplSrvr => RawError::Kind(WIN32::NERR_CantConnectRplSrvr),
            WIN32::NERR_CantOpenImageFile => RawError::Kind(WIN32::NERR_CantOpenImageFile),
            WIN32::NERR_CallingRplSrvr => RawError::Kind(WIN32::NERR_CallingRplSrvr),
            WIN32::NERR_StartingRplBoot => RawError::Kind(WIN32::NERR_StartingRplBoot),
            WIN32::NERR_RplBootServiceTerm => RawError::Kind(WIN32::NERR_RplBootServiceTerm),
            WIN32::NERR_RplBootStartFailed => RawError::Kind(WIN32::NERR_RplBootStartFailed),
            WIN32::NERR_RPL_CONNECTED => RawError::Kind(WIN32::NERR_RPL_CONNECTED),
            WIN32::NERR_BrowserConfiguredToNotRun => RawError::Kind(WIN32::NERR_BrowserConfiguredToNotRun),
            WIN32::NERR_RplNoAdaptersStarted => RawError::Kind(WIN32::NERR_RplNoAdaptersStarted),
            WIN32::NERR_RplBadRegistry => RawError::Kind(WIN32::NERR_RplBadRegistry),
            WIN32::NERR_RplBadDatabase => RawError::Kind(WIN32::NERR_RplBadDatabase),
            WIN32::NERR_RplRplfilesShare => RawError::Kind(WIN32::NERR_RplRplfilesShare),
            WIN32::NERR_RplNotRplServer => RawError::Kind(WIN32::NERR_RplNotRplServer),
            WIN32::NERR_RplCannotEnum => RawError::Kind(WIN32::NERR_RplCannotEnum),
            WIN32::NERR_RplWkstaInfoCorrupted => RawError::Kind(WIN32::NERR_RplWkstaInfoCorrupted),
            WIN32::NERR_RplWkstaNotFound => RawError::Kind(WIN32::NERR_RplWkstaNotFound),
            WIN32::NERR_RplWkstaNameUnavailable => RawError::Kind(WIN32::NERR_RplWkstaNameUnavailable),
            WIN32::NERR_RplProfileInfoCorrupted => RawError::Kind(WIN32::NERR_RplProfileInfoCorrupted),
            WIN32::NERR_RplProfileNotFound => RawError::Kind(WIN32::NERR_RplProfileNotFound),
            WIN32::NERR_RplProfileNameUnavailable => RawError::Kind(WIN32::NERR_RplProfileNameUnavailable),
            WIN32::NERR_RplProfileNotEmpty => RawError::Kind(WIN32::NERR_RplProfileNotEmpty),
            WIN32::NERR_RplConfigInfoCorrupted => RawError::Kind(WIN32::NERR_RplConfigInfoCorrupted),
            WIN32::NERR_RplConfigNotFound => RawError::Kind(WIN32::NERR_RplConfigNotFound),
            WIN32::NERR_RplAdapterInfoCorrupted => RawError::Kind(WIN32::NERR_RplAdapterInfoCorrupted),
            WIN32::NERR_RplInternal => RawError::Kind(WIN32::NERR_RplInternal),
            WIN32::NERR_RplVendorInfoCorrupted => RawError::Kind(WIN32::NERR_RplVendorInfoCorrupted),
            WIN32::NERR_RplBootInfoCorrupted => RawError::Kind(WIN32::NERR_RplBootInfoCorrupted),
            WIN32::NERR_RplWkstaNeedsUserAcct => RawError::Kind(WIN32::NERR_RplWkstaNeedsUserAcct),
            WIN32::NERR_RplNeedsRPLUSERAcct => RawError::Kind(WIN32::NERR_RplNeedsRPLUSERAcct),
            WIN32::NERR_RplBootNotFound => RawError::Kind(WIN32::NERR_RplBootNotFound),
            WIN32::NERR_RplIncompatibleProfile => RawError::Kind(WIN32::NERR_RplIncompatibleProfile),
            WIN32::NERR_RplAdapterNameUnavailable => RawError::Kind(WIN32::NERR_RplAdapterNameUnavailable),
            WIN32::NERR_RplConfigNotEmpty => RawError::Kind(WIN32::NERR_RplConfigNotEmpty),
            WIN32::NERR_RplBootInUse => RawError::Kind(WIN32::NERR_RplBootInUse),
            WIN32::NERR_RplBackupDatabase => RawError::Kind(WIN32::NERR_RplBackupDatabase),
            WIN32::NERR_RplAdapterNotFound => RawError::Kind(WIN32::NERR_RplAdapterNotFound),
            WIN32::NERR_RplVendorNotFound => RawError::Kind(WIN32::NERR_RplVendorNotFound),
            WIN32::NERR_RplVendorNameUnavailable => RawError::Kind(WIN32::NERR_RplVendorNameUnavailable),
            WIN32::NERR_RplBootNameUnavailable => RawError::Kind(WIN32::NERR_RplBootNameUnavailable),
            WIN32::NERR_RplConfigNameUnavailable => RawError::Kind(WIN32::NERR_RplConfigNameUnavailable),
            WIN32::NERR_DfsInternalCorruption => RawError::Kind(WIN32::NERR_DfsInternalCorruption),
            WIN32::NERR_DfsVolumeDataCorrupt => RawError::Kind(WIN32::NERR_DfsVolumeDataCorrupt),
            WIN32::NERR_DfsNoSuchVolume => RawError::Kind(WIN32::NERR_DfsNoSuchVolume),
            WIN32::NERR_DfsVolumeAlreadyExists => RawError::Kind(WIN32::NERR_DfsVolumeAlreadyExists),
            WIN32::NERR_DfsAlreadyShared => RawError::Kind(WIN32::NERR_DfsAlreadyShared),
            WIN32::NERR_DfsNoSuchShare => RawError::Kind(WIN32::NERR_DfsNoSuchShare),
            WIN32::NERR_DfsNotALeafVolume => RawError::Kind(WIN32::NERR_DfsNotALeafVolume),
            WIN32::NERR_DfsLeafVolume => RawError::Kind(WIN32::NERR_DfsLeafVolume),
            WIN32::NERR_DfsVolumeHasMultipleServers => RawError::Kind(WIN32::NERR_DfsVolumeHasMultipleServers),
            WIN32::NERR_DfsCantCreateJunctionPoint => RawError::Kind(WIN32::NERR_DfsCantCreateJunctionPoint),
            WIN32::NERR_DfsServerNotDfsAware => RawError::Kind(WIN32::NERR_DfsServerNotDfsAware),
            WIN32::NERR_DfsBadRenamePath => RawError::Kind(WIN32::NERR_DfsBadRenamePath),
            WIN32::NERR_DfsVolumeIsOffline => RawError::Kind(WIN32::NERR_DfsVolumeIsOffline),
            WIN32::NERR_DfsNoSuchServer => RawError::Kind(WIN32::NERR_DfsNoSuchServer),
            WIN32::NERR_DfsCyclicalName => RawError::Kind(WIN32::NERR_DfsCyclicalName),
            WIN32::NERR_DfsNotSupportedInServerDfs => RawError::Kind(WIN32::NERR_DfsNotSupportedInServerDfs),
            WIN32::NERR_DfsDuplicateService => RawError::Kind(WIN32::NERR_DfsDuplicateService),
            WIN32::NERR_DfsCantRemoveLastServerShare => RawError::Kind(WIN32::NERR_DfsCantRemoveLastServerShare),
            WIN32::NERR_DfsVolumeIsInterDfs => RawError::Kind(WIN32::NERR_DfsVolumeIsInterDfs),
            WIN32::NERR_DfsInconsistent => RawError::Kind(WIN32::NERR_DfsInconsistent),
            WIN32::NERR_DfsServerUpgraded => RawError::Kind(WIN32::NERR_DfsServerUpgraded),
            WIN32::NERR_DfsDataIsIdentical => RawError::Kind(WIN32::NERR_DfsDataIsIdentical),
            WIN32::NERR_DfsCantRemoveDfsRoot => RawError::Kind(WIN32::NERR_DfsCantRemoveDfsRoot),
            WIN32::NERR_DfsChildOrParentInDfs => RawError::Kind(WIN32::NERR_DfsChildOrParentInDfs),
            WIN32::NERR_DfsInternalError => RawError::Kind(WIN32::NERR_DfsInternalError),
            WIN32::NERR_SetupAlreadyJoined => RawError::Kind(WIN32::NERR_SetupAlreadyJoined),
            WIN32::NERR_SetupNotJoined => RawError::Kind(WIN32::NERR_SetupNotJoined),
            WIN32::NERR_SetupDomainController => RawError::Kind(WIN32::NERR_SetupDomainController),
            WIN32::NERR_DefaultJoinRequired => RawError::Kind(WIN32::NERR_DefaultJoinRequired),
            WIN32::NERR_InvalidWorkgroupName => RawError::Kind(WIN32::NERR_InvalidWorkgroupName),
            WIN32::NERR_NameUsesIncompatibleCodePage => RawError::Kind(WIN32::NERR_NameUsesIncompatibleCodePage),
            WIN32::NERR_ComputerAccountNotFound => RawError::Kind(WIN32::NERR_ComputerAccountNotFound),
            WIN32::NERR_PersonalSku => RawError::Kind(WIN32::NERR_PersonalSku),
            WIN32::NERR_PasswordMustChange => RawError::Kind(WIN32::NERR_PasswordMustChange),
            WIN32::NERR_AccountLockedOut => RawError::Kind(WIN32::NERR_AccountLockedOut),
            WIN32::NERR_PasswordTooLong => RawError::Kind(WIN32::NERR_PasswordTooLong),
            WIN32::NERR_PasswordNotComplexEnough => RawError::Kind(WIN32::NERR_PasswordNotComplexEnough),
            WIN32::NERR_PasswordFilterError => RawError::Kind(WIN32::NERR_PasswordFilterError),
            WIN32::ERROR_UNKNOWN_PRINT_MONITOR => RawError::Kind(WIN32::ERROR_UNKNOWN_PRINT_MONITOR),
            WIN32::ERROR_PRINTER_DRIVER_IN_USE => RawError::Kind(WIN32::ERROR_PRINTER_DRIVER_IN_USE),
            WIN32::ERROR_SPOOL_FILE_NOT_FOUND => RawError::Kind(WIN32::ERROR_SPOOL_FILE_NOT_FOUND),
            WIN32::ERROR_SPL_NO_STARTDOC => RawError::Kind(WIN32::ERROR_SPL_NO_STARTDOC),
            WIN32::ERROR_SPL_NO_ADDJOB => RawError::Kind(WIN32::ERROR_SPL_NO_ADDJOB),
            WIN32::ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED => RawError::Kind(WIN32::ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED),
            WIN32::ERROR_PRINT_MONITOR_ALREADY_INSTALLED => RawError::Kind(WIN32::ERROR_PRINT_MONITOR_ALREADY_INSTALLED),
            WIN32::ERROR_INVALID_PRINT_MONITOR => RawError::Kind(WIN32::ERROR_INVALID_PRINT_MONITOR),
            WIN32::ERROR_PRINT_MONITOR_IN_USE => RawError::Kind(WIN32::ERROR_PRINT_MONITOR_IN_USE),
            WIN32::ERROR_PRINTER_HAS_JOBS_QUEUED => RawError::Kind(WIN32::ERROR_PRINTER_HAS_JOBS_QUEUED),
            WIN32::ERROR_SUCCESS_REBOOT_REQUIRED => RawError::Kind(WIN32::ERROR_SUCCESS_REBOOT_REQUIRED),
            WIN32::ERROR_SUCCESS_RESTART_REQUIRED => RawError::Kind(WIN32::ERROR_SUCCESS_RESTART_REQUIRED),
            WIN32::ERROR_PRINTER_NOT_FOUND => RawError::Kind(WIN32::ERROR_PRINTER_NOT_FOUND),
            WIN32::ERROR_PRINTER_DRIVER_WARNED => RawError::Kind(WIN32::ERROR_PRINTER_DRIVER_WARNED),
            WIN32::ERROR_PRINTER_DRIVER_BLOCKED => RawError::Kind(WIN32::ERROR_PRINTER_DRIVER_BLOCKED),
            WIN32::ERROR_PRINTER_DRIVER_PACKAGE_IN_USE => RawError::Kind(WIN32::ERROR_PRINTER_DRIVER_PACKAGE_IN_USE),
            WIN32::ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND => RawError::Kind(WIN32::ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND),
            WIN32::ERROR_FAIL_REBOOT_REQUIRED => RawError::Kind(WIN32::ERROR_FAIL_REBOOT_REQUIRED),
            WIN32::ERROR_FAIL_REBOOT_INITIATED => RawError::Kind(WIN32::ERROR_FAIL_REBOOT_INITIATED),
            WIN32::ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED => RawError::Kind(WIN32::ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED),
            WIN32::ERROR_PRINT_JOB_RESTART_REQUIRED => RawError::Kind(WIN32::ERROR_PRINT_JOB_RESTART_REQUIRED),
            WIN32::ERROR_INVALID_PRINTER_DRIVER_MANIFEST => RawError::Kind(WIN32::ERROR_INVALID_PRINTER_DRIVER_MANIFEST),
            WIN32::ERROR_PRINTER_NOT_SHAREABLE => RawError::Kind(WIN32::ERROR_PRINTER_NOT_SHAREABLE),
            WIN32::ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1 => RawError::Kind(WIN32::ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1),
            WIN32::ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED => RawError::Kind(WIN32::ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED),
            WIN32::ERROR_REQUEST_PAUSED => RawError::Kind(WIN32::ERROR_REQUEST_PAUSED),
            WIN32::ERROR_APPEXEC_CONDITION_NOT_SATISFIED => RawError::Kind(WIN32::ERROR_APPEXEC_CONDITION_NOT_SATISFIED),
            WIN32::ERROR_APPEXEC_HANDLE_INVALIDATED => RawError::Kind(WIN32::ERROR_APPEXEC_HANDLE_INVALIDATED),
            WIN32::ERROR_APPEXEC_INVALID_HOST_GENERATION => RawError::Kind(WIN32::ERROR_APPEXEC_INVALID_HOST_GENERATION),
            WIN32::ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION => RawError::Kind(WIN32::ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION),
            WIN32::ERROR_APPEXEC_INVALID_HOST_STATE => RawError::Kind(WIN32::ERROR_APPEXEC_INVALID_HOST_STATE),
            WIN32::ERROR_APPEXEC_NO_DONOR => RawError::Kind(WIN32::ERROR_APPEXEC_NO_DONOR),
            WIN32::ERROR_APPEXEC_HOST_ID_MISMATCH => RawError::Kind(WIN32::ERROR_APPEXEC_HOST_ID_MISMATCH),
            WIN32::ERROR_APPEXEC_UNKNOWN_USER => RawError::Kind(WIN32::ERROR_APPEXEC_UNKNOWN_USER),
            WIN32::ERROR_APPEXEC_APP_COMPAT_BLOCK => RawError::Kind(WIN32::ERROR_APPEXEC_APP_COMPAT_BLOCK),
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT => RawError::Kind(WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT),
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION => RawError::Kind(WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION),
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING => RawError::Kind(WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING),
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES => RawError::Kind(WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES),
            WIN32::ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED),
            WIN32::ERROR_VRF_VOLATILE_NOT_STOPPABLE => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_NOT_STOPPABLE),
            WIN32::ERROR_VRF_VOLATILE_SAFE_MODE => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_SAFE_MODE),
            WIN32::ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM),
            WIN32::ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS),
            WIN32::ERROR_VRF_VOLATILE_PROTECTED_DRIVER => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_PROTECTED_DRIVER),
            WIN32::ERROR_VRF_VOLATILE_NMI_REGISTERED => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_NMI_REGISTERED),
            WIN32::ERROR_VRF_VOLATILE_SETTINGS_CONFLICT => RawError::Kind(WIN32::ERROR_VRF_VOLATILE_SETTINGS_CONFLICT),
            WIN32::ERROR_DIF_IOCALLBACK_NOT_REPLACED => RawError::Kind(WIN32::ERROR_DIF_IOCALLBACK_NOT_REPLACED),
            WIN32::ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED),
            WIN32::ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED),
            WIN32::ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED),
            WIN32::ERROR_DIF_VOLATILE_INVALID_INFO => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_INVALID_INFO),
            WIN32::ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING),
            WIN32::ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING),
            WIN32::ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED),
            WIN32::ERROR_DIF_VOLATILE_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_DIF_VOLATILE_NOT_ALLOWED),
            WIN32::ERROR_DIF_BINDING_API_NOT_FOUND => RawError::Kind(WIN32::ERROR_DIF_BINDING_API_NOT_FOUND),
            WIN32::ERROR_IO_REISSUE_AS_CACHED => RawError::Kind(WIN32::ERROR_IO_REISSUE_AS_CACHED),
            WIN32::ERROR_WINS_INTERNAL => RawError::Kind(WIN32::ERROR_WINS_INTERNAL),
            WIN32::ERROR_CAN_NOT_DEL_LOCAL_WINS => RawError::Kind(WIN32::ERROR_CAN_NOT_DEL_LOCAL_WINS),
            WIN32::ERROR_STATIC_INIT => RawError::Kind(WIN32::ERROR_STATIC_INIT),
            WIN32::ERROR_INC_BACKUP => RawError::Kind(WIN32::ERROR_INC_BACKUP),
            WIN32::ERROR_FULL_BACKUP => RawError::Kind(WIN32::ERROR_FULL_BACKUP),
            WIN32::ERROR_REC_NON_EXISTENT => RawError::Kind(WIN32::ERROR_REC_NON_EXISTENT),
            WIN32::ERROR_RPL_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_RPL_NOT_ALLOWED),
            WIN32::PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED => RawError::Kind(WIN32::PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED),
            WIN32::PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO => RawError::Kind(WIN32::PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO),
            WIN32::PEERDIST_ERROR_MISSING_DATA => RawError::Kind(WIN32::PEERDIST_ERROR_MISSING_DATA),
            WIN32::PEERDIST_ERROR_NO_MORE => RawError::Kind(WIN32::PEERDIST_ERROR_NO_MORE),
            WIN32::PEERDIST_ERROR_NOT_INITIALIZED => RawError::Kind(WIN32::PEERDIST_ERROR_NOT_INITIALIZED),
            WIN32::PEERDIST_ERROR_ALREADY_INITIALIZED => RawError::Kind(WIN32::PEERDIST_ERROR_ALREADY_INITIALIZED),
            WIN32::PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS => RawError::Kind(WIN32::PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS),
            WIN32::PEERDIST_ERROR_INVALIDATED => RawError::Kind(WIN32::PEERDIST_ERROR_INVALIDATED),
            WIN32::PEERDIST_ERROR_ALREADY_EXISTS => RawError::Kind(WIN32::PEERDIST_ERROR_ALREADY_EXISTS),
            WIN32::PEERDIST_ERROR_OPERATION_NOTFOUND => RawError::Kind(WIN32::PEERDIST_ERROR_OPERATION_NOTFOUND),
            WIN32::PEERDIST_ERROR_ALREADY_COMPLETED => RawError::Kind(WIN32::PEERDIST_ERROR_ALREADY_COMPLETED),
            WIN32::PEERDIST_ERROR_OUT_OF_BOUNDS => RawError::Kind(WIN32::PEERDIST_ERROR_OUT_OF_BOUNDS),
            WIN32::PEERDIST_ERROR_VERSION_UNSUPPORTED => RawError::Kind(WIN32::PEERDIST_ERROR_VERSION_UNSUPPORTED),
            WIN32::PEERDIST_ERROR_INVALID_CONFIGURATION => RawError::Kind(WIN32::PEERDIST_ERROR_INVALID_CONFIGURATION),
            WIN32::PEERDIST_ERROR_NOT_LICENSED => RawError::Kind(WIN32::PEERDIST_ERROR_NOT_LICENSED),
            WIN32::PEERDIST_ERROR_SERVICE_UNAVAILABLE => RawError::Kind(WIN32::PEERDIST_ERROR_SERVICE_UNAVAILABLE),
            WIN32::PEERDIST_ERROR_TRUST_FAILURE => RawError::Kind(WIN32::PEERDIST_ERROR_TRUST_FAILURE),
            WIN32::ERROR_DHCP_ADDRESS_CONFLICT => RawError::Kind(WIN32::ERROR_DHCP_ADDRESS_CONFLICT),
            WIN32::ERROR_WMI_GUID_NOT_FOUND => RawError::Kind(WIN32::ERROR_WMI_GUID_NOT_FOUND),
            WIN32::ERROR_WMI_INSTANCE_NOT_FOUND => RawError::Kind(WIN32::ERROR_WMI_INSTANCE_NOT_FOUND),
            WIN32::ERROR_WMI_ITEMID_NOT_FOUND => RawError::Kind(WIN32::ERROR_WMI_ITEMID_NOT_FOUND),
            WIN32::ERROR_WMI_TRY_AGAIN => RawError::Kind(WIN32::ERROR_WMI_TRY_AGAIN),
            WIN32::ERROR_WMI_DP_NOT_FOUND => RawError::Kind(WIN32::ERROR_WMI_DP_NOT_FOUND),
            WIN32::ERROR_WMI_UNRESOLVED_INSTANCE_REF => RawError::Kind(WIN32::ERROR_WMI_UNRESOLVED_INSTANCE_REF),
            WIN32::ERROR_WMI_ALREADY_ENABLED => RawError::Kind(WIN32::ERROR_WMI_ALREADY_ENABLED),
            WIN32::ERROR_WMI_GUID_DISCONNECTED => RawError::Kind(WIN32::ERROR_WMI_GUID_DISCONNECTED),
            WIN32::ERROR_WMI_SERVER_UNAVAILABLE => RawError::Kind(WIN32::ERROR_WMI_SERVER_UNAVAILABLE),
            WIN32::ERROR_WMI_DP_FAILED => RawError::Kind(WIN32::ERROR_WMI_DP_FAILED),
            WIN32::ERROR_WMI_INVALID_MOF => RawError::Kind(WIN32::ERROR_WMI_INVALID_MOF),
            WIN32::ERROR_WMI_INVALID_REGINFO => RawError::Kind(WIN32::ERROR_WMI_INVALID_REGINFO),
            WIN32::ERROR_WMI_ALREADY_DISABLED => RawError::Kind(WIN32::ERROR_WMI_ALREADY_DISABLED),
            WIN32::ERROR_WMI_READ_ONLY => RawError::Kind(WIN32::ERROR_WMI_READ_ONLY),
            WIN32::ERROR_WMI_SET_FAILURE => RawError::Kind(WIN32::ERROR_WMI_SET_FAILURE),
            WIN32::ERROR_NOT_APPCONTAINER => RawError::Kind(WIN32::ERROR_NOT_APPCONTAINER),
            WIN32::ERROR_APPCONTAINER_REQUIRED => RawError::Kind(WIN32::ERROR_APPCONTAINER_REQUIRED),
            WIN32::ERROR_NOT_SUPPORTED_IN_APPCONTAINER => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_IN_APPCONTAINER),
            WIN32::ERROR_INVALID_PACKAGE_SID_LENGTH => RawError::Kind(WIN32::ERROR_INVALID_PACKAGE_SID_LENGTH),
            WIN32::ERROR_INVALID_MEDIA => RawError::Kind(WIN32::ERROR_INVALID_MEDIA),
            WIN32::ERROR_INVALID_LIBRARY => RawError::Kind(WIN32::ERROR_INVALID_LIBRARY),
            WIN32::ERROR_INVALID_MEDIA_POOL => RawError::Kind(WIN32::ERROR_INVALID_MEDIA_POOL),
            WIN32::ERROR_DRIVE_MEDIA_MISMATCH => RawError::Kind(WIN32::ERROR_DRIVE_MEDIA_MISMATCH),
            WIN32::ERROR_MEDIA_OFFLINE => RawError::Kind(WIN32::ERROR_MEDIA_OFFLINE),
            WIN32::ERROR_LIBRARY_OFFLINE => RawError::Kind(WIN32::ERROR_LIBRARY_OFFLINE),
            WIN32::ERROR_EMPTY => RawError::Kind(WIN32::ERROR_EMPTY),
            WIN32::ERROR_NOT_EMPTY => RawError::Kind(WIN32::ERROR_NOT_EMPTY),
            WIN32::ERROR_MEDIA_UNAVAILABLE => RawError::Kind(WIN32::ERROR_MEDIA_UNAVAILABLE),
            WIN32::ERROR_RESOURCE_DISABLED => RawError::Kind(WIN32::ERROR_RESOURCE_DISABLED),
            WIN32::ERROR_INVALID_CLEANER => RawError::Kind(WIN32::ERROR_INVALID_CLEANER),
            WIN32::ERROR_UNABLE_TO_CLEAN => RawError::Kind(WIN32::ERROR_UNABLE_TO_CLEAN),
            WIN32::ERROR_OBJECT_NOT_FOUND => RawError::Kind(WIN32::ERROR_OBJECT_NOT_FOUND),
            WIN32::ERROR_DATABASE_FAILURE => RawError::Kind(WIN32::ERROR_DATABASE_FAILURE),
            WIN32::ERROR_DATABASE_FULL => RawError::Kind(WIN32::ERROR_DATABASE_FULL),
            WIN32::ERROR_MEDIA_INCOMPATIBLE => RawError::Kind(WIN32::ERROR_MEDIA_INCOMPATIBLE),
            WIN32::ERROR_RESOURCE_NOT_PRESENT => RawError::Kind(WIN32::ERROR_RESOURCE_NOT_PRESENT),
            WIN32::ERROR_INVALID_OPERATION => RawError::Kind(WIN32::ERROR_INVALID_OPERATION),
            WIN32::ERROR_MEDIA_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_MEDIA_NOT_AVAILABLE),
            WIN32::ERROR_DEVICE_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_DEVICE_NOT_AVAILABLE),
            WIN32::ERROR_REQUEST_REFUSED => RawError::Kind(WIN32::ERROR_REQUEST_REFUSED),
            WIN32::ERROR_INVALID_DRIVE_OBJECT => RawError::Kind(WIN32::ERROR_INVALID_DRIVE_OBJECT),
            WIN32::ERROR_LIBRARY_FULL => RawError::Kind(WIN32::ERROR_LIBRARY_FULL),
            WIN32::ERROR_MEDIUM_NOT_ACCESSIBLE => RawError::Kind(WIN32::ERROR_MEDIUM_NOT_ACCESSIBLE),
            WIN32::ERROR_UNABLE_TO_LOAD_MEDIUM => RawError::Kind(WIN32::ERROR_UNABLE_TO_LOAD_MEDIUM),
            WIN32::ERROR_UNABLE_TO_INVENTORY_DRIVE => RawError::Kind(WIN32::ERROR_UNABLE_TO_INVENTORY_DRIVE),
            WIN32::ERROR_UNABLE_TO_INVENTORY_SLOT => RawError::Kind(WIN32::ERROR_UNABLE_TO_INVENTORY_SLOT),
            WIN32::ERROR_UNABLE_TO_INVENTORY_TRANSPORT => RawError::Kind(WIN32::ERROR_UNABLE_TO_INVENTORY_TRANSPORT),
            WIN32::ERROR_TRANSPORT_FULL => RawError::Kind(WIN32::ERROR_TRANSPORT_FULL),
            WIN32::ERROR_CONTROLLING_IEPORT => RawError::Kind(WIN32::ERROR_CONTROLLING_IEPORT),
            WIN32::ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA => RawError::Kind(WIN32::ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA),
            WIN32::ERROR_CLEANER_SLOT_SET => RawError::Kind(WIN32::ERROR_CLEANER_SLOT_SET),
            WIN32::ERROR_CLEANER_SLOT_NOT_SET => RawError::Kind(WIN32::ERROR_CLEANER_SLOT_NOT_SET),
            WIN32::ERROR_CLEANER_CARTRIDGE_SPENT => RawError::Kind(WIN32::ERROR_CLEANER_CARTRIDGE_SPENT),
            WIN32::ERROR_UNEXPECTED_OMID => RawError::Kind(WIN32::ERROR_UNEXPECTED_OMID),
            WIN32::ERROR_CANT_DELETE_LAST_ITEM => RawError::Kind(WIN32::ERROR_CANT_DELETE_LAST_ITEM),
            WIN32::ERROR_MESSAGE_EXCEEDS_MAX_SIZE => RawError::Kind(WIN32::ERROR_MESSAGE_EXCEEDS_MAX_SIZE),
            WIN32::ERROR_VOLUME_CONTAINS_SYS_FILES => RawError::Kind(WIN32::ERROR_VOLUME_CONTAINS_SYS_FILES),
            WIN32::ERROR_INDIGENOUS_TYPE => RawError::Kind(WIN32::ERROR_INDIGENOUS_TYPE),
            WIN32::ERROR_NO_SUPPORTING_DRIVES => RawError::Kind(WIN32::ERROR_NO_SUPPORTING_DRIVES),
            WIN32::ERROR_CLEANER_CARTRIDGE_INSTALLED => RawError::Kind(WIN32::ERROR_CLEANER_CARTRIDGE_INSTALLED),
            WIN32::ERROR_IEPORT_FULL => RawError::Kind(WIN32::ERROR_IEPORT_FULL),
            WIN32::ERROR_FILE_OFFLINE => RawError::Kind(WIN32::ERROR_FILE_OFFLINE),
            WIN32::ERROR_REMOTE_STORAGE_NOT_ACTIVE => RawError::Kind(WIN32::ERROR_REMOTE_STORAGE_NOT_ACTIVE),
            WIN32::ERROR_REMOTE_STORAGE_MEDIA_ERROR => RawError::Kind(WIN32::ERROR_REMOTE_STORAGE_MEDIA_ERROR),
            WIN32::ERROR_NOT_A_REPARSE_POINT => RawError::Kind(WIN32::ERROR_NOT_A_REPARSE_POINT),
            WIN32::ERROR_REPARSE_ATTRIBUTE_CONFLICT => RawError::Kind(WIN32::ERROR_REPARSE_ATTRIBUTE_CONFLICT),
            WIN32::ERROR_INVALID_REPARSE_DATA => RawError::Kind(WIN32::ERROR_INVALID_REPARSE_DATA),
            WIN32::ERROR_REPARSE_TAG_INVALID => RawError::Kind(WIN32::ERROR_REPARSE_TAG_INVALID),
            WIN32::ERROR_REPARSE_TAG_MISMATCH => RawError::Kind(WIN32::ERROR_REPARSE_TAG_MISMATCH),
            WIN32::ERROR_REPARSE_POINT_ENCOUNTERED => RawError::Kind(WIN32::ERROR_REPARSE_POINT_ENCOUNTERED),
            WIN32::ERROR_APP_DATA_NOT_FOUND => RawError::Kind(WIN32::ERROR_APP_DATA_NOT_FOUND),
            WIN32::ERROR_APP_DATA_EXPIRED => RawError::Kind(WIN32::ERROR_APP_DATA_EXPIRED),
            WIN32::ERROR_APP_DATA_CORRUPT => RawError::Kind(WIN32::ERROR_APP_DATA_CORRUPT),
            WIN32::ERROR_APP_DATA_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_APP_DATA_LIMIT_EXCEEDED),
            WIN32::ERROR_APP_DATA_REBOOT_REQUIRED => RawError::Kind(WIN32::ERROR_APP_DATA_REBOOT_REQUIRED),
            WIN32::ERROR_SECUREBOOT_ROLLBACK_DETECTED => RawError::Kind(WIN32::ERROR_SECUREBOOT_ROLLBACK_DETECTED),
            WIN32::ERROR_SECUREBOOT_POLICY_VIOLATION => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_VIOLATION),
            WIN32::ERROR_SECUREBOOT_INVALID_POLICY => RawError::Kind(WIN32::ERROR_SECUREBOOT_INVALID_POLICY),
            WIN32::ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND),
            WIN32::ERROR_SECUREBOOT_POLICY_NOT_SIGNED => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_NOT_SIGNED),
            WIN32::ERROR_SECUREBOOT_NOT_ENABLED => RawError::Kind(WIN32::ERROR_SECUREBOOT_NOT_ENABLED),
            WIN32::ERROR_SECUREBOOT_FILE_REPLACED => RawError::Kind(WIN32::ERROR_SECUREBOOT_FILE_REPLACED),
            WIN32::ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED),
            WIN32::ERROR_SECUREBOOT_POLICY_UNKNOWN => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_UNKNOWN),
            WIN32::ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION),
            WIN32::ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH => RawError::Kind(WIN32::ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH),
            WIN32::ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED),
            WIN32::ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH => RawError::Kind(WIN32::ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH),
            WIN32::ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING => RawError::Kind(WIN32::ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING),
            WIN32::ERROR_SECUREBOOT_NOT_BASE_POLICY => RawError::Kind(WIN32::ERROR_SECUREBOOT_NOT_BASE_POLICY),
            WIN32::ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY => RawError::Kind(WIN32::ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY),
            WIN32::ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED),
            WIN32::ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED),
            WIN32::ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED),
            WIN32::ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED),
            WIN32::ERROR_ALREADY_HAS_STREAM_ID => RawError::Kind(WIN32::ERROR_ALREADY_HAS_STREAM_ID),
            WIN32::ERROR_SMR_GARBAGE_COLLECTION_REQUIRED => RawError::Kind(WIN32::ERROR_SMR_GARBAGE_COLLECTION_REQUIRED),
            WIN32::ERROR_WOF_WIM_HEADER_CORRUPT => RawError::Kind(WIN32::ERROR_WOF_WIM_HEADER_CORRUPT),
            WIN32::ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT => RawError::Kind(WIN32::ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT),
            WIN32::ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT => RawError::Kind(WIN32::ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT),
            WIN32::ERROR_OBJECT_IS_IMMUTABLE => RawError::Kind(WIN32::ERROR_OBJECT_IS_IMMUTABLE),
            WIN32::ERROR_VOLUME_NOT_SIS_ENABLED => RawError::Kind(WIN32::ERROR_VOLUME_NOT_SIS_ENABLED),
            WIN32::ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED),
            WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION),
            WIN32::ERROR_SYSTEM_INTEGRITY_INVALID_POLICY => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_INVALID_POLICY),
            WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED),
            WIN32::ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES),
            WIN32::ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE),
            WIN32::ERROR_VSM_NOT_INITIALIZED => RawError::Kind(WIN32::ERROR_VSM_NOT_INITIALIZED),
            WIN32::ERROR_VSM_DMA_PROTECTION_NOT_IN_USE => RawError::Kind(WIN32::ERROR_VSM_DMA_PROTECTION_NOT_IN_USE),
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED),
            WIN32::ERROR_PLATFORM_MANIFEST_INVALID => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_INVALID),
            WIN32::ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED),
            WIN32::ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED),
            WIN32::ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND),
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_ACTIVE => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_NOT_ACTIVE),
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_SIGNED => RawError::Kind(WIN32::ERROR_PLATFORM_MANIFEST_NOT_SIGNED),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE),
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE => RawError::Kind(WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE),
            WIN32::ERROR_DEPENDENT_RESOURCE_EXISTS => RawError::Kind(WIN32::ERROR_DEPENDENT_RESOURCE_EXISTS),
            WIN32::ERROR_DEPENDENCY_NOT_FOUND => RawError::Kind(WIN32::ERROR_DEPENDENCY_NOT_FOUND),
            WIN32::ERROR_DEPENDENCY_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_DEPENDENCY_ALREADY_EXISTS),
            WIN32::ERROR_RESOURCE_NOT_ONLINE => RawError::Kind(WIN32::ERROR_RESOURCE_NOT_ONLINE),
            WIN32::ERROR_HOST_NODE_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_HOST_NODE_NOT_AVAILABLE),
            WIN32::ERROR_RESOURCE_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_RESOURCE_NOT_AVAILABLE),
            WIN32::ERROR_RESOURCE_NOT_FOUND => RawError::Kind(WIN32::ERROR_RESOURCE_NOT_FOUND),
            WIN32::ERROR_SHUTDOWN_CLUSTER => RawError::Kind(WIN32::ERROR_SHUTDOWN_CLUSTER),
            WIN32::ERROR_CANT_EVICT_ACTIVE_NODE => RawError::Kind(WIN32::ERROR_CANT_EVICT_ACTIVE_NODE),
            WIN32::ERROR_OBJECT_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_OBJECT_ALREADY_EXISTS),
            WIN32::ERROR_OBJECT_IN_LIST => RawError::Kind(WIN32::ERROR_OBJECT_IN_LIST),
            WIN32::ERROR_GROUP_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_GROUP_NOT_AVAILABLE),
            WIN32::ERROR_GROUP_NOT_FOUND => RawError::Kind(WIN32::ERROR_GROUP_NOT_FOUND),
            WIN32::ERROR_GROUP_NOT_ONLINE => RawError::Kind(WIN32::ERROR_GROUP_NOT_ONLINE),
            WIN32::ERROR_HOST_NODE_NOT_RESOURCE_OWNER => RawError::Kind(WIN32::ERROR_HOST_NODE_NOT_RESOURCE_OWNER),
            WIN32::ERROR_HOST_NODE_NOT_GROUP_OWNER => RawError::Kind(WIN32::ERROR_HOST_NODE_NOT_GROUP_OWNER),
            WIN32::ERROR_RESMON_CREATE_FAILED => RawError::Kind(WIN32::ERROR_RESMON_CREATE_FAILED),
            WIN32::ERROR_RESMON_ONLINE_FAILED => RawError::Kind(WIN32::ERROR_RESMON_ONLINE_FAILED),
            WIN32::ERROR_RESOURCE_ONLINE => RawError::Kind(WIN32::ERROR_RESOURCE_ONLINE),
            WIN32::ERROR_QUORUM_RESOURCE => RawError::Kind(WIN32::ERROR_QUORUM_RESOURCE),
            WIN32::ERROR_NOT_QUORUM_CAPABLE => RawError::Kind(WIN32::ERROR_NOT_QUORUM_CAPABLE),
            WIN32::ERROR_CLUSTER_SHUTTING_DOWN => RawError::Kind(WIN32::ERROR_CLUSTER_SHUTTING_DOWN),
            WIN32::ERROR_INVALID_STATE => RawError::Kind(WIN32::ERROR_INVALID_STATE),
            WIN32::ERROR_RESOURCE_PROPERTIES_STORED => RawError::Kind(WIN32::ERROR_RESOURCE_PROPERTIES_STORED),
            WIN32::ERROR_NOT_QUORUM_CLASS => RawError::Kind(WIN32::ERROR_NOT_QUORUM_CLASS),
            WIN32::ERROR_CORE_RESOURCE => RawError::Kind(WIN32::ERROR_CORE_RESOURCE),
            WIN32::ERROR_QUORUM_RESOURCE_ONLINE_FAILED => RawError::Kind(WIN32::ERROR_QUORUM_RESOURCE_ONLINE_FAILED),
            WIN32::ERROR_QUORUMLOG_OPEN_FAILED => RawError::Kind(WIN32::ERROR_QUORUMLOG_OPEN_FAILED),
            WIN32::ERROR_CLUSTERLOG_CORRUPT => RawError::Kind(WIN32::ERROR_CLUSTERLOG_CORRUPT),
            WIN32::ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE => RawError::Kind(WIN32::ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE),
            WIN32::ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE => RawError::Kind(WIN32::ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE),
            WIN32::ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND),
            WIN32::ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE => RawError::Kind(WIN32::ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE),
            WIN32::ERROR_QUORUM_OWNER_ALIVE => RawError::Kind(WIN32::ERROR_QUORUM_OWNER_ALIVE),
            WIN32::ERROR_NETWORK_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_NETWORK_NOT_AVAILABLE),
            WIN32::ERROR_NODE_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_NODE_NOT_AVAILABLE),
            WIN32::ERROR_ALL_NODES_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_ALL_NODES_NOT_AVAILABLE),
            WIN32::ERROR_RESOURCE_FAILED => RawError::Kind(WIN32::ERROR_RESOURCE_FAILED),
            WIN32::ERROR_CLUSTER_INVALID_NODE => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_NODE),
            WIN32::ERROR_CLUSTER_NODE_EXISTS => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_EXISTS),
            WIN32::ERROR_CLUSTER_JOIN_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_JOIN_IN_PROGRESS),
            WIN32::ERROR_CLUSTER_NODE_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_NOT_FOUND),
            WIN32::ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND),
            WIN32::ERROR_CLUSTER_NETWORK_EXISTS => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_EXISTS),
            WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND),
            WIN32::ERROR_CLUSTER_NETINTERFACE_EXISTS => RawError::Kind(WIN32::ERROR_CLUSTER_NETINTERFACE_EXISTS),
            WIN32::ERROR_CLUSTER_NETINTERFACE_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_NETINTERFACE_NOT_FOUND),
            WIN32::ERROR_CLUSTER_INVALID_REQUEST => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_REQUEST),
            WIN32::ERROR_CLUSTER_INVALID_NETWORK_PROVIDER => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_NETWORK_PROVIDER),
            WIN32::ERROR_CLUSTER_NODE_DOWN => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_DOWN),
            WIN32::ERROR_CLUSTER_NODE_UNREACHABLE => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_UNREACHABLE),
            WIN32::ERROR_CLUSTER_NODE_NOT_MEMBER => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_NOT_MEMBER),
            WIN32::ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS),
            WIN32::ERROR_CLUSTER_INVALID_NETWORK => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_NETWORK),
            WIN32::ERROR_CLUSTER_NODE_UP => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_UP),
            WIN32::ERROR_CLUSTER_IPADDR_IN_USE => RawError::Kind(WIN32::ERROR_CLUSTER_IPADDR_IN_USE),
            WIN32::ERROR_CLUSTER_NODE_NOT_PAUSED => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_NOT_PAUSED),
            WIN32::ERROR_CLUSTER_NO_SECURITY_CONTEXT => RawError::Kind(WIN32::ERROR_CLUSTER_NO_SECURITY_CONTEXT),
            WIN32::ERROR_CLUSTER_NETWORK_NOT_INTERNAL => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_NOT_INTERNAL),
            WIN32::ERROR_CLUSTER_NODE_ALREADY_UP => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_ALREADY_UP),
            WIN32::ERROR_CLUSTER_NODE_ALREADY_DOWN => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_ALREADY_DOWN),
            WIN32::ERROR_CLUSTER_NETWORK_ALREADY_ONLINE => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_ALREADY_ONLINE),
            WIN32::ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE),
            WIN32::ERROR_CLUSTER_NODE_ALREADY_MEMBER => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_ALREADY_MEMBER),
            WIN32::ERROR_CLUSTER_LAST_INTERNAL_NETWORK => RawError::Kind(WIN32::ERROR_CLUSTER_LAST_INTERNAL_NETWORK),
            WIN32::ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS),
            WIN32::ERROR_INVALID_OPERATION_ON_QUORUM => RawError::Kind(WIN32::ERROR_INVALID_OPERATION_ON_QUORUM),
            WIN32::ERROR_DEPENDENCY_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_DEPENDENCY_NOT_ALLOWED),
            WIN32::ERROR_CLUSTER_NODE_PAUSED => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_PAUSED),
            WIN32::ERROR_NODE_CANT_HOST_RESOURCE => RawError::Kind(WIN32::ERROR_NODE_CANT_HOST_RESOURCE),
            WIN32::ERROR_CLUSTER_NODE_NOT_READY => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_NOT_READY),
            WIN32::ERROR_CLUSTER_NODE_SHUTTING_DOWN => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_SHUTTING_DOWN),
            WIN32::ERROR_CLUSTER_JOIN_ABORTED => RawError::Kind(WIN32::ERROR_CLUSTER_JOIN_ABORTED),
            WIN32::ERROR_CLUSTER_INCOMPATIBLE_VERSIONS => RawError::Kind(WIN32::ERROR_CLUSTER_INCOMPATIBLE_VERSIONS),
            WIN32::ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED => RawError::Kind(WIN32::ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED),
            WIN32::ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED => RawError::Kind(WIN32::ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED),
            WIN32::ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND),
            WIN32::ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED),
            WIN32::ERROR_CLUSTER_RESNAME_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_RESNAME_NOT_FOUND),
            WIN32::ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED => RawError::Kind(WIN32::ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED),
            WIN32::ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST => RawError::Kind(WIN32::ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST),
            WIN32::ERROR_CLUSTER_DATABASE_SEQMISMATCH => RawError::Kind(WIN32::ERROR_CLUSTER_DATABASE_SEQMISMATCH),
            WIN32::ERROR_RESMON_INVALID_STATE => RawError::Kind(WIN32::ERROR_RESMON_INVALID_STATE),
            WIN32::ERROR_CLUSTER_GUM_NOT_LOCKER => RawError::Kind(WIN32::ERROR_CLUSTER_GUM_NOT_LOCKER),
            WIN32::ERROR_QUORUM_DISK_NOT_FOUND => RawError::Kind(WIN32::ERROR_QUORUM_DISK_NOT_FOUND),
            WIN32::ERROR_DATABASE_BACKUP_CORRUPT => RawError::Kind(WIN32::ERROR_DATABASE_BACKUP_CORRUPT),
            WIN32::ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT),
            WIN32::ERROR_RESOURCE_PROPERTY_UNCHANGEABLE => RawError::Kind(WIN32::ERROR_RESOURCE_PROPERTY_UNCHANGEABLE),
            WIN32::ERROR_NO_ADMIN_ACCESS_POINT => RawError::Kind(WIN32::ERROR_NO_ADMIN_ACCESS_POINT),
            WIN32::ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE => RawError::Kind(WIN32::ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE),
            WIN32::ERROR_CLUSTER_QUORUMLOG_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_QUORUMLOG_NOT_FOUND),
            WIN32::ERROR_CLUSTER_MEMBERSHIP_HALT => RawError::Kind(WIN32::ERROR_CLUSTER_MEMBERSHIP_HALT),
            WIN32::ERROR_CLUSTER_INSTANCE_ID_MISMATCH => RawError::Kind(WIN32::ERROR_CLUSTER_INSTANCE_ID_MISMATCH),
            WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP => RawError::Kind(WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP),
            WIN32::ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH => RawError::Kind(WIN32::ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH),
            WIN32::ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP => RawError::Kind(WIN32::ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP),
            WIN32::ERROR_CLUSTER_PARAMETER_MISMATCH => RawError::Kind(WIN32::ERROR_CLUSTER_PARAMETER_MISMATCH),
            WIN32::ERROR_NODE_CANNOT_BE_CLUSTERED => RawError::Kind(WIN32::ERROR_NODE_CANNOT_BE_CLUSTERED),
            WIN32::ERROR_CLUSTER_WRONG_OS_VERSION => RawError::Kind(WIN32::ERROR_CLUSTER_WRONG_OS_VERSION),
            WIN32::ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME => RawError::Kind(WIN32::ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME),
            WIN32::ERROR_CLUSCFG_ALREADY_COMMITTED => RawError::Kind(WIN32::ERROR_CLUSCFG_ALREADY_COMMITTED),
            WIN32::ERROR_CLUSCFG_ROLLBACK_FAILED => RawError::Kind(WIN32::ERROR_CLUSCFG_ROLLBACK_FAILED),
            WIN32::ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT => RawError::Kind(WIN32::ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT),
            WIN32::ERROR_CLUSTER_OLD_VERSION => RawError::Kind(WIN32::ERROR_CLUSTER_OLD_VERSION),
            WIN32::ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME => RawError::Kind(WIN32::ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME),
            WIN32::ERROR_CLUSTER_NO_NET_ADAPTERS => RawError::Kind(WIN32::ERROR_CLUSTER_NO_NET_ADAPTERS),
            WIN32::ERROR_CLUSTER_POISONED => RawError::Kind(WIN32::ERROR_CLUSTER_POISONED),
            WIN32::ERROR_CLUSTER_GROUP_MOVING => RawError::Kind(WIN32::ERROR_CLUSTER_GROUP_MOVING),
            WIN32::ERROR_CLUSTER_RESOURCE_TYPE_BUSY => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_TYPE_BUSY),
            WIN32::ERROR_RESOURCE_CALL_TIMED_OUT => RawError::Kind(WIN32::ERROR_RESOURCE_CALL_TIMED_OUT),
            WIN32::ERROR_INVALID_CLUSTER_IPV6_ADDRESS => RawError::Kind(WIN32::ERROR_INVALID_CLUSTER_IPV6_ADDRESS),
            WIN32::ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION => RawError::Kind(WIN32::ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION),
            WIN32::ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS => RawError::Kind(WIN32::ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS),
            WIN32::ERROR_CLUSTER_PARTIAL_SEND => RawError::Kind(WIN32::ERROR_CLUSTER_PARTIAL_SEND),
            WIN32::ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION => RawError::Kind(WIN32::ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION),
            WIN32::ERROR_CLUSTER_INVALID_STRING_TERMINATION => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_STRING_TERMINATION),
            WIN32::ERROR_CLUSTER_INVALID_STRING_FORMAT => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_STRING_FORMAT),
            WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS),
            WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS),
            WIN32::ERROR_CLUSTER_NULL_DATA => RawError::Kind(WIN32::ERROR_CLUSTER_NULL_DATA),
            WIN32::ERROR_CLUSTER_PARTIAL_READ => RawError::Kind(WIN32::ERROR_CLUSTER_PARTIAL_READ),
            WIN32::ERROR_CLUSTER_PARTIAL_WRITE => RawError::Kind(WIN32::ERROR_CLUSTER_PARTIAL_WRITE),
            WIN32::ERROR_CLUSTER_CANT_DESERIALIZE_DATA => RawError::Kind(WIN32::ERROR_CLUSTER_CANT_DESERIALIZE_DATA),
            WIN32::ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT => RawError::Kind(WIN32::ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT),
            WIN32::ERROR_CLUSTER_NO_QUORUM => RawError::Kind(WIN32::ERROR_CLUSTER_NO_QUORUM),
            WIN32::ERROR_CLUSTER_INVALID_IPV6_NETWORK => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_IPV6_NETWORK),
            WIN32::ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK),
            WIN32::ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP => RawError::Kind(WIN32::ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP),
            WIN32::ERROR_DEPENDENCY_TREE_TOO_COMPLEX => RawError::Kind(WIN32::ERROR_DEPENDENCY_TREE_TOO_COMPLEX),
            WIN32::ERROR_EXCEPTION_IN_RESOURCE_CALL => RawError::Kind(WIN32::ERROR_EXCEPTION_IN_RESOURCE_CALL),
            WIN32::ERROR_CLUSTER_RHS_FAILED_INITIALIZATION => RawError::Kind(WIN32::ERROR_CLUSTER_RHS_FAILED_INITIALIZATION),
            WIN32::ERROR_CLUSTER_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_CLUSTER_NOT_INSTALLED),
            WIN32::ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE),
            WIN32::ERROR_CLUSTER_MAX_NODES_IN_CLUSTER => RawError::Kind(WIN32::ERROR_CLUSTER_MAX_NODES_IN_CLUSTER),
            WIN32::ERROR_CLUSTER_TOO_MANY_NODES => RawError::Kind(WIN32::ERROR_CLUSTER_TOO_MANY_NODES),
            WIN32::ERROR_CLUSTER_OBJECT_ALREADY_USED => RawError::Kind(WIN32::ERROR_CLUSTER_OBJECT_ALREADY_USED),
            WIN32::ERROR_NONCORE_GROUPS_FOUND => RawError::Kind(WIN32::ERROR_NONCORE_GROUPS_FOUND),
            WIN32::ERROR_FILE_SHARE_RESOURCE_CONFLICT => RawError::Kind(WIN32::ERROR_FILE_SHARE_RESOURCE_CONFLICT),
            WIN32::ERROR_CLUSTER_EVICT_INVALID_REQUEST => RawError::Kind(WIN32::ERROR_CLUSTER_EVICT_INVALID_REQUEST),
            WIN32::ERROR_CLUSTER_SINGLETON_RESOURCE => RawError::Kind(WIN32::ERROR_CLUSTER_SINGLETON_RESOURCE),
            WIN32::ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE => RawError::Kind(WIN32::ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE),
            WIN32::ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED),
            WIN32::ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR),
            WIN32::ERROR_CLUSTER_GROUP_BUSY => RawError::Kind(WIN32::ERROR_CLUSTER_GROUP_BUSY),
            WIN32::ERROR_CLUSTER_NOT_SHARED_VOLUME => RawError::Kind(WIN32::ERROR_CLUSTER_NOT_SHARED_VOLUME),
            WIN32::ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR),
            WIN32::ERROR_CLUSTER_SHARED_VOLUMES_IN_USE => RawError::Kind(WIN32::ERROR_CLUSTER_SHARED_VOLUMES_IN_USE),
            WIN32::ERROR_CLUSTER_USE_SHARED_VOLUMES_API => RawError::Kind(WIN32::ERROR_CLUSTER_USE_SHARED_VOLUMES_API),
            WIN32::ERROR_CLUSTER_BACKUP_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_BACKUP_IN_PROGRESS),
            WIN32::ERROR_NON_CSV_PATH => RawError::Kind(WIN32::ERROR_NON_CSV_PATH),
            WIN32::ERROR_CSV_VOLUME_NOT_LOCAL => RawError::Kind(WIN32::ERROR_CSV_VOLUME_NOT_LOCAL),
            WIN32::ERROR_CLUSTER_WATCHDOG_TERMINATING => RawError::Kind(WIN32::ERROR_CLUSTER_WATCHDOG_TERMINATING),
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES),
            WIN32::ERROR_CLUSTER_INVALID_NODE_WEIGHT => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_NODE_WEIGHT),
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_CALL => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_VETOED_CALL),
            WIN32::ERROR_RESMON_SYSTEM_RESOURCES_LACKING => RawError::Kind(WIN32::ERROR_RESMON_SYSTEM_RESOURCES_LACKING),
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION),
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE),
            WIN32::ERROR_CLUSTER_GROUP_QUEUED => RawError::Kind(WIN32::ERROR_CLUSTER_GROUP_QUEUED),
            WIN32::ERROR_CLUSTER_RESOURCE_LOCKED_STATUS => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_LOCKED_STATUS),
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED),
            WIN32::ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS),
            WIN32::ERROR_CLUSTER_DISK_NOT_CONNECTED => RawError::Kind(WIN32::ERROR_CLUSTER_DISK_NOT_CONNECTED),
            WIN32::ERROR_DISK_NOT_CSV_CAPABLE => RawError::Kind(WIN32::ERROR_DISK_NOT_CSV_CAPABLE),
            WIN32::ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE => RawError::Kind(WIN32::ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE),
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED => RawError::Kind(WIN32::ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED),
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED => RawError::Kind(WIN32::ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED),
            WIN32::ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES => RawError::Kind(WIN32::ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES),
            WIN32::ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES),
            WIN32::ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE),
            WIN32::ERROR_CLUSTER_AFFINITY_CONFLICT => RawError::Kind(WIN32::ERROR_CLUSTER_AFFINITY_CONFLICT),
            WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE),
            WIN32::ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS => RawError::Kind(WIN32::ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS),
            WIN32::ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED),
            WIN32::ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED => RawError::Kind(WIN32::ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED),
            WIN32::ERROR_CLUSTER_UPGRADE_IN_PROGRESS => RawError::Kind(WIN32::ERROR_CLUSTER_UPGRADE_IN_PROGRESS),
            WIN32::ERROR_CLUSTER_UPGRADE_INCOMPLETE => RawError::Kind(WIN32::ERROR_CLUSTER_UPGRADE_INCOMPLETE),
            WIN32::ERROR_CLUSTER_NODE_IN_GRACE_PERIOD => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_IN_GRACE_PERIOD),
            WIN32::ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT => RawError::Kind(WIN32::ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT),
            WIN32::ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER => RawError::Kind(WIN32::ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER),
            WIN32::ERROR_CLUSTER_RESOURCE_NOT_MONITORED => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_NOT_MONITORED),
            WIN32::ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED),
            WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICATED => RawError::Kind(WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICATED),
            WIN32::ERROR_CLUSTER_NODE_ISOLATED => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_ISOLATED),
            WIN32::ERROR_CLUSTER_NODE_QUARANTINED => RawError::Kind(WIN32::ERROR_CLUSTER_NODE_QUARANTINED),
            WIN32::ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED => RawError::Kind(WIN32::ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED),
            WIN32::ERROR_CLUSTER_SPACE_DEGRADED => RawError::Kind(WIN32::ERROR_CLUSTER_SPACE_DEGRADED),
            WIN32::ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED),
            WIN32::ERROR_CLUSTER_CSV_INVALID_HANDLE => RawError::Kind(WIN32::ERROR_CLUSTER_CSV_INVALID_HANDLE),
            WIN32::ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR => RawError::Kind(WIN32::ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR),
            WIN32::ERROR_GROUPSET_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_GROUPSET_NOT_AVAILABLE),
            WIN32::ERROR_GROUPSET_NOT_FOUND => RawError::Kind(WIN32::ERROR_GROUPSET_NOT_FOUND),
            WIN32::ERROR_GROUPSET_CANT_PROVIDE => RawError::Kind(WIN32::ERROR_GROUPSET_CANT_PROVIDE),
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND => RawError::Kind(WIN32::ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND),
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY => RawError::Kind(WIN32::ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY),
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION => RawError::Kind(WIN32::ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION),
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS => RawError::Kind(WIN32::ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS),
            WIN32::ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME => RawError::Kind(WIN32::ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME),
            WIN32::ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE => RawError::Kind(WIN32::ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE),
            WIN32::ERROR_ENCRYPTION_FAILED => RawError::Kind(WIN32::ERROR_ENCRYPTION_FAILED),
            WIN32::ERROR_DECRYPTION_FAILED => RawError::Kind(WIN32::ERROR_DECRYPTION_FAILED),
            WIN32::ERROR_FILE_ENCRYPTED => RawError::Kind(WIN32::ERROR_FILE_ENCRYPTED),
            WIN32::ERROR_NO_RECOVERY_POLICY => RawError::Kind(WIN32::ERROR_NO_RECOVERY_POLICY),
            WIN32::ERROR_NO_EFS => RawError::Kind(WIN32::ERROR_NO_EFS),
            WIN32::ERROR_WRONG_EFS => RawError::Kind(WIN32::ERROR_WRONG_EFS),
            WIN32::ERROR_NO_USER_KEYS => RawError::Kind(WIN32::ERROR_NO_USER_KEYS),
            WIN32::ERROR_FILE_NOT_ENCRYPTED => RawError::Kind(WIN32::ERROR_FILE_NOT_ENCRYPTED),
            WIN32::ERROR_NOT_EXPORT_FORMAT => RawError::Kind(WIN32::ERROR_NOT_EXPORT_FORMAT),
            WIN32::ERROR_FILE_READ_ONLY => RawError::Kind(WIN32::ERROR_FILE_READ_ONLY),
            WIN32::ERROR_DIR_EFS_DISALLOWED => RawError::Kind(WIN32::ERROR_DIR_EFS_DISALLOWED),
            WIN32::ERROR_EFS_SERVER_NOT_TRUSTED => RawError::Kind(WIN32::ERROR_EFS_SERVER_NOT_TRUSTED),
            WIN32::ERROR_BAD_RECOVERY_POLICY => RawError::Kind(WIN32::ERROR_BAD_RECOVERY_POLICY),
            WIN32::ERROR_EFS_ALG_BLOB_TOO_BIG => RawError::Kind(WIN32::ERROR_EFS_ALG_BLOB_TOO_BIG),
            WIN32::ERROR_VOLUME_NOT_SUPPORT_EFS => RawError::Kind(WIN32::ERROR_VOLUME_NOT_SUPPORT_EFS),
            WIN32::ERROR_EFS_DISABLED => RawError::Kind(WIN32::ERROR_EFS_DISABLED),
            WIN32::ERROR_EFS_VERSION_NOT_SUPPORT => RawError::Kind(WIN32::ERROR_EFS_VERSION_NOT_SUPPORT),
            WIN32::ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE => RawError::Kind(WIN32::ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE),
            WIN32::ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER => RawError::Kind(WIN32::ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER),
            WIN32::ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE => RawError::Kind(WIN32::ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE),
            WIN32::ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE => RawError::Kind(WIN32::ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE),
            WIN32::ERROR_CS_ENCRYPTION_FILE_NOT_CSE => RawError::Kind(WIN32::ERROR_CS_ENCRYPTION_FILE_NOT_CSE),
            WIN32::ERROR_ENCRYPTION_POLICY_DENIES_OPERATION => RawError::Kind(WIN32::ERROR_ENCRYPTION_POLICY_DENIES_OPERATION),
            WIN32::ERROR_WIP_ENCRYPTION_FAILED => RawError::Kind(WIN32::ERROR_WIP_ENCRYPTION_FAILED),
            WIN32::ERROR_NO_BROWSER_SERVERS_FOUND => RawError::Kind(WIN32::ERROR_NO_BROWSER_SERVERS_FOUND),
            WIN32::SCHED_E_SERVICE_NOT_LOCALSYSTEM => RawError::Kind(WIN32::SCHED_E_SERVICE_NOT_LOCALSYSTEM),
            WIN32::ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM => RawError::Kind(WIN32::ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM),
            WIN32::ERROR_LOG_SECTOR_INVALID => RawError::Kind(WIN32::ERROR_LOG_SECTOR_INVALID),
            WIN32::ERROR_LOG_SECTOR_PARITY_INVALID => RawError::Kind(WIN32::ERROR_LOG_SECTOR_PARITY_INVALID),
            WIN32::ERROR_LOG_SECTOR_REMAPPED => RawError::Kind(WIN32::ERROR_LOG_SECTOR_REMAPPED),
            WIN32::ERROR_LOG_BLOCK_INCOMPLETE => RawError::Kind(WIN32::ERROR_LOG_BLOCK_INCOMPLETE),
            WIN32::ERROR_LOG_INVALID_RANGE => RawError::Kind(WIN32::ERROR_LOG_INVALID_RANGE),
            WIN32::ERROR_LOG_BLOCKS_EXHAUSTED => RawError::Kind(WIN32::ERROR_LOG_BLOCKS_EXHAUSTED),
            WIN32::ERROR_LOG_READ_CONTEXT_INVALID => RawError::Kind(WIN32::ERROR_LOG_READ_CONTEXT_INVALID),
            WIN32::ERROR_LOG_RESTART_INVALID => RawError::Kind(WIN32::ERROR_LOG_RESTART_INVALID),
            WIN32::ERROR_LOG_BLOCK_VERSION => RawError::Kind(WIN32::ERROR_LOG_BLOCK_VERSION),
            WIN32::ERROR_LOG_BLOCK_INVALID => RawError::Kind(WIN32::ERROR_LOG_BLOCK_INVALID),
            WIN32::ERROR_LOG_READ_MODE_INVALID => RawError::Kind(WIN32::ERROR_LOG_READ_MODE_INVALID),
            WIN32::ERROR_LOG_NO_RESTART => RawError::Kind(WIN32::ERROR_LOG_NO_RESTART),
            WIN32::ERROR_LOG_METADATA_CORRUPT => RawError::Kind(WIN32::ERROR_LOG_METADATA_CORRUPT),
            WIN32::ERROR_LOG_METADATA_INVALID => RawError::Kind(WIN32::ERROR_LOG_METADATA_INVALID),
            WIN32::ERROR_LOG_METADATA_INCONSISTENT => RawError::Kind(WIN32::ERROR_LOG_METADATA_INCONSISTENT),
            WIN32::ERROR_LOG_RESERVATION_INVALID => RawError::Kind(WIN32::ERROR_LOG_RESERVATION_INVALID),
            WIN32::ERROR_LOG_CANT_DELETE => RawError::Kind(WIN32::ERROR_LOG_CANT_DELETE),
            WIN32::ERROR_LOG_CONTAINER_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_LOG_CONTAINER_LIMIT_EXCEEDED),
            WIN32::ERROR_LOG_START_OF_LOG => RawError::Kind(WIN32::ERROR_LOG_START_OF_LOG),
            WIN32::ERROR_LOG_POLICY_ALREADY_INSTALLED => RawError::Kind(WIN32::ERROR_LOG_POLICY_ALREADY_INSTALLED),
            WIN32::ERROR_LOG_POLICY_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_LOG_POLICY_NOT_INSTALLED),
            WIN32::ERROR_LOG_POLICY_INVALID => RawError::Kind(WIN32::ERROR_LOG_POLICY_INVALID),
            WIN32::ERROR_LOG_POLICY_CONFLICT => RawError::Kind(WIN32::ERROR_LOG_POLICY_CONFLICT),
            WIN32::ERROR_LOG_PINNED_ARCHIVE_TAIL => RawError::Kind(WIN32::ERROR_LOG_PINNED_ARCHIVE_TAIL),
            WIN32::ERROR_LOG_RECORD_NONEXISTENT => RawError::Kind(WIN32::ERROR_LOG_RECORD_NONEXISTENT),
            WIN32::ERROR_LOG_RECORDS_RESERVED_INVALID => RawError::Kind(WIN32::ERROR_LOG_RECORDS_RESERVED_INVALID),
            WIN32::ERROR_LOG_SPACE_RESERVED_INVALID => RawError::Kind(WIN32::ERROR_LOG_SPACE_RESERVED_INVALID),
            WIN32::ERROR_LOG_TAIL_INVALID => RawError::Kind(WIN32::ERROR_LOG_TAIL_INVALID),
            WIN32::ERROR_LOG_FULL => RawError::Kind(WIN32::ERROR_LOG_FULL),
            WIN32::ERROR_COULD_NOT_RESIZE_LOG => RawError::Kind(WIN32::ERROR_COULD_NOT_RESIZE_LOG),
            WIN32::ERROR_LOG_MULTIPLEXED => RawError::Kind(WIN32::ERROR_LOG_MULTIPLEXED),
            WIN32::ERROR_LOG_DEDICATED => RawError::Kind(WIN32::ERROR_LOG_DEDICATED),
            WIN32::ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS => RawError::Kind(WIN32::ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS),
            WIN32::ERROR_LOG_ARCHIVE_IN_PROGRESS => RawError::Kind(WIN32::ERROR_LOG_ARCHIVE_IN_PROGRESS),
            WIN32::ERROR_LOG_EPHEMERAL => RawError::Kind(WIN32::ERROR_LOG_EPHEMERAL),
            WIN32::ERROR_LOG_NOT_ENOUGH_CONTAINERS => RawError::Kind(WIN32::ERROR_LOG_NOT_ENOUGH_CONTAINERS),
            WIN32::ERROR_LOG_CLIENT_ALREADY_REGISTERED => RawError::Kind(WIN32::ERROR_LOG_CLIENT_ALREADY_REGISTERED),
            WIN32::ERROR_LOG_CLIENT_NOT_REGISTERED => RawError::Kind(WIN32::ERROR_LOG_CLIENT_NOT_REGISTERED),
            WIN32::ERROR_LOG_FULL_HANDLER_IN_PROGRESS => RawError::Kind(WIN32::ERROR_LOG_FULL_HANDLER_IN_PROGRESS),
            WIN32::ERROR_LOG_CONTAINER_READ_FAILED => RawError::Kind(WIN32::ERROR_LOG_CONTAINER_READ_FAILED),
            WIN32::ERROR_LOG_CONTAINER_WRITE_FAILED => RawError::Kind(WIN32::ERROR_LOG_CONTAINER_WRITE_FAILED),
            WIN32::ERROR_LOG_CONTAINER_OPEN_FAILED => RawError::Kind(WIN32::ERROR_LOG_CONTAINER_OPEN_FAILED),
            WIN32::ERROR_LOG_CONTAINER_STATE_INVALID => RawError::Kind(WIN32::ERROR_LOG_CONTAINER_STATE_INVALID),
            WIN32::ERROR_LOG_STATE_INVALID => RawError::Kind(WIN32::ERROR_LOG_STATE_INVALID),
            WIN32::ERROR_LOG_PINNED => RawError::Kind(WIN32::ERROR_LOG_PINNED),
            WIN32::ERROR_LOG_METADATA_FLUSH_FAILED => RawError::Kind(WIN32::ERROR_LOG_METADATA_FLUSH_FAILED),
            WIN32::ERROR_LOG_INCONSISTENT_SECURITY => RawError::Kind(WIN32::ERROR_LOG_INCONSISTENT_SECURITY),
            WIN32::ERROR_LOG_APPENDED_FLUSH_FAILED => RawError::Kind(WIN32::ERROR_LOG_APPENDED_FLUSH_FAILED),
            WIN32::ERROR_LOG_PINNED_RESERVATION => RawError::Kind(WIN32::ERROR_LOG_PINNED_RESERVATION),
            WIN32::ERROR_INVALID_TRANSACTION => RawError::Kind(WIN32::ERROR_INVALID_TRANSACTION),
            WIN32::ERROR_TRANSACTION_NOT_ACTIVE => RawError::Kind(WIN32::ERROR_TRANSACTION_NOT_ACTIVE),
            WIN32::ERROR_TRANSACTION_REQUEST_NOT_VALID => RawError::Kind(WIN32::ERROR_TRANSACTION_REQUEST_NOT_VALID),
            WIN32::ERROR_TRANSACTION_NOT_REQUESTED => RawError::Kind(WIN32::ERROR_TRANSACTION_NOT_REQUESTED),
            WIN32::ERROR_TRANSACTION_ALREADY_ABORTED => RawError::Kind(WIN32::ERROR_TRANSACTION_ALREADY_ABORTED),
            WIN32::ERROR_TRANSACTION_ALREADY_COMMITTED => RawError::Kind(WIN32::ERROR_TRANSACTION_ALREADY_COMMITTED),
            WIN32::ERROR_TM_INITIALIZATION_FAILED => RawError::Kind(WIN32::ERROR_TM_INITIALIZATION_FAILED),
            WIN32::ERROR_RESOURCEMANAGER_READ_ONLY => RawError::Kind(WIN32::ERROR_RESOURCEMANAGER_READ_ONLY),
            WIN32::ERROR_TRANSACTION_NOT_JOINED => RawError::Kind(WIN32::ERROR_TRANSACTION_NOT_JOINED),
            WIN32::ERROR_TRANSACTION_SUPERIOR_EXISTS => RawError::Kind(WIN32::ERROR_TRANSACTION_SUPERIOR_EXISTS),
            WIN32::ERROR_CRM_PROTOCOL_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_CRM_PROTOCOL_ALREADY_EXISTS),
            WIN32::ERROR_TRANSACTION_PROPAGATION_FAILED => RawError::Kind(WIN32::ERROR_TRANSACTION_PROPAGATION_FAILED),
            WIN32::ERROR_CRM_PROTOCOL_NOT_FOUND => RawError::Kind(WIN32::ERROR_CRM_PROTOCOL_NOT_FOUND),
            WIN32::ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER => RawError::Kind(WIN32::ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER),
            WIN32::ERROR_CURRENT_TRANSACTION_NOT_VALID => RawError::Kind(WIN32::ERROR_CURRENT_TRANSACTION_NOT_VALID),
            WIN32::ERROR_TRANSACTION_NOT_FOUND => RawError::Kind(WIN32::ERROR_TRANSACTION_NOT_FOUND),
            WIN32::ERROR_RESOURCEMANAGER_NOT_FOUND => RawError::Kind(WIN32::ERROR_RESOURCEMANAGER_NOT_FOUND),
            WIN32::ERROR_ENLISTMENT_NOT_FOUND => RawError::Kind(WIN32::ERROR_ENLISTMENT_NOT_FOUND),
            WIN32::ERROR_TRANSACTIONMANAGER_NOT_FOUND => RawError::Kind(WIN32::ERROR_TRANSACTIONMANAGER_NOT_FOUND),
            WIN32::ERROR_TRANSACTIONMANAGER_NOT_ONLINE => RawError::Kind(WIN32::ERROR_TRANSACTIONMANAGER_NOT_ONLINE),
            WIN32::ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION => RawError::Kind(WIN32::ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION),
            WIN32::ERROR_TRANSACTION_NOT_ROOT => RawError::Kind(WIN32::ERROR_TRANSACTION_NOT_ROOT),
            WIN32::ERROR_TRANSACTION_OBJECT_EXPIRED => RawError::Kind(WIN32::ERROR_TRANSACTION_OBJECT_EXPIRED),
            WIN32::ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED => RawError::Kind(WIN32::ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED),
            WIN32::ERROR_TRANSACTION_RECORD_TOO_LONG => RawError::Kind(WIN32::ERROR_TRANSACTION_RECORD_TOO_LONG),
            WIN32::ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED),
            WIN32::ERROR_TRANSACTION_INTEGRITY_VIOLATED => RawError::Kind(WIN32::ERROR_TRANSACTION_INTEGRITY_VIOLATED),
            WIN32::ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH => RawError::Kind(WIN32::ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH),
            WIN32::ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT => RawError::Kind(WIN32::ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT),
            WIN32::ERROR_TRANSACTION_MUST_WRITETHROUGH => RawError::Kind(WIN32::ERROR_TRANSACTION_MUST_WRITETHROUGH),
            WIN32::ERROR_TRANSACTION_NO_SUPERIOR => RawError::Kind(WIN32::ERROR_TRANSACTION_NO_SUPERIOR),
            WIN32::ERROR_HEURISTIC_DAMAGE_POSSIBLE => RawError::Kind(WIN32::ERROR_HEURISTIC_DAMAGE_POSSIBLE),
            WIN32::ERROR_TRANSACTIONAL_CONFLICT => RawError::Kind(WIN32::ERROR_TRANSACTIONAL_CONFLICT),
            WIN32::ERROR_RM_NOT_ACTIVE => RawError::Kind(WIN32::ERROR_RM_NOT_ACTIVE),
            WIN32::ERROR_RM_METADATA_CORRUPT => RawError::Kind(WIN32::ERROR_RM_METADATA_CORRUPT),
            WIN32::ERROR_DIRECTORY_NOT_RM => RawError::Kind(WIN32::ERROR_DIRECTORY_NOT_RM),
            WIN32::ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE => RawError::Kind(WIN32::ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE),
            WIN32::ERROR_LOG_RESIZE_INVALID_SIZE => RawError::Kind(WIN32::ERROR_LOG_RESIZE_INVALID_SIZE),
            WIN32::ERROR_OBJECT_NO_LONGER_EXISTS => RawError::Kind(WIN32::ERROR_OBJECT_NO_LONGER_EXISTS),
            WIN32::ERROR_STREAM_MINIVERSION_NOT_FOUND => RawError::Kind(WIN32::ERROR_STREAM_MINIVERSION_NOT_FOUND),
            WIN32::ERROR_STREAM_MINIVERSION_NOT_VALID => RawError::Kind(WIN32::ERROR_STREAM_MINIVERSION_NOT_VALID),
            WIN32::ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION => RawError::Kind(WIN32::ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION),
            WIN32::ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT => RawError::Kind(WIN32::ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT),
            WIN32::ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS => RawError::Kind(WIN32::ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS),
            WIN32::ERROR_REMOTE_FILE_VERSION_MISMATCH => RawError::Kind(WIN32::ERROR_REMOTE_FILE_VERSION_MISMATCH),
            WIN32::ERROR_HANDLE_NO_LONGER_VALID => RawError::Kind(WIN32::ERROR_HANDLE_NO_LONGER_VALID),
            WIN32::ERROR_NO_TXF_METADATA => RawError::Kind(WIN32::ERROR_NO_TXF_METADATA),
            WIN32::ERROR_LOG_CORRUPTION_DETECTED => RawError::Kind(WIN32::ERROR_LOG_CORRUPTION_DETECTED),
            WIN32::ERROR_CANT_RECOVER_WITH_HANDLE_OPEN => RawError::Kind(WIN32::ERROR_CANT_RECOVER_WITH_HANDLE_OPEN),
            WIN32::ERROR_RM_DISCONNECTED => RawError::Kind(WIN32::ERROR_RM_DISCONNECTED),
            WIN32::ERROR_ENLISTMENT_NOT_SUPERIOR => RawError::Kind(WIN32::ERROR_ENLISTMENT_NOT_SUPERIOR),
            WIN32::ERROR_RECOVERY_NOT_NEEDED => RawError::Kind(WIN32::ERROR_RECOVERY_NOT_NEEDED),
            WIN32::ERROR_RM_ALREADY_STARTED => RawError::Kind(WIN32::ERROR_RM_ALREADY_STARTED),
            WIN32::ERROR_FILE_IDENTITY_NOT_PERSISTENT => RawError::Kind(WIN32::ERROR_FILE_IDENTITY_NOT_PERSISTENT),
            WIN32::ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY => RawError::Kind(WIN32::ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY),
            WIN32::ERROR_CANT_CROSS_RM_BOUNDARY => RawError::Kind(WIN32::ERROR_CANT_CROSS_RM_BOUNDARY),
            WIN32::ERROR_TXF_DIR_NOT_EMPTY => RawError::Kind(WIN32::ERROR_TXF_DIR_NOT_EMPTY),
            WIN32::ERROR_INDOUBT_TRANSACTIONS_EXIST => RawError::Kind(WIN32::ERROR_INDOUBT_TRANSACTIONS_EXIST),
            WIN32::ERROR_TM_VOLATILE => RawError::Kind(WIN32::ERROR_TM_VOLATILE),
            WIN32::ERROR_ROLLBACK_TIMER_EXPIRED => RawError::Kind(WIN32::ERROR_ROLLBACK_TIMER_EXPIRED),
            WIN32::ERROR_TXF_ATTRIBUTE_CORRUPT => RawError::Kind(WIN32::ERROR_TXF_ATTRIBUTE_CORRUPT),
            WIN32::ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION => RawError::Kind(WIN32::ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION),
            WIN32::ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED),
            WIN32::ERROR_LOG_GROWTH_FAILED => RawError::Kind(WIN32::ERROR_LOG_GROWTH_FAILED),
            WIN32::ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE => RawError::Kind(WIN32::ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE),
            WIN32::ERROR_TXF_METADATA_ALREADY_PRESENT => RawError::Kind(WIN32::ERROR_TXF_METADATA_ALREADY_PRESENT),
            WIN32::ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET => RawError::Kind(WIN32::ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET),
            WIN32::ERROR_TRANSACTION_REQUIRED_PROMOTION => RawError::Kind(WIN32::ERROR_TRANSACTION_REQUIRED_PROMOTION),
            WIN32::ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION => RawError::Kind(WIN32::ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION),
            WIN32::ERROR_TRANSACTIONS_NOT_FROZEN => RawError::Kind(WIN32::ERROR_TRANSACTIONS_NOT_FROZEN),
            WIN32::ERROR_TRANSACTION_FREEZE_IN_PROGRESS => RawError::Kind(WIN32::ERROR_TRANSACTION_FREEZE_IN_PROGRESS),
            WIN32::ERROR_NOT_SNAPSHOT_VOLUME => RawError::Kind(WIN32::ERROR_NOT_SNAPSHOT_VOLUME),
            WIN32::ERROR_NO_SAVEPOINT_WITH_OPEN_FILES => RawError::Kind(WIN32::ERROR_NO_SAVEPOINT_WITH_OPEN_FILES),
            WIN32::ERROR_DATA_LOST_REPAIR => RawError::Kind(WIN32::ERROR_DATA_LOST_REPAIR),
            WIN32::ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION => RawError::Kind(WIN32::ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION),
            WIN32::ERROR_TM_IDENTITY_MISMATCH => RawError::Kind(WIN32::ERROR_TM_IDENTITY_MISMATCH),
            WIN32::ERROR_FLOATED_SECTION => RawError::Kind(WIN32::ERROR_FLOATED_SECTION),
            WIN32::ERROR_CANNOT_ACCEPT_TRANSACTED_WORK => RawError::Kind(WIN32::ERROR_CANNOT_ACCEPT_TRANSACTED_WORK),
            WIN32::ERROR_CANNOT_ABORT_TRANSACTIONS => RawError::Kind(WIN32::ERROR_CANNOT_ABORT_TRANSACTIONS),
            WIN32::ERROR_BAD_CLUSTERS => RawError::Kind(WIN32::ERROR_BAD_CLUSTERS),
            WIN32::ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION => RawError::Kind(WIN32::ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION),
            WIN32::ERROR_VOLUME_DIRTY => RawError::Kind(WIN32::ERROR_VOLUME_DIRTY),
            WIN32::ERROR_NO_LINK_TRACKING_IN_TRANSACTION => RawError::Kind(WIN32::ERROR_NO_LINK_TRACKING_IN_TRANSACTION),
            WIN32::ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION => RawError::Kind(WIN32::ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION),
            WIN32::ERROR_EXPIRED_HANDLE => RawError::Kind(WIN32::ERROR_EXPIRED_HANDLE),
            WIN32::ERROR_TRANSACTION_NOT_ENLISTED => RawError::Kind(WIN32::ERROR_TRANSACTION_NOT_ENLISTED),
            WIN32::ERROR_CTX_WINSTATION_NAME_INVALID => RawError::Kind(WIN32::ERROR_CTX_WINSTATION_NAME_INVALID),
            WIN32::ERROR_CTX_INVALID_PD => RawError::Kind(WIN32::ERROR_CTX_INVALID_PD),
            WIN32::ERROR_CTX_PD_NOT_FOUND => RawError::Kind(WIN32::ERROR_CTX_PD_NOT_FOUND),
            WIN32::ERROR_CTX_WD_NOT_FOUND => RawError::Kind(WIN32::ERROR_CTX_WD_NOT_FOUND),
            WIN32::ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY => RawError::Kind(WIN32::ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY),
            WIN32::ERROR_CTX_SERVICE_NAME_COLLISION => RawError::Kind(WIN32::ERROR_CTX_SERVICE_NAME_COLLISION),
            WIN32::ERROR_CTX_CLOSE_PENDING => RawError::Kind(WIN32::ERROR_CTX_CLOSE_PENDING),
            WIN32::ERROR_CTX_NO_OUTBUF => RawError::Kind(WIN32::ERROR_CTX_NO_OUTBUF),
            WIN32::ERROR_CTX_MODEM_INF_NOT_FOUND => RawError::Kind(WIN32::ERROR_CTX_MODEM_INF_NOT_FOUND),
            WIN32::ERROR_CTX_INVALID_MODEMNAME => RawError::Kind(WIN32::ERROR_CTX_INVALID_MODEMNAME),
            WIN32::ERROR_CTX_MODEM_RESPONSE_ERROR => RawError::Kind(WIN32::ERROR_CTX_MODEM_RESPONSE_ERROR),
            WIN32::ERROR_CTX_MODEM_RESPONSE_TIMEOUT => RawError::Kind(WIN32::ERROR_CTX_MODEM_RESPONSE_TIMEOUT),
            WIN32::ERROR_CTX_MODEM_RESPONSE_NO_CARRIER => RawError::Kind(WIN32::ERROR_CTX_MODEM_RESPONSE_NO_CARRIER),
            WIN32::ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE => RawError::Kind(WIN32::ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE),
            WIN32::ERROR_CTX_MODEM_RESPONSE_BUSY => RawError::Kind(WIN32::ERROR_CTX_MODEM_RESPONSE_BUSY),
            WIN32::ERROR_CTX_MODEM_RESPONSE_VOICE => RawError::Kind(WIN32::ERROR_CTX_MODEM_RESPONSE_VOICE),
            WIN32::ERROR_CTX_TD_ERROR => RawError::Kind(WIN32::ERROR_CTX_TD_ERROR),
            WIN32::ERROR_CTX_WINSTATION_NOT_FOUND => RawError::Kind(WIN32::ERROR_CTX_WINSTATION_NOT_FOUND),
            WIN32::ERROR_CTX_WINSTATION_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_CTX_WINSTATION_ALREADY_EXISTS),
            WIN32::ERROR_CTX_WINSTATION_BUSY => RawError::Kind(WIN32::ERROR_CTX_WINSTATION_BUSY),
            WIN32::ERROR_CTX_BAD_VIDEO_MODE => RawError::Kind(WIN32::ERROR_CTX_BAD_VIDEO_MODE),
            WIN32::ERROR_CTX_GRAPHICS_INVALID => RawError::Kind(WIN32::ERROR_CTX_GRAPHICS_INVALID),
            WIN32::ERROR_CTX_LOGON_DISABLED => RawError::Kind(WIN32::ERROR_CTX_LOGON_DISABLED),
            WIN32::ERROR_CTX_NOT_CONSOLE => RawError::Kind(WIN32::ERROR_CTX_NOT_CONSOLE),
            WIN32::ERROR_CTX_CLIENT_QUERY_TIMEOUT => RawError::Kind(WIN32::ERROR_CTX_CLIENT_QUERY_TIMEOUT),
            WIN32::ERROR_CTX_CONSOLE_DISCONNECT => RawError::Kind(WIN32::ERROR_CTX_CONSOLE_DISCONNECT),
            WIN32::ERROR_CTX_CONSOLE_CONNECT => RawError::Kind(WIN32::ERROR_CTX_CONSOLE_CONNECT),
            WIN32::ERROR_CTX_SHADOW_DENIED => RawError::Kind(WIN32::ERROR_CTX_SHADOW_DENIED),
            WIN32::ERROR_CTX_WINSTATION_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_CTX_WINSTATION_ACCESS_DENIED),
            WIN32::ERROR_CTX_INVALID_WD => RawError::Kind(WIN32::ERROR_CTX_INVALID_WD),
            WIN32::ERROR_CTX_SHADOW_INVALID => RawError::Kind(WIN32::ERROR_CTX_SHADOW_INVALID),
            WIN32::ERROR_CTX_SHADOW_DISABLED => RawError::Kind(WIN32::ERROR_CTX_SHADOW_DISABLED),
            WIN32::ERROR_CTX_CLIENT_LICENSE_IN_USE => RawError::Kind(WIN32::ERROR_CTX_CLIENT_LICENSE_IN_USE),
            WIN32::ERROR_CTX_CLIENT_LICENSE_NOT_SET => RawError::Kind(WIN32::ERROR_CTX_CLIENT_LICENSE_NOT_SET),
            WIN32::ERROR_CTX_LICENSE_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_CTX_LICENSE_NOT_AVAILABLE),
            WIN32::ERROR_CTX_LICENSE_CLIENT_INVALID => RawError::Kind(WIN32::ERROR_CTX_LICENSE_CLIENT_INVALID),
            WIN32::ERROR_CTX_LICENSE_EXPIRED => RawError::Kind(WIN32::ERROR_CTX_LICENSE_EXPIRED),
            WIN32::ERROR_CTX_SHADOW_NOT_RUNNING => RawError::Kind(WIN32::ERROR_CTX_SHADOW_NOT_RUNNING),
            WIN32::ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE => RawError::Kind(WIN32::ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE),
            WIN32::ERROR_ACTIVATION_COUNT_EXCEEDED => RawError::Kind(WIN32::ERROR_ACTIVATION_COUNT_EXCEEDED),
            WIN32::ERROR_CTX_WINSTATIONS_DISABLED => RawError::Kind(WIN32::ERROR_CTX_WINSTATIONS_DISABLED),
            WIN32::ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED => RawError::Kind(WIN32::ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED),
            WIN32::ERROR_CTX_SESSION_IN_USE => RawError::Kind(WIN32::ERROR_CTX_SESSION_IN_USE),
            WIN32::ERROR_CTX_NO_FORCE_LOGOFF => RawError::Kind(WIN32::ERROR_CTX_NO_FORCE_LOGOFF),
            WIN32::ERROR_CTX_ACCOUNT_RESTRICTION => RawError::Kind(WIN32::ERROR_CTX_ACCOUNT_RESTRICTION),
            WIN32::ERROR_RDP_PROTOCOL_ERROR => RawError::Kind(WIN32::ERROR_RDP_PROTOCOL_ERROR),
            WIN32::ERROR_CTX_CDM_CONNECT => RawError::Kind(WIN32::ERROR_CTX_CDM_CONNECT),
            WIN32::ERROR_CTX_CDM_DISCONNECT => RawError::Kind(WIN32::ERROR_CTX_CDM_DISCONNECT),
            WIN32::ERROR_CTX_SECURITY_LAYER_ERROR => RawError::Kind(WIN32::ERROR_CTX_SECURITY_LAYER_ERROR),
            WIN32::ERROR_TS_INCOMPATIBLE_SESSIONS => RawError::Kind(WIN32::ERROR_TS_INCOMPATIBLE_SESSIONS),
            WIN32::ERROR_TS_VIDEO_SUBSYSTEM_ERROR => RawError::Kind(WIN32::ERROR_TS_VIDEO_SUBSYSTEM_ERROR),
            WIN32::FRS_ERR_INVALID_API_SEQUENCE => RawError::Kind(WIN32::FRS_ERR_INVALID_API_SEQUENCE),
            WIN32::FRS_ERR_STARTING_SERVICE => RawError::Kind(WIN32::FRS_ERR_STARTING_SERVICE),
            WIN32::FRS_ERR_STOPPING_SERVICE => RawError::Kind(WIN32::FRS_ERR_STOPPING_SERVICE),
            WIN32::FRS_ERR_INTERNAL_API => RawError::Kind(WIN32::FRS_ERR_INTERNAL_API),
            WIN32::FRS_ERR_INTERNAL => RawError::Kind(WIN32::FRS_ERR_INTERNAL),
            WIN32::FRS_ERR_SERVICE_COMM => RawError::Kind(WIN32::FRS_ERR_SERVICE_COMM),
            WIN32::FRS_ERR_INSUFFICIENT_PRIV => RawError::Kind(WIN32::FRS_ERR_INSUFFICIENT_PRIV),
            WIN32::FRS_ERR_AUTHENTICATION => RawError::Kind(WIN32::FRS_ERR_AUTHENTICATION),
            WIN32::FRS_ERR_PARENT_INSUFFICIENT_PRIV => RawError::Kind(WIN32::FRS_ERR_PARENT_INSUFFICIENT_PRIV),
            WIN32::FRS_ERR_PARENT_AUTHENTICATION => RawError::Kind(WIN32::FRS_ERR_PARENT_AUTHENTICATION),
            WIN32::FRS_ERR_CHILD_TO_PARENT_COMM => RawError::Kind(WIN32::FRS_ERR_CHILD_TO_PARENT_COMM),
            WIN32::FRS_ERR_PARENT_TO_CHILD_COMM => RawError::Kind(WIN32::FRS_ERR_PARENT_TO_CHILD_COMM),
            WIN32::FRS_ERR_SYSVOL_POPULATE => RawError::Kind(WIN32::FRS_ERR_SYSVOL_POPULATE),
            WIN32::FRS_ERR_SYSVOL_POPULATE_TIMEOUT => RawError::Kind(WIN32::FRS_ERR_SYSVOL_POPULATE_TIMEOUT),
            WIN32::FRS_ERR_SYSVOL_IS_BUSY => RawError::Kind(WIN32::FRS_ERR_SYSVOL_IS_BUSY),
            WIN32::FRS_ERR_SYSVOL_DEMOTE => RawError::Kind(WIN32::FRS_ERR_SYSVOL_DEMOTE),
            WIN32::FRS_ERR_INVALID_SERVICE_PARAMETER => RawError::Kind(WIN32::FRS_ERR_INVALID_SERVICE_PARAMETER),
            WIN32::ERROR_DS_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_DS_NOT_INSTALLED),
            WIN32::ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY => RawError::Kind(WIN32::ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY),
            WIN32::ERROR_DS_NO_ATTRIBUTE_OR_VALUE => RawError::Kind(WIN32::ERROR_DS_NO_ATTRIBUTE_OR_VALUE),
            WIN32::ERROR_DS_INVALID_ATTRIBUTE_SYNTAX => RawError::Kind(WIN32::ERROR_DS_INVALID_ATTRIBUTE_SYNTAX),
            WIN32::ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED => RawError::Kind(WIN32::ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED),
            WIN32::ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS => RawError::Kind(WIN32::ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS),
            WIN32::ERROR_DS_BUSY => RawError::Kind(WIN32::ERROR_DS_BUSY),
            WIN32::ERROR_DS_UNAVAILABLE => RawError::Kind(WIN32::ERROR_DS_UNAVAILABLE),
            WIN32::ERROR_DS_NO_RIDS_ALLOCATED => RawError::Kind(WIN32::ERROR_DS_NO_RIDS_ALLOCATED),
            WIN32::ERROR_DS_NO_MORE_RIDS => RawError::Kind(WIN32::ERROR_DS_NO_MORE_RIDS),
            WIN32::ERROR_DS_INCORRECT_ROLE_OWNER => RawError::Kind(WIN32::ERROR_DS_INCORRECT_ROLE_OWNER),
            WIN32::ERROR_DS_RIDMGR_INIT_ERROR => RawError::Kind(WIN32::ERROR_DS_RIDMGR_INIT_ERROR),
            WIN32::ERROR_DS_OBJ_CLASS_VIOLATION => RawError::Kind(WIN32::ERROR_DS_OBJ_CLASS_VIOLATION),
            WIN32::ERROR_DS_CANT_ON_NON_LEAF => RawError::Kind(WIN32::ERROR_DS_CANT_ON_NON_LEAF),
            WIN32::ERROR_DS_CANT_ON_RDN => RawError::Kind(WIN32::ERROR_DS_CANT_ON_RDN),
            WIN32::ERROR_DS_CANT_MOD_OBJ_CLASS => RawError::Kind(WIN32::ERROR_DS_CANT_MOD_OBJ_CLASS),
            WIN32::ERROR_DS_CROSS_DOM_MOVE_ERROR => RawError::Kind(WIN32::ERROR_DS_CROSS_DOM_MOVE_ERROR),
            WIN32::ERROR_DS_GC_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_DS_GC_NOT_AVAILABLE),
            WIN32::ERROR_SHARED_POLICY => RawError::Kind(WIN32::ERROR_SHARED_POLICY),
            WIN32::ERROR_POLICY_OBJECT_NOT_FOUND => RawError::Kind(WIN32::ERROR_POLICY_OBJECT_NOT_FOUND),
            WIN32::ERROR_POLICY_ONLY_IN_DS => RawError::Kind(WIN32::ERROR_POLICY_ONLY_IN_DS),
            WIN32::ERROR_PROMOTION_ACTIVE => RawError::Kind(WIN32::ERROR_PROMOTION_ACTIVE),
            WIN32::ERROR_NO_PROMOTION_ACTIVE => RawError::Kind(WIN32::ERROR_NO_PROMOTION_ACTIVE),
            WIN32::ERROR_DS_OPERATIONS_ERROR => RawError::Kind(WIN32::ERROR_DS_OPERATIONS_ERROR),
            WIN32::ERROR_DS_PROTOCOL_ERROR => RawError::Kind(WIN32::ERROR_DS_PROTOCOL_ERROR),
            WIN32::ERROR_DS_TIMELIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_TIMELIMIT_EXCEEDED),
            WIN32::ERROR_DS_SIZELIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_SIZELIMIT_EXCEEDED),
            WIN32::ERROR_DS_ADMIN_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_ADMIN_LIMIT_EXCEEDED),
            WIN32::ERROR_DS_COMPARE_FALSE => RawError::Kind(WIN32::ERROR_DS_COMPARE_FALSE),
            WIN32::ERROR_DS_COMPARE_TRUE => RawError::Kind(WIN32::ERROR_DS_COMPARE_TRUE),
            WIN32::ERROR_DS_AUTH_METHOD_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_DS_AUTH_METHOD_NOT_SUPPORTED),
            WIN32::ERROR_DS_STRONG_AUTH_REQUIRED => RawError::Kind(WIN32::ERROR_DS_STRONG_AUTH_REQUIRED),
            WIN32::ERROR_DS_INAPPROPRIATE_AUTH => RawError::Kind(WIN32::ERROR_DS_INAPPROPRIATE_AUTH),
            WIN32::ERROR_DS_AUTH_UNKNOWN => RawError::Kind(WIN32::ERROR_DS_AUTH_UNKNOWN),
            WIN32::ERROR_DS_REFERRAL => RawError::Kind(WIN32::ERROR_DS_REFERRAL),
            WIN32::ERROR_DS_UNAVAILABLE_CRIT_EXTENSION => RawError::Kind(WIN32::ERROR_DS_UNAVAILABLE_CRIT_EXTENSION),
            WIN32::ERROR_DS_CONFIDENTIALITY_REQUIRED => RawError::Kind(WIN32::ERROR_DS_CONFIDENTIALITY_REQUIRED),
            WIN32::ERROR_DS_INAPPROPRIATE_MATCHING => RawError::Kind(WIN32::ERROR_DS_INAPPROPRIATE_MATCHING),
            WIN32::ERROR_DS_CONSTRAINT_VIOLATION => RawError::Kind(WIN32::ERROR_DS_CONSTRAINT_VIOLATION),
            WIN32::ERROR_DS_NO_SUCH_OBJECT => RawError::Kind(WIN32::ERROR_DS_NO_SUCH_OBJECT),
            WIN32::ERROR_DS_ALIAS_PROBLEM => RawError::Kind(WIN32::ERROR_DS_ALIAS_PROBLEM),
            WIN32::ERROR_DS_INVALID_DN_SYNTAX => RawError::Kind(WIN32::ERROR_DS_INVALID_DN_SYNTAX),
            WIN32::ERROR_DS_IS_LEAF => RawError::Kind(WIN32::ERROR_DS_IS_LEAF),
            WIN32::ERROR_DS_ALIAS_DEREF_PROBLEM => RawError::Kind(WIN32::ERROR_DS_ALIAS_DEREF_PROBLEM),
            WIN32::ERROR_DS_UNWILLING_TO_PERFORM => RawError::Kind(WIN32::ERROR_DS_UNWILLING_TO_PERFORM),
            WIN32::ERROR_DS_LOOP_DETECT => RawError::Kind(WIN32::ERROR_DS_LOOP_DETECT),
            WIN32::ERROR_DS_NAMING_VIOLATION => RawError::Kind(WIN32::ERROR_DS_NAMING_VIOLATION),
            WIN32::ERROR_DS_OBJECT_RESULTS_TOO_LARGE => RawError::Kind(WIN32::ERROR_DS_OBJECT_RESULTS_TOO_LARGE),
            WIN32::ERROR_DS_AFFECTS_MULTIPLE_DSAS => RawError::Kind(WIN32::ERROR_DS_AFFECTS_MULTIPLE_DSAS),
            WIN32::ERROR_DS_SERVER_DOWN => RawError::Kind(WIN32::ERROR_DS_SERVER_DOWN),
            WIN32::ERROR_DS_LOCAL_ERROR => RawError::Kind(WIN32::ERROR_DS_LOCAL_ERROR),
            WIN32::ERROR_DS_ENCODING_ERROR => RawError::Kind(WIN32::ERROR_DS_ENCODING_ERROR),
            WIN32::ERROR_DS_DECODING_ERROR => RawError::Kind(WIN32::ERROR_DS_DECODING_ERROR),
            WIN32::ERROR_DS_FILTER_UNKNOWN => RawError::Kind(WIN32::ERROR_DS_FILTER_UNKNOWN),
            WIN32::ERROR_DS_PARAM_ERROR => RawError::Kind(WIN32::ERROR_DS_PARAM_ERROR),
            WIN32::ERROR_DS_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_DS_NOT_SUPPORTED),
            WIN32::ERROR_DS_NO_RESULTS_RETURNED => RawError::Kind(WIN32::ERROR_DS_NO_RESULTS_RETURNED),
            WIN32::ERROR_DS_CONTROL_NOT_FOUND => RawError::Kind(WIN32::ERROR_DS_CONTROL_NOT_FOUND),
            WIN32::ERROR_DS_CLIENT_LOOP => RawError::Kind(WIN32::ERROR_DS_CLIENT_LOOP),
            WIN32::ERROR_DS_REFERRAL_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_REFERRAL_LIMIT_EXCEEDED),
            WIN32::ERROR_DS_SORT_CONTROL_MISSING => RawError::Kind(WIN32::ERROR_DS_SORT_CONTROL_MISSING),
            WIN32::ERROR_DS_OFFSET_RANGE_ERROR => RawError::Kind(WIN32::ERROR_DS_OFFSET_RANGE_ERROR),
            WIN32::ERROR_DS_RIDMGR_DISABLED => RawError::Kind(WIN32::ERROR_DS_RIDMGR_DISABLED),
            WIN32::ERROR_DS_ROOT_MUST_BE_NC => RawError::Kind(WIN32::ERROR_DS_ROOT_MUST_BE_NC),
            WIN32::ERROR_DS_ADD_REPLICA_INHIBITED => RawError::Kind(WIN32::ERROR_DS_ADD_REPLICA_INHIBITED),
            WIN32::ERROR_DS_ATT_NOT_DEF_IN_SCHEMA => RawError::Kind(WIN32::ERROR_DS_ATT_NOT_DEF_IN_SCHEMA),
            WIN32::ERROR_DS_MAX_OBJ_SIZE_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_MAX_OBJ_SIZE_EXCEEDED),
            WIN32::ERROR_DS_OBJ_STRING_NAME_EXISTS => RawError::Kind(WIN32::ERROR_DS_OBJ_STRING_NAME_EXISTS),
            WIN32::ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA => RawError::Kind(WIN32::ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA),
            WIN32::ERROR_DS_RDN_DOESNT_MATCH_SCHEMA => RawError::Kind(WIN32::ERROR_DS_RDN_DOESNT_MATCH_SCHEMA),
            WIN32::ERROR_DS_NO_REQUESTED_ATTS_FOUND => RawError::Kind(WIN32::ERROR_DS_NO_REQUESTED_ATTS_FOUND),
            WIN32::ERROR_DS_USER_BUFFER_TO_SMALL => RawError::Kind(WIN32::ERROR_DS_USER_BUFFER_TO_SMALL),
            WIN32::ERROR_DS_ATT_IS_NOT_ON_OBJ => RawError::Kind(WIN32::ERROR_DS_ATT_IS_NOT_ON_OBJ),
            WIN32::ERROR_DS_ILLEGAL_MOD_OPERATION => RawError::Kind(WIN32::ERROR_DS_ILLEGAL_MOD_OPERATION),
            WIN32::ERROR_DS_OBJ_TOO_LARGE => RawError::Kind(WIN32::ERROR_DS_OBJ_TOO_LARGE),
            WIN32::ERROR_DS_BAD_INSTANCE_TYPE => RawError::Kind(WIN32::ERROR_DS_BAD_INSTANCE_TYPE),
            WIN32::ERROR_DS_MASTERDSA_REQUIRED => RawError::Kind(WIN32::ERROR_DS_MASTERDSA_REQUIRED),
            WIN32::ERROR_DS_OBJECT_CLASS_REQUIRED => RawError::Kind(WIN32::ERROR_DS_OBJECT_CLASS_REQUIRED),
            WIN32::ERROR_DS_MISSING_REQUIRED_ATT => RawError::Kind(WIN32::ERROR_DS_MISSING_REQUIRED_ATT),
            WIN32::ERROR_DS_ATT_NOT_DEF_FOR_CLASS => RawError::Kind(WIN32::ERROR_DS_ATT_NOT_DEF_FOR_CLASS),
            WIN32::ERROR_DS_ATT_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_DS_ATT_ALREADY_EXISTS),
            WIN32::ERROR_DS_CANT_ADD_ATT_VALUES => RawError::Kind(WIN32::ERROR_DS_CANT_ADD_ATT_VALUES),
            WIN32::ERROR_DS_SINGLE_VALUE_CONSTRAINT => RawError::Kind(WIN32::ERROR_DS_SINGLE_VALUE_CONSTRAINT),
            WIN32::ERROR_DS_RANGE_CONSTRAINT => RawError::Kind(WIN32::ERROR_DS_RANGE_CONSTRAINT),
            WIN32::ERROR_DS_ATT_VAL_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_DS_ATT_VAL_ALREADY_EXISTS),
            WIN32::ERROR_DS_CANT_REM_MISSING_ATT => RawError::Kind(WIN32::ERROR_DS_CANT_REM_MISSING_ATT),
            WIN32::ERROR_DS_CANT_REM_MISSING_ATT_VAL => RawError::Kind(WIN32::ERROR_DS_CANT_REM_MISSING_ATT_VAL),
            WIN32::ERROR_DS_ROOT_CANT_BE_SUBREF => RawError::Kind(WIN32::ERROR_DS_ROOT_CANT_BE_SUBREF),
            WIN32::ERROR_DS_NO_CHAINING => RawError::Kind(WIN32::ERROR_DS_NO_CHAINING),
            WIN32::ERROR_DS_NO_CHAINED_EVAL => RawError::Kind(WIN32::ERROR_DS_NO_CHAINED_EVAL),
            WIN32::ERROR_DS_NO_PARENT_OBJECT => RawError::Kind(WIN32::ERROR_DS_NO_PARENT_OBJECT),
            WIN32::ERROR_DS_PARENT_IS_AN_ALIAS => RawError::Kind(WIN32::ERROR_DS_PARENT_IS_AN_ALIAS),
            WIN32::ERROR_DS_CANT_MIX_MASTER_AND_REPS => RawError::Kind(WIN32::ERROR_DS_CANT_MIX_MASTER_AND_REPS),
            WIN32::ERROR_DS_CHILDREN_EXIST => RawError::Kind(WIN32::ERROR_DS_CHILDREN_EXIST),
            WIN32::ERROR_DS_OBJ_NOT_FOUND => RawError::Kind(WIN32::ERROR_DS_OBJ_NOT_FOUND),
            WIN32::ERROR_DS_ALIASED_OBJ_MISSING => RawError::Kind(WIN32::ERROR_DS_ALIASED_OBJ_MISSING),
            WIN32::ERROR_DS_BAD_NAME_SYNTAX => RawError::Kind(WIN32::ERROR_DS_BAD_NAME_SYNTAX),
            WIN32::ERROR_DS_ALIAS_POINTS_TO_ALIAS => RawError::Kind(WIN32::ERROR_DS_ALIAS_POINTS_TO_ALIAS),
            WIN32::ERROR_DS_CANT_DEREF_ALIAS => RawError::Kind(WIN32::ERROR_DS_CANT_DEREF_ALIAS),
            WIN32::ERROR_DS_OUT_OF_SCOPE => RawError::Kind(WIN32::ERROR_DS_OUT_OF_SCOPE),
            WIN32::ERROR_DS_OBJECT_BEING_REMOVED => RawError::Kind(WIN32::ERROR_DS_OBJECT_BEING_REMOVED),
            WIN32::ERROR_DS_CANT_DELETE_DSA_OBJ => RawError::Kind(WIN32::ERROR_DS_CANT_DELETE_DSA_OBJ),
            WIN32::ERROR_DS_GENERIC_ERROR => RawError::Kind(WIN32::ERROR_DS_GENERIC_ERROR),
            WIN32::ERROR_DS_DSA_MUST_BE_INT_MASTER => RawError::Kind(WIN32::ERROR_DS_DSA_MUST_BE_INT_MASTER),
            WIN32::ERROR_DS_CLASS_NOT_DSA => RawError::Kind(WIN32::ERROR_DS_CLASS_NOT_DSA),
            WIN32::ERROR_DS_INSUFF_ACCESS_RIGHTS => RawError::Kind(WIN32::ERROR_DS_INSUFF_ACCESS_RIGHTS),
            WIN32::ERROR_DS_ILLEGAL_SUPERIOR => RawError::Kind(WIN32::ERROR_DS_ILLEGAL_SUPERIOR),
            WIN32::ERROR_DS_ATTRIBUTE_OWNED_BY_SAM => RawError::Kind(WIN32::ERROR_DS_ATTRIBUTE_OWNED_BY_SAM),
            WIN32::ERROR_DS_NAME_TOO_MANY_PARTS => RawError::Kind(WIN32::ERROR_DS_NAME_TOO_MANY_PARTS),
            WIN32::ERROR_DS_NAME_TOO_LONG => RawError::Kind(WIN32::ERROR_DS_NAME_TOO_LONG),
            WIN32::ERROR_DS_NAME_VALUE_TOO_LONG => RawError::Kind(WIN32::ERROR_DS_NAME_VALUE_TOO_LONG),
            WIN32::ERROR_DS_NAME_UNPARSEABLE => RawError::Kind(WIN32::ERROR_DS_NAME_UNPARSEABLE),
            WIN32::ERROR_DS_NAME_TYPE_UNKNOWN => RawError::Kind(WIN32::ERROR_DS_NAME_TYPE_UNKNOWN),
            WIN32::ERROR_DS_NOT_AN_OBJECT => RawError::Kind(WIN32::ERROR_DS_NOT_AN_OBJECT),
            WIN32::ERROR_DS_SEC_DESC_TOO_SHORT => RawError::Kind(WIN32::ERROR_DS_SEC_DESC_TOO_SHORT),
            WIN32::ERROR_DS_SEC_DESC_INVALID => RawError::Kind(WIN32::ERROR_DS_SEC_DESC_INVALID),
            WIN32::ERROR_DS_NO_DELETED_NAME => RawError::Kind(WIN32::ERROR_DS_NO_DELETED_NAME),
            WIN32::ERROR_DS_SUBREF_MUST_HAVE_PARENT => RawError::Kind(WIN32::ERROR_DS_SUBREF_MUST_HAVE_PARENT),
            WIN32::ERROR_DS_NCNAME_MUST_BE_NC => RawError::Kind(WIN32::ERROR_DS_NCNAME_MUST_BE_NC),
            WIN32::ERROR_DS_CANT_ADD_SYSTEM_ONLY => RawError::Kind(WIN32::ERROR_DS_CANT_ADD_SYSTEM_ONLY),
            WIN32::ERROR_DS_CLASS_MUST_BE_CONCRETE => RawError::Kind(WIN32::ERROR_DS_CLASS_MUST_BE_CONCRETE),
            WIN32::ERROR_DS_INVALID_DMD => RawError::Kind(WIN32::ERROR_DS_INVALID_DMD),
            WIN32::ERROR_DS_OBJ_GUID_EXISTS => RawError::Kind(WIN32::ERROR_DS_OBJ_GUID_EXISTS),
            WIN32::ERROR_DS_NOT_ON_BACKLINK => RawError::Kind(WIN32::ERROR_DS_NOT_ON_BACKLINK),
            WIN32::ERROR_DS_NO_CROSSREF_FOR_NC => RawError::Kind(WIN32::ERROR_DS_NO_CROSSREF_FOR_NC),
            WIN32::ERROR_DS_SHUTTING_DOWN => RawError::Kind(WIN32::ERROR_DS_SHUTTING_DOWN),
            WIN32::ERROR_DS_UNKNOWN_OPERATION => RawError::Kind(WIN32::ERROR_DS_UNKNOWN_OPERATION),
            WIN32::ERROR_DS_INVALID_ROLE_OWNER => RawError::Kind(WIN32::ERROR_DS_INVALID_ROLE_OWNER),
            WIN32::ERROR_DS_COULDNT_CONTACT_FSMO => RawError::Kind(WIN32::ERROR_DS_COULDNT_CONTACT_FSMO),
            WIN32::ERROR_DS_CROSS_NC_DN_RENAME => RawError::Kind(WIN32::ERROR_DS_CROSS_NC_DN_RENAME),
            WIN32::ERROR_DS_CANT_MOD_SYSTEM_ONLY => RawError::Kind(WIN32::ERROR_DS_CANT_MOD_SYSTEM_ONLY),
            WIN32::ERROR_DS_REPLICATOR_ONLY => RawError::Kind(WIN32::ERROR_DS_REPLICATOR_ONLY),
            WIN32::ERROR_DS_OBJ_CLASS_NOT_DEFINED => RawError::Kind(WIN32::ERROR_DS_OBJ_CLASS_NOT_DEFINED),
            WIN32::ERROR_DS_OBJ_CLASS_NOT_SUBCLASS => RawError::Kind(WIN32::ERROR_DS_OBJ_CLASS_NOT_SUBCLASS),
            WIN32::ERROR_DS_NAME_REFERENCE_INVALID => RawError::Kind(WIN32::ERROR_DS_NAME_REFERENCE_INVALID),
            WIN32::ERROR_DS_CROSS_REF_EXISTS => RawError::Kind(WIN32::ERROR_DS_CROSS_REF_EXISTS),
            WIN32::ERROR_DS_CANT_DEL_MASTER_CROSSREF => RawError::Kind(WIN32::ERROR_DS_CANT_DEL_MASTER_CROSSREF),
            WIN32::ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD => RawError::Kind(WIN32::ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD),
            WIN32::ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX => RawError::Kind(WIN32::ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX),
            WIN32::ERROR_DS_DUP_RDN => RawError::Kind(WIN32::ERROR_DS_DUP_RDN),
            WIN32::ERROR_DS_DUP_OID => RawError::Kind(WIN32::ERROR_DS_DUP_OID),
            WIN32::ERROR_DS_DUP_MAPI_ID => RawError::Kind(WIN32::ERROR_DS_DUP_MAPI_ID),
            WIN32::ERROR_DS_DUP_SCHEMA_ID_GUID => RawError::Kind(WIN32::ERROR_DS_DUP_SCHEMA_ID_GUID),
            WIN32::ERROR_DS_DUP_LDAP_DISPLAY_NAME => RawError::Kind(WIN32::ERROR_DS_DUP_LDAP_DISPLAY_NAME),
            WIN32::ERROR_DS_SEMANTIC_ATT_TEST => RawError::Kind(WIN32::ERROR_DS_SEMANTIC_ATT_TEST),
            WIN32::ERROR_DS_SYNTAX_MISMATCH => RawError::Kind(WIN32::ERROR_DS_SYNTAX_MISMATCH),
            WIN32::ERROR_DS_EXISTS_IN_MUST_HAVE => RawError::Kind(WIN32::ERROR_DS_EXISTS_IN_MUST_HAVE),
            WIN32::ERROR_DS_EXISTS_IN_MAY_HAVE => RawError::Kind(WIN32::ERROR_DS_EXISTS_IN_MAY_HAVE),
            WIN32::ERROR_DS_NONEXISTENT_MAY_HAVE => RawError::Kind(WIN32::ERROR_DS_NONEXISTENT_MAY_HAVE),
            WIN32::ERROR_DS_NONEXISTENT_MUST_HAVE => RawError::Kind(WIN32::ERROR_DS_NONEXISTENT_MUST_HAVE),
            WIN32::ERROR_DS_AUX_CLS_TEST_FAIL => RawError::Kind(WIN32::ERROR_DS_AUX_CLS_TEST_FAIL),
            WIN32::ERROR_DS_NONEXISTENT_POSS_SUP => RawError::Kind(WIN32::ERROR_DS_NONEXISTENT_POSS_SUP),
            WIN32::ERROR_DS_SUB_CLS_TEST_FAIL => RawError::Kind(WIN32::ERROR_DS_SUB_CLS_TEST_FAIL),
            WIN32::ERROR_DS_BAD_RDN_ATT_ID_SYNTAX => RawError::Kind(WIN32::ERROR_DS_BAD_RDN_ATT_ID_SYNTAX),
            WIN32::ERROR_DS_EXISTS_IN_AUX_CLS => RawError::Kind(WIN32::ERROR_DS_EXISTS_IN_AUX_CLS),
            WIN32::ERROR_DS_EXISTS_IN_SUB_CLS => RawError::Kind(WIN32::ERROR_DS_EXISTS_IN_SUB_CLS),
            WIN32::ERROR_DS_EXISTS_IN_POSS_SUP => RawError::Kind(WIN32::ERROR_DS_EXISTS_IN_POSS_SUP),
            WIN32::ERROR_DS_RECALCSCHEMA_FAILED => RawError::Kind(WIN32::ERROR_DS_RECALCSCHEMA_FAILED),
            WIN32::ERROR_DS_TREE_DELETE_NOT_FINISHED => RawError::Kind(WIN32::ERROR_DS_TREE_DELETE_NOT_FINISHED),
            WIN32::ERROR_DS_CANT_DELETE => RawError::Kind(WIN32::ERROR_DS_CANT_DELETE),
            WIN32::ERROR_DS_ATT_SCHEMA_REQ_ID => RawError::Kind(WIN32::ERROR_DS_ATT_SCHEMA_REQ_ID),
            WIN32::ERROR_DS_BAD_ATT_SCHEMA_SYNTAX => RawError::Kind(WIN32::ERROR_DS_BAD_ATT_SCHEMA_SYNTAX),
            WIN32::ERROR_DS_CANT_CACHE_ATT => RawError::Kind(WIN32::ERROR_DS_CANT_CACHE_ATT),
            WIN32::ERROR_DS_CANT_CACHE_CLASS => RawError::Kind(WIN32::ERROR_DS_CANT_CACHE_CLASS),
            WIN32::ERROR_DS_CANT_REMOVE_ATT_CACHE => RawError::Kind(WIN32::ERROR_DS_CANT_REMOVE_ATT_CACHE),
            WIN32::ERROR_DS_CANT_REMOVE_CLASS_CACHE => RawError::Kind(WIN32::ERROR_DS_CANT_REMOVE_CLASS_CACHE),
            WIN32::ERROR_DS_CANT_RETRIEVE_DN => RawError::Kind(WIN32::ERROR_DS_CANT_RETRIEVE_DN),
            WIN32::ERROR_DS_MISSING_SUPREF => RawError::Kind(WIN32::ERROR_DS_MISSING_SUPREF),
            WIN32::ERROR_DS_CANT_RETRIEVE_INSTANCE => RawError::Kind(WIN32::ERROR_DS_CANT_RETRIEVE_INSTANCE),
            WIN32::ERROR_DS_CODE_INCONSISTENCY => RawError::Kind(WIN32::ERROR_DS_CODE_INCONSISTENCY),
            WIN32::ERROR_DS_DATABASE_ERROR => RawError::Kind(WIN32::ERROR_DS_DATABASE_ERROR),
            WIN32::ERROR_DS_GOVERNSID_MISSING => RawError::Kind(WIN32::ERROR_DS_GOVERNSID_MISSING),
            WIN32::ERROR_DS_MISSING_EXPECTED_ATT => RawError::Kind(WIN32::ERROR_DS_MISSING_EXPECTED_ATT),
            WIN32::ERROR_DS_NCNAME_MISSING_CR_REF => RawError::Kind(WIN32::ERROR_DS_NCNAME_MISSING_CR_REF),
            WIN32::ERROR_DS_SECURITY_CHECKING_ERROR => RawError::Kind(WIN32::ERROR_DS_SECURITY_CHECKING_ERROR),
            WIN32::ERROR_DS_SCHEMA_NOT_LOADED => RawError::Kind(WIN32::ERROR_DS_SCHEMA_NOT_LOADED),
            WIN32::ERROR_DS_SCHEMA_ALLOC_FAILED => RawError::Kind(WIN32::ERROR_DS_SCHEMA_ALLOC_FAILED),
            WIN32::ERROR_DS_ATT_SCHEMA_REQ_SYNTAX => RawError::Kind(WIN32::ERROR_DS_ATT_SCHEMA_REQ_SYNTAX),
            WIN32::ERROR_DS_GCVERIFY_ERROR => RawError::Kind(WIN32::ERROR_DS_GCVERIFY_ERROR),
            WIN32::ERROR_DS_DRA_SCHEMA_MISMATCH => RawError::Kind(WIN32::ERROR_DS_DRA_SCHEMA_MISMATCH),
            WIN32::ERROR_DS_CANT_FIND_DSA_OBJ => RawError::Kind(WIN32::ERROR_DS_CANT_FIND_DSA_OBJ),
            WIN32::ERROR_DS_CANT_FIND_EXPECTED_NC => RawError::Kind(WIN32::ERROR_DS_CANT_FIND_EXPECTED_NC),
            WIN32::ERROR_DS_CANT_FIND_NC_IN_CACHE => RawError::Kind(WIN32::ERROR_DS_CANT_FIND_NC_IN_CACHE),
            WIN32::ERROR_DS_CANT_RETRIEVE_CHILD => RawError::Kind(WIN32::ERROR_DS_CANT_RETRIEVE_CHILD),
            WIN32::ERROR_DS_SECURITY_ILLEGAL_MODIFY => RawError::Kind(WIN32::ERROR_DS_SECURITY_ILLEGAL_MODIFY),
            WIN32::ERROR_DS_CANT_REPLACE_HIDDEN_REC => RawError::Kind(WIN32::ERROR_DS_CANT_REPLACE_HIDDEN_REC),
            WIN32::ERROR_DS_BAD_HIERARCHY_FILE => RawError::Kind(WIN32::ERROR_DS_BAD_HIERARCHY_FILE),
            WIN32::ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED => RawError::Kind(WIN32::ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED),
            WIN32::ERROR_DS_CONFIG_PARAM_MISSING => RawError::Kind(WIN32::ERROR_DS_CONFIG_PARAM_MISSING),
            WIN32::ERROR_DS_COUNTING_AB_INDICES_FAILED => RawError::Kind(WIN32::ERROR_DS_COUNTING_AB_INDICES_FAILED),
            WIN32::ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED => RawError::Kind(WIN32::ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED),
            WIN32::ERROR_DS_INTERNAL_FAILURE => RawError::Kind(WIN32::ERROR_DS_INTERNAL_FAILURE),
            WIN32::ERROR_DS_UNKNOWN_ERROR => RawError::Kind(WIN32::ERROR_DS_UNKNOWN_ERROR),
            WIN32::ERROR_DS_ROOT_REQUIRES_CLASS_TOP => RawError::Kind(WIN32::ERROR_DS_ROOT_REQUIRES_CLASS_TOP),
            WIN32::ERROR_DS_REFUSING_FSMO_ROLES => RawError::Kind(WIN32::ERROR_DS_REFUSING_FSMO_ROLES),
            WIN32::ERROR_DS_MISSING_FSMO_SETTINGS => RawError::Kind(WIN32::ERROR_DS_MISSING_FSMO_SETTINGS),
            WIN32::ERROR_DS_UNABLE_TO_SURRENDER_ROLES => RawError::Kind(WIN32::ERROR_DS_UNABLE_TO_SURRENDER_ROLES),
            WIN32::ERROR_DS_DRA_GENERIC => RawError::Kind(WIN32::ERROR_DS_DRA_GENERIC),
            WIN32::ERROR_DS_DRA_INVALID_PARAMETER => RawError::Kind(WIN32::ERROR_DS_DRA_INVALID_PARAMETER),
            WIN32::ERROR_DS_DRA_BUSY => RawError::Kind(WIN32::ERROR_DS_DRA_BUSY),
            WIN32::ERROR_DS_DRA_BAD_DN => RawError::Kind(WIN32::ERROR_DS_DRA_BAD_DN),
            WIN32::ERROR_DS_DRA_BAD_NC => RawError::Kind(WIN32::ERROR_DS_DRA_BAD_NC),
            WIN32::ERROR_DS_DRA_DN_EXISTS => RawError::Kind(WIN32::ERROR_DS_DRA_DN_EXISTS),
            WIN32::ERROR_DS_DRA_INTERNAL_ERROR => RawError::Kind(WIN32::ERROR_DS_DRA_INTERNAL_ERROR),
            WIN32::ERROR_DS_DRA_INCONSISTENT_DIT => RawError::Kind(WIN32::ERROR_DS_DRA_INCONSISTENT_DIT),
            WIN32::ERROR_DS_DRA_CONNECTION_FAILED => RawError::Kind(WIN32::ERROR_DS_DRA_CONNECTION_FAILED),
            WIN32::ERROR_DS_DRA_BAD_INSTANCE_TYPE => RawError::Kind(WIN32::ERROR_DS_DRA_BAD_INSTANCE_TYPE),
            WIN32::ERROR_DS_DRA_OUT_OF_MEM => RawError::Kind(WIN32::ERROR_DS_DRA_OUT_OF_MEM),
            WIN32::ERROR_DS_DRA_MAIL_PROBLEM => RawError::Kind(WIN32::ERROR_DS_DRA_MAIL_PROBLEM),
            WIN32::ERROR_DS_DRA_REF_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_DS_DRA_REF_ALREADY_EXISTS),
            WIN32::ERROR_DS_DRA_REF_NOT_FOUND => RawError::Kind(WIN32::ERROR_DS_DRA_REF_NOT_FOUND),
            WIN32::ERROR_DS_DRA_OBJ_IS_REP_SOURCE => RawError::Kind(WIN32::ERROR_DS_DRA_OBJ_IS_REP_SOURCE),
            WIN32::ERROR_DS_DRA_DB_ERROR => RawError::Kind(WIN32::ERROR_DS_DRA_DB_ERROR),
            WIN32::ERROR_DS_DRA_NO_REPLICA => RawError::Kind(WIN32::ERROR_DS_DRA_NO_REPLICA),
            WIN32::ERROR_DS_DRA_ACCESS_DENIED => RawError::Kind(WIN32::ERROR_DS_DRA_ACCESS_DENIED),
            WIN32::ERROR_DS_DRA_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_DS_DRA_NOT_SUPPORTED),
            WIN32::ERROR_DS_DRA_RPC_CANCELLED => RawError::Kind(WIN32::ERROR_DS_DRA_RPC_CANCELLED),
            WIN32::ERROR_DS_DRA_SOURCE_DISABLED => RawError::Kind(WIN32::ERROR_DS_DRA_SOURCE_DISABLED),
            WIN32::ERROR_DS_DRA_SINK_DISABLED => RawError::Kind(WIN32::ERROR_DS_DRA_SINK_DISABLED),
            WIN32::ERROR_DS_DRA_NAME_COLLISION => RawError::Kind(WIN32::ERROR_DS_DRA_NAME_COLLISION),
            WIN32::ERROR_DS_DRA_SOURCE_REINSTALLED => RawError::Kind(WIN32::ERROR_DS_DRA_SOURCE_REINSTALLED),
            WIN32::ERROR_DS_DRA_MISSING_PARENT => RawError::Kind(WIN32::ERROR_DS_DRA_MISSING_PARENT),
            WIN32::ERROR_DS_DRA_PREEMPTED => RawError::Kind(WIN32::ERROR_DS_DRA_PREEMPTED),
            WIN32::ERROR_DS_DRA_ABANDON_SYNC => RawError::Kind(WIN32::ERROR_DS_DRA_ABANDON_SYNC),
            WIN32::ERROR_DS_DRA_SHUTDOWN => RawError::Kind(WIN32::ERROR_DS_DRA_SHUTDOWN),
            WIN32::ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET => RawError::Kind(WIN32::ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET),
            WIN32::ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA => RawError::Kind(WIN32::ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA),
            WIN32::ERROR_DS_DRA_EXTN_CONNECTION_FAILED => RawError::Kind(WIN32::ERROR_DS_DRA_EXTN_CONNECTION_FAILED),
            WIN32::ERROR_DS_INSTALL_SCHEMA_MISMATCH => RawError::Kind(WIN32::ERROR_DS_INSTALL_SCHEMA_MISMATCH),
            WIN32::ERROR_DS_DUP_LINK_ID => RawError::Kind(WIN32::ERROR_DS_DUP_LINK_ID),
            WIN32::ERROR_DS_NAME_ERROR_RESOLVING => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_RESOLVING),
            WIN32::ERROR_DS_NAME_ERROR_NOT_FOUND => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_NOT_FOUND),
            WIN32::ERROR_DS_NAME_ERROR_NOT_UNIQUE => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_NOT_UNIQUE),
            WIN32::ERROR_DS_NAME_ERROR_NO_MAPPING => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_NO_MAPPING),
            WIN32::ERROR_DS_NAME_ERROR_DOMAIN_ONLY => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_DOMAIN_ONLY),
            WIN32::ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING),
            WIN32::ERROR_DS_CONSTRUCTED_ATT_MOD => RawError::Kind(WIN32::ERROR_DS_CONSTRUCTED_ATT_MOD),
            WIN32::ERROR_DS_WRONG_OM_OBJ_CLASS => RawError::Kind(WIN32::ERROR_DS_WRONG_OM_OBJ_CLASS),
            WIN32::ERROR_DS_DRA_REPL_PENDING => RawError::Kind(WIN32::ERROR_DS_DRA_REPL_PENDING),
            WIN32::ERROR_DS_DS_REQUIRED => RawError::Kind(WIN32::ERROR_DS_DS_REQUIRED),
            WIN32::ERROR_DS_INVALID_LDAP_DISPLAY_NAME => RawError::Kind(WIN32::ERROR_DS_INVALID_LDAP_DISPLAY_NAME),
            WIN32::ERROR_DS_NON_BASE_SEARCH => RawError::Kind(WIN32::ERROR_DS_NON_BASE_SEARCH),
            WIN32::ERROR_DS_CANT_RETRIEVE_ATTS => RawError::Kind(WIN32::ERROR_DS_CANT_RETRIEVE_ATTS),
            WIN32::ERROR_DS_BACKLINK_WITHOUT_LINK => RawError::Kind(WIN32::ERROR_DS_BACKLINK_WITHOUT_LINK),
            WIN32::ERROR_DS_EPOCH_MISMATCH => RawError::Kind(WIN32::ERROR_DS_EPOCH_MISMATCH),
            WIN32::ERROR_DS_SRC_NAME_MISMATCH => RawError::Kind(WIN32::ERROR_DS_SRC_NAME_MISMATCH),
            WIN32::ERROR_DS_SRC_AND_DST_NC_IDENTICAL => RawError::Kind(WIN32::ERROR_DS_SRC_AND_DST_NC_IDENTICAL),
            WIN32::ERROR_DS_DST_NC_MISMATCH => RawError::Kind(WIN32::ERROR_DS_DST_NC_MISMATCH),
            WIN32::ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC => RawError::Kind(WIN32::ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC),
            WIN32::ERROR_DS_SRC_GUID_MISMATCH => RawError::Kind(WIN32::ERROR_DS_SRC_GUID_MISMATCH),
            WIN32::ERROR_DS_CANT_MOVE_DELETED_OBJECT => RawError::Kind(WIN32::ERROR_DS_CANT_MOVE_DELETED_OBJECT),
            WIN32::ERROR_DS_PDC_OPERATION_IN_PROGRESS => RawError::Kind(WIN32::ERROR_DS_PDC_OPERATION_IN_PROGRESS),
            WIN32::ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD => RawError::Kind(WIN32::ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD),
            WIN32::ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION => RawError::Kind(WIN32::ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION),
            WIN32::ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS => RawError::Kind(WIN32::ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS),
            WIN32::ERROR_DS_NC_MUST_HAVE_NC_PARENT => RawError::Kind(WIN32::ERROR_DS_NC_MUST_HAVE_NC_PARENT),
            WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE => RawError::Kind(WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE),
            WIN32::ERROR_DS_DST_DOMAIN_NOT_NATIVE => RawError::Kind(WIN32::ERROR_DS_DST_DOMAIN_NOT_NATIVE),
            WIN32::ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER => RawError::Kind(WIN32::ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER),
            WIN32::ERROR_DS_CANT_MOVE_ACCOUNT_GROUP => RawError::Kind(WIN32::ERROR_DS_CANT_MOVE_ACCOUNT_GROUP),
            WIN32::ERROR_DS_CANT_MOVE_RESOURCE_GROUP => RawError::Kind(WIN32::ERROR_DS_CANT_MOVE_RESOURCE_GROUP),
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG => RawError::Kind(WIN32::ERROR_DS_INVALID_SEARCH_FLAG),
            WIN32::ERROR_DS_NO_TREE_DELETE_ABOVE_NC => RawError::Kind(WIN32::ERROR_DS_NO_TREE_DELETE_ABOVE_NC),
            WIN32::ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE => RawError::Kind(WIN32::ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE),
            WIN32::ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE => RawError::Kind(WIN32::ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE),
            WIN32::ERROR_DS_SAM_INIT_FAILURE => RawError::Kind(WIN32::ERROR_DS_SAM_INIT_FAILURE),
            WIN32::ERROR_DS_SENSITIVE_GROUP_VIOLATION => RawError::Kind(WIN32::ERROR_DS_SENSITIVE_GROUP_VIOLATION),
            WIN32::ERROR_DS_CANT_MOD_PRIMARYGROUPID => RawError::Kind(WIN32::ERROR_DS_CANT_MOD_PRIMARYGROUPID),
            WIN32::ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD => RawError::Kind(WIN32::ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD),
            WIN32::ERROR_DS_NONSAFE_SCHEMA_CHANGE => RawError::Kind(WIN32::ERROR_DS_NONSAFE_SCHEMA_CHANGE),
            WIN32::ERROR_DS_SCHEMA_UPDATE_DISALLOWED => RawError::Kind(WIN32::ERROR_DS_SCHEMA_UPDATE_DISALLOWED),
            WIN32::ERROR_DS_CANT_CREATE_UNDER_SCHEMA => RawError::Kind(WIN32::ERROR_DS_CANT_CREATE_UNDER_SCHEMA),
            WIN32::ERROR_DS_INSTALL_NO_SRC_SCH_VERSION => RawError::Kind(WIN32::ERROR_DS_INSTALL_NO_SRC_SCH_VERSION),
            WIN32::ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE => RawError::Kind(WIN32::ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE),
            WIN32::ERROR_DS_INVALID_GROUP_TYPE => RawError::Kind(WIN32::ERROR_DS_INVALID_GROUP_TYPE),
            WIN32::ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN => RawError::Kind(WIN32::ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN),
            WIN32::ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN => RawError::Kind(WIN32::ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN),
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER => RawError::Kind(WIN32::ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER),
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER => RawError::Kind(WIN32::ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER),
            WIN32::ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER => RawError::Kind(WIN32::ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER),
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER => RawError::Kind(WIN32::ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER),
            WIN32::ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER => RawError::Kind(WIN32::ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER),
            WIN32::ERROR_DS_HAVE_PRIMARY_MEMBERS => RawError::Kind(WIN32::ERROR_DS_HAVE_PRIMARY_MEMBERS),
            WIN32::ERROR_DS_STRING_SD_CONVERSION_FAILED => RawError::Kind(WIN32::ERROR_DS_STRING_SD_CONVERSION_FAILED),
            WIN32::ERROR_DS_NAMING_MASTER_GC => RawError::Kind(WIN32::ERROR_DS_NAMING_MASTER_GC),
            WIN32::ERROR_DS_DNS_LOOKUP_FAILURE => RawError::Kind(WIN32::ERROR_DS_DNS_LOOKUP_FAILURE),
            WIN32::ERROR_DS_COULDNT_UPDATE_SPNS => RawError::Kind(WIN32::ERROR_DS_COULDNT_UPDATE_SPNS),
            WIN32::ERROR_DS_CANT_RETRIEVE_SD => RawError::Kind(WIN32::ERROR_DS_CANT_RETRIEVE_SD),
            WIN32::ERROR_DS_KEY_NOT_UNIQUE => RawError::Kind(WIN32::ERROR_DS_KEY_NOT_UNIQUE),
            WIN32::ERROR_DS_WRONG_LINKED_ATT_SYNTAX => RawError::Kind(WIN32::ERROR_DS_WRONG_LINKED_ATT_SYNTAX),
            WIN32::ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD => RawError::Kind(WIN32::ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD),
            WIN32::ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY => RawError::Kind(WIN32::ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY),
            WIN32::ERROR_DS_CANT_START => RawError::Kind(WIN32::ERROR_DS_CANT_START),
            WIN32::ERROR_DS_INIT_FAILURE => RawError::Kind(WIN32::ERROR_DS_INIT_FAILURE),
            WIN32::ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION => RawError::Kind(WIN32::ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION),
            WIN32::ERROR_DS_SOURCE_DOMAIN_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_SOURCE_DOMAIN_IN_FOREST),
            WIN32::ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST),
            WIN32::ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED => RawError::Kind(WIN32::ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED),
            WIN32::ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN => RawError::Kind(WIN32::ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN),
            WIN32::ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER => RawError::Kind(WIN32::ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER),
            WIN32::ERROR_DS_SRC_SID_EXISTS_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_SRC_SID_EXISTS_IN_FOREST),
            WIN32::ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH => RawError::Kind(WIN32::ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH),
            WIN32::ERROR_SAM_INIT_FAILURE => RawError::Kind(WIN32::ERROR_SAM_INIT_FAILURE),
            WIN32::ERROR_DS_DRA_SCHEMA_INFO_SHIP => RawError::Kind(WIN32::ERROR_DS_DRA_SCHEMA_INFO_SHIP),
            WIN32::ERROR_DS_DRA_SCHEMA_CONFLICT => RawError::Kind(WIN32::ERROR_DS_DRA_SCHEMA_CONFLICT),
            WIN32::ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT => RawError::Kind(WIN32::ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT),
            WIN32::ERROR_DS_DRA_OBJ_NC_MISMATCH => RawError::Kind(WIN32::ERROR_DS_DRA_OBJ_NC_MISMATCH),
            WIN32::ERROR_DS_NC_STILL_HAS_DSAS => RawError::Kind(WIN32::ERROR_DS_NC_STILL_HAS_DSAS),
            WIN32::ERROR_DS_GC_REQUIRED => RawError::Kind(WIN32::ERROR_DS_GC_REQUIRED),
            WIN32::ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY => RawError::Kind(WIN32::ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY),
            WIN32::ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS => RawError::Kind(WIN32::ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS),
            WIN32::ERROR_DS_CANT_ADD_TO_GC => RawError::Kind(WIN32::ERROR_DS_CANT_ADD_TO_GC),
            WIN32::ERROR_DS_NO_CHECKPOINT_WITH_PDC => RawError::Kind(WIN32::ERROR_DS_NO_CHECKPOINT_WITH_PDC),
            WIN32::ERROR_DS_SOURCE_AUDITING_NOT_ENABLED => RawError::Kind(WIN32::ERROR_DS_SOURCE_AUDITING_NOT_ENABLED),
            WIN32::ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC => RawError::Kind(WIN32::ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC),
            WIN32::ERROR_DS_INVALID_NAME_FOR_SPN => RawError::Kind(WIN32::ERROR_DS_INVALID_NAME_FOR_SPN),
            WIN32::ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS => RawError::Kind(WIN32::ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS),
            WIN32::ERROR_DS_UNICODEPWD_NOT_IN_QUOTES => RawError::Kind(WIN32::ERROR_DS_UNICODEPWD_NOT_IN_QUOTES),
            WIN32::ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED),
            WIN32::ERROR_DS_MUST_BE_RUN_ON_DST_DC => RawError::Kind(WIN32::ERROR_DS_MUST_BE_RUN_ON_DST_DC),
            WIN32::ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER => RawError::Kind(WIN32::ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER),
            WIN32::ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ => RawError::Kind(WIN32::ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ),
            WIN32::ERROR_DS_INIT_FAILURE_CONSOLE => RawError::Kind(WIN32::ERROR_DS_INIT_FAILURE_CONSOLE),
            WIN32::ERROR_DS_SAM_INIT_FAILURE_CONSOLE => RawError::Kind(WIN32::ERROR_DS_SAM_INIT_FAILURE_CONSOLE),
            WIN32::ERROR_DS_FOREST_VERSION_TOO_HIGH => RawError::Kind(WIN32::ERROR_DS_FOREST_VERSION_TOO_HIGH),
            WIN32::ERROR_DS_DOMAIN_VERSION_TOO_HIGH => RawError::Kind(WIN32::ERROR_DS_DOMAIN_VERSION_TOO_HIGH),
            WIN32::ERROR_DS_FOREST_VERSION_TOO_LOW => RawError::Kind(WIN32::ERROR_DS_FOREST_VERSION_TOO_LOW),
            WIN32::ERROR_DS_DOMAIN_VERSION_TOO_LOW => RawError::Kind(WIN32::ERROR_DS_DOMAIN_VERSION_TOO_LOW),
            WIN32::ERROR_DS_INCOMPATIBLE_VERSION => RawError::Kind(WIN32::ERROR_DS_INCOMPATIBLE_VERSION),
            WIN32::ERROR_DS_LOW_DSA_VERSION => RawError::Kind(WIN32::ERROR_DS_LOW_DSA_VERSION),
            WIN32::ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN => RawError::Kind(WIN32::ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN),
            WIN32::ERROR_DS_NOT_SUPPORTED_SORT_ORDER => RawError::Kind(WIN32::ERROR_DS_NOT_SUPPORTED_SORT_ORDER),
            WIN32::ERROR_DS_NAME_NOT_UNIQUE => RawError::Kind(WIN32::ERROR_DS_NAME_NOT_UNIQUE),
            WIN32::ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4 => RawError::Kind(WIN32::ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4),
            WIN32::ERROR_DS_OUT_OF_VERSION_STORE => RawError::Kind(WIN32::ERROR_DS_OUT_OF_VERSION_STORE),
            WIN32::ERROR_DS_INCOMPATIBLE_CONTROLS_USED => RawError::Kind(WIN32::ERROR_DS_INCOMPATIBLE_CONTROLS_USED),
            WIN32::ERROR_DS_NO_REF_DOMAIN => RawError::Kind(WIN32::ERROR_DS_NO_REF_DOMAIN),
            WIN32::ERROR_DS_RESERVED_LINK_ID => RawError::Kind(WIN32::ERROR_DS_RESERVED_LINK_ID),
            WIN32::ERROR_DS_LINK_ID_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_DS_LINK_ID_NOT_AVAILABLE),
            WIN32::ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER => RawError::Kind(WIN32::ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER),
            WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE => RawError::Kind(WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE),
            WIN32::ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC => RawError::Kind(WIN32::ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC),
            WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG => RawError::Kind(WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG),
            WIN32::ERROR_DS_MODIFYDN_WRONG_GRANDPARENT => RawError::Kind(WIN32::ERROR_DS_MODIFYDN_WRONG_GRANDPARENT),
            WIN32::ERROR_DS_NAME_ERROR_TRUST_REFERRAL => RawError::Kind(WIN32::ERROR_DS_NAME_ERROR_TRUST_REFERRAL),
            WIN32::ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER => RawError::Kind(WIN32::ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER),
            WIN32::ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD => RawError::Kind(WIN32::ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD),
            WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2 => RawError::Kind(WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2),
            WIN32::ERROR_DS_THREAD_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_THREAD_LIMIT_EXCEEDED),
            WIN32::ERROR_DS_NOT_CLOSEST => RawError::Kind(WIN32::ERROR_DS_NOT_CLOSEST),
            WIN32::ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF => RawError::Kind(WIN32::ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF),
            WIN32::ERROR_DS_SINGLE_USER_MODE_FAILED => RawError::Kind(WIN32::ERROR_DS_SINGLE_USER_MODE_FAILED),
            WIN32::ERROR_DS_NTDSCRIPT_SYNTAX_ERROR => RawError::Kind(WIN32::ERROR_DS_NTDSCRIPT_SYNTAX_ERROR),
            WIN32::ERROR_DS_NTDSCRIPT_PROCESS_ERROR => RawError::Kind(WIN32::ERROR_DS_NTDSCRIPT_PROCESS_ERROR),
            WIN32::ERROR_DS_DIFFERENT_REPL_EPOCHS => RawError::Kind(WIN32::ERROR_DS_DIFFERENT_REPL_EPOCHS),
            WIN32::ERROR_DS_DRS_EXTENSIONS_CHANGED => RawError::Kind(WIN32::ERROR_DS_DRS_EXTENSIONS_CHANGED),
            WIN32::ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR => RawError::Kind(WIN32::ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR),
            WIN32::ERROR_DS_NO_MSDS_INTID => RawError::Kind(WIN32::ERROR_DS_NO_MSDS_INTID),
            WIN32::ERROR_DS_DUP_MSDS_INTID => RawError::Kind(WIN32::ERROR_DS_DUP_MSDS_INTID),
            WIN32::ERROR_DS_EXISTS_IN_RDNATTID => RawError::Kind(WIN32::ERROR_DS_EXISTS_IN_RDNATTID),
            WIN32::ERROR_DS_AUTHORIZATION_FAILED => RawError::Kind(WIN32::ERROR_DS_AUTHORIZATION_FAILED),
            WIN32::ERROR_DS_INVALID_SCRIPT => RawError::Kind(WIN32::ERROR_DS_INVALID_SCRIPT),
            WIN32::ERROR_DS_REMOTE_CROSSREF_OP_FAILED => RawError::Kind(WIN32::ERROR_DS_REMOTE_CROSSREF_OP_FAILED),
            WIN32::ERROR_DS_CROSS_REF_BUSY => RawError::Kind(WIN32::ERROR_DS_CROSS_REF_BUSY),
            WIN32::ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN => RawError::Kind(WIN32::ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN),
            WIN32::ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC => RawError::Kind(WIN32::ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC),
            WIN32::ERROR_DS_DUPLICATE_ID_FOUND => RawError::Kind(WIN32::ERROR_DS_DUPLICATE_ID_FOUND),
            WIN32::ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT => RawError::Kind(WIN32::ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT),
            WIN32::ERROR_DS_GROUP_CONVERSION_ERROR => RawError::Kind(WIN32::ERROR_DS_GROUP_CONVERSION_ERROR),
            WIN32::ERROR_DS_CANT_MOVE_APP_BASIC_GROUP => RawError::Kind(WIN32::ERROR_DS_CANT_MOVE_APP_BASIC_GROUP),
            WIN32::ERROR_DS_CANT_MOVE_APP_QUERY_GROUP => RawError::Kind(WIN32::ERROR_DS_CANT_MOVE_APP_QUERY_GROUP),
            WIN32::ERROR_DS_ROLE_NOT_VERIFIED => RawError::Kind(WIN32::ERROR_DS_ROLE_NOT_VERIFIED),
            WIN32::ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL => RawError::Kind(WIN32::ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL),
            WIN32::ERROR_DS_DOMAIN_RENAME_IN_PROGRESS => RawError::Kind(WIN32::ERROR_DS_DOMAIN_RENAME_IN_PROGRESS),
            WIN32::ERROR_DS_EXISTING_AD_CHILD_NC => RawError::Kind(WIN32::ERROR_DS_EXISTING_AD_CHILD_NC),
            WIN32::ERROR_DS_REPL_LIFETIME_EXCEEDED => RawError::Kind(WIN32::ERROR_DS_REPL_LIFETIME_EXCEEDED),
            WIN32::ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER => RawError::Kind(WIN32::ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER),
            WIN32::ERROR_DS_LDAP_SEND_QUEUE_FULL => RawError::Kind(WIN32::ERROR_DS_LDAP_SEND_QUEUE_FULL),
            WIN32::ERROR_DS_DRA_OUT_SCHEDULE_WINDOW => RawError::Kind(WIN32::ERROR_DS_DRA_OUT_SCHEDULE_WINDOW),
            WIN32::ERROR_DS_POLICY_NOT_KNOWN => RawError::Kind(WIN32::ERROR_DS_POLICY_NOT_KNOWN),
            WIN32::ERROR_NO_SITE_SETTINGS_OBJECT => RawError::Kind(WIN32::ERROR_NO_SITE_SETTINGS_OBJECT),
            WIN32::ERROR_NO_SECRETS => RawError::Kind(WIN32::ERROR_NO_SECRETS),
            WIN32::ERROR_NO_WRITABLE_DC_FOUND => RawError::Kind(WIN32::ERROR_NO_WRITABLE_DC_FOUND),
            WIN32::ERROR_DS_NO_SERVER_OBJECT => RawError::Kind(WIN32::ERROR_DS_NO_SERVER_OBJECT),
            WIN32::ERROR_DS_NO_NTDSA_OBJECT => RawError::Kind(WIN32::ERROR_DS_NO_NTDSA_OBJECT),
            WIN32::ERROR_DS_NON_ASQ_SEARCH => RawError::Kind(WIN32::ERROR_DS_NON_ASQ_SEARCH),
            WIN32::ERROR_DS_AUDIT_FAILURE => RawError::Kind(WIN32::ERROR_DS_AUDIT_FAILURE),
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE => RawError::Kind(WIN32::ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE),
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG_TUPLE => RawError::Kind(WIN32::ERROR_DS_INVALID_SEARCH_FLAG_TUPLE),
            WIN32::ERROR_DS_HIERARCHY_TABLE_TOO_DEEP => RawError::Kind(WIN32::ERROR_DS_HIERARCHY_TABLE_TOO_DEEP),
            WIN32::ERROR_DS_DRA_CORRUPT_UTD_VECTOR => RawError::Kind(WIN32::ERROR_DS_DRA_CORRUPT_UTD_VECTOR),
            WIN32::ERROR_DS_DRA_SECRETS_DENIED => RawError::Kind(WIN32::ERROR_DS_DRA_SECRETS_DENIED),
            WIN32::ERROR_DS_RESERVED_MAPI_ID => RawError::Kind(WIN32::ERROR_DS_RESERVED_MAPI_ID),
            WIN32::ERROR_DS_MAPI_ID_NOT_AVAILABLE => RawError::Kind(WIN32::ERROR_DS_MAPI_ID_NOT_AVAILABLE),
            WIN32::ERROR_DS_DRA_MISSING_KRBTGT_SECRET => RawError::Kind(WIN32::ERROR_DS_DRA_MISSING_KRBTGT_SECRET),
            WIN32::ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST),
            WIN32::ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST),
            WIN32::ERROR_INVALID_USER_PRINCIPAL_NAME => RawError::Kind(WIN32::ERROR_INVALID_USER_PRINCIPAL_NAME),
            WIN32::ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS => RawError::Kind(WIN32::ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS),
            WIN32::ERROR_DS_OID_NOT_FOUND => RawError::Kind(WIN32::ERROR_DS_OID_NOT_FOUND),
            WIN32::ERROR_DS_DRA_RECYCLED_TARGET => RawError::Kind(WIN32::ERROR_DS_DRA_RECYCLED_TARGET),
            WIN32::ERROR_DS_DISALLOWED_NC_REDIRECT => RawError::Kind(WIN32::ERROR_DS_DISALLOWED_NC_REDIRECT),
            WIN32::ERROR_DS_HIGH_ADLDS_FFL => RawError::Kind(WIN32::ERROR_DS_HIGH_ADLDS_FFL),
            WIN32::ERROR_DS_HIGH_DSA_VERSION => RawError::Kind(WIN32::ERROR_DS_HIGH_DSA_VERSION),
            WIN32::ERROR_DS_LOW_ADLDS_FFL => RawError::Kind(WIN32::ERROR_DS_LOW_ADLDS_FFL),
            WIN32::ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION => RawError::Kind(WIN32::ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION),
            WIN32::ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED => RawError::Kind(WIN32::ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED),
            WIN32::ERROR_INCORRECT_ACCOUNT_TYPE => RawError::Kind(WIN32::ERROR_INCORRECT_ACCOUNT_TYPE),
            WIN32::ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST),
            WIN32::ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST => RawError::Kind(WIN32::ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST),
            WIN32::ERROR_DS_MISSING_FOREST_TRUST => RawError::Kind(WIN32::ERROR_DS_MISSING_FOREST_TRUST),
            WIN32::ERROR_DS_VALUE_KEY_NOT_UNIQUE => RawError::Kind(WIN32::ERROR_DS_VALUE_KEY_NOT_UNIQUE),
            WIN32::ERROR_WEAK_WHFBKEY_BLOCKED => RawError::Kind(WIN32::ERROR_WEAK_WHFBKEY_BLOCKED),
            WIN32::ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD => RawError::Kind(WIN32::ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD),
            WIN32::ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED),
            WIN32::ERROR_POLICY_CONTROLLED_ACCOUNT => RawError::Kind(WIN32::ERROR_POLICY_CONTROLLED_ACCOUNT),
            WIN32::ERROR_LAPS_LEGACY_SCHEMA_MISSING => RawError::Kind(WIN32::ERROR_LAPS_LEGACY_SCHEMA_MISSING),
            WIN32::ERROR_LAPS_SCHEMA_MISSING => RawError::Kind(WIN32::ERROR_LAPS_SCHEMA_MISSING),
            WIN32::ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL => RawError::Kind(WIN32::ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL),
            WIN32::DNS_ERROR_RCODE_FORMAT_ERROR => RawError::Kind(WIN32::DNS_ERROR_RCODE_FORMAT_ERROR),
            WIN32::DNS_ERROR_RCODE_SERVER_FAILURE => RawError::Kind(WIN32::DNS_ERROR_RCODE_SERVER_FAILURE),
            WIN32::DNS_ERROR_RCODE_NAME_ERROR => RawError::Kind(WIN32::DNS_ERROR_RCODE_NAME_ERROR),
            WIN32::DNS_ERROR_RCODE_NOT_IMPLEMENTED => RawError::Kind(WIN32::DNS_ERROR_RCODE_NOT_IMPLEMENTED),
            WIN32::DNS_ERROR_RCODE_REFUSED => RawError::Kind(WIN32::DNS_ERROR_RCODE_REFUSED),
            WIN32::DNS_ERROR_RCODE_YXDOMAIN => RawError::Kind(WIN32::DNS_ERROR_RCODE_YXDOMAIN),
            WIN32::DNS_ERROR_RCODE_YXRRSET => RawError::Kind(WIN32::DNS_ERROR_RCODE_YXRRSET),
            WIN32::DNS_ERROR_RCODE_NXRRSET => RawError::Kind(WIN32::DNS_ERROR_RCODE_NXRRSET),
            WIN32::DNS_ERROR_RCODE_NOTAUTH => RawError::Kind(WIN32::DNS_ERROR_RCODE_NOTAUTH),
            WIN32::DNS_ERROR_RCODE_NOTZONE => RawError::Kind(WIN32::DNS_ERROR_RCODE_NOTZONE),
            WIN32::DNS_ERROR_RCODE_BADSIG => RawError::Kind(WIN32::DNS_ERROR_RCODE_BADSIG),
            WIN32::DNS_ERROR_RCODE_BADKEY => RawError::Kind(WIN32::DNS_ERROR_RCODE_BADKEY),
            WIN32::DNS_ERROR_RCODE_BADTIME => RawError::Kind(WIN32::DNS_ERROR_RCODE_BADTIME),
            WIN32::DNS_ERROR_KEYMASTER_REQUIRED => RawError::Kind(WIN32::DNS_ERROR_KEYMASTER_REQUIRED),
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE),
            WIN32::DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1 => RawError::Kind(WIN32::DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1),
            WIN32::DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS => RawError::Kind(WIN32::DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS),
            WIN32::DNS_ERROR_UNSUPPORTED_ALGORITHM => RawError::Kind(WIN32::DNS_ERROR_UNSUPPORTED_ALGORITHM),
            WIN32::DNS_ERROR_INVALID_KEY_SIZE => RawError::Kind(WIN32::DNS_ERROR_INVALID_KEY_SIZE),
            WIN32::DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE => RawError::Kind(WIN32::DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE),
            WIN32::DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION => RawError::Kind(WIN32::DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION),
            WIN32::DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR => RawError::Kind(WIN32::DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR),
            WIN32::DNS_ERROR_UNEXPECTED_CNG_ERROR => RawError::Kind(WIN32::DNS_ERROR_UNEXPECTED_CNG_ERROR),
            WIN32::DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION => RawError::Kind(WIN32::DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION),
            WIN32::DNS_ERROR_KSP_NOT_ACCESSIBLE => RawError::Kind(WIN32::DNS_ERROR_KSP_NOT_ACCESSIBLE),
            WIN32::DNS_ERROR_TOO_MANY_SKDS => RawError::Kind(WIN32::DNS_ERROR_TOO_MANY_SKDS),
            WIN32::DNS_ERROR_INVALID_ROLLOVER_PERIOD => RawError::Kind(WIN32::DNS_ERROR_INVALID_ROLLOVER_PERIOD),
            WIN32::DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET => RawError::Kind(WIN32::DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET),
            WIN32::DNS_ERROR_ROLLOVER_IN_PROGRESS => RawError::Kind(WIN32::DNS_ERROR_ROLLOVER_IN_PROGRESS),
            WIN32::DNS_ERROR_STANDBY_KEY_NOT_PRESENT => RawError::Kind(WIN32::DNS_ERROR_STANDBY_KEY_NOT_PRESENT),
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ZSK => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_ON_ZSK),
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD),
            WIN32::DNS_ERROR_ROLLOVER_ALREADY_QUEUED => RawError::Kind(WIN32::DNS_ERROR_ROLLOVER_ALREADY_QUEUED),
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE),
            WIN32::DNS_ERROR_BAD_KEYMASTER => RawError::Kind(WIN32::DNS_ERROR_BAD_KEYMASTER),
            WIN32::DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD => RawError::Kind(WIN32::DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD),
            WIN32::DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT => RawError::Kind(WIN32::DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT),
            WIN32::DNS_ERROR_DNSSEC_IS_DISABLED => RawError::Kind(WIN32::DNS_ERROR_DNSSEC_IS_DISABLED),
            WIN32::DNS_ERROR_INVALID_XML => RawError::Kind(WIN32::DNS_ERROR_INVALID_XML),
            WIN32::DNS_ERROR_NO_VALID_TRUST_ANCHORS => RawError::Kind(WIN32::DNS_ERROR_NO_VALID_TRUST_ANCHORS),
            WIN32::DNS_ERROR_ROLLOVER_NOT_POKEABLE => RawError::Kind(WIN32::DNS_ERROR_ROLLOVER_NOT_POKEABLE),
            WIN32::DNS_ERROR_NSEC3_NAME_COLLISION => RawError::Kind(WIN32::DNS_ERROR_NSEC3_NAME_COLLISION),
            WIN32::DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1 => RawError::Kind(WIN32::DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1),
            WIN32::DNS_INFO_NO_RECORDS => RawError::Kind(WIN32::DNS_INFO_NO_RECORDS),
            WIN32::DNS_ERROR_BAD_PACKET => RawError::Kind(WIN32::DNS_ERROR_BAD_PACKET),
            WIN32::DNS_ERROR_NO_PACKET => RawError::Kind(WIN32::DNS_ERROR_NO_PACKET),
            WIN32::DNS_ERROR_RCODE => RawError::Kind(WIN32::DNS_ERROR_RCODE),
            WIN32::DNS_ERROR_UNSECURE_PACKET => RawError::Kind(WIN32::DNS_ERROR_UNSECURE_PACKET),
            WIN32::DNS_REQUEST_PENDING => RawError::Kind(WIN32::DNS_REQUEST_PENDING),
            WIN32::DNS_ERROR_INVALID_TYPE => RawError::Kind(WIN32::DNS_ERROR_INVALID_TYPE),
            WIN32::DNS_ERROR_INVALID_IP_ADDRESS => RawError::Kind(WIN32::DNS_ERROR_INVALID_IP_ADDRESS),
            WIN32::DNS_ERROR_INVALID_PROPERTY => RawError::Kind(WIN32::DNS_ERROR_INVALID_PROPERTY),
            WIN32::DNS_ERROR_TRY_AGAIN_LATER => RawError::Kind(WIN32::DNS_ERROR_TRY_AGAIN_LATER),
            WIN32::DNS_ERROR_NOT_UNIQUE => RawError::Kind(WIN32::DNS_ERROR_NOT_UNIQUE),
            WIN32::DNS_ERROR_NON_RFC_NAME => RawError::Kind(WIN32::DNS_ERROR_NON_RFC_NAME),
            WIN32::DNS_STATUS_FQDN => RawError::Kind(WIN32::DNS_STATUS_FQDN),
            WIN32::DNS_STATUS_DOTTED_NAME => RawError::Kind(WIN32::DNS_STATUS_DOTTED_NAME),
            WIN32::DNS_STATUS_SINGLE_PART_NAME => RawError::Kind(WIN32::DNS_STATUS_SINGLE_PART_NAME),
            WIN32::DNS_ERROR_INVALID_NAME_CHAR => RawError::Kind(WIN32::DNS_ERROR_INVALID_NAME_CHAR),
            WIN32::DNS_ERROR_NUMERIC_NAME => RawError::Kind(WIN32::DNS_ERROR_NUMERIC_NAME),
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER),
            WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION),
            WIN32::DNS_ERROR_CANNOT_FIND_ROOT_HINTS => RawError::Kind(WIN32::DNS_ERROR_CANNOT_FIND_ROOT_HINTS),
            WIN32::DNS_ERROR_INCONSISTENT_ROOT_HINTS => RawError::Kind(WIN32::DNS_ERROR_INCONSISTENT_ROOT_HINTS),
            WIN32::DNS_ERROR_DWORD_VALUE_TOO_SMALL => RawError::Kind(WIN32::DNS_ERROR_DWORD_VALUE_TOO_SMALL),
            WIN32::DNS_ERROR_DWORD_VALUE_TOO_LARGE => RawError::Kind(WIN32::DNS_ERROR_DWORD_VALUE_TOO_LARGE),
            WIN32::DNS_ERROR_BACKGROUND_LOADING => RawError::Kind(WIN32::DNS_ERROR_BACKGROUND_LOADING),
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_RODC => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_ON_RODC),
            WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DNAME => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DNAME),
            WIN32::DNS_ERROR_DELEGATION_REQUIRED => RawError::Kind(WIN32::DNS_ERROR_DELEGATION_REQUIRED),
            WIN32::DNS_ERROR_INVALID_POLICY_TABLE => RawError::Kind(WIN32::DNS_ERROR_INVALID_POLICY_TABLE),
            WIN32::DNS_ERROR_ADDRESS_REQUIRED => RawError::Kind(WIN32::DNS_ERROR_ADDRESS_REQUIRED),
            WIN32::DNS_ERROR_ZONE_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_ZONE_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_NO_ZONE_INFO => RawError::Kind(WIN32::DNS_ERROR_NO_ZONE_INFO),
            WIN32::DNS_ERROR_INVALID_ZONE_OPERATION => RawError::Kind(WIN32::DNS_ERROR_INVALID_ZONE_OPERATION),
            WIN32::DNS_ERROR_ZONE_CONFIGURATION_ERROR => RawError::Kind(WIN32::DNS_ERROR_ZONE_CONFIGURATION_ERROR),
            WIN32::DNS_ERROR_ZONE_HAS_NO_SOA_RECORD => RawError::Kind(WIN32::DNS_ERROR_ZONE_HAS_NO_SOA_RECORD),
            WIN32::DNS_ERROR_ZONE_HAS_NO_NS_RECORDS => RawError::Kind(WIN32::DNS_ERROR_ZONE_HAS_NO_NS_RECORDS),
            WIN32::DNS_ERROR_ZONE_LOCKED => RawError::Kind(WIN32::DNS_ERROR_ZONE_LOCKED),
            WIN32::DNS_ERROR_ZONE_CREATION_FAILED => RawError::Kind(WIN32::DNS_ERROR_ZONE_CREATION_FAILED),
            WIN32::DNS_ERROR_ZONE_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_ZONE_ALREADY_EXISTS),
            WIN32::DNS_ERROR_AUTOZONE_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_AUTOZONE_ALREADY_EXISTS),
            WIN32::DNS_ERROR_INVALID_ZONE_TYPE => RawError::Kind(WIN32::DNS_ERROR_INVALID_ZONE_TYPE),
            WIN32::DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP => RawError::Kind(WIN32::DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP),
            WIN32::DNS_ERROR_ZONE_NOT_SECONDARY => RawError::Kind(WIN32::DNS_ERROR_ZONE_NOT_SECONDARY),
            WIN32::DNS_ERROR_NEED_SECONDARY_ADDRESSES => RawError::Kind(WIN32::DNS_ERROR_NEED_SECONDARY_ADDRESSES),
            WIN32::DNS_ERROR_WINS_INIT_FAILED => RawError::Kind(WIN32::DNS_ERROR_WINS_INIT_FAILED),
            WIN32::DNS_ERROR_NEED_WINS_SERVERS => RawError::Kind(WIN32::DNS_ERROR_NEED_WINS_SERVERS),
            WIN32::DNS_ERROR_NBSTAT_INIT_FAILED => RawError::Kind(WIN32::DNS_ERROR_NBSTAT_INIT_FAILED),
            WIN32::DNS_ERROR_SOA_DELETE_INVALID => RawError::Kind(WIN32::DNS_ERROR_SOA_DELETE_INVALID),
            WIN32::DNS_ERROR_FORWARDER_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_FORWARDER_ALREADY_EXISTS),
            WIN32::DNS_ERROR_ZONE_REQUIRES_MASTER_IP => RawError::Kind(WIN32::DNS_ERROR_ZONE_REQUIRES_MASTER_IP),
            WIN32::DNS_ERROR_ZONE_IS_SHUTDOWN => RawError::Kind(WIN32::DNS_ERROR_ZONE_IS_SHUTDOWN),
            WIN32::DNS_ERROR_ZONE_LOCKED_FOR_SIGNING => RawError::Kind(WIN32::DNS_ERROR_ZONE_LOCKED_FOR_SIGNING),
            WIN32::DNS_ERROR_PRIMARY_REQUIRES_DATAFILE => RawError::Kind(WIN32::DNS_ERROR_PRIMARY_REQUIRES_DATAFILE),
            WIN32::DNS_ERROR_INVALID_DATAFILE_NAME => RawError::Kind(WIN32::DNS_ERROR_INVALID_DATAFILE_NAME),
            WIN32::DNS_ERROR_DATAFILE_OPEN_FAILURE => RawError::Kind(WIN32::DNS_ERROR_DATAFILE_OPEN_FAILURE),
            WIN32::DNS_ERROR_FILE_WRITEBACK_FAILED => RawError::Kind(WIN32::DNS_ERROR_FILE_WRITEBACK_FAILED),
            WIN32::DNS_ERROR_DATAFILE_PARSING => RawError::Kind(WIN32::DNS_ERROR_DATAFILE_PARSING),
            WIN32::DNS_ERROR_RECORD_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_RECORD_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_RECORD_FORMAT => RawError::Kind(WIN32::DNS_ERROR_RECORD_FORMAT),
            WIN32::DNS_ERROR_NODE_CREATION_FAILED => RawError::Kind(WIN32::DNS_ERROR_NODE_CREATION_FAILED),
            WIN32::DNS_ERROR_UNKNOWN_RECORD_TYPE => RawError::Kind(WIN32::DNS_ERROR_UNKNOWN_RECORD_TYPE),
            WIN32::DNS_ERROR_RECORD_TIMED_OUT => RawError::Kind(WIN32::DNS_ERROR_RECORD_TIMED_OUT),
            WIN32::DNS_ERROR_NAME_NOT_IN_ZONE => RawError::Kind(WIN32::DNS_ERROR_NAME_NOT_IN_ZONE),
            WIN32::DNS_ERROR_CNAME_LOOP => RawError::Kind(WIN32::DNS_ERROR_CNAME_LOOP),
            WIN32::DNS_ERROR_NODE_IS_CNAME => RawError::Kind(WIN32::DNS_ERROR_NODE_IS_CNAME),
            WIN32::DNS_ERROR_CNAME_COLLISION => RawError::Kind(WIN32::DNS_ERROR_CNAME_COLLISION),
            WIN32::DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT => RawError::Kind(WIN32::DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT),
            WIN32::DNS_ERROR_RECORD_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_RECORD_ALREADY_EXISTS),
            WIN32::DNS_ERROR_SECONDARY_DATA => RawError::Kind(WIN32::DNS_ERROR_SECONDARY_DATA),
            WIN32::DNS_ERROR_NO_CREATE_CACHE_DATA => RawError::Kind(WIN32::DNS_ERROR_NO_CREATE_CACHE_DATA),
            WIN32::DNS_ERROR_NAME_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_NAME_DOES_NOT_EXIST),
            WIN32::DNS_WARNING_PTR_CREATE_FAILED => RawError::Kind(WIN32::DNS_WARNING_PTR_CREATE_FAILED),
            WIN32::DNS_WARNING_DOMAIN_UNDELETED => RawError::Kind(WIN32::DNS_WARNING_DOMAIN_UNDELETED),
            WIN32::DNS_ERROR_DS_UNAVAILABLE => RawError::Kind(WIN32::DNS_ERROR_DS_UNAVAILABLE),
            WIN32::DNS_ERROR_DS_ZONE_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_DS_ZONE_ALREADY_EXISTS),
            WIN32::DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE => RawError::Kind(WIN32::DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE),
            WIN32::DNS_ERROR_NODE_IS_DNAME => RawError::Kind(WIN32::DNS_ERROR_NODE_IS_DNAME),
            WIN32::DNS_ERROR_DNAME_COLLISION => RawError::Kind(WIN32::DNS_ERROR_DNAME_COLLISION),
            WIN32::DNS_ERROR_ALIAS_LOOP => RawError::Kind(WIN32::DNS_ERROR_ALIAS_LOOP),
            WIN32::DNS_INFO_AXFR_COMPLETE => RawError::Kind(WIN32::DNS_INFO_AXFR_COMPLETE),
            WIN32::DNS_ERROR_AXFR => RawError::Kind(WIN32::DNS_ERROR_AXFR),
            WIN32::DNS_INFO_ADDED_LOCAL_WINS => RawError::Kind(WIN32::DNS_INFO_ADDED_LOCAL_WINS),
            WIN32::DNS_STATUS_CONTINUE_NEEDED => RawError::Kind(WIN32::DNS_STATUS_CONTINUE_NEEDED),
            WIN32::DNS_ERROR_NO_TCPIP => RawError::Kind(WIN32::DNS_ERROR_NO_TCPIP),
            WIN32::DNS_ERROR_NO_DNS_SERVERS => RawError::Kind(WIN32::DNS_ERROR_NO_DNS_SERVERS),
            WIN32::DNS_ERROR_DP_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_DP_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_DP_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_DP_ALREADY_EXISTS),
            WIN32::DNS_ERROR_DP_NOT_ENLISTED => RawError::Kind(WIN32::DNS_ERROR_DP_NOT_ENLISTED),
            WIN32::DNS_ERROR_DP_ALREADY_ENLISTED => RawError::Kind(WIN32::DNS_ERROR_DP_ALREADY_ENLISTED),
            WIN32::DNS_ERROR_DP_NOT_AVAILABLE => RawError::Kind(WIN32::DNS_ERROR_DP_NOT_AVAILABLE),
            WIN32::DNS_ERROR_DP_FSMO_ERROR => RawError::Kind(WIN32::DNS_ERROR_DP_FSMO_ERROR),
            WIN32::DNS_ERROR_RRL_NOT_ENABLED => RawError::Kind(WIN32::DNS_ERROR_RRL_NOT_ENABLED),
            WIN32::DNS_ERROR_RRL_INVALID_WINDOW_SIZE => RawError::Kind(WIN32::DNS_ERROR_RRL_INVALID_WINDOW_SIZE),
            WIN32::DNS_ERROR_RRL_INVALID_IPV4_PREFIX => RawError::Kind(WIN32::DNS_ERROR_RRL_INVALID_IPV4_PREFIX),
            WIN32::DNS_ERROR_RRL_INVALID_IPV6_PREFIX => RawError::Kind(WIN32::DNS_ERROR_RRL_INVALID_IPV6_PREFIX),
            WIN32::DNS_ERROR_RRL_INVALID_TC_RATE => RawError::Kind(WIN32::DNS_ERROR_RRL_INVALID_TC_RATE),
            WIN32::DNS_ERROR_RRL_INVALID_LEAK_RATE => RawError::Kind(WIN32::DNS_ERROR_RRL_INVALID_LEAK_RATE),
            WIN32::DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE => RawError::Kind(WIN32::DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE),
            WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS),
            WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_VIRTUALIZATION_TREE_LOCKED => RawError::Kind(WIN32::DNS_ERROR_VIRTUALIZATION_TREE_LOCKED),
            WIN32::DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME => RawError::Kind(WIN32::DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME),
            WIN32::DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE => RawError::Kind(WIN32::DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE),
            WIN32::DNS_ERROR_ZONESCOPE_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_ZONESCOPE_ALREADY_EXISTS),
            WIN32::DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_DEFAULT_ZONESCOPE => RawError::Kind(WIN32::DNS_ERROR_DEFAULT_ZONESCOPE),
            WIN32::DNS_ERROR_INVALID_ZONESCOPE_NAME => RawError::Kind(WIN32::DNS_ERROR_INVALID_ZONESCOPE_NAME),
            WIN32::DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES => RawError::Kind(WIN32::DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES),
            WIN32::DNS_ERROR_LOAD_ZONESCOPE_FAILED => RawError::Kind(WIN32::DNS_ERROR_LOAD_ZONESCOPE_FAILED),
            WIN32::DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED => RawError::Kind(WIN32::DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED),
            WIN32::DNS_ERROR_INVALID_SCOPE_NAME => RawError::Kind(WIN32::DNS_ERROR_INVALID_SCOPE_NAME),
            WIN32::DNS_ERROR_SCOPE_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_SCOPE_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_DEFAULT_SCOPE => RawError::Kind(WIN32::DNS_ERROR_DEFAULT_SCOPE),
            WIN32::DNS_ERROR_INVALID_SCOPE_OPERATION => RawError::Kind(WIN32::DNS_ERROR_INVALID_SCOPE_OPERATION),
            WIN32::DNS_ERROR_SCOPE_LOCKED => RawError::Kind(WIN32::DNS_ERROR_SCOPE_LOCKED),
            WIN32::DNS_ERROR_SCOPE_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_SCOPE_ALREADY_EXISTS),
            WIN32::DNS_ERROR_POLICY_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_POLICY_ALREADY_EXISTS),
            WIN32::DNS_ERROR_POLICY_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_POLICY_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA),
            WIN32::DNS_ERROR_POLICY_INVALID_SETTINGS => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_SETTINGS),
            WIN32::DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED => RawError::Kind(WIN32::DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED),
            WIN32::DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS),
            WIN32::DNS_ERROR_SUBNET_DOES_NOT_EXIST => RawError::Kind(WIN32::DNS_ERROR_SUBNET_DOES_NOT_EXIST),
            WIN32::DNS_ERROR_SUBNET_ALREADY_EXISTS => RawError::Kind(WIN32::DNS_ERROR_SUBNET_ALREADY_EXISTS),
            WIN32::DNS_ERROR_POLICY_LOCKED => RawError::Kind(WIN32::DNS_ERROR_POLICY_LOCKED),
            WIN32::DNS_ERROR_POLICY_INVALID_WEIGHT => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_WEIGHT),
            WIN32::DNS_ERROR_POLICY_INVALID_NAME => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_NAME),
            WIN32::DNS_ERROR_POLICY_MISSING_CRITERIA => RawError::Kind(WIN32::DNS_ERROR_POLICY_MISSING_CRITERIA),
            WIN32::DNS_ERROR_INVALID_CLIENT_SUBNET_NAME => RawError::Kind(WIN32::DNS_ERROR_INVALID_CLIENT_SUBNET_NAME),
            WIN32::DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID => RawError::Kind(WIN32::DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID),
            WIN32::DNS_ERROR_POLICY_SCOPE_MISSING => RawError::Kind(WIN32::DNS_ERROR_POLICY_SCOPE_MISSING),
            WIN32::DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED => RawError::Kind(WIN32::DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED),
            WIN32::DNS_ERROR_SERVERSCOPE_IS_REFERENCED => RawError::Kind(WIN32::DNS_ERROR_SERVERSCOPE_IS_REFERENCED),
            WIN32::DNS_ERROR_ZONESCOPE_IS_REFERENCED => RawError::Kind(WIN32::DNS_ERROR_ZONESCOPE_IS_REFERENCED),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE),
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY => RawError::Kind(WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY),
            WIN32::WSAEINTR => RawError::Kind(WIN32::WSAEINTR),
            WIN32::WSAEBADF => RawError::Kind(WIN32::WSAEBADF),
            WIN32::WSAEACCES => RawError::Kind(WIN32::WSAEACCES),
            WIN32::WSAEFAULT => RawError::Kind(WIN32::WSAEFAULT),
            WIN32::WSAEINVAL => RawError::Kind(WIN32::WSAEINVAL),
            WIN32::WSAEMFILE => RawError::Kind(WIN32::WSAEMFILE),
            WIN32::WSAEWOULDBLOCK => RawError::Kind(WIN32::WSAEWOULDBLOCK),
            WIN32::WSAEINPROGRESS => RawError::Kind(WIN32::WSAEINPROGRESS),
            WIN32::WSAEALREADY => RawError::Kind(WIN32::WSAEALREADY),
            WIN32::WSAENOTSOCK => RawError::Kind(WIN32::WSAENOTSOCK),
            WIN32::WSAEDESTADDRREQ => RawError::Kind(WIN32::WSAEDESTADDRREQ),
            WIN32::WSAEMSGSIZE => RawError::Kind(WIN32::WSAEMSGSIZE),
            WIN32::WSAEPROTOTYPE => RawError::Kind(WIN32::WSAEPROTOTYPE),
            WIN32::WSAENOPROTOOPT => RawError::Kind(WIN32::WSAENOPROTOOPT),
            WIN32::WSAEPROTONOSUPPORT => RawError::Kind(WIN32::WSAEPROTONOSUPPORT),
            WIN32::WSAESOCKTNOSUPPORT => RawError::Kind(WIN32::WSAESOCKTNOSUPPORT),
            WIN32::WSAEOPNOTSUPP => RawError::Kind(WIN32::WSAEOPNOTSUPP),
            WIN32::WSAEPFNOSUPPORT => RawError::Kind(WIN32::WSAEPFNOSUPPORT),
            WIN32::WSAEAFNOSUPPORT => RawError::Kind(WIN32::WSAEAFNOSUPPORT),
            WIN32::WSAEADDRINUSE => RawError::Kind(WIN32::WSAEADDRINUSE),
            WIN32::WSAEADDRNOTAVAIL => RawError::Kind(WIN32::WSAEADDRNOTAVAIL),
            WIN32::WSAENETDOWN => RawError::Kind(WIN32::WSAENETDOWN),
            WIN32::WSAENETUNREACH => RawError::Kind(WIN32::WSAENETUNREACH),
            WIN32::WSAENETRESET => RawError::Kind(WIN32::WSAENETRESET),
            WIN32::WSAECONNABORTED => RawError::Kind(WIN32::WSAECONNABORTED),
            WIN32::WSAECONNRESET => RawError::Kind(WIN32::WSAECONNRESET),
            WIN32::WSAENOBUFS => RawError::Kind(WIN32::WSAENOBUFS),
            WIN32::WSAEISCONN => RawError::Kind(WIN32::WSAEISCONN),
            WIN32::WSAENOTCONN => RawError::Kind(WIN32::WSAENOTCONN),
            WIN32::WSAESHUTDOWN => RawError::Kind(WIN32::WSAESHUTDOWN),
            WIN32::WSAETOOMANYREFS => RawError::Kind(WIN32::WSAETOOMANYREFS),
            WIN32::WSAETIMEDOUT => RawError::Kind(WIN32::WSAETIMEDOUT),
            WIN32::WSAECONNREFUSED => RawError::Kind(WIN32::WSAECONNREFUSED),
            WIN32::WSAELOOP => RawError::Kind(WIN32::WSAELOOP),
            WIN32::WSAENAMETOOLONG => RawError::Kind(WIN32::WSAENAMETOOLONG),
            WIN32::WSAEHOSTDOWN => RawError::Kind(WIN32::WSAEHOSTDOWN),
            WIN32::WSAEHOSTUNREACH => RawError::Kind(WIN32::WSAEHOSTUNREACH),
            WIN32::WSAENOTEMPTY => RawError::Kind(WIN32::WSAENOTEMPTY),
            WIN32::WSAEPROCLIM => RawError::Kind(WIN32::WSAEPROCLIM),
            WIN32::WSAEUSERS => RawError::Kind(WIN32::WSAEUSERS),
            WIN32::WSAEDQUOT => RawError::Kind(WIN32::WSAEDQUOT),
            WIN32::WSAESTALE => RawError::Kind(WIN32::WSAESTALE),
            WIN32::WSAEREMOTE => RawError::Kind(WIN32::WSAEREMOTE),
            WIN32::WSASYSNOTREADY => RawError::Kind(WIN32::WSASYSNOTREADY),
            WIN32::WSAVERNOTSUPPORTED => RawError::Kind(WIN32::WSAVERNOTSUPPORTED),
            WIN32::WSANOTINITIALISED => RawError::Kind(WIN32::WSANOTINITIALISED),
            WIN32::WSAEDISCON => RawError::Kind(WIN32::WSAEDISCON),
            WIN32::WSAENOMORE => RawError::Kind(WIN32::WSAENOMORE),
            WIN32::WSAECANCELLED => RawError::Kind(WIN32::WSAECANCELLED),
            WIN32::WSAEINVALIDPROCTABLE => RawError::Kind(WIN32::WSAEINVALIDPROCTABLE),
            WIN32::WSAEINVALIDPROVIDER => RawError::Kind(WIN32::WSAEINVALIDPROVIDER),
            WIN32::WSAEPROVIDERFAILEDINIT => RawError::Kind(WIN32::WSAEPROVIDERFAILEDINIT),
            WIN32::WSASYSCALLFAILURE => RawError::Kind(WIN32::WSASYSCALLFAILURE),
            WIN32::WSASERVICE_NOT_FOUND => RawError::Kind(WIN32::WSASERVICE_NOT_FOUND),
            WIN32::WSATYPE_NOT_FOUND => RawError::Kind(WIN32::WSATYPE_NOT_FOUND),
            WIN32::WSA_E_NO_MORE => RawError::Kind(WIN32::WSA_E_NO_MORE),
            WIN32::WSA_E_CANCELLED => RawError::Kind(WIN32::WSA_E_CANCELLED),
            WIN32::WSAEREFUSED => RawError::Kind(WIN32::WSAEREFUSED),
            WIN32::WSAHOST_NOT_FOUND => RawError::Kind(WIN32::WSAHOST_NOT_FOUND),
            WIN32::WSATRY_AGAIN => RawError::Kind(WIN32::WSATRY_AGAIN),
            WIN32::WSANO_RECOVERY => RawError::Kind(WIN32::WSANO_RECOVERY),
            WIN32::WSANO_DATA => RawError::Kind(WIN32::WSANO_DATA),
            WIN32::WSA_QOS_RECEIVERS => RawError::Kind(WIN32::WSA_QOS_RECEIVERS),
            WIN32::WSA_QOS_SENDERS => RawError::Kind(WIN32::WSA_QOS_SENDERS),
            WIN32::WSA_QOS_NO_SENDERS => RawError::Kind(WIN32::WSA_QOS_NO_SENDERS),
            WIN32::WSA_QOS_NO_RECEIVERS => RawError::Kind(WIN32::WSA_QOS_NO_RECEIVERS),
            WIN32::WSA_QOS_REQUEST_CONFIRMED => RawError::Kind(WIN32::WSA_QOS_REQUEST_CONFIRMED),
            WIN32::WSA_QOS_ADMISSION_FAILURE => RawError::Kind(WIN32::WSA_QOS_ADMISSION_FAILURE),
            WIN32::WSA_QOS_POLICY_FAILURE => RawError::Kind(WIN32::WSA_QOS_POLICY_FAILURE),
            WIN32::WSA_QOS_BAD_STYLE => RawError::Kind(WIN32::WSA_QOS_BAD_STYLE),
            WIN32::WSA_QOS_BAD_OBJECT => RawError::Kind(WIN32::WSA_QOS_BAD_OBJECT),
            WIN32::WSA_QOS_TRAFFIC_CTRL_ERROR => RawError::Kind(WIN32::WSA_QOS_TRAFFIC_CTRL_ERROR),
            WIN32::WSA_QOS_GENERIC_ERROR => RawError::Kind(WIN32::WSA_QOS_GENERIC_ERROR),
            WIN32::WSA_QOS_ESERVICETYPE => RawError::Kind(WIN32::WSA_QOS_ESERVICETYPE),
            WIN32::WSA_QOS_EFLOWSPEC => RawError::Kind(WIN32::WSA_QOS_EFLOWSPEC),
            WIN32::WSA_QOS_EPROVSPECBUF => RawError::Kind(WIN32::WSA_QOS_EPROVSPECBUF),
            WIN32::WSA_QOS_EFILTERSTYLE => RawError::Kind(WIN32::WSA_QOS_EFILTERSTYLE),
            WIN32::WSA_QOS_EFILTERTYPE => RawError::Kind(WIN32::WSA_QOS_EFILTERTYPE),
            WIN32::WSA_QOS_EFILTERCOUNT => RawError::Kind(WIN32::WSA_QOS_EFILTERCOUNT),
            WIN32::WSA_QOS_EOBJLENGTH => RawError::Kind(WIN32::WSA_QOS_EOBJLENGTH),
            WIN32::WSA_QOS_EFLOWCOUNT => RawError::Kind(WIN32::WSA_QOS_EFLOWCOUNT),
            WIN32::WSA_QOS_EUNKOWNPSOBJ => RawError::Kind(WIN32::WSA_QOS_EUNKOWNPSOBJ),
            WIN32::WSA_QOS_EPOLICYOBJ => RawError::Kind(WIN32::WSA_QOS_EPOLICYOBJ),
            WIN32::WSA_QOS_EFLOWDESC => RawError::Kind(WIN32::WSA_QOS_EFLOWDESC),
            WIN32::WSA_QOS_EPSFLOWSPEC => RawError::Kind(WIN32::WSA_QOS_EPSFLOWSPEC),
            WIN32::WSA_QOS_EPSFILTERSPEC => RawError::Kind(WIN32::WSA_QOS_EPSFILTERSPEC),
            WIN32::WSA_QOS_ESDMODEOBJ => RawError::Kind(WIN32::WSA_QOS_ESDMODEOBJ),
            WIN32::WSA_QOS_ESHAPERATEOBJ => RawError::Kind(WIN32::WSA_QOS_ESHAPERATEOBJ),
            WIN32::WSA_QOS_RESERVED_PETYPE => RawError::Kind(WIN32::WSA_QOS_RESERVED_PETYPE),
            WIN32::WSA_SECURE_HOST_NOT_FOUND => RawError::Kind(WIN32::WSA_SECURE_HOST_NOT_FOUND),
            WIN32::WSA_IPSEC_NAME_POLICY_ERROR => RawError::Kind(WIN32::WSA_IPSEC_NAME_POLICY_ERROR),
            WIN32::PEER_E_CLOUD_NOT_FOUND => RawError::Kind(WIN32::PEER_E_CLOUD_NOT_FOUND),
            WIN32::PEER_E_CLOUD_DISABLED => RawError::Kind(WIN32::PEER_E_CLOUD_DISABLED),
            WIN32::PEER_E_INVALID_IDENTITY => RawError::Kind(WIN32::PEER_E_INVALID_IDENTITY),
            WIN32::PEER_E_TOO_MUCH_LOAD => RawError::Kind(WIN32::PEER_E_TOO_MUCH_LOAD),
            WIN32::PEER_E_CLOUD_IS_SEARCH_ONLY => RawError::Kind(WIN32::PEER_E_CLOUD_IS_SEARCH_ONLY),
            WIN32::PEER_E_CLIENT_INVALID_COMPARTMENT_ID => RawError::Kind(WIN32::PEER_E_CLIENT_INVALID_COMPARTMENT_ID),
            WIN32::PEER_E_DUPLICATE_PEER_NAME => RawError::Kind(WIN32::PEER_E_DUPLICATE_PEER_NAME),
            WIN32::PEER_E_CLOUD_IS_DEAD => RawError::Kind(WIN32::PEER_E_CLOUD_IS_DEAD),
            WIN32::ERROR_INTERNET_ => RawError::Kind(WIN32::ERROR_INTERNET_),
            WIN32::WININET_E_OUT_OF_HANDLES => RawError::Kind(WIN32::WININET_E_OUT_OF_HANDLES),
            WIN32::ERROR_INTERNET_OUT_OF_HANDLES => RawError::Kind(WIN32::ERROR_INTERNET_OUT_OF_HANDLES),
            WIN32::WININET_E_TIMEOUT => RawError::Kind(WIN32::WININET_E_TIMEOUT),
            WIN32::ERROR_INTERNET_TIMEOUT => RawError::Kind(WIN32::ERROR_INTERNET_TIMEOUT),
            WIN32::ERROR_WINHTTP_TIMEOUT => RawError::Kind(WIN32::ERROR_WINHTTP_TIMEOUT),
            WIN32::WININET_E_EXTENDED_ERROR => RawError::Kind(WIN32::WININET_E_EXTENDED_ERROR),
            WIN32::ERROR_INTERNET_EXTENDED_ERROR => RawError::Kind(WIN32::ERROR_INTERNET_EXTENDED_ERROR),
            WIN32::WININET_E_INTERNAL_ERROR => RawError::Kind(WIN32::WININET_E_INTERNAL_ERROR),
            WIN32::ERROR_INTERNET_INTERNAL_ERROR => RawError::Kind(WIN32::ERROR_INTERNET_INTERNAL_ERROR),
            WIN32::ERROR_WINHTTP_INTERNAL_ERROR => RawError::Kind(WIN32::ERROR_WINHTTP_INTERNAL_ERROR),
            WIN32::WININET_E_INVALID_URL => RawError::Kind(WIN32::WININET_E_INVALID_URL),
            WIN32::ERROR_INTERNET_INVALID_URL => RawError::Kind(WIN32::ERROR_INTERNET_INVALID_URL),
            WIN32::ERROR_WINHTTP_INVALID_URL => RawError::Kind(WIN32::ERROR_WINHTTP_INVALID_URL),
            WIN32::WININET_E_UNRECOGNIZED_SCHEME => RawError::Kind(WIN32::WININET_E_UNRECOGNIZED_SCHEME),
            WIN32::ERROR_INTERNET_UNRECOGNIZED_SCHEME => RawError::Kind(WIN32::ERROR_INTERNET_UNRECOGNIZED_SCHEME),
            WIN32::ERROR_WINHTTP_UNRECOGNIZED_SCHEME => RawError::Kind(WIN32::ERROR_WINHTTP_UNRECOGNIZED_SCHEME),
            WIN32::WININET_E_NAME_NOT_RESOLVED => RawError::Kind(WIN32::WININET_E_NAME_NOT_RESOLVED),
            WIN32::ERROR_INTERNET_NAME_NOT_RESOLVED => RawError::Kind(WIN32::ERROR_INTERNET_NAME_NOT_RESOLVED),
            WIN32::ERROR_WINHTTP_NAME_NOT_RESOLVED => RawError::Kind(WIN32::ERROR_WINHTTP_NAME_NOT_RESOLVED),
            WIN32::WININET_E_PROTOCOL_NOT_FOUND => RawError::Kind(WIN32::WININET_E_PROTOCOL_NOT_FOUND),
            WIN32::ERROR_INTERNET_PROTOCOL_NOT_FOUND => RawError::Kind(WIN32::ERROR_INTERNET_PROTOCOL_NOT_FOUND),
            WIN32::WININET_E_INVALID_OPTION => RawError::Kind(WIN32::WININET_E_INVALID_OPTION),
            WIN32::ERROR_INTERNET_INVALID_OPTION => RawError::Kind(WIN32::ERROR_INTERNET_INVALID_OPTION),
            WIN32::ERROR_WINHTTP_INVALID_OPTION => RawError::Kind(WIN32::ERROR_WINHTTP_INVALID_OPTION),
            WIN32::WININET_E_BAD_OPTION_LENGTH => RawError::Kind(WIN32::WININET_E_BAD_OPTION_LENGTH),
            WIN32::ERROR_INTERNET_BAD_OPTION_LENGTH => RawError::Kind(WIN32::ERROR_INTERNET_BAD_OPTION_LENGTH),
            WIN32::WININET_E_OPTION_NOT_SETTABLE => RawError::Kind(WIN32::WININET_E_OPTION_NOT_SETTABLE),
            WIN32::ERROR_INTERNET_OPTION_NOT_SETTABLE => RawError::Kind(WIN32::ERROR_INTERNET_OPTION_NOT_SETTABLE),
            WIN32::WININET_E_SHUTDOWN => RawError::Kind(WIN32::WININET_E_SHUTDOWN),
            WIN32::ERROR_INTERNET_SHUTDOWN => RawError::Kind(WIN32::ERROR_INTERNET_SHUTDOWN),
            WIN32::ERROR_WINHTTP_SHUTDOWN => RawError::Kind(WIN32::ERROR_WINHTTP_SHUTDOWN),
            WIN32::WININET_E_INCORRECT_USER_NAME => RawError::Kind(WIN32::WININET_E_INCORRECT_USER_NAME),
            WIN32::ERROR_INTERNET_INCORRECT_USER_NAME => RawError::Kind(WIN32::ERROR_INTERNET_INCORRECT_USER_NAME),
            WIN32::WININET_E_INCORRECT_PASSWORD => RawError::Kind(WIN32::WININET_E_INCORRECT_PASSWORD),
            WIN32::ERROR_INTERNET_INCORRECT_PASSWORD => RawError::Kind(WIN32::ERROR_INTERNET_INCORRECT_PASSWORD),
            WIN32::WININET_E_LOGIN_FAILURE => RawError::Kind(WIN32::WININET_E_LOGIN_FAILURE),
            WIN32::ERROR_INTERNET_LOGIN_FAILURE => RawError::Kind(WIN32::ERROR_INTERNET_LOGIN_FAILURE),
            WIN32::ERROR_WINHTTP_LOGIN_FAILURE => RawError::Kind(WIN32::ERROR_WINHTTP_LOGIN_FAILURE),
            WIN32::WININET_E_INVALID_OPERATION => RawError::Kind(WIN32::WININET_E_INVALID_OPERATION),
            WIN32::ERROR_INTERNET_INVALID_OPERATION => RawError::Kind(WIN32::ERROR_INTERNET_INVALID_OPERATION),
            WIN32::WININET_E_OPERATION_CANCELLED => RawError::Kind(WIN32::WININET_E_OPERATION_CANCELLED),
            WIN32::ERROR_INTERNET_OPERATION_CANCELLED => RawError::Kind(WIN32::ERROR_INTERNET_OPERATION_CANCELLED),
            WIN32::ERROR_WINHTTP_OPERATION_CANCELLED => RawError::Kind(WIN32::ERROR_WINHTTP_OPERATION_CANCELLED),
            WIN32::WININET_E_INCORRECT_HANDLE_TYPE => RawError::Kind(WIN32::WININET_E_INCORRECT_HANDLE_TYPE),
            WIN32::ERROR_INTERNET_INCORRECT_HANDLE_TYPE => RawError::Kind(WIN32::ERROR_INTERNET_INCORRECT_HANDLE_TYPE),
            WIN32::WININET_E_INCORRECT_HANDLE_STATE => RawError::Kind(WIN32::WININET_E_INCORRECT_HANDLE_STATE),
            WIN32::ERROR_INTERNET_INCORRECT_HANDLE_STATE => RawError::Kind(WIN32::ERROR_INTERNET_INCORRECT_HANDLE_STATE),
            WIN32::ERROR_WINHTTP_INCORRECT_HANDLE_STATE => RawError::Kind(WIN32::ERROR_WINHTTP_INCORRECT_HANDLE_STATE),
            WIN32::WININET_E_NOT_PROXY_REQUEST => RawError::Kind(WIN32::WININET_E_NOT_PROXY_REQUEST),
            WIN32::ERROR_INTERNET_NOT_PROXY_REQUEST => RawError::Kind(WIN32::ERROR_INTERNET_NOT_PROXY_REQUEST),
            WIN32::WININET_E_REGISTRY_VALUE_NOT_FOUND => RawError::Kind(WIN32::WININET_E_REGISTRY_VALUE_NOT_FOUND),
            WIN32::ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND => RawError::Kind(WIN32::ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND),
            WIN32::WININET_E_BAD_REGISTRY_PARAMETER => RawError::Kind(WIN32::WININET_E_BAD_REGISTRY_PARAMETER),
            WIN32::ERROR_INTERNET_BAD_REGISTRY_PARAMETER => RawError::Kind(WIN32::ERROR_INTERNET_BAD_REGISTRY_PARAMETER),
            WIN32::WININET_E_NO_DIRECT_ACCESS => RawError::Kind(WIN32::WININET_E_NO_DIRECT_ACCESS),
            WIN32::ERROR_INTERNET_NO_DIRECT_ACCESS => RawError::Kind(WIN32::ERROR_INTERNET_NO_DIRECT_ACCESS),
            WIN32::WININET_E_NO_CONTEXT => RawError::Kind(WIN32::WININET_E_NO_CONTEXT),
            WIN32::ERROR_INTERNET_NO_CONTEXT => RawError::Kind(WIN32::ERROR_INTERNET_NO_CONTEXT),
            WIN32::WININET_E_NO_CALLBACK => RawError::Kind(WIN32::WININET_E_NO_CALLBACK),
            WIN32::ERROR_INTERNET_NO_CALLBACK => RawError::Kind(WIN32::ERROR_INTERNET_NO_CALLBACK),
            WIN32::WININET_E_REQUEST_PENDING => RawError::Kind(WIN32::WININET_E_REQUEST_PENDING),
            WIN32::ERROR_INTERNET_REQUEST_PENDING => RawError::Kind(WIN32::ERROR_INTERNET_REQUEST_PENDING),
            WIN32::WININET_E_INCORRECT_FORMAT => RawError::Kind(WIN32::WININET_E_INCORRECT_FORMAT),
            WIN32::ERROR_INTERNET_INCORRECT_FORMAT => RawError::Kind(WIN32::ERROR_INTERNET_INCORRECT_FORMAT),
            WIN32::WININET_E_ITEM_NOT_FOUND => RawError::Kind(WIN32::WININET_E_ITEM_NOT_FOUND),
            WIN32::ERROR_INTERNET_ITEM_NOT_FOUND => RawError::Kind(WIN32::ERROR_INTERNET_ITEM_NOT_FOUND),
            WIN32::WININET_E_CANNOT_CONNECT => RawError::Kind(WIN32::WININET_E_CANNOT_CONNECT),
            WIN32::ERROR_INTERNET_CANNOT_CONNECT => RawError::Kind(WIN32::ERROR_INTERNET_CANNOT_CONNECT),
            WIN32::ERROR_WINHTTP_CANNOT_CONNECT => RawError::Kind(WIN32::ERROR_WINHTTP_CANNOT_CONNECT),
            WIN32::WININET_E_CONNECTION_ABORTED => RawError::Kind(WIN32::WININET_E_CONNECTION_ABORTED),
            WIN32::ERROR_INTERNET_CONNECTION_ABORTED => RawError::Kind(WIN32::ERROR_INTERNET_CONNECTION_ABORTED),
            WIN32::ERROR_WINHTTP_CONNECTION_ABORTED => RawError::Kind(WIN32::ERROR_WINHTTP_CONNECTION_ABORTED),
            WIN32::WININET_E_CONNECTION_RESET => RawError::Kind(WIN32::WININET_E_CONNECTION_RESET),
            WIN32::ERROR_INTERNET_CONNECTION_RESET => RawError::Kind(WIN32::ERROR_INTERNET_CONNECTION_RESET),
            WIN32::ERROR_WINHTTP_CONNECTION_RESET => RawError::Kind(WIN32::ERROR_WINHTTP_CONNECTION_RESET),
            WIN32::WININET_E_FORCE_RETRY => RawError::Kind(WIN32::WININET_E_FORCE_RETRY),
            WIN32::ERROR_INTERNET_FORCE_RETRY => RawError::Kind(WIN32::ERROR_INTERNET_FORCE_RETRY),
            WIN32::WININET_E_INVALID_PROXY_REQUEST => RawError::Kind(WIN32::WININET_E_INVALID_PROXY_REQUEST),
            WIN32::ERROR_INTERNET_INVALID_PROXY_REQUEST => RawError::Kind(WIN32::ERROR_INTERNET_INVALID_PROXY_REQUEST),
            WIN32::WININET_E_NEED_UI => RawError::Kind(WIN32::WININET_E_NEED_UI),
            WIN32::ERROR_INTERNET_NEED_UI => RawError::Kind(WIN32::ERROR_INTERNET_NEED_UI),
            WIN32::WININET_E_HANDLE_EXISTS => RawError::Kind(WIN32::WININET_E_HANDLE_EXISTS),
            WIN32::ERROR_INTERNET_HANDLE_EXISTS => RawError::Kind(WIN32::ERROR_INTERNET_HANDLE_EXISTS),
            WIN32::WININET_E_SEC_CERT_DATE_INVALID => RawError::Kind(WIN32::WININET_E_SEC_CERT_DATE_INVALID),
            WIN32::ERROR_INTERNET_SEC_CERT_DATE_INVALID => RawError::Kind(WIN32::ERROR_INTERNET_SEC_CERT_DATE_INVALID),
            WIN32::ERROR_WINHTTP_SEC_CERT_DATE_INVALID => RawError::Kind(WIN32::ERROR_WINHTTP_SEC_CERT_DATE_INVALID),
            WIN32::WININET_E_SEC_CERT_CN_INVALID => RawError::Kind(WIN32::WININET_E_SEC_CERT_CN_INVALID),
            WIN32::ERROR_INTERNET_SEC_CERT_CN_INVALID => RawError::Kind(WIN32::ERROR_INTERNET_SEC_CERT_CN_INVALID),
            WIN32::ERROR_WINHTTP_SEC_CERT_CN_INVALID => RawError::Kind(WIN32::ERROR_WINHTTP_SEC_CERT_CN_INVALID),
            WIN32::WININET_E_HTTP_TO_HTTPS_ON_REDIR => RawError::Kind(WIN32::WININET_E_HTTP_TO_HTTPS_ON_REDIR),
            WIN32::ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR => RawError::Kind(WIN32::ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR),
            WIN32::WININET_E_HTTPS_TO_HTTP_ON_REDIR => RawError::Kind(WIN32::WININET_E_HTTPS_TO_HTTP_ON_REDIR),
            WIN32::ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR => RawError::Kind(WIN32::ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR),
            WIN32::WININET_E_MIXED_SECURITY => RawError::Kind(WIN32::WININET_E_MIXED_SECURITY),
            WIN32::ERROR_INTERNET_MIXED_SECURITY => RawError::Kind(WIN32::ERROR_INTERNET_MIXED_SECURITY),
            WIN32::WININET_E_CHG_POST_IS_NON_SECURE => RawError::Kind(WIN32::WININET_E_CHG_POST_IS_NON_SECURE),
            WIN32::ERROR_INTERNET_CHG_POST_IS_NON_SECURE => RawError::Kind(WIN32::ERROR_INTERNET_CHG_POST_IS_NON_SECURE),
            WIN32::WININET_E_POST_IS_NON_SECURE => RawError::Kind(WIN32::WININET_E_POST_IS_NON_SECURE),
            WIN32::ERROR_INTERNET_POST_IS_NON_SECURE => RawError::Kind(WIN32::ERROR_INTERNET_POST_IS_NON_SECURE),
            WIN32::WININET_E_CLIENT_AUTH_CERT_NEEDED => RawError::Kind(WIN32::WININET_E_CLIENT_AUTH_CERT_NEEDED),
            WIN32::ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED => RawError::Kind(WIN32::ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED),
            WIN32::ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED => RawError::Kind(WIN32::ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED),
            WIN32::WININET_E_INVALID_CA => RawError::Kind(WIN32::WININET_E_INVALID_CA),
            WIN32::ERROR_INTERNET_INVALID_CA => RawError::Kind(WIN32::ERROR_INTERNET_INVALID_CA),
            WIN32::ERROR_WINHTTP_INVALID_CA => RawError::Kind(WIN32::ERROR_WINHTTP_INVALID_CA),
            WIN32::WININET_E_CLIENT_AUTH_NOT_SETUP => RawError::Kind(WIN32::WININET_E_CLIENT_AUTH_NOT_SETUP),
            WIN32::ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP => RawError::Kind(WIN32::ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP),
            WIN32::WININET_E_ASYNC_THREAD_FAILED => RawError::Kind(WIN32::WININET_E_ASYNC_THREAD_FAILED),
            WIN32::ERROR_INTERNET_ASYNC_THREAD_FAILED => RawError::Kind(WIN32::ERROR_INTERNET_ASYNC_THREAD_FAILED),
            WIN32::WININET_E_REDIRECT_SCHEME_CHANGE => RawError::Kind(WIN32::WININET_E_REDIRECT_SCHEME_CHANGE),
            WIN32::ERROR_INTERNET_REDIRECT_SCHEME_CHANGE => RawError::Kind(WIN32::ERROR_INTERNET_REDIRECT_SCHEME_CHANGE),
            WIN32::WININET_E_DIALOG_PENDING => RawError::Kind(WIN32::WININET_E_DIALOG_PENDING),
            WIN32::ERROR_INTERNET_DIALOG_PENDING => RawError::Kind(WIN32::ERROR_INTERNET_DIALOG_PENDING),
            WIN32::WININET_E_RETRY_DIALOG => RawError::Kind(WIN32::WININET_E_RETRY_DIALOG),
            WIN32::ERROR_INTERNET_RETRY_DIALOG => RawError::Kind(WIN32::ERROR_INTERNET_RETRY_DIALOG),
            WIN32::WININET_E_NO_NEW_CONTAINERS => RawError::Kind(WIN32::WININET_E_NO_NEW_CONTAINERS),
            WIN32::WININET_E_HTTPS_HTTP_SUBMIT_REDIR => RawError::Kind(WIN32::WININET_E_HTTPS_HTTP_SUBMIT_REDIR),
            WIN32::ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR => RawError::Kind(WIN32::ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR),
            WIN32::ERROR_INTERNET_INSERT_CDROM => RawError::Kind(WIN32::ERROR_INTERNET_INSERT_CDROM),
            WIN32::ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED => RawError::Kind(WIN32::ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED),
            WIN32::WININET_E_SEC_CERT_ERRORS => RawError::Kind(WIN32::WININET_E_SEC_CERT_ERRORS),
            WIN32::ERROR_INTERNET_SEC_CERT_ERRORS => RawError::Kind(WIN32::ERROR_INTERNET_SEC_CERT_ERRORS),
            WIN32::ERROR_INTERNET_SEC_CERT_NO_REV => RawError::Kind(WIN32::ERROR_INTERNET_SEC_CERT_NO_REV),
            WIN32::WININET_E_SEC_CERT_REV_FAILED => RawError::Kind(WIN32::WININET_E_SEC_CERT_REV_FAILED),
            WIN32::ERROR_INTERNET_SEC_CERT_REV_FAILED => RawError::Kind(WIN32::ERROR_INTERNET_SEC_CERT_REV_FAILED),
            WIN32::ERROR_WINHTTP_NO_CM_CONNECTION => RawError::Kind(WIN32::ERROR_WINHTTP_NO_CM_CONNECTION),
            WIN32::ERROR_FTP_TRANSFER_IN_PROGRESS => RawError::Kind(WIN32::ERROR_FTP_TRANSFER_IN_PROGRESS),
            WIN32::ERROR_FTP_DROPPED => RawError::Kind(WIN32::ERROR_FTP_DROPPED),
            WIN32::ERROR_FTP_NO_PASSIVE_MODE => RawError::Kind(WIN32::ERROR_FTP_NO_PASSIVE_MODE),
            WIN32::ERROR_GOPHER_PROTOCOL_ERROR => RawError::Kind(WIN32::ERROR_GOPHER_PROTOCOL_ERROR),
            WIN32::ERROR_GOPHER_NOT_FILE => RawError::Kind(WIN32::ERROR_GOPHER_NOT_FILE),
            WIN32::ERROR_GOPHER_DATA_ERROR => RawError::Kind(WIN32::ERROR_GOPHER_DATA_ERROR),
            WIN32::ERROR_GOPHER_END_OF_DATA => RawError::Kind(WIN32::ERROR_GOPHER_END_OF_DATA),
            WIN32::ERROR_GOPHER_INVALID_LOCATOR => RawError::Kind(WIN32::ERROR_GOPHER_INVALID_LOCATOR),
            WIN32::ERROR_GOPHER_INCORRECT_LOCATOR_TYPE => RawError::Kind(WIN32::ERROR_GOPHER_INCORRECT_LOCATOR_TYPE),
            WIN32::ERROR_GOPHER_NOT_GOPHER_PLUS => RawError::Kind(WIN32::ERROR_GOPHER_NOT_GOPHER_PLUS),
            WIN32::ERROR_GOPHER_ATTRIBUTE_NOT_FOUND => RawError::Kind(WIN32::ERROR_GOPHER_ATTRIBUTE_NOT_FOUND),
            WIN32::ERROR_GOPHER_UNKNOWN_LOCATOR => RawError::Kind(WIN32::ERROR_GOPHER_UNKNOWN_LOCATOR),
            WIN32::WININET_E_HEADER_NOT_FOUND => RawError::Kind(WIN32::WININET_E_HEADER_NOT_FOUND),
            WIN32::ERROR_HTTP_HEADER_NOT_FOUND => RawError::Kind(WIN32::ERROR_HTTP_HEADER_NOT_FOUND),
            WIN32::ERROR_WINHTTP_HEADER_NOT_FOUND => RawError::Kind(WIN32::ERROR_WINHTTP_HEADER_NOT_FOUND),
            WIN32::WININET_E_DOWNLEVEL_SERVER => RawError::Kind(WIN32::WININET_E_DOWNLEVEL_SERVER),
            WIN32::ERROR_HTTP_DOWNLEVEL_SERVER => RawError::Kind(WIN32::ERROR_HTTP_DOWNLEVEL_SERVER),
            WIN32::WININET_E_INVALID_SERVER_RESPONSE => RawError::Kind(WIN32::WININET_E_INVALID_SERVER_RESPONSE),
            WIN32::ERROR_HTTP_INVALID_SERVER_RESPONSE => RawError::Kind(WIN32::ERROR_HTTP_INVALID_SERVER_RESPONSE),
            WIN32::ERROR_WINHTTP_INVALID_SERVER_RESPONSE => RawError::Kind(WIN32::ERROR_WINHTTP_INVALID_SERVER_RESPONSE),
            WIN32::WININET_E_INVALID_HEADER => RawError::Kind(WIN32::WININET_E_INVALID_HEADER),
            WIN32::ERROR_HTTP_INVALID_HEADER => RawError::Kind(WIN32::ERROR_HTTP_INVALID_HEADER),
            WIN32::WININET_E_INVALID_QUERY_REQUEST => RawError::Kind(WIN32::WININET_E_INVALID_QUERY_REQUEST),
            WIN32::ERROR_HTTP_INVALID_QUERY_REQUEST => RawError::Kind(WIN32::ERROR_HTTP_INVALID_QUERY_REQUEST),
            WIN32::ERROR_WINHTTP_INVALID_QUERY_REQUEST => RawError::Kind(WIN32::ERROR_WINHTTP_INVALID_QUERY_REQUEST),
            WIN32::WININET_E_HEADER_ALREADY_EXISTS => RawError::Kind(WIN32::WININET_E_HEADER_ALREADY_EXISTS),
            WIN32::ERROR_HTTP_HEADER_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_HTTP_HEADER_ALREADY_EXISTS),
            WIN32::WININET_E_REDIRECT_FAILED => RawError::Kind(WIN32::WININET_E_REDIRECT_FAILED),
            WIN32::ERROR_HTTP_REDIRECT_FAILED => RawError::Kind(WIN32::ERROR_HTTP_REDIRECT_FAILED),
            WIN32::ERROR_WINHTTP_REDIRECT_FAILED => RawError::Kind(WIN32::ERROR_WINHTTP_REDIRECT_FAILED),
            WIN32::WININET_E_SECURITY_CHANNEL_ERROR => RawError::Kind(WIN32::WININET_E_SECURITY_CHANNEL_ERROR),
            WIN32::ERROR_INTERNET_SECURITY_CHANNEL_ERROR => RawError::Kind(WIN32::ERROR_INTERNET_SECURITY_CHANNEL_ERROR),
            WIN32::ERROR_WINHTTP_SECURE_CHANNEL_ERROR => RawError::Kind(WIN32::ERROR_WINHTTP_SECURE_CHANNEL_ERROR),
            WIN32::WININET_E_UNABLE_TO_CACHE_FILE => RawError::Kind(WIN32::WININET_E_UNABLE_TO_CACHE_FILE),
            WIN32::ERROR_INTERNET_UNABLE_TO_CACHE_FILE => RawError::Kind(WIN32::ERROR_INTERNET_UNABLE_TO_CACHE_FILE),
            WIN32::WININET_E_TCPIP_NOT_INSTALLED => RawError::Kind(WIN32::WININET_E_TCPIP_NOT_INSTALLED),
            WIN32::ERROR_INTERNET_TCPIP_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_INTERNET_TCPIP_NOT_INSTALLED),
            WIN32::WININET_E_NOT_REDIRECTED => RawError::Kind(WIN32::WININET_E_NOT_REDIRECTED),
            WIN32::ERROR_HTTP_NOT_REDIRECTED => RawError::Kind(WIN32::ERROR_HTTP_NOT_REDIRECTED),
            WIN32::WININET_E_COOKIE_NEEDS_CONFIRMATION => RawError::Kind(WIN32::WININET_E_COOKIE_NEEDS_CONFIRMATION),
            WIN32::ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION => RawError::Kind(WIN32::ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION),
            WIN32::WININET_E_COOKIE_DECLINED => RawError::Kind(WIN32::WININET_E_COOKIE_DECLINED),
            WIN32::ERROR_HTTP_COOKIE_DECLINED => RawError::Kind(WIN32::ERROR_HTTP_COOKIE_DECLINED),
            WIN32::WININET_E_DISCONNECTED => RawError::Kind(WIN32::WININET_E_DISCONNECTED),
            WIN32::ERROR_INTERNET_DISCONNECTED => RawError::Kind(WIN32::ERROR_INTERNET_DISCONNECTED),
            WIN32::WININET_E_SERVER_UNREACHABLE => RawError::Kind(WIN32::WININET_E_SERVER_UNREACHABLE),
            WIN32::ERROR_INTERNET_SERVER_UNREACHABLE => RawError::Kind(WIN32::ERROR_INTERNET_SERVER_UNREACHABLE),
            WIN32::WININET_E_PROXY_SERVER_UNREACHABLE => RawError::Kind(WIN32::WININET_E_PROXY_SERVER_UNREACHABLE),
            WIN32::ERROR_INTERNET_PROXY_SERVER_UNREACHABLE => RawError::Kind(WIN32::ERROR_INTERNET_PROXY_SERVER_UNREACHABLE),
            WIN32::WININET_E_BAD_AUTO_PROXY_SCRIPT => RawError::Kind(WIN32::WININET_E_BAD_AUTO_PROXY_SCRIPT),
            WIN32::ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT => RawError::Kind(WIN32::ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT),
            WIN32::WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT => RawError::Kind(WIN32::WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT),
            WIN32::ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT => RawError::Kind(WIN32::ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT),
            WIN32::WININET_E_REDIRECT_NEEDS_CONFIRMATION => RawError::Kind(WIN32::WININET_E_REDIRECT_NEEDS_CONFIRMATION),
            WIN32::ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION => RawError::Kind(WIN32::ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION),
            WIN32::WININET_E_SEC_INVALID_CERT => RawError::Kind(WIN32::WININET_E_SEC_INVALID_CERT),
            WIN32::ERROR_INTERNET_SEC_INVALID_CERT => RawError::Kind(WIN32::ERROR_INTERNET_SEC_INVALID_CERT),
            WIN32::ERROR_WINHTTP_SECURE_INVALID_CERT => RawError::Kind(WIN32::ERROR_WINHTTP_SECURE_INVALID_CERT),
            WIN32::WININET_E_SEC_CERT_REVOKED => RawError::Kind(WIN32::WININET_E_SEC_CERT_REVOKED),
            WIN32::ERROR_INTERNET_SEC_CERT_REVOKED => RawError::Kind(WIN32::ERROR_INTERNET_SEC_CERT_REVOKED),
            WIN32::WININET_E_FAILED_DUETOSECURITYCHECK => RawError::Kind(WIN32::WININET_E_FAILED_DUETOSECURITYCHECK),
            WIN32::ERROR_INTERNET_FAILED_DUETOSECURITYCHECK => RawError::Kind(WIN32::ERROR_INTERNET_FAILED_DUETOSECURITYCHECK),
            WIN32::WININET_E_NOT_INITIALIZED => RawError::Kind(WIN32::WININET_E_NOT_INITIALIZED),
            WIN32::ERROR_INTERNET_NOT_INITIALIZED => RawError::Kind(WIN32::ERROR_INTERNET_NOT_INITIALIZED),
            WIN32::ERROR_INTERNET_NEED_MSN_SSPI_PKG => RawError::Kind(WIN32::ERROR_INTERNET_NEED_MSN_SSPI_PKG),
            WIN32::WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY => RawError::Kind(WIN32::WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY),
            WIN32::ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY => RawError::Kind(WIN32::ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY),
            WIN32::WININET_E_DECODING_FAILED => RawError::Kind(WIN32::WININET_E_DECODING_FAILED),
            WIN32::ERROR_INTERNET_DECODING_FAILED => RawError::Kind(WIN32::ERROR_INTERNET_DECODING_FAILED),
            WIN32::ERROR_WINHTTP_SECURE_FAILURE => RawError::Kind(WIN32::ERROR_WINHTTP_SECURE_FAILURE),
            WIN32::ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW => RawError::Kind(WIN32::ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW),
            WIN32::ERROR_IPSEC_QM_POLICY_EXISTS => RawError::Kind(WIN32::ERROR_IPSEC_QM_POLICY_EXISTS),
            WIN32::ERROR_IPSEC_QM_POLICY_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_QM_POLICY_NOT_FOUND),
            WIN32::ERROR_IPSEC_QM_POLICY_IN_USE => RawError::Kind(WIN32::ERROR_IPSEC_QM_POLICY_IN_USE),
            WIN32::ERROR_IPSEC_MM_POLICY_EXISTS => RawError::Kind(WIN32::ERROR_IPSEC_MM_POLICY_EXISTS),
            WIN32::ERROR_IPSEC_MM_POLICY_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_MM_POLICY_NOT_FOUND),
            WIN32::ERROR_IPSEC_MM_POLICY_IN_USE => RawError::Kind(WIN32::ERROR_IPSEC_MM_POLICY_IN_USE),
            WIN32::ERROR_IPSEC_MM_FILTER_EXISTS => RawError::Kind(WIN32::ERROR_IPSEC_MM_FILTER_EXISTS),
            WIN32::ERROR_IPSEC_MM_FILTER_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_MM_FILTER_NOT_FOUND),
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_EXISTS => RawError::Kind(WIN32::ERROR_IPSEC_TRANSPORT_FILTER_EXISTS),
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND),
            WIN32::ERROR_IPSEC_MM_AUTH_EXISTS => RawError::Kind(WIN32::ERROR_IPSEC_MM_AUTH_EXISTS),
            WIN32::ERROR_IPSEC_MM_AUTH_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_MM_AUTH_NOT_FOUND),
            WIN32::ERROR_IPSEC_MM_AUTH_IN_USE => RawError::Kind(WIN32::ERROR_IPSEC_MM_AUTH_IN_USE),
            WIN32::ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND),
            WIN32::ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND),
            WIN32::ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND),
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_EXISTS => RawError::Kind(WIN32::ERROR_IPSEC_TUNNEL_FILTER_EXISTS),
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND => RawError::Kind(WIN32::ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND),
            WIN32::ERROR_IPSEC_MM_FILTER_PENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_MM_FILTER_PENDING_DELETION),
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION),
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION),
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION),
            WIN32::ERROR_IPSEC_MM_POLICY_PENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_MM_POLICY_PENDING_DELETION),
            WIN32::ERROR_IPSEC_MM_POLICY_PENDING_ELETION => RawError::Kind(WIN32::ERROR_IPSEC_MM_POLICY_PENDING_ELETION),
            WIN32::ERROR_IPSEC_MM_AUTH_PENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_MM_AUTH_PENDING_DELETION),
            WIN32::ERROR_IPSEC_QM_POLICY_PENDING_DELETION => RawError::Kind(WIN32::ERROR_IPSEC_QM_POLICY_PENDING_DELETION),
            WIN32::WARNING_IPSEC_MM_POLICY_PRUNED => RawError::Kind(WIN32::WARNING_IPSEC_MM_POLICY_PRUNED),
            WIN32::WARNING_IPSEC_QM_POLICY_PRUNED => RawError::Kind(WIN32::WARNING_IPSEC_QM_POLICY_PRUNED),
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_BEGIN => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NEG_STATUS_BEGIN),
            WIN32::ERROR_IPSEC_IKE_AUTH_FAIL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_AUTH_FAIL),
            WIN32::ERROR_IPSEC_IKE_ATTRIB_FAIL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_ATTRIB_FAIL),
            WIN32::ERROR_IPSEC_IKE_NEGOTIATION_PENDING => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NEGOTIATION_PENDING),
            WIN32::ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR => RawError::Kind(WIN32::ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR),
            WIN32::ERROR_IPSEC_IKE_TIMED_OUT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_TIMED_OUT),
            WIN32::ERROR_IPSEC_IKE_NO_CERT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NO_CERT),
            WIN32::ERROR_IPSEC_IKE_SA_DELETED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SA_DELETED),
            WIN32::ERROR_IPSEC_IKE_SA_REAPED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SA_REAPED),
            WIN32::ERROR_IPSEC_IKE_MM_ACQUIRE_DROP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_MM_ACQUIRE_DROP),
            WIN32::ERROR_IPSEC_IKE_QM_ACQUIRE_DROP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_QM_ACQUIRE_DROP),
            WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_MM => RawError::Kind(WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_MM),
            WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM => RawError::Kind(WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM),
            WIN32::ERROR_IPSEC_IKE_DROP_NO_RESPONSE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_DROP_NO_RESPONSE),
            WIN32::ERROR_IPSEC_IKE_MM_DELAY_DROP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_MM_DELAY_DROP),
            WIN32::ERROR_IPSEC_IKE_QM_DELAY_DROP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_QM_DELAY_DROP),
            WIN32::ERROR_IPSEC_IKE_ERROR => RawError::Kind(WIN32::ERROR_IPSEC_IKE_ERROR),
            WIN32::ERROR_IPSEC_IKE_CRL_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_CRL_FAILED),
            WIN32::ERROR_IPSEC_IKE_INVALID_KEY_USAGE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_KEY_USAGE),
            WIN32::ERROR_IPSEC_IKE_INVALID_CERT_TYPE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_CERT_TYPE),
            WIN32::ERROR_IPSEC_IKE_NO_PRIVATE_KEY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NO_PRIVATE_KEY),
            WIN32::ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY),
            WIN32::ERROR_IPSEC_IKE_DH_FAIL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_DH_FAIL),
            WIN32::ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED),
            WIN32::ERROR_IPSEC_IKE_INVALID_HEADER => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_HEADER),
            WIN32::ERROR_IPSEC_IKE_NO_POLICY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NO_POLICY),
            WIN32::ERROR_IPSEC_IKE_INVALID_SIGNATURE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_SIGNATURE),
            WIN32::ERROR_IPSEC_IKE_KERBEROS_ERROR => RawError::Kind(WIN32::ERROR_IPSEC_IKE_KERBEROS_ERROR),
            WIN32::ERROR_IPSEC_IKE_NO_PUBLIC_KEY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NO_PUBLIC_KEY),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SA => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SA),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_PROP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_PROP),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_TRANS => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_TRANS),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_KE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_KE),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_ID => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_ID),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_HASH => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_HASH),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SIG => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SIG),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NONCE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NONCE),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_DELETE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_DELETE),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR),
            WIN32::ERROR_IPSEC_IKE_INVALID_PAYLOAD => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_PAYLOAD),
            WIN32::ERROR_IPSEC_IKE_LOAD_SOFT_SA => RawError::Kind(WIN32::ERROR_IPSEC_IKE_LOAD_SOFT_SA),
            WIN32::ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN),
            WIN32::ERROR_IPSEC_IKE_INVALID_COOKIE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_COOKIE),
            WIN32::ERROR_IPSEC_IKE_NO_PEER_CERT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NO_PEER_CERT),
            WIN32::ERROR_IPSEC_IKE_PEER_CRL_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PEER_CRL_FAILED),
            WIN32::ERROR_IPSEC_IKE_POLICY_CHANGE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_POLICY_CHANGE),
            WIN32::ERROR_IPSEC_IKE_NO_MM_POLICY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NO_MM_POLICY),
            WIN32::ERROR_IPSEC_IKE_NOTCBPRIV => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NOTCBPRIV),
            WIN32::ERROR_IPSEC_IKE_SECLOADFAIL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SECLOADFAIL),
            WIN32::ERROR_IPSEC_IKE_FAILSSPINIT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_FAILSSPINIT),
            WIN32::ERROR_IPSEC_IKE_FAILQUERYSSP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_FAILQUERYSSP),
            WIN32::ERROR_IPSEC_IKE_SRVACQFAIL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SRVACQFAIL),
            WIN32::ERROR_IPSEC_IKE_SRVQUERYCRED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SRVQUERYCRED),
            WIN32::ERROR_IPSEC_IKE_GETSPIFAIL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_GETSPIFAIL),
            WIN32::ERROR_IPSEC_IKE_INVALID_FILTER => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_FILTER),
            WIN32::ERROR_IPSEC_IKE_OUT_OF_MEMORY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_OUT_OF_MEMORY),
            WIN32::ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED),
            WIN32::ERROR_IPSEC_IKE_INVALID_POLICY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_POLICY),
            WIN32::ERROR_IPSEC_IKE_UNKNOWN_DOI => RawError::Kind(WIN32::ERROR_IPSEC_IKE_UNKNOWN_DOI),
            WIN32::ERROR_IPSEC_IKE_INVALID_SITUATION => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_SITUATION),
            WIN32::ERROR_IPSEC_IKE_DH_FAILURE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_DH_FAILURE),
            WIN32::ERROR_IPSEC_IKE_INVALID_GROUP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_GROUP),
            WIN32::ERROR_IPSEC_IKE_ENCRYPT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_ENCRYPT),
            WIN32::ERROR_IPSEC_IKE_DECRYPT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_DECRYPT),
            WIN32::ERROR_IPSEC_IKE_POLICY_MATCH => RawError::Kind(WIN32::ERROR_IPSEC_IKE_POLICY_MATCH),
            WIN32::ERROR_IPSEC_IKE_UNSUPPORTED_ID => RawError::Kind(WIN32::ERROR_IPSEC_IKE_UNSUPPORTED_ID),
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_HASH),
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH_ALG => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_HASH_ALG),
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH_SIZE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_HASH_SIZE),
            WIN32::ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG),
            WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_ALG => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_ALG),
            WIN32::ERROR_IPSEC_IKE_INVALID_SIG => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_SIG),
            WIN32::ERROR_IPSEC_IKE_LOAD_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_LOAD_FAILED),
            WIN32::ERROR_IPSEC_IKE_RPC_DELETE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_RPC_DELETE),
            WIN32::ERROR_IPSEC_IKE_BENIGN_REINIT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_BENIGN_REINIT),
            WIN32::ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY),
            WIN32::ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION),
            WIN32::ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN),
            WIN32::ERROR_IPSEC_IKE_MM_LIMIT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_MM_LIMIT),
            WIN32::ERROR_IPSEC_IKE_NEGOTIATION_DISABLED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NEGOTIATION_DISABLED),
            WIN32::ERROR_IPSEC_IKE_QM_LIMIT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_QM_LIMIT),
            WIN32::ERROR_IPSEC_IKE_MM_EXPIRED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_MM_EXPIRED),
            WIN32::ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID),
            WIN32::ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH => RawError::Kind(WIN32::ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH),
            WIN32::ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID => RawError::Kind(WIN32::ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID),
            WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD),
            WIN32::ERROR_IPSEC_IKE_INVALID_UMATTS => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_UMATTS),
            WIN32::ERROR_IPSEC_IKE_DOS_COOKIE_SENT => RawError::Kind(WIN32::ERROR_IPSEC_IKE_DOS_COOKIE_SENT),
            WIN32::ERROR_IPSEC_IKE_SHUTTING_DOWN => RawError::Kind(WIN32::ERROR_IPSEC_IKE_SHUTTING_DOWN),
            WIN32::ERROR_IPSEC_IKE_CGA_AUTH_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_CGA_AUTH_FAILED),
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NATOA => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NATOA),
            WIN32::ERROR_IPSEC_IKE_INVALID_MM_FOR_QM => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INVALID_MM_FOR_QM),
            WIN32::ERROR_IPSEC_IKE_QM_EXPIRED => RawError::Kind(WIN32::ERROR_IPSEC_IKE_QM_EXPIRED),
            WIN32::ERROR_IPSEC_IKE_TOO_MANY_FILTERS => RawError::Kind(WIN32::ERROR_IPSEC_IKE_TOO_MANY_FILTERS),
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_END => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NEG_STATUS_END),
            WIN32::ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL => RawError::Kind(WIN32::ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL),
            WIN32::ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE),
            WIN32::ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING => RawError::Kind(WIN32::ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING),
            WIN32::ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING => RawError::Kind(WIN32::ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING),
            WIN32::ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS => RawError::Kind(WIN32::ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS),
            WIN32::ERROR_IPSEC_IKE_RATELIMIT_DROP => RawError::Kind(WIN32::ERROR_IPSEC_IKE_RATELIMIT_DROP),
            WIN32::ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE),
            WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE),
            WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE),
            WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY => RawError::Kind(WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY),
            WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE => RawError::Kind(WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE),
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END => RawError::Kind(WIN32::ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END),
            WIN32::ERROR_IPSEC_BAD_SPI => RawError::Kind(WIN32::ERROR_IPSEC_BAD_SPI),
            WIN32::ERROR_IPSEC_SA_LIFETIME_EXPIRED => RawError::Kind(WIN32::ERROR_IPSEC_SA_LIFETIME_EXPIRED),
            WIN32::ERROR_IPSEC_WRONG_SA => RawError::Kind(WIN32::ERROR_IPSEC_WRONG_SA),
            WIN32::ERROR_IPSEC_REPLAY_CHECK_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_REPLAY_CHECK_FAILED),
            WIN32::ERROR_IPSEC_INVALID_PACKET => RawError::Kind(WIN32::ERROR_IPSEC_INVALID_PACKET),
            WIN32::ERROR_IPSEC_INTEGRITY_CHECK_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_INTEGRITY_CHECK_FAILED),
            WIN32::ERROR_IPSEC_CLEAR_TEXT_DROP => RawError::Kind(WIN32::ERROR_IPSEC_CLEAR_TEXT_DROP),
            WIN32::ERROR_IPSEC_AUTH_FIREWALL_DROP => RawError::Kind(WIN32::ERROR_IPSEC_AUTH_FIREWALL_DROP),
            WIN32::ERROR_IPSEC_THROTTLE_DROP => RawError::Kind(WIN32::ERROR_IPSEC_THROTTLE_DROP),
            WIN32::ERROR_IPSEC_DOSP_BLOCK => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_BLOCK),
            WIN32::ERROR_IPSEC_DOSP_RECEIVED_MULTICAST => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_RECEIVED_MULTICAST),
            WIN32::ERROR_IPSEC_DOSP_INVALID_PACKET => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_INVALID_PACKET),
            WIN32::ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED),
            WIN32::ERROR_IPSEC_DOSP_MAX_ENTRIES => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_MAX_ENTRIES),
            WIN32::ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED),
            WIN32::ERROR_IPSEC_DOSP_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_NOT_INSTALLED),
            WIN32::ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES => RawError::Kind(WIN32::ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES),
            WIN32::ERROR_SXS_SECTION_NOT_FOUND => RawError::Kind(WIN32::ERROR_SXS_SECTION_NOT_FOUND),
            WIN32::ERROR_SXS_CANT_GEN_ACTCTX => RawError::Kind(WIN32::ERROR_SXS_CANT_GEN_ACTCTX),
            WIN32::ERROR_SXS_INVALID_ACTCTXDATA_FORMAT => RawError::Kind(WIN32::ERROR_SXS_INVALID_ACTCTXDATA_FORMAT),
            WIN32::ERROR_SXS_ASSEMBLY_NOT_FOUND => RawError::Kind(WIN32::ERROR_SXS_ASSEMBLY_NOT_FOUND),
            WIN32::ERROR_SXS_MANIFEST_FORMAT_ERROR => RawError::Kind(WIN32::ERROR_SXS_MANIFEST_FORMAT_ERROR),
            WIN32::ERROR_SXS_MANIFEST_PARSE_ERROR => RawError::Kind(WIN32::ERROR_SXS_MANIFEST_PARSE_ERROR),
            WIN32::ERROR_SXS_ACTIVATION_CONTEXT_DISABLED => RawError::Kind(WIN32::ERROR_SXS_ACTIVATION_CONTEXT_DISABLED),
            WIN32::ERROR_SXS_KEY_NOT_FOUND => RawError::Kind(WIN32::ERROR_SXS_KEY_NOT_FOUND),
            WIN32::ERROR_SXS_VERSION_CONFLICT => RawError::Kind(WIN32::ERROR_SXS_VERSION_CONFLICT),
            WIN32::ERROR_SXS_WRONG_SECTION_TYPE => RawError::Kind(WIN32::ERROR_SXS_WRONG_SECTION_TYPE),
            WIN32::ERROR_SXS_THREAD_QUERIES_DISABLED => RawError::Kind(WIN32::ERROR_SXS_THREAD_QUERIES_DISABLED),
            WIN32::ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET => RawError::Kind(WIN32::ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET),
            WIN32::ERROR_SXS_UNKNOWN_ENCODING_GROUP => RawError::Kind(WIN32::ERROR_SXS_UNKNOWN_ENCODING_GROUP),
            WIN32::ERROR_SXS_UNKNOWN_ENCODING => RawError::Kind(WIN32::ERROR_SXS_UNKNOWN_ENCODING),
            WIN32::ERROR_SXS_INVALID_XML_NAMESPACE_URI => RawError::Kind(WIN32::ERROR_SXS_INVALID_XML_NAMESPACE_URI),
            WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED),
            WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED => RawError::Kind(WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED),
            WIN32::ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED),
            WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE => RawError::Kind(WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE),
            WIN32::ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE => RawError::Kind(WIN32::ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE),
            WIN32::ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE => RawError::Kind(WIN32::ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE),
            WIN32::ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT => RawError::Kind(WIN32::ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT),
            WIN32::ERROR_SXS_DUPLICATE_DLL_NAME => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_DLL_NAME),
            WIN32::ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME),
            WIN32::ERROR_SXS_DUPLICATE_CLSID => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_CLSID),
            WIN32::ERROR_SXS_DUPLICATE_IID => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_IID),
            WIN32::ERROR_SXS_DUPLICATE_TLBID => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_TLBID),
            WIN32::ERROR_SXS_DUPLICATE_PROGID => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_PROGID),
            WIN32::ERROR_SXS_DUPLICATE_ASSEMBLY_NAME => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_ASSEMBLY_NAME),
            WIN32::ERROR_SXS_FILE_HASH_MISMATCH => RawError::Kind(WIN32::ERROR_SXS_FILE_HASH_MISMATCH),
            WIN32::ERROR_SXS_POLICY_PARSE_ERROR => RawError::Kind(WIN32::ERROR_SXS_POLICY_PARSE_ERROR),
            WIN32::ERROR_SXS_XML_E_MISSINGQUOTE => RawError::Kind(WIN32::ERROR_SXS_XML_E_MISSINGQUOTE),
            WIN32::ERROR_SXS_XML_E_COMMENTSYNTAX => RawError::Kind(WIN32::ERROR_SXS_XML_E_COMMENTSYNTAX),
            WIN32::ERROR_SXS_XML_E_BADSTARTNAMECHAR => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADSTARTNAMECHAR),
            WIN32::ERROR_SXS_XML_E_BADNAMECHAR => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADNAMECHAR),
            WIN32::ERROR_SXS_XML_E_BADCHARINSTRING => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADCHARINSTRING),
            WIN32::ERROR_SXS_XML_E_XMLDECLSYNTAX => RawError::Kind(WIN32::ERROR_SXS_XML_E_XMLDECLSYNTAX),
            WIN32::ERROR_SXS_XML_E_BADCHARDATA => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADCHARDATA),
            WIN32::ERROR_SXS_XML_E_MISSINGWHITESPACE => RawError::Kind(WIN32::ERROR_SXS_XML_E_MISSINGWHITESPACE),
            WIN32::ERROR_SXS_XML_E_EXPECTINGTAGEND => RawError::Kind(WIN32::ERROR_SXS_XML_E_EXPECTINGTAGEND),
            WIN32::ERROR_SXS_XML_E_MISSINGSEMICOLON => RawError::Kind(WIN32::ERROR_SXS_XML_E_MISSINGSEMICOLON),
            WIN32::ERROR_SXS_XML_E_UNBALANCEDPAREN => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNBALANCEDPAREN),
            WIN32::ERROR_SXS_XML_E_INTERNALERROR => RawError::Kind(WIN32::ERROR_SXS_XML_E_INTERNALERROR),
            WIN32::ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE),
            WIN32::ERROR_SXS_XML_E_INCOMPLETE_ENCODING => RawError::Kind(WIN32::ERROR_SXS_XML_E_INCOMPLETE_ENCODING),
            WIN32::ERROR_SXS_XML_E_MISSING_PAREN => RawError::Kind(WIN32::ERROR_SXS_XML_E_MISSING_PAREN),
            WIN32::ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE => RawError::Kind(WIN32::ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE),
            WIN32::ERROR_SXS_XML_E_MULTIPLE_COLONS => RawError::Kind(WIN32::ERROR_SXS_XML_E_MULTIPLE_COLONS),
            WIN32::ERROR_SXS_XML_E_INVALID_DECIMAL => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALID_DECIMAL),
            WIN32::ERROR_SXS_XML_E_INVALID_HEXIDECIMAL => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALID_HEXIDECIMAL),
            WIN32::ERROR_SXS_XML_E_INVALID_UNICODE => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALID_UNICODE),
            WIN32::ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK => RawError::Kind(WIN32::ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK),
            WIN32::ERROR_SXS_XML_E_UNEXPECTEDENDTAG => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNEXPECTEDENDTAG),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDTAG => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDTAG),
            WIN32::ERROR_SXS_XML_E_DUPLICATEATTRIBUTE => RawError::Kind(WIN32::ERROR_SXS_XML_E_DUPLICATEATTRIBUTE),
            WIN32::ERROR_SXS_XML_E_MULTIPLEROOTS => RawError::Kind(WIN32::ERROR_SXS_XML_E_MULTIPLEROOTS),
            WIN32::ERROR_SXS_XML_E_INVALIDATROOTLEVEL => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALIDATROOTLEVEL),
            WIN32::ERROR_SXS_XML_E_BADXMLDECL => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADXMLDECL),
            WIN32::ERROR_SXS_XML_E_MISSINGROOT => RawError::Kind(WIN32::ERROR_SXS_XML_E_MISSINGROOT),
            WIN32::ERROR_SXS_XML_E_UNEXPECTEDEOF => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNEXPECTEDEOF),
            WIN32::ERROR_SXS_XML_E_BADPEREFINSUBSET => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADPEREFINSUBSET),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDSTARTTAG => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDSTARTTAG),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDENDTAG => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDENDTAG),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDSTRING => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDSTRING),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDCOMMENT => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDCOMMENT),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDDECL => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDDECL),
            WIN32::ERROR_SXS_XML_E_UNCLOSEDCDATA => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNCLOSEDCDATA),
            WIN32::ERROR_SXS_XML_E_RESERVEDNAMESPACE => RawError::Kind(WIN32::ERROR_SXS_XML_E_RESERVEDNAMESPACE),
            WIN32::ERROR_SXS_XML_E_INVALIDENCODING => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALIDENCODING),
            WIN32::ERROR_SXS_XML_E_INVALIDSWITCH => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALIDSWITCH),
            WIN32::ERROR_SXS_XML_E_BADXMLCASE => RawError::Kind(WIN32::ERROR_SXS_XML_E_BADXMLCASE),
            WIN32::ERROR_SXS_XML_E_INVALID_STANDALONE => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALID_STANDALONE),
            WIN32::ERROR_SXS_XML_E_UNEXPECTED_STANDALONE => RawError::Kind(WIN32::ERROR_SXS_XML_E_UNEXPECTED_STANDALONE),
            WIN32::ERROR_SXS_XML_E_INVALID_VERSION => RawError::Kind(WIN32::ERROR_SXS_XML_E_INVALID_VERSION),
            WIN32::ERROR_SXS_XML_E_MISSINGEQUALS => RawError::Kind(WIN32::ERROR_SXS_XML_E_MISSINGEQUALS),
            WIN32::ERROR_SXS_PROTECTION_RECOVERY_FAILED => RawError::Kind(WIN32::ERROR_SXS_PROTECTION_RECOVERY_FAILED),
            WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT => RawError::Kind(WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT),
            WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT => RawError::Kind(WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT),
            WIN32::ERROR_SXS_PROTECTION_CATALOG_NOT_VALID => RawError::Kind(WIN32::ERROR_SXS_PROTECTION_CATALOG_NOT_VALID),
            WIN32::ERROR_SXS_UNTRANSLATABLE_HRESULT => RawError::Kind(WIN32::ERROR_SXS_UNTRANSLATABLE_HRESULT),
            WIN32::ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING => RawError::Kind(WIN32::ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING),
            WIN32::ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE => RawError::Kind(WIN32::ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE),
            WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME => RawError::Kind(WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME),
            WIN32::ERROR_SXS_ASSEMBLY_MISSING => RawError::Kind(WIN32::ERROR_SXS_ASSEMBLY_MISSING),
            WIN32::ERROR_SXS_CORRUPT_ACTIVATION_STACK => RawError::Kind(WIN32::ERROR_SXS_CORRUPT_ACTIVATION_STACK),
            WIN32::ERROR_SXS_CORRUPTION => RawError::Kind(WIN32::ERROR_SXS_CORRUPTION),
            WIN32::ERROR_SXS_EARLY_DEACTIVATION => RawError::Kind(WIN32::ERROR_SXS_EARLY_DEACTIVATION),
            WIN32::ERROR_SXS_INVALID_DEACTIVATION => RawError::Kind(WIN32::ERROR_SXS_INVALID_DEACTIVATION),
            WIN32::ERROR_SXS_MULTIPLE_DEACTIVATION => RawError::Kind(WIN32::ERROR_SXS_MULTIPLE_DEACTIVATION),
            WIN32::ERROR_SXS_PROCESS_TERMINATION_REQUESTED => RawError::Kind(WIN32::ERROR_SXS_PROCESS_TERMINATION_REQUESTED),
            WIN32::ERROR_SXS_RELEASE_ACTIVATION_CONTEXT => RawError::Kind(WIN32::ERROR_SXS_RELEASE_ACTIVATION_CONTEXT),
            WIN32::ERROR_SXS_RELEASE_ACTIVATION_ONTEXT => RawError::Kind(WIN32::ERROR_SXS_RELEASE_ACTIVATION_ONTEXT),
            WIN32::ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY => RawError::Kind(WIN32::ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY),
            WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE => RawError::Kind(WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE),
            WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME => RawError::Kind(WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME),
            WIN32::ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE => RawError::Kind(WIN32::ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE),
            WIN32::ERROR_SXS_IDENTITY_PARSE_ERROR => RawError::Kind(WIN32::ERROR_SXS_IDENTITY_PARSE_ERROR),
            WIN32::ERROR_MALFORMED_SUBSTITUTION_STRING => RawError::Kind(WIN32::ERROR_MALFORMED_SUBSTITUTION_STRING),
            WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN => RawError::Kind(WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN),
            WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN => RawError::Kind(WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN),
            WIN32::ERROR_UNMAPPED_SUBSTITUTION_STRING => RawError::Kind(WIN32::ERROR_UNMAPPED_SUBSTITUTION_STRING),
            WIN32::ERROR_SXS_ASSEMBLY_NOT_LOCKED => RawError::Kind(WIN32::ERROR_SXS_ASSEMBLY_NOT_LOCKED),
            WIN32::ERROR_SXS_COMPONENT_STORE_CORRUPT => RawError::Kind(WIN32::ERROR_SXS_COMPONENT_STORE_CORRUPT),
            WIN32::ERROR_ADVANCED_INSTALLER_FAILED => RawError::Kind(WIN32::ERROR_ADVANCED_INSTALLER_FAILED),
            WIN32::ERROR_XML_ENCODING_MISMATCH => RawError::Kind(WIN32::ERROR_XML_ENCODING_MISMATCH),
            WIN32::ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT => RawError::Kind(WIN32::ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT),
            WIN32::ERROR_SXS_IDENTITIES_DIFFERENT => RawError::Kind(WIN32::ERROR_SXS_IDENTITIES_DIFFERENT),
            WIN32::ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT => RawError::Kind(WIN32::ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT),
            WIN32::ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY => RawError::Kind(WIN32::ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY),
            WIN32::ERROR_SXS_MANIFEST_TOO_BIG => RawError::Kind(WIN32::ERROR_SXS_MANIFEST_TOO_BIG),
            WIN32::ERROR_SXS_SETTING_NOT_REGISTERED => RawError::Kind(WIN32::ERROR_SXS_SETTING_NOT_REGISTERED),
            WIN32::ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE => RawError::Kind(WIN32::ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE),
            WIN32::ERROR_SMI_PRIMITIVE_INSTALLER_FAILED => RawError::Kind(WIN32::ERROR_SMI_PRIMITIVE_INSTALLER_FAILED),
            WIN32::ERROR_GENERIC_COMMAND_FAILED => RawError::Kind(WIN32::ERROR_GENERIC_COMMAND_FAILED),
            WIN32::ERROR_SXS_FILE_HASH_MISSING => RawError::Kind(WIN32::ERROR_SXS_FILE_HASH_MISSING),
            WIN32::ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS => RawError::Kind(WIN32::ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS),
            WIN32::ERROR_EVT_INVALID_CHANNEL_PATH => RawError::Kind(WIN32::ERROR_EVT_INVALID_CHANNEL_PATH),
            WIN32::ERROR_EVT_INVALID_QUERY => RawError::Kind(WIN32::ERROR_EVT_INVALID_QUERY),
            WIN32::ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND),
            WIN32::ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND),
            WIN32::ERROR_EVT_INVALID_PUBLISHER_NAME => RawError::Kind(WIN32::ERROR_EVT_INVALID_PUBLISHER_NAME),
            WIN32::ERROR_EVT_INVALID_EVENT_DATA => RawError::Kind(WIN32::ERROR_EVT_INVALID_EVENT_DATA),
            WIN32::ERROR_EVT_CHANNEL_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_CHANNEL_NOT_FOUND),
            WIN32::ERROR_EVT_MALFORMED_XML_TEXT => RawError::Kind(WIN32::ERROR_EVT_MALFORMED_XML_TEXT),
            WIN32::ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL => RawError::Kind(WIN32::ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL),
            WIN32::ERROR_EVT_CONFIGURATION_ERROR => RawError::Kind(WIN32::ERROR_EVT_CONFIGURATION_ERROR),
            WIN32::ERROR_EVT_QUERY_RESULT_STALE => RawError::Kind(WIN32::ERROR_EVT_QUERY_RESULT_STALE),
            WIN32::ERROR_EVT_QUERY_RESULT_INVALID_POSITION => RawError::Kind(WIN32::ERROR_EVT_QUERY_RESULT_INVALID_POSITION),
            WIN32::ERROR_EVT_NON_VALIDATING_MSXML => RawError::Kind(WIN32::ERROR_EVT_NON_VALIDATING_MSXML),
            WIN32::ERROR_EVT_FILTER_ALREADYSCOPED => RawError::Kind(WIN32::ERROR_EVT_FILTER_ALREADYSCOPED),
            WIN32::ERROR_EVT_FILTER_NOTELTSET => RawError::Kind(WIN32::ERROR_EVT_FILTER_NOTELTSET),
            WIN32::ERROR_EVT_FILTER_INVARG => RawError::Kind(WIN32::ERROR_EVT_FILTER_INVARG),
            WIN32::ERROR_EVT_FILTER_INVTEST => RawError::Kind(WIN32::ERROR_EVT_FILTER_INVTEST),
            WIN32::ERROR_EVT_FILTER_INVTYPE => RawError::Kind(WIN32::ERROR_EVT_FILTER_INVTYPE),
            WIN32::ERROR_EVT_FILTER_PARSEERR => RawError::Kind(WIN32::ERROR_EVT_FILTER_PARSEERR),
            WIN32::ERROR_EVT_FILTER_UNSUPPORTEDOP => RawError::Kind(WIN32::ERROR_EVT_FILTER_UNSUPPORTEDOP),
            WIN32::ERROR_EVT_FILTER_UNEXPECTEDTOKEN => RawError::Kind(WIN32::ERROR_EVT_FILTER_UNEXPECTEDTOKEN),
            WIN32::ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL => RawError::Kind(WIN32::ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL),
            WIN32::ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE => RawError::Kind(WIN32::ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE),
            WIN32::ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE => RawError::Kind(WIN32::ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE),
            WIN32::ERROR_EVT_CHANNEL_CANNOT_ACTIVATE => RawError::Kind(WIN32::ERROR_EVT_CHANNEL_CANNOT_ACTIVATE),
            WIN32::ERROR_EVT_FILTER_TOO_COMPLEX => RawError::Kind(WIN32::ERROR_EVT_FILTER_TOO_COMPLEX),
            WIN32::ERROR_EVT_MESSAGE_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_MESSAGE_NOT_FOUND),
            WIN32::ERROR_EVT_MESSAGE_ID_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_MESSAGE_ID_NOT_FOUND),
            WIN32::ERROR_EVT_UNRESOLVED_VALUE_INSERT => RawError::Kind(WIN32::ERROR_EVT_UNRESOLVED_VALUE_INSERT),
            WIN32::ERROR_EVT_UNRESOLVED_PARAMETER_INSERT => RawError::Kind(WIN32::ERROR_EVT_UNRESOLVED_PARAMETER_INSERT),
            WIN32::ERROR_EVT_MAX_INSERTS_REACHED => RawError::Kind(WIN32::ERROR_EVT_MAX_INSERTS_REACHED),
            WIN32::ERROR_EVT_EVENT_DEFINITION_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_EVENT_DEFINITION_NOT_FOUND),
            WIN32::ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND => RawError::Kind(WIN32::ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND),
            WIN32::ERROR_EVT_VERSION_TOO_OLD => RawError::Kind(WIN32::ERROR_EVT_VERSION_TOO_OLD),
            WIN32::ERROR_EVT_VERSION_TOO_NEW => RawError::Kind(WIN32::ERROR_EVT_VERSION_TOO_NEW),
            WIN32::ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY => RawError::Kind(WIN32::ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY),
            WIN32::ERROR_EVT_PUBLISHER_DISABLED => RawError::Kind(WIN32::ERROR_EVT_PUBLISHER_DISABLED),
            WIN32::ERROR_EVT_FILTER_OUT_OF_RANGE => RawError::Kind(WIN32::ERROR_EVT_FILTER_OUT_OF_RANGE),
            WIN32::ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE => RawError::Kind(WIN32::ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE),
            WIN32::ERROR_EC_LOG_DISABLED => RawError::Kind(WIN32::ERROR_EC_LOG_DISABLED),
            WIN32::ERROR_EC_CIRCULAR_FORWARDING => RawError::Kind(WIN32::ERROR_EC_CIRCULAR_FORWARDING),
            WIN32::ERROR_EC_CREDSTORE_FULL => RawError::Kind(WIN32::ERROR_EC_CREDSTORE_FULL),
            WIN32::ERROR_EC_CRED_NOT_FOUND => RawError::Kind(WIN32::ERROR_EC_CRED_NOT_FOUND),
            WIN32::ERROR_EC_NO_ACTIVE_CHANNEL => RawError::Kind(WIN32::ERROR_EC_NO_ACTIVE_CHANNEL),
            WIN32::ERROR_MUI_FILE_NOT_FOUND => RawError::Kind(WIN32::ERROR_MUI_FILE_NOT_FOUND),
            WIN32::ERROR_MUI_INVALID_FILE => RawError::Kind(WIN32::ERROR_MUI_INVALID_FILE),
            WIN32::ERROR_MUI_INVALID_RC_CONFIG => RawError::Kind(WIN32::ERROR_MUI_INVALID_RC_CONFIG),
            WIN32::ERROR_MUI_INVALID_LOCALE_NAME => RawError::Kind(WIN32::ERROR_MUI_INVALID_LOCALE_NAME),
            WIN32::ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME => RawError::Kind(WIN32::ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME),
            WIN32::ERROR_MUI_FILE_NOT_LOADED => RawError::Kind(WIN32::ERROR_MUI_FILE_NOT_LOADED),
            WIN32::ERROR_RESOURCE_ENUM_USER_STOP => RawError::Kind(WIN32::ERROR_RESOURCE_ENUM_USER_STOP),
            WIN32::ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED => RawError::Kind(WIN32::ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED),
            WIN32::ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME => RawError::Kind(WIN32::ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME),
            WIN32::ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE => RawError::Kind(WIN32::ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE),
            WIN32::ERROR_MRM_INVALID_PRICONFIG => RawError::Kind(WIN32::ERROR_MRM_INVALID_PRICONFIG),
            WIN32::ERROR_MRM_INVALID_FILE_TYPE => RawError::Kind(WIN32::ERROR_MRM_INVALID_FILE_TYPE),
            WIN32::ERROR_MRM_UNKNOWN_QUALIFIER => RawError::Kind(WIN32::ERROR_MRM_UNKNOWN_QUALIFIER),
            WIN32::ERROR_MRM_INVALID_QUALIFIER_VALUE => RawError::Kind(WIN32::ERROR_MRM_INVALID_QUALIFIER_VALUE),
            WIN32::ERROR_MRM_NO_CANDIDATE => RawError::Kind(WIN32::ERROR_MRM_NO_CANDIDATE),
            WIN32::ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE => RawError::Kind(WIN32::ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE),
            WIN32::ERROR_MRM_RESOURCE_TYPE_MISMATCH => RawError::Kind(WIN32::ERROR_MRM_RESOURCE_TYPE_MISMATCH),
            WIN32::ERROR_MRM_DUPLICATE_MAP_NAME => RawError::Kind(WIN32::ERROR_MRM_DUPLICATE_MAP_NAME),
            WIN32::ERROR_MRM_DUPLICATE_ENTRY => RawError::Kind(WIN32::ERROR_MRM_DUPLICATE_ENTRY),
            WIN32::ERROR_MRM_INVALID_RESOURCE_IDENTIFIER => RawError::Kind(WIN32::ERROR_MRM_INVALID_RESOURCE_IDENTIFIER),
            WIN32::ERROR_MRM_FILEPATH_TOO_LONG => RawError::Kind(WIN32::ERROR_MRM_FILEPATH_TOO_LONG),
            WIN32::ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE => RawError::Kind(WIN32::ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE),
            WIN32::ERROR_MRM_INVALID_PRI_FILE => RawError::Kind(WIN32::ERROR_MRM_INVALID_PRI_FILE),
            WIN32::ERROR_MRM_NAMED_RESOURCE_NOT_FOUND => RawError::Kind(WIN32::ERROR_MRM_NAMED_RESOURCE_NOT_FOUND),
            WIN32::ERROR_MRM_MAP_NOT_FOUND => RawError::Kind(WIN32::ERROR_MRM_MAP_NOT_FOUND),
            WIN32::ERROR_MRM_UNSUPPORTED_PROFILE_TYPE => RawError::Kind(WIN32::ERROR_MRM_UNSUPPORTED_PROFILE_TYPE),
            WIN32::ERROR_MRM_INVALID_QUALIFIER_OPERATOR => RawError::Kind(WIN32::ERROR_MRM_INVALID_QUALIFIER_OPERATOR),
            WIN32::ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE => RawError::Kind(WIN32::ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE),
            WIN32::ERROR_MRM_AUTOMERGE_ENABLED => RawError::Kind(WIN32::ERROR_MRM_AUTOMERGE_ENABLED),
            WIN32::ERROR_MRM_TOO_MANY_RESOURCES => RawError::Kind(WIN32::ERROR_MRM_TOO_MANY_RESOURCES),
            WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE => RawError::Kind(WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE),
            WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE => RawError::Kind(WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE),
            WIN32::ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD => RawError::Kind(WIN32::ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD),
            WIN32::ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST => RawError::Kind(WIN32::ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST),
            WIN32::ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT => RawError::Kind(WIN32::ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT),
            WIN32::ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE => RawError::Kind(WIN32::ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE),
            WIN32::ERROR_MRM_GENERATION_COUNT_MISMATCH => RawError::Kind(WIN32::ERROR_MRM_GENERATION_COUNT_MISMATCH),
            WIN32::ERROR_PRI_MERGE_VERSION_MISMATCH => RawError::Kind(WIN32::ERROR_PRI_MERGE_VERSION_MISMATCH),
            WIN32::ERROR_PRI_MERGE_MISSING_SCHEMA => RawError::Kind(WIN32::ERROR_PRI_MERGE_MISSING_SCHEMA),
            WIN32::ERROR_PRI_MERGE_LOAD_FILE_FAILED => RawError::Kind(WIN32::ERROR_PRI_MERGE_LOAD_FILE_FAILED),
            WIN32::ERROR_PRI_MERGE_ADD_FILE_FAILED => RawError::Kind(WIN32::ERROR_PRI_MERGE_ADD_FILE_FAILED),
            WIN32::ERROR_PRI_MERGE_WRITE_FILE_FAILED => RawError::Kind(WIN32::ERROR_PRI_MERGE_WRITE_FILE_FAILED),
            WIN32::ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED),
            WIN32::ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED),
            WIN32::ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED),
            WIN32::ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED => RawError::Kind(WIN32::ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED),
            WIN32::ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED => RawError::Kind(WIN32::ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED),
            WIN32::ERROR_PRI_MERGE_INVALID_FILE_NAME => RawError::Kind(WIN32::ERROR_PRI_MERGE_INVALID_FILE_NAME),
            WIN32::ERROR_MRM_PACKAGE_NOT_FOUND => RawError::Kind(WIN32::ERROR_MRM_PACKAGE_NOT_FOUND),
            WIN32::ERROR_MRM_MISSING_DEFAULT_LANGUAGE => RawError::Kind(WIN32::ERROR_MRM_MISSING_DEFAULT_LANGUAGE),
            WIN32::ERROR_MRM_SCOPE_ITEM_CONFLICT => RawError::Kind(WIN32::ERROR_MRM_SCOPE_ITEM_CONFLICT),
            WIN32::ERROR_MCA_INVALID_CAPABILITIES_STRING => RawError::Kind(WIN32::ERROR_MCA_INVALID_CAPABILITIES_STRING),
            WIN32::ERROR_MCA_INVALID_VCP_VERSION => RawError::Kind(WIN32::ERROR_MCA_INVALID_VCP_VERSION),
            WIN32::ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION => RawError::Kind(WIN32::ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION),
            WIN32::ERROR_MCA_MCCS_VERSION_MISMATCH => RawError::Kind(WIN32::ERROR_MCA_MCCS_VERSION_MISMATCH),
            WIN32::ERROR_MCA_UNSUPPORTED_MCCS_VERSION => RawError::Kind(WIN32::ERROR_MCA_UNSUPPORTED_MCCS_VERSION),
            WIN32::ERROR_MCA_INTERNAL_ERROR => RawError::Kind(WIN32::ERROR_MCA_INTERNAL_ERROR),
            WIN32::ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED => RawError::Kind(WIN32::ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED),
            WIN32::ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE => RawError::Kind(WIN32::ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE),
            WIN32::ERROR_AMBIGUOUS_SYSTEM_DEVICE => RawError::Kind(WIN32::ERROR_AMBIGUOUS_SYSTEM_DEVICE),
            WIN32::ERROR_SYSTEM_DEVICE_NOT_FOUND => RawError::Kind(WIN32::ERROR_SYSTEM_DEVICE_NOT_FOUND),
            WIN32::ERROR_HASH_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_HASH_NOT_SUPPORTED),
            WIN32::ERROR_HASH_NOT_PRESENT => RawError::Kind(WIN32::ERROR_HASH_NOT_PRESENT),
            WIN32::ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED => RawError::Kind(WIN32::ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED),
            WIN32::ERROR_GPIO_CLIENT_INFORMATION_INVALID => RawError::Kind(WIN32::ERROR_GPIO_CLIENT_INFORMATION_INVALID),
            WIN32::ERROR_GPIO_VERSION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_GPIO_VERSION_NOT_SUPPORTED),
            WIN32::ERROR_GPIO_INVALID_REGISTRATION_PACKET => RawError::Kind(WIN32::ERROR_GPIO_INVALID_REGISTRATION_PACKET),
            WIN32::ERROR_GPIO_OPERATION_DENIED => RawError::Kind(WIN32::ERROR_GPIO_OPERATION_DENIED),
            WIN32::ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE => RawError::Kind(WIN32::ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE),
            WIN32::ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED => RawError::Kind(WIN32::ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED),
            WIN32::ERROR_CANNOT_SWITCH_RUNLEVEL => RawError::Kind(WIN32::ERROR_CANNOT_SWITCH_RUNLEVEL),
            WIN32::ERROR_INVALID_RUNLEVEL_SETTING => RawError::Kind(WIN32::ERROR_INVALID_RUNLEVEL_SETTING),
            WIN32::ERROR_RUNLEVEL_SWITCH_TIMEOUT => RawError::Kind(WIN32::ERROR_RUNLEVEL_SWITCH_TIMEOUT),
            WIN32::ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT => RawError::Kind(WIN32::ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT),
            WIN32::ERROR_RUNLEVEL_SWITCH_IN_PROGRESS => RawError::Kind(WIN32::ERROR_RUNLEVEL_SWITCH_IN_PROGRESS),
            WIN32::ERROR_SERVICES_FAILED_AUTOSTART => RawError::Kind(WIN32::ERROR_SERVICES_FAILED_AUTOSTART),
            WIN32::ERROR_COM_TASK_STOP_PENDING => RawError::Kind(WIN32::ERROR_COM_TASK_STOP_PENDING),
            WIN32::ERROR_INSTALL_OPEN_PACKAGE_FAILED => RawError::Kind(WIN32::ERROR_INSTALL_OPEN_PACKAGE_FAILED),
            WIN32::ERROR_INSTALL_PACKAGE_NOT_FOUND => RawError::Kind(WIN32::ERROR_INSTALL_PACKAGE_NOT_FOUND),
            WIN32::ERROR_INSTALL_INVALID_PACKAGE => RawError::Kind(WIN32::ERROR_INSTALL_INVALID_PACKAGE),
            WIN32::ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED => RawError::Kind(WIN32::ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED),
            WIN32::ERROR_INSTALL_OUT_OF_DISK_SPACE => RawError::Kind(WIN32::ERROR_INSTALL_OUT_OF_DISK_SPACE),
            WIN32::ERROR_INSTALL_NETWORK_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_NETWORK_FAILURE),
            WIN32::ERROR_INSTALL_REGISTRATION_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_REGISTRATION_FAILURE),
            WIN32::ERROR_INSTALL_DEREGISTRATION_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_DEREGISTRATION_FAILURE),
            WIN32::ERROR_INSTALL_CANCEL => RawError::Kind(WIN32::ERROR_INSTALL_CANCEL),
            WIN32::ERROR_INSTALL_FAILED => RawError::Kind(WIN32::ERROR_INSTALL_FAILED),
            WIN32::ERROR_REMOVE_FAILED => RawError::Kind(WIN32::ERROR_REMOVE_FAILED),
            WIN32::ERROR_PACKAGE_ALREADY_EXISTS => RawError::Kind(WIN32::ERROR_PACKAGE_ALREADY_EXISTS),
            WIN32::ERROR_NEEDS_REMEDIATION => RawError::Kind(WIN32::ERROR_NEEDS_REMEDIATION),
            WIN32::ERROR_INSTALL_PREREQUISITE_FAILED => RawError::Kind(WIN32::ERROR_INSTALL_PREREQUISITE_FAILED),
            WIN32::ERROR_PACKAGE_REPOSITORY_CORRUPTED => RawError::Kind(WIN32::ERROR_PACKAGE_REPOSITORY_CORRUPTED),
            WIN32::ERROR_INSTALL_POLICY_FAILURE => RawError::Kind(WIN32::ERROR_INSTALL_POLICY_FAILURE),
            WIN32::ERROR_PACKAGE_UPDATING => RawError::Kind(WIN32::ERROR_PACKAGE_UPDATING),
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_POLICY => RawError::Kind(WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_POLICY),
            WIN32::ERROR_PACKAGES_IN_USE => RawError::Kind(WIN32::ERROR_PACKAGES_IN_USE),
            WIN32::ERROR_RECOVERY_FILE_CORRUPT => RawError::Kind(WIN32::ERROR_RECOVERY_FILE_CORRUPT),
            WIN32::ERROR_INVALID_STAGED_SIGNATURE => RawError::Kind(WIN32::ERROR_INVALID_STAGED_SIGNATURE),
            WIN32::ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED => RawError::Kind(WIN32::ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED),
            WIN32::ERROR_INSTALL_PACKAGE_DOWNGRADE => RawError::Kind(WIN32::ERROR_INSTALL_PACKAGE_DOWNGRADE),
            WIN32::ERROR_SYSTEM_NEEDS_REMEDIATION => RawError::Kind(WIN32::ERROR_SYSTEM_NEEDS_REMEDIATION),
            WIN32::ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN => RawError::Kind(WIN32::ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN),
            WIN32::ERROR_RESILIENCY_FILE_CORRUPT => RawError::Kind(WIN32::ERROR_RESILIENCY_FILE_CORRUPT),
            WIN32::ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING => RawError::Kind(WIN32::ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING),
            WIN32::ERROR_PACKAGE_MOVE_FAILED => RawError::Kind(WIN32::ERROR_PACKAGE_MOVE_FAILED),
            WIN32::ERROR_INSTALL_VOLUME_NOT_EMPTY => RawError::Kind(WIN32::ERROR_INSTALL_VOLUME_NOT_EMPTY),
            WIN32::ERROR_INSTALL_VOLUME_OFFLINE => RawError::Kind(WIN32::ERROR_INSTALL_VOLUME_OFFLINE),
            WIN32::ERROR_INSTALL_VOLUME_CORRUPT => RawError::Kind(WIN32::ERROR_INSTALL_VOLUME_CORRUPT),
            WIN32::ERROR_NEEDS_REGISTRATION => RawError::Kind(WIN32::ERROR_NEEDS_REGISTRATION),
            WIN32::ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE => RawError::Kind(WIN32::ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE),
            WIN32::ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED),
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE => RawError::Kind(WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE),
            WIN32::ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM => RawError::Kind(WIN32::ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM),
            WIN32::ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING => RawError::Kind(WIN32::ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING),
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE => RawError::Kind(WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE),
            WIN32::ERROR_PACKAGE_STAGING_ONHOLD => RawError::Kind(WIN32::ERROR_PACKAGE_STAGING_ONHOLD),
            WIN32::ERROR_INSTALL_INVALID_RELATED_SET_UPDATE => RawError::Kind(WIN32::ERROR_INSTALL_INVALID_RELATED_SET_UPDATE),
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY => RawError::Kind(WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY),
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF => RawError::Kind(WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF),
            WIN32::ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED => RawError::Kind(WIN32::ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED),
            WIN32::ERROR_PACKAGES_REPUTATION_CHECK_FAILED => RawError::Kind(WIN32::ERROR_PACKAGES_REPUTATION_CHECK_FAILED),
            WIN32::ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT => RawError::Kind(WIN32::ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT),
            WIN32::ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED),
            WIN32::ERROR_APPINSTALLER_ACTIVATION_BLOCKED => RawError::Kind(WIN32::ERROR_APPINSTALLER_ACTIVATION_BLOCKED),
            WIN32::ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED => RawError::Kind(WIN32::ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED),
            WIN32::ERROR_APPX_RAW_DATA_WRITE_FAILED => RawError::Kind(WIN32::ERROR_APPX_RAW_DATA_WRITE_FAILED),
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE => RawError::Kind(WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE),
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE => RawError::Kind(WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE),
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY => RawError::Kind(WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY),
            WIN32::ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY => RawError::Kind(WIN32::ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY),
            WIN32::ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER => RawError::Kind(WIN32::ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER),
            WIN32::ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED => RawError::Kind(WIN32::ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED),
            WIN32::ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE => RawError::Kind(WIN32::ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE),
            WIN32::ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES => RawError::Kind(WIN32::ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES),
            WIN32::ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED),
            WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST => RawError::Kind(WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST),
            WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT => RawError::Kind(WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT),
            WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE => RawError::Kind(WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE),
            WIN32::ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE => RawError::Kind(WIN32::ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE),
            WIN32::ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED),
            WIN32::ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY => RawError::Kind(WIN32::ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY),
            WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS => RawError::Kind(WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS),
            WIN32::ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED => RawError::Kind(WIN32::ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED),
            WIN32::ERROR_MACHINE_SCOPE_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_MACHINE_SCOPE_NOT_ALLOWED),
            WIN32::ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED => RawError::Kind(WIN32::ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED),
            WIN32::ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE => RawError::Kind(WIN32::ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE),
            WIN32::ERROR_PACKAGE_NOT_REGISTERED_FOR_USER => RawError::Kind(WIN32::ERROR_PACKAGE_NOT_REGISTERED_FOR_USER),
            WIN32::ERROR_PACKAGE_NAME_MISMATCH => RawError::Kind(WIN32::ERROR_PACKAGE_NAME_MISMATCH),
            WIN32::ERROR_APPINSTALLER_URI_IN_USE => RawError::Kind(WIN32::ERROR_APPINSTALLER_URI_IN_USE),
            WIN32::ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM => RawError::Kind(WIN32::ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM),
            WIN32::APPMODEL_ERROR_NO_PACKAGE => RawError::Kind(WIN32::APPMODEL_ERROR_NO_PACKAGE),
            WIN32::APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT => RawError::Kind(WIN32::APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT),
            WIN32::APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT => RawError::Kind(WIN32::APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT),
            WIN32::APPMODEL_ERROR_NO_APPLICATION => RawError::Kind(WIN32::APPMODEL_ERROR_NO_APPLICATION),
            WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED => RawError::Kind(WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED),
            WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID => RawError::Kind(WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID),
            WIN32::APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE => RawError::Kind(WIN32::APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE),
            WIN32::APPMODEL_ERROR_NO_MUTABLE_DIRECTORY => RawError::Kind(WIN32::APPMODEL_ERROR_NO_MUTABLE_DIRECTORY),
            WIN32::ERROR_STATE_LOAD_STORE_FAILED => RawError::Kind(WIN32::ERROR_STATE_LOAD_STORE_FAILED),
            WIN32::ERROR_STATE_GET_VERSION_FAILED => RawError::Kind(WIN32::ERROR_STATE_GET_VERSION_FAILED),
            WIN32::ERROR_STATE_SET_VERSION_FAILED => RawError::Kind(WIN32::ERROR_STATE_SET_VERSION_FAILED),
            WIN32::ERROR_STATE_STRUCTURED_RESET_FAILED => RawError::Kind(WIN32::ERROR_STATE_STRUCTURED_RESET_FAILED),
            WIN32::ERROR_STATE_OPEN_CONTAINER_FAILED => RawError::Kind(WIN32::ERROR_STATE_OPEN_CONTAINER_FAILED),
            WIN32::ERROR_STATE_CREATE_CONTAINER_FAILED => RawError::Kind(WIN32::ERROR_STATE_CREATE_CONTAINER_FAILED),
            WIN32::ERROR_STATE_DELETE_CONTAINER_FAILED => RawError::Kind(WIN32::ERROR_STATE_DELETE_CONTAINER_FAILED),
            WIN32::ERROR_STATE_READ_SETTING_FAILED => RawError::Kind(WIN32::ERROR_STATE_READ_SETTING_FAILED),
            WIN32::ERROR_STATE_WRITE_SETTING_FAILED => RawError::Kind(WIN32::ERROR_STATE_WRITE_SETTING_FAILED),
            WIN32::ERROR_STATE_DELETE_SETTING_FAILED => RawError::Kind(WIN32::ERROR_STATE_DELETE_SETTING_FAILED),
            WIN32::ERROR_STATE_QUERY_SETTING_FAILED => RawError::Kind(WIN32::ERROR_STATE_QUERY_SETTING_FAILED),
            WIN32::ERROR_STATE_READ_COMPOSITE_SETTING_FAILED => RawError::Kind(WIN32::ERROR_STATE_READ_COMPOSITE_SETTING_FAILED),
            WIN32::ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED => RawError::Kind(WIN32::ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED),
            WIN32::ERROR_STATE_ENUMERATE_CONTAINER_FAILED => RawError::Kind(WIN32::ERROR_STATE_ENUMERATE_CONTAINER_FAILED),
            WIN32::ERROR_STATE_ENUMERATE_SETTINGS_FAILED => RawError::Kind(WIN32::ERROR_STATE_ENUMERATE_SETTINGS_FAILED),
            WIN32::ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED),
            WIN32::ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED),
            WIN32::ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED),
            WIN32::ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED => RawError::Kind(WIN32::ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED),
            WIN32::ERROR_API_UNAVAILABLE => RawError::Kind(WIN32::ERROR_API_UNAVAILABLE),
            WIN32::STORE_ERROR_UNLICENSED => RawError::Kind(WIN32::STORE_ERROR_UNLICENSED),
            WIN32::STORE_ERROR_UNLICENSED_USER => RawError::Kind(WIN32::STORE_ERROR_UNLICENSED_USER),
            WIN32::STORE_ERROR_PENDING_COM_TRANSACTION => RawError::Kind(WIN32::STORE_ERROR_PENDING_COM_TRANSACTION),
            WIN32::STORE_ERROR_LICENSE_REVOKED => RawError::Kind(WIN32::STORE_ERROR_LICENSE_REVOKED),
            WIN32::ERROR_SUCCESS => RawError::Kind(WIN32::ERROR_SUCCESS),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WIN32::ERROR_INVALID_FUNCTION => "Incorrect function.",
            WIN32::PDH_CSTATUS_NEW_DATA => "The return data value is valid and different from the last sample.",
            WIN32::ERROR_FILE_NOT_FOUND => "The system cannot find the file specified.",
            WIN32::ERROR_PATH_NOT_FOUND => "The system cannot find the path specified.",
            WIN32::E_PATH_NOT_FOUND => "The system cannot find the path specified.",
            WIN32::ERROR_TOO_MANY_OPEN_FILES => "The system cannot open the file.",
            WIN32::ERROR_ACCESS_DENIED => "Access is denied.",
            WIN32::E_ACCESSDENIED => "General access denied error.",
            WIN32::ERROR_INVALID_HANDLE => "The handle is invalid.",
            WIN32::E_HANDLE => "Invalid handle.",
            WIN32::ERROR_ARENA_TRASHED => "The storage control blocks were destroyed.",
            WIN32::ERROR_NOT_ENOUGH_MEMORY => "Not enough memory resources are available to process this command.",
            WIN32::ERROR_INVALID_BLOCK => "The storage control block address is invalid.",
            WIN32::ERROR_BAD_ENVIRONMENT => "The environment is incorrect.",
            WIN32::ERROR_BAD_FORMAT => "An attempt was made to load a program with an incorrect format.",
            WIN32::ERROR_INVALID_ACCESS => "The access code is invalid.",
            WIN32::ERROR_INVALID_DATA => "The data is invalid.",
            WIN32::E_OUTOFMEMORY => "Ran out of memory.",
            WIN32::ERROR_OUTOFMEMORY => "Not enough memory resources are available to complete this operation.",
            WIN32::DDERR_OUTOFMEMORY => "DirectDraw does not have enough memory to perform the operation.",
            WIN32::ERROR_INVALID_DRIVE => "The system cannot find the drive specified.",
            WIN32::ERROR_CURRENT_DIRECTORY => "The directory cannot be removed.",
            WIN32::ERROR_NOT_SAME_DEVICE => "The system cannot move the file to a different disk drive.",
            WIN32::ERROR_NO_MORE_FILES => "There are no more files.",
            WIN32::ERROR_WRITE_PROTECT => "The media is write protected.",
            WIN32::ERROR_BAD_UNIT => "The system cannot find the device specified.",
            WIN32::ERROR_NOT_READY => "The device is not ready.",
            WIN32::ERROR_BAD_COMMAND => "The device does not recognize the command.",
            WIN32::ERROR_CRC => "Data error (cyclic redundancy check).",
            WIN32::ERROR_BAD_LENGTH => "The program issued a command but the command length is incorrect.",
            WIN32::ERROR_SEEK => "The drive cannot locate a specific area or track on the disk.",
            WIN32::ERROR_NOT_DOS_DISK => "The specified disk or diskette cannot be accessed.",
            WIN32::ERROR_SECTOR_NOT_FOUND => "The drive cannot find the sector requested.",
            WIN32::ERROR_OUT_OF_PAPER => "The printer is out of paper.",
            WIN32::ERROR_WRITE_FAULT => "The system cannot write to the specified device.",
            WIN32::ERROR_READ_FAULT => "The system cannot read from the specified device.",
            WIN32::ERROR_GEN_FAILURE => "A device attached to the system is not functioning.",
            WIN32::ERROR_SHARING_VIOLATION => "The process cannot access the file because it is being used by another process.",
            WIN32::E_SHARING_VIOLATION => "The output file is in use.",
            WIN32::ERROR_LOCK_VIOLATION => "The process cannot access the file because another process has locked a portion of the file.",
            WIN32::ERROR_WRONG_DISK => "The wrong diskette is in the drive.",
            WIN32::ERROR_SHARING_BUFFER_EXCEEDED => "Too many files opened for sharing.",
            WIN32::ERROR_HANDLE_EOF => "Reached the end of the file.",
            WIN32::ERROR_HANDLE_DISK_FULL => "The disk is full.",
            WIN32::ERROR_NOT_SUPPORTED => "The request is not supported.",
            WIN32::ERROR_REM_NOT_LIST => "Windows cannot find the network path. Verify that the network path is correct and the destination computer is not busy or turned off. If Windows still cannot find the network path, contact your network administrator.",
            WIN32::ERROR_DUP_NAME => "You were not connected because a duplicate name exists on the network. If joining a domain, go to System in Control Panel to change the computer name and try again. If joining a workgroup, choose another workgroup name.",
            WIN32::ERROR_BAD_NETPATH => "The network path was not found.",
            WIN32::ERROR_NETWORK_BUSY => "The network is busy.",
            WIN32::ERROR_DEV_NOT_EXIST => "The specified network resource or device is no longer available.",
            WIN32::ERROR_TOO_MANY_CMDS => "The network BIOS command limit has been reached.",
            WIN32::ERROR_ADAP_HDW_ERR => "A network adapter hardware error occurred.",
            WIN32::ERROR_BAD_NET_RESP => "The specified server cannot perform the requested operation.",
            WIN32::ERROR_UNEXP_NET_ERR => "An unexpected network error occurred.",
            WIN32::ERROR_BAD_REM_ADAP => "The remote adapter is not compatible.",
            WIN32::ERROR_PRINTQ_FULL => "The printer queue is full.",
            WIN32::ERROR_NO_SPOOL_SPACE => "Space to store the file waiting to be printed is not available on the server.",
            WIN32::ERROR_PRINT_CANCELLED => "Your file waiting to be printed was deleted.",
            WIN32::ERROR_NETNAME_DELETED => "The specified network name is no longer available.",
            WIN32::ERROR_NETWORK_ACCESS_DENIED => "Network access is denied.",
            WIN32::ERROR_BAD_DEV_TYPE => "The network resource type is not correct.",
            WIN32::ERROR_BAD_NET_NAME => "The network name cannot be found.",
            WIN32::ERROR_TOO_MANY_NAMES => "The name limit for the local computer network adapter card was exceeded.",
            WIN32::ERROR_TOO_MANY_SESS => "The network BIOS session limit was exceeded.",
            WIN32::ERROR_SHARING_PAUSED => "The remote server has been paused or is in the process of being started.",
            WIN32::ERROR_REQ_NOT_ACCEP => "No more connections can be made to this remote computer at this time because there are already as many connections as the computer can accept.",
            WIN32::ERROR_REDIR_PAUSED => "The specified printer or disk device has been paused.",
            WIN32::ERROR_FILE_EXISTS => "The file exists.",
            WIN32::ERROR_CANNOT_MAKE => "The directory or file cannot be created.",
            WIN32::ERROR_FAIL_I24 => "Fail on INT 24.",
            WIN32::ERROR_OUT_OF_STRUCTURES => "Storage to process this request is not available.",
            WIN32::ERROR_ALREADY_ASSIGNED => "The local device name is already in use.",
            WIN32::ERROR_INVALID_PASSWORD => "The specified network password is not correct.",
            WIN32::ERROR_INVALID_PARAMETER => "The parameter is incorrect.",
            WIN32::E_INVALIDARG => "One or more arguments are invalid.",
            WIN32::DDERR_INVALIDPARAMS => "One or more of the parameters passed to the method are incorrect.",
            WIN32::ERROR_NET_WRITE_FAULT => "A write fault occurred on the network.",
            WIN32::ERROR_NO_PROC_SLOTS => "The system cannot start another process at this time.",
            WIN32::ERROR_TOO_MANY_SEMAPHORES => "Cannot create another system semaphore.",
            WIN32::ERROR_EXCL_SEM_ALREADY_OWNED => "The exclusive semaphore is owned by another process.",
            WIN32::ERROR_SEM_IS_SET => "The semaphore is set and cannot be closed.",
            WIN32::ERROR_TOO_MANY_SEM_REQUESTS => "The semaphore cannot be set again.",
            WIN32::ERROR_INVALID_AT_INTERRUPT_TIME => "Cannot request exclusive semaphores at interrupt time.",
            WIN32::ERROR_SEM_OWNER_DIED => "The previous ownership of this semaphore has ended.",
            WIN32::ERROR_SEM_USER_LIMIT => "Insert the diskette for drive %1.",
            WIN32::ERROR_DISK_CHANGE => "The program stopped because an alternate diskette was not inserted.",
            WIN32::ERROR_DRIVE_LOCKED => "The disk is in use or locked by another process.",
            WIN32::ERROR_BROKEN_PIPE => "The pipe has been ended.",
            WIN32::ERROR_OPEN_FAILED => "The system cannot open the device or file specified.",
            WIN32::ERROR_BUFFER_OVERFLOW => "The file name is too long.",
            WIN32::ERROR_DISK_FULL => "There is not enough space on the disk.",
            WIN32::ERROR_NO_MORE_SEARCH_HANDLES => "No more internal file identifiers available.",
            WIN32::ERROR_INVALID_TARGET_HANDLE => "The target internal file identifier is incorrect.",
            WIN32::ERROR_INVALID_CATEGORY => "The IOCTL call made by the application program is not correct.",
            WIN32::ERROR_INVALID_VERIFY_SWITCH => "The verify-on-write switch parameter value is not correct.",
            WIN32::ERROR_BAD_DRIVER_LEVEL => "The system does not support the command requested.",
            WIN32::ERROR_CALL_NOT_IMPLEMENTED => "This function is not supported on this system.",
            WIN32::ERROR_SEM_TIMEOUT => "The semaphore timeout period has expired.",
            WIN32::ERROR_INSUFFICIENT_BUFFER => "The data area passed to a system call is too small.",
            WIN32::ERROR_INVALID_NAME => "The filename, directory name, or volume label syntax is incorrect.",
            WIN32::ERROR_INVALID_LEVEL => "The system call level is not correct.",
            WIN32::ERROR_NO_VOLUME_LABEL => "The disk has no volume label.",
            WIN32::ERROR_MOD_NOT_FOUND => "The specified module could not be found.",
            WIN32::ERROR_PROC_NOT_FOUND => "The specified procedure could not be found.",
            WIN32::ERROR_WAIT_NO_CHILDREN => "There are no child processes to wait for.",
            WIN32::ERROR_CHILD_NOT_COMPLETE => "The %1 application cannot be run in Win32 mode.",
            WIN32::ERROR_DIRECT_ACCESS_HANDLE => "Attempt to use a file handle to an open disk partition for an operation other than raw disk I/O.",
            WIN32::ERROR_NEGATIVE_SEEK => "An attempt was made to move the file pointer before the beginning of the file.",
            WIN32::ERROR_SEEK_ON_DEVICE => "The file pointer cannot be set on the specified device or file.",
            WIN32::ERROR_IS_JOIN_TARGET => "A JOIN or SUBST command cannot be used for a drive that contains previously joined drives.",
            WIN32::ERROR_IS_JOINED => "An attempt was made to use a JOIN or SUBST command on a drive that has already been joined.",
            WIN32::ERROR_IS_SUBSTED => "An attempt was made to use a JOIN or SUBST command on a drive that has already been substituted.",
            WIN32::ERROR_NOT_JOINED => "The system tried to delete the JOIN of a drive that is not joined.",
            WIN32::ERROR_NOT_SUBSTED => "The system tried to delete the substitution of a drive that is not substituted.",
            WIN32::ERROR_JOIN_TO_JOIN => "The system tried to join a drive to a directory on a joined drive.",
            WIN32::ERROR_SUBST_TO_SUBST => "The system tried to substitute a drive to a directory on a substituted drive.",
            WIN32::ERROR_JOIN_TO_SUBST => "The system tried to join a drive to a directory on a substituted drive.",
            WIN32::ERROR_SUBST_TO_JOIN => "The system tried to SUBST a drive to a directory on a joined drive.",
            WIN32::ERROR_BUSY_DRIVE => "The system cannot perform a JOIN or SUBST at this time.",
            WIN32::ERROR_SAME_DRIVE => "The system cannot join or substitute a drive to or for a directory on the same drive.",
            WIN32::ERROR_DIR_NOT_ROOT => "The directory is not a subdirectory of the root directory.",
            WIN32::ERROR_DIR_NOT_EMPTY => "The directory is not empty.",
            WIN32::ERROR_IS_SUBST_PATH => "The path specified is being used in a substitute.",
            WIN32::ERROR_IS_JOIN_PATH => "Not enough resources are available to process this command.",
            WIN32::ERROR_PATH_BUSY => "The path specified cannot be used at this time.",
            WIN32::ERROR_IS_SUBST_TARGET => "An attempt was made to join or substitute a drive for which a directory on the drive is the target of a previous substitute.",
            WIN32::ERROR_SYSTEM_TRACE => "System trace information was not specified in your CONFIG.SYS file, or tracing is disallowed.",
            WIN32::ERROR_INVALID_EVENT_COUNT => "The number of specified semaphore events for DosMuxSemWait is not correct.",
            WIN32::ERROR_TOO_MANY_MUXWAITERS => "DosMuxSemWait did not execute; too many semaphores are already set.",
            WIN32::ERROR_INVALID_LIST_FORMAT => "The DosMuxSemWait list is not correct.",
            WIN32::ERROR_LABEL_TOO_LONG => "The volume label you entered exceeds the label character limit of the target file system.",
            WIN32::ERROR_TOO_MANY_TCBS => "Cannot create another thread.",
            WIN32::ERROR_SIGNAL_REFUSED => "The recipient process has refused the signal.",
            WIN32::ERROR_DISCARDED => "The segment is already discarded and cannot be locked.",
            WIN32::ERROR_NOT_LOCKED => "The segment is already unlocked.",
            WIN32::ERROR_BAD_THREADID_ADDR => "The address for the thread ID is not correct.",
            WIN32::ERROR_BAD_ARGUMENTS => "One or more arguments are not correct.",
            WIN32::ERROR_BAD_PATHNAME => "The specified path is invalid.",
            WIN32::ERROR_SIGNAL_PENDING => "A signal is already pending.",
            WIN32::ERROR_MAX_THRDS_REACHED => "No more threads can be created in the system.",
            WIN32::ERROR_LOCK_FAILED => "Unable to lock a region of a file.",
            WIN32::ERROR_BUSY => "The requested resource is in use.",
            WIN32::ERROR_DEVICE_SUPPORT_IN_PROGRESS => "Device's command support detection is in progress.",
            WIN32::ERROR_CANCEL_VIOLATION => "A lock request was not outstanding for the supplied cancel region.",
            WIN32::ERROR_ATOMIC_LOCKS_NOT_SUPPORTED => "The file system does not support atomic changes to the lock type.",
            WIN32::ERROR_INVALID_SEGMENT_NUMBER => "The system detected a segment number that was not correct.",
            WIN32::ERROR_INVALID_ORDINAL => "The operating system cannot run %1.",
            WIN32::ERROR_ALREADY_EXISTS => "Cannot create a file when that file already exists.",
            WIN32::ERROR_INVALID_FLAG_NUMBER => "The flag passed is not correct.",
            WIN32::ERROR_SEM_NOT_FOUND => "The specified system semaphore name was not found.",
            WIN32::ERROR_INVALID_STARTING_CODESEG => "The operating system cannot run %1.",
            WIN32::ERROR_INVALID_STACKSEG => "The operating system cannot run %1.",
            WIN32::ERROR_INVALID_MODULETYPE => "The operating system cannot run %1.",
            WIN32::ERROR_INVALID_EXE_SIGNATURE => "Cannot run %1 in Win32 mode.",
            WIN32::ERROR_EXE_MARKED_INVALID => "The operating system cannot run %1.",
            WIN32::ERROR_BAD_EXE_FORMAT => "%1 is not a valid Win32 application.",
            WIN32::ERROR_ITERATED_DATA_EXCEEDS_64k => "The operating system cannot run %1.",
            WIN32::ERROR_INVALID_MINALLOCSIZE => "The operating system cannot run %1.",
            WIN32::ERROR_DYNLINK_FROM_INVALID_RING => "The operating system cannot run this application program.",
            WIN32::ERROR_IOPL_NOT_ENABLED => "The operating system is not presently configured to run this application.",
            WIN32::ERROR_INVALID_SEGDPL => "The operating system cannot run %1.",
            WIN32::ERROR_AUTODATASEG_EXCEEDS_64k => "The operating system cannot run this application program.",
            WIN32::ERROR_RING2SEG_MUST_BE_MOVABLE => "The code segment cannot be greater than or equal to 64K.",
            WIN32::ERROR_RELOC_CHAIN_XEEDS_SEGLIM => "The operating system cannot run %1.",
            WIN32::ERROR_INFLOOP_IN_RELOC_CHAIN => "The operating system cannot run %1.",
            WIN32::ERROR_ENVVAR_NOT_FOUND => "The system could not find the environment option that was entered.",
            WIN32::ERROR_NO_SIGNAL_SENT => "No process in the command subtree has a signal handler.",
            WIN32::ERROR_FILENAME_EXCED_RANGE => "The filename or extension is too long.",
            WIN32::ERROR_RING2_STACK_IN_USE => "The ring 2 stack is in use.",
            WIN32::ERROR_META_EXPANSION_TOO_LONG => "The global filename characters, * or ?, are entered incorrectly or too many global filename characters are specified.",
            WIN32::ERROR_INVALID_SIGNAL_NUMBER => "The signal being posted is not correct.",
            WIN32::ERROR_THREAD_1_INACTIVE => "The signal handler cannot be set.",
            WIN32::ERROR_LOCKED => "The segment is locked and cannot be reallocated.",
            WIN32::ERROR_TOO_MANY_MODULES => "Too many dynamic-link modules are attached to this program or dynamic-link module.",
            WIN32::ERROR_NESTING_NOT_ALLOWED => "Cannot nest calls to LoadModule.",
            WIN32::ERROR_EXE_MACHINE_TYPE_MISMATCH => "This version of %1 is not compatible with the version of Windows you're running. Check your computer's system information and then contact the software publisher.",
            WIN32::ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY => "The image file %1 is signed, unable to modify.",
            WIN32::ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY => "The image file %1 is strong signed, unable to modify.",
            WIN32::ERROR_FILE_CHECKED_OUT => "This file is checked out or locked for editing by another user.",
            WIN32::ERROR_CHECKOUT_REQUIRED => "The file must be checked out before saving changes.",
            WIN32::ERROR_BAD_FILE_TYPE => "The file type being saved or retrieved has been blocked.",
            WIN32::ERROR_FILE_TOO_LARGE => "The file size exceeds the limit allowed and cannot be saved.",
            WIN32::ERROR_FORMS_AUTH_REQUIRED => "Access Denied. Before opening files in this location, you must first add the web site to your trusted sites list, browse to the web site, and select the option to login automatically.",
            WIN32::ERROR_VIRUS_INFECTED => "Operation did not complete successfully because the file contains a virus or potentially unwanted software.",
            WIN32::ERROR_VIRUS_DELETED => "This file contains a virus or potentially unwanted software and cannot be opened. Due to the nature of this virus or potentially unwanted software, the file has been removed from this location.",
            WIN32::ERROR_PIPE_LOCAL => "The pipe is local.",
            WIN32::ERROR_BAD_PIPE => "The pipe state is invalid.",
            WIN32::ERROR_PIPE_BUSY => "All pipe instances are busy.",
            WIN32::ERROR_NO_DATA => "The pipe is being closed.",
            WIN32::ERROR_PIPE_NOT_CONNECTED => "No process is on the other end of the pipe.",
            WIN32::ERROR_MORE_DATA => "More data is available.",
            WIN32::ERROR_NO_WORK_DONE => "The action requested resulted in no work being done. Error-style clean-up has been performed.",
            WIN32::ERROR_VC_DISCONNECTED => "The session was canceled.",
            WIN32::ERROR_INVALID_EA_NAME => "The specified extended attribute name was invalid.",
            WIN32::ERROR_EA_LIST_INCONSISTENT => "The extended attributes are inconsistent.",
            WIN32::WAIT_TIMEOUT => "The wait operation timed out.",
            WIN32::ERROR_NO_MORE_ITEMS => "No more data is available.",
            WIN32::ERROR_CANNOT_COPY => "The copy functions cannot be used.",
            WIN32::ERROR_DIRECTORY => "The directory name is invalid.",
            WIN32::ERROR_EAS_DIDNT_FIT => "The extended attributes did not fit in the buffer.",
            WIN32::ERROR_EA_FILE_CORRUPT => "The extended attribute file on the mounted file system is corrupt.",
            WIN32::ERROR_EA_TABLE_FULL => "The extended attribute table file is full.",
            WIN32::ERROR_INVALID_EA_HANDLE => "The specified extended attribute handle is invalid.",
            WIN32::ERROR_EAS_NOT_SUPPORTED => "The mounted file system does not support extended attributes.",
            WIN32::ERROR_NOT_OWNER => "Attempt to release mutex not owned by caller.",
            WIN32::ERROR_TOO_MANY_POSTS => "Too many posts were made to a semaphore.",
            WIN32::ERROR_PARTIAL_COPY => "Only part of a ReadProcessMemory or WriteProcessMemory request was completed.",
            WIN32::ERROR_OPLOCK_NOT_GRANTED => "The oplock request is denied.",
            WIN32::ERROR_INVALID_OPLOCK_PROTOCOL => "An invalid oplock acknowledgment was received by the system.",
            WIN32::ERROR_DISK_TOO_FRAGMENTED => "The volume is too fragmented to complete this operation.",
            WIN32::ERROR_DELETE_PENDING => "The file cannot be opened because it is in the process of being deleted.",
            WIN32::ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING => "Short name settings may not be changed on this volume due to the global registry setting.",
            WIN32::ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME => "Short names are not enabled on this volume.",
            WIN32::ERROR_SECURITY_STREAM_IS_INCONSISTENT => "The security stream for the given volume is in an inconsistent state.",
            WIN32::ERROR_INVALID_LOCK_RANGE => "A requested file lock operation cannot be processed due to an invalid byte range.",
            WIN32::ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT => "The subsystem needed to support the image type is not present.",
            WIN32::ERROR_NOTIFICATION_GUID_ALREADY_DEFINED => "The specified file already has a notification GUID associated with it.",
            WIN32::ERROR_INVALID_EXCEPTION_HANDLER => "An invalid exception handler routine has been detected.",
            WIN32::ERROR_DUPLICATE_PRIVILEGES => "Duplicate privileges were specified for the token.",
            WIN32::ERROR_NO_RANGES_PROCESSED => "No ranges for the specified operation were able to be processed.",
            WIN32::ERROR_NOT_ALLOWED_ON_SYSTEM_FILE => "Operation is not allowed on a file system internal file.",
            WIN32::ERROR_DISK_RESOURCES_EXHAUSTED => "The physical resources of this disk have been exhausted.",
            WIN32::ERROR_INVALID_TOKEN => "The token representing the data is invalid.",
            WIN32::ERROR_DEVICE_FEATURE_NOT_SUPPORTED => "The device does not support the command feature.",
            WIN32::ERROR_MR_MID_NOT_FOUND => "The system cannot find message text for message number 0x%1 in the message file for %2.",
            WIN32::ERROR_SCOPE_NOT_FOUND => "The scope specified was not found.",
            WIN32::ERROR_UNDEFINED_SCOPE => "The Central Access Policy specified is not defined on the target machine.",
            WIN32::ERROR_INVALID_CAP => "The Central Access Policy obtained from Active Directory is invalid.",
            WIN32::ERROR_DEVICE_UNREACHABLE => "The device is unreachable.",
            WIN32::ERROR_DEVICE_NO_RESOURCES => "The target device has insufficient resources to complete the operation.",
            WIN32::ERROR_DATA_CHECKSUM_ERROR => "A data integrity checksum error occurred. Data in the file stream is corrupt.",
            WIN32::ERROR_INTERMIXED_KERNEL_EA_OPERATION => "An attempt was made to modify both a KERNEL and normal Extended Attribute (EA) in the same operation.",
            WIN32::ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED => "Device does not support file-level TRIM.",
            WIN32::ERROR_OFFSET_ALIGNMENT_VIOLATION => "The command specified a data offset that does not align to the device's granularity/alignment.",
            WIN32::ERROR_INVALID_FIELD_IN_PARAMETER_LIST => "The command specified an invalid field in its parameter list.",
            WIN32::ERROR_OPERATION_IN_PROGRESS => "An operation is currently in progress with the device.",
            WIN32::ERROR_BAD_DEVICE_PATH => "An attempt was made to send down the command via an invalid path to the target device.",
            WIN32::ERROR_TOO_MANY_DESCRIPTORS => "The command specified a number of descriptors that exceeded the maximum supported by the device.",
            WIN32::ERROR_SCRUB_DATA_DISABLED => "Scrub is disabled on the specified file.",
            WIN32::ERROR_NOT_REDUNDANT_STORAGE => "The storage device does not provide redundancy.",
            WIN32::ERROR_RESIDENT_FILE_NOT_SUPPORTED => "The specified operation is not supported on a resident file.",
            WIN32::ERROR_COMPRESSED_FILE_NOT_SUPPORTED => "The specified operation is not supported on a compressed file.",
            WIN32::ERROR_DIRECTORY_NOT_SUPPORTED => "The specified operation is not supported on a directory.",
            WIN32::ERROR_NOT_READ_FROM_COPY => "The specified copy of the requested data could not be read.",
            WIN32::ERROR_FT_WRITE_FAILURE => "The specified data could not be written to any of the copies.",
            WIN32::ERROR_FT_DI_SCAN_REQUIRED => "One or more copies of data on this device may be out of sync. No writes may be performed until a data integrity scan is completed.",
            WIN32::ERROR_INVALID_KERNEL_INFO_VERSION => "The supplied kernel information version is invalid.",
            WIN32::ERROR_INVALID_PEP_INFO_VERSION => "The supplied PEP information version is invalid.",
            WIN32::ERROR_OBJECT_NOT_EXTERNALLY_BACKED => "This object is not externally backed by any provider.",
            WIN32::ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN => "The external backing provider is not recognized.",
            WIN32::ERROR_COMPRESSION_NOT_BENEFICIAL => "Compressing this object would not save space.",
            WIN32::ERROR_STORAGE_TOPOLOGY_ID_MISMATCH => "The request failed due to a storage topology ID mismatch.",
            WIN32::ERROR_BLOCKED_BY_PARENTAL_CONTROLS => "The operation was blocked by parental controls.",
            WIN32::ERROR_BLOCK_TOO_MANY_REFERENCES => "A file system block being referenced has already reached the maximum reference count and can't be referenced any further.",
            WIN32::ERROR_MARKED_TO_DISALLOW_WRITES => "The requested operation failed because the file stream is marked to disallow writes.",
            WIN32::ERROR_ENCLAVE_FAILURE => "The requested operation failed with an architecture-specific failure code.",
            WIN32::ERROR_FAIL_NOACTION_REBOOT => "No action was taken as a system reboot is required.",
            WIN32::ERROR_FAIL_SHUTDOWN => "The shutdown operation failed.",
            WIN32::ERROR_FAIL_RESTART => "The restart operation failed.",
            WIN32::ERROR_MAX_SESSIONS_REACHED => "The maximum number of sessions has been reached.",
            WIN32::ERROR_NETWORK_ACCESS_DENIED_EDP => "Windows Information Protection policy does not allow access to this network resource.",
            WIN32::ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL => "The device hint name buffer is too small to receive the remaining name.",
            WIN32::ERROR_EDP_POLICY_DENIES_OPERATION => "The requested operation was blocked by Windows Information Protection policy. For more information, contact your system administrator.",
            WIN32::ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED => "The requested operation cannot be performed because hardware or software configuration of the device does not comply with Windows Information Protection under Lock policy. Please, verify that user PIN has been created. For more information, contact your system administrator.",
            WIN32::ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT => "The cloud sync root metadata is corrupted.",
            WIN32::ERROR_CLOUD_FILE_PROVIDER_UNKNOWN => "The Cloud File provider is unknown.",
            WIN32::ERROR_DEVICE_IN_MAINTENANCE => "The device is in maintenance mode.",
            WIN32::ERROR_NOT_SUPPORTED_ON_DAX => "The specified operation is not supported on a DAX volume.",
            WIN32::ERROR_DAX_MAPPING_EXISTS => "The volume has active DAX mappings.",
            WIN32::ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING => "The cloud file provider is not running.",
            WIN32::ERROR_CLOUD_FILE_METADATA_CORRUPT => "The cloud file metadata is corrupt and unreadable.",
            WIN32::ERROR_CLOUD_FILE_METADATA_TOO_LARGE => "The cloud file metadata is too large.",
            WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE => "The cloud file property is too large.",
            WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH => "The cloud file property is possibly corrupt. The on-disk checksum does not match the computed checksum.",
            WIN32::ERROR_CHILD_PROCESS_BLOCKED => "The process creation has been blocked.",
            WIN32::ERROR_STORAGE_LOST_DATA_PERSISTENCE => "The storage device has lost data or persistence.",
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE => "The provider that supports file system virtualization is temporarily unavailable.",
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT => "The metadata for file system virtualization is corrupt and unreadable.",
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY => "The provider that supports file system virtualization is too busy to complete this operation.",
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN => "The provider that supports file system virtualization is unknown.",
            WIN32::ERROR_GDI_HANDLE_LEAK => "GDI handles were potentially leaked by the application.",
            WIN32::ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS => "The maximum number of cloud file properties has been reached.",
            WIN32::ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED => "The version of the cloud file property store is not supported.",
            WIN32::ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED => "The operation could not be completed because the Cloud File metadata version is not supported.",
            WIN32::ERROR_NOT_A_CLOUD_FILE => "The file is not a cloud file.",
            WIN32::ERROR_CLOUD_FILE_NOT_IN_SYNC => "The file is not in sync with the cloud.",
            WIN32::ERROR_CLOUD_FILE_ALREADY_CONNECTED => "The cloud sync root is already connected with another cloud sync provider.",
            WIN32::ERROR_CLOUD_FILE_NOT_SUPPORTED => "The operation is not supported by the cloud sync provider.",
            WIN32::ERROR_CLOUD_FILE_INVALID_REQUEST => "The cloud operation is invalid.",
            WIN32::ERROR_CLOUD_FILE_READ_ONLY_VOLUME => "The cloud operation is not supported on a read-only volume.",
            WIN32::ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY => "The operation is reserved for a connected cloud sync provider.",
            WIN32::ERROR_CLOUD_FILE_VALIDATION_FAILED => "The cloud sync provider failed to validate the downloaded data.",
            WIN32::ERROR_SMB1_NOT_AVAILABLE => "You can't connect to the file share because it's not secure. This share requires the obsolete SMB1 protocol, which is unsafe and could expose your system to attack.",
            WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION => "The virtualization operation is not allowed on the file in its current state.",
            WIN32::ERROR_CLOUD_FILE_AUTHENTICATION_FAILED => "The cloud sync provider failed user authentication.",
            WIN32::ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES => "The cloud sync provider failed to perform the operation due to low system resources.",
            WIN32::ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE => "The cloud sync provider failed to perform the operation due to network being unavailable.",
            WIN32::ERROR_CLOUD_FILE_UNSUCCESSFUL => "The cloud operation was unsuccessful.",
            WIN32::ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT => "The operation is only supported on files under a cloud sync root.",
            WIN32::ERROR_CLOUD_FILE_IN_USE => "The operation cannot be performed on cloud files in use.",
            WIN32::ERROR_CLOUD_FILE_PINNED => "The operation cannot be performed on pinned cloud files.",
            WIN32::ERROR_CLOUD_FILE_REQUEST_ABORTED => "The cloud operation was aborted.",
            WIN32::ERROR_CLOUD_FILE_PROPERTY_CORRUPT => "The cloud file's property store is corrupt.",
            WIN32::ERROR_CLOUD_FILE_ACCESS_DENIED => "Access to the cloud file is denied.",
            WIN32::ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS => "The cloud operation cannot be performed on a file with incompatible hardlinks.",
            WIN32::ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT => "The operation failed due to a conflicting cloud file property lock.",
            WIN32::ERROR_CLOUD_FILE_REQUEST_CANCELED => "The cloud operation was canceled by user.",
            WIN32::ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED => "An externally encrypted syskey has been configured, but the system no longer supports this feature. Please see https://go.microsoft.com/fwlink/?linkid=851152 for more information.",
            WIN32::ERROR_THREAD_MODE_ALREADY_BACKGROUND => "The thread is already in background processing mode.",
            WIN32::ERROR_THREAD_MODE_NOT_BACKGROUND => "The thread is not in background processing mode.",
            WIN32::ERROR_PROCESS_MODE_ALREADY_BACKGROUND => "The process is already in background processing mode.",
            WIN32::ERROR_PROCESS_MODE_NOT_BACKGROUND => "The process is not in background processing mode.",
            WIN32::ERROR_CLOUD_FILE_PROVIDER_TERMINATED => "The cloud file provider exited unexpectedly.",
            WIN32::ERROR_NOT_A_CLOUD_SYNC_ROOT => "The file is not a cloud sync root.",
            WIN32::ERROR_FILE_PROTECTED_UNDER_DPL => "The read or write operation to an encrypted file could not be completed because the file can only be accessed when the device is unlocked.",
            WIN32::ERROR_VOLUME_NOT_CLUSTER_ALIGNED => "The volume is not cluster aligned on the disk.",
            WIN32::ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND => "No physically aligned free space was found on the volume.",
            WIN32::ERROR_APPX_FILE_NOT_ENCRYPTED => "The APPX file can not be accessed because it is not encrypted as expected.",
            WIN32::ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED => "A read or write of raw encrypted data cannot be performed because the file is not encrypted.",
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET => "An invalid file offset in the encrypted data info block was passed for read or write operation of file's raw encrypted data.",
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE => "An invalid offset and length combination in the encrypted data info block was passed for read or write operation of file's raw encrypted data.",
            WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER => "An invalid parameter in the encrypted data info block was passed for read or write operation of file's raw encrypted data.",
            WIN32::ERROR_LINUX_SUBSYSTEM_NOT_PRESENT => "The Windows Subsystem for Linux has not been enabled.",
            WIN32::ERROR_FT_READ_FAILURE => "The specified data could not be read from any of the copies.",
            WIN32::ERROR_STORAGE_RESERVE_ID_INVALID => "The specified storage reserve ID is invalid.",
            WIN32::ERROR_STORAGE_RESERVE_DOES_NOT_EXIST => "The specified storage reserve does not exist.",
            WIN32::ERROR_STORAGE_RESERVE_ALREADY_EXISTS => "The specified storage reserve already exists.",
            WIN32::ERROR_STORAGE_RESERVE_NOT_EMPTY => "The specified storage reserve is not empty.",
            WIN32::ERROR_NOT_A_DAX_VOLUME => "This operation requires a DAX volume.",
            WIN32::ERROR_NOT_DAX_MAPPABLE => "This stream is not DAX mappable.",
            WIN32::ERROR_TIME_SENSITIVE_THREAD => "Operation cannot be performed on a time critical thread.",
            WIN32::ERROR_DPL_NOT_SUPPORTED_FOR_USER => "User data protection is not supported for the current or provided user.",
            WIN32::ERROR_CASE_DIFFERING_NAMES_IN_DIR => "This directory contains entries whose names differ only in case.",
            WIN32::ERROR_FILE_NOT_SUPPORTED => "The file cannot be safely opened because it is not supported by this version of Windows.",
            WIN32::ERROR_CLOUD_FILE_REQUEST_TIMEOUT => "The cloud operation was not completed before the time-out period expired.",
            WIN32::ERROR_NO_TASK_QUEUE => "A task queue is required for this operation but none is available.",
            WIN32::ERROR_SRC_SRV_DLL_LOAD_FAILED => "Failed loading a valid version of srcsrv.dll.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_BTT => "This operation is not supported with BTT enabled.",
            WIN32::ERROR_ENCRYPTION_DISABLED => "This operation cannot be performed because encryption is currently disabled.",
            WIN32::ERROR_ENCRYPTING_METADATA_DISALLOWED => "This encryption operation cannot be performed on filesystem metadata.",
            WIN32::ERROR_CANT_CLEAR_ENCRYPTION_FLAG => "Encryption cannot be cleared on this file/directory because it still has an encrypted attribute.",
            WIN32::ERROR_NO_SUCH_DEVICE => "A device which does not exist was specified.",
            WIN32::ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED => "Dehydration of the cloud file is disallowed by the cloud sync provider.",
            WIN32::ERROR_FILE_SNAP_IN_PROGRESS => "A file snapshot operation was attempted when one is already in progress.",
            WIN32::ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED => "A snapshot of the file cannot be taken because a user-mapped section is present.",
            WIN32::ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED => "The file snapshot operation was terminated because one of the files was modified in a way incompatible with a snapshot operation. Please try again.",
            WIN32::ERROR_FILE_SNAP_IO_NOT_COORDINATED => "An I/O request could not be coordinated with a file snapshot operation.",
            WIN32::ERROR_FILE_SNAP_UNEXPECTED_ERROR => "An unexpected error occurred while processing a file snapshot operation.",
            WIN32::ERROR_FILE_SNAP_INVALID_PARAMETER => "A file snapshot operation received an invalid parameter.",
            WIN32::ERROR_UNSATISFIED_DEPENDENCIES => "The operation could not be completed due to one or more unsatisfied dependencies.",
            WIN32::ERROR_CASE_SENSITIVE_PATH => "The file cannot be opened because the path has a case-sensitive directory.",
            WIN32::ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR => "The filesystem couldn't handle one of the CacheManager's callback error codes.",
            WIN32::ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED => "WSL 2 requires an update to its kernel component. For information please visit https://aka.ms/wsl2kernel.",
            WIN32::ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION => "This action is blocked, but you can choose to allow it. Please refer to the data loss prevention notification for further information.",
            WIN32::ERROR_DLP_POLICY_DENIES_OPERATION => "This action is blocked. Please refer to the data loss prevention notification for further information.",
            WIN32::ERROR_SECURITY_DENIES_OPERATION => "Access is denied because the file contains potentially unwanted software or content the security administrator decided to block.",
            WIN32::ERROR_UNTRUSTED_MOUNT_POINT => "The path cannot be traversed because it contains an untrusted mount point.",
            WIN32::ERROR_DLP_POLICY_SILENTLY_FAIL => "This action is blocked. Please refer to the data loss prevention notification for further information.",
            WIN32::ERROR_CAPAUTHZ_NOT_DEVUNLOCKED => "Neither developer unlocked mode nor side loading mode is enabled on the device.",
            WIN32::ERROR_CAPAUTHZ_CHANGE_TYPE => "Can not change application type during upgrade or re-provision.",
            WIN32::ERROR_CAPAUTHZ_NOT_PROVISIONED => "The application has not been provisioned.",
            WIN32::ERROR_CAPAUTHZ_NOT_AUTHORIZED => "The requested capability can not be authorized for this application.",
            WIN32::ERROR_CAPAUTHZ_NO_POLICY => "There is no capability authorization policy on the device.",
            WIN32::ERROR_CAPAUTHZ_DB_CORRUPTED => "The capability authorization database has been corrupted.",
            WIN32::ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG => "The custom capability's SCCD has an invalid catalog.",
            WIN32::ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY => "None of the authorized entity elements in the SCCD matched the app being installed; either the PFNs don't match, or the element's signature hash doesn't validate.",
            WIN32::ERROR_CAPAUTHZ_SCCD_PARSE_ERROR => "The custom capability's SCCD failed to parse.",
            WIN32::ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED => "The custom capability's SCCD requires developer mode.",
            WIN32::ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH => "There not all declared custom capabilities are found in the SCCD.",
            WIN32::ERROR_CIMFS_IMAGE_CORRUPT => "The CimFS image is corrupt.",
            WIN32::ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED => "The system does not support this version of the CimFS image.",
            WIN32::ERROR_STORAGE_STACK_ACCESS_DENIED => "The storage stack returned STATUS_ACCESS_DENEID for the current operation.",
            WIN32::ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES => "Insufficient Virtual Address resources to complete the operation.",
            WIN32::ERROR_INDEX_OUT_OF_BOUNDS => "The specified index is beyond the bounds of valid range.",
            WIN32::ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT => "The cloud provider failed to acknowledge a message before the time-out expired.",
            WIN32::ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT => "The operation timed out waiting for this device to complete a PnP query-remove request due to a potential hang in its device stack. The system may need to be rebooted to complete the request.",
            WIN32::ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT => "The operation timed out waiting for this device to complete a PnP query-remove request due to a potential hang in the device stack of a related device. The system may need to be rebooted to complete the operation.",
            WIN32::ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT => "The operation timed out waiting for this device to complete a PnP query-remove request due to a potential hang in the device stack of an unrelated device. The system may need to be rebooted to complete the operation.",
            WIN32::ERROR_DEVICE_HARDWARE_ERROR => "The request failed due to a fatal device hardware error.",
            WIN32::ERROR_INVALID_ADDRESS => "Attempt to access invalid address.",
            WIN32::ERROR_HAS_SYSTEM_CRITICAL_FILES => "The volume contains paging, crash dump or other system critical files.",
            WIN32::ERROR_ENCRYPTED_FILE_NOT_SUPPORTED => "The specified operation is not supported on an encrypted file.",
            WIN32::ERROR_SPARSE_FILE_NOT_SUPPORTED => "The specified operation is not supported on a sparse file.",
            WIN32::ERROR_PAGEFILE_NOT_SUPPORTED => "The specified operation is not supported on a pagefile.",
            WIN32::ERROR_VOLUME_NOT_SUPPORTED => "The specified operation is not supported on a volume.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_BYPASSIO => "The specified operation is not supported on a BypassIO enabled file.",
            WIN32::ERROR_NO_BYPASSIO_DRIVER_SUPPORT => "The specified driver does not support BypassIO operations.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_ENCRYPTION => "The specified operation is not supported while encryption is enabled on the target object.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_COMPRESSION => "The specified operation is not supported while compression is enabled on the target object.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_REPLICATION => "The specified operation is not supported while replication is enabled on the target object.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION => "The specified operation is not supported while deduplication is enabled on the target object.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_AUDITING => "The specified operation is not supported while auditing is enabled on the target object.",
            WIN32::ERROR_USER_PROFILE_LOAD => "User profile cannot be loaded.",
            WIN32::ERROR_SESSION_KEY_TOO_SHORT => "The negotiated session key does not meet the minimum length requirement.",
            WIN32::ERROR_ACCESS_DENIED_APPDATA => "Access denied when accessing the user profile.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_MONITORING => "The specified operation is not supported while monitoring is enabled on the target object.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_SNAPSHOT => "The specified operation is not supported while snapshot is enabled on the target object.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION => "The specified operation is not supported while virtualization is enabled on the target object.",
            WIN32::ERROR_BYPASSIO_FLT_NOT_SUPPORTED => "At least one minifilter does not support bypass IO.",
            WIN32::ERROR_DEVICE_RESET_REQUIRED => "The device needs to be reset.",
            WIN32::ERROR_VOLUME_WRITE_ACCESS_DENIED => "The volume is opened for exclusive write access, preventing files from being opened for write access.",
            WIN32::ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE => "The specified operation is not supported on a file opened for cached IO.",
            WIN32::ERROR_FS_METADATA_INCONSISTENT => "The file system encountered a metadata file with inconsistent data.",
            WIN32::ERROR_BLOCK_WEAK_REFERENCE_INVALID => "A file system block being referenced has been modified after containing a weak reference.",
            WIN32::ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID => "The source file system block being referenced has been modified after containing a weak reference.",
            WIN32::ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID => "The target file system block being referenced has been modified after containing a weak reference.",
            WIN32::ERROR_BLOCK_SHARED => "The target file system block is shared between multiple extents.",
            WIN32::ERROR_ARITHMETIC_OVERFLOW => "Arithmetic result exceeded 32 bits.",
            WIN32::ERROR_PIPE_CONNECTED => "There is a process on other end of the pipe.",
            WIN32::ERROR_PIPE_LISTENING => "Waiting for a process to open the other end of the pipe.",
            WIN32::ERROR_VERIFIER_STOP => "Application verifier has found an error in the current process.",
            WIN32::ERROR_ABIOS_ERROR => "An error occurred in the ABIOS subsystem.",
            WIN32::ERROR_WX86_WARNING => "A warning occurred in the WX86 subsystem.",
            WIN32::ERROR_WX86_ERROR => "An error occurred in the WX86 subsystem.",
            WIN32::ERROR_TIMER_NOT_CANCELED => "An attempt was made to cancel or set a timer that has an associated APC and the subject thread is not the thread that originally set the timer with an associated APC routine.",
            WIN32::ERROR_UNWIND => "Unwind exception code.",
            WIN32::ERROR_BAD_STACK => "An invalid or unaligned stack was encountered during an unwind operation.",
            WIN32::ERROR_INVALID_UNWIND_TARGET => "An invalid unwind target was encountered during an unwind operation.",
            WIN32::ERROR_INVALID_PORT_ATTRIBUTES => "Invalid Object Attributes specified to NtCreatePort or invalid Port Attributes specified to NtConnectPort.",
            WIN32::ERROR_PORT_MESSAGE_TOO_LONG => "Length of message passed to NtRequestPort or NtRequestWaitReplyPort was longer than the maximum message allowed by the port.",
            WIN32::ERROR_INVALID_QUOTA_LOWER => "An attempt was made to lower a quota limit below the current usage.",
            WIN32::ERROR_DEVICE_ALREADY_ATTACHED => "An attempt was made to attach to a device that was already attached to another device.",
            WIN32::ERROR_INSTRUCTION_MISALIGNMENT => "An attempt was made to execute an instruction at an unaligned address and the host system does not support unaligned instruction references.",
            WIN32::ERROR_PROFILING_NOT_STARTED => "Profiling not started.",
            WIN32::ERROR_PROFILING_NOT_STOPPED => "Profiling not stopped.",
            WIN32::ERROR_COULD_NOT_INTERPRET => "The passed ACL did not contain the minimum required information.",
            WIN32::ERROR_PROFILING_AT_LIMIT => "The number of active profiling objects is at the maximum and no more may be started.",
            WIN32::ERROR_CANT_WAIT => "Used to indicate that an operation cannot continue without blocking for I/O.",
            WIN32::ERROR_CANT_TERMINATE_SELF => "Indicates that a thread attempted to terminate itself by default (called NtTerminateThread with NULL) and it was the last thread in the current process.",
            WIN32::ERROR_UNEXPECTED_MM_CREATE_ERR => "If an MM error is returned which is not defined in the standard FsRtl filter, it is converted to one of the following errors which is guaranteed to be in the filter.",
            WIN32::ERROR_UNEXPECTED_MM_MAP_ERROR => "If an MM error is returned which is not defined in the standard FsRtl filter, it is converted to one of the following errors which is guaranteed to be in the filter.",
            WIN32::ERROR_UNEXPECTED_MM_EXTEND_ERR => "If an MM error is returned which is not defined in the standard FsRtl filter, it is converted to one of the following errors which is guaranteed to be in the filter.",
            WIN32::ERROR_BAD_FUNCTION_TABLE => "A malformed function table was encountered during an unwind operation.",
            WIN32::ERROR_NO_GUID_TRANSLATION => "Indicates that an attempt was made to assign protection to a file system file or directory and one of the SIDs in the security descriptor could not be translated into a GUID that could be stored by the file system.",
            WIN32::ERROR_INVALID_LDT_SIZE => "Indicates that an attempt was made to grow an LDT by setting its size, or that the size was not an even number of selectors.",
            WIN32::ERROR_INVALID_LDT_OFFSET => "Indicates that the starting value for the LDT information was not an integral multiple of the selector size.",
            WIN32::ERROR_INVALID_LDT_DESCRIPTOR => "Indicates that the user supplied an invalid descriptor when trying to set up Ldt descriptors.",
            WIN32::ERROR_TOO_MANY_THREADS => "Indicates a process has too many threads to perform the requested action. For example, assignment of a primary token may only be performed when a process has zero or one threads.",
            WIN32::ERROR_THREAD_NOT_IN_PROCESS => "An attempt was made to operate on a thread within a specific process, but the thread specified is not in the process specified.",
            WIN32::ERROR_PAGEFILE_QUOTA_EXCEEDED => "Pagefile quota was exceeded.",
            WIN32::ERROR_LOGON_SERVER_CONFLICT => "The Netlogon service cannot start because another Netlogon service running in the domain conflicts with the specified role.",
            WIN32::ERROR_SYNCHRONIZATION_REQUIRED => "The SAM database on a Windows Server is significantly out of synchronization with the copy on the Domain Controller. A complete synchronization is required.",
            WIN32::ERROR_NET_OPEN_FAILED => "The NtCreateFile API failed. This error should never be returned to an application, it is a place holder for the Windows Lan Manager Redirector to use in its internal error mapping routines.",
            WIN32::ERROR_IO_PRIVILEGE_FAILED => "{Privilege Failed}.",
            WIN32::ERROR_CONTROL_C_EXIT => "{Application Exit by CTRL+C} // The application terminated as a result of a CTRL+C.",
            WIN32::ERROR_MISSING_SYSTEMFILE => "{Missing System File}.",
            WIN32::ERROR_UNHANDLED_EXCEPTION => "{Application Error}.",
            WIN32::ERROR_APP_INIT_FAILURE => "{Application Error}.",
            WIN32::ERROR_PAGEFILE_CREATE_FAILED => "{Unable to Create Paging File}.",
            WIN32::ERROR_INVALID_IMAGE_HASH => "Windows cannot verify the digital signature for this file. A recent hardware or software change might have installed a file that is signed incorrectly or damaged, or that might be malicious software from an unknown source.",
            WIN32::ERROR_NO_PAGEFILE => "{No Paging File Specified}.",
            WIN32::ERROR_ILLEGAL_FLOAT_CONTEXT => "{EXCEPTION}.",
            WIN32::ERROR_NO_EVENT_PAIR => "An event pair synchronization operation was performed using the thread specific client/server event pair object, but no event pair object was associated with the thread.",
            WIN32::ERROR_DOMAIN_CTRLR_CONFIG_ERROR => "A Windows Server has an incorrect configuration.",
            WIN32::ERROR_ILLEGAL_CHARACTER => "An illegal character was encountered. For a multi-byte character set this includes a lead byte without a succeeding trail byte. For the Unicode character set this includes the characters 0xFFFF and 0xFFFE.",
            WIN32::ERROR_UNDEFINED_CHARACTER => "The Unicode character is not defined in the Unicode character set installed on the system.",
            WIN32::ERROR_FLOPPY_VOLUME => "The paging file cannot be created on a floppy diskette.",
            WIN32::ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT => "The system BIOS failed to connect a system interrupt to the device or bus for which the device is connected.",
            WIN32::ERROR_BACKUP_CONTROLLER => "This operation is only allowed for the Primary Domain Controller of the domain.",
            WIN32::ERROR_MUTANT_LIMIT_EXCEEDED => "An attempt was made to acquire a mutant such that its maximum count would have been exceeded.",
            WIN32::ERROR_FS_DRIVER_REQUIRED => "A volume has been accessed for which a file system driver is required that has not yet been loaded.",
            WIN32::ERROR_CANNOT_LOAD_REGISTRY_FILE => "{Registry File Failure}.",
            WIN32::ERROR_DEBUG_ATTACH_FAILED => "{Unexpected Failure in DebugActiveProcess}.",
            WIN32::ERROR_SYSTEM_PROCESS_TERMINATED => "{Fatal System Error}.",
            WIN32::ERROR_DATA_NOT_ACCEPTED => "{Data Not Accepted}.",
            WIN32::ERROR_VDM_HARD_ERROR => "NTVDM encountered a hard error.",
            WIN32::ERROR_DRIVER_CANCEL_TIMEOUT => "{Cancel Timeout}.",
            WIN32::ERROR_REPLY_MESSAGE_MISMATCH => "{Reply Message Mismatch}.",
            WIN32::ERROR_LOST_WRITEBEHIND_DATA => "{Delayed Write Failed}.",
            WIN32::ERROR_CLIENT_SERVER_PARAMETERS_INVALID => "The parameter(s) passed to the server in the client/server shared memory window were invalid. Too much data may have been put in the shared memory window.",
            WIN32::ERROR_NOT_TINY_STREAM => "The stream is not a tiny stream.",
            WIN32::ERROR_STACK_OVERFLOW_READ => "The request must be handled by the stack overflow code.",
            WIN32::ERROR_CONVERT_TO_LARGE => "Internal OFS status codes indicating how an allocation operation is handled. Either it is retried after the containing onode is moved or the extent stream is converted to a large stream.",
            WIN32::ERROR_FOUND_OUT_OF_SCOPE => "The attempt to find the object found an object matching by ID on the volume but it is out of the scope of the handle used for the operation.",
            WIN32::ERROR_ALLOCATE_BUCKET => "The bucket array must be grown. Retry transaction after doing so.",
            WIN32::ERROR_MARSHALL_OVERFLOW => "The user/kernel marshalling buffer has overflowed.",
            WIN32::ERROR_INVALID_VARIANT => "The supplied variant structure contains invalid data.",
            WIN32::ERROR_BAD_COMPRESSION_BUFFER => "The specified buffer contains ill-formed data.",
            WIN32::ERROR_AUDIT_FAILED => "{Audit Failed}.",
            WIN32::ERROR_TIMER_RESOLUTION_NOT_SET => "The timer resolution was not previously set by the current process.",
            WIN32::ERROR_INSUFFICIENT_LOGON_INFO => "There is insufficient account information to log you on.",
            WIN32::ERROR_BAD_DLL_ENTRYPOINT => "{Invalid DLL Entrypoint}.",
            WIN32::ERROR_BAD_SERVICE_ENTRYPOINT => "{Invalid Service Callback Entrypoint}.",
            WIN32::ERROR_IP_ADDRESS_CONFLICT1 => "There is an IP address conflict with another system on the network.",
            WIN32::ERROR_IP_ADDRESS_CONFLICT2 => "There is an IP address conflict with another system on the network.",
            WIN32::ERROR_REGISTRY_QUOTA_LIMIT => "{Low On Registry Space}.",
            WIN32::ERROR_NO_CALLBACK_ACTIVE => "A callback return system service cannot be executed when no callback is active.",
            WIN32::ERROR_PWD_TOO_SHORT => "The password provided is too short to meet the policy of your user account.",
            WIN32::ERROR_PWD_TOO_RECENT => "The policy of your user account does not allow you to change passwords too frequently.",
            WIN32::ERROR_PWD_HISTORY_CONFLICT => "You have attempted to change your password to one that you have used in the past.",
            WIN32::ERROR_UNSUPPORTED_COMPRESSION => "The specified compression format is unsupported.",
            WIN32::ERROR_INVALID_HW_PROFILE => "The specified hardware profile configuration is invalid.",
            WIN32::ERROR_INVALID_PLUGPLAY_DEVICE_PATH => "The specified Plug and Play registry device path is invalid.",
            WIN32::ERROR_QUOTA_LIST_INCONSISTENT => "The specified quota list is internally inconsistent with its descriptor.",
            WIN32::ERROR_EVALUATION_EXPIRATION => "{Windows Evaluation Notification}.",
            WIN32::ERROR_ILLEGAL_DLL_RELOCATION => "{Illegal System DLL Relocation}.",
            WIN32::ERROR_DLL_INIT_FAILED_LOGOFF => "{DLL Initialization Failed}.",
            WIN32::ERROR_VALIDATE_CONTINUE => "The validation process needs to continue on to the next step.",
            WIN32::ERROR_NO_MORE_MATCHES => "There are no more matches for the current index enumeration.",
            WIN32::ERROR_RANGE_LIST_CONFLICT => "The range could not be added to the range list because of a conflict.",
            WIN32::ERROR_SERVER_SID_MISMATCH => "The server process is running under a SID different than that required by client.",
            WIN32::ERROR_CANT_ENABLE_DENY_ONLY => "A group marked use for deny only cannot be enabled.",
            WIN32::ERROR_FLOAT_MULTIPLE_FAULTS => "{EXCEPTION} // Multiple floating point faults.",
            WIN32::ERROR_FLOAT_MULTIPLE_TRAPS => "{EXCEPTION} // Multiple floating point traps.",
            WIN32::ERROR_NOINTERFACE => "The requested interface is not supported.",
            WIN32::ERROR_DRIVER_FAILED_SLEEP => "{System Standby Failed}.",
            WIN32::ERROR_CORRUPT_SYSTEM_FILE => "The system file %1 has become corrupt and has been replaced.",
            WIN32::ERROR_COMMITMENT_MINIMUM => "{Virtual Memory Minimum Too Low}.",
            WIN32::ERROR_PNP_RESTART_ENUMERATION => "A device was removed so enumeration must be restarted.",
            WIN32::ERROR_SYSTEM_IMAGE_BAD_SIGNATURE => "{Fatal System Error}.",
            WIN32::ERROR_PNP_REBOOT_REQUIRED => "Device will not start without a reboot.",
            WIN32::ERROR_INSUFFICIENT_POWER => "There is not enough power to complete the requested operation.",
            WIN32::ERROR_MULTIPLE_FAULT_VIOLATION => "ERROR_MULTIPLE_FAULT_VIOLATION.",
            WIN32::ERROR_SYSTEM_SHUTDOWN => "The system is in the process of shutting down.",
            WIN32::ERROR_PORT_NOT_SET => "An attempt to remove a processes DebugPort was made, but a port was not already associated with the process.",
            WIN32::ERROR_DS_VERSION_CHECK_FAILURE => "This version of Windows is not compatible with the behavior version of directory forest, domain or domain controller.",
            WIN32::ERROR_RANGE_NOT_FOUND => "The specified range could not be found in the range list.",
            WIN32::ERROR_NOT_SAFE_MODE_DRIVER => "The driver was not loaded because the system is booting into safe mode.",
            WIN32::ERROR_FAILED_DRIVER_ENTRY => "The driver was not loaded because it failed its initialization call.",
            WIN32::ERROR_DEVICE_ENUMERATION_ERROR => "The '%hs' encountered an error while applying power or reading the device configuration. // This may be caused by a failure of your hardware or by a poor connection.",
            WIN32::ERROR_MOUNT_POINT_NOT_RESOLVED => "The create operation failed because the name contained at least one mount point which resolves to a volume to which the specified device object is not attached.",
            WIN32::ERROR_INVALID_DEVICE_OBJECT_PARAMETER => "The device object parameter is either not a valid device object or is not attached to the volume specified by the file name.",
            WIN32::ERROR_MCA_OCCURED => "A Machine Check Error has occurred. Please check the system eventlog for additional information.",
            WIN32::ERROR_DRIVER_DATABASE_ERROR => "There was error [%2] processing the driver database.",
            WIN32::ERROR_SYSTEM_HIVE_TOO_LARGE => "System hive size has exceeded its limit.",
            WIN32::ERROR_DRIVER_FAILED_PRIOR_UNLOAD => "The driver could not be loaded because a previous version of the driver is still in memory.",
            WIN32::ERROR_VOLSNAP_PREPARE_HIBERNATE => "{Volume Shadow Copy Service}.",
            WIN32::ERROR_HIBERNATION_FAILURE => "The system has failed to hibernate (The error code is %hs). Hibernation will be disabled until the system is restarted.",
            WIN32::ERROR_PWD_TOO_LONG => "The password provided is too long to meet the policy of your user account.",
            WIN32::ERROR_FILE_SYSTEM_LIMITATION => "The requested operation could not be completed due to a file system limitation.",
            WIN32::ERROR_ASSERTION_FAILURE => "An assertion failure has occurred.",
            WIN32::ERROR_ACPI_ERROR => "An error occurred in the ACPI subsystem.",
            WIN32::ERROR_WOW_ASSERTION => "WOW Assertion Error.",
            WIN32::ERROR_PNP_BAD_MPS_TABLE => "A device is missing in the system BIOS MPS table. This device will not be used.",
            WIN32::ERROR_PNP_TRANSLATION_FAILED => "A translator failed to translate resources.",
            WIN32::ERROR_PNP_IRQ_TRANSLATION_FAILED => "A IRQ translator failed to translate resources.",
            WIN32::ERROR_PNP_INVALID_ID => "Driver %2 returned invalid ID for a child device (%3).",
            WIN32::ERROR_WAKE_SYSTEM_DEBUGGER => "{Kernel Debugger Awakened}.",
            WIN32::ERROR_HANDLES_CLOSED => "{Handles Closed}.",
            WIN32::ERROR_EXTRANEOUS_INFORMATION => "{Too Much Information}.",
            WIN32::ERROR_RXACT_COMMIT_NECESSARY => "This warning level status indicates that the transaction state already exists for the registry sub-tree, but that a transaction commit was previously aborted.",
            WIN32::ERROR_MEDIA_CHECK => "{Media Changed}.",
            WIN32::ERROR_GUID_SUBSTITUTION_MADE => "{GUID Substitution}.",
            WIN32::ERROR_STOPPED_ON_SYMLINK => "The create operation stopped after reaching a symbolic link.",
            WIN32::ERROR_LONGJUMP => "A long jump has been executed.",
            WIN32::ERROR_PLUGPLAY_QUERY_VETOED => "The Plug and Play query operation was not successful.",
            WIN32::ERROR_UNWIND_CONSOLIDATE => "A frame consolidation has been executed.",
            WIN32::ERROR_REGISTRY_HIVE_RECOVERED => "{Registry Hive Recovered}.",
            WIN32::ERROR_DLL_MIGHT_BE_INSECURE => "The application is attempting to run executable code from the module %hs. This may be insecure. An alternative, %hs, is available. Should the application use the secure module %hs?.",
            WIN32::ERROR_DLL_MIGHT_BE_INCOMPATIBLE => "The application is loading executable code from the module %hs. This is secure, but may be incompatible with previous releases of the operating system. An alternative, %hs, is available. Should the application use the secure module %hs?.",
            WIN32::ERROR_DBG_EXCEPTION_NOT_HANDLED => "Debugger did not handle the exception.",
            WIN32::ERROR_DBG_REPLY_LATER => "Debugger will reply later.",
            WIN32::ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE => "Debugger cannot provide handle.",
            WIN32::ERROR_DBG_TERMINATE_THREAD => "Debugger terminated thread.",
            WIN32::ERROR_DBG_TERMINATE_PROCESS => "Debugger terminated process.",
            WIN32::ERROR_DBG_CONTROL_C => "Debugger got control C.",
            WIN32::ERROR_DBG_PRINTEXCEPTION_C => "Debugger printed exception on control C.",
            WIN32::ERROR_DBG_RIPEXCEPTION => "Debugger received RIP exception.",
            WIN32::ERROR_DBG_CONTROL_BREAK => "Debugger received control break.",
            WIN32::ERROR_DBG_COMMAND_EXCEPTION => "Debugger command communication exception.",
            WIN32::ERROR_OBJECT_NAME_EXISTS => "{Object Exists}.",
            WIN32::ERROR_THREAD_WAS_SUSPENDED => "{Thread Suspended}.",
            WIN32::ERROR_IMAGE_NOT_AT_BASE => "{Image Relocated}.",
            WIN32::ERROR_RXACT_STATE_CREATED => "This informational level status indicates that a specified registry sub-tree transaction state did not yet exist and had to be created.",
            WIN32::ERROR_SEGMENT_NOTIFICATION => "{Segment Load} // A virtual DOS machine (VDM) is loading, unloading, or moving an MS-DOS or Win16 program segment image. // An exception is raised so a debugger can load, unload or track symbols and breakpoints within these 16-bit segments.",
            WIN32::ERROR_BAD_CURRENT_DIRECTORY => "{Invalid Current Directory}.",
            WIN32::ERROR_FT_READ_RECOVERY_FROM_BACKUP => "{Redundant Read}.",
            WIN32::ERROR_FT_WRITE_RECOVERY => "{Redundant Write}.",
            WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH => "{Machine Type Mismatch}.",
            WIN32::ERROR_RECEIVE_PARTIAL => "{Partial Data Received}.",
            WIN32::ERROR_RECEIVE_EXPEDITED => "{Expedited Data Received}.",
            WIN32::ERROR_RECEIVE_PARTIAL_EXPEDITED => "{Partial Expedited Data Received}.",
            WIN32::ERROR_EVENT_DONE => "{TDI Event Done}.",
            WIN32::ERROR_EVENT_PENDING => "{TDI Event Pending}.",
            WIN32::ERROR_CHECKING_FILE_SYSTEM => "Checking file system on %wZ.",
            WIN32::ERROR_FATAL_APP_EXIT => "{Fatal Application Exit}.",
            WIN32::ERROR_PREDEFINED_HANDLE => "The specified registry key is referenced by a predefined handle.",
            WIN32::ERROR_WAS_UNLOCKED => "{Page Unlocked}.",
            WIN32::ERROR_SERVICE_NOTIFICATION => "%hs.",
            WIN32::ERROR_WAS_LOCKED => "{Page Locked}.",
            WIN32::ERROR_LOG_HARD_ERROR => "Application popup: %1: %2.",
            WIN32::ERROR_ALREADY_WIN32 => "ERROR_ALREADY_WIN32.",
            WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE => "{Machine Type Mismatch}.",
            WIN32::ERROR_NO_YIELD_PERFORMED => "A yield execution was performed and no thread was available to run.",
            WIN32::ERROR_TIMER_RESUME_IGNORED => "The resumable flag to a timer API was ignored.",
            WIN32::ERROR_ARBITRATION_UNHANDLED => "The arbiter has deferred arbitration of these resources to its parent.",
            WIN32::ERROR_CARDBUS_NOT_SUPPORTED => "The inserted CardBus device cannot be started because of a configuration error on .",
            WIN32::ERROR_MP_PROCESSOR_MISMATCH => "The CPUs in this multiprocessor system are not all the same revision level. To use all processors the operating system restricts itself to the features of the least capable processor in the system. Should problems occur with this system, contact the CPU manufacturer to see if this mix of processors is supported.",
            WIN32::ERROR_HIBERNATED => "The system was put into hibernation.",
            WIN32::ERROR_RESUME_HIBERNATION => "The system was resumed from hibernation.",
            WIN32::ERROR_FIRMWARE_UPDATED => "Windows has detected that the system firmware (BIOS) was updated [previous firmware date = %2, current firmware date %3].",
            WIN32::ERROR_DRIVERS_LEAKING_LOCKED_PAGES => "A device driver is leaking locked I/O pages causing system degradation. The system has automatically enabled tracking code in order to try and catch the culprit.",
            WIN32::ERROR_WAKE_SYSTEM => "The system has awoken.",
            WIN32::ERROR_WAIT_1 => "ERROR_WAIT_1.",
            WIN32::ERROR_WAIT_2 => "ERROR_WAIT_2.",
            WIN32::ERROR_WAIT_3 => "ERROR_WAIT_3.",
            WIN32::ERROR_WAIT_63 => "ERROR_WAIT_63.",
            WIN32::ERROR_ABANDONED_WAIT_0 => "ERROR_ABANDONED_WAIT_0.",
            WIN32::ERROR_ABANDONED_WAIT_63 => "ERROR_ABANDONED_WAIT_63.",
            WIN32::ERROR_USER_APC => "ERROR_USER_APC.",
            WIN32::ERROR_KERNEL_APC => "ERROR_KERNEL_APC.",
            WIN32::ERROR_ALERTED => "ERROR_ALERTED.",
            WIN32::ERROR_ELEVATION_REQUIRED => "The requested operation requires elevation.",
            WIN32::ERROR_REPARSE => "A reparse should be performed by the Object Manager since the name of the file resulted in a symbolic link.",
            WIN32::ERROR_OPLOCK_BREAK_IN_PROGRESS => "An open/create operation completed while an oplock break is underway.",
            WIN32::ERROR_VOLUME_MOUNTED => "A new volume has been mounted by a file system.",
            WIN32::ERROR_RXACT_COMMITTED => "This success level status indicates that the transaction state already exists for the registry sub-tree, but that a transaction commit was previously aborted.",
            WIN32::ERROR_NOTIFY_CLEANUP => "This indicates that a notify change request has been completed due to closing the handle which made the notify change request.",
            WIN32::ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED => "{Connect Failure on Primary Transport}.",
            WIN32::ERROR_PAGE_FAULT_TRANSITION => "Page fault was a transition fault.",
            WIN32::ERROR_PAGE_FAULT_DEMAND_ZERO => "Page fault was a demand zero fault.",
            WIN32::ERROR_PAGE_FAULT_COPY_ON_WRITE => "Page fault was a demand zero fault.",
            WIN32::ERROR_PAGE_FAULT_GUARD_PAGE => "Page fault was a demand zero fault.",
            WIN32::ERROR_PAGE_FAULT_PAGING_FILE => "Page fault was satisfied by reading from a secondary storage device.",
            WIN32::ERROR_CACHE_PAGE_LOCKED => "Cached page was locked during operation.",
            WIN32::ERROR_CRASH_DUMP => "Crash dump exists in paging file.",
            WIN32::ERROR_BUFFER_ALL_ZEROS => "Specified buffer contains all zeros.",
            WIN32::ERROR_REPARSE_OBJECT => "A reparse should be performed by the Object Manager since the name of the file resulted in a symbolic link.",
            WIN32::ERROR_RESOURCE_REQUIREMENTS_CHANGED => "The device has succeeded a query-stop and its resource requirements have changed.",
            WIN32::ERROR_TRANSLATION_COMPLETE => "The translator has translated these resources into the global space and no further translations should be performed.",
            WIN32::ERROR_NOTHING_TO_TERMINATE => "A process being terminated has no threads to terminate.",
            WIN32::ERROR_PROCESS_NOT_IN_JOB => "The specified process is not part of a job.",
            WIN32::ERROR_PROCESS_IN_JOB => "The specified process is part of a job.",
            WIN32::ERROR_VOLSNAP_HIBERNATE_READY => "{Volume Shadow Copy Service}.",
            WIN32::ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY => "A file system or file system filter driver has successfully completed an FsFilter operation.",
            WIN32::ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED => "The specified interrupt vector was already connected.",
            WIN32::ERROR_INTERRUPT_STILL_CONNECTED => "The specified interrupt vector is still connected.",
            WIN32::ERROR_WAIT_FOR_OPLOCK => "An operation is blocked waiting for an oplock.",
            WIN32::ERROR_DBG_EXCEPTION_HANDLED => "Debugger handled exception.",
            WIN32::ERROR_DBG_CONTINUE => "Debugger continued.",
            WIN32::ERROR_CALLBACK_POP_STACK => "An exception occurred in a user mode callback and the kernel callback frame should be removed.",
            WIN32::ERROR_COMPRESSION_DISABLED => "Compression is disabled for this volume.",
            WIN32::ERROR_CANTFETCHBACKWARDS => "The data provider cannot fetch backwards through a result set.",
            WIN32::ERROR_CANTSCROLLBACKWARDS => "The data provider cannot scroll backwards through a result set.",
            WIN32::ERROR_ROWSNOTRELEASED => "The data provider requires that previously fetched data is released before asking for more data.",
            WIN32::ERROR_BAD_ACCESSOR_FLAGS => "The data provider was not able to interpret the flags set for a column binding in an accessor.",
            WIN32::ERROR_ERRORS_ENCOUNTERED => "One or more errors occurred while processing the request.",
            WIN32::ERROR_NOT_CAPABLE => "The implementation is not capable of performing the request.",
            WIN32::ERROR_REQUEST_OUT_OF_SEQUENCE => "The client of a component requested an operation which is not valid given the state of the component instance.",
            WIN32::ERROR_VERSION_PARSE_ERROR => "A version number could not be parsed.",
            WIN32::ERROR_BADSTARTPOSITION => "The iterator's start position is invalid.",
            WIN32::ERROR_MEMORY_HARDWARE => "The hardware has reported an uncorrectable memory error.",
            WIN32::ERROR_DISK_REPAIR_DISABLED => "The attempted operation required self healing to be enabled.",
            WIN32::ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE => "The Desktop heap encountered an error while allocating session memory. There is more information in the system event log.",
            WIN32::ERROR_SYSTEM_POWERSTATE_TRANSITION => "The system power state is transitioning from %2 to %3.",
            WIN32::ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION => "The system power state is transitioning from %2 to %3 but could enter %4.",
            WIN32::ERROR_MCA_EXCEPTION => "A thread is getting dispatched with MCA EXCEPTION because of MCA.",
            WIN32::ERROR_ACCESS_AUDIT_BY_POLICY => "Access to %1 is monitored by policy rule %2.",
            WIN32::ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY => "Access to %1 has been restricted by your Administrator by policy rule %2.",
            WIN32::ERROR_ABANDON_HIBERFILE => "A valid hibernation file has been invalidated and should be abandoned.",
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED => "{Delayed Write Failed}.",
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR => "{Delayed Write Failed}.",
            WIN32::ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR => "{Delayed Write Failed}.",
            WIN32::ERROR_BAD_MCFG_TABLE => "The resources required for this device conflict with the MCFG table.",
            WIN32::ERROR_DISK_REPAIR_REDIRECTED => "The volume repair could not be performed while it is online.",
            WIN32::ERROR_DISK_REPAIR_UNSUCCESSFUL => "The volume repair was not successful.",
            WIN32::ERROR_CORRUPT_LOG_OVERFULL => "One of the volume corruption logs is full. Further corruptions that may be detected won't be logged.",
            WIN32::ERROR_CORRUPT_LOG_CORRUPTED => "One of the volume corruption logs is internally corrupted and needs to be recreated. The volume may contain undetected corruptions and must be scanned.",
            WIN32::ERROR_CORRUPT_LOG_UNAVAILABLE => "One of the volume corruption logs is unavailable for being operated on.",
            WIN32::ERROR_CORRUPT_LOG_DELETED_FULL => "One of the volume corruption logs was deleted while still having corruption records in them. The volume contains detected corruptions and must be scanned.",
            WIN32::ERROR_CORRUPT_LOG_CLEARED => "One of the volume corruption logs was cleared by chkdsk and no longer contains real corruptions.",
            WIN32::ERROR_ORPHAN_NAME_EXHAUSTED => "Orphaned files exist on the volume but could not be recovered because no more new names could be created in the recovery directory. Files must be moved from the recovery directory.",
            WIN32::ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE => "The oplock that was associated with this handle is now associated with a different handle.",
            WIN32::ERROR_CANNOT_GRANT_REQUESTED_OPLOCK => "An oplock of the requested level cannot be granted. An oplock of a lower level may be available.",
            WIN32::ERROR_CANNOT_BREAK_OPLOCK => "The operation did not complete successfully because it would cause an oplock to be broken. The caller has requested that existing oplocks not be broken.",
            WIN32::ERROR_OPLOCK_HANDLE_CLOSED => "The handle with which this oplock was associated has been closed. The oplock is now broken.",
            WIN32::ERROR_NO_ACE_CONDITION => "The specified access control entry (ACE) does not contain a condition.",
            WIN32::ERROR_INVALID_ACE_CONDITION => "The specified access control entry (ACE) contains an invalid condition.",
            WIN32::ERROR_FILE_HANDLE_REVOKED => "Access to the specified file handle has been revoked.",
            WIN32::ERROR_IMAGE_AT_DIFFERENT_BASE => "{Image Relocated}.",
            WIN32::ERROR_ENCRYPTED_IO_NOT_POSSIBLE => "The read or write operation to an encrypted file could not be completed because the file has not been opened for data access.",
            WIN32::ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS => "File metadata optimization is already in progress.",
            WIN32::ERROR_QUOTA_ACTIVITY => "The requested operation failed due to quota operation is still in progress.",
            WIN32::ERROR_HANDLE_REVOKED => "Access to the specified handle has been revoked.",
            WIN32::ERROR_CALLBACK_INVOKE_INLINE => "The callback function must be invoked inline.",
            WIN32::ERROR_CPU_SET_INVALID => "The specified CPU Set IDs are invalid.",
            WIN32::ERROR_ENCLAVE_NOT_TERMINATED => "The specified enclave has not yet been terminated.",
            WIN32::ERROR_ENCLAVE_VIOLATION => "An attempt was made to access protected memory in violation of its secure access policy.",
            WIN32::ERROR_SERVER_TRANSPORT_CONFLICT => "Multiple mappings to shared resource(s) on a server, using more than one transport, are not allowed. Use a single transport for all mappings to a server and try again.",
            WIN32::ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT => "Multiple mappings to shared resource(s) on a server, using different certificate validation preferences, are not allowed. Use the same preference for all mappings to a server and try again.",
            WIN32::ERROR_FT_READ_FROM_COPY_FAILURE => "The specified copy of the requested data could not be read.",
            WIN32::ERROR_SECTION_DIRECT_MAP_ONLY => "The section creation request was failed because it would have been satisfied with a direct map and the caller explicitly signified this was not wanted.",
            WIN32::ERROR_EA_ACCESS_DENIED => "Access to the extended attribute was denied.",
            WIN32::ERROR_OPERATION_ABORTED => "The I/O operation has been aborted because of either a thread exit or an application request.",
            WIN32::ERROR_IO_INCOMPLETE => "Overlapped I/O event is not in a signaled state.",
            WIN32::ERROR_IO_PENDING => "Overlapped I/O operation is in progress.",
            WIN32::ERROR_NOACCESS => "Invalid access to memory location.",
            WIN32::ERROR_SWAPERROR => "Error performing inpage operation.",
            WIN32::ERROR_STACK_OVERFLOW => "Recursion too deep; the stack overflowed.",
            WIN32::ERROR_INVALID_MESSAGE => "The window cannot act on the sent message.",
            WIN32::ERROR_CAN_NOT_COMPLETE => "Cannot complete this function.",
            WIN32::ERROR_INVALID_FLAGS => "Invalid flags.",
            WIN32::ERROR_UNRECOGNIZED_VOLUME => "The volume does not contain a recognized file system.",
            WIN32::ERROR_FILE_INVALID => "The volume for a file has been externally altered so that the opened file is no longer valid.",
            WIN32::ERROR_FULLSCREEN_MODE => "The requested operation cannot be performed in full-screen mode.",
            WIN32::ERROR_NO_TOKEN => "An attempt was made to reference a token that does not exist.",
            WIN32::ERROR_BADDB => "The configuration registry database is corrupt.",
            WIN32::ERROR_BADKEY => "The configuration registry key is invalid.",
            WIN32::ERROR_CANTOPEN => "The configuration registry key could not be opened.",
            WIN32::ERROR_CANTREAD => "The configuration registry key could not be read.",
            WIN32::ERROR_CANTWRITE => "The configuration registry key could not be written.",
            WIN32::ERROR_REGISTRY_RECOVERED => "One of the files in the registry database had to be recovered by use of a log or alternate copy. The recovery was successful.",
            WIN32::ERROR_REGISTRY_CORRUPT => "The registry is corrupted. The structure of one of the files containing registry data is corrupted, or the system's memory image of the file is corrupted, or the file could not be recovered because the alternate copy or log was absent or corrupted.",
            WIN32::ERROR_REGISTRY_IO_FAILED => "An I/O operation initiated by the registry failed unrecoverably. The registry could not read in, or write out, or flush, one of the files that contain the system's image of the registry.",
            WIN32::ERROR_NOT_REGISTRY_FILE => "The system has attempted to load or restore a file into the registry, but the specified file is not in a registry file format.",
            WIN32::ERROR_KEY_DELETED => "Illegal operation attempted on a registry key that has been marked for deletion.",
            WIN32::ERROR_NO_LOG_SPACE => "System could not allocate the required space in a registry log.",
            WIN32::ERROR_KEY_HAS_CHILDREN => "Cannot create a symbolic link in a registry key that already has subkeys or values.",
            WIN32::ERROR_CHILD_MUST_BE_VOLATILE => "Cannot create a stable subkey under a volatile parent key.",
            WIN32::ERROR_NOTIFY_ENUM_DIR => "A notify change request is being completed and the information is not being returned in the caller's buffer. The caller now needs to enumerate the files to find the changes.",
            WIN32::ERROR_DEPENDENT_SERVICES_RUNNING => "A stop control has been sent to a service that other running services are dependent on.",
            WIN32::ERROR_INVALID_SERVICE_CONTROL => "The requested control is not valid for this service.",
            WIN32::ERROR_SERVICE_REQUEST_TIMEOUT => "The service did not respond to the start or control request in a timely fashion.",
            WIN32::ERROR_SERVICE_NO_THREAD => "A thread could not be created for the service.",
            WIN32::ERROR_SERVICE_DATABASE_LOCKED => "The service database is locked.",
            WIN32::ERROR_SERVICE_ALREADY_RUNNING => "An instance of the service is already running.",
            WIN32::ERROR_INVALID_SERVICE_ACCOUNT => "The account name is invalid or does not exist, or the password is invalid for the account name specified.",
            WIN32::ERROR_SERVICE_DISABLED => "The service cannot be started, either because it is disabled or because it has no enabled devices associated with it.",
            WIN32::ERROR_CIRCULAR_DEPENDENCY => "Circular service dependency was specified.",
            WIN32::ERROR_SERVICE_DOES_NOT_EXIST => "The specified service does not exist as an installed service.",
            WIN32::ERROR_SERVICE_CANNOT_ACCEPT_CTRL => "The service cannot accept control messages at this time.",
            WIN32::ERROR_SERVICE_NOT_ACTIVE => "The service has not been started.",
            WIN32::ERROR_FAILED_SERVICE_CONTROLLER_CONNECT => "The service process could not connect to the service controller.",
            WIN32::ERROR_EXCEPTION_IN_SERVICE => "An exception occurred in the service when handling the control request.",
            WIN32::ERROR_DATABASE_DOES_NOT_EXIST => "The database specified does not exist.",
            WIN32::ERROR_SERVICE_SPECIFIC_ERROR => "The service has returned a service-specific error code.",
            WIN32::ERROR_PROCESS_ABORTED => "The process terminated unexpectedly.",
            WIN32::ERROR_SERVICE_DEPENDENCY_FAIL => "The dependency service or group failed to start.",
            WIN32::ERROR_SERVICE_LOGON_FAILED => "The service did not start due to a logon failure.",
            WIN32::ERROR_SERVICE_START_HANG => "After starting, the service hung in a start-pending state.",
            WIN32::ERROR_INVALID_SERVICE_LOCK => "The specified service database lock is invalid.",
            WIN32::ERROR_SERVICE_MARKED_FOR_DELETE => "The specified service has been marked for deletion.",
            WIN32::ERROR_SERVICE_EXISTS => "The specified service already exists.",
            WIN32::ERROR_ALREADY_RUNNING_LKG => "The system is currently running with the last-known-good configuration.",
            WIN32::ERROR_SERVICE_DEPENDENCY_DELETED => "The dependency service does not exist or has been marked for deletion.",
            WIN32::ERROR_BOOT_ALREADY_ACCEPTED => "The current boot has already been accepted for use as the last-known-good control set.",
            WIN32::ERROR_SERVICE_NEVER_STARTED => "No attempts to start the service have been made since the last boot.",
            WIN32::ERROR_DUPLICATE_SERVICE_NAME => "The name is already in use as either a service name or a service display name.",
            WIN32::ERROR_DIFFERENT_SERVICE_ACCOUNT => "The account specified for this service is different from the account specified for other services running in the same process.",
            WIN32::ERROR_CANNOT_DETECT_DRIVER_FAILURE => "Failure actions can only be set for Win32 services, not for drivers.",
            WIN32::ERROR_CANNOT_DETECT_PROCESS_ABORT => "This service runs in the same process as the service control manager.",
            WIN32::ERROR_NO_RECOVERY_PROGRAM => "No recovery program has been configured for this service.",
            WIN32::ERROR_SERVICE_NOT_IN_EXE => "The executable program that this service is configured to run in does not implement the service.",
            WIN32::ERROR_NOT_SAFEBOOT_SERVICE => "This service cannot be started in Safe Mode.",
            WIN32::ERROR_END_OF_MEDIA => "The physical end of the tape has been reached.",
            WIN32::ERROR_FILEMARK_DETECTED => "A tape access reached a filemark.",
            WIN32::ERROR_BEGINNING_OF_MEDIA => "The beginning of the tape or a partition was encountered.",
            WIN32::ERROR_SETMARK_DETECTED => "A tape access reached the end of a set of files.",
            WIN32::ERROR_NO_DATA_DETECTED => "No more data is on the tape.",
            WIN32::ERROR_PARTITION_FAILURE => "Tape could not be partitioned.",
            WIN32::ERROR_INVALID_BLOCK_LENGTH => "When accessing a new tape of a multivolume partition, the current block size is incorrect.",
            WIN32::ERROR_DEVICE_NOT_PARTITIONED => "Tape partition information could not be found when loading a tape.",
            WIN32::ERROR_UNABLE_TO_LOCK_MEDIA => "Unable to lock the media eject mechanism.",
            WIN32::ERROR_UNABLE_TO_UNLOAD_MEDIA => "Unable to unload the media.",
            WIN32::ERROR_MEDIA_CHANGED => "The media in the drive may have changed.",
            WIN32::ERROR_BUS_RESET => "The I/O bus was reset.",
            WIN32::ERROR_NO_MEDIA_IN_DRIVE => "No media in drive.",
            WIN32::ERROR_NO_UNICODE_TRANSLATION => "No mapping for the Unicode character exists in the target multi-byte code page.",
            WIN32::ERROR_DLL_INIT_FAILED => "A dynamic link library (DLL) initialization routine failed.",
            WIN32::ERROR_SHUTDOWN_IN_PROGRESS => "A system shutdown is in progress.",
            WIN32::ERROR_NO_SHUTDOWN_IN_PROGRESS => "Unable to abort the system shutdown because no shutdown was in progress.",
            WIN32::ERROR_IO_DEVICE => "The request could not be performed because of an I/O device error.",
            WIN32::ERROR_SERIAL_NO_DEVICE => "No serial device was successfully initialized. The serial driver will unload.",
            WIN32::ERROR_IRQ_BUSY => "Unable to open a device that was sharing an interrupt request (IRQ) with other devices. At least one other device that uses that IRQ was already opened.",
            WIN32::ERROR_MORE_WRITES => "A serial I/O operation was completed by another write to the serial port.",
            WIN32::ERROR_COUNTER_TIMEOUT => "A serial I/O operation completed because the timeout period expired.",
            WIN32::ERROR_FLOPPY_ID_MARK_NOT_FOUND => "No ID address mark was found on the floppy disk.",
            WIN32::ERROR_FLOPPY_WRONG_CYLINDER => "Mismatch between the floppy disk sector ID field and the floppy disk controller track address.",
            WIN32::ERROR_FLOPPY_UNKNOWN_ERROR => "The floppy disk controller reported an error that is not recognized by the floppy disk driver.",
            WIN32::ERROR_FLOPPY_BAD_REGISTERS => "The floppy disk controller returned inconsistent results in its registers.",
            WIN32::ERROR_DISK_RECALIBRATE_FAILED => "While accessing the hard disk, a recalibrate operation failed, even after retries.",
            WIN32::ERROR_DISK_OPERATION_FAILED => "While accessing the hard disk, a disk operation failed even after retries.",
            WIN32::ERROR_DISK_RESET_FAILED => "While accessing the hard disk, a disk controller reset was needed, but even that failed.",
            WIN32::ERROR_EOM_OVERFLOW => "Physical end of tape encountered.",
            WIN32::ERROR_NOT_ENOUGH_SERVER_MEMORY => "Not enough server memory resources are available to process this command.",
            WIN32::ERROR_POSSIBLE_DEADLOCK => "A potential deadlock condition has been detected.",
            WIN32::ERROR_MAPPED_ALIGNMENT => "The base address or the file offset specified does not have the proper alignment.",
            WIN32::ERROR_SET_POWER_STATE_VETOED => "An attempt to change the system power state was vetoed by another application or driver.",
            WIN32::ERROR_SET_POWER_STATE_FAILED => "The system BIOS failed an attempt to change the system power state.",
            WIN32::ERROR_TOO_MANY_LINKS => "An attempt was made to create more links on a file than the file system supports.",
            WIN32::ERROR_OLD_WIN_VERSION => "The specified program requires a newer version of Windows.",
            WIN32::ERROR_APP_WRONG_OS => "The specified program is not a Windows or MS-DOS program.",
            WIN32::ERROR_SINGLE_INSTANCE_APP => "Cannot start more than one instance of the specified program.",
            WIN32::ERROR_RMODE_APP => "The specified program was written for an earlier version of Windows.",
            WIN32::ERROR_INVALID_DLL => "One of the library files needed to run this application is damaged.",
            WIN32::ERROR_NO_ASSOCIATION => "No application is associated with the specified file for this operation.",
            WIN32::ERROR_DDE_FAIL => "An error occurred in sending the command to the application.",
            WIN32::ERROR_DLL_NOT_FOUND => "One of the library files needed to run this application cannot be found.",
            WIN32::ERROR_NO_MORE_USER_HANDLES => "The current process has used all of its system allowance of handles for Window Manager objects.",
            WIN32::ERROR_MESSAGE_SYNC_ONLY => "The message can be used only with synchronous operations.",
            WIN32::ERROR_SOURCE_ELEMENT_EMPTY => "The indicated source element has no media.",
            WIN32::ERROR_DESTINATION_ELEMENT_FULL => "The indicated destination element already contains media.",
            WIN32::ERROR_ILLEGAL_ELEMENT_ADDRESS => "The indicated element does not exist.",
            WIN32::ERROR_MAGAZINE_NOT_PRESENT => "The indicated element is part of a magazine that is not present.",
            WIN32::ERROR_DEVICE_REINITIALIZATION_NEEDED => "The indicated device requires reinitialization due to hardware errors.",
            WIN32::ERROR_DEVICE_REQUIRES_CLEANING => "The device has indicated that cleaning is required before further operations are attempted.",
            WIN32::ERROR_DEVICE_DOOR_OPEN => "The device has indicated that its door is open.",
            WIN32::ERROR_DEVICE_NOT_CONNECTED => "The device is not connected.",
            WIN32::ERROR_NOT_FOUND => "Element not found.",
            WIN32::E_PROP_ID_UNSUPPORTED => "The property is not supported.",
            WIN32::ERROR_NO_MATCH => "There was no match for the specified key in the index.",
            WIN32::ERROR_SET_NOT_FOUND => "The property set specified does not exist on the object.",
            WIN32::E_PROP_SET_UNSUPPORTED => "Setting of the property is not supported.",
            WIN32::ERROR_POINT_NOT_FOUND => "The point passed to GetMouseMovePoints is not in the buffer.",
            WIN32::ERROR_NO_TRACKING_SERVICE => "The tracking (workstation) service is not running.",
            WIN32::ERROR_NO_VOLUME_ID => "The Volume ID could not be found.",
            WIN32::ERROR_UNABLE_TO_REMOVE_REPLACED => "Unable to remove the file to be replaced.",
            WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT => "Unable to move the replacement file to the file to be replaced. The file to be replaced has retained its original name.",
            WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT_2 => "Unable to move the replacement file to the file to be replaced. The file to be replaced has been renamed using the backup name.",
            WIN32::ERROR_JOURNAL_DELETE_IN_PROGRESS => "The volume change journal is being deleted.",
            WIN32::ERROR_JOURNAL_NOT_ACTIVE => "The volume change journal is not active.",
            WIN32::ERROR_POTENTIAL_FILE_FOUND => "A file was found, but it may not be the correct file.",
            WIN32::ERROR_JOURNAL_ENTRY_DELETED => "The journal entry has been deleted from the journal.",
            WIN32::ERROR_VRF_CFG_ENABLED => "Driver Verifier Volatile settings cannot be set when CFG is enabled.",
            WIN32::ERROR_PARTITION_TERMINATING => "An attempt was made to access a partition that has begun termination.",
            WIN32::ERROR_SHUTDOWN_IS_SCHEDULED => "A system shutdown has already been scheduled.",
            WIN32::ERROR_SHUTDOWN_USERS_LOGGED_ON => "The system shutdown cannot be initiated because there are other users logged on to the computer.",
            WIN32::ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE => "The system shutdown cannot safely proceed without enabling node maintenance mode for cluster node and waiting for the drain to complete.",
            WIN32::ERROR_BAD_DEVICE => "The specified device name is invalid.",
            WIN32::ERROR_CONNECTION_UNAVAIL => "The device is not currently connected but it is a remembered connection.",
            WIN32::ERROR_DEVICE_ALREADY_REMEMBERED => "The local device name has a remembered connection to another network resource.",
            WIN32::ERROR_NO_NET_OR_BAD_PATH => "The network path was either typed incorrectly, does not exist, or the network provider is not currently available. Please try retyping the path or contact your network administrator.",
            WIN32::ERROR_BAD_PROVIDER => "The specified network provider name is invalid.",
            WIN32::ERROR_CANNOT_OPEN_PROFILE => "Unable to open the network connection profile.",
            WIN32::ERROR_BAD_PROFILE => "The network connection profile is corrupted.",
            WIN32::ERROR_NOT_CONTAINER => "Cannot enumerate a noncontainer.",
            WIN32::ERROR_EXTENDED_ERROR => "An extended error has occurred.",
            WIN32::ERROR_INVALID_GROUPNAME => "The format of the specified group name is invalid.",
            WIN32::ERROR_INVALID_COMPUTERNAME => "The format of the specified computer name is invalid.",
            WIN32::ERROR_INVALID_EVENTNAME => "The format of the specified event name is invalid.",
            WIN32::ERROR_INVALID_DOMAINNAME => "The format of the specified domain name is invalid.",
            WIN32::ERROR_INVALID_SERVICENAME => "The format of the specified service name is invalid.",
            WIN32::ERROR_INVALID_NETNAME => "The format of the specified network name is invalid.",
            WIN32::ERROR_INVALID_SHARENAME => "The format of the specified share name is invalid.",
            WIN32::ERROR_INVALID_PASSWORDNAME => "The format of the specified password is invalid.",
            WIN32::ERROR_INVALID_MESSAGENAME => "The format of the specified message name is invalid.",
            WIN32::ERROR_INVALID_MESSAGEDEST => "The format of the specified message destination is invalid.",
            WIN32::ERROR_SESSION_CREDENTIAL_CONFLICT => "Multiple connections to a server or shared resource by the same user, using more than one user name, are not allowed. Disconnect all previous connections to the server or shared resource and try again.",
            WIN32::ERROR_REMOTE_SESSION_LIMIT_EXCEEDED => "An attempt was made to establish a session to a network server, but there are already too many sessions established to that server.",
            WIN32::ERROR_DUP_DOMAINNAME => "The workgroup or domain name is already in use by another computer on the network.",
            WIN32::ERROR_NO_NETWORK => "The network is not present or not started.",
            WIN32::ERROR_CANCELLED => "The operation was canceled by the user.",
            WIN32::ERROR_USER_MAPPED_FILE => "The requested operation cannot be performed on a file with a user-mapped section open.",
            WIN32::ERROR_CONNECTION_REFUSED => "The remote computer refused the network connection.",
            WIN32::ERROR_GRACEFUL_DISCONNECT => "The network connection was gracefully closed.",
            WIN32::ERROR_ADDRESS_ALREADY_ASSOCIATED => "The network transport endpoint already has an address associated with it.",
            WIN32::ERROR_ADDRESS_NOT_ASSOCIATED => "An address has not yet been associated with the network endpoint.",
            WIN32::ERROR_CONNECTION_INVALID => "An operation was attempted on a nonexistent network connection.",
            WIN32::ERROR_CONNECTION_ACTIVE => "An invalid operation was attempted on an active network connection.",
            WIN32::ERROR_NETWORK_UNREACHABLE => "The network location cannot be reached. For information about network troubleshooting, see Windows Help.",
            WIN32::ERROR_HOST_UNREACHABLE => "The network location cannot be reached. For information about network troubleshooting, see Windows Help.",
            WIN32::ERROR_PROTOCOL_UNREACHABLE => "The network location cannot be reached. For information about network troubleshooting, see Windows Help.",
            WIN32::ERROR_PORT_UNREACHABLE => "No service is operating at the destination network endpoint on the remote system.",
            WIN32::ERROR_REQUEST_ABORTED => "The request was aborted.",
            WIN32::ERROR_CONNECTION_ABORTED => "The network connection was aborted by the local system.",
            WIN32::ERROR_RETRY => "The operation could not be completed. A retry should be performed.",
            WIN32::ERROR_CONNECTION_COUNT_LIMIT => "A connection to the server could not be made because the limit on the number of concurrent connections for this account has been reached.",
            WIN32::ERROR_LOGIN_TIME_RESTRICTION => "Attempting to log in during an unauthorized time of day for this account.",
            WIN32::ERROR_LOGIN_WKSTA_RESTRICTION => "The account is not authorized to log in from this station.",
            WIN32::ERROR_INCORRECT_ADDRESS => "The network address could not be used for the operation requested.",
            WIN32::ERROR_ALREADY_REGISTERED => "The service is already registered.",
            WIN32::ERROR_SERVICE_NOT_FOUND => "The specified service does not exist.",
            WIN32::ERROR_NOT_AUTHENTICATED => "The operation being requested was not performed because the user has not been authenticated.",
            WIN32::ERROR_NOT_LOGGED_ON => "The operation being requested was not performed because the user has not logged on to the network. The specified service does not exist.",
            WIN32::ERROR_CONTINUE => "Continue with work in progress.",
            WIN32::ERROR_ALREADY_INITIALIZED => "An attempt was made to perform an initialization operation when initialization has already been completed.",
            WIN32::ERROR_NO_MORE_DEVICES => "No more local devices.",
            WIN32::ERROR_NO_SUCH_SITE => "The specified site does not exist.",
            WIN32::ERROR_DOMAIN_CONTROLLER_EXISTS => "A domain controller with the specified name already exists.",
            WIN32::ERROR_ONLY_IF_CONNECTED => "This operation is supported only when you are connected to the server.",
            WIN32::ERROR_OVERRIDE_NOCHANGES => "The group policy framework should call the extension even if there are no changes.",
            WIN32::ERROR_BAD_USER_PROFILE => "The specified user does not have a valid profile.",
            WIN32::ERROR_NOT_SUPPORTED_ON_SBS => "This operation is not supported on a computer running Windows Server 2003 for Small Business Server.",
            WIN32::ERROR_SERVER_SHUTDOWN_IN_PROGRESS => "The server machine is shutting down.",
            WIN32::ERROR_HOST_DOWN => "The remote system is not available. For information about network troubleshooting, see Windows Help.",
            WIN32::ERROR_NON_ACCOUNT_SID => "The security identifier provided is not from an account domain.",
            WIN32::ERROR_NON_DOMAIN_SID => "The security identifier provided does not have a domain component.",
            WIN32::ERROR_APPHELP_BLOCK => "AppHelp dialog canceled thus preventing the application from starting.",
            WIN32::ERROR_ACCESS_DISABLED_BY_POLICY => "This program is blocked by group policy. For more information, contact your system administrator.",
            WIN32::ERROR_REG_NAT_CONSUMPTION => "A program attempt to use an invalid register value. Normally caused by an uninitialized register. This error is Itanium specific.",
            WIN32::ERROR_CSCSHARE_OFFLINE => "The share is currently offline or does not exist.",
            WIN32::ERROR_PKINIT_FAILURE => "The Kerberos protocol encountered an error while validating the KDC certificate during smartcard logon. There is more information in the system event log.",
            WIN32::ERROR_SMARTCARD_SUBSYSTEM_FAILURE => "The Kerberos protocol encountered an error while attempting to utilize the smartcard subsystem.",
            WIN32::ERROR_DOWNGRADE_DETECTED => "The system cannot contact a domain controller to service the authentication request. Please try again later.",
            WIN32::ERROR_MACHINE_LOCKED => "The machine is locked and cannot be shut down without the force option.",
            WIN32::ERROR_SMB_GUEST_LOGON_BLOCKED => "You can't access this shared folder because your organization's security policies block unauthenticated guest access. These policies help protect your PC from unsafe or malicious devices on the network.",
            WIN32::ERROR_CALLBACK_SUPPLIED_INVALID_DATA => "An application-defined callback gave invalid data when called.",
            WIN32::ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED => "The group policy framework should call the extension in the synchronous foreground policy refresh.",
            WIN32::ERROR_DRIVER_BLOCKED => "This driver has been blocked from loading.",
            WIN32::ERROR_INVALID_IMPORT_OF_NON_DLL => "A dynamic link library (DLL) referenced a module that was neither a DLL nor the process's executable image.",
            WIN32::ERROR_ACCESS_DISABLED_WEBBLADE => "Windows cannot open this program since it has been disabled.",
            WIN32::ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER => "Windows cannot open this program because the license enforcement system has been tampered with or become corrupted.",
            WIN32::ERROR_RECOVERY_FAILURE => "A transaction recover failed.",
            WIN32::ERROR_ALREADY_FIBER => "The current thread has already been converted to a fiber.",
            WIN32::ERROR_ALREADY_THREAD => "The current thread has already been converted from a fiber.",
            WIN32::ERROR_STACK_BUFFER_OVERRUN => "The system detected an overrun of a stack-based buffer in this application. This overrun could potentially allow a malicious user to gain control of this application.",
            WIN32::ERROR_PARAMETER_QUOTA_EXCEEDED => "Data present in one of the parameters is more than the function can operate on.",
            WIN32::ERROR_DEBUGGER_INACTIVE => "An attempt to do an operation on a debug object failed because the object is in the process of being deleted.",
            WIN32::ERROR_DELAY_LOAD_FAILED => "An attempt to delay-load a .dll or get a function address in a delay-loaded .dll failed.",
            WIN32::ERROR_VDM_DISALLOWED => "%1 is a 16-bit application. You do not have permissions to execute 16-bit applications. Check your permissions with your system administrator.",
            WIN32::ERROR_UNIDENTIFIED_ERROR => "Insufficient information exists to identify the cause of failure.",
            WIN32::ERROR_INVALID_CRUNTIME_PARAMETER => "The parameter passed to a C runtime function is incorrect.",
            WIN32::ERROR_BEYOND_VDL => "The operation occurred beyond the valid data length of the file.",
            WIN32::ERROR_INCOMPATIBLE_SERVICE_SID_TYPE => "The service start failed since one or more services in the same process have an incompatible service SID type setting. A service with restricted service SID type can only coexist in the same process with other services with a restricted SID type. If the service SID type for this service was just configured, the hosting process must be restarted in order to start this service.",
            WIN32::ERROR_DRIVER_PROCESS_TERMINATED => "The process hosting the driver for this device has been terminated.",
            WIN32::ERROR_IMPLEMENTATION_LIMIT => "An operation attempted to exceed an implementation-defined limit.",
            WIN32::ERROR_PROCESS_IS_PROTECTED => "Either the target process, or the target thread's containing process, is a protected process.",
            WIN32::ERROR_SERVICE_NOTIFY_CLIENT_LAGGING => "The service notification client is lagging too far behind the current state of services in the machine.",
            WIN32::ERROR_DISK_QUOTA_EXCEEDED => "The requested file operation failed because the storage quota was exceeded.",
            WIN32::ERROR_CONTENT_BLOCKED => "The requested file operation failed because the storage policy blocks that type of file. For more information, contact your system administrator.",
            WIN32::ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE => "A privilege that the service requires to function properly does not exist in the service account configuration.",
            WIN32::ERROR_APP_HANG => "A thread involved in this operation appears to be unresponsive.",
            WIN32::ERROR_INVALID_LABEL => "Indicates a particular Security ID may not be assigned as the label of an object.",
            WIN32::ERROR_NOT_ALL_ASSIGNED => "Not all privileges or groups referenced are assigned to the caller.",
            WIN32::ERROR_SOME_NOT_MAPPED => "Some mapping between account names and security IDs was not done.",
            WIN32::ERROR_NO_QUOTAS_FOR_ACCOUNT => "No system quota limits are specifically set for this account.",
            WIN32::ERROR_LOCAL_USER_SESSION_KEY => "No encryption key is available. A well-known encryption key was returned.",
            WIN32::ERROR_NULL_LM_PASSWORD => "The password is too complex to be converted to a LAN Manager password. The LAN Manager password returned is a NULL string.",
            WIN32::ERROR_UNKNOWN_REVISION => "The revision level is unknown.",
            WIN32::ERROR_REVISION_MISMATCH => "Indicates two revision levels are incompatible.",
            WIN32::ERROR_INVALID_OWNER => "This security ID may not be assigned as the owner of this object.",
            WIN32::ERROR_INVALID_PRIMARY_GROUP => "This security ID may not be assigned as the primary group of an object.",
            WIN32::ERROR_NO_IMPERSONATION_TOKEN => "An attempt has been made to operate on an impersonation token by a thread that is not currently impersonating a client.",
            WIN32::ERROR_CANT_DISABLE_MANDATORY => "The group may not be disabled.",
            WIN32::ERROR_NO_LOGON_SERVERS => "We can't sign you in with this credential because your domain isn't available. Make sure your device is connected to your organization's network and try again. If you previously signed in on this device with another credential, you can sign in with that credential.",
            WIN32::ERROR_NO_SUCH_LOGON_SESSION => "A specified logon session does not exist. It may already have been terminated.",
            WIN32::ERROR_NO_SUCH_PRIVILEGE => "A specified privilege does not exist.",
            WIN32::ERROR_PRIVILEGE_NOT_HELD => "A required privilege is not held by the client.",
            WIN32::ERROR_INVALID_ACCOUNT_NAME => "The name provided is not a properly formed account name.",
            WIN32::ERROR_USER_EXISTS => "The specified account already exists.",
            WIN32::ERROR_NO_SUCH_USER => "The specified account does not exist.",
            WIN32::ERROR_GROUP_EXISTS => "The specified group already exists.",
            WIN32::ERROR_NO_SUCH_GROUP => "The specified group does not exist.",
            WIN32::ERROR_MEMBER_IN_GROUP => "Either the specified user account is already a member of the specified group, or the specified group cannot be deleted because it contains a member.",
            WIN32::ERROR_MEMBER_NOT_IN_GROUP => "The specified user account is not a member of the specified group account.",
            WIN32::ERROR_LAST_ADMIN => "This operation is disallowed as it could result in an administration account being disabled, deleted or unable to logon.",
            WIN32::ERROR_WRONG_PASSWORD => "Unable to update the password. The value provided as the current password is incorrect.",
            WIN32::ERROR_ILL_FORMED_PASSWORD => "Unable to update the password. The value provided for the new password contains values that are not allowed in passwords.",
            WIN32::ERROR_PASSWORD_RESTRICTION => "Unable to update the password. The value provided for the new password does not meet the length, complexity, or history requirements of the domain.",
            WIN32::ERROR_LOGON_FAILURE => "The user name or password is incorrect.",
            WIN32::ERROR_ACCOUNT_RESTRICTION => "Account restrictions are preventing this user from signing in. For example: blank passwords aren't allowed, sign-in times are limited, or a policy restriction has been enforced.",
            WIN32::ERROR_INVALID_LOGON_HOURS => "Your account has time restrictions that keep you from signing in right now.",
            WIN32::ERROR_INVALID_WORKSTATION => "This user isn't allowed to sign in to this computer.",
            WIN32::ERROR_PASSWORD_EXPIRED => "The password for this account has expired.",
            WIN32::ERROR_ACCOUNT_DISABLED => "This user can't sign in because this account is currently disabled.",
            WIN32::ERROR_NONE_MAPPED => "No mapping between account names and security IDs was done.",
            WIN32::ERROR_TOO_MANY_LUIDS_REQUESTED => "Too many local user identifiers (LUIDs) were requested at one time.",
            WIN32::ERROR_LUIDS_EXHAUSTED => "No more local user identifiers (LUIDs) are available.",
            WIN32::ERROR_INVALID_SUB_AUTHORITY => "The subauthority part of a security ID is invalid for this particular use.",
            WIN32::ERROR_INVALID_ACL => "The access control list (ACL) structure is invalid.",
            WIN32::ERROR_INVALID_SID => "The security ID structure is invalid.",
            WIN32::ERROR_INVALID_SECURITY_DESCR => "The security descriptor structure is invalid.",
            WIN32::ERROR_BAD_INHERITANCE_ACL => "The inherited access control list (ACL) or access control entry (ACE) could not be built.",
            WIN32::ERROR_SERVER_DISABLED => "The server is currently disabled.",
            WIN32::ERROR_SERVER_NOT_DISABLED => "The server is currently enabled.",
            WIN32::ERROR_INVALID_ID_AUTHORITY => "The value provided was an invalid value for an identifier authority.",
            WIN32::ERROR_ALLOTTED_SPACE_EXCEEDED => "No more memory is available for security information updates.",
            WIN32::ERROR_INVALID_GROUP_ATTRIBUTES => "The specified attributes are invalid, or incompatible with the attributes for the group as a whole.",
            WIN32::ERROR_BAD_IMPERSONATION_LEVEL => "Either a required impersonation level was not provided, or the provided impersonation level is invalid.",
            WIN32::ERROR_CANT_OPEN_ANONYMOUS => "Cannot open an anonymous level security token.",
            WIN32::ERROR_BAD_VALIDATION_CLASS => "The validation information class requested was invalid.",
            WIN32::ERROR_BAD_TOKEN_TYPE => "The type of the token is inappropriate for its attempted use.",
            WIN32::ERROR_NO_SECURITY_ON_OBJECT => "Unable to perform a security operation on an object that has no associated security.",
            WIN32::ERROR_CANT_ACCESS_DOMAIN_INFO => "Configuration information could not be read from the domain controller, either because the machine is unavailable, or access has been denied.",
            WIN32::ERROR_INVALID_SERVER_STATE => "The security account manager (SAM) or local security authority (LSA) server was in the wrong state to perform the security operation.",
            WIN32::ERROR_INVALID_DOMAIN_STATE => "The domain was in the wrong state to perform the security operation.",
            WIN32::ERROR_INVALID_DOMAIN_ROLE => "This operation is only allowed for the Primary Domain Controller of the domain.",
            WIN32::ERROR_NO_SUCH_DOMAIN => "The specified domain either does not exist or could not be contacted.",
            WIN32::ERROR_DOMAIN_EXISTS => "The specified domain already exists.",
            WIN32::ERROR_DOMAIN_LIMIT_EXCEEDED => "An attempt was made to exceed the limit on the number of domains per server.",
            WIN32::ERROR_INTERNAL_DB_CORRUPTION => "Unable to complete the requested operation because of either a catastrophic media failure or a data structure corruption on the disk.",
            WIN32::ERROR_INTERNAL_ERROR => "An internal error occurred.",
            WIN32::ERROR_GENERIC_NOT_MAPPED => "Generic access types were contained in an access mask which should already be mapped to nongeneric types.",
            WIN32::ERROR_BAD_DESCRIPTOR_FORMAT => "A security descriptor is not in the right format (absolute or self-relative).",
            WIN32::ERROR_NOT_LOGON_PROCESS => "The requested action is restricted for use by logon processes only. The calling process has not registered as a logon process.",
            WIN32::ERROR_LOGON_SESSION_EXISTS => "Cannot start a new logon session with an ID that is already in use.",
            WIN32::ERROR_NO_SUCH_PACKAGE => "A specified authentication package is unknown.",
            WIN32::ERROR_BAD_LOGON_SESSION_STATE => "The logon session is not in a state that is consistent with the requested operation.",
            WIN32::ERROR_LOGON_SESSION_COLLISION => "The logon session ID is already in use.",
            WIN32::ERROR_INVALID_LOGON_TYPE => "A logon request contained an invalid logon type value.",
            WIN32::ERROR_CANNOT_IMPERSONATE => "Unable to impersonate using a named pipe until data has been read from that pipe.",
            WIN32::ERROR_RXACT_INVALID_STATE => "The transaction state of a registry subtree is incompatible with the requested operation.",
            WIN32::ERROR_RXACT_COMMIT_FAILURE => "An internal security database corruption has been encountered.",
            WIN32::ERROR_SPECIAL_ACCOUNT => "Cannot perform this operation on built-in accounts.",
            WIN32::ERROR_SPECIAL_GROUP => "Cannot perform this operation on this built-in special group.",
            WIN32::ERROR_SPECIAL_USER => "Cannot perform this operation on this built-in special user.",
            WIN32::ERROR_MEMBERS_PRIMARY_GROUP => "The user cannot be removed from a group because the group is currently the user's primary group.",
            WIN32::ERROR_TOKEN_ALREADY_IN_USE => "The token is already in use as a primary token.",
            WIN32::ERROR_NO_SUCH_ALIAS => "The specified local group does not exist.",
            WIN32::ERROR_MEMBER_NOT_IN_ALIAS => "The specified account name is not a member of the group.",
            WIN32::ERROR_MEMBER_IN_ALIAS => "The specified account name is already a member of the group.",
            WIN32::ERROR_ALIAS_EXISTS => "The specified local group already exists.",
            WIN32::ERROR_LOGON_NOT_GRANTED => "Logon failure: the user has not been granted the requested logon type at this computer.",
            WIN32::ERROR_TOO_MANY_SECRETS => "The maximum number of secrets that may be stored in a single system has been exceeded.",
            WIN32::ERROR_SECRET_TOO_LONG => "The length of a secret exceeds the maximum length allowed.",
            WIN32::ERROR_INTERNAL_DB_ERROR => "The local security authority database contains an internal inconsistency.",
            WIN32::ERROR_TOO_MANY_CONTEXT_IDS => "During a logon attempt, the user's security context accumulated too many security IDs.",
            WIN32::ERROR_LOGON_TYPE_NOT_GRANTED => "Logon failure: the user has not been granted the requested logon type at this computer.",
            WIN32::ERROR_NT_CROSS_ENCRYPTION_REQUIRED => "A cross-encrypted password is necessary to change a user password.",
            WIN32::ERROR_NO_SUCH_MEMBER => "A member could not be added to or removed from the local group because the member does not exist.",
            WIN32::ERROR_INVALID_MEMBER => "A new member could not be added to a local group because the member has the wrong account type.",
            WIN32::ERROR_TOO_MANY_SIDS => "Too many security IDs have been specified.",
            WIN32::ERROR_LM_CROSS_ENCRYPTION_REQUIRED => "A cross-encrypted password is necessary to change this user password.",
            WIN32::ERROR_NO_INHERITANCE => "Indicates an ACL contains no inheritable components.",
            WIN32::ERROR_FILE_CORRUPT => "The file or directory is corrupted and unreadable.",
            WIN32::ERROR_DISK_CORRUPT => "The disk structure is corrupted and unreadable.",
            WIN32::ERROR_NO_USER_SESSION_KEY => "There is no user session key for the specified logon session.",
            WIN32::ERROR_LICENSE_QUOTA_EXCEEDED => "The service being accessed is licensed for a particular number of connections. No more connections can be made to the service at this time because there are already as many connections as the service can accept.",
            WIN32::ERROR_WRONG_TARGET_NAME => "The target account name is incorrect.",
            WIN32::ERROR_MUTUAL_AUTH_FAILED => "Mutual Authentication failed. The server's password is out of date at the domain controller.",
            WIN32::ERROR_TIME_SKEW => "There is a time and/or date difference between the client and server.",
            WIN32::ERROR_CURRENT_DOMAIN_NOT_ALLOWED => "This operation cannot be performed on the current domain.",
            WIN32::ERROR_INVALID_WINDOW_HANDLE => "Invalid window handle.",
            WIN32::ERROR_INVALID_MENU_HANDLE => "Invalid menu handle.",
            WIN32::ERROR_INVALID_CURSOR_HANDLE => "Invalid cursor handle.",
            WIN32::ERROR_INVALID_ACCEL_HANDLE => "Invalid accelerator table handle.",
            WIN32::ERROR_INVALID_HOOK_HANDLE => "Invalid hook handle.",
            WIN32::ERROR_INVALID_DWP_HANDLE => "Invalid handle to a multiple-window position structure.",
            WIN32::ERROR_TLW_WITH_WSCHILD => "Cannot create a top-level child window.",
            WIN32::ERROR_CANNOT_FIND_WND_CLASS => "Cannot find window class.",
            WIN32::ERROR_WINDOW_OF_OTHER_THREAD => "Invalid window; it belongs to other thread.",
            WIN32::ERROR_HOTKEY_ALREADY_REGISTERED => "Hot key is already registered.",
            WIN32::ERROR_CLASS_ALREADY_EXISTS => "Class already exists.",
            WIN32::ERROR_CLASS_DOES_NOT_EXIST => "Class does not exist.",
            WIN32::ERROR_CLASS_HAS_WINDOWS => "Class still has open windows.",
            WIN32::ERROR_INVALID_INDEX => "Invalid index.",
            WIN32::ERROR_INVALID_ICON_HANDLE => "Invalid icon handle.",
            WIN32::ERROR_PRIVATE_DIALOG_INDEX => "Using private DIALOG window words.",
            WIN32::ERROR_LISTBOX_ID_NOT_FOUND => "The list box identifier was not found.",
            WIN32::ERROR_NO_WILDCARD_CHARACTERS => "No wildcards were found.",
            WIN32::ERROR_CLIPBOARD_NOT_OPEN => "Thread does not have a clipboard open.",
            WIN32::ERROR_HOTKEY_NOT_REGISTERED => "Hot key is not registered.",
            WIN32::ERROR_WINDOW_NOT_DIALOG => "The window is not a valid dialog window.",
            WIN32::ERROR_CONTROL_ID_NOT_FOUND => "Control ID not found.",
            WIN32::ERROR_INVALID_COMBOBOX_MESSAGE => "Invalid message for a combo box because it does not have an edit control.",
            WIN32::ERROR_WINDOW_NOT_COMBOBOX => "The window is not a combo box.",
            WIN32::ERROR_INVALID_EDIT_HEIGHT => "Height must be less than 256.",
            WIN32::ERROR_DC_NOT_FOUND => "Invalid device context (DC) handle.",
            WIN32::ERROR_INVALID_HOOK_FILTER => "Invalid hook procedure type.",
            WIN32::ERROR_INVALID_FILTER_PROC => "Invalid hook procedure.",
            WIN32::ERROR_HOOK_NEEDS_HMOD => "Cannot set nonlocal hook without a module handle.",
            WIN32::ERROR_GLOBAL_ONLY_HOOK => "This hook procedure can only be set globally.",
            WIN32::ERROR_JOURNAL_HOOK_SET => "The journal hook procedure is already installed.",
            WIN32::ERROR_HOOK_NOT_INSTALLED => "The hook procedure is not installed.",
            WIN32::ERROR_INVALID_LB_MESSAGE => "Invalid message for single-selection list box.",
            WIN32::ERROR_SETCOUNT_ON_BAD_LB => "LB_SETCOUNT sent to non-lazy list box.",
            WIN32::ERROR_LB_WITHOUT_TABSTOPS => "This list box does not support tab stops.",
            WIN32::ERROR_DESTROY_OBJECT_OF_OTHER_THREAD => "Cannot destroy object created by another thread.",
            WIN32::ERROR_CHILD_WINDOW_MENU => "Child windows cannot have menus.",
            WIN32::ERROR_NO_SYSTEM_MENU => "The window does not have a system menu.",
            WIN32::ERROR_INVALID_MSGBOX_STYLE => "Invalid message box style.",
            WIN32::ERROR_INVALID_SPI_VALUE => "Invalid system-wide (SPI_*) parameter.",
            WIN32::ERROR_SCREEN_ALREADY_LOCKED => "Screen already locked.",
            WIN32::ERROR_HWNDS_HAVE_DIFF_PARENT => "All handles to windows in a multiple-window position structure must have the same parent.",
            WIN32::ERROR_NOT_CHILD_WINDOW => "The window is not a child window.",
            WIN32::ERROR_INVALID_GW_COMMAND => "Invalid GW_* command.",
            WIN32::ERROR_INVALID_THREAD_ID => "Invalid thread identifier.",
            WIN32::ERROR_NON_MDICHILD_WINDOW => "Cannot process a message from a window that is not a multiple document interface (MDI) window.",
            WIN32::ERROR_POPUP_ALREADY_ACTIVE => "Popup menu already active.",
            WIN32::ERROR_NO_SCROLLBARS => "The window does not have scroll bars.",
            WIN32::ERROR_INVALID_SCROLLBAR_RANGE => "Scroll bar range cannot be greater than MAXLONG.",
            WIN32::ERROR_INVALID_SHOWWIN_COMMAND => "Cannot show or remove the window in the way specified.",
            WIN32::ERROR_NO_SYSTEM_RESOURCES => "Insufficient system resources exist to complete the requested service.",
            WIN32::ERROR_NONPAGED_SYSTEM_RESOURCES => "Insufficient system resources exist to complete the requested service.",
            WIN32::ERROR_PAGED_SYSTEM_RESOURCES => "Insufficient system resources exist to complete the requested service.",
            WIN32::ERROR_WORKING_SET_QUOTA => "Insufficient quota to complete the requested service.",
            WIN32::ERROR_PAGEFILE_QUOTA => "Insufficient quota to complete the requested service.",
            WIN32::ERROR_COMMITMENT_LIMIT => "The paging file is too small for this operation to complete.",
            WIN32::ERROR_MENU_ITEM_NOT_FOUND => "A menu item was not found.",
            WIN32::ERROR_INVALID_KEYBOARD_HANDLE => "Invalid keyboard layout handle.",
            WIN32::ERROR_HOOK_TYPE_NOT_ALLOWED => "Hook type not allowed.",
            WIN32::ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION => "This operation requires an interactive window station.",
            WIN32::ERROR_TIMEOUT => "This operation returned because the timeout period expired.",
            WIN32::E_TIMEOUT => "The cloud provider failed to acknowledge a message before the time-out expired.",
            WIN32::ERROR_INVALID_MONITOR_HANDLE => "Invalid monitor handle.",
            WIN32::ERROR_INCORRECT_SIZE => "Incorrect size argument.",
            WIN32::ERROR_SYMLINK_CLASS_DISABLED => "The symbolic link cannot be followed because its type is disabled.",
            WIN32::ERROR_SYMLINK_NOT_SUPPORTED => "This application does not support the current operation on symbolic links.",
            WIN32::ERROR_XML_PARSE_ERROR => "Windows was unable to parse the requested XML data.",
            WIN32::ERROR_XMLDSIG_ERROR => "An error was encountered while processing an XML digital signature.",
            WIN32::ERROR_RESTART_APPLICATION => "This application must be restarted.",
            WIN32::ERROR_WRONG_COMPARTMENT => "The caller made the connection request in the wrong routing compartment.",
            WIN32::ERROR_AUTHIP_FAILURE => "There was an AuthIP failure when attempting to connect to the remote host.",
            WIN32::ERROR_NO_NVRAM_RESOURCES => "Insufficient NVRAM resources exist to complete the requested service. A reboot might be required.",
            WIN32::ERROR_NOT_GUI_PROCESS => "Unable to finish the requested operation because the specified process is not a GUI process.",
            WIN32::ERROR_EVENTLOG_FILE_CORRUPT => "The event log file is corrupted.",
            WIN32::ERROR_EVENTLOG_CANT_START => "No event log file could be opened, so the event logging service did not start.",
            WIN32::ERROR_LOG_FILE_FULL => "The event log file is full.",
            WIN32::ERROR_EVENTLOG_FILE_CHANGED => "The event log file has changed between read operations.",
            WIN32::ERROR_CONTAINER_ASSIGNED => "The specified Job already has a container assigned to it.",
            WIN32::ERROR_JOB_NO_CONTAINER => "The specified Job does not have a container assigned to it.",
            WIN32::ERROR_INVALID_TASK_NAME => "The specified task name is invalid.",
            WIN32::ERROR_INVALID_TASK_INDEX => "The specified task index is invalid.",
            WIN32::ERROR_THREAD_ALREADY_IN_TASK => "The specified thread is already joining a task.",
            WIN32::ERROR_INSTALL_SERVICE_FAILURE => "The Windows Installer Service could not be accessed. This can occur if the Windows Installer is not correctly installed. Contact your support personnel for assistance.",
            WIN32::ERROR_INSTALL_USEREXIT => "User cancelled installation.",
            WIN32::ERROR_INSTALL_FAILURE => "Fatal error during installation.",
            WIN32::ERROR_INSTALL_SUSPEND => "Installation suspended, incomplete.",
            WIN32::ERROR_UNKNOWN_PRODUCT => "This action is only valid for products that are currently installed.",
            WIN32::ERROR_UNKNOWN_FEATURE => "Feature ID not registered.",
            WIN32::ERROR_UNKNOWN_COMPONENT => "Component ID not registered.",
            WIN32::ERROR_UNKNOWN_PROPERTY => "Unknown property.",
            WIN32::ERROR_INVALID_HANDLE_STATE => "Handle is in an invalid state.",
            WIN32::ERROR_BAD_CONFIGURATION => "The configuration data for this product is corrupt. Contact your support personnel.",
            WIN32::ERROR_INDEX_ABSENT => "Component qualifier not present.",
            WIN32::ERROR_INSTALL_SOURCE_ABSENT => "The installation source for this product is not available. Verify that the source exists and that you can access it.",
            WIN32::ERROR_INSTALL_PACKAGE_VERSION => "This installation package cannot be installed by the Windows Installer service. You must install a Windows service pack that contains a newer version of the Windows Installer service.",
            WIN32::ERROR_PRODUCT_UNINSTALLED => "Product is uninstalled.",
            WIN32::ERROR_BAD_QUERY_SYNTAX => "SQL query syntax invalid or unsupported.",
            WIN32::ERROR_INVALID_FIELD => "Record field does not exist.",
            WIN32::ERROR_DEVICE_REMOVED => "The device has been removed.",
            WIN32::ERROR_INSTALL_ALREADY_RUNNING => "Another installation is already in progress. Complete that installation before proceeding with this install.",
            WIN32::ERROR_INSTALL_PACKAGE_OPEN_FAILED => "This installation package could not be opened. Verify that the package exists and that you can access it, or contact the application vendor to verify that this is a valid Windows Installer package.",
            WIN32::ERROR_INSTALL_PACKAGE_INVALID => "This installation package could not be opened. Contact the application vendor to verify that this is a valid Windows Installer package.",
            WIN32::ERROR_INSTALL_UI_FAILURE => "There was an error starting the Windows Installer service user interface. Contact your support personnel.",
            WIN32::ERROR_INSTALL_LOG_FAILURE => "Error opening installation log file. Verify that the specified log file location exists and that you can write to it.",
            WIN32::ERROR_INSTALL_LANGUAGE_UNSUPPORTED => "The language of this installation package is not supported by your system.",
            WIN32::ERROR_INSTALL_TRANSFORM_FAILURE => "Error applying transforms. Verify that the specified transform paths are valid.",
            WIN32::ERROR_INSTALL_PACKAGE_REJECTED => "This installation is forbidden by system policy. Contact your system administrator.",
            WIN32::ERROR_FUNCTION_NOT_CALLED => "Function could not be executed.",
            WIN32::ERROR_FUNCTION_FAILED => "Function failed during execution.",
            WIN32::ERROR_INVALID_TABLE => "Invalid or unknown table specified.",
            WIN32::ERROR_DATATYPE_MISMATCH => "Data supplied is of wrong type.",
            WIN32::ERROR_UNSUPPORTED_TYPE => "Data of this type is not supported.",
            WIN32::ERROR_CREATE_FAILED => "The Windows Installer service failed to start. Contact your support personnel.",
            WIN32::ERROR_INSTALL_TEMP_UNWRITABLE => "The Temp folder is on a drive that is full or is inaccessible. Free up space on the drive or verify that you have write permission on the Temp folder.",
            WIN32::ERROR_INSTALL_PLATFORM_UNSUPPORTED => "This installation package is not supported by this processor type. Contact your product vendor.",
            WIN32::ERROR_INSTALL_NOTUSED => "Component not used on this computer.",
            WIN32::ERROR_PATCH_PACKAGE_OPEN_FAILED => "This update package could not be opened. Verify that the update package exists and that you can access it, or contact the application vendor to verify that this is a valid Windows Installer update package.",
            WIN32::ERROR_PATCH_PACKAGE_INVALID => "This update package could not be opened. Contact the application vendor to verify that this is a valid Windows Installer update package.",
            WIN32::ERROR_PATCH_PACKAGE_UNSUPPORTED => "This update package cannot be processed by the Windows Installer service. You must install a Windows service pack that contains a newer version of the Windows Installer service.",
            WIN32::ERROR_PRODUCT_VERSION => "Another version of this product is already installed. Installation of this version cannot continue. To configure or remove the existing version of this product, use Add/Remove Programs on the Control Panel.",
            WIN32::ERROR_INVALID_COMMAND_LINE => "Invalid command line argument. Consult the Windows Installer SDK for detailed command line help.",
            WIN32::ERROR_INSTALL_REMOTE_DISALLOWED => "Only administrators have permission to add, remove, or configure server software during a Terminal services remote session. If you want to install or configure software on the server, contact your network administrator.",
            WIN32::ERROR_SUCCESS_REBOOT_INITIATED => "The requested operation completed successfully. The system will be restarted so the changes can take effect.",
            WIN32::ERROR_PATCH_TARGET_NOT_FOUND => "The upgrade cannot be installed by the Windows Installer service because the program to be upgraded may be missing, or the upgrade may update a different version of the program. Verify that the program to be upgraded exists on your computer and that you have the correct upgrade.",
            WIN32::ERROR_PATCH_PACKAGE_REJECTED => "The update package is not permitted by software restriction policy.",
            WIN32::ERROR_INSTALL_TRANSFORM_REJECTED => "One or more customizations are not permitted by software restriction policy.",
            WIN32::ERROR_INSTALL_REMOTE_PROHIBITED => "The Windows Installer does not permit installation from a Remote Desktop Connection.",
            WIN32::ERROR_PATCH_REMOVAL_UNSUPPORTED => "Uninstallation of the update package is not supported.",
            WIN32::ERROR_UNKNOWN_PATCH => "The update is not applied to this product.",
            WIN32::ERROR_PATCH_NO_SEQUENCE => "No valid sequence could be found for the set of updates.",
            WIN32::ERROR_PATCH_REMOVAL_DISALLOWED => "Update removal was disallowed by policy.",
            WIN32::ERROR_INVALID_PATCH_XML => "The XML update data is invalid.",
            WIN32::ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT => "Windows Installer does not permit updating of managed advertised products. At least one feature of the product must be installed before applying the update.",
            WIN32::ERROR_INSTALL_SERVICE_SAFEBOOT => "The Windows Installer service is not accessible in Safe Mode. Please try again when your computer is not in Safe Mode or you can use System Restore to return your machine to a previous good state.",
            WIN32::ERROR_FAIL_FAST_EXCEPTION => "A fail fast exception occurred. Exception handlers will not be invoked and the process will be terminated immediately.",
            WIN32::ERROR_INSTALL_REJECTED => "The app that you are trying to run is not supported on this version of Windows.",
            WIN32::ERROR_DYNAMIC_CODE_BLOCKED => "The operation was blocked as the process prohibits dynamic code generation.",
            WIN32::ERROR_NOT_SAME_OBJECT => "The objects are not identical.",
            WIN32::ERROR_STRICT_CFG_VIOLATION => "The specified image file was blocked from loading because it does not enable a feature required by the process: Control Flow Guard.",
            WIN32::ERROR_STRICT_RFG_VIOLATION => "The specified image file was blocked from loading because it does not enable a feature required by the process: Return Flow Guard.",
            WIN32::ERROR_RFG_ACCESS_VIOLATION => "An invalid memory access occurred to a Return Flow Guard restricted region.",
            WIN32::ERROR_SET_CONTEXT_DENIED => "The thread context could not be updated because this has been restricted for the process.",
            WIN32::ERROR_CROSS_PARTITION_VIOLATION => "An invalid cross-partition private file/section access was attempted.",
            WIN32::ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT => "A return address hijack is being attempted. This is supported by the operating system when user-mode shadow stacks are enabled.",
            WIN32::RPC_S_INVALID_STRING_BINDING => "The string binding is invalid.",
            WIN32::RPC_S_WRONG_KIND_OF_BINDING => "The binding handle is not the correct type.",
            WIN32::RPC_S_INVALID_BINDING => "The binding handle is invalid.",
            WIN32::RPC_S_PROTSEQ_NOT_SUPPORTED => "The RPC protocol sequence is not supported.",
            WIN32::RPC_S_INVALID_RPC_PROTSEQ => "The RPC protocol sequence is invalid.",
            WIN32::RPC_S_INVALID_STRING_UUID => "The string universal unique identifier (UUID) is invalid.",
            WIN32::RPC_S_INVALID_ENDPOINT_FORMAT => "The endpoint format is invalid.",
            WIN32::RPC_S_INVALID_NET_ADDR => "The network address is invalid.",
            WIN32::RPC_S_NO_ENDPOINT_FOUND => "No endpoint was found.",
            WIN32::RPC_S_INVALID_TIMEOUT => "The timeout value is invalid.",
            WIN32::RPC_S_OBJECT_NOT_FOUND => "The object universal unique identifier (UUID) was not found.",
            WIN32::RPC_S_ALREADY_REGISTERED => "The object universal unique identifier (UUID) has already been registered.",
            WIN32::RPC_S_TYPE_ALREADY_REGISTERED => "The type universal unique identifier (UUID) has already been registered.",
            WIN32::RPC_S_ALREADY_LISTENING => "The RPC server is already listening.",
            WIN32::RPC_S_NO_PROTSEQS_REGISTERED => "No protocol sequences have been registered.",
            WIN32::RPC_S_NOT_LISTENING => "The RPC server is not listening.",
            WIN32::RPC_S_UNKNOWN_MGR_TYPE => "The manager type is unknown.",
            WIN32::RPC_S_UNKNOWN_IF => "The interface is unknown.",
            WIN32::RPC_S_NO_BINDINGS => "There are no bindings.",
            WIN32::RPC_S_NO_PROTSEQS => "There are no protocol sequences.",
            WIN32::RPC_S_CANT_CREATE_ENDPOINT => "The endpoint cannot be created.",
            WIN32::RPC_S_OUT_OF_RESOURCES => "Not enough resources are available to complete this operation.",
            WIN32::RPC_S_SERVER_UNAVAILABLE => "The RPC server is unavailable.",
            WIN32::RPC_S_SERVER_TOO_BUSY => "The RPC server is too busy to complete this operation.",
            WIN32::RPC_S_INVALID_NETWORK_OPTIONS => "The network options are invalid.",
            WIN32::RPC_S_NO_CALL_ACTIVE => "There are no remote procedure calls active on this thread.",
            WIN32::RPC_S_CALL_FAILED => "The remote procedure call failed.",
            WIN32::RPC_S_CALL_FAILED_DNE => "The remote procedure call failed and did not execute.",
            WIN32::RPC_S_PROTOCOL_ERROR => "A remote procedure call (RPC) protocol error occurred.",
            WIN32::RPC_S_PROXY_ACCESS_DENIED => "Access to the HTTP proxy is denied.",
            WIN32::RPC_S_UNSUPPORTED_TRANS_SYN => "The transfer syntax is not supported by the RPC server.",
            WIN32::RPC_S_UNSUPPORTED_TYPE => "The universal unique identifier (UUID) type is not supported.",
            WIN32::RPC_S_INVALID_TAG => "The tag is invalid.",
            WIN32::RPC_S_INVALID_BOUND => "The array bounds are invalid.",
            WIN32::RPC_S_NO_ENTRY_NAME => "The binding does not contain an entry name.",
            WIN32::RPC_S_INVALID_NAME_SYNTAX => "The name syntax is invalid.",
            WIN32::RPC_S_UNSUPPORTED_NAME_SYNTAX => "The name syntax is not supported.",
            WIN32::RPC_S_UUID_NO_ADDRESS => "No network address is available to use to construct a universal unique identifier (UUID).",
            WIN32::RPC_S_DUPLICATE_ENDPOINT => "The endpoint is a duplicate.",
            WIN32::RPC_S_UNKNOWN_AUTHN_TYPE => "The authentication type is unknown.",
            WIN32::RPC_S_MAX_CALLS_TOO_SMALL => "The maximum number of calls is too small.",
            WIN32::RPC_S_STRING_TOO_LONG => "The string is too long.",
            WIN32::RPC_S_PROTSEQ_NOT_FOUND => "The RPC protocol sequence was not found.",
            WIN32::RPC_S_PROCNUM_OUT_OF_RANGE => "The procedure number is out of range.",
            WIN32::RPC_S_BINDING_HAS_NO_AUTH => "The binding does not contain any authentication information.",
            WIN32::RPC_S_UNKNOWN_AUTHN_SERVICE => "The authentication service is unknown.",
            WIN32::RPC_S_UNKNOWN_AUTHN_LEVEL => "The authentication level is unknown.",
            WIN32::RPC_S_INVALID_AUTH_IDENTITY => "The security context is invalid.",
            WIN32::RPC_S_UNKNOWN_AUTHZ_SERVICE => "The authorization service is unknown.",
            WIN32::EPT_S_INVALID_ENTRY => "The entry is invalid.",
            WIN32::EPT_S_CANT_PERFORM_OP => "The server endpoint cannot perform the operation.",
            WIN32::EPT_S_NOT_REGISTERED => "There are no more endpoints available from the endpoint mapper.",
            WIN32::RPC_S_NOTHING_TO_EXPORT => "No interfaces have been exported.",
            WIN32::RPC_S_INCOMPLETE_NAME => "The entry name is incomplete.",
            WIN32::RPC_S_INVALID_VERS_OPTION => "The version option is invalid.",
            WIN32::RPC_S_NO_MORE_MEMBERS => "There are no more members.",
            WIN32::RPC_S_NOT_ALL_OBJS_UNEXPORTED => "There is nothing to unexport.",
            WIN32::RPC_S_INTERFACE_NOT_FOUND => "The interface was not found.",
            WIN32::RPC_S_ENTRY_ALREADY_EXISTS => "The entry already exists.",
            WIN32::RPC_S_ENTRY_NOT_FOUND => "The entry is not found.",
            WIN32::RPC_S_NAME_SERVICE_UNAVAILABLE => "The name service is unavailable.",
            WIN32::RPC_S_INVALID_NAF_ID => "The network address family is invalid.",
            WIN32::RPC_S_CANNOT_SUPPORT => "The requested operation is not supported.",
            WIN32::RPC_S_NO_CONTEXT_AVAILABLE => "No security context is available to allow impersonation.",
            WIN32::RPC_S_INTERNAL_ERROR => "An internal error occurred in a remote procedure call (RPC).",
            WIN32::RPC_S_ZERO_DIVIDE => "The RPC server attempted an integer division by zero.",
            WIN32::RPC_S_ADDRESS_ERROR => "An addressing error occurred in the RPC server.",
            WIN32::RPC_S_FP_DIV_ZERO => "A floating-point operation at the RPC server caused a division by zero.",
            WIN32::RPC_S_FP_UNDERFLOW => "A floating-point underflow occurred at the RPC server.",
            WIN32::RPC_S_FP_OVERFLOW => "A floating-point overflow occurred at the RPC server.",
            WIN32::RPC_X_NO_MORE_ENTRIES => "The list of RPC servers available for the binding of auto handles has been exhausted.",
            WIN32::RPC_X_SS_CHAR_TRANS_OPEN_FAIL => "Unable to open the character translation table file.",
            WIN32::RPC_X_SS_CHAR_TRANS_SHORT_FILE => "The file containing the character translation table has fewer than 512 bytes.",
            WIN32::RPC_X_SS_IN_NULL_CONTEXT => "A null context handle was passed from the client to the host during a remote procedure call.",
            WIN32::RPC_X_SS_CONTEXT_DAMAGED => "The context handle changed during a remote procedure call.",
            WIN32::RPC_X_SS_HANDLES_MISMATCH => "The binding handles passed to a remote procedure call do not match.",
            WIN32::RPC_X_SS_CANNOT_GET_CALL_HANDLE => "The stub is unable to get the remote procedure call handle.",
            WIN32::RPC_X_NULL_REF_POINTER => "A null reference pointer was passed to the stub.",
            WIN32::RPC_X_ENUM_VALUE_OUT_OF_RANGE => "The enumeration value is out of range.",
            WIN32::RPC_X_BYTE_COUNT_TOO_SMALL => "The byte count is too small.",
            WIN32::RPC_X_BAD_STUB_DATA => "The stub received bad data.",
            WIN32::ERROR_INVALID_USER_BUFFER => "The supplied user buffer is not valid for the requested operation.",
            WIN32::ERROR_UNRECOGNIZED_MEDIA => "The disk media is not recognized. It may not be formatted.",
            WIN32::ERROR_NO_TRUST_LSA_SECRET => "The workstation does not have a trust secret.",
            WIN32::ERROR_NO_TRUST_SAM_ACCOUNT => "The security database on the server does not have a computer account for this workstation trust relationship.",
            WIN32::ERROR_TRUSTED_DOMAIN_FAILURE => "The trust relationship between the primary domain and the trusted domain failed.",
            WIN32::ERROR_TRUSTED_RELATIONSHIP_FAILURE => "The trust relationship between this workstation and the primary domain failed.",
            WIN32::ERROR_TRUST_FAILURE => "The network logon failed.",
            WIN32::RPC_S_CALL_IN_PROGRESS => "A remote procedure call is already in progress for this thread.",
            WIN32::ERROR_NETLOGON_NOT_STARTED => "An attempt was made to logon, but the network logon service was not started.",
            WIN32::ERROR_ACCOUNT_EXPIRED => "The user's account has expired.",
            WIN32::ERROR_REDIRECTOR_HAS_OPEN_HANDLES => "The redirector is in use and cannot be unloaded.",
            WIN32::ERROR_PRINTER_DRIVER_ALREADY_INSTALLED => "The specified printer driver is already installed.",
            WIN32::ERROR_UNKNOWN_PORT => "The specified port is unknown.",
            WIN32::ERROR_UNKNOWN_PRINTER_DRIVER => "The printer driver is unknown.",
            WIN32::ERROR_UNKNOWN_PRINTPROCESSOR => "The print processor is unknown.",
            WIN32::ERROR_INVALID_SEPARATOR_FILE => "The specified separator file is invalid.",
            WIN32::ERROR_INVALID_PRIORITY => "The specified priority is invalid.",
            WIN32::ERROR_INVALID_PRINTER_NAME => "The printer name is invalid.",
            WIN32::ERROR_PRINTER_ALREADY_EXISTS => "The printer already exists.",
            WIN32::ERROR_INVALID_PRINTER_COMMAND => "The printer command is invalid.",
            WIN32::ERROR_INVALID_DATATYPE => "The specified datatype is invalid.",
            WIN32::ERROR_INVALID_ENVIRONMENT => "The environment specified is invalid.",
            WIN32::RPC_S_NO_MORE_BINDINGS => "There are no more bindings.",
            WIN32::ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT => "The account used is an interdomain trust account. Use your global user account or local user account to access this server.",
            WIN32::ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT => "The account used is a computer account. Use your global user account or local user account to access this server.",
            WIN32::ERROR_NOLOGON_SERVER_TRUST_ACCOUNT => "The account used is a server trust account. Use your global user account or local user account to access this server.",
            WIN32::ERROR_DOMAIN_TRUST_INCONSISTENT => "The name or security ID (SID) of the domain specified is inconsistent with the trust information for that domain.",
            WIN32::ERROR_SERVER_HAS_OPEN_HANDLES => "The server is in use and cannot be unloaded.",
            WIN32::ERROR_RESOURCE_DATA_NOT_FOUND => "The specified image file did not contain a resource section.",
            WIN32::ERROR_RESOURCE_TYPE_NOT_FOUND => "The specified resource type cannot be found in the image file.",
            WIN32::ERROR_RESOURCE_NAME_NOT_FOUND => "The specified resource name cannot be found in the image file.",
            WIN32::ERROR_RESOURCE_LANG_NOT_FOUND => "The specified resource language ID cannot be found in the image file.",
            WIN32::ERROR_NOT_ENOUGH_QUOTA => "Not enough quota is available to process this command.",
            WIN32::RPC_S_NO_INTERFACES => "No interfaces have been registered.",
            WIN32::RPC_S_CALL_CANCELLED => "The remote procedure call was cancelled.",
            WIN32::RPC_S_BINDING_INCOMPLETE => "The binding handle does not contain all required information.",
            WIN32::RPC_S_COMM_FAILURE => "A communications failure occurred during a remote procedure call.",
            WIN32::RPC_S_UNSUPPORTED_AUTHN_LEVEL => "The requested authentication level is not supported.",
            WIN32::RPC_S_NO_PRINC_NAME => "No principal name registered.",
            WIN32::RPC_S_NOT_RPC_ERROR => "The error specified is not a valid Windows RPC error code.",
            WIN32::RPC_S_UUID_LOCAL_ONLY => "A UUID that is valid only on this computer has been allocated.",
            WIN32::RPC_S_SEC_PKG_ERROR => "A security package specific error occurred.",
            WIN32::RPC_S_NOT_CANCELLED => "Thread is not canceled.",
            WIN32::RPC_X_INVALID_ES_ACTION => "Invalid operation on the encoding/decoding handle.",
            WIN32::RPC_X_WRONG_ES_VERSION => "Incompatible version of the serializing package.",
            WIN32::RPC_X_WRONG_STUB_VERSION => "Incompatible version of the RPC stub.",
            WIN32::RPC_X_INVALID_PIPE_OBJECT => "The RPC pipe object is invalid or corrupted.",
            WIN32::RPC_X_WRONG_PIPE_ORDER => "An invalid operation was attempted on an RPC pipe object.",
            WIN32::RPC_X_WRONG_PIPE_VERSION => "Unsupported RPC pipe version.",
            WIN32::RPC_S_COOKIE_AUTH_FAILED => "HTTP proxy server rejected the connection because the cookie authentication failed.",
            WIN32::RPC_S_DO_NOT_DISTURB => "The RPC server is suspended, and could not be resumed for this request. The call did not execute.",
            WIN32::RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED => "The RPC call contains too many handles to be transmitted in a single request.",
            WIN32::RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH => "The RPC call contains a handle that differs from the declared handle type.",
            WIN32::RPC_S_GROUP_MEMBER_NOT_FOUND => "The group member was not found.",
            WIN32::EPT_S_CANT_CREATE => "The endpoint mapper database entry could not be created.",
            WIN32::RPC_S_INVALID_OBJECT => "The object universal unique identifier (UUID) is the nil UUID.",
            WIN32::ERROR_INVALID_TIME => "The specified time is invalid.",
            WIN32::ERROR_INVALID_FORM_NAME => "The specified form name is invalid.",
            WIN32::ERROR_INVALID_FORM_SIZE => "The specified form size is invalid.",
            WIN32::ERROR_ALREADY_WAITING => "The specified printer handle is already being waited on.",
            WIN32::ERROR_PRINTER_DELETED => "The specified printer has been deleted.",
            WIN32::ERROR_INVALID_PRINTER_STATE => "The state of the printer is invalid.",
            WIN32::ERROR_PASSWORD_MUST_CHANGE => "The user's password must be changed before signing in.",
            WIN32::ERROR_DOMAIN_CONTROLLER_NOT_FOUND => "Could not find the domain controller for this domain.",
            WIN32::ERROR_ACCOUNT_LOCKED_OUT => "The referenced account is currently locked out and may not be logged on to.",
            WIN32::OR_INVALID_OXID => "The object exporter specified was not found.",
            WIN32::OR_INVALID_OID => "The object specified was not found.",
            WIN32::OR_INVALID_SET => "The object resolver set specified was not found.",
            WIN32::RPC_S_SEND_INCOMPLETE => "Some data remains to be sent in the request buffer.",
            WIN32::RPC_S_INVALID_ASYNC_HANDLE => "Invalid asynchronous remote procedure call handle.",
            WIN32::RPC_S_INVALID_ASYNC_CALL => "Invalid asynchronous RPC call handle for this operation.",
            WIN32::RPC_X_PIPE_CLOSED => "The RPC pipe object has already been closed.",
            WIN32::RPC_X_PIPE_DISCIPLINE_ERROR => "The RPC call completed before all pipes were processed.",
            WIN32::RPC_X_PIPE_EMPTY => "No more data is available from the RPC pipe.",
            WIN32::ERROR_NO_SITENAME => "No site name is available for this machine.",
            WIN32::ERROR_CANT_ACCESS_FILE => "The file cannot be accessed by the system.",
            WIN32::ERROR_CANT_RESOLVE_FILENAME => "The name of the file cannot be resolved by the system.",
            WIN32::RPC_S_ENTRY_TYPE_MISMATCH => "The entry is not of the expected type.",
            WIN32::RPC_S_NOT_ALL_OBJS_EXPORTED => "Not all object UUIDs could be exported to the specified entry.",
            WIN32::RPC_S_INTERFACE_NOT_EXPORTED => "Interface could not be exported to the specified entry.",
            WIN32::RPC_S_PROFILE_NOT_ADDED => "The specified profile entry could not be added.",
            WIN32::RPC_S_PRF_ELT_NOT_ADDED => "The specified profile element could not be added.",
            WIN32::RPC_S_PRF_ELT_NOT_REMOVED => "The specified profile element could not be removed.",
            WIN32::RPC_S_GRP_ELT_NOT_ADDED => "The group element could not be added.",
            WIN32::RPC_S_GRP_ELT_NOT_REMOVED => "The group element could not be removed.",
            WIN32::ERROR_KM_DRIVER_BLOCKED => "The printer driver is not compatible with a policy enabled on your computer that blocks NT 4.0 drivers.",
            WIN32::ERROR_CONTEXT_EXPIRED => "The context has expired and can no longer be used.",
            WIN32::ERROR_PER_USER_TRUST_QUOTA_EXCEEDED => "The current user's delegated trust creation quota has been exceeded.",
            WIN32::ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED => "The total delegated trust creation quota has been exceeded.",
            WIN32::ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED => "The current user's delegated trust deletion quota has been exceeded.",
            WIN32::ERROR_AUTHENTICATION_FIREWALL_FAILED => "The computer you are signing into is protected by an authentication firewall. The specified account is not allowed to authenticate to the computer.",
            WIN32::ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED => "Remote connections to the Print Spooler are blocked by a policy set on your machine.",
            WIN32::ERROR_NTLM_BLOCKED => "Authentication failed because NTLM authentication has been disabled.",
            WIN32::ERROR_PASSWORD_CHANGE_REQUIRED => "Logon Failure: EAS policy requires that the user change their password before this operation can be performed.",
            WIN32::ERROR_LOST_MODE_LOGON_RESTRICTION => "An administrator has restricted sign in. To sign in, make sure your device is connected to the Internet, and have your administrator sign in first.",
            WIN32::ERROR_INVALID_PIXEL_FORMAT => "The pixel format is invalid.",
            WIN32::ERROR_BAD_DRIVER => "The specified driver is invalid.",
            WIN32::ERROR_INVALID_WINDOW_STYLE => "The window style or class attribute is invalid for this operation.",
            WIN32::ERROR_METAFILE_NOT_SUPPORTED => "The requested metafile operation is not supported.",
            WIN32::ERROR_TRANSFORM_NOT_SUPPORTED => "The requested transformation operation is not supported.",
            WIN32::ERROR_CLIPPING_NOT_SUPPORTED => "The requested clipping operation is not supported.",
            WIN32::ERROR_INVALID_CMM => "The specified color management module is invalid.",
            WIN32::ERROR_INVALID_PROFILE => "The specified color profile is invalid.",
            WIN32::ERROR_TAG_NOT_FOUND => "The specified tag was not found.",
            WIN32::ERROR_TAG_NOT_PRESENT => "A required tag is not present.",
            WIN32::ERROR_DUPLICATE_TAG => "The specified tag is already present.",
            WIN32::ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE => "The specified color profile is not associated with the specified device.",
            WIN32::ERROR_PROFILE_NOT_FOUND => "The specified color profile was not found.",
            WIN32::ERROR_INVALID_COLORSPACE => "The specified color space is invalid.",
            WIN32::ERROR_ICM_NOT_ENABLED => "Image Color Management is not enabled.",
            WIN32::ERROR_DELETING_ICM_XFORM => "There was an error while deleting the color transform.",
            WIN32::ERROR_INVALID_TRANSFORM => "The specified color transform is invalid.",
            WIN32::ERROR_COLORSPACE_MISMATCH => "The specified transform does not match the bitmap's color space.",
            WIN32::ERROR_INVALID_COLORINDEX => "The specified named color index is not present in the profile.",
            WIN32::ERROR_PROFILE_DOES_NOT_MATCH_DEVICE => "The specified profile is intended for a device of a different type than the specified device.",
            WIN32::NERR_NetNotStarted => "The workstation driver is not installed.",
            WIN32::NERR_UnknownServer => "The server could not be located.",
            WIN32::NERR_ShareMem => "An internal error occurred. The network cannot access a shared memory segment.",
            WIN32::NERR_NoNetworkResource => "A network resource shortage occurred.",
            WIN32::NERR_RemoteOnly => "This operation is not supported on workstations.",
            WIN32::NERR_DevNotRedirected => "The device is not connected.",
            WIN32::ERROR_CONNECTED_OTHER_PASSWORD => "The network connection was made successfully, but the user had to be prompted for a password other than the one originally specified.",
            WIN32::ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT => "The network connection was made successfully using default credentials.",
            WIN32::NERR_ServerNotStarted => "The Server service is not started.",
            WIN32::NERR_ItemNotFound => "The queue is empty.",
            WIN32::NERR_UnknownDevDir => "The device or directory does not exist.",
            WIN32::NERR_RedirectedPath => "The operation is invalid on a redirected resource.",
            WIN32::NERR_DuplicateShare => "The name has already been shared.",
            WIN32::NERR_NoRoom => "The server is currently out of the requested resource.",
            WIN32::NERR_TooManyItems => "Requested addition of items exceeds the maximum allowed.",
            WIN32::NERR_InvalidMaxUsers => "The Peer service supports only two simultaneous users.",
            WIN32::NERR_BufTooSmall => "The API return buffer is too small.",
            WIN32::NERR_RemoteErr => "A remote API error occurred.",
            WIN32::NERR_LanmanIniError => "An error occurred when opening or reading the configuration file.",
            WIN32::NERR_NetworkError => "A general network error occurred.",
            WIN32::NERR_WkstaInconsistentState => "The Workstation service is in an inconsistent state. Restart the computer before restarting the Workstation service.",
            WIN32::NERR_WkstaNotStarted => "The Workstation service has not been started.",
            WIN32::NERR_BrowserNotStarted => "The requested information is not available.",
            WIN32::NERR_InternalError => "An internal error occurred.",
            WIN32::NERR_BadTransactConfig => "The server is not configured for transactions.",
            WIN32::NERR_InvalidAPI => "The requested API is not supported on the remote server.",
            WIN32::NERR_BadEventName => "The event name is invalid.",
            WIN32::NERR_DupNameReboot => "The computer name already exists on the network. Change it and reboot the computer.",
            WIN32::NERR_CfgCompNotFound => "The specified component could not be found in the configuration information.",
            WIN32::NERR_CfgParamNotFound => "The specified parameter could not be found in the configuration information.",
            WIN32::NERR_LineTooLong => "A line in the configuration file is too long.",
            WIN32::NERR_QNotFound => "The printer does not exist.",
            WIN32::NERR_JobNotFound => "The print job does not exist.",
            WIN32::NERR_DestNotFound => "The printer destination cannot be found.",
            WIN32::NERR_DestExists => "The printer destination already exists.",
            WIN32::NERR_QExists => "The print queue already exists.",
            WIN32::NERR_QNoRoom => "No more printers can be added.",
            WIN32::NERR_JobNoRoom => "No more print jobs can be added.",
            WIN32::NERR_DestNoRoom => "No more printer destinations can be added.",
            WIN32::NERR_DestIdle => "This printer destination is idle and cannot accept control operations.",
            WIN32::NERR_DestInvalidOp => "This printer destination request contains an invalid control function.",
            WIN32::NERR_ProcNoRespond => "The print processor is not responding.",
            WIN32::NERR_SpoolerNotLoaded => "The spooler is not running.",
            WIN32::NERR_DestInvalidState => "This operation cannot be performed on the print destination in its current state.",
            WIN32::NERR_QinvalidState => "This operation cannot be performed on the print queue in its current state.",
            WIN32::NERR_JobInvalidState => "This operation cannot be performed on the print job in its current state.",
            WIN32::NERR_SpoolNoMemory => "A spooler memory allocation failure occurred.",
            WIN32::NERR_DriverNotFound => "The device driver does not exist.",
            WIN32::NERR_DataTypeInvalid => "The data type is not supported by the print processor.",
            WIN32::NERR_ProcNotFound => "The print processor is not installed.",
            WIN32::NERR_ServiceTableLocked => "The service database is locked.",
            WIN32::NERR_ServiceTableFull => "The service table is full.",
            WIN32::NERR_ServiceInstalled => "The requested service has already been started.",
            WIN32::NERR_ServiceEntryLocked => "The service does not respond to control actions.",
            WIN32::NERR_ServiceNotInstalled => "The service has not been started.",
            WIN32::NERR_BadServiceName => "The service name is invalid.",
            WIN32::NERR_ServiceCtlTimeout => "The service is not responding to the control function.",
            WIN32::NERR_ServiceCtlBusy => "The service control is busy.",
            WIN32::NERR_BadServiceProgName => "The configuration file contains an invalid service program name.",
            WIN32::NERR_ServiceNotCtrl => "The service could not be controlled in its present state.",
            WIN32::NERR_ServiceKillProc => "The service ended abnormally.",
            WIN32::NERR_ServiceCtlNotValid => "The requested pause or stop is not valid for this service.",
            WIN32::NERR_NotInDispatchTbl => "The service control dispatcher could not find the service name in the dispatch table.",
            WIN32::NERR_BadControlRecv => "The service control dispatcher pipe read failed.",
            WIN32::NERR_ServiceNotStarting => "A thread for the new service could not be created.",
            WIN32::NERR_AlreadyLoggedOn => "This workstation is already logged on to the LAN.",
            WIN32::NERR_NotLoggedOn => "The workstation is not logged on to the LAN.",
            WIN32::ERROR_BAD_USERNAME => "The specified username is invalid.",
            WIN32::NERR_BadUsername => "The user name or group name parameter is invalid.",
            WIN32::NERR_BadPassword => "The password parameter is invalid.",
            WIN32::NERR_UnableToAddName_W => "The logon processor did not add the message alias.",
            WIN32::NERR_UnableToAddName_F => "The logon processor did not add the message alias.",
            WIN32::NERR_UnableToDelName_W => "@W The logoff processor did not delete the message alias.",
            WIN32::NERR_UnableToDelName_F => "The logoff processor did not delete the message alias.",
            WIN32::NERR_LogonsPaused => "Network logons are paused.",
            WIN32::NERR_LogonServerConflict => "A centralized logon server conflict occurred.",
            WIN32::NERR_LogonNoUserPath => "The server is configured without a valid user path.",
            WIN32::NERR_LogonScriptError => "An error occurred while loading or running the logon script.",
            WIN32::NERR_StandaloneLogon => "The logon server was not specified. The computer will be logged on as STANDALONE.",
            WIN32::NERR_LogonServerNotFound => "The logon server could not be found.",
            WIN32::NERR_LogonDomainExists => "There is already a logon domain for this computer.",
            WIN32::NERR_NonValidatedLogon => "The logon server could not validate the logon.",
            WIN32::NERR_ACFNotFound => "The security database could not be found.",
            WIN32::NERR_GroupNotFound => "The group name could not be found.",
            WIN32::NERR_UserNotFound => "The user name could not be found.",
            WIN32::NERR_ResourceNotFound => "The resource name could not be found.",
            WIN32::NERR_GroupExists => "The group already exists.",
            WIN32::NERR_UserExists => "The user account already exists.",
            WIN32::NERR_ResourceExists => "The resource permission list already exists.",
            WIN32::NERR_NotPrimary => "This operation is allowed only on the PDC of the domain.",
            WIN32::NERR_ACFNotLoaded => "The security database has not been started.",
            WIN32::NERR_ACFNoRoom => "There are too many names in the user accounts database.",
            WIN32::NERR_ACFFileIOFail => "A disk I/O failure occurred.",
            WIN32::NERR_ACFTooManyLists => "The limit of 64 entries per resource was exceeded.",
            WIN32::NERR_UserLogon => "Deleting a user with a session is not allowed.",
            WIN32::NERR_ACFNoParent => "The parent directory could not be located.",
            WIN32::NERR_CanNotGrowSegment => "Unable to add to the security database session cache segment.",
            WIN32::NERR_SpeGroupOp => "This operation is not allowed on this special group.",
            WIN32::NERR_NotInCache => "This user is not cached in the user accounts database session cache.",
            WIN32::NERR_UserInGroup => "The user already belongs to this group.",
            WIN32::NERR_UserNotInGroup => "The user does not belong to this group.",
            WIN32::NERR_AccountUndefined => "This user account is undefined.",
            WIN32::NERR_AccountExpired => "This user account has expired.",
            WIN32::NERR_InvalidWorkstation => "The user is not allowed to log on from this workstation.",
            WIN32::NERR_InvalidLogonHours => "The user is not allowed to log on at this time.",
            WIN32::NERR_PasswordExpired => "The password of this user has expired.",
            WIN32::NERR_PasswordCantChange => "The password of this user cannot change.",
            WIN32::NERR_PasswordHistConflict => "This password cannot be used now.",
            WIN32::NERR_PasswordTooShort => "The password does not meet the password policy requirements. Check the minimum password length, password complexity, and password history requirements.",
            WIN32::NERR_PasswordTooRecent => "The password of this user is too recent to change.",
            WIN32::NERR_InvalidDatabase => "The security database is corrupted.",
            WIN32::NERR_DatabaseUpToDate => "No updates are necessary to this replicant network or local security database.",
            WIN32::NERR_SyncRequired => "This replicant database is outdated; synchronization is required.",
            WIN32::ERROR_NOT_CONNECTED => "This network connection does not exist.",
            WIN32::NERR_UseNotFound => "The network connection could not be found.",
            WIN32::NERR_BadAsgType => "This asg_type is invalid.",
            WIN32::NERR_DeviceIsShared => "This device is currently being shared.",
            WIN32::NERR_NoComputerName => "The computer name could not be added as a message alias. The name might already exist on the network.",
            WIN32::NERR_MsgAlreadyStarted => "The Messenger service is already started.",
            WIN32::NERR_MsgInitFailed => "The Messenger service failed to start.",
            WIN32::NERR_NameNotFound => "The message alias could not be found on the network.",
            WIN32::NERR_AlreadyForwarded => "This message alias has already been forwarded.",
            WIN32::NERR_AddForwarded => "This message alias has been added but is still forwarded.",
            WIN32::NERR_AlreadyExists => "This message alias already exists locally.",
            WIN32::NERR_TooManyNames => "The maximum number of added message aliases has been exceeded.",
            WIN32::NERR_DelComputerName => "The computer name could not be deleted.",
            WIN32::NERR_LocalForward => "Messages cannot be forwarded back to the same workstation.",
            WIN32::NERR_GrpMsgProcessor => "An error occurred in the domain message processor.",
            WIN32::NERR_PausedRemote => "The message was sent, but the recipient has paused the Messenger service.",
            WIN32::NERR_BadReceive => "The message was sent but not received.",
            WIN32::NERR_NameInUse => "The message alias is currently in use. Try again later.",
            WIN32::NERR_MsgNotStarted => "The Messenger service has not been started.",
            WIN32::NERR_NotLocalName => "The name is not on the local computer.",
            WIN32::NERR_NoForwardName => "The forwarded message alias could not be found on the network.",
            WIN32::NERR_RemoteFull => "The message alias table on the remote station is full.",
            WIN32::NERR_NameNotForwarded => "Messages for this alias are not currently being forwarded.",
            WIN32::NERR_TruncatedBroadcast => "The broadcast message was truncated.",
            WIN32::NERR_InvalidDevice => "This is an invalid device name.",
            WIN32::NERR_WriteFault => "A write fault occurred.",
            WIN32::NERR_DuplicateName => "A duplicate message alias exists on the network.",
            WIN32::NERR_DeleteLater => "This message alias will be deleted later.",
            WIN32::NERR_IncompleteDel => "The message alias was not successfully deleted from all networks.",
            WIN32::NERR_MultipleNets => "This operation is not supported on computers with multiple networks.",
            WIN32::NERR_NetNameNotFound => "This shared resource does not exist.",
            WIN32::NERR_DeviceNotShared => "This device is not shared.",
            WIN32::NERR_ClientNameNotFound => "A session does not exist with that computer name.",
            WIN32::NERR_FileIdNotFound => "There is not an open file with that identification number.",
            WIN32::NERR_ExecFailure => "A failure occurred when executing a remote administration command.",
            WIN32::NERR_TmpFile => "A failure occurred when opening a remote temporary file.",
            WIN32::NERR_TooMuchData => "The data returned from a remote administration command has been truncated to 64 KB.",
            WIN32::NERR_DeviceShareConflict => "This device cannot be shared as both a spooled and a nonspooled resource.",
            WIN32::NERR_BrowserTableIncomplete => "The information in the list of servers might be incorrect.",
            WIN32::NERR_NotLocalDomain => "The computer is not active in this domain.",
            WIN32::NERR_IsDfsShare => "The share must be removed from the Distributed File System (DFS) before it can be deleted.",
            WIN32::NERR_DevInvalidOpCode => "The operation is invalid for this device.",
            WIN32::NERR_DevNotFound => "This device cannot be shared.",
            WIN32::NERR_DevNotOpen => "This device was not open.",
            WIN32::NERR_BadQueueDevString => "This device name list is invalid.",
            WIN32::NERR_BadQueuePriority => "The queue priority is invalid.",
            WIN32::NERR_NoCommDevs => "There are no shared communication devices.",
            WIN32::NERR_QueueNotFound => "The queue you specified does not exist.",
            WIN32::NERR_BadDevString => "This list of devices is invalid.",
            WIN32::NERR_BadDev => "The requested device is invalid.",
            WIN32::NERR_InUseBySpooler => "This device is already in use by the spooler.",
            WIN32::NERR_CommDevInUse => "This device is already in use as a communication device.",
            WIN32::NERR_InvalidComputer => "This computer name is invalid.",
            WIN32::NERR_MaxLenExceeded => "The string and prefix specified are too long.",
            WIN32::NERR_BadComponent => "This path component is invalid.",
            WIN32::NERR_CantType => "Could not determine the type of input.",
            WIN32::NERR_TooManyEntries => "The buffer for types is not big enough.",
            WIN32::NERR_ProfileFileTooBig => "Profile files cannot exceed 64 KB.",
            WIN32::NERR_ProfileOffset => "The start offset is out of range.",
            WIN32::NERR_ProfileCleanup => "The system cannot delete current connections to network resources.",
            WIN32::NERR_ProfileUnknownCmd => "The system was unable to parse the command line in this file.",
            WIN32::NERR_ProfileLoadErr => "An error occurred while loading the profile file.",
            WIN32::NERR_ProfileSaveErr => "Errors occurred while saving the profile file. The profile was partially saved.",
            WIN32::NERR_LogOverflow => "Log file %1 is full.",
            WIN32::NERR_LogFileChanged => "This log file has changed between reads.",
            WIN32::NERR_LogFileCorrupt => "Log file %1 is corrupt.",
            WIN32::NERR_SourceIsDir => "The source path cannot be a directory.",
            WIN32::NERR_BadSource => "The source path is illegal.",
            WIN32::NERR_BadDest => "The destination path is illegal.",
            WIN32::NERR_DifferentServers => "The source and destination paths are on different servers.",
            WIN32::NERR_RunSrvPaused => "The Run server you requested is paused.",
            WIN32::NERR_ErrCommRunSrv => "An error occurred when communicating with a Run server.",
            WIN32::NERR_ErrorExecingGhost => "An error occurred when starting a background process.",
            WIN32::NERR_ShareNotFound => "The shared resource you are connected to could not be found.",
            WIN32::NERR_InvalidLana => "The LAN adapter number is invalid.",
            WIN32::ERROR_OPEN_FILES => "This network connection has files open or requests pending.",
            WIN32::NERR_OpenFiles => "There are open files on the connection.",
            WIN32::ERROR_ACTIVE_CONNECTIONS => "Active connections still exist.",
            WIN32::NERR_ActiveConns => "Active connections still exist.",
            WIN32::NERR_BadPasswordCore => "This share name or password is invalid.",
            WIN32::ERROR_DEVICE_IN_USE => "The device is in use by an active process and cannot be disconnected.",
            WIN32::NERR_DevInUse => "The device is being accessed by an active process.",
            WIN32::NERR_LocalDrive => "The drive letter is in use locally.",
            WIN32::NERR_AlertExists => "The specified client is already registered for the specified event.",
            WIN32::NERR_TooManyAlerts => "The alert table is full.",
            WIN32::NERR_NoSuchAlert => "An invalid or nonexistent alert name was raised.",
            WIN32::NERR_BadRecipient => "The alert recipient is invalid.",
            WIN32::NERR_AcctLimitExceeded => "A user's session with this server has been deleted.",
            WIN32::NERR_InvalidLogSeek => "The log file does not contain the requested record number.",
            WIN32::NERR_BadUasConfig => "The user accounts database is not configured correctly.",
            WIN32::NERR_InvalidUASOp => "This operation is not permitted when the Net Logon service is running.",
            WIN32::NERR_LastAdmin => "This operation is not allowed on the last administrative account.",
            WIN32::NERR_DCNotFound => "Could not find the domain controller for this domain.",
            WIN32::NERR_LogonTrackingError => "Could not set logon information for this user.",
            WIN32::NERR_NetlogonNotStarted => "The Net Logon service has not been started.",
            WIN32::NERR_CanNotGrowUASFile => "Unable to add to the user accounts database.",
            WIN32::NERR_TimeDiffAtDC => "This server's clock is not synchronized with the PDC's clock.",
            WIN32::NERR_PasswordMismatch => "A password mismatch has been detected.",
            WIN32::NERR_NoSuchServer => "The server identification does not specify a valid server.",
            WIN32::NERR_NoSuchSession => "The session identification does not specify a valid session.",
            WIN32::NERR_NoSuchConnection => "The connection identification does not specify a valid connection.",
            WIN32::NERR_TooManyServers => "There is no space for another entry in the table of available servers.",
            WIN32::NERR_TooManySessions => "The server has reached the maximum number of sessions it supports.",
            WIN32::NERR_TooManyConnections => "The server has reached the maximum number of connections it supports.",
            WIN32::NERR_TooManyFiles => "The server cannot open more files because it has reached its maximum number.",
            WIN32::NERR_NoAlternateServers => "There are no alternate servers registered on this server.",
            WIN32::NERR_TryDownLevel => "Try the down-level (remote admin protocol) version of API instead.",
            WIN32::NERR_UPSDriverNotStarted => "The uninterruptible power supply (UPS) driver could not be accessed by the UPS service.",
            WIN32::NERR_UPSInvalidConfig => "The UPS service is not configured correctly.",
            WIN32::NERR_UPSInvalidCommPort => "The UPS service could not access the specified Comm Port.",
            WIN32::NERR_UPSSignalAsserted => "The UPS indicated a line fail or low battery situation. Service not started.",
            WIN32::NERR_UPSShutdownFailed => "The UPS service failed to perform a system shut down.",
            WIN32::NERR_BadDosRetCode => "The program below returned an MS-DOS error code.",
            WIN32::NERR_ProgNeedsExtraMem => "The program below needs more memory.",
            WIN32::NERR_BadDosFunction => "The program below called an unsupported MS-DOS function.",
            WIN32::NERR_RemoteBootFailed => "The workstation failed to boot.",
            WIN32::NERR_BadFileCheckSum => "The file below is corrupt.",
            WIN32::NERR_NoRplBootSystem => "No loader is specified in the boot-block definition file.",
            WIN32::NERR_RplLoadrNetBiosErr => "NetBIOS returned an error: The network control blocks (NCBs) and Server Message Block (SMB) are dumped above.",
            WIN32::NERR_RplLoadrDiskErr => "A disk I/O error occurred.",
            WIN32::NERR_ImageParamErr => "Image parameter substitution failed.",
            WIN32::NERR_TooManyImageParams => "Too many image parameters cross disk sector boundaries.",
            WIN32::NERR_NonDosFloppyUsed => "The image was not generated from an MS-DOS disk formatted with /S.",
            WIN32::NERR_RplBootRestart => "Remote boot will be restarted later.",
            WIN32::NERR_RplSrvrCallFailed => "The call to the Remoteboot server failed.",
            WIN32::NERR_CantConnectRplSrvr => "Cannot connect to the Remoteboot server.",
            WIN32::NERR_CantOpenImageFile => "Cannot open image file on the Remoteboot server.",
            WIN32::NERR_CallingRplSrvr => "Connecting to the Remoteboot server.",
            WIN32::NERR_StartingRplBoot => "Connecting to the Remoteboot server.",
            WIN32::NERR_RplBootServiceTerm => "Remote boot service was stopped, check the error log for the cause of the problem.",
            WIN32::NERR_RplBootStartFailed => "Remote boot startup failed; check the error log for the cause of the problem.",
            WIN32::NERR_RPL_CONNECTED => "A second connection to a Remoteboot resource is not allowed.",
            WIN32::NERR_BrowserConfiguredToNotRun => "The browser service was configured with MaintainServerList=No.",
            WIN32::NERR_RplNoAdaptersStarted => "Service failed to start because none of the network adapters started with this service.",
            WIN32::NERR_RplBadRegistry => "Service failed to start due to bad startup information in the registry.",
            WIN32::NERR_RplBadDatabase => "Service failed to start because its database is absent or corrupt.",
            WIN32::NERR_RplRplfilesShare => "Service failed to start because the RPLFILES share is absent.",
            WIN32::NERR_RplNotRplServer => "Service failed to start because the RPLUSER group is absent.",
            WIN32::NERR_RplCannotEnum => "Cannot enumerate service records.",
            WIN32::NERR_RplWkstaInfoCorrupted => "Workstation record information has been corrupted.",
            WIN32::NERR_RplWkstaNotFound => "Workstation record was not found.",
            WIN32::NERR_RplWkstaNameUnavailable => "Workstation name is in use by some other workstation.",
            WIN32::NERR_RplProfileInfoCorrupted => "Profile record information has been corrupted.",
            WIN32::NERR_RplProfileNotFound => "Profile record was not found.",
            WIN32::NERR_RplProfileNameUnavailable => "Profile name is in use by some other profile.",
            WIN32::NERR_RplProfileNotEmpty => "There are workstations using this profile.",
            WIN32::NERR_RplConfigInfoCorrupted => "Configuration record information has been corrupted.",
            WIN32::NERR_RplConfigNotFound => "Configuration record was not found.",
            WIN32::NERR_RplAdapterInfoCorrupted => "Adapter ID record information has been corrupted.",
            WIN32::NERR_RplInternal => "An internal service error has occurred.",
            WIN32::NERR_RplVendorInfoCorrupted => "Vendor ID record information has been corrupted.",
            WIN32::NERR_RplBootInfoCorrupted => "Boot block record information has been corrupted.",
            WIN32::NERR_RplWkstaNeedsUserAcct => "The user account for this workstation record is missing.",
            WIN32::NERR_RplNeedsRPLUSERAcct => "The RPLUSER local group could not be found.",
            WIN32::NERR_RplBootNotFound => "Boot block record was not found.",
            WIN32::NERR_RplIncompatibleProfile => "Chosen profile is incompatible with this workstation.",
            WIN32::NERR_RplAdapterNameUnavailable => "Chosen network adapter ID is in use by some other workstation.",
            WIN32::NERR_RplConfigNotEmpty => "There are profiles using this configuration.",
            WIN32::NERR_RplBootInUse => "There are workstations, profiles, or configurations using this boot block.",
            WIN32::NERR_RplBackupDatabase => "Service failed to back up the Remoteboot database.",
            WIN32::NERR_RplAdapterNotFound => "Adapter record was not found.",
            WIN32::NERR_RplVendorNotFound => "Vendor record was not found.",
            WIN32::NERR_RplVendorNameUnavailable => "Vendor name is in use by some other vendor record.",
            WIN32::NERR_RplBootNameUnavailable => "The boot name or vendor ID is in use by some other boot block record.",
            WIN32::NERR_RplConfigNameUnavailable => "The configuration name is in use by some other configuration.",
            WIN32::NERR_DfsInternalCorruption => "The internal database maintained by the DFS service is corrupt.",
            WIN32::NERR_DfsVolumeDataCorrupt => "One of the records in the internal DFS database is corrupt.",
            WIN32::NERR_DfsNoSuchVolume => "There is no DFS name whose entry path matches the input entry path.",
            WIN32::NERR_DfsVolumeAlreadyExists => "A root or link with the given name already exists.",
            WIN32::NERR_DfsAlreadyShared => "The server share specified is already shared in the DFS.",
            WIN32::NERR_DfsNoSuchShare => "The indicated server share does not support the indicated DFS namespace.",
            WIN32::NERR_DfsNotALeafVolume => "The operation is not valid in this portion of the namespace.",
            WIN32::NERR_DfsLeafVolume => "The operation is not valid in this portion of the namespace.",
            WIN32::NERR_DfsVolumeHasMultipleServers => "The operation is ambiguous because the link has multiple servers.",
            WIN32::NERR_DfsCantCreateJunctionPoint => "Unable to create a link.",
            WIN32::NERR_DfsServerNotDfsAware => "The server is not DFS-aware.",
            WIN32::NERR_DfsBadRenamePath => "The specified rename target path is invalid.",
            WIN32::NERR_DfsVolumeIsOffline => "The specified DFS link is offline.",
            WIN32::NERR_DfsNoSuchServer => "The specified server is not a server for this link.",
            WIN32::NERR_DfsCyclicalName => "A cycle in the DFS name was detected.",
            WIN32::NERR_DfsNotSupportedInServerDfs => "The operation is not supported on a server-based DFS.",
            WIN32::NERR_DfsDuplicateService => "This link is already supported by the specified server share.",
            WIN32::NERR_DfsCantRemoveLastServerShare => "Cannot remove the last server share supporting this root or link.",
            WIN32::NERR_DfsVolumeIsInterDfs => "The operation is not supported for an inter-DFS link.",
            WIN32::NERR_DfsInconsistent => "The internal state of the DFS Service has become inconsistent.",
            WIN32::NERR_DfsServerUpgraded => "The DFS Service has been installed on the specified server.",
            WIN32::NERR_DfsDataIsIdentical => "The DFS data being reconciled is identical.",
            WIN32::NERR_DfsCantRemoveDfsRoot => "The DFS root cannot be deleted. Uninstall DFS if required.",
            WIN32::NERR_DfsChildOrParentInDfs => "A child or parent directory of the share is already in a DFS.",
            WIN32::NERR_DfsInternalError => "DFS internal error.",
            WIN32::NERR_SetupAlreadyJoined => "This machine is already joined to a domain.",
            WIN32::NERR_SetupNotJoined => "This machine is not currently joined to a domain.",
            WIN32::NERR_SetupDomainController => "This machine is a domain controller and cannot be unjoined from a domain.",
            WIN32::NERR_DefaultJoinRequired => "The destination domain controller does not support creating machine accounts in organizational units (OUs).",
            WIN32::NERR_InvalidWorkgroupName => "The specified workgroup name is invalid.",
            WIN32::NERR_NameUsesIncompatibleCodePage => "The specified computer name is incompatible with the default language used on the domain controller.",
            WIN32::NERR_ComputerAccountNotFound => "The specified computer account could not be found.",
            WIN32::NERR_PersonalSku => "This version of Windows cannot be joined to a domain.",
            WIN32::NERR_PasswordMustChange => "The password must change at the next logon.",
            WIN32::NERR_AccountLockedOut => "The account is locked out.",
            WIN32::NERR_PasswordTooLong => "The password is too long.",
            WIN32::NERR_PasswordNotComplexEnough => "The password does not meet the complexity policy.",
            WIN32::NERR_PasswordFilterError => "The password does not meet the requirements of the password filter DLLs.",
            WIN32::ERROR_UNKNOWN_PRINT_MONITOR => "The specified print monitor is unknown.",
            WIN32::ERROR_PRINTER_DRIVER_IN_USE => "The specified printer driver is currently in use.",
            WIN32::ERROR_SPOOL_FILE_NOT_FOUND => "The spool file was not found.",
            WIN32::ERROR_SPL_NO_STARTDOC => "A StartDocPrinter call was not issued.",
            WIN32::ERROR_SPL_NO_ADDJOB => "An AddJob call was not issued.",
            WIN32::ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED => "The specified print processor has already been installed.",
            WIN32::ERROR_PRINT_MONITOR_ALREADY_INSTALLED => "The specified print monitor has already been installed.",
            WIN32::ERROR_INVALID_PRINT_MONITOR => "The specified print monitor does not have the required functions.",
            WIN32::ERROR_PRINT_MONITOR_IN_USE => "The specified print monitor is currently in use.",
            WIN32::ERROR_PRINTER_HAS_JOBS_QUEUED => "The requested operation is not allowed when there are jobs queued to the printer.",
            WIN32::ERROR_SUCCESS_REBOOT_REQUIRED => "The requested operation is successful. Changes will not be effective until the system is rebooted.",
            WIN32::ERROR_SUCCESS_RESTART_REQUIRED => "The requested operation is successful. Changes will not be effective until the service is restarted.",
            WIN32::ERROR_PRINTER_NOT_FOUND => "No printers were found.",
            WIN32::ERROR_PRINTER_DRIVER_WARNED => "The printer driver is known to be unreliable.",
            WIN32::ERROR_PRINTER_DRIVER_BLOCKED => "The printer driver is known to harm the system.",
            WIN32::ERROR_PRINTER_DRIVER_PACKAGE_IN_USE => "The specified printer driver package is currently in use.",
            WIN32::ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND => "Unable to find a core driver package that is required by the printer driver package.",
            WIN32::ERROR_FAIL_REBOOT_REQUIRED => "The requested operation failed. A system reboot is required to roll back changes made.",
            WIN32::ERROR_FAIL_REBOOT_INITIATED => "The requested operation failed. A system reboot has been initiated to roll back changes made.",
            WIN32::ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED => "The specified printer driver was not found on the system and needs to be downloaded.",
            WIN32::ERROR_PRINT_JOB_RESTART_REQUIRED => "The requested print job has failed to print. A print system update requires the job to be resubmitted.",
            WIN32::ERROR_INVALID_PRINTER_DRIVER_MANIFEST => "The printer driver does not contain a valid manifest, or contains too many manifests.",
            WIN32::ERROR_PRINTER_NOT_SHAREABLE => "The specified printer cannot be shared.",
            WIN32::ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1 => "The requested function requires SMB1 to be present and enabled.",
            WIN32::ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED => "The user canceled the authentication prompt to a remote server.",
            WIN32::ERROR_REQUEST_PAUSED => "The operation was paused.",
            WIN32::ERROR_APPEXEC_CONDITION_NOT_SATISFIED => "The condition supplied for the app execution request was not satisfied, so the request was not performed.",
            WIN32::ERROR_APPEXEC_HANDLE_INVALIDATED => "The supplied handle has been invalidated and may not be used for the requested operation.",
            WIN32::ERROR_APPEXEC_INVALID_HOST_GENERATION => "The supplied host generation has been invalidated and may not be used for the requested operation.",
            WIN32::ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION => "An attempt to register a process failed because the target host was not in a valid state to receive process registrations.",
            WIN32::ERROR_APPEXEC_INVALID_HOST_STATE => "The host is not in a valid state to support the execution request.",
            WIN32::ERROR_APPEXEC_NO_DONOR => "The operation was not completed because a required resource donor was not found for the host.",
            WIN32::ERROR_APPEXEC_HOST_ID_MISMATCH => "The operation was not completed because an unexpected host ID was encountered.",
            WIN32::ERROR_APPEXEC_UNKNOWN_USER => "The operation was not completed because the specified user was not known to the service.",
            WIN32::ERROR_APPEXEC_APP_COMPAT_BLOCK => "The application is blocked by app compat policy.",
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT => "The caller specified wait timed out before the operation completed.",
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION => "The caller specified wait timed out before the operation completed because a host termination is in queued.",
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING => "The caller specified wait timed out before the operation completed because a licensing operation is being performed.",
            WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES => "The caller specified wait timed out before the operation completed because resources are being acquired.",
            WIN32::ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED => "Enabling driver verification from volatile command is currently not supported when both CFG and IO are enabled.",
            WIN32::ERROR_VRF_VOLATILE_NOT_STOPPABLE => "Removal of current driver verification is not supported from volatile command.",
            WIN32::ERROR_VRF_VOLATILE_SAFE_MODE => "Enabling driver verification is not supported in safe mode.",
            WIN32::ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM => "Enabling driver verification is not supported from volatile mode in current system.",
            WIN32::ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS => "The specified rule class (a.k.a. flag) is not supported from volatile mode.",
            WIN32::ERROR_VRF_VOLATILE_PROTECTED_DRIVER => "The specified driver is protected and volatile verification is currently not supported.",
            WIN32::ERROR_VRF_VOLATILE_NMI_REGISTERED => "Enabling driver verification is not supported for a driver with  NMI callback(s) registered.",
            WIN32::ERROR_VRF_VOLATILE_SETTINGS_CONFLICT => "Volatile verification settings cannot be changed when verification is enabled from boot or DIF volatile verification is enabled.",
            WIN32::ERROR_DIF_IOCALLBACK_NOT_REPLACED => "The specified driver is not associated with driver object or driver extension.",
            WIN32::ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED => "Verifier's internal data size exceeds the limit of live dump secondary data.",
            WIN32::ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED => "Verification cannot start because an attempt to lock code or data section failed.",
            WIN32::ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED => "DIF volatile verification is not supported for hotpatched driver.",
            WIN32::ERROR_DIF_VOLATILE_INVALID_INFO => "The passed system DIF information is invalid.",
            WIN32::ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING => "DIF volatile verification only supports on loaded drivers.",
            WIN32::ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING => "Currently no plugin is running.",
            WIN32::ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED => "Currently running plugin must be removed before applying a new plugin.",
            WIN32::ERROR_DIF_VOLATILE_NOT_ALLOWED => "The plugin is not allowed to run in volatile mode.",
            WIN32::ERROR_DIF_BINDING_API_NOT_FOUND => "One or more DDI is not yet supported by DIF.",
            WIN32::ERROR_IO_REISSUE_AS_CACHED => "Reissue the given operation as a cached IO operation.",
            WIN32::ERROR_WINS_INTERNAL => "WINS encountered an error while processing the command.",
            WIN32::ERROR_CAN_NOT_DEL_LOCAL_WINS => "The local WINS cannot be deleted.",
            WIN32::ERROR_STATIC_INIT => "The importation from the file failed.",
            WIN32::ERROR_INC_BACKUP => "The backup failed. Was a full backup done before?.",
            WIN32::ERROR_FULL_BACKUP => "The backup failed. Check the directory to which you are backing the database.",
            WIN32::ERROR_REC_NON_EXISTENT => "The name does not exist in the WINS database.",
            WIN32::ERROR_RPL_NOT_ALLOWED => "Replication with a nonconfigured partner is not allowed.",
            WIN32::PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED => "The version of the supplied content information is not supported.",
            WIN32::PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO => "The supplied content information is malformed.",
            WIN32::PEERDIST_ERROR_MISSING_DATA => "The requested data cannot be found in local or peer caches.",
            WIN32::PEERDIST_ERROR_NO_MORE => "No more data is available or required.",
            WIN32::PEERDIST_ERROR_NOT_INITIALIZED => "The supplied object has not been initialized.",
            WIN32::PEERDIST_ERROR_ALREADY_INITIALIZED => "The supplied object has already been initialized.",
            WIN32::PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS => "A shutdown operation is already in progress.",
            WIN32::PEERDIST_ERROR_INVALIDATED => "The supplied object has already been invalidated.",
            WIN32::PEERDIST_ERROR_ALREADY_EXISTS => "An element already exists and was not replaced.",
            WIN32::PEERDIST_ERROR_OPERATION_NOTFOUND => "Can not cancel the requested operation as it has already been completed.",
            WIN32::PEERDIST_ERROR_ALREADY_COMPLETED => "Can not perform the requested operation because it has already been carried out.",
            WIN32::PEERDIST_ERROR_OUT_OF_BOUNDS => "An operation accessed data beyond the bounds of valid data.",
            WIN32::PEERDIST_ERROR_VERSION_UNSUPPORTED => "The requested version is not supported.",
            WIN32::PEERDIST_ERROR_INVALID_CONFIGURATION => "A configuration value is invalid.",
            WIN32::PEERDIST_ERROR_NOT_LICENSED => "The SKU is not licensed.",
            WIN32::PEERDIST_ERROR_SERVICE_UNAVAILABLE => "PeerDist Service is still initializing and will be available shortly.",
            WIN32::PEERDIST_ERROR_TRUST_FAILURE => "Communication with one or more computers will be temporarily blocked due to recent errors.",
            WIN32::ERROR_DHCP_ADDRESS_CONFLICT => "The DHCP client has obtained an IP address that is already in use on the network. The local interface will be disabled until the DHCP client can obtain a new address.",
            WIN32::ERROR_WMI_GUID_NOT_FOUND => "The GUID passed was not recognized as valid by a WMI data provider.",
            WIN32::ERROR_WMI_INSTANCE_NOT_FOUND => "The instance name passed was not recognized as valid by a WMI data provider.",
            WIN32::ERROR_WMI_ITEMID_NOT_FOUND => "The data item ID passed was not recognized as valid by a WMI data provider.",
            WIN32::ERROR_WMI_TRY_AGAIN => "The WMI request could not be completed and should be retried.",
            WIN32::ERROR_WMI_DP_NOT_FOUND => "The WMI data provider could not be located.",
            WIN32::ERROR_WMI_UNRESOLVED_INSTANCE_REF => "The WMI data provider references an instance set that has not been registered.",
            WIN32::ERROR_WMI_ALREADY_ENABLED => "The WMI data block or event notification has already been enabled.",
            WIN32::ERROR_WMI_GUID_DISCONNECTED => "The WMI data block is no longer available.",
            WIN32::ERROR_WMI_SERVER_UNAVAILABLE => "The WMI data service is not available.",
            WIN32::ERROR_WMI_DP_FAILED => "The WMI data provider failed to carry out the request.",
            WIN32::ERROR_WMI_INVALID_MOF => "The WMI MOF information is not valid.",
            WIN32::ERROR_WMI_INVALID_REGINFO => "The WMI registration information is not valid.",
            WIN32::ERROR_WMI_ALREADY_DISABLED => "The WMI data block or event notification has already been disabled.",
            WIN32::ERROR_WMI_READ_ONLY => "The WMI data item or data block is read only.",
            WIN32::ERROR_WMI_SET_FAILURE => "The WMI data item or data block could not be changed.",
            WIN32::ERROR_NOT_APPCONTAINER => "This operation is only valid in the context of an app container.",
            WIN32::ERROR_APPCONTAINER_REQUIRED => "This application can only run in the context of an app container.",
            WIN32::ERROR_NOT_SUPPORTED_IN_APPCONTAINER => "This functionality is not supported in the context of an app container.",
            WIN32::ERROR_INVALID_PACKAGE_SID_LENGTH => "The length of the SID supplied is not a valid length for app container SIDs.",
            WIN32::ERROR_INVALID_MEDIA => "The media identifier does not represent a valid medium.",
            WIN32::ERROR_INVALID_LIBRARY => "The library identifier does not represent a valid library.",
            WIN32::ERROR_INVALID_MEDIA_POOL => "The media pool identifier does not represent a valid media pool.",
            WIN32::ERROR_DRIVE_MEDIA_MISMATCH => "The drive and medium are not compatible or exist in different libraries.",
            WIN32::ERROR_MEDIA_OFFLINE => "The medium currently exists in an offline library and must be online to perform this operation.",
            WIN32::ERROR_LIBRARY_OFFLINE => "The operation cannot be performed on an offline library.",
            WIN32::ERROR_EMPTY => "The library, drive, or media pool is empty.",
            WIN32::ERROR_NOT_EMPTY => "The library, drive, or media pool must be empty to perform this operation.",
            WIN32::ERROR_MEDIA_UNAVAILABLE => "No media is currently available in this media pool or library.",
            WIN32::ERROR_RESOURCE_DISABLED => "A resource required for this operation is disabled.",
            WIN32::ERROR_INVALID_CLEANER => "The media identifier does not represent a valid cleaner.",
            WIN32::ERROR_UNABLE_TO_CLEAN => "The drive cannot be cleaned or does not support cleaning.",
            WIN32::ERROR_OBJECT_NOT_FOUND => "The object identifier does not represent a valid object.",
            WIN32::ERROR_DATABASE_FAILURE => "Unable to read from or write to the database.",
            WIN32::ERROR_DATABASE_FULL => "The database is full.",
            WIN32::ERROR_MEDIA_INCOMPATIBLE => "The medium is not compatible with the device or media pool.",
            WIN32::ERROR_RESOURCE_NOT_PRESENT => "The resource required for this operation does not exist.",
            WIN32::ERROR_INVALID_OPERATION => "The operation identifier is not valid.",
            WIN32::ERROR_MEDIA_NOT_AVAILABLE => "The media is not mounted or ready for use.",
            WIN32::ERROR_DEVICE_NOT_AVAILABLE => "The device is not ready for use.",
            WIN32::ERROR_REQUEST_REFUSED => "The operator or administrator has refused the request.",
            WIN32::ERROR_INVALID_DRIVE_OBJECT => "The drive identifier does not represent a valid drive.",
            WIN32::ERROR_LIBRARY_FULL => "Library is full. No slot is available for use.",
            WIN32::ERROR_MEDIUM_NOT_ACCESSIBLE => "The transport cannot access the medium.",
            WIN32::ERROR_UNABLE_TO_LOAD_MEDIUM => "Unable to load the medium into the drive.",
            WIN32::ERROR_UNABLE_TO_INVENTORY_DRIVE => "Unable to retrieve the drive status.",
            WIN32::ERROR_UNABLE_TO_INVENTORY_SLOT => "Unable to retrieve the slot status.",
            WIN32::ERROR_UNABLE_TO_INVENTORY_TRANSPORT => "Unable to retrieve status about the transport.",
            WIN32::ERROR_TRANSPORT_FULL => "Cannot use the transport because it is already in use.",
            WIN32::ERROR_CONTROLLING_IEPORT => "Unable to open or close the inject/eject port.",
            WIN32::ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA => "Unable to eject the medium because it is in a drive.",
            WIN32::ERROR_CLEANER_SLOT_SET => "A cleaner slot is already reserved.",
            WIN32::ERROR_CLEANER_SLOT_NOT_SET => "A cleaner slot is not reserved.",
            WIN32::ERROR_CLEANER_CARTRIDGE_SPENT => "The cleaner cartridge has performed the maximum number of drive cleanings.",
            WIN32::ERROR_UNEXPECTED_OMID => "Unexpected on-medium identifier.",
            WIN32::ERROR_CANT_DELETE_LAST_ITEM => "The last remaining item in this group or resource cannot be deleted.",
            WIN32::ERROR_MESSAGE_EXCEEDS_MAX_SIZE => "The message provided exceeds the maximum size allowed for this parameter.",
            WIN32::ERROR_VOLUME_CONTAINS_SYS_FILES => "The volume contains system or paging files.",
            WIN32::ERROR_INDIGENOUS_TYPE => "The media type cannot be removed from this library since at least one drive in the library reports it can support this media type.",
            WIN32::ERROR_NO_SUPPORTING_DRIVES => "This offline media cannot be mounted on this system since no enabled drives are present which can be used.",
            WIN32::ERROR_CLEANER_CARTRIDGE_INSTALLED => "A cleaner cartridge is present in the tape library.",
            WIN32::ERROR_IEPORT_FULL => "Cannot use the inject/eject port because it is not empty.",
            WIN32::ERROR_FILE_OFFLINE => "This file is currently not available for use on this computer.",
            WIN32::ERROR_REMOTE_STORAGE_NOT_ACTIVE => "The remote storage service is not operational at this time.",
            WIN32::ERROR_REMOTE_STORAGE_MEDIA_ERROR => "The remote storage service encountered a media error.",
            WIN32::ERROR_NOT_A_REPARSE_POINT => "The file or directory is not a reparse point.",
            WIN32::ERROR_REPARSE_ATTRIBUTE_CONFLICT => "The reparse point attribute cannot be set because it conflicts with an existing attribute.",
            WIN32::ERROR_INVALID_REPARSE_DATA => "The data present in the reparse point buffer is invalid.",
            WIN32::ERROR_REPARSE_TAG_INVALID => "The tag present in the reparse point buffer is invalid.",
            WIN32::ERROR_REPARSE_TAG_MISMATCH => "There is a mismatch between the tag specified in the request and the tag present in the reparse point.",
            WIN32::ERROR_REPARSE_POINT_ENCOUNTERED => "The object manager encountered a reparse point while retrieving an object.",
            WIN32::ERROR_APP_DATA_NOT_FOUND => "Fast Cache data not found.",
            WIN32::ERROR_APP_DATA_EXPIRED => "Fast Cache data expired.",
            WIN32::ERROR_APP_DATA_CORRUPT => "Fast Cache data corrupt.",
            WIN32::ERROR_APP_DATA_LIMIT_EXCEEDED => "Fast Cache data has exceeded its max size and cannot be updated.",
            WIN32::ERROR_APP_DATA_REBOOT_REQUIRED => "Fast Cache has been ReArmed and requires a reboot until it can be updated.",
            WIN32::ERROR_SECUREBOOT_ROLLBACK_DETECTED => "Secure Boot detected that rollback of protected data has been attempted.",
            WIN32::ERROR_SECUREBOOT_POLICY_VIOLATION => "The value is protected by Secure Boot policy and cannot be modified or deleted.",
            WIN32::ERROR_SECUREBOOT_INVALID_POLICY => "The Secure Boot policy is invalid.",
            WIN32::ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND => "A new Secure Boot policy did not contain the current publisher on its update list.",
            WIN32::ERROR_SECUREBOOT_POLICY_NOT_SIGNED => "The Secure Boot policy is either not signed or is signed by a non-trusted signer.",
            WIN32::ERROR_SECUREBOOT_NOT_ENABLED => "Secure Boot is not enabled on this machine.",
            WIN32::ERROR_SECUREBOOT_FILE_REPLACED => "Secure Boot requires that certain files and drivers are not replaced by other files or drivers.",
            WIN32::ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED => "The Secure Boot Supplemental Policy file was not authorized on this machine.",
            WIN32::ERROR_SECUREBOOT_POLICY_UNKNOWN => "The Supplemental Policy is not recognized on this device.",
            WIN32::ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION => "The Antirollback version was not found in the Secure Boot Policy.",
            WIN32::ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH => "The Platform ID specified in the Secure Boot policy does not match the Platform ID on this device.",
            WIN32::ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED => "The Secure Boot policy file has an older Antirollback Version than this device.",
            WIN32::ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH => "The Secure Boot policy file does not match the upgraded legacy policy.",
            WIN32::ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING => "The Secure Boot policy file is required but could not be found.",
            WIN32::ERROR_SECUREBOOT_NOT_BASE_POLICY => "Supplemental Secure Boot policy file can not be loaded as a base Secure Boot policy.",
            WIN32::ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY => "Base Secure Boot policy file can not be loaded as a Supplemental Secure Boot policy.",
            WIN32::ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED => "The copy offload read operation is not supported by a filter.",
            WIN32::ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED => "The copy offload write operation is not supported by a filter.",
            WIN32::ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED => "The copy offload read operation is not supported for the file.",
            WIN32::ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED => "The copy offload write operation is not supported for the file.",
            WIN32::ERROR_ALREADY_HAS_STREAM_ID => "This file is currently associated with a different stream id.",
            WIN32::ERROR_SMR_GARBAGE_COLLECTION_REQUIRED => "The volume must undergo garbage collection.",
            WIN32::ERROR_WOF_WIM_HEADER_CORRUPT => "The WOF driver encountered a corruption in WIM image's Header.",
            WIN32::ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT => "The WOF driver encountered a corruption in WIM image's Resource Table.",
            WIN32::ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT => "The WOF driver encountered a corruption in the compressed file's Resource Table.",
            WIN32::ERROR_OBJECT_IS_IMMUTABLE => "The request cannot be completed as it requires modifying an immutable object.",
            WIN32::ERROR_VOLUME_NOT_SIS_ENABLED => "Single Instance Storage is not available on this volume.",
            WIN32::ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED => "System Integrity detected that policy rollback has been attempted.",
            WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION => "Your organization used Device Guard to block this app. Contact your support person for more info.",
            WIN32::ERROR_SYSTEM_INTEGRITY_INVALID_POLICY => "The System Integrity policy is invalid.",
            WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED => "The System Integrity policy is either not signed or is signed by a non-trusted signer.",
            WIN32::ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES => "The number of System Integrity policies is out of limit.",
            WIN32::ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED => "The Code Integrity supplemental policy is not authorized by a Code Integrity base policy.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS => "System Integrity policy has been violated. Malicious binary reputation.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA => "System Integrity policy has been violated. Potentially unwanted application.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT => "System Integrity policy has been violated. Dangerous file extension from the web.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE => "System Integrity policy has been violated. Unable to contact reputation service for unknown file.",
            WIN32::ERROR_VSM_NOT_INITIALIZED => "Virtual Secure Mode (VSM) is not initialized. The hypervisor or VSM may not be present or enabled.",
            WIN32::ERROR_VSM_DMA_PROTECTION_NOT_IN_USE => "The hypervisor is not protecting DMA because an IOMMU is not present or not enabled in the BIOS.",
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED => "The Platform Manifest file was not authorized on this machine.",
            WIN32::ERROR_PLATFORM_MANIFEST_INVALID => "The Platform Manifest file was not valid.",
            WIN32::ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED => "The file is not authorized on this platform because an entry was not found in the Platform Manifest.",
            WIN32::ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED => "The catalog is not authorized on this platform because an entry was not found in the Platform Manifest.",
            WIN32::ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND => "The file is not authorized on this platform because a Binary ID was not found in the embedded signature.",
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_ACTIVE => "No active Platform Manifest exists on this system.",
            WIN32::ERROR_PLATFORM_MANIFEST_NOT_SIGNED => "The Platform Manifest file was not properly signed.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE => "System Integrity policy has been violated. Unfriendly file.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE => "System Integrity policy has been violated. Failed to obtain file reputation because an infrastructure issue occurred. Try again later.",
            WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE => "System Integrity policy has been violated. Explicit denied file.",
            WIN32::ERROR_DEPENDENT_RESOURCE_EXISTS => "The operation cannot be completed because other resources are dependent on this resource.",
            WIN32::ERROR_DEPENDENCY_NOT_FOUND => "The cluster resource dependency cannot be found.",
            WIN32::ERROR_DEPENDENCY_ALREADY_EXISTS => "The cluster resource cannot be made dependent on the specified resource because it is already dependent.",
            WIN32::ERROR_RESOURCE_NOT_ONLINE => "The cluster resource is not online.",
            WIN32::ERROR_HOST_NODE_NOT_AVAILABLE => "A cluster node is not available for this operation.",
            WIN32::ERROR_RESOURCE_NOT_AVAILABLE => "The cluster resource is not available.",
            WIN32::ERROR_RESOURCE_NOT_FOUND => "The cluster resource could not be found.",
            WIN32::ERROR_SHUTDOWN_CLUSTER => "The cluster is being shut down.",
            WIN32::ERROR_CANT_EVICT_ACTIVE_NODE => "A cluster node cannot be evicted from the cluster unless the node is down or it is the last node.",
            WIN32::ERROR_OBJECT_ALREADY_EXISTS => "The object already exists.",
            WIN32::ERROR_OBJECT_IN_LIST => "The object is already in the list.",
            WIN32::ERROR_GROUP_NOT_AVAILABLE => "The cluster group is not available for any new requests.",
            WIN32::ERROR_GROUP_NOT_FOUND => "The cluster group could not be found.",
            WIN32::ERROR_GROUP_NOT_ONLINE => "The operation could not be completed because the cluster group is not online.",
            WIN32::ERROR_HOST_NODE_NOT_RESOURCE_OWNER => "The operation failed because either the specified cluster node is not the owner of the resource, or the node is not a possible owner of the resource.",
            WIN32::ERROR_HOST_NODE_NOT_GROUP_OWNER => "The operation failed because either the specified cluster node is not the owner of the group, or the node is not a possible owner of the group.",
            WIN32::ERROR_RESMON_CREATE_FAILED => "The cluster resource could not be created in the specified resource monitor.",
            WIN32::ERROR_RESMON_ONLINE_FAILED => "The cluster resource could not be brought online by the resource monitor.",
            WIN32::ERROR_RESOURCE_ONLINE => "The operation could not be completed because the cluster resource is online.",
            WIN32::ERROR_QUORUM_RESOURCE => "The cluster resource could not be deleted or brought offline because it is the quorum resource.",
            WIN32::ERROR_NOT_QUORUM_CAPABLE => "The cluster could not make the specified resource a quorum resource because it is not capable of being a quorum resource.",
            WIN32::ERROR_CLUSTER_SHUTTING_DOWN => "The cluster software is shutting down.",
            WIN32::ERROR_INVALID_STATE => "The group or resource is not in the correct state to perform the requested operation.",
            WIN32::ERROR_RESOURCE_PROPERTIES_STORED => "The properties were stored but not all changes will take effect until the next time the resource is brought online.",
            WIN32::ERROR_NOT_QUORUM_CLASS => "The cluster could not make the specified resource a quorum resource because it does not belong to a shared storage class.",
            WIN32::ERROR_CORE_RESOURCE => "The cluster resource could not be deleted since it is a core resource.",
            WIN32::ERROR_QUORUM_RESOURCE_ONLINE_FAILED => "The quorum resource failed to come online.",
            WIN32::ERROR_QUORUMLOG_OPEN_FAILED => "The quorum log could not be created or mounted successfully.",
            WIN32::ERROR_CLUSTERLOG_CORRUPT => "The cluster log is corrupt.",
            WIN32::ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE => "The record could not be written to the cluster log since it exceeds the maximum size.",
            WIN32::ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE => "The cluster log exceeds its maximum size.",
            WIN32::ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND => "No checkpoint record was found in the cluster log.",
            WIN32::ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE => "The minimum required disk space needed for logging is not available.",
            WIN32::ERROR_QUORUM_OWNER_ALIVE => "The cluster node failed to take control of the quorum resource because the resource is owned by another active node.",
            WIN32::ERROR_NETWORK_NOT_AVAILABLE => "A cluster network is not available for this operation.",
            WIN32::ERROR_NODE_NOT_AVAILABLE => "A cluster node is not available for this operation.",
            WIN32::ERROR_ALL_NODES_NOT_AVAILABLE => "All cluster nodes must be running to perform this operation.",
            WIN32::ERROR_RESOURCE_FAILED => "A cluster resource failed.",
            WIN32::ERROR_CLUSTER_INVALID_NODE => "The cluster node is not valid.",
            WIN32::ERROR_CLUSTER_NODE_EXISTS => "The cluster node already exists.",
            WIN32::ERROR_CLUSTER_JOIN_IN_PROGRESS => "A node is in the process of joining the cluster.",
            WIN32::ERROR_CLUSTER_NODE_NOT_FOUND => "The cluster node was not found.",
            WIN32::ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND => "The cluster local node information was not found.",
            WIN32::ERROR_CLUSTER_NETWORK_EXISTS => "The cluster network already exists.",
            WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND => "The cluster network was not found.",
            WIN32::ERROR_CLUSTER_NETINTERFACE_EXISTS => "The cluster network interface already exists.",
            WIN32::ERROR_CLUSTER_NETINTERFACE_NOT_FOUND => "The cluster network interface was not found.",
            WIN32::ERROR_CLUSTER_INVALID_REQUEST => "The cluster request is not valid for this object.",
            WIN32::ERROR_CLUSTER_INVALID_NETWORK_PROVIDER => "The cluster network provider is not valid.",
            WIN32::ERROR_CLUSTER_NODE_DOWN => "The cluster node is down.",
            WIN32::ERROR_CLUSTER_NODE_UNREACHABLE => "The cluster node is not reachable.",
            WIN32::ERROR_CLUSTER_NODE_NOT_MEMBER => "The cluster node is not a member of the cluster.",
            WIN32::ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS => "A cluster join operation is not in progress.",
            WIN32::ERROR_CLUSTER_INVALID_NETWORK => "The cluster network is not valid.",
            WIN32::ERROR_CLUSTER_NODE_UP => "The cluster node is up.",
            WIN32::ERROR_CLUSTER_IPADDR_IN_USE => "The cluster IP address is already in use.",
            WIN32::ERROR_CLUSTER_NODE_NOT_PAUSED => "The cluster node is not paused.",
            WIN32::ERROR_CLUSTER_NO_SECURITY_CONTEXT => "No cluster security context is available.",
            WIN32::ERROR_CLUSTER_NETWORK_NOT_INTERNAL => "The cluster network is not configured for internal cluster communication.",
            WIN32::ERROR_CLUSTER_NODE_ALREADY_UP => "The cluster node is already up.",
            WIN32::ERROR_CLUSTER_NODE_ALREADY_DOWN => "The cluster node is already down.",
            WIN32::ERROR_CLUSTER_NETWORK_ALREADY_ONLINE => "The cluster network is already online.",
            WIN32::ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE => "The cluster network is already offline.",
            WIN32::ERROR_CLUSTER_NODE_ALREADY_MEMBER => "The cluster node is already a member of the cluster.",
            WIN32::ERROR_CLUSTER_LAST_INTERNAL_NETWORK => "The cluster network is the only one configured for internal cluster communication between two or more active cluster nodes. The internal communication capability cannot be removed from the network.",
            WIN32::ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS => "One or more cluster resources depend on the network to provide service to clients. The client access capability cannot be removed from the network.",
            WIN32::ERROR_INVALID_OPERATION_ON_QUORUM => "This operation cannot currently be performed on the cluster group containing the quorum resource.",
            WIN32::ERROR_DEPENDENCY_NOT_ALLOWED => "The cluster quorum resource is not allowed to have any dependencies.",
            WIN32::ERROR_CLUSTER_NODE_PAUSED => "The cluster node is paused.",
            WIN32::ERROR_NODE_CANT_HOST_RESOURCE => "The cluster resource cannot be brought online. The owner node cannot run this resource.",
            WIN32::ERROR_CLUSTER_NODE_NOT_READY => "The cluster node is not ready to perform the requested operation.",
            WIN32::ERROR_CLUSTER_NODE_SHUTTING_DOWN => "The cluster node is shutting down.",
            WIN32::ERROR_CLUSTER_JOIN_ABORTED => "The cluster join operation was aborted.",
            WIN32::ERROR_CLUSTER_INCOMPATIBLE_VERSIONS => "The node failed to join the cluster because the joining node and other nodes in the cluster have incompatible operating system versions. To get more information about operating system versions of the cluster, run the Validate a Configuration Wizard or the Test-Cluster Windows PowerShell cmdlet.",
            WIN32::ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED => "This resource cannot be created because the cluster has reached the limit on the number of resources it can monitor.",
            WIN32::ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED => "The system configuration changed during the cluster join or form operation. The join or form operation was aborted.",
            WIN32::ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND => "The specified resource type was not found.",
            WIN32::ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED => "The specified node does not support a resource of this type. This may be due to version inconsistencies or due to the absence of the resource DLL on this node.",
            WIN32::ERROR_CLUSTER_RESNAME_NOT_FOUND => "The specified resource name is not supported by this resource DLL. This may be due to a bad (or changed) name supplied to the resource DLL.",
            WIN32::ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED => "No authentication package could be registered with the RPC server.",
            WIN32::ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST => "You cannot bring the group online because the owner of the group is not in the preferred list for the group. To change the owner node for the group, move the group.",
            WIN32::ERROR_CLUSTER_DATABASE_SEQMISMATCH => "The join operation failed because the cluster database sequence number has changed or is incompatible with the locker node. This may happen during a join operation if the cluster database was changing during the join.",
            WIN32::ERROR_RESMON_INVALID_STATE => "The resource monitor will not allow the fail operation to be performed while the resource is in its current state. This may happen if the resource is in a pending state.",
            WIN32::ERROR_CLUSTER_GUM_NOT_LOCKER => "A non locker code got a request to reserve the lock for making global updates.",
            WIN32::ERROR_QUORUM_DISK_NOT_FOUND => "The quorum disk could not be located by the cluster service.",
            WIN32::ERROR_DATABASE_BACKUP_CORRUPT => "The backed up cluster database is possibly corrupt.",
            WIN32::ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT => "A DFS root already exists in this cluster node.",
            WIN32::ERROR_RESOURCE_PROPERTY_UNCHANGEABLE => "An attempt to modify a resource property failed because it conflicts with another existing property.",
            WIN32::ERROR_NO_ADMIN_ACCESS_POINT => "This operation is not supported on a cluster without an Administrator Access Point.",
            WIN32::ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE => "An operation was attempted that is incompatible with the current membership state of the node.",
            WIN32::ERROR_CLUSTER_QUORUMLOG_NOT_FOUND => "The quorum resource does not contain the quorum log.",
            WIN32::ERROR_CLUSTER_MEMBERSHIP_HALT => "The membership engine requested shutdown of the cluster service on this node.",
            WIN32::ERROR_CLUSTER_INSTANCE_ID_MISMATCH => "The join operation failed because the cluster instance ID of the joining node does not match the cluster instance ID of the sponsor node.",
            WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP => "A matching cluster network for the specified IP address could not be found.",
            WIN32::ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH => "The actual data type of the property did not match the expected data type of the property.",
            WIN32::ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP => "The cluster node was evicted from the cluster successfully, but the node was not cleaned up. To determine what cleanup steps failed and how to recover, see the Failover Clustering application event log using Event Viewer.",
            WIN32::ERROR_CLUSTER_PARAMETER_MISMATCH => "Two or more parameter values specified for a resource's properties are in conflict.",
            WIN32::ERROR_NODE_CANNOT_BE_CLUSTERED => "This computer cannot be made a member of a cluster.",
            WIN32::ERROR_CLUSTER_WRONG_OS_VERSION => "This computer cannot be made a member of a cluster because it does not have the correct version of Windows installed.",
            WIN32::ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME => "A cluster cannot be created with the specified cluster name because that cluster name is already in use. Specify a different name for the cluster.",
            WIN32::ERROR_CLUSCFG_ALREADY_COMMITTED => "The cluster configuration action has already been committed.",
            WIN32::ERROR_CLUSCFG_ROLLBACK_FAILED => "The cluster configuration action could not be rolled back.",
            WIN32::ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT => "The drive letter assigned to a system disk on one node conflicted with the drive letter assigned to a disk on another node.",
            WIN32::ERROR_CLUSTER_OLD_VERSION => "One or more nodes in the cluster are running a version of Windows that does not support this operation.",
            WIN32::ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME => "The name of the corresponding computer account doesn't match the Network Name for this resource.",
            WIN32::ERROR_CLUSTER_NO_NET_ADAPTERS => "No network adapters are available.",
            WIN32::ERROR_CLUSTER_POISONED => "The cluster node has been poisoned.",
            WIN32::ERROR_CLUSTER_GROUP_MOVING => "The group is unable to accept the request since it is moving to another node.",
            WIN32::ERROR_CLUSTER_RESOURCE_TYPE_BUSY => "The resource type cannot accept the request since is too busy performing another operation.",
            WIN32::ERROR_RESOURCE_CALL_TIMED_OUT => "The call to the cluster resource DLL timed out.",
            WIN32::ERROR_INVALID_CLUSTER_IPV6_ADDRESS => "The address is not valid for an IPv6 Address resource. A global IPv6 address is required, and it must match a cluster network. Compatibility addresses are not permitted.",
            WIN32::ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION => "An internal cluster error occurred. A call to an invalid function was attempted.",
            WIN32::ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS => "A parameter value is out of acceptable range.",
            WIN32::ERROR_CLUSTER_PARTIAL_SEND => "A network error occurred while sending data to another node in the cluster. The number of bytes transmitted was less than required.",
            WIN32::ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION => "An invalid cluster registry operation was attempted.",
            WIN32::ERROR_CLUSTER_INVALID_STRING_TERMINATION => "An input string of characters is not properly terminated.",
            WIN32::ERROR_CLUSTER_INVALID_STRING_FORMAT => "An input string of characters is not in a valid format for the data it represents.",
            WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS => "An internal cluster error occurred. A cluster database transaction was attempted while a transaction was already in progress.",
            WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS => "An internal cluster error occurred. There was an attempt to commit a cluster database transaction while no transaction was in progress.",
            WIN32::ERROR_CLUSTER_NULL_DATA => "An internal cluster error occurred. Data was not properly initialized.",
            WIN32::ERROR_CLUSTER_PARTIAL_READ => "An error occurred while reading from a stream of data. An unexpected number of bytes was returned.",
            WIN32::ERROR_CLUSTER_PARTIAL_WRITE => "An error occurred while writing to a stream of data. The required number of bytes could not be written.",
            WIN32::ERROR_CLUSTER_CANT_DESERIALIZE_DATA => "An error occurred while deserializing a stream of cluster data.",
            WIN32::ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT => "One or more property values for this resource are in conflict with one or more property values associated with its dependent resource(s).",
            WIN32::ERROR_CLUSTER_NO_QUORUM => "A quorum of cluster nodes was not present to form a cluster.",
            WIN32::ERROR_CLUSTER_INVALID_IPV6_NETWORK => "The cluster network is not valid for an IPv6 Address resource, or it does not match the configured address.",
            WIN32::ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK => "The cluster network is not valid for an IPv6 Tunnel resource. Check the configuration of the IP Address resource on which the IPv6 Tunnel resource depends.",
            WIN32::ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP => "Quorum resource cannot reside in the Available Storage group.",
            WIN32::ERROR_DEPENDENCY_TREE_TOO_COMPLEX => "The dependencies for this resource are nested too deeply.",
            WIN32::ERROR_EXCEPTION_IN_RESOURCE_CALL => "The call into the resource DLL raised an unhandled exception.",
            WIN32::ERROR_CLUSTER_RHS_FAILED_INITIALIZATION => "The RHS process failed to initialize.",
            WIN32::ERROR_CLUSTER_NOT_INSTALLED => "The Failover Clustering feature is not installed on this node.",
            WIN32::ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE => "The resources must be online on the same node for this operation.",
            WIN32::ERROR_CLUSTER_MAX_NODES_IN_CLUSTER => "A new node can not be added since this cluster is already at its maximum number of nodes.",
            WIN32::ERROR_CLUSTER_TOO_MANY_NODES => "This cluster can not be created since the specified number of nodes exceeds the maximum allowed limit.",
            WIN32::ERROR_CLUSTER_OBJECT_ALREADY_USED => "An attempt to use the specified cluster name failed because an enabled computer object with the given name already exists in the domain.",
            WIN32::ERROR_NONCORE_GROUPS_FOUND => "This cluster cannot be destroyed. It has non-core application groups which must be deleted before the cluster can be destroyed.",
            WIN32::ERROR_FILE_SHARE_RESOURCE_CONFLICT => "File share associated with file share witness resource cannot be hosted by this cluster or any of its nodes.",
            WIN32::ERROR_CLUSTER_EVICT_INVALID_REQUEST => "Eviction of this node is invalid at this time. Due to quorum requirements node eviction will result in cluster shutdown.",
            WIN32::ERROR_CLUSTER_SINGLETON_RESOURCE => "Only one instance of this resource type is allowed in the cluster.",
            WIN32::ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE => "Only one instance of this resource type is allowed per resource group.",
            WIN32::ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED => "The resource failed to come online due to the failure of one or more provider resources.",
            WIN32::ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR => "The resource has indicated that it cannot come online on any node.",
            WIN32::ERROR_CLUSTER_GROUP_BUSY => "The current operation cannot be performed on this group at this time.",
            WIN32::ERROR_CLUSTER_NOT_SHARED_VOLUME => "The directory or file is not located on a cluster shared volume.",
            WIN32::ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR => "The Security Descriptor does not meet the requirements for a cluster.",
            WIN32::ERROR_CLUSTER_SHARED_VOLUMES_IN_USE => "There is one or more shared volumes resources configured in the cluster.",
            WIN32::ERROR_CLUSTER_USE_SHARED_VOLUMES_API => "This group or resource cannot be directly manipulated.",
            WIN32::ERROR_CLUSTER_BACKUP_IN_PROGRESS => "Back up is in progress. Please wait for backup completion before trying this operation again.",
            WIN32::ERROR_NON_CSV_PATH => "The path does not belong to a cluster shared volume.",
            WIN32::ERROR_CSV_VOLUME_NOT_LOCAL => "The cluster shared volume is not locally mounted on this node.",
            WIN32::ERROR_CLUSTER_WATCHDOG_TERMINATING => "The cluster watchdog is terminating.",
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES => "A resource vetoed a move between two nodes because they are incompatible.",
            WIN32::ERROR_CLUSTER_INVALID_NODE_WEIGHT => "The request is invalid either because node weight cannot be changed while the cluster is in disk-only quorum mode, or because changing the node weight would violate the minimum cluster quorum requirements.",
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_CALL => "The resource vetoed the call.",
            WIN32::ERROR_RESMON_SYSTEM_RESOURCES_LACKING => "Resource could not start or run because it could not reserve sufficient system resources.",
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION => "A resource vetoed a move between two nodes because the destination currently does not have enough resources to complete the operation.",
            WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE => "A resource vetoed a move between two nodes because the source currently does not have enough resources to complete the operation.",
            WIN32::ERROR_CLUSTER_GROUP_QUEUED => "The requested operation can not be completed because the group is queued for an operation.",
            WIN32::ERROR_CLUSTER_RESOURCE_LOCKED_STATUS => "The requested operation can not be completed because a resource has locked status.",
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED => "The resource cannot move to another node because a cluster shared volume vetoed the operation.",
            WIN32::ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS => "A node drain is already in progress.",
            WIN32::ERROR_CLUSTER_DISK_NOT_CONNECTED => "Clustered storage is not connected to the node.",
            WIN32::ERROR_DISK_NOT_CSV_CAPABLE => "The disk is not configured in a way to be used with CSV. CSV disks must have at least one partition that is formatted with NTFS or REFS.",
            WIN32::ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE => "The resource must be part of the Available Storage group to complete this action.",
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED => "CSVFS failed operation as volume is in redirected mode.",
            WIN32::ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED => "CSVFS failed operation as volume is not in redirected mode.",
            WIN32::ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES => "Cluster properties cannot be returned at this time.",
            WIN32::ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES => "The clustered disk resource contains software snapshot diff area that are not supported for Cluster Shared Volumes.",
            WIN32::ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE => "The operation cannot be completed because the resource is in maintenance mode.",
            WIN32::ERROR_CLUSTER_AFFINITY_CONFLICT => "The operation cannot be completed because of cluster affinity conflicts.",
            WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE => "The operation cannot be completed because the resource is a replica virtual machine.",
            WIN32::ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS => "The Cluster Functional Level could not be increased because not all nodes in the cluster support the updated version.",
            WIN32::ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED => "Updating the cluster functional level failed because the cluster is running in fix quorum mode.",
            WIN32::ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED => "The cluster functional level has been successfully updated but not all features are available yet. Restart the cluster by.",
            WIN32::ERROR_CLUSTER_UPGRADE_IN_PROGRESS => "The cluster is currently performing a version upgrade.",
            WIN32::ERROR_CLUSTER_UPGRADE_INCOMPLETE => "The cluster did not successfully complete the version upgrade.",
            WIN32::ERROR_CLUSTER_NODE_IN_GRACE_PERIOD => "The cluster node is in grace period.",
            WIN32::ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT => "The operation has failed because CSV volume was not able to recover in time specified on this file object.",
            WIN32::ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER => "The operation failed because the requested node is not currently part of active cluster membership.",
            WIN32::ERROR_CLUSTER_RESOURCE_NOT_MONITORED => "The operation failed because the requested cluster resource is currently unmonitored.",
            WIN32::ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED => "The operation failed because a resource does not support running in an unmonitored state.",
            WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICATED => "The operation cannot be completed because a resource participates in replication.",
            WIN32::ERROR_CLUSTER_NODE_ISOLATED => "The operation failed because the requested cluster node has been isolated.",
            WIN32::ERROR_CLUSTER_NODE_QUARANTINED => "The operation failed because the requested cluster node has been quarantined.",
            WIN32::ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED => "The operation failed because the specified database update condition was not met.",
            WIN32::ERROR_CLUSTER_SPACE_DEGRADED => "A clustered space is in a degraded condition and the requested action cannot be completed at this time.",
            WIN32::ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED => "The operation failed because token delegation for this control is not supported.",
            WIN32::ERROR_CLUSTER_CSV_INVALID_HANDLE => "The operation has failed because CSV has invalidated this file object.",
            WIN32::ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR => "This operation is supported only on the CSV coordinator node.",
            WIN32::ERROR_GROUPSET_NOT_AVAILABLE => "The cluster group set is not available for any further requests.",
            WIN32::ERROR_GROUPSET_NOT_FOUND => "The cluster group set could not be found.",
            WIN32::ERROR_GROUPSET_CANT_PROVIDE => "The action cannot be completed at this time because the cluster group set would fall below quorum and not be able to act as a provider.",
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND => "The specified parent fault domain is not found.",
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY => "The fault domain cannot be a child of the parent specified.",
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION => "Storage Spaces Direct has rejected the proposed fault domain changes because it impacts the fault tolerance of the storage.",
            WIN32::ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS => "Storage Spaces Direct has rejected the proposed fault domain changes because it reduces the storage connected to the system.",
            WIN32::ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME => "Cluster infrastructure file server creation failed because a valid non-empty file server name was not provided.",
            WIN32::ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE => "The action cannot be completed because the cluster set management cluster is unreachable.",
            WIN32::ERROR_ENCRYPTION_FAILED => "The specified file could not be encrypted.",
            WIN32::ERROR_DECRYPTION_FAILED => "The specified file could not be decrypted.",
            WIN32::ERROR_FILE_ENCRYPTED => "The specified file is encrypted and the user does not have the ability to decrypt it.",
            WIN32::ERROR_NO_RECOVERY_POLICY => "There is no valid encryption recovery policy configured for this system.",
            WIN32::ERROR_NO_EFS => "The required encryption driver is not loaded for this system.",
            WIN32::ERROR_WRONG_EFS => "The file was encrypted with a different encryption driver than is currently loaded.",
            WIN32::ERROR_NO_USER_KEYS => "There are no EFS keys defined for the user.",
            WIN32::ERROR_FILE_NOT_ENCRYPTED => "The specified file is not encrypted.",
            WIN32::ERROR_NOT_EXPORT_FORMAT => "The specified file is not in the defined EFS export format.",
            WIN32::ERROR_FILE_READ_ONLY => "The specified file is read only.",
            WIN32::ERROR_DIR_EFS_DISALLOWED => "The directory has been disabled for encryption.",
            WIN32::ERROR_EFS_SERVER_NOT_TRUSTED => "The server is not trusted for remote encryption operation.",
            WIN32::ERROR_BAD_RECOVERY_POLICY => "Recovery policy configured for this system contains invalid recovery certificate.",
            WIN32::ERROR_EFS_ALG_BLOB_TOO_BIG => "The encryption algorithm used on the source file needs a bigger key buffer than the one on the destination file.",
            WIN32::ERROR_VOLUME_NOT_SUPPORT_EFS => "The disk partition does not support file encryption.",
            WIN32::ERROR_EFS_DISABLED => "This machine is disabled for file encryption.",
            WIN32::ERROR_EFS_VERSION_NOT_SUPPORT => "A newer system is required to decrypt this encrypted file.",
            WIN32::ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE => "The remote server sent an invalid response for a file being opened with Client Side Encryption.",
            WIN32::ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER => "Client Side Encryption is not supported by the remote server even though it claims to support it.",
            WIN32::ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE => "File is encrypted and should be opened in Client Side Encryption mode.",
            WIN32::ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE => "A new encrypted file is being created and a $EFS needs to be provided.",
            WIN32::ERROR_CS_ENCRYPTION_FILE_NOT_CSE => "The SMB client requested a CSE FSCTL on a non-CSE file.",
            WIN32::ERROR_ENCRYPTION_POLICY_DENIES_OPERATION => "The requested operation was blocked by policy. For more information, contact your system administrator.",
            WIN32::ERROR_WIP_ENCRYPTION_FAILED => "The specified file could not be encrypted with Windows Information Protection.",
            WIN32::ERROR_NO_BROWSER_SERVERS_FOUND => "The list of servers for this workgroup is not currently available.",
            WIN32::SCHED_E_SERVICE_NOT_LOCALSYSTEM => "The Task Scheduler service must be configured to run in the System account to function properly. Individual tasks may be configured to run in other accounts.",
            WIN32::ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM => "The object cannot be deleted from the local cluster because it is registered with the cluster set.",
            WIN32::ERROR_LOG_SECTOR_INVALID => "Log service encountered an invalid log sector.",
            WIN32::ERROR_LOG_SECTOR_PARITY_INVALID => "Log service encountered a log sector with invalid block parity.",
            WIN32::ERROR_LOG_SECTOR_REMAPPED => "Log service encountered a remapped log sector.",
            WIN32::ERROR_LOG_BLOCK_INCOMPLETE => "Log service encountered a partial or incomplete log block.",
            WIN32::ERROR_LOG_INVALID_RANGE => "Log service encountered an attempt access data outside the active log range.",
            WIN32::ERROR_LOG_BLOCKS_EXHAUSTED => "Log service user marshalling buffers are exhausted.",
            WIN32::ERROR_LOG_READ_CONTEXT_INVALID => "Log service encountered an attempt read from a marshalling area with an invalid read context.",
            WIN32::ERROR_LOG_RESTART_INVALID => "Log service encountered an invalid log restart area.",
            WIN32::ERROR_LOG_BLOCK_VERSION => "Log service encountered an invalid log block version.",
            WIN32::ERROR_LOG_BLOCK_INVALID => "Log service encountered an invalid log block.",
            WIN32::ERROR_LOG_READ_MODE_INVALID => "Log service encountered an attempt to read the log with an invalid read mode.",
            WIN32::ERROR_LOG_NO_RESTART => "Log service encountered a log stream with no restart area.",
            WIN32::ERROR_LOG_METADATA_CORRUPT => "Log service encountered a corrupted metadata file.",
            WIN32::ERROR_LOG_METADATA_INVALID => "Log service encountered a metadata file that could not be created by the log file system.",
            WIN32::ERROR_LOG_METADATA_INCONSISTENT => "Log service encountered a metadata file with inconsistent data.",
            WIN32::ERROR_LOG_RESERVATION_INVALID => "Log service encountered an attempt to erroneous allocate or dispose reservation space.",
            WIN32::ERROR_LOG_CANT_DELETE => "Log service cannot delete log file or file system container.",
            WIN32::ERROR_LOG_CONTAINER_LIMIT_EXCEEDED => "Log service has reached the maximum allowable containers allocated to a log file.",
            WIN32::ERROR_LOG_START_OF_LOG => "Log service has attempted to read or write backward past the start of the log.",
            WIN32::ERROR_LOG_POLICY_ALREADY_INSTALLED => "Log policy could not be installed because a policy of the same type is already present.",
            WIN32::ERROR_LOG_POLICY_NOT_INSTALLED => "Log policy in question was not installed at the time of the request.",
            WIN32::ERROR_LOG_POLICY_INVALID => "The installed set of policies on the log is invalid.",
            WIN32::ERROR_LOG_POLICY_CONFLICT => "A policy on the log in question prevented the operation from completing.",
            WIN32::ERROR_LOG_PINNED_ARCHIVE_TAIL => "Log space cannot be reclaimed because the log is pinned by the archive tail.",
            WIN32::ERROR_LOG_RECORD_NONEXISTENT => "Log record is not a record in the log file.",
            WIN32::ERROR_LOG_RECORDS_RESERVED_INVALID => "Number of reserved log records or the adjustment of the number of reserved log records is invalid.",
            WIN32::ERROR_LOG_SPACE_RESERVED_INVALID => "Reserved log space or the adjustment of the log space is invalid.",
            WIN32::ERROR_LOG_TAIL_INVALID => "An new or existing archive tail or base of the active log is invalid.",
            WIN32::ERROR_LOG_FULL => "Log space is exhausted.",
            WIN32::ERROR_COULD_NOT_RESIZE_LOG => "The log could not be set to the requested size.",
            WIN32::ERROR_LOG_MULTIPLEXED => "Log is multiplexed, no direct writes to the physical log is allowed.",
            WIN32::ERROR_LOG_DEDICATED => "The operation failed because the log is a dedicated log.",
            WIN32::ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS => "The operation requires an archive context.",
            WIN32::ERROR_LOG_ARCHIVE_IN_PROGRESS => "Log archival is in progress.",
            WIN32::ERROR_LOG_EPHEMERAL => "The operation requires a non-ephemeral log, but the log is ephemeral.",
            WIN32::ERROR_LOG_NOT_ENOUGH_CONTAINERS => "The log must have at least two containers before it can be read from or written to.",
            WIN32::ERROR_LOG_CLIENT_ALREADY_REGISTERED => "A log client has already registered on the stream.",
            WIN32::ERROR_LOG_CLIENT_NOT_REGISTERED => "A log client has not been registered on the stream.",
            WIN32::ERROR_LOG_FULL_HANDLER_IN_PROGRESS => "A request has already been made to handle the log full condition.",
            WIN32::ERROR_LOG_CONTAINER_READ_FAILED => "Log service encountered an error when attempting to read from a log container.",
            WIN32::ERROR_LOG_CONTAINER_WRITE_FAILED => "Log service encountered an error when attempting to write to a log container.",
            WIN32::ERROR_LOG_CONTAINER_OPEN_FAILED => "Log service encountered an error when attempting open a log container.",
            WIN32::ERROR_LOG_CONTAINER_STATE_INVALID => "Log service encountered an invalid container state when attempting a requested action.",
            WIN32::ERROR_LOG_STATE_INVALID => "Log service is not in the correct state to perform a requested action.",
            WIN32::ERROR_LOG_PINNED => "Log space cannot be reclaimed because the log is pinned.",
            WIN32::ERROR_LOG_METADATA_FLUSH_FAILED => "Log metadata flush failed.",
            WIN32::ERROR_LOG_INCONSISTENT_SECURITY => "Security on the log and its containers is inconsistent.",
            WIN32::ERROR_LOG_APPENDED_FLUSH_FAILED => "Records were appended to the log or reservation changes were made, but the log could not be flushed.",
            WIN32::ERROR_LOG_PINNED_RESERVATION => "The log is pinned due to reservation consuming most of the log space. Free some reserved records to make space available.",
            WIN32::ERROR_INVALID_TRANSACTION => "The transaction handle associated with this operation is not valid.",
            WIN32::ERROR_TRANSACTION_NOT_ACTIVE => "The requested operation was made in the context of a transaction that is no longer active.",
            WIN32::ERROR_TRANSACTION_REQUEST_NOT_VALID => "The requested operation is not valid on the Transaction object in its current state.",
            WIN32::ERROR_TRANSACTION_NOT_REQUESTED => "The caller has called a response API, but the response is not expected because the TM did not issue the corresponding request to the caller.",
            WIN32::ERROR_TRANSACTION_ALREADY_ABORTED => "It is too late to perform the requested operation, since the Transaction has already been aborted.",
            WIN32::ERROR_TRANSACTION_ALREADY_COMMITTED => "It is too late to perform the requested operation, since the Transaction has already been committed.",
            WIN32::ERROR_TM_INITIALIZATION_FAILED => "The Transaction Manager was unable to be successfully initialized. Transacted operations are not supported.",
            WIN32::ERROR_RESOURCEMANAGER_READ_ONLY => "The specified ResourceManager made no changes or updates to the resource under this transaction.",
            WIN32::ERROR_TRANSACTION_NOT_JOINED => "The resource manager has attempted to prepare a transaction that it has not successfully joined.",
            WIN32::ERROR_TRANSACTION_SUPERIOR_EXISTS => "The Transaction object already has a superior enlistment, and the caller attempted an operation that would have created a new superior. Only a single superior enlistment is allow.",
            WIN32::ERROR_CRM_PROTOCOL_ALREADY_EXISTS => "The RM tried to register a protocol that already exists.",
            WIN32::ERROR_TRANSACTION_PROPAGATION_FAILED => "The attempt to propagate the Transaction failed.",
            WIN32::ERROR_CRM_PROTOCOL_NOT_FOUND => "The requested propagation protocol was not registered as a CRM.",
            WIN32::ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER => "The buffer passed in to PushTransaction or PullTransaction is not in a valid format.",
            WIN32::ERROR_CURRENT_TRANSACTION_NOT_VALID => "The current transaction context associated with the thread is not a valid handle to a transaction object.",
            WIN32::ERROR_TRANSACTION_NOT_FOUND => "The specified Transaction object could not be opened, because it was not found.",
            WIN32::ERROR_RESOURCEMANAGER_NOT_FOUND => "The specified ResourceManager object could not be opened, because it was not found.",
            WIN32::ERROR_ENLISTMENT_NOT_FOUND => "The specified Enlistment object could not be opened, because it was not found.",
            WIN32::ERROR_TRANSACTIONMANAGER_NOT_FOUND => "The specified TransactionManager object could not be opened, because it was not found.",
            WIN32::ERROR_TRANSACTIONMANAGER_NOT_ONLINE => "The object specified could not be created or opened, because its associated TransactionManager is not online. The TransactionManager must be brought fully Online by calling RecoverTransactionManager to recover to the end of its LogFile before objects in its Transaction or ResourceManager namespaces can be opened. In addition, errors in writing records to its LogFile can cause a TransactionManager to go offline.",
            WIN32::ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION => "The specified TransactionManager was unable to create the objects contained in its logfile in the Ob namespace. Therefore, the TransactionManager was unable to recover.",
            WIN32::ERROR_TRANSACTION_NOT_ROOT => "The call to create a superior Enlistment on this Transaction object could not be completed, because the Transaction object specified for the enlistment is a subordinate branch of the Transaction. Only the root of the Transaction can be enlisted on as a superior.",
            WIN32::ERROR_TRANSACTION_OBJECT_EXPIRED => "Because the associated transaction manager or resource manager has been closed, the handle is no longer valid.",
            WIN32::ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED => "The specified operation could not be performed on this Superior enlistment, because the enlistment was not created with the corresponding completion response in the NotificationMask.",
            WIN32::ERROR_TRANSACTION_RECORD_TOO_LONG => "The specified operation could not be performed, because the record that would be logged was too long. This can occur because of two conditions: either there are too many Enlistments on this Transaction, or the combined RecoveryInformation being logged on behalf of those Enlistments is too long.",
            WIN32::ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED => "Implicit transaction are not supported.",
            WIN32::ERROR_TRANSACTION_INTEGRITY_VIOLATED => "The kernel transaction manager had to abort or forget the transaction because it blocked forward progress.",
            WIN32::ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH => "The TransactionManager identity that was supplied did not match the one recorded in the TransactionManager's log file.",
            WIN32::ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT => "This snapshot operation cannot continue because a transactional resource manager cannot be frozen in its current state. Please try again.",
            WIN32::ERROR_TRANSACTION_MUST_WRITETHROUGH => "The transaction cannot be enlisted on with the specified EnlistmentMask, because the transaction has already completed the PrePrepare phase. In order to ensure correctness, the ResourceManager must switch to a write-through mode and cease caching data within this transaction. Enlisting for only subsequent transaction phases may still succeed.",
            WIN32::ERROR_TRANSACTION_NO_SUPERIOR => "The transaction does not have a superior enlistment.",
            WIN32::ERROR_HEURISTIC_DAMAGE_POSSIBLE => "The attempt to commit the Transaction completed, but it is possible that some portion of the transaction tree did not commit successfully due to heuristics. Therefore it is possible that some data modified in the transaction may not have committed, resulting in transactional inconsistency. If possible, check the consistency of the associated data.",
            WIN32::ERROR_TRANSACTIONAL_CONFLICT => "The function attempted to use a name that is reserved for use by another transaction.",
            WIN32::ERROR_RM_NOT_ACTIVE => "Transaction support within the specified resource manager is not started or was shut down due to an error.",
            WIN32::ERROR_RM_METADATA_CORRUPT => "The metadata of the RM has been corrupted. The RM will not function.",
            WIN32::ERROR_DIRECTORY_NOT_RM => "The specified directory does not contain a resource manager.",
            WIN32::ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE => "The remote server or share does not support transacted file operations.",
            WIN32::ERROR_LOG_RESIZE_INVALID_SIZE => "The requested log size is invalid.",
            WIN32::ERROR_OBJECT_NO_LONGER_EXISTS => "The object (file, stream, link) corresponding to the handle has been deleted by a Transaction Savepoint Rollback.",
            WIN32::ERROR_STREAM_MINIVERSION_NOT_FOUND => "The specified file miniversion was not found for this transacted file open.",
            WIN32::ERROR_STREAM_MINIVERSION_NOT_VALID => "The specified file miniversion was found but has been invalidated. Most likely cause is a transaction savepoint rollback.",
            WIN32::ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION => "A miniversion may only be opened in the context of the transaction that created it.",
            WIN32::ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT => "It is not possible to open a miniversion with modify access.",
            WIN32::ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS => "It is not possible to create any more miniversions for this stream.",
            WIN32::ERROR_REMOTE_FILE_VERSION_MISMATCH => "The remote server sent mismatching version number or Fid for a file opened with transactions.",
            WIN32::ERROR_HANDLE_NO_LONGER_VALID => "The handle has been invalidated by a transaction. The most likely cause is the presence of memory mapping on a file or an open handle when the transaction ended or rolled back to savepoint.",
            WIN32::ERROR_NO_TXF_METADATA => "There is no transaction metadata on the file.",
            WIN32::ERROR_LOG_CORRUPTION_DETECTED => "The log data is corrupt.",
            WIN32::ERROR_CANT_RECOVER_WITH_HANDLE_OPEN => "The file can't be recovered because there is a handle still open on it.",
            WIN32::ERROR_RM_DISCONNECTED => "The transaction outcome is unavailable because the resource manager responsible for it has disconnected.",
            WIN32::ERROR_ENLISTMENT_NOT_SUPERIOR => "The request was rejected because the enlistment in question is not a superior enlistment.",
            WIN32::ERROR_RECOVERY_NOT_NEEDED => "The transactional resource manager is already consistent. Recovery is not needed.",
            WIN32::ERROR_RM_ALREADY_STARTED => "The transactional resource manager has already been started.",
            WIN32::ERROR_FILE_IDENTITY_NOT_PERSISTENT => "The file cannot be opened transactionally, because its identity depends on the outcome of an unresolved transaction.",
            WIN32::ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY => "The operation cannot be performed because another transaction is depending on the fact that this property will not change.",
            WIN32::ERROR_CANT_CROSS_RM_BOUNDARY => "The operation would involve a single file with two transactional resource managers and is therefore not allowed.",
            WIN32::ERROR_TXF_DIR_NOT_EMPTY => "The $Txf directory must be empty for this operation to succeed.",
            WIN32::ERROR_INDOUBT_TRANSACTIONS_EXIST => "The operation would leave a transactional resource manager in an inconsistent state and is therefore not allowed.",
            WIN32::ERROR_TM_VOLATILE => "The operation could not be completed because the transaction manager does not have a log.",
            WIN32::ERROR_ROLLBACK_TIMER_EXPIRED => "A rollback could not be scheduled because a previously scheduled rollback has already executed or been queued for execution.",
            WIN32::ERROR_TXF_ATTRIBUTE_CORRUPT => "The transactional metadata attribute on the file or directory is corrupt and unreadable.",
            WIN32::ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION => "The encryption operation could not be completed because a transaction is active.",
            WIN32::ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED => "This object is not allowed to be opened in a transaction.",
            WIN32::ERROR_LOG_GROWTH_FAILED => "An attempt to create space in the transactional resource manager's log failed. The failure status has been recorded in the event log.",
            WIN32::ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE => "Memory mapping (creating a mapped section) a remote file under a transaction is not supported.",
            WIN32::ERROR_TXF_METADATA_ALREADY_PRESENT => "Transaction metadata is already present on this file and cannot be superseded.",
            WIN32::ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET => "A transaction scope could not be entered because the scope handler has not been initialized.",
            WIN32::ERROR_TRANSACTION_REQUIRED_PROMOTION => "Promotion was required in order to allow the resource manager to enlist, but the transaction was set to disallow it.",
            WIN32::ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION => "This file is open for modification in an unresolved transaction and may be opened for execute only by a transacted reader.",
            WIN32::ERROR_TRANSACTIONS_NOT_FROZEN => "The request to thaw frozen transactions was ignored because transactions had not previously been frozen.",
            WIN32::ERROR_TRANSACTION_FREEZE_IN_PROGRESS => "Transactions cannot be frozen because a freeze is already in progress.",
            WIN32::ERROR_NOT_SNAPSHOT_VOLUME => "The target volume is not a snapshot volume. This operation is only valid on a volume mounted as a snapshot.",
            WIN32::ERROR_NO_SAVEPOINT_WITH_OPEN_FILES => "The savepoint operation failed because files are open on the transaction. This is not permitted.",
            WIN32::ERROR_DATA_LOST_REPAIR => "Windows has discovered corruption in a file, and that file has since been repaired. Data loss may have occurred.",
            WIN32::ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION => "The sparse operation could not be completed because a transaction is active on the file.",
            WIN32::ERROR_TM_IDENTITY_MISMATCH => "The call to create a TransactionManager object failed because the Tm Identity stored in the logfile does not match the Tm Identity that was passed in as an argument.",
            WIN32::ERROR_FLOATED_SECTION => "I/O was attempted on a section object that has been floated as a result of a transaction ending. There is no valid data.",
            WIN32::ERROR_CANNOT_ACCEPT_TRANSACTED_WORK => "The transactional resource manager cannot currently accept transacted work due to a transient condition such as low resources.",
            WIN32::ERROR_CANNOT_ABORT_TRANSACTIONS => "The transactional resource manager had too many transactions outstanding that could not be aborted. The transactional resource manger has been shut down.",
            WIN32::ERROR_BAD_CLUSTERS => "The operation could not be completed due to bad clusters on disk.",
            WIN32::ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION => "The compression operation could not be completed because a transaction is active on the file.",
            WIN32::ERROR_VOLUME_DIRTY => "The operation could not be completed because the volume is dirty. Please run chkdsk and try again.",
            WIN32::ERROR_NO_LINK_TRACKING_IN_TRANSACTION => "The link tracking operation could not be completed because a transaction is active.",
            WIN32::ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION => "This operation cannot be performed in a transaction.",
            WIN32::ERROR_EXPIRED_HANDLE => "The handle is no longer properly associated with its transaction. It may have been opened in a transactional resource manager that was subsequently forced to restart. Please close the handle and open a new one.",
            WIN32::ERROR_TRANSACTION_NOT_ENLISTED => "The specified operation could not be performed because the resource manager is not enlisted in the transaction.",
            WIN32::ERROR_CTX_WINSTATION_NAME_INVALID => "The specified session name is invalid.",
            WIN32::ERROR_CTX_INVALID_PD => "The specified protocol driver is invalid.",
            WIN32::ERROR_CTX_PD_NOT_FOUND => "The specified protocol driver was not found in the system path.",
            WIN32::ERROR_CTX_WD_NOT_FOUND => "The specified terminal connection driver was not found in the system path.",
            WIN32::ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY => "A registry key for event logging could not be created for this session.",
            WIN32::ERROR_CTX_SERVICE_NAME_COLLISION => "A service with the same name already exists on the system.",
            WIN32::ERROR_CTX_CLOSE_PENDING => "A close operation is pending on the session.",
            WIN32::ERROR_CTX_NO_OUTBUF => "There are no free output buffers available.",
            WIN32::ERROR_CTX_MODEM_INF_NOT_FOUND => "The MODEM.INF file was not found.",
            WIN32::ERROR_CTX_INVALID_MODEMNAME => "The modem name was not found in MODEM.INF.",
            WIN32::ERROR_CTX_MODEM_RESPONSE_ERROR => "The modem did not accept the command sent to it. Verify that the configured modem name matches the attached modem.",
            WIN32::ERROR_CTX_MODEM_RESPONSE_TIMEOUT => "The modem did not respond to the command sent to it. Verify that the modem is properly cabled and powered on.",
            WIN32::ERROR_CTX_MODEM_RESPONSE_NO_CARRIER => "Carrier detect has failed or carrier has been dropped due to disconnect.",
            WIN32::ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE => "Dial tone not detected within the required time. Verify that the phone cable is properly attached and functional.",
            WIN32::ERROR_CTX_MODEM_RESPONSE_BUSY => "Busy signal detected at remote site on callback.",
            WIN32::ERROR_CTX_MODEM_RESPONSE_VOICE => "Voice detected at remote site on callback.",
            WIN32::ERROR_CTX_TD_ERROR => "Transport driver error.",
            WIN32::ERROR_CTX_WINSTATION_NOT_FOUND => "The specified session cannot be found.",
            WIN32::ERROR_CTX_WINSTATION_ALREADY_EXISTS => "The specified session name is already in use.",
            WIN32::ERROR_CTX_WINSTATION_BUSY => "The task you are trying to do can't be completed because Remote Desktop Services is currently busy. Please try again in a few minutes. Other users should still be able to log on.",
            WIN32::ERROR_CTX_BAD_VIDEO_MODE => "An attempt has been made to connect to a session whose video mode is not supported by the current client.",
            WIN32::ERROR_CTX_GRAPHICS_INVALID => "The application attempted to enable DOS graphics mode. DOS graphics mode is not supported.",
            WIN32::ERROR_CTX_LOGON_DISABLED => "Your interactive logon privilege has been disabled. Please contact your administrator.",
            WIN32::ERROR_CTX_NOT_CONSOLE => "The requested operation can be performed only on the system console. This is most often the result of a driver or system DLL requiring direct console access.",
            WIN32::ERROR_CTX_CLIENT_QUERY_TIMEOUT => "The client failed to respond to the server connect message.",
            WIN32::ERROR_CTX_CONSOLE_DISCONNECT => "Disconnecting the console session is not supported.",
            WIN32::ERROR_CTX_CONSOLE_CONNECT => "Reconnecting a disconnected session to the console is not supported.",
            WIN32::ERROR_CTX_SHADOW_DENIED => "The request to control another session remotely was denied.",
            WIN32::ERROR_CTX_WINSTATION_ACCESS_DENIED => "The requested session access is denied.",
            WIN32::ERROR_CTX_INVALID_WD => "The specified terminal connection driver is invalid.",
            WIN32::ERROR_CTX_SHADOW_INVALID => "The requested session cannot be controlled remotely.",
            WIN32::ERROR_CTX_SHADOW_DISABLED => "The requested session is not configured to allow remote control.",
            WIN32::ERROR_CTX_CLIENT_LICENSE_IN_USE => "Your request to connect to this Terminal Server has been rejected. Your Terminal Server client license number is currently being used by another user. Please call your system administrator to obtain a unique license number.",
            WIN32::ERROR_CTX_CLIENT_LICENSE_NOT_SET => "Your request to connect to this Terminal Server has been rejected. Your Terminal Server client license number has not been entered for this copy of the Terminal Server client. Please contact your system administrator.",
            WIN32::ERROR_CTX_LICENSE_NOT_AVAILABLE => "The number of connections to this computer is limited and all connections are in use right now. Try connecting later or contact your system administrator.",
            WIN32::ERROR_CTX_LICENSE_CLIENT_INVALID => "The client you are using is not licensed to use this system. Your logon request is denied.",
            WIN32::ERROR_CTX_LICENSE_EXPIRED => "The system license has expired. Your logon request is denied.",
            WIN32::ERROR_CTX_SHADOW_NOT_RUNNING => "Remote control could not be terminated because the specified session is not currently being remotely controlled.",
            WIN32::ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE => "The remote control of the console was terminated because the display mode was changed. Changing the display mode in a remote control session is not supported.",
            WIN32::ERROR_ACTIVATION_COUNT_EXCEEDED => "Activation has already been reset the maximum number of times for this installation. Your activation timer will not be cleared.",
            WIN32::ERROR_CTX_WINSTATIONS_DISABLED => "Remote logins are currently disabled.",
            WIN32::ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED => "You do not have the proper encryption level to access this Session.",
            WIN32::ERROR_CTX_SESSION_IN_USE => "The user %s\\%s is currently logged on to this computer. Only the current user or an administrator can log on to this computer.",
            WIN32::ERROR_CTX_NO_FORCE_LOGOFF => "The user %s\\%s is already logged on to the console of this computer. You do not have permission to log in at this time. To resolve this issue, contact %s\\%s and have them log off.",
            WIN32::ERROR_CTX_ACCOUNT_RESTRICTION => "Unable to log you on because of an account restriction.",
            WIN32::ERROR_RDP_PROTOCOL_ERROR => "The RDP protocol component %2 detected an error in the protocol stream and has disconnected the client.",
            WIN32::ERROR_CTX_CDM_CONNECT => "The Client Drive Mapping Service Has Connected on Terminal Connection.",
            WIN32::ERROR_CTX_CDM_DISCONNECT => "The Client Drive Mapping Service Has Disconnected on Terminal Connection.",
            WIN32::ERROR_CTX_SECURITY_LAYER_ERROR => "The Terminal Server security layer detected an error in the protocol stream and has disconnected the client.",
            WIN32::ERROR_TS_INCOMPATIBLE_SESSIONS => "The target session is incompatible with the current session.",
            WIN32::ERROR_TS_VIDEO_SUBSYSTEM_ERROR => "Windows can't connect to your session because a problem occurred in the Windows video subsystem. Try connecting again later, or contact the server administrator for assistance.",
            WIN32::FRS_ERR_INVALID_API_SEQUENCE => "The file replication service API was called incorrectly.",
            WIN32::FRS_ERR_STARTING_SERVICE => "The file replication service cannot be started.",
            WIN32::FRS_ERR_STOPPING_SERVICE => "The file replication service cannot be stopped.",
            WIN32::FRS_ERR_INTERNAL_API => "The file replication service API terminated the request. The event log may have more information.",
            WIN32::FRS_ERR_INTERNAL => "The file replication service terminated the request. The event log may have more information.",
            WIN32::FRS_ERR_SERVICE_COMM => "The file replication service cannot be contacted. The event log may have more information.",
            WIN32::FRS_ERR_INSUFFICIENT_PRIV => "The file replication service cannot satisfy the request because the user has insufficient privileges. The event log may have more information.",
            WIN32::FRS_ERR_AUTHENTICATION => "The file replication service cannot satisfy the request because authenticated RPC is not available. The event log may have more information.",
            WIN32::FRS_ERR_PARENT_INSUFFICIENT_PRIV => "The file replication service cannot satisfy the request because the user has insufficient privileges on the domain controller. The event log may have more information.",
            WIN32::FRS_ERR_PARENT_AUTHENTICATION => "The file replication service cannot satisfy the request because authenticated RPC is not available on the domain controller. The event log may have more information.",
            WIN32::FRS_ERR_CHILD_TO_PARENT_COMM => "The file replication service cannot communicate with the file replication service on the domain controller. The event log may have more information.",
            WIN32::FRS_ERR_PARENT_TO_CHILD_COMM => "The file replication service on the domain controller cannot communicate with the file replication service on this computer. The event log may have more information.",
            WIN32::FRS_ERR_SYSVOL_POPULATE => "The file replication service cannot populate the system volume because of an internal error. The event log may have more information.",
            WIN32::FRS_ERR_SYSVOL_POPULATE_TIMEOUT => "The file replication service cannot populate the system volume because of an internal timeout. The event log may have more information.",
            WIN32::FRS_ERR_SYSVOL_IS_BUSY => "The file replication service cannot process the request. The system volume is busy with a previous request.",
            WIN32::FRS_ERR_SYSVOL_DEMOTE => "The file replication service cannot stop replicating the system volume because of an internal error. The event log may have more information.",
            WIN32::FRS_ERR_INVALID_SERVICE_PARAMETER => "The file replication service detected an invalid parameter.",
            WIN32::ERROR_DS_NOT_INSTALLED => "An error occurred while installing the directory service. For more information, see the event log.",
            WIN32::ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY => "The directory service evaluated group memberships locally.",
            WIN32::ERROR_DS_NO_ATTRIBUTE_OR_VALUE => "The specified directory service attribute or value does not exist.",
            WIN32::ERROR_DS_INVALID_ATTRIBUTE_SYNTAX => "The attribute syntax specified to the directory service is invalid.",
            WIN32::ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED => "The attribute type specified to the directory service is not defined.",
            WIN32::ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS => "The specified directory service attribute or value already exists.",
            WIN32::ERROR_DS_BUSY => "The directory service is busy.",
            WIN32::ERROR_DS_UNAVAILABLE => "The directory service is unavailable.",
            WIN32::ERROR_DS_NO_RIDS_ALLOCATED => "The directory service was unable to allocate a relative identifier.",
            WIN32::ERROR_DS_NO_MORE_RIDS => "The directory service has exhausted the pool of relative identifiers.",
            WIN32::ERROR_DS_INCORRECT_ROLE_OWNER => "The requested operation could not be performed because the directory service is not the master for that type of operation.",
            WIN32::ERROR_DS_RIDMGR_INIT_ERROR => "The directory service was unable to initialize the subsystem that allocates relative identifiers.",
            WIN32::ERROR_DS_OBJ_CLASS_VIOLATION => "The requested operation did not satisfy one or more constraints associated with the class of the object.",
            WIN32::ERROR_DS_CANT_ON_NON_LEAF => "The directory service can perform the requested operation only on a leaf object.",
            WIN32::ERROR_DS_CANT_ON_RDN => "The directory service cannot perform the requested operation on the RDN attribute of an object.",
            WIN32::ERROR_DS_CANT_MOD_OBJ_CLASS => "The directory service detected an attempt to modify the object class of an object.",
            WIN32::ERROR_DS_CROSS_DOM_MOVE_ERROR => "The requested cross-domain move operation could not be performed.",
            WIN32::ERROR_DS_GC_NOT_AVAILABLE => "Unable to contact the global catalog server.",
            WIN32::ERROR_SHARED_POLICY => "The policy object is shared and can only be modified at the root.",
            WIN32::ERROR_POLICY_OBJECT_NOT_FOUND => "The policy object does not exist.",
            WIN32::ERROR_POLICY_ONLY_IN_DS => "The requested policy information is only in the directory service.",
            WIN32::ERROR_PROMOTION_ACTIVE => "A domain controller promotion is currently active.",
            WIN32::ERROR_NO_PROMOTION_ACTIVE => "A domain controller promotion is not currently active.",
            WIN32::ERROR_DS_OPERATIONS_ERROR => "An operations error occurred.",
            WIN32::ERROR_DS_PROTOCOL_ERROR => "A protocol error occurred.",
            WIN32::ERROR_DS_TIMELIMIT_EXCEEDED => "The time limit for this request was exceeded.",
            WIN32::ERROR_DS_SIZELIMIT_EXCEEDED => "The size limit for this request was exceeded.",
            WIN32::ERROR_DS_ADMIN_LIMIT_EXCEEDED => "The administrative limit for this request was exceeded.",
            WIN32::ERROR_DS_COMPARE_FALSE => "The compare response was false.",
            WIN32::ERROR_DS_COMPARE_TRUE => "The compare response was true.",
            WIN32::ERROR_DS_AUTH_METHOD_NOT_SUPPORTED => "The requested authentication method is not supported by the server.",
            WIN32::ERROR_DS_STRONG_AUTH_REQUIRED => "A more secure authentication method is required for this server.",
            WIN32::ERROR_DS_INAPPROPRIATE_AUTH => "Inappropriate authentication.",
            WIN32::ERROR_DS_AUTH_UNKNOWN => "The authentication mechanism is unknown.",
            WIN32::ERROR_DS_REFERRAL => "A referral was returned from the server.",
            WIN32::ERROR_DS_UNAVAILABLE_CRIT_EXTENSION => "The server does not support the requested critical extension.",
            WIN32::ERROR_DS_CONFIDENTIALITY_REQUIRED => "This request requires a secure connection.",
            WIN32::ERROR_DS_INAPPROPRIATE_MATCHING => "Inappropriate matching.",
            WIN32::ERROR_DS_CONSTRAINT_VIOLATION => "A constraint violation occurred.",
            WIN32::ERROR_DS_NO_SUCH_OBJECT => "There is no such object on the server.",
            WIN32::ERROR_DS_ALIAS_PROBLEM => "There is an alias problem.",
            WIN32::ERROR_DS_INVALID_DN_SYNTAX => "An invalid dn syntax has been specified.",
            WIN32::ERROR_DS_IS_LEAF => "The object is a leaf object.",
            WIN32::ERROR_DS_ALIAS_DEREF_PROBLEM => "There is an alias dereferencing problem.",
            WIN32::ERROR_DS_UNWILLING_TO_PERFORM => "The server is unwilling to process the request.",
            WIN32::ERROR_DS_LOOP_DETECT => "A loop has been detected.",
            WIN32::ERROR_DS_NAMING_VIOLATION => "There is a naming violation.",
            WIN32::ERROR_DS_OBJECT_RESULTS_TOO_LARGE => "The result set is too large.",
            WIN32::ERROR_DS_AFFECTS_MULTIPLE_DSAS => "The operation affects multiple DSAs.",
            WIN32::ERROR_DS_SERVER_DOWN => "The server is not operational.",
            WIN32::ERROR_DS_LOCAL_ERROR => "A local error has occurred.",
            WIN32::ERROR_DS_ENCODING_ERROR => "An encoding error has occurred.",
            WIN32::ERROR_DS_DECODING_ERROR => "A decoding error has occurred.",
            WIN32::ERROR_DS_FILTER_UNKNOWN => "The search filter cannot be recognized.",
            WIN32::ERROR_DS_PARAM_ERROR => "One or more parameters are illegal.",
            WIN32::ERROR_DS_NOT_SUPPORTED => "The specified method is not supported.",
            WIN32::ERROR_DS_NO_RESULTS_RETURNED => "No results were returned.",
            WIN32::ERROR_DS_CONTROL_NOT_FOUND => "The specified control is not supported by the server.",
            WIN32::ERROR_DS_CLIENT_LOOP => "A referral loop was detected by the client.",
            WIN32::ERROR_DS_REFERRAL_LIMIT_EXCEEDED => "The preset referral limit was exceeded.",
            WIN32::ERROR_DS_SORT_CONTROL_MISSING => "The search requires a SORT control.",
            WIN32::ERROR_DS_OFFSET_RANGE_ERROR => "The search results exceed the offset range specified.",
            WIN32::ERROR_DS_RIDMGR_DISABLED => "The directory service detected the subsystem that allocates relative identifiers is disabled. This can occur as a protective mechanism when the system determines a significant portion of relative identifiers (RIDs) have been exhausted. Please see http://go.microsoft.com/fwlink/?LinkId=228610 for recommended diagnostic steps and the procedure to re-enable account creation.",
            WIN32::ERROR_DS_ROOT_MUST_BE_NC => "The root object must be the head of a naming context. The root object cannot have an instantiated parent.",
            WIN32::ERROR_DS_ADD_REPLICA_INHIBITED => "The add replica operation cannot be performed. The naming context must be writeable in order to create the replica.",
            WIN32::ERROR_DS_ATT_NOT_DEF_IN_SCHEMA => "A reference to an attribute that is not defined in the schema occurred.",
            WIN32::ERROR_DS_MAX_OBJ_SIZE_EXCEEDED => "The maximum size of an object has been exceeded.",
            WIN32::ERROR_DS_OBJ_STRING_NAME_EXISTS => "An attempt was made to add an object to the directory with a name that is already in use.",
            WIN32::ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA => "An attempt was made to add an object of a class that does not have an RDN defined in the schema.",
            WIN32::ERROR_DS_RDN_DOESNT_MATCH_SCHEMA => "An attempt was made to add an object using an RDN that is not the RDN defined in the schema.",
            WIN32::ERROR_DS_NO_REQUESTED_ATTS_FOUND => "None of the requested attributes were found on the objects.",
            WIN32::ERROR_DS_USER_BUFFER_TO_SMALL => "The user buffer is too small.",
            WIN32::ERROR_DS_ATT_IS_NOT_ON_OBJ => "The attribute specified in the operation is not present on the object.",
            WIN32::ERROR_DS_ILLEGAL_MOD_OPERATION => "Illegal modify operation. Some aspect of the modification is not permitted.",
            WIN32::ERROR_DS_OBJ_TOO_LARGE => "The specified object is too large.",
            WIN32::ERROR_DS_BAD_INSTANCE_TYPE => "The specified instance type is not valid.",
            WIN32::ERROR_DS_MASTERDSA_REQUIRED => "The operation must be performed at a master DSA.",
            WIN32::ERROR_DS_OBJECT_CLASS_REQUIRED => "The object class attribute must be specified.",
            WIN32::ERROR_DS_MISSING_REQUIRED_ATT => "A required attribute is missing.",
            WIN32::ERROR_DS_ATT_NOT_DEF_FOR_CLASS => "An attempt was made to modify an object to include an attribute that is not legal for its class.",
            WIN32::ERROR_DS_ATT_ALREADY_EXISTS => "The specified attribute is already present on the object.",
            WIN32::ERROR_DS_CANT_ADD_ATT_VALUES => "The specified attribute is not present, or has no values.",
            WIN32::ERROR_DS_SINGLE_VALUE_CONSTRAINT => "Multiple values were specified for an attribute that can have only one value.",
            WIN32::ERROR_DS_RANGE_CONSTRAINT => "A value for the attribute was not in the acceptable range of values.",
            WIN32::ERROR_DS_ATT_VAL_ALREADY_EXISTS => "The specified value already exists.",
            WIN32::ERROR_DS_CANT_REM_MISSING_ATT => "The attribute cannot be removed because it is not present on the object.",
            WIN32::ERROR_DS_CANT_REM_MISSING_ATT_VAL => "The attribute value cannot be removed because it is not present on the object.",
            WIN32::ERROR_DS_ROOT_CANT_BE_SUBREF => "The specified root object cannot be a subref.",
            WIN32::ERROR_DS_NO_CHAINING => "Chaining is not permitted.",
            WIN32::ERROR_DS_NO_CHAINED_EVAL => "Chained evaluation is not permitted.",
            WIN32::ERROR_DS_NO_PARENT_OBJECT => "The operation could not be performed because the object's parent is either uninstantiated or deleted.",
            WIN32::ERROR_DS_PARENT_IS_AN_ALIAS => "Having a parent that is an alias is not permitted. Aliases are leaf objects.",
            WIN32::ERROR_DS_CANT_MIX_MASTER_AND_REPS => "The object and parent must be of the same type, either both masters or both replicas.",
            WIN32::ERROR_DS_CHILDREN_EXIST => "The operation cannot be performed because child objects exist. This operation can only be performed on a leaf object.",
            WIN32::ERROR_DS_OBJ_NOT_FOUND => "Directory object not found.",
            WIN32::ERROR_DS_ALIASED_OBJ_MISSING => "The aliased object is missing.",
            WIN32::ERROR_DS_BAD_NAME_SYNTAX => "The object name has bad syntax.",
            WIN32::ERROR_DS_ALIAS_POINTS_TO_ALIAS => "It is not permitted for an alias to refer to another alias.",
            WIN32::ERROR_DS_CANT_DEREF_ALIAS => "The alias cannot be dereferenced.",
            WIN32::ERROR_DS_OUT_OF_SCOPE => "The operation is out of scope.",
            WIN32::ERROR_DS_OBJECT_BEING_REMOVED => "The operation cannot continue because the object is in the process of being removed.",
            WIN32::ERROR_DS_CANT_DELETE_DSA_OBJ => "The DSA object cannot be deleted.",
            WIN32::ERROR_DS_GENERIC_ERROR => "A directory service error has occurred.",
            WIN32::ERROR_DS_DSA_MUST_BE_INT_MASTER => "The operation can only be performed on an internal master DSA object.",
            WIN32::ERROR_DS_CLASS_NOT_DSA => "The object must be of class DSA.",
            WIN32::ERROR_DS_INSUFF_ACCESS_RIGHTS => "Insufficient access rights to perform the operation.",
            WIN32::ERROR_DS_ILLEGAL_SUPERIOR => "The object cannot be added because the parent is not on the list of possible superiors.",
            WIN32::ERROR_DS_ATTRIBUTE_OWNED_BY_SAM => "Access to the attribute is not permitted because the attribute is owned by the Security Accounts Manager (SAM).",
            WIN32::ERROR_DS_NAME_TOO_MANY_PARTS => "The name has too many parts.",
            WIN32::ERROR_DS_NAME_TOO_LONG => "The name is too long.",
            WIN32::ERROR_DS_NAME_VALUE_TOO_LONG => "The name value is too long.",
            WIN32::ERROR_DS_NAME_UNPARSEABLE => "The directory service encountered an error parsing a name.",
            WIN32::ERROR_DS_NAME_TYPE_UNKNOWN => "The directory service cannot get the attribute type for a name.",
            WIN32::ERROR_DS_NOT_AN_OBJECT => "The name does not identify an object; the name identifies a phantom.",
            WIN32::ERROR_DS_SEC_DESC_TOO_SHORT => "The security descriptor is too short.",
            WIN32::ERROR_DS_SEC_DESC_INVALID => "The security descriptor is invalid.",
            WIN32::ERROR_DS_NO_DELETED_NAME => "Failed to create name for deleted object.",
            WIN32::ERROR_DS_SUBREF_MUST_HAVE_PARENT => "The parent of a new subref must exist.",
            WIN32::ERROR_DS_NCNAME_MUST_BE_NC => "The object must be a naming context.",
            WIN32::ERROR_DS_CANT_ADD_SYSTEM_ONLY => "It is not permitted to add an attribute which is owned by the system.",
            WIN32::ERROR_DS_CLASS_MUST_BE_CONCRETE => "The class of the object must be structural; you cannot instantiate an abstract class.",
            WIN32::ERROR_DS_INVALID_DMD => "The schema object could not be found.",
            WIN32::ERROR_DS_OBJ_GUID_EXISTS => "A local object with this GUID (dead or alive) already exists.",
            WIN32::ERROR_DS_NOT_ON_BACKLINK => "The operation cannot be performed on a back link.",
            WIN32::ERROR_DS_NO_CROSSREF_FOR_NC => "The cross reference for the specified naming context could not be found.",
            WIN32::ERROR_DS_SHUTTING_DOWN => "The operation could not be performed because the directory service is shutting down.",
            WIN32::ERROR_DS_UNKNOWN_OPERATION => "The directory service request is invalid.",
            WIN32::ERROR_DS_INVALID_ROLE_OWNER => "The role owner attribute could not be read.",
            WIN32::ERROR_DS_COULDNT_CONTACT_FSMO => "The requested FSMO operation failed. The current FSMO holder could not be contacted.",
            WIN32::ERROR_DS_CROSS_NC_DN_RENAME => "Modification of a DN across a naming context is not permitted.",
            WIN32::ERROR_DS_CANT_MOD_SYSTEM_ONLY => "The attribute cannot be modified because it is owned by the system.",
            WIN32::ERROR_DS_REPLICATOR_ONLY => "Only the replicator can perform this function.",
            WIN32::ERROR_DS_OBJ_CLASS_NOT_DEFINED => "The specified class is not defined.",
            WIN32::ERROR_DS_OBJ_CLASS_NOT_SUBCLASS => "The specified class is not a subclass.",
            WIN32::ERROR_DS_NAME_REFERENCE_INVALID => "The name reference is invalid.",
            WIN32::ERROR_DS_CROSS_REF_EXISTS => "A cross reference already exists.",
            WIN32::ERROR_DS_CANT_DEL_MASTER_CROSSREF => "It is not permitted to delete a master cross reference.",
            WIN32::ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD => "Subtree notifications are only supported on NC heads.",
            WIN32::ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX => "Notification filter is too complex.",
            WIN32::ERROR_DS_DUP_RDN => "Schema update failed: duplicate RDN.",
            WIN32::ERROR_DS_DUP_OID => "Schema update failed: duplicate OID.",
            WIN32::ERROR_DS_DUP_MAPI_ID => "Schema update failed: duplicate MAPI identifier.",
            WIN32::ERROR_DS_DUP_SCHEMA_ID_GUID => "Schema update failed: duplicate schema-id GUID.",
            WIN32::ERROR_DS_DUP_LDAP_DISPLAY_NAME => "Schema update failed: duplicate LDAP display name.",
            WIN32::ERROR_DS_SEMANTIC_ATT_TEST => "Schema update failed: range-lower less than range upper.",
            WIN32::ERROR_DS_SYNTAX_MISMATCH => "Schema update failed: syntax mismatch.",
            WIN32::ERROR_DS_EXISTS_IN_MUST_HAVE => "Schema deletion failed: attribute is used in must-contain.",
            WIN32::ERROR_DS_EXISTS_IN_MAY_HAVE => "Schema deletion failed: attribute is used in may-contain.",
            WIN32::ERROR_DS_NONEXISTENT_MAY_HAVE => "Schema update failed: attribute in may-contain does not exist.",
            WIN32::ERROR_DS_NONEXISTENT_MUST_HAVE => "Schema update failed: attribute in must-contain does not exist.",
            WIN32::ERROR_DS_AUX_CLS_TEST_FAIL => "Schema update failed: class in aux-class list does not exist or is not an auxiliary class.",
            WIN32::ERROR_DS_NONEXISTENT_POSS_SUP => "Schema update failed: class in poss-superiors does not exist.",
            WIN32::ERROR_DS_SUB_CLS_TEST_FAIL => "Schema update failed: class in subclassof list does not exist or does not satisfy hierarchy rules.",
            WIN32::ERROR_DS_BAD_RDN_ATT_ID_SYNTAX => "Schema update failed: Rdn-Att-Id has wrong syntax.",
            WIN32::ERROR_DS_EXISTS_IN_AUX_CLS => "Schema deletion failed: class is used as auxiliary class.",
            WIN32::ERROR_DS_EXISTS_IN_SUB_CLS => "Schema deletion failed: class is used as sub class.",
            WIN32::ERROR_DS_EXISTS_IN_POSS_SUP => "Schema deletion failed: class is used as poss superior.",
            WIN32::ERROR_DS_RECALCSCHEMA_FAILED => "Schema update failed in recalculating validation cache.",
            WIN32::ERROR_DS_TREE_DELETE_NOT_FINISHED => "The tree deletion is not finished. The request must be made again to continue deleting the tree.",
            WIN32::ERROR_DS_CANT_DELETE => "The requested delete operation could not be performed.",
            WIN32::ERROR_DS_ATT_SCHEMA_REQ_ID => "Cannot read the governs class identifier for the schema record.",
            WIN32::ERROR_DS_BAD_ATT_SCHEMA_SYNTAX => "The attribute schema has bad syntax.",
            WIN32::ERROR_DS_CANT_CACHE_ATT => "The attribute could not be cached.",
            WIN32::ERROR_DS_CANT_CACHE_CLASS => "The class could not be cached.",
            WIN32::ERROR_DS_CANT_REMOVE_ATT_CACHE => "The attribute could not be removed from the cache.",
            WIN32::ERROR_DS_CANT_REMOVE_CLASS_CACHE => "The class could not be removed from the cache.",
            WIN32::ERROR_DS_CANT_RETRIEVE_DN => "The distinguished name attribute could not be read.",
            WIN32::ERROR_DS_MISSING_SUPREF => "No superior reference has been configured for the directory service. The directory service is therefore unable to issue referrals to objects outside this forest.",
            WIN32::ERROR_DS_CANT_RETRIEVE_INSTANCE => "The instance type attribute could not be retrieved.",
            WIN32::ERROR_DS_CODE_INCONSISTENCY => "An internal error has occurred.",
            WIN32::ERROR_DS_DATABASE_ERROR => "A database error has occurred.",
            WIN32::ERROR_DS_GOVERNSID_MISSING => "The attribute GOVERNSID is missing.",
            WIN32::ERROR_DS_MISSING_EXPECTED_ATT => "An expected attribute is missing.",
            WIN32::ERROR_DS_NCNAME_MISSING_CR_REF => "The specified naming context is missing a cross reference.",
            WIN32::ERROR_DS_SECURITY_CHECKING_ERROR => "A security checking error has occurred.",
            WIN32::ERROR_DS_SCHEMA_NOT_LOADED => "The schema is not loaded.",
            WIN32::ERROR_DS_SCHEMA_ALLOC_FAILED => "Schema allocation failed. Please check if the machine is running low on memory.",
            WIN32::ERROR_DS_ATT_SCHEMA_REQ_SYNTAX => "Failed to obtain the required syntax for the attribute schema.",
            WIN32::ERROR_DS_GCVERIFY_ERROR => "The global catalog verification failed. The global catalog is not available or does not support the operation. Some part of the directory is currently not available.",
            WIN32::ERROR_DS_DRA_SCHEMA_MISMATCH => "The replication operation failed because of a schema mismatch between the servers involved.",
            WIN32::ERROR_DS_CANT_FIND_DSA_OBJ => "The DSA object could not be found.",
            WIN32::ERROR_DS_CANT_FIND_EXPECTED_NC => "The naming context could not be found.",
            WIN32::ERROR_DS_CANT_FIND_NC_IN_CACHE => "The naming context could not be found in the cache.",
            WIN32::ERROR_DS_CANT_RETRIEVE_CHILD => "The child object could not be retrieved.",
            WIN32::ERROR_DS_SECURITY_ILLEGAL_MODIFY => "The modification was not permitted for security reasons.",
            WIN32::ERROR_DS_CANT_REPLACE_HIDDEN_REC => "The operation cannot replace the hidden record.",
            WIN32::ERROR_DS_BAD_HIERARCHY_FILE => "The hierarchy file is invalid.",
            WIN32::ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED => "The attempt to build the hierarchy table failed.",
            WIN32::ERROR_DS_CONFIG_PARAM_MISSING => "The directory configuration parameter is missing from the registry.",
            WIN32::ERROR_DS_COUNTING_AB_INDICES_FAILED => "The attempt to count the address book indices failed.",
            WIN32::ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED => "The allocation of the hierarchy table failed.",
            WIN32::ERROR_DS_INTERNAL_FAILURE => "The directory service encountered an internal failure.",
            WIN32::ERROR_DS_UNKNOWN_ERROR => "The directory service encountered an unknown failure.",
            WIN32::ERROR_DS_ROOT_REQUIRES_CLASS_TOP => "A root object requires a class of 'top'.",
            WIN32::ERROR_DS_REFUSING_FSMO_ROLES => "This directory server is shutting down, and cannot take ownership of new floating single-master operation roles.",
            WIN32::ERROR_DS_MISSING_FSMO_SETTINGS => "The directory service is missing mandatory configuration information, and is unable to determine the ownership of floating single-master operation roles.",
            WIN32::ERROR_DS_UNABLE_TO_SURRENDER_ROLES => "The directory service was unable to transfer ownership of one or more floating single-master operation roles to other servers.",
            WIN32::ERROR_DS_DRA_GENERIC => "The replication operation failed.",
            WIN32::ERROR_DS_DRA_INVALID_PARAMETER => "An invalid parameter was specified for this replication operation.",
            WIN32::ERROR_DS_DRA_BUSY => "The directory service is too busy to complete the replication operation at this time.",
            WIN32::ERROR_DS_DRA_BAD_DN => "The distinguished name specified for this replication operation is invalid.",
            WIN32::ERROR_DS_DRA_BAD_NC => "The naming context specified for this replication operation is invalid.",
            WIN32::ERROR_DS_DRA_DN_EXISTS => "The distinguished name specified for this replication operation already exists.",
            WIN32::ERROR_DS_DRA_INTERNAL_ERROR => "The replication system encountered an internal error.",
            WIN32::ERROR_DS_DRA_INCONSISTENT_DIT => "The replication operation encountered a database inconsistency.",
            WIN32::ERROR_DS_DRA_CONNECTION_FAILED => "The server specified for this replication operation could not be contacted.",
            WIN32::ERROR_DS_DRA_BAD_INSTANCE_TYPE => "The replication operation encountered an object with an invalid instance type.",
            WIN32::ERROR_DS_DRA_OUT_OF_MEM => "The replication operation failed to allocate memory.",
            WIN32::ERROR_DS_DRA_MAIL_PROBLEM => "The replication operation encountered an error with the mail system.",
            WIN32::ERROR_DS_DRA_REF_ALREADY_EXISTS => "The replication reference information for the target server already exists.",
            WIN32::ERROR_DS_DRA_REF_NOT_FOUND => "The replication reference information for the target server does not exist.",
            WIN32::ERROR_DS_DRA_OBJ_IS_REP_SOURCE => "The naming context cannot be removed because it is replicated to another server.",
            WIN32::ERROR_DS_DRA_DB_ERROR => "The replication operation encountered a database error.",
            WIN32::ERROR_DS_DRA_NO_REPLICA => "The naming context is in the process of being removed or is not replicated from the specified server.",
            WIN32::ERROR_DS_DRA_ACCESS_DENIED => "Replication access was denied.",
            WIN32::ERROR_DS_DRA_NOT_SUPPORTED => "The requested operation is not supported by this version of the directory service.",
            WIN32::ERROR_DS_DRA_RPC_CANCELLED => "The replication remote procedure call was cancelled.",
            WIN32::ERROR_DS_DRA_SOURCE_DISABLED => "The source server is currently rejecting replication requests.",
            WIN32::ERROR_DS_DRA_SINK_DISABLED => "The destination server is currently rejecting replication requests.",
            WIN32::ERROR_DS_DRA_NAME_COLLISION => "The replication operation failed due to a collision of object names.",
            WIN32::ERROR_DS_DRA_SOURCE_REINSTALLED => "The replication source has been reinstalled.",
            WIN32::ERROR_DS_DRA_MISSING_PARENT => "The replication operation failed because a required parent object is missing.",
            WIN32::ERROR_DS_DRA_PREEMPTED => "The replication operation was preempted.",
            WIN32::ERROR_DS_DRA_ABANDON_SYNC => "The replication synchronization attempt was abandoned because of a lack of updates.",
            WIN32::ERROR_DS_DRA_SHUTDOWN => "The replication operation was terminated because the system is shutting down.",
            WIN32::ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET => "Synchronization attempt failed because the destination DC is currently waiting to synchronize new partial attributes from source. This condition is normal if a recent schema change modified the partial attribute set. The destination partial attribute set is not a subset of source partial attribute set.",
            WIN32::ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA => "The replication synchronization attempt failed because a master replica attempted to sync from a partial replica.",
            WIN32::ERROR_DS_DRA_EXTN_CONNECTION_FAILED => "The server specified for this replication operation was contacted, but that server was unable to contact an additional server needed to complete the operation.",
            WIN32::ERROR_DS_INSTALL_SCHEMA_MISMATCH => "The version of the directory service schema of the source forest is not compatible with the version of directory service on this computer.",
            WIN32::ERROR_DS_DUP_LINK_ID => "Schema update failed: An attribute with the same link identifier already exists.",
            WIN32::ERROR_DS_NAME_ERROR_RESOLVING => "Name translation: Generic processing error.",
            WIN32::ERROR_DS_NAME_ERROR_NOT_FOUND => "Name translation: Could not find the name or insufficient right to see name.",
            WIN32::ERROR_DS_NAME_ERROR_NOT_UNIQUE => "Name translation: Input name mapped to more than one output name.",
            WIN32::ERROR_DS_NAME_ERROR_NO_MAPPING => "Name translation: Input name found, but not the associated output format.",
            WIN32::ERROR_DS_NAME_ERROR_DOMAIN_ONLY => "Name translation: Unable to resolve completely, only the domain was found.",
            WIN32::ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING => "Name translation: Unable to perform purely syntactical mapping at the client without going out to the wire.",
            WIN32::ERROR_DS_CONSTRUCTED_ATT_MOD => "Modification of a constructed attribute is not allowed.",
            WIN32::ERROR_DS_WRONG_OM_OBJ_CLASS => "The OM-Object-Class specified is incorrect for an attribute with the specified syntax.",
            WIN32::ERROR_DS_DRA_REPL_PENDING => "The replication request has been posted; waiting for reply.",
            WIN32::ERROR_DS_DS_REQUIRED => "The requested operation requires a directory service, and none was available.",
            WIN32::ERROR_DS_INVALID_LDAP_DISPLAY_NAME => "The LDAP display name of the class or attribute contains non-ASCII characters.",
            WIN32::ERROR_DS_NON_BASE_SEARCH => "The requested search operation is only supported for base searches.",
            WIN32::ERROR_DS_CANT_RETRIEVE_ATTS => "The search failed to retrieve attributes from the database.",
            WIN32::ERROR_DS_BACKLINK_WITHOUT_LINK => "The schema update operation tried to add a backward link attribute that has no corresponding forward link.",
            WIN32::ERROR_DS_EPOCH_MISMATCH => "Source and destination of a cross-domain move do not agree on the object's epoch number. Either source or destination does not have the latest version of the object.",
            WIN32::ERROR_DS_SRC_NAME_MISMATCH => "Source and destination of a cross-domain move do not agree on the object's current name. Either source or destination does not have the latest version of the object.",
            WIN32::ERROR_DS_SRC_AND_DST_NC_IDENTICAL => "Source and destination for the cross-domain move operation are identical. Caller should use local move operation instead of cross-domain move operation.",
            WIN32::ERROR_DS_DST_NC_MISMATCH => "Source and destination for a cross-domain move are not in agreement on the naming contexts in the forest. Either source or destination does not have the latest version of the Partitions container.",
            WIN32::ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC => "Destination of a cross-domain move is not authoritative for the destination naming context.",
            WIN32::ERROR_DS_SRC_GUID_MISMATCH => "Source and destination of a cross-domain move do not agree on the identity of the source object. Either source or destination does not have the latest version of the source object.",
            WIN32::ERROR_DS_CANT_MOVE_DELETED_OBJECT => "Object being moved across-domains is already known to be deleted by the destination server. The source server does not have the latest version of the source object.",
            WIN32::ERROR_DS_PDC_OPERATION_IN_PROGRESS => "Another operation which requires exclusive access to the PDC FSMO is already in progress.",
            WIN32::ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD => "A cross-domain move operation failed such that two versions of the moved object exist - one each in the source and destination domains. The destination object needs to be removed to restore the system to a consistent state.",
            WIN32::ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION => "This object may not be moved across domain boundaries either because cross-domain moves for this class are disallowed, or the object has some special characteristics, e.g.: trust account or restricted RID, which prevent its move.",
            WIN32::ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS => "Can't move objects with memberships across domain boundaries as once moved, this would violate the membership conditions of the account group. Remove the object from any account group memberships and retry.",
            WIN32::ERROR_DS_NC_MUST_HAVE_NC_PARENT => "A naming context head must be the immediate child of another naming context head, not of an interior node.",
            WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE => "The directory cannot validate the proposed naming context name because it does not hold a replica of the naming context above the proposed naming context. Please ensure that the domain naming master role is held by a server that is configured as a global catalog server, and that the server is up to date with its replication partners. (Applies only to Windows 2000 Domain Naming masters).",
            WIN32::ERROR_DS_DST_DOMAIN_NOT_NATIVE => "Destination domain must be in native mode.",
            WIN32::ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER => "The operation cannot be performed because the server does not have an infrastructure container in the domain of interest.",
            WIN32::ERROR_DS_CANT_MOVE_ACCOUNT_GROUP => "Cross-domain move of non-empty account groups is not allowed.",
            WIN32::ERROR_DS_CANT_MOVE_RESOURCE_GROUP => "Cross-domain move of non-empty resource groups is not allowed.",
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG => "The search flags for the attribute are invalid. The ANR bit is valid only on attributes of Unicode or Teletex strings.",
            WIN32::ERROR_DS_NO_TREE_DELETE_ABOVE_NC => "Tree deletions starting at an object which has an NC head as a descendant are not allowed.",
            WIN32::ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE => "The directory service failed to lock a tree in preparation for a tree deletion because the tree was in use.",
            WIN32::ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE => "The directory service failed to identify the list of objects to delete while attempting a tree deletion.",
            WIN32::ERROR_DS_SAM_INIT_FAILURE => "Security Accounts Manager initialization failed because of the following error: %1.",
            WIN32::ERROR_DS_SENSITIVE_GROUP_VIOLATION => "Only an administrator can modify the membership list of an administrative group.",
            WIN32::ERROR_DS_CANT_MOD_PRIMARYGROUPID => "Cannot change the primary group ID of a domain controller account.",
            WIN32::ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD => "An attempt is made to modify the base schema.",
            WIN32::ERROR_DS_NONSAFE_SCHEMA_CHANGE => "Adding a new mandatory attribute to an existing class, deleting a mandatory attribute from an existing class, or adding an optional attribute to the special class Top that is not a backlink attribute (directly or through inheritance, for example, by adding or deleting an auxiliary class) is not allowed.",
            WIN32::ERROR_DS_SCHEMA_UPDATE_DISALLOWED => "Schema update is not allowed on this DC because the DC is not the schema FSMO Role Owner.",
            WIN32::ERROR_DS_CANT_CREATE_UNDER_SCHEMA => "An object of this class cannot be created under the schema container. You can only create attribute-schema and class-schema objects under the schema container.",
            WIN32::ERROR_DS_INSTALL_NO_SRC_SCH_VERSION => "The replica/child install failed to get the objectVersion attribute on the schema container on the source DC. Either the attribute is missing on the schema container or the credentials supplied do not have permission to read it.",
            WIN32::ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE => "The replica/child install failed to read the objectVersion attribute in the SCHEMA section of the file schema.ini in the system32 directory.",
            WIN32::ERROR_DS_INVALID_GROUP_TYPE => "The specified group type is invalid.",
            WIN32::ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN => "You cannot nest global groups in a mixed domain if the group is security-enabled.",
            WIN32::ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN => "You cannot nest local groups in a mixed domain if the group is security-enabled.",
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER => "A global group cannot have a local group as a member.",
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER => "A global group cannot have a universal group as a member.",
            WIN32::ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER => "A universal group cannot have a local group as a member.",
            WIN32::ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER => "A global group cannot have a cross-domain member.",
            WIN32::ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER => "A local group cannot have another cross domain local group as a member.",
            WIN32::ERROR_DS_HAVE_PRIMARY_MEMBERS => "A group with primary members cannot change to a security-disabled group.",
            WIN32::ERROR_DS_STRING_SD_CONVERSION_FAILED => "The schema cache load failed to convert the string default SD on a class-schema object.",
            WIN32::ERROR_DS_NAMING_MASTER_GC => "Only DSAs configured to be Global Catalog servers should be allowed to hold the Domain Naming Master FSMO role. (Applies only to Windows 2000 servers).",
            WIN32::ERROR_DS_DNS_LOOKUP_FAILURE => "The DSA operation is unable to proceed because of a DNS lookup failure.",
            WIN32::ERROR_DS_COULDNT_UPDATE_SPNS => "While processing a change to the DNS Host Name for an object, the Service Principal Name values could not be kept in sync.",
            WIN32::ERROR_DS_CANT_RETRIEVE_SD => "The Security Descriptor attribute could not be read.",
            WIN32::ERROR_DS_KEY_NOT_UNIQUE => "The object requested was not found, but an object with that key was found.",
            WIN32::ERROR_DS_WRONG_LINKED_ATT_SYNTAX => "The syntax of the linked attribute being added is incorrect. Forward links can only have syntax 2.5.5.1, 2.5.5.7, and 2.5.5.14, and backlinks can only have syntax 2.5.5.1.",
            WIN32::ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD => "Security Account Manager needs to get the boot password.",
            WIN32::ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY => "Security Account Manager needs to get the boot key from floppy disk.",
            WIN32::ERROR_DS_CANT_START => "Directory Service cannot start.",
            WIN32::ERROR_DS_INIT_FAILURE => "Directory Services could not start.",
            WIN32::ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION => "The connection between client and server requires packet privacy or better.",
            WIN32::ERROR_DS_SOURCE_DOMAIN_IN_FOREST => "The source domain may not be in the same forest as destination.",
            WIN32::ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST => "The destination domain must be in the forest.",
            WIN32::ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED => "The operation requires that destination domain auditing be enabled.",
            WIN32::ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN => "The operation couldn't locate a DC for the source domain.",
            WIN32::ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER => "The source object must be a group or user.",
            WIN32::ERROR_DS_SRC_SID_EXISTS_IN_FOREST => "The source object's SID already exists in destination forest.",
            WIN32::ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH => "The source and destination object must be of the same type.",
            WIN32::ERROR_SAM_INIT_FAILURE => "Security Accounts Manager initialization failed because of the following error: %1.",
            WIN32::ERROR_DS_DRA_SCHEMA_INFO_SHIP => "Schema information could not be included in the replication request.",
            WIN32::ERROR_DS_DRA_SCHEMA_CONFLICT => "The replication operation could not be completed due to a schema incompatibility.",
            WIN32::ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT => "The replication operation could not be completed due to a previous schema incompatibility.",
            WIN32::ERROR_DS_DRA_OBJ_NC_MISMATCH => "The replication update could not be applied because either the source or the destination has not yet received information regarding a recent cross-domain move operation.",
            WIN32::ERROR_DS_NC_STILL_HAS_DSAS => "The requested domain could not be deleted because there exist domain controllers that still host this domain.",
            WIN32::ERROR_DS_GC_REQUIRED => "The requested operation can be performed only on a global catalog server.",
            WIN32::ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY => "A local group can only be a member of other local groups in the same domain.",
            WIN32::ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS => "Foreign security principals cannot be members of universal groups.",
            WIN32::ERROR_DS_CANT_ADD_TO_GC => "The attribute is not allowed to be replicated to the GC because of security reasons.",
            WIN32::ERROR_DS_NO_CHECKPOINT_WITH_PDC => "The checkpoint with the PDC could not be taken because there too many modifications being processed currently.",
            WIN32::ERROR_DS_SOURCE_AUDITING_NOT_ENABLED => "The operation requires that source domain auditing be enabled.",
            WIN32::ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC => "Security principal objects can only be created inside domain naming contexts.",
            WIN32::ERROR_DS_INVALID_NAME_FOR_SPN => "A Service Principal Name (SPN) could not be constructed because the provided hostname is not in the necessary format.",
            WIN32::ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS => "A Filter was passed that uses constructed attributes.",
            WIN32::ERROR_DS_UNICODEPWD_NOT_IN_QUOTES => "The unicodePwd attribute value must be enclosed in double quotes.",
            WIN32::ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED => "Your computer could not be joined to the domain. You have exceeded the maximum number of computer accounts you are allowed to create in this domain. Contact your system administrator to have this limit reset or increased.",
            WIN32::ERROR_DS_MUST_BE_RUN_ON_DST_DC => "For security reasons, the operation must be run on the destination DC.",
            WIN32::ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER => "For security reasons, the source DC must be NT4SP4 or greater.",
            WIN32::ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ => "Critical Directory Service System objects cannot be deleted during tree delete operations. The tree delete may have been partially performed.",
            WIN32::ERROR_DS_INIT_FAILURE_CONSOLE => "Directory Services could not start because of the following error: %1.",
            WIN32::ERROR_DS_SAM_INIT_FAILURE_CONSOLE => "Security Accounts Manager initialization failed because of the following error: %1.",
            WIN32::ERROR_DS_FOREST_VERSION_TOO_HIGH => "The version of the operating system is incompatible with the current AD DS forest functional level or AD LDS Configuration Set functional level. You must upgrade to a new version of the operating system before this server can become an AD DS Domain Controller or add an AD LDS Instance in this AD DS Forest or AD LDS Configuration Set.",
            WIN32::ERROR_DS_DOMAIN_VERSION_TOO_HIGH => "The version of the operating system installed is incompatible with the current domain functional level. You must upgrade to a new version of the operating system before this server can become a domain controller in this domain.",
            WIN32::ERROR_DS_FOREST_VERSION_TOO_LOW => "The version of the operating system installed on this server no longer supports the current AD DS Forest functional level or AD LDS Configuration Set functional level. You must raise the AD DS Forest functional level or AD LDS Configuration Set functional level before this server can become an AD DS Domain Controller or an AD LDS Instance in this Forest or Configuration Set.",
            WIN32::ERROR_DS_DOMAIN_VERSION_TOO_LOW => "The version of the operating system installed on this server no longer supports the current domain functional level. You must raise the domain functional level before this server can become a domain controller in this domain.",
            WIN32::ERROR_DS_INCOMPATIBLE_VERSION => "The version of the operating system installed on this server is incompatible with the functional level of the domain or forest.",
            WIN32::ERROR_DS_LOW_DSA_VERSION => "The functional level of the domain (or forest) cannot be raised to the requested value, because there exist one or more domain controllers in the domain (or forest) that are at a lower incompatible functional level.",
            WIN32::ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN => "The forest functional level cannot be raised to the requested value since one or more domains are still in mixed domain mode. All domains in the forest must be in native mode, for you to raise the forest functional level.",
            WIN32::ERROR_DS_NOT_SUPPORTED_SORT_ORDER => "The sort order requested is not supported.",
            WIN32::ERROR_DS_NAME_NOT_UNIQUE => "The requested name already exists as a unique identifier.",
            WIN32::ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4 => "The machine account was created pre-NT4. The account needs to be recreated.",
            WIN32::ERROR_DS_OUT_OF_VERSION_STORE => "The database is out of version store.",
            WIN32::ERROR_DS_INCOMPATIBLE_CONTROLS_USED => "Unable to continue operation because multiple conflicting controls were used.",
            WIN32::ERROR_DS_NO_REF_DOMAIN => "Unable to find a valid security descriptor reference domain for this partition.",
            WIN32::ERROR_DS_RESERVED_LINK_ID => "Schema update failed: The link identifier is reserved.",
            WIN32::ERROR_DS_LINK_ID_NOT_AVAILABLE => "Schema update failed: There are no link identifiers available.",
            WIN32::ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER => "An account group cannot have a universal group as a member.",
            WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE => "Rename or move operations on naming context heads or read-only objects are not allowed.",
            WIN32::ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC => "Move operations on objects in the schema naming context are not allowed.",
            WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG => "A system flag has been set on the object and does not allow the object to be moved or renamed.",
            WIN32::ERROR_DS_MODIFYDN_WRONG_GRANDPARENT => "This object is not allowed to change its grandparent container. Moves are not forbidden on this object, but are restricted to sibling containers.",
            WIN32::ERROR_DS_NAME_ERROR_TRUST_REFERRAL => "Unable to resolve completely, a referral to another forest is generated.",
            WIN32::ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER => "The requested action is not supported on standard server.",
            WIN32::ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD => "Could not access a partition of the directory service located on a remote server. Make sure at least one server is running for the partition in question.",
            WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2 => "The directory cannot validate the proposed naming context (or partition) name because it does not hold a replica nor can it contact a replica of the naming context above the proposed naming context. Please ensure that the parent naming context is properly registered in DNS, and at least one replica of this naming context is reachable by the Domain Naming master.",
            WIN32::ERROR_DS_THREAD_LIMIT_EXCEEDED => "The thread limit for this request was exceeded.",
            WIN32::ERROR_DS_NOT_CLOSEST => "The Global catalog server is not in the closest site.",
            WIN32::ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF => "The DS cannot derive a service principal name (SPN) with which to mutually authenticate the target server because the corresponding server object in the local DS database has no serverReference attribute.",
            WIN32::ERROR_DS_SINGLE_USER_MODE_FAILED => "The Directory Service failed to enter single user mode.",
            WIN32::ERROR_DS_NTDSCRIPT_SYNTAX_ERROR => "The Directory Service cannot parse the script because of a syntax error.",
            WIN32::ERROR_DS_NTDSCRIPT_PROCESS_ERROR => "The Directory Service cannot process the script because of an error.",
            WIN32::ERROR_DS_DIFFERENT_REPL_EPOCHS => "The directory service cannot perform the requested operation because the servers involved are of different replication epochs (which is usually related to a domain rename that is in progress).",
            WIN32::ERROR_DS_DRS_EXTENSIONS_CHANGED => "The directory service binding must be renegotiated due to a change in the server extensions information.",
            WIN32::ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR => "Operation not allowed on a disabled cross ref.",
            WIN32::ERROR_DS_NO_MSDS_INTID => "Schema update failed: No values for msDS-IntId are available.",
            WIN32::ERROR_DS_DUP_MSDS_INTID => "Schema update failed: Duplicate msDS-INtId. Retry the operation.",
            WIN32::ERROR_DS_EXISTS_IN_RDNATTID => "Schema deletion failed: attribute is used in rDNAttID.",
            WIN32::ERROR_DS_AUTHORIZATION_FAILED => "The directory service failed to authorize the request.",
            WIN32::ERROR_DS_INVALID_SCRIPT => "The Directory Service cannot process the script because it is invalid.",
            WIN32::ERROR_DS_REMOTE_CROSSREF_OP_FAILED => "The remote create cross reference operation failed on the Domain Naming Master FSMO. The operation's error is in the extended data.",
            WIN32::ERROR_DS_CROSS_REF_BUSY => "A cross reference is in use locally with the same name.",
            WIN32::ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN => "The DS cannot derive a service principal name (SPN) with which to mutually authenticate the target server because the server's domain has been deleted from the forest.",
            WIN32::ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC => "Writeable NCs prevent this DC from demoting.",
            WIN32::ERROR_DS_DUPLICATE_ID_FOUND => "The requested object has a non-unique identifier and cannot be retrieved.",
            WIN32::ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT => "Insufficient attributes were given to create an object. This object may not exist because it may have been deleted and already garbage collected.",
            WIN32::ERROR_DS_GROUP_CONVERSION_ERROR => "The group cannot be converted due to attribute restrictions on the requested group type.",
            WIN32::ERROR_DS_CANT_MOVE_APP_BASIC_GROUP => "Cross-domain move of non-empty basic application groups is not allowed.",
            WIN32::ERROR_DS_CANT_MOVE_APP_QUERY_GROUP => "Cross-domain move of non-empty query based application groups is not allowed.",
            WIN32::ERROR_DS_ROLE_NOT_VERIFIED => "The FSMO role ownership could not be verified because its directory partition has not replicated successfully with at least one replication partner.",
            WIN32::ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL => "The target container for a redirection of a well known object container cannot already be a special container.",
            WIN32::ERROR_DS_DOMAIN_RENAME_IN_PROGRESS => "The Directory Service cannot perform the requested operation because a domain rename operation is in progress.",
            WIN32::ERROR_DS_EXISTING_AD_CHILD_NC => "The directory service detected a child partition below the requested partition name. The partition hierarchy must be created in a top down method.",
            WIN32::ERROR_DS_REPL_LIFETIME_EXCEEDED => "The directory service cannot replicate with this server because the time since the last replication with this server has exceeded the tombstone lifetime.",
            WIN32::ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER => "The requested operation is not allowed on an object under the system container.",
            WIN32::ERROR_DS_LDAP_SEND_QUEUE_FULL => "The LDAP servers network send queue has filled up because the client is not processing the results of its requests fast enough. No more requests will be processed until the client catches up. If the client does not catch up then it will be disconnected.",
            WIN32::ERROR_DS_DRA_OUT_SCHEDULE_WINDOW => "The scheduled replication did not take place because the system was too busy to execute the request within the schedule window. The replication queue is overloaded. Consider reducing the number of partners or decreasing the scheduled replication frequency.",
            WIN32::ERROR_DS_POLICY_NOT_KNOWN => "At this time, it cannot be determined if the branch replication policy is available on the hub domain controller. Please retry at a later time to account for replication latencies.",
            WIN32::ERROR_NO_SITE_SETTINGS_OBJECT => "The site settings object for the specified site does not exist.",
            WIN32::ERROR_NO_SECRETS => "The local account store does not contain secret material for the specified account.",
            WIN32::ERROR_NO_WRITABLE_DC_FOUND => "Could not find a writable domain controller in the domain.",
            WIN32::ERROR_DS_NO_SERVER_OBJECT => "The server object for the domain controller does not exist.",
            WIN32::ERROR_DS_NO_NTDSA_OBJECT => "The NTDS Settings object for the domain controller does not exist.",
            WIN32::ERROR_DS_NON_ASQ_SEARCH => "The requested search operation is not supported for ASQ searches.",
            WIN32::ERROR_DS_AUDIT_FAILURE => "A required audit event could not be generated for the operation.",
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE => "The search flags for the attribute are invalid. The subtree index bit is valid only on single valued attributes.",
            WIN32::ERROR_DS_INVALID_SEARCH_FLAG_TUPLE => "The search flags for the attribute are invalid. The tuple index bit is valid only on attributes of Unicode strings.",
            WIN32::ERROR_DS_HIERARCHY_TABLE_TOO_DEEP => "The address books are nested too deeply. Failed to build the hierarchy table.",
            WIN32::ERROR_DS_DRA_CORRUPT_UTD_VECTOR => "The specified up-to-date-ness vector is corrupt.",
            WIN32::ERROR_DS_DRA_SECRETS_DENIED => "The request to replicate secrets is denied.",
            WIN32::ERROR_DS_RESERVED_MAPI_ID => "Schema update failed: The MAPI identifier is reserved.",
            WIN32::ERROR_DS_MAPI_ID_NOT_AVAILABLE => "Schema update failed: There are no MAPI identifiers available.",
            WIN32::ERROR_DS_DRA_MISSING_KRBTGT_SECRET => "The replication operation failed because the required attributes of the local krbtgt object are missing.",
            WIN32::ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST => "The domain name of the trusted domain already exists in the forest.",
            WIN32::ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST => "The flat name of the trusted domain already exists in the forest.",
            WIN32::ERROR_INVALID_USER_PRINCIPAL_NAME => "The User Principal Name (UPN) is invalid.",
            WIN32::ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS => "OID mapped groups cannot have members.",
            WIN32::ERROR_DS_OID_NOT_FOUND => "The specified OID cannot be found.",
            WIN32::ERROR_DS_DRA_RECYCLED_TARGET => "The replication operation failed because the target object referred by a link value is recycled.",
            WIN32::ERROR_DS_DISALLOWED_NC_REDIRECT => "The redirect operation failed because the target object is in a NC different from the domain NC of the current domain controller.",
            WIN32::ERROR_DS_HIGH_ADLDS_FFL => "The functional level of the AD LDS configuration set cannot be lowered to the requested value.",
            WIN32::ERROR_DS_HIGH_DSA_VERSION => "The functional level of the domain (or forest) cannot be lowered to the requested value.",
            WIN32::ERROR_DS_LOW_ADLDS_FFL => "The functional level of the AD LDS configuration set cannot be raised to the requested value, because there exist one or more ADLDS instances that are at a lower incompatible functional level.",
            WIN32::ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION => "The domain join cannot be completed because the SID of the domain you attempted to join was identical to the SID of this machine. This is a symptom of an improperly cloned operating system install. You should run sysprep on this machine in order to generate a new machine SID. Please see http://go.microsoft.com/fwlink/?LinkId=168895 for more information.",
            WIN32::ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED => "The undelete operation failed because the Sam Account Name or Additional Sam Account Name of the object being undeleted conflicts with an existing live object.",
            WIN32::ERROR_INCORRECT_ACCOUNT_TYPE => "The system is not authoritative for the specified account and therefore cannot complete the operation. Please retry the operation using the provider associated with this account. If this is an online provider please use the provider's online site.",
            WIN32::ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST => "The operation failed because SPN value provided for addition/modification is not unique forest-wide.",
            WIN32::ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST => "The operation failed because UPN value provided for addition/modification is not unique forest-wide.",
            WIN32::ERROR_DS_MISSING_FOREST_TRUST => "The operation failed because the addition/modification referenced an inbound forest-wide trust that is not present.",
            WIN32::ERROR_DS_VALUE_KEY_NOT_UNIQUE => "The link value specified was not found, but a link value with that key was found.",
            WIN32::ERROR_WEAK_WHFBKEY_BLOCKED => "The Security Account Manager blocked the use of a weak Windows Hello for Business key.",
            WIN32::ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD => "The add object operation failed because the caller was not authorized to add one or more attributes included in the request.",
            WIN32::ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED => "The local account policy modification request was rejected because the policy is controlled by a regional authority.",
            WIN32::ERROR_POLICY_CONTROLLED_ACCOUNT => "The account is controlled by external policy and cannot be modified.",
            WIN32::ERROR_LAPS_LEGACY_SCHEMA_MISSING => "The Local Administrator Password Solution password update operation failed because the legacy LAPS schema needs to be added to Active Directory.",
            WIN32::ERROR_LAPS_SCHEMA_MISSING => "The Local Administrator Password Solution password update operation failed because the Windows LAPS schema needs to be added to Active Directory.",
            WIN32::ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL => "The Local Administrator Password Solution encrypted password update operation failed because Active Directory is not yet running at the minimum required domain functional level (2016).",
            WIN32::DNS_ERROR_RCODE_FORMAT_ERROR => "DNS server unable to interpret format.",
            WIN32::DNS_ERROR_RCODE_SERVER_FAILURE => "DNS server failure.",
            WIN32::DNS_ERROR_RCODE_NAME_ERROR => "DNS name does not exist.",
            WIN32::DNS_ERROR_RCODE_NOT_IMPLEMENTED => "DNS request not supported by name server.",
            WIN32::DNS_ERROR_RCODE_REFUSED => "DNS operation refused.",
            WIN32::DNS_ERROR_RCODE_YXDOMAIN => "DNS name that ought not exist, does exist.",
            WIN32::DNS_ERROR_RCODE_YXRRSET => "DNS RR set that ought not exist, does exist.",
            WIN32::DNS_ERROR_RCODE_NXRRSET => "DNS RR set that ought to exist, does not exist.",
            WIN32::DNS_ERROR_RCODE_NOTAUTH => "DNS server not authoritative for zone.",
            WIN32::DNS_ERROR_RCODE_NOTZONE => "DNS name in update or prereq is not in zone.",
            WIN32::DNS_ERROR_RCODE_BADSIG => "DNS signature failed to verify.",
            WIN32::DNS_ERROR_RCODE_BADKEY => "DNS bad key.",
            WIN32::DNS_ERROR_RCODE_BADTIME => "DNS signature validity expired.",
            WIN32::DNS_ERROR_KEYMASTER_REQUIRED => "Only the DNS server acting as the key master for the zone may perform this operation.",
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE => "This operation is not allowed on a zone that is signed or has signing keys.",
            WIN32::DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1 => "NSEC3 is not compatible with the RSA-SHA-1 algorithm. Choose a different algorithm or use NSEC.",
            WIN32::DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS => "The zone does not have enough signing keys. There must be at least one key signing key (KSK) and at least one zone signing key (ZSK).",
            WIN32::DNS_ERROR_UNSUPPORTED_ALGORITHM => "The specified algorithm is not supported.",
            WIN32::DNS_ERROR_INVALID_KEY_SIZE => "The specified key size is not supported.",
            WIN32::DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE => "One or more of the signing keys for a zone are not accessible to the DNS server. Zone signing will not be operational until this error is resolved.",
            WIN32::DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION => "The specified key storage provider does not support DPAPI++ data protection. Zone signing will not be operational until this error is resolved.",
            WIN32::DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR => "An unexpected DPAPI++ error was encountered. Zone signing will not be operational until this error is resolved.",
            WIN32::DNS_ERROR_UNEXPECTED_CNG_ERROR => "An unexpected crypto error was encountered. Zone signing may not be operational until this error is resolved.",
            WIN32::DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION => "The DNS server encountered a signing key with an unknown version. Zone signing will not be operational until this error is resolved.",
            WIN32::DNS_ERROR_KSP_NOT_ACCESSIBLE => "The specified key service provider cannot be opened by the DNS server.",
            WIN32::DNS_ERROR_TOO_MANY_SKDS => "The DNS server cannot accept any more signing keys with the specified algorithm and KSK flag value for this zone.",
            WIN32::DNS_ERROR_INVALID_ROLLOVER_PERIOD => "The specified rollover period is invalid.",
            WIN32::DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET => "The specified initial rollover offset is invalid.",
            WIN32::DNS_ERROR_ROLLOVER_IN_PROGRESS => "The specified signing key is already in process of rolling over keys.",
            WIN32::DNS_ERROR_STANDBY_KEY_NOT_PRESENT => "The specified signing key does not have a standby key to revoke.",
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ZSK => "This operation is not allowed on a zone signing key (ZSK).",
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD => "This operation is not allowed on an active signing key.",
            WIN32::DNS_ERROR_ROLLOVER_ALREADY_QUEUED => "The specified signing key is already queued for rollover.",
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE => "This operation is not allowed on an unsigned zone.",
            WIN32::DNS_ERROR_BAD_KEYMASTER => "This operation could not be completed because the DNS server listed as the current key master for this zone is down or misconfigured. Resolve the problem on the current key master for this zone or use another DNS server to seize the key master role.",
            WIN32::DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD => "The specified signature validity period is invalid.",
            WIN32::DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT => "The specified NSEC3 iteration count is higher than allowed by the minimum key length used in the zone.",
            WIN32::DNS_ERROR_DNSSEC_IS_DISABLED => "This operation could not be completed because the DNS server has been configured with DNSSEC features disabled. Enable DNSSEC on the DNS server.",
            WIN32::DNS_ERROR_INVALID_XML => "This operation could not be completed because the XML stream received is empty or syntactically invalid.",
            WIN32::DNS_ERROR_NO_VALID_TRUST_ANCHORS => "This operation completed, but no trust anchors were added because all of the trust anchors received were either invalid, unsupported, expired, or would not become valid in less than 30 days.",
            WIN32::DNS_ERROR_ROLLOVER_NOT_POKEABLE => "The specified signing key is not waiting for parental DS update.",
            WIN32::DNS_ERROR_NSEC3_NAME_COLLISION => "Hash collision detected during NSEC3 signing. Specify a different user-provided salt, or use a randomly generated salt, and attempt to sign the zone again.",
            WIN32::DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1 => "NSEC is not compatible with the NSEC3-RSA-SHA-1 algorithm. Choose a different algorithm or use NSEC3.",
            WIN32::DNS_INFO_NO_RECORDS => "No records found for given DNS query.",
            WIN32::DNS_ERROR_BAD_PACKET => "Bad DNS packet.",
            WIN32::DNS_ERROR_NO_PACKET => "No DNS packet.",
            WIN32::DNS_ERROR_RCODE => "DNS error, check rcode.",
            WIN32::DNS_ERROR_UNSECURE_PACKET => "Unsecured DNS packet.",
            WIN32::DNS_REQUEST_PENDING => "DNS query request is pending.",
            WIN32::DNS_ERROR_INVALID_TYPE => "Invalid DNS type.",
            WIN32::DNS_ERROR_INVALID_IP_ADDRESS => "Invalid IP address.",
            WIN32::DNS_ERROR_INVALID_PROPERTY => "Invalid property.",
            WIN32::DNS_ERROR_TRY_AGAIN_LATER => "Try DNS operation again later.",
            WIN32::DNS_ERROR_NOT_UNIQUE => "Record for given name and type is not unique.",
            WIN32::DNS_ERROR_NON_RFC_NAME => "DNS name does not comply with RFC specifications.",
            WIN32::DNS_STATUS_FQDN => "DNS name is a fully-qualified DNS name.",
            WIN32::DNS_STATUS_DOTTED_NAME => "DNS name is dotted (multi-label).",
            WIN32::DNS_STATUS_SINGLE_PART_NAME => "DNS name is a single-part name.",
            WIN32::DNS_ERROR_INVALID_NAME_CHAR => "DNS name contains an invalid character.",
            WIN32::DNS_ERROR_NUMERIC_NAME => "DNS name is entirely numeric.",
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER => "The operation requested is not permitted on a DNS root server.",
            WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION => "The record could not be created because this part of the DNS namespace has been delegated to another server.",
            WIN32::DNS_ERROR_CANNOT_FIND_ROOT_HINTS => "The DNS server could not find a set of root hints.",
            WIN32::DNS_ERROR_INCONSISTENT_ROOT_HINTS => "The DNS server found root hints but they were not consistent across all adapters.",
            WIN32::DNS_ERROR_DWORD_VALUE_TOO_SMALL => "The specified value is too small for this parameter.",
            WIN32::DNS_ERROR_DWORD_VALUE_TOO_LARGE => "The specified value is too large for this parameter.",
            WIN32::DNS_ERROR_BACKGROUND_LOADING => "This operation is not allowed while the DNS server is loading zones in the background. Please try again later.",
            WIN32::DNS_ERROR_NOT_ALLOWED_ON_RODC => "The operation requested is not permitted on against a DNS server running on a read-only DC.",
            WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DNAME => "No data is allowed to exist underneath a DNAME record.",
            WIN32::DNS_ERROR_DELEGATION_REQUIRED => "This operation requires credentials delegation.",
            WIN32::DNS_ERROR_INVALID_POLICY_TABLE => "Name resolution policy table has been corrupted. DNS resolution will fail until it is fixed. Contact your network administrator.",
            WIN32::DNS_ERROR_ADDRESS_REQUIRED => "Not allowed to remove all addresses.",
            WIN32::DNS_ERROR_ZONE_DOES_NOT_EXIST => "DNS zone does not exist.",
            WIN32::DNS_ERROR_NO_ZONE_INFO => "DNS zone information not available.",
            WIN32::DNS_ERROR_INVALID_ZONE_OPERATION => "Invalid operation for DNS zone.",
            WIN32::DNS_ERROR_ZONE_CONFIGURATION_ERROR => "Invalid DNS zone configuration.",
            WIN32::DNS_ERROR_ZONE_HAS_NO_SOA_RECORD => "DNS zone has no start of authority (SOA) record.",
            WIN32::DNS_ERROR_ZONE_HAS_NO_NS_RECORDS => "DNS zone has no Name Server (NS) record.",
            WIN32::DNS_ERROR_ZONE_LOCKED => "DNS zone is locked.",
            WIN32::DNS_ERROR_ZONE_CREATION_FAILED => "DNS zone creation failed.",
            WIN32::DNS_ERROR_ZONE_ALREADY_EXISTS => "DNS zone already exists.",
            WIN32::DNS_ERROR_AUTOZONE_ALREADY_EXISTS => "DNS automatic zone already exists.",
            WIN32::DNS_ERROR_INVALID_ZONE_TYPE => "Invalid DNS zone type.",
            WIN32::DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP => "Secondary DNS zone requires master IP address.",
            WIN32::DNS_ERROR_ZONE_NOT_SECONDARY => "DNS zone not secondary.",
            WIN32::DNS_ERROR_NEED_SECONDARY_ADDRESSES => "Need secondary IP address.",
            WIN32::DNS_ERROR_WINS_INIT_FAILED => "WINS initialization failed.",
            WIN32::DNS_ERROR_NEED_WINS_SERVERS => "Need WINS servers.",
            WIN32::DNS_ERROR_NBSTAT_INIT_FAILED => "NBTSTAT initialization call failed.",
            WIN32::DNS_ERROR_SOA_DELETE_INVALID => "Invalid delete of start of authority (SOA).",
            WIN32::DNS_ERROR_FORWARDER_ALREADY_EXISTS => "A conditional forwarding zone already exists for that name.",
            WIN32::DNS_ERROR_ZONE_REQUIRES_MASTER_IP => "This zone must be configured with one or more master DNS server IP addresses.",
            WIN32::DNS_ERROR_ZONE_IS_SHUTDOWN => "The operation cannot be performed because this zone is shut down.",
            WIN32::DNS_ERROR_ZONE_LOCKED_FOR_SIGNING => "This operation cannot be performed because the zone is currently being signed. Please try again later.",
            WIN32::DNS_ERROR_PRIMARY_REQUIRES_DATAFILE => "Primary DNS zone requires datafile.",
            WIN32::DNS_ERROR_INVALID_DATAFILE_NAME => "Invalid datafile name for DNS zone.",
            WIN32::DNS_ERROR_DATAFILE_OPEN_FAILURE => "Failed to open datafile for DNS zone.",
            WIN32::DNS_ERROR_FILE_WRITEBACK_FAILED => "Failed to write datafile for DNS zone.",
            WIN32::DNS_ERROR_DATAFILE_PARSING => "Failure while reading datafile for DNS zone.",
            WIN32::DNS_ERROR_RECORD_DOES_NOT_EXIST => "DNS record does not exist.",
            WIN32::DNS_ERROR_RECORD_FORMAT => "DNS record format error.",
            WIN32::DNS_ERROR_NODE_CREATION_FAILED => "Node creation failure in DNS.",
            WIN32::DNS_ERROR_UNKNOWN_RECORD_TYPE => "Unknown DNS record type.",
            WIN32::DNS_ERROR_RECORD_TIMED_OUT => "DNS record timed out.",
            WIN32::DNS_ERROR_NAME_NOT_IN_ZONE => "Name not in DNS zone.",
            WIN32::DNS_ERROR_CNAME_LOOP => "CNAME loop detected.",
            WIN32::DNS_ERROR_NODE_IS_CNAME => "Node is a CNAME DNS record.",
            WIN32::DNS_ERROR_CNAME_COLLISION => "A CNAME record already exists for given name.",
            WIN32::DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT => "Record only at DNS zone root.",
            WIN32::DNS_ERROR_RECORD_ALREADY_EXISTS => "DNS record already exists.",
            WIN32::DNS_ERROR_SECONDARY_DATA => "Secondary DNS zone data error.",
            WIN32::DNS_ERROR_NO_CREATE_CACHE_DATA => "Could not create DNS cache data.",
            WIN32::DNS_ERROR_NAME_DOES_NOT_EXIST => "DNS name does not exist.",
            WIN32::DNS_WARNING_PTR_CREATE_FAILED => "Could not create pointer (PTR) record.",
            WIN32::DNS_WARNING_DOMAIN_UNDELETED => "DNS domain was undeleted.",
            WIN32::DNS_ERROR_DS_UNAVAILABLE => "The directory service is unavailable.",
            WIN32::DNS_ERROR_DS_ZONE_ALREADY_EXISTS => "DNS zone already exists in the directory service.",
            WIN32::DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE => "DNS server not creating or reading the boot file for the directory service integrated DNS zone.",
            WIN32::DNS_ERROR_NODE_IS_DNAME => "Node is a DNAME DNS record.",
            WIN32::DNS_ERROR_DNAME_COLLISION => "A DNAME record already exists for given name.",
            WIN32::DNS_ERROR_ALIAS_LOOP => "An alias loop has been detected with either CNAME or DNAME records.",
            WIN32::DNS_INFO_AXFR_COMPLETE => "DNS AXFR (zone transfer) complete.",
            WIN32::DNS_ERROR_AXFR => "DNS zone transfer failed.",
            WIN32::DNS_INFO_ADDED_LOCAL_WINS => "Added local WINS server.",
            WIN32::DNS_STATUS_CONTINUE_NEEDED => "Secure update call needs to continue update request.",
            WIN32::DNS_ERROR_NO_TCPIP => "TCP/IP network protocol not installed.",
            WIN32::DNS_ERROR_NO_DNS_SERVERS => "No DNS servers configured for local system.",
            WIN32::DNS_ERROR_DP_DOES_NOT_EXIST => "The specified directory partition does not exist.",
            WIN32::DNS_ERROR_DP_ALREADY_EXISTS => "The specified directory partition already exists.",
            WIN32::DNS_ERROR_DP_NOT_ENLISTED => "This DNS server is not enlisted in the specified directory partition.",
            WIN32::DNS_ERROR_DP_ALREADY_ENLISTED => "This DNS server is already enlisted in the specified directory partition.",
            WIN32::DNS_ERROR_DP_NOT_AVAILABLE => "The directory partition is not available at this time. Please wait a few minutes and try again.",
            WIN32::DNS_ERROR_DP_FSMO_ERROR => "The operation failed because the domain naming master FSMO role could not be reached. The domain controller holding the domain naming master FSMO role is down or unable to service the request or is not running Windows Server 2003 or later.",
            WIN32::DNS_ERROR_RRL_NOT_ENABLED => "The RRL is not enabled.",
            WIN32::DNS_ERROR_RRL_INVALID_WINDOW_SIZE => "The window size parameter is invalid. It should be greater than or equal to 1.",
            WIN32::DNS_ERROR_RRL_INVALID_IPV4_PREFIX => "The IPv4 prefix length parameter is invalid. It should be less than or equal to 32.",
            WIN32::DNS_ERROR_RRL_INVALID_IPV6_PREFIX => "The IPv6 prefix length parameter is invalid. It should be less than or equal to 128.",
            WIN32::DNS_ERROR_RRL_INVALID_TC_RATE => "The TC Rate parameter is invalid. It should be less than 10.",
            WIN32::DNS_ERROR_RRL_INVALID_LEAK_RATE => "The Leak Rate parameter is invalid. It should be either 0, or between 2 and 10.",
            WIN32::DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE => "The Leak Rate or TC Rate parameter is invalid. Leak Rate should be greater than TC Rate.",
            WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS => "The virtualization instance already exists.",
            WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST => "The virtualization instance does not exist.",
            WIN32::DNS_ERROR_VIRTUALIZATION_TREE_LOCKED => "The virtualization tree is locked.",
            WIN32::DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME => "Invalid virtualization instance name.",
            WIN32::DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE => "The default virtualization instance cannot be added, removed or modified.",
            WIN32::DNS_ERROR_ZONESCOPE_ALREADY_EXISTS => "The scope already exists for the zone.",
            WIN32::DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST => "The scope does not exist for the zone.",
            WIN32::DNS_ERROR_DEFAULT_ZONESCOPE => "The scope is the same as the default zone scope.",
            WIN32::DNS_ERROR_INVALID_ZONESCOPE_NAME => "The scope name contains invalid characters.",
            WIN32::DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES => "Operation not allowed when the zone has scopes.",
            WIN32::DNS_ERROR_LOAD_ZONESCOPE_FAILED => "Failed to load zone scope.",
            WIN32::DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED => "Failed to write data file for DNS zone scope. Please verify the file exists and is writable.",
            WIN32::DNS_ERROR_INVALID_SCOPE_NAME => "The scope name contains invalid characters.",
            WIN32::DNS_ERROR_SCOPE_DOES_NOT_EXIST => "The scope does not exist.",
            WIN32::DNS_ERROR_DEFAULT_SCOPE => "The scope is the same as the default scope.",
            WIN32::DNS_ERROR_INVALID_SCOPE_OPERATION => "The operation is invalid on the scope.",
            WIN32::DNS_ERROR_SCOPE_LOCKED => "The scope is locked.",
            WIN32::DNS_ERROR_SCOPE_ALREADY_EXISTS => "The scope already exists.",
            WIN32::DNS_ERROR_POLICY_ALREADY_EXISTS => "A policy with the same name already exists on this level (server level or zone level) on the DNS server.",
            WIN32::DNS_ERROR_POLICY_DOES_NOT_EXIST => "No policy with this name exists on this level (server level or zone level) on the DNS server.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA => "The criteria provided in the policy are invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_SETTINGS => "At least one of the settings of this policy is invalid.",
            WIN32::DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED => "The client subnet cannot be deleted while it is being accessed by a policy.",
            WIN32::DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST => "The client subnet does not exist on the DNS server.",
            WIN32::DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS => "A client subnet with this name already exists on the DNS server.",
            WIN32::DNS_ERROR_SUBNET_DOES_NOT_EXIST => "The IP subnet specified does not exist in the client subnet.",
            WIN32::DNS_ERROR_SUBNET_ALREADY_EXISTS => "The IP subnet that is being added, already exists in the client subnet.",
            WIN32::DNS_ERROR_POLICY_LOCKED => "The policy is locked.",
            WIN32::DNS_ERROR_POLICY_INVALID_WEIGHT => "The weight of the scope in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_NAME => "The DNS policy name is invalid.",
            WIN32::DNS_ERROR_POLICY_MISSING_CRITERIA => "The policy is missing criteria.",
            WIN32::DNS_ERROR_INVALID_CLIENT_SUBNET_NAME => "The name of the the client subnet record is invalid.",
            WIN32::DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID => "Invalid policy processing order.",
            WIN32::DNS_ERROR_POLICY_SCOPE_MISSING => "The scope information has not been provided for a policy that requires it.",
            WIN32::DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED => "The scope information has been provided for a policy that does not require it.",
            WIN32::DNS_ERROR_SERVERSCOPE_IS_REFERENCED => "The server scope cannot be deleted because it is referenced by a DNS Policy.",
            WIN32::DNS_ERROR_ZONESCOPE_IS_REFERENCED => "The zone scope cannot be deleted because it is referenced by a DNS Policy.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET => "The criterion client subnet provided in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL => "The criterion transport protocol provided in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL => "The criterion network protocol provided in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE => "The criterion interface provided in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN => "The criterion FQDN provided in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE => "The criterion query type provided in the policy is invalid.",
            WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY => "The criterion time of day provided in the policy is invalid.",
            WIN32::WSAEINTR => "A blocking operation was interrupted by a call to WSACancelBlockingCall.",
            WIN32::WSAEBADF => "The file handle supplied is not valid.",
            WIN32::WSAEACCES => "An attempt was made to access a socket in a way forbidden by its access permissions.",
            WIN32::WSAEFAULT => "The system detected an invalid pointer address in attempting to use a pointer argument in a call.",
            WIN32::WSAEINVAL => "An invalid argument was supplied.",
            WIN32::WSAEMFILE => "Too many open sockets.",
            WIN32::WSAEWOULDBLOCK => "A non-blocking socket operation could not be completed immediately.",
            WIN32::WSAEINPROGRESS => "A blocking operation is currently executing.",
            WIN32::WSAEALREADY => "An operation was attempted on a non-blocking socket that already had an operation in progress.",
            WIN32::WSAENOTSOCK => "An operation was attempted on something that is not a socket.",
            WIN32::WSAEDESTADDRREQ => "A required address was omitted from an operation on a socket.",
            WIN32::WSAEMSGSIZE => "A message sent on a datagram socket was larger than the internal message buffer or some other network limit, or the buffer used to receive a datagram into was smaller than the datagram itself.",
            WIN32::WSAEPROTOTYPE => "A protocol was specified in the socket function call that does not support the semantics of the socket type requested.",
            WIN32::WSAENOPROTOOPT => "An unknown, invalid, or unsupported option or level was specified in a getsockopt or setsockopt call.",
            WIN32::WSAEPROTONOSUPPORT => "The requested protocol has not been configured into the system, or no implementation for it exists.",
            WIN32::WSAESOCKTNOSUPPORT => "The support for the specified socket type does not exist in this address family.",
            WIN32::WSAEOPNOTSUPP => "The attempted operation is not supported for the type of object referenced.",
            WIN32::WSAEPFNOSUPPORT => "The protocol family has not been configured into the system or no implementation for it exists.",
            WIN32::WSAEAFNOSUPPORT => "An address incompatible with the requested protocol was used.",
            WIN32::WSAEADDRINUSE => "Only one usage of each socket address (protocol/network address/port) is normally permitted.",
            WIN32::WSAEADDRNOTAVAIL => "The requested address is not valid in its context.",
            WIN32::WSAENETDOWN => "A socket operation encountered a dead network.",
            WIN32::WSAENETUNREACH => "A socket operation was attempted to an unreachable network.",
            WIN32::WSAENETRESET => "The connection has been broken due to keep-alive activity detecting a failure while the operation was in progress.",
            WIN32::WSAECONNABORTED => "An established connection was aborted by the software in your host machine.",
            WIN32::WSAECONNRESET => "An existing connection was forcibly closed by the remote host.",
            WIN32::WSAENOBUFS => "An operation on a socket could not be performed because the system lacked sufficient buffer space or because a queue was full.",
            WIN32::WSAEISCONN => "A connect request was made on an already connected socket.",
            WIN32::WSAENOTCONN => "A request to send or receive data was disallowed because the socket is not connected and (when sending on a datagram socket using a sendto call) no address was supplied.",
            WIN32::WSAESHUTDOWN => "A request to send or receive data was disallowed because the socket had already been shut down in that direction with a previous shutdown call.",
            WIN32::WSAETOOMANYREFS => "Too many references to some kernel object.",
            WIN32::WSAETIMEDOUT => "A connection attempt failed because the connected party did not properly respond after a period of time, or established connection failed because connected host has failed to respond.",
            WIN32::WSAECONNREFUSED => "No connection could be made because the target machine actively refused it.",
            WIN32::WSAELOOP => "Cannot translate name.",
            WIN32::WSAENAMETOOLONG => "Name component or name was too long.",
            WIN32::WSAEHOSTDOWN => "A socket operation failed because the destination host was down.",
            WIN32::WSAEHOSTUNREACH => "A socket operation was attempted to an unreachable host.",
            WIN32::WSAENOTEMPTY => "Cannot remove a directory that is not empty.",
            WIN32::WSAEPROCLIM => "A Windows Sockets implementation may have a limit on the number of applications that may use it simultaneously.",
            WIN32::WSAEUSERS => "Ran out of quota.",
            WIN32::WSAEDQUOT => "Ran out of disk quota.",
            WIN32::WSAESTALE => "File handle reference is no longer available.",
            WIN32::WSAEREMOTE => "Item is not available locally.",
            WIN32::WSASYSNOTREADY => "WSAStartup cannot function at this time because the underlying system it uses to provide network services is currently unavailable.",
            WIN32::WSAVERNOTSUPPORTED => "The Windows Sockets version requested is not supported.",
            WIN32::WSANOTINITIALISED => "Either the application has not called WSAStartup, or WSAStartup failed.",
            WIN32::WSAEDISCON => "Returned by WSARecv or WSARecvFrom to indicate the remote party has initiated a graceful shutdown sequence.",
            WIN32::WSAENOMORE => "No more results can be returned by WSALookupServiceNext.",
            WIN32::WSAECANCELLED => "A call to WSALookupServiceEnd was made while this call was still processing. The call has been canceled.",
            WIN32::WSAEINVALIDPROCTABLE => "The procedure call table is invalid.",
            WIN32::WSAEINVALIDPROVIDER => "The requested service provider is invalid.",
            WIN32::WSAEPROVIDERFAILEDINIT => "The requested service provider could not be loaded or initialized.",
            WIN32::WSASYSCALLFAILURE => "A system call has failed.",
            WIN32::WSASERVICE_NOT_FOUND => "No such service is known. The service cannot be found in the specified name space.",
            WIN32::WSATYPE_NOT_FOUND => "The specified class was not found.",
            WIN32::WSA_E_NO_MORE => "No more results can be returned by WSALookupServiceNext.",
            WIN32::WSA_E_CANCELLED => "A call to WSALookupServiceEnd was made while this call was still processing. The call has been canceled.",
            WIN32::WSAEREFUSED => "A database query failed because it was actively refused.",
            WIN32::WSAHOST_NOT_FOUND => "No such host is known.",
            WIN32::WSATRY_AGAIN => "This is usually a temporary error during hostname resolution and means that the local server did not receive a response from an authoritative server.",
            WIN32::WSANO_RECOVERY => "A non-recoverable error occurred during a database lookup.",
            WIN32::WSANO_DATA => "The requested name is valid, but no data of the requested type was found.",
            WIN32::WSA_QOS_RECEIVERS => "At least one reserve has arrived.",
            WIN32::WSA_QOS_SENDERS => "At least one path has arrived.",
            WIN32::WSA_QOS_NO_SENDERS => "There are no senders.",
            WIN32::WSA_QOS_NO_RECEIVERS => "There are no receivers.",
            WIN32::WSA_QOS_REQUEST_CONFIRMED => "Reserve has been confirmed.",
            WIN32::WSA_QOS_ADMISSION_FAILURE => "Error due to lack of resources.",
            WIN32::WSA_QOS_POLICY_FAILURE => "Rejected for administrative reasons - bad credentials.",
            WIN32::WSA_QOS_BAD_STYLE => "Unknown or conflicting style.",
            WIN32::WSA_QOS_BAD_OBJECT => "Problem with some part of the filterspec or providerspecific buffer in general.",
            WIN32::WSA_QOS_TRAFFIC_CTRL_ERROR => "Problem with some part of the flowspec.",
            WIN32::WSA_QOS_GENERIC_ERROR => "General QOS error.",
            WIN32::WSA_QOS_ESERVICETYPE => "An invalid or unrecognized service type was found in the flowspec.",
            WIN32::WSA_QOS_EFLOWSPEC => "An invalid or inconsistent flowspec was found in the QOS structure.",
            WIN32::WSA_QOS_EPROVSPECBUF => "Invalid QOS provider-specific buffer.",
            WIN32::WSA_QOS_EFILTERSTYLE => "An invalid QOS filter style was used.",
            WIN32::WSA_QOS_EFILTERTYPE => "An invalid QOS filter type was used.",
            WIN32::WSA_QOS_EFILTERCOUNT => "An incorrect number of QOS FILTERSPECs were specified in the FLOWDESCRIPTOR.",
            WIN32::WSA_QOS_EOBJLENGTH => "An object with an invalid ObjectLength field was specified in the QOS provider-specific buffer.",
            WIN32::WSA_QOS_EFLOWCOUNT => "An incorrect number of flow descriptors was specified in the QOS structure.",
            WIN32::WSA_QOS_EUNKOWNPSOBJ => "An unrecognized object was found in the QOS provider-specific buffer.",
            WIN32::WSA_QOS_EPOLICYOBJ => "An invalid policy object was found in the QOS provider-specific buffer.",
            WIN32::WSA_QOS_EFLOWDESC => "An invalid QOS flow descriptor was found in the flow descriptor list.",
            WIN32::WSA_QOS_EPSFLOWSPEC => "An invalid or inconsistent flowspec was found in the QOS provider specific buffer.",
            WIN32::WSA_QOS_EPSFILTERSPEC => "An invalid FILTERSPEC was found in the QOS provider-specific buffer.",
            WIN32::WSA_QOS_ESDMODEOBJ => "An invalid shape discard mode object was found in the QOS provider specific buffer.",
            WIN32::WSA_QOS_ESHAPERATEOBJ => "An invalid shaping rate object was found in the QOS provider-specific buffer.",
            WIN32::WSA_QOS_RESERVED_PETYPE => "A reserved policy element was found in the QOS provider-specific buffer.",
            WIN32::WSA_SECURE_HOST_NOT_FOUND => "No such host is known securely.",
            WIN32::WSA_IPSEC_NAME_POLICY_ERROR => "Name based IPSEC policy could not be added.",
            WIN32::PEER_E_CLOUD_NOT_FOUND => "Description is missing",
            WIN32::PEER_E_CLOUD_DISABLED => "Description is missing",
            WIN32::PEER_E_INVALID_IDENTITY => "Description is missing",
            WIN32::PEER_E_TOO_MUCH_LOAD => "Description is missing",
            WIN32::PEER_E_CLOUD_IS_SEARCH_ONLY => "Description is missing",
            WIN32::PEER_E_CLIENT_INVALID_COMPARTMENT_ID => "Description is missing",
            WIN32::PEER_E_DUPLICATE_PEER_NAME => "Description is missing",
            WIN32::PEER_E_CLOUD_IS_DEAD => "Description is missing",
            WIN32::ERROR_INTERNET_ => "See Internet Error Codes and WinInet.h.",
            WIN32::WININET_E_OUT_OF_HANDLES => "No more Internet handles can be allocated.",
            WIN32::ERROR_INTERNET_OUT_OF_HANDLES => "No more handles could be generated at this time.",
            WIN32::WININET_E_TIMEOUT => "The operation timed out.",
            WIN32::ERROR_INTERNET_TIMEOUT => "The request has timed out.",
            WIN32::ERROR_WINHTTP_TIMEOUT => "The operation timed out.",
            WIN32::WININET_E_EXTENDED_ERROR => "The server returned extended information.",
            WIN32::ERROR_INTERNET_EXTENDED_ERROR => "An extended error was returned from the server. This is typically a string or buffer containing a verbose error message. Call  InternetGetLastResponseInfo to retrieve the error text.",
            WIN32::WININET_E_INTERNAL_ERROR => "An internal error occurred in the Microsoft Internet extensions.",
            WIN32::ERROR_INTERNET_INTERNAL_ERROR => "An internal error has occurred.",
            WIN32::ERROR_WINHTTP_INTERNAL_ERROR => "An internal error occurred in the Microsoft Internet extensions.",
            WIN32::WININET_E_INVALID_URL => "The URL is invalid.",
            WIN32::ERROR_INTERNET_INVALID_URL => "The URL is invalid.",
            WIN32::ERROR_WINHTTP_INVALID_URL => "The URL is invalid.",
            WIN32::WININET_E_UNRECOGNIZED_SCHEME => "The URL does not use a recognized protocol.",
            WIN32::ERROR_INTERNET_UNRECOGNIZED_SCHEME => "The URL scheme could not be recognized, or is not supported.",
            WIN32::ERROR_WINHTTP_UNRECOGNIZED_SCHEME => "The URL does not use a recognized protocol.",
            WIN32::WININET_E_NAME_NOT_RESOLVED => "The server name or address could not be resolved.",
            WIN32::ERROR_INTERNET_NAME_NOT_RESOLVED => "The server name could not be resolved.",
            WIN32::ERROR_WINHTTP_NAME_NOT_RESOLVED => "The server name or address could not be resolved.",
            WIN32::WININET_E_PROTOCOL_NOT_FOUND => "A protocol with the required capabilities was not found.",
            WIN32::ERROR_INTERNET_PROTOCOL_NOT_FOUND => "The requested protocol could not be located.",
            WIN32::WININET_E_INVALID_OPTION => "The option is invalid.",
            WIN32::ERROR_INTERNET_INVALID_OPTION => "A request to  InternetQueryOption or  InternetSetOption specified an invalid option value.",
            WIN32::ERROR_WINHTTP_INVALID_OPTION => "The option is invalid.",
            WIN32::WININET_E_BAD_OPTION_LENGTH => "The length is incorrect for the option type.",
            WIN32::ERROR_INTERNET_BAD_OPTION_LENGTH => "The length of an option supplied to  InternetQueryOption or  InternetSetOption is incorrect for the type of option specified.",
            WIN32::WININET_E_OPTION_NOT_SETTABLE => "The option value cannot be set.",
            WIN32::ERROR_INTERNET_OPTION_NOT_SETTABLE => "The requested option cannot be set, only queried.",
            WIN32::WININET_E_SHUTDOWN => "Microsoft Internet Extension support has been shut down.",
            WIN32::ERROR_INTERNET_SHUTDOWN => "WinINet support is being shut down or unloaded.",
            WIN32::ERROR_WINHTTP_SHUTDOWN => "Microsoft Internet Extension support has been shut down.",
            WIN32::WININET_E_INCORRECT_USER_NAME => "The user name was not allowed.",
            WIN32::ERROR_INTERNET_INCORRECT_USER_NAME => "The request to connect and log on to an FTP server could not be completed because the supplied user name is incorrect.",
            WIN32::WININET_E_INCORRECT_PASSWORD => "The password was not allowed.",
            WIN32::ERROR_INTERNET_INCORRECT_PASSWORD => "The request to connect and log on to an FTP server could not be completed because the supplied password is incorrect.",
            WIN32::WININET_E_LOGIN_FAILURE => "The login request was denied.",
            WIN32::ERROR_INTERNET_LOGIN_FAILURE => "The request to connect and log on to an FTP server failed.",
            WIN32::ERROR_WINHTTP_LOGIN_FAILURE => "The login request was denied.",
            WIN32::WININET_E_INVALID_OPERATION => "The requested operation is invalid.",
            WIN32::ERROR_INTERNET_INVALID_OPERATION => "The requested operation is invalid.",
            WIN32::WININET_E_OPERATION_CANCELLED => "The operation has been canceled.",
            WIN32::ERROR_INTERNET_OPERATION_CANCELLED => "The operation was canceled, usually because the handle on which the request was operating was closed before the operation completed.",
            WIN32::ERROR_WINHTTP_OPERATION_CANCELLED => "The operation has been canceled.",
            WIN32::WININET_E_INCORRECT_HANDLE_TYPE => "The supplied handle is the wrong type for the requested operation.",
            WIN32::ERROR_INTERNET_INCORRECT_HANDLE_TYPE => "The type of handle supplied is incorrect for this operation.",
            WIN32::WININET_E_INCORRECT_HANDLE_STATE => "The handle is in the wrong state for the requested operation.",
            WIN32::ERROR_INTERNET_INCORRECT_HANDLE_STATE => "The requested operation cannot be carried out because the handle supplied is not in the correct state.",
            WIN32::ERROR_WINHTTP_INCORRECT_HANDLE_STATE => "The handle is in the wrong state for the requested operation.",
            WIN32::WININET_E_NOT_PROXY_REQUEST => "The request cannot be made on a Proxy session.",
            WIN32::ERROR_INTERNET_NOT_PROXY_REQUEST => "The request cannot be made via a proxy.",
            WIN32::WININET_E_REGISTRY_VALUE_NOT_FOUND => "The registry value could not be found.",
            WIN32::ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND => "A required registry value could not be located.",
            WIN32::WININET_E_BAD_REGISTRY_PARAMETER => "The registry parameter is incorrect.",
            WIN32::ERROR_INTERNET_BAD_REGISTRY_PARAMETER => "A required registry value was located but is an incorrect type or has an invalid value.",
            WIN32::WININET_E_NO_DIRECT_ACCESS => "Direct Internet access is not available.",
            WIN32::ERROR_INTERNET_NO_DIRECT_ACCESS => "Direct network access cannot be made at this time.",
            WIN32::WININET_E_NO_CONTEXT => "No context value was supplied.",
            WIN32::ERROR_INTERNET_NO_CONTEXT => "An asynchronous request could not be made because a zero context value was supplied.",
            WIN32::WININET_E_NO_CALLBACK => "No status callback was supplied.",
            WIN32::ERROR_INTERNET_NO_CALLBACK => "An asynchronous request could not be made because a callback function has not been set.",
            WIN32::WININET_E_REQUEST_PENDING => "There are outstanding requests.",
            WIN32::ERROR_INTERNET_REQUEST_PENDING => "The required operation could not be completed because one or more requests are pending.",
            WIN32::WININET_E_INCORRECT_FORMAT => "The information format is incorrect.",
            WIN32::ERROR_INTERNET_INCORRECT_FORMAT => "The format of the request is invalid.",
            WIN32::WININET_E_ITEM_NOT_FOUND => "The requested item could not be found.",
            WIN32::ERROR_INTERNET_ITEM_NOT_FOUND => "The requested item could not be located.",
            WIN32::WININET_E_CANNOT_CONNECT => "A connection with the server could not be established.",
            WIN32::ERROR_INTERNET_CANNOT_CONNECT => "The attempt to connect to the server failed.",
            WIN32::ERROR_WINHTTP_CANNOT_CONNECT => "A connection with the server could not be established.",
            WIN32::WININET_E_CONNECTION_ABORTED => "The connection with the server was terminated abnormally.",
            WIN32::ERROR_INTERNET_CONNECTION_ABORTED => "The connection with the server has been terminated.",
            WIN32::ERROR_WINHTTP_CONNECTION_ABORTED => "he connection with the server was terminated abnormally.",
            WIN32::WININET_E_CONNECTION_RESET => "The connection with the server was reset.",
            WIN32::ERROR_INTERNET_CONNECTION_RESET => "The connection with the server has been reset.",
            WIN32::ERROR_WINHTTP_CONNECTION_RESET => "The connection with the server was reset.",
            WIN32::WININET_E_FORCE_RETRY => "The action must be retried.",
            WIN32::ERROR_INTERNET_FORCE_RETRY => "The function needs to redo the request.",
            WIN32::WININET_E_INVALID_PROXY_REQUEST => "The proxy request is invalid.",
            WIN32::ERROR_INTERNET_INVALID_PROXY_REQUEST => "The request to the proxy was invalid.",
            WIN32::WININET_E_NEED_UI => "User interaction is required to complete the operation.",
            WIN32::ERROR_INTERNET_NEED_UI => "A user interface or other blocking operation has been requested.",
            WIN32::WININET_E_HANDLE_EXISTS => "The handle already exists.",
            WIN32::ERROR_INTERNET_HANDLE_EXISTS => "The request failed because the handle already exists.",
            WIN32::WININET_E_SEC_CERT_DATE_INVALID => "The date in the certificate is invalid or has expired.",
            WIN32::ERROR_INTERNET_SEC_CERT_DATE_INVALID => "SSL certificate date that was received from the server is bad. The certificate is expired.",
            WIN32::ERROR_WINHTTP_SEC_CERT_DATE_INVALID => "The date in the certificate is invalid or has expired.",
            WIN32::WININET_E_SEC_CERT_CN_INVALID => "The host name in the certificate is invalid or does not match.",
            WIN32::ERROR_INTERNET_SEC_CERT_CN_INVALID => "SSL certificate common name (host name field) is incorrect - for example, if you entered www.server.com and the common name on the certificate says www.different.com.",
            WIN32::ERROR_WINHTTP_SEC_CERT_CN_INVALID => "The host name in the certificate is invalid or does not match.",
            WIN32::WININET_E_HTTP_TO_HTTPS_ON_REDIR => "A redirect request will change a non-secure to a secure connection.",
            WIN32::ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR => "The application is moving from a non-SSL to an SSL connection because of a redirect.",
            WIN32::WININET_E_HTTPS_TO_HTTP_ON_REDIR => "A redirect request will change a secure to a non-secure connection.",
            WIN32::ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR => "The application is moving from an SSL to an non-SSL connection because of a redirect.",
            WIN32::WININET_E_MIXED_SECURITY => "Mixed secure and non-secure connections.",
            WIN32::ERROR_INTERNET_MIXED_SECURITY => "The content is not entirely secure. Some of the content being viewed may have come from unsecured servers.",
            WIN32::WININET_E_CHG_POST_IS_NON_SECURE => "Changing to non-secure post.",
            WIN32::ERROR_INTERNET_CHG_POST_IS_NON_SECURE => "The application is posting and attempting to change multiple lines of text on a server that is not secure.",
            WIN32::WININET_E_POST_IS_NON_SECURE => "Data is being posted on a non-secure connection.",
            WIN32::ERROR_INTERNET_POST_IS_NON_SECURE => "The application is posting data to a server that is not secure.",
            WIN32::WININET_E_CLIENT_AUTH_CERT_NEEDED => "A certificate is required to complete client authentication.",
            WIN32::ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED => "The server is requesting client authentication.",
            WIN32::ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED => "A certificate is required to complete client authentication.",
            WIN32::WININET_E_INVALID_CA => "The certificate authority is invalid or incorrect.",
            WIN32::ERROR_INTERNET_INVALID_CA => "The function is unfamiliar with the Certificate Authority that generated the server's certificate.",
            WIN32::ERROR_WINHTTP_INVALID_CA => "The certificate authority is invalid or incorrect.",
            WIN32::WININET_E_CLIENT_AUTH_NOT_SETUP => "Client authentication has not been correctly installed.",
            WIN32::ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP => "Client authorization is not set up on this computer.",
            WIN32::WININET_E_ASYNC_THREAD_FAILED => "An error has occurred in a Wininet asynchronous thread. You may need to restart.",
            WIN32::ERROR_INTERNET_ASYNC_THREAD_FAILED => "The application could not start an asynchronous thread.",
            WIN32::WININET_E_REDIRECT_SCHEME_CHANGE => "The protocol scheme has changed during a redirect operation.",
            WIN32::ERROR_INTERNET_REDIRECT_SCHEME_CHANGE => "The function could not handle the redirection, because the scheme changed (for example, HTTP to FTP).",
            WIN32::WININET_E_DIALOG_PENDING => "There are operations awaiting retry.",
            WIN32::ERROR_INTERNET_DIALOG_PENDING => "Another thread has a password dialog box in progress.",
            WIN32::WININET_E_RETRY_DIALOG => "The operation must be retried.",
            WIN32::ERROR_INTERNET_RETRY_DIALOG => "The dialog box should be retried.",
            WIN32::WININET_E_NO_NEW_CONTAINERS => "There are no new cache containers.",
            WIN32::WININET_E_HTTPS_HTTP_SUBMIT_REDIR => "A security zone check indicates the operation must be retried.",
            WIN32::ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR => "The data being submitted to an SSL connection is being redirected to a non-SSL connection.",
            WIN32::ERROR_INTERNET_INSERT_CDROM => "The request requires a CD-ROM to be inserted in the CD-ROM drive to locate the resource requested.",
            WIN32::ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED => "The requested resource requires Fortezza authentication.",
            WIN32::WININET_E_SEC_CERT_ERRORS => "The SSL certificate contains errors.",
            WIN32::ERROR_INTERNET_SEC_CERT_ERRORS => "The SSL certificate contains errors.",
            WIN32::ERROR_INTERNET_SEC_CERT_NO_REV => "The SSL certificate was not revoked.",
            WIN32::WININET_E_SEC_CERT_REV_FAILED => "It was not possible to connect to the revocation server or a definitive response could not be obtained.",
            WIN32::ERROR_INTERNET_SEC_CERT_REV_FAILED => "Revocation of the SSL certificate failed.",
            WIN32::ERROR_WINHTTP_NO_CM_CONNECTION => "There was a problem connecting to the server.",
            WIN32::ERROR_FTP_TRANSFER_IN_PROGRESS => "The requested operation cannot be made on the FTP session handle because an operation is already in progress.",
            WIN32::ERROR_FTP_DROPPED => "The FTP operation was not completed because the session was aborted.",
            WIN32::ERROR_FTP_NO_PASSIVE_MODE => "Passive mode is not available on the server.",
            WIN32::ERROR_GOPHER_PROTOCOL_ERROR => "An error was detected while parsing data returned from the Gopher server.",
            WIN32::ERROR_GOPHER_NOT_FILE => "The request must be made for a file locator.",
            WIN32::ERROR_GOPHER_DATA_ERROR => "An error was detected while receiving data from the Gopher server.",
            WIN32::ERROR_GOPHER_END_OF_DATA => "The end of the data has been reached.",
            WIN32::ERROR_GOPHER_INVALID_LOCATOR => "The supplied locator is not valid.",
            WIN32::ERROR_GOPHER_INCORRECT_LOCATOR_TYPE => "The type of the locator is not correct for this operation.",
            WIN32::ERROR_GOPHER_NOT_GOPHER_PLUS => "The requested operation can be made only against a Gopher+ server, or with a locator that specifies a Gopher+ operation.",
            WIN32::ERROR_GOPHER_ATTRIBUTE_NOT_FOUND => "The requested attribute could not be located.",
            WIN32::ERROR_GOPHER_UNKNOWN_LOCATOR => "The locator type is unknown.",
            WIN32::WININET_E_HEADER_NOT_FOUND => "The requested header was not found.",
            WIN32::ERROR_HTTP_HEADER_NOT_FOUND => "The requested header could not be located.",
            WIN32::ERROR_WINHTTP_HEADER_NOT_FOUND => "The requested header was not found.",
            WIN32::WININET_E_DOWNLEVEL_SERVER => "The server does not support the requested protocol level.",
            WIN32::ERROR_HTTP_DOWNLEVEL_SERVER => "The server did not return any headers.",
            WIN32::WININET_E_INVALID_SERVER_RESPONSE => "The server returned an invalid or unrecognized response.",
            WIN32::ERROR_HTTP_INVALID_SERVER_RESPONSE => "The server response could not be parsed.",
            WIN32::ERROR_WINHTTP_INVALID_SERVER_RESPONSE => "The server returned an invalid or unrecognized response.",
            WIN32::WININET_E_INVALID_HEADER => "The supplied HTTP header is invalid.",
            WIN32::ERROR_HTTP_INVALID_HEADER => "The supplied header is invalid.",
            WIN32::WININET_E_INVALID_QUERY_REQUEST => "The request for a HTTP header is invalid.",
            WIN32::ERROR_HTTP_INVALID_QUERY_REQUEST => "The request made to  HttpQueryInfo is invalid.",
            WIN32::ERROR_WINHTTP_INVALID_QUERY_REQUEST => "The request for a HTTP header is invalid.",
            WIN32::WININET_E_HEADER_ALREADY_EXISTS => "The HTTP header already exists.",
            WIN32::ERROR_HTTP_HEADER_ALREADY_EXISTS => "The header could not be added because it already exists.",
            WIN32::WININET_E_REDIRECT_FAILED => "The HTTP redirect request failed.",
            WIN32::ERROR_HTTP_REDIRECT_FAILED => "The redirection failed because either the scheme changed (for example, HTTP to FTP) or all attempts made to redirect failed (default is five attempts).",
            WIN32::ERROR_WINHTTP_REDIRECT_FAILED => "The redirection failed because either the scheme changed (for example, HTTP to FTP) or all attempts made to redirect failed (default is five attempts).",
            WIN32::WININET_E_SECURITY_CHANNEL_ERROR => "An error occurred in the secure channel support.",
            WIN32::ERROR_INTERNET_SECURITY_CHANNEL_ERROR => "The application experienced an internal error loading the SSL libraries.",
            WIN32::ERROR_WINHTTP_SECURE_CHANNEL_ERROR => "The application experienced an internal error loading the SSL libraries.",
            WIN32::WININET_E_UNABLE_TO_CACHE_FILE => "The file could not be written to the cache.",
            WIN32::ERROR_INTERNET_UNABLE_TO_CACHE_FILE => "The function was unable to cache the file.",
            WIN32::WININET_E_TCPIP_NOT_INSTALLED => "The TCP/IP protocol is not installed properly.",
            WIN32::ERROR_INTERNET_TCPIP_NOT_INSTALLED => "The required protocol stack is not loaded and the application cannot start WinSock.",
            WIN32::WININET_E_NOT_REDIRECTED => "The HTTP request was not redirected.",
            WIN32::ERROR_HTTP_NOT_REDIRECTED => "The HTTP request was not redirected.",
            WIN32::WININET_E_COOKIE_NEEDS_CONFIRMATION => "A cookie from the server must be confirmed by the user.",
            WIN32::ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION => "The HTTP cookie requires confirmation.",
            WIN32::WININET_E_COOKIE_DECLINED => "A cookie from the server has been declined acceptance.",
            WIN32::ERROR_HTTP_COOKIE_DECLINED => "The HTTP cookie was declined by the server.",
            WIN32::WININET_E_DISCONNECTED => "The computer is disconnected from the network.",
            WIN32::ERROR_INTERNET_DISCONNECTED => "The Internet connection has been lost.",
            WIN32::WININET_E_SERVER_UNREACHABLE => "The server is unreachable.",
            WIN32::ERROR_INTERNET_SERVER_UNREACHABLE => "The website or server indicated is unreachable.",
            WIN32::WININET_E_PROXY_SERVER_UNREACHABLE => "The proxy server is unreachable.",
            WIN32::ERROR_INTERNET_PROXY_SERVER_UNREACHABLE => "The designated proxy server cannot be reached.",
            WIN32::WININET_E_BAD_AUTO_PROXY_SCRIPT => "The proxy auto-configuration script is in error.",
            WIN32::ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT => "There was an error in the automatic proxy configuration script.",
            WIN32::WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT => "Could not download the proxy auto-configuration script file.",
            WIN32::ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT => "The automatic proxy configuration script could not be downloaded. The INTERNET_FLAG_MUST_CACHE_REQUEST flag was set.",
            WIN32::WININET_E_REDIRECT_NEEDS_CONFIRMATION => "The HTTP redirect request must be confirmed by the user.",
            WIN32::ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION => "The redirection requires user confirmation.",
            WIN32::WININET_E_SEC_INVALID_CERT => "The supplied certificate is invalid.",
            WIN32::ERROR_INTERNET_SEC_INVALID_CERT => "The SSL certificate is invalid.",
            WIN32::ERROR_WINHTTP_SECURE_INVALID_CERT => "The SSL certificate is invalid.",
            WIN32::WININET_E_SEC_CERT_REVOKED => "The supplied certificate has been revoked.",
            WIN32::ERROR_INTERNET_SEC_CERT_REVOKED => "The SSL certificate was revoked.",
            WIN32::WININET_E_FAILED_DUETOSECURITYCHECK => "The Dialup failed because file sharing was turned on and a failure was requested if security check was needed.",
            WIN32::ERROR_INTERNET_FAILED_DUETOSECURITYCHECK => "The function failed due to a security check.",
            WIN32::WININET_E_NOT_INITIALIZED => "Initialization of the WinINet API has not occurred.",
            WIN32::ERROR_INTERNET_NOT_INITIALIZED => "Initialization of the WinINet API has not occurred. Indicates that a higher-level function, such as  InternetOpen, has not been called yet.",
            WIN32::ERROR_INTERNET_NEED_MSN_SSPI_PKG => "Not currently implemented.",
            WIN32::WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY => "Login failed and the client should display the entity body to the user.",
            WIN32::ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY => "The MS-Logoff digest header has been returned from the website. This header specifically instructs the digest package to purge credentials for the associated realm. This error will only be returned if  INTERNET_ERROR_MASK_LOGIN_FAILURE_DISPLAY_ENTITY_BODY option has been set; otherwise, ERROR_INTERNET_LOGIN_FAILURE is returned.",
            WIN32::WININET_E_DECODING_FAILED => "Content decoding has failed.",
            WIN32::ERROR_INTERNET_DECODING_FAILED => "WinINet failed to perform content decoding on the response. For more information, see the Content Encoding topic.",
            WIN32::ERROR_WINHTTP_SECURE_FAILURE => "WinINet failed to perform content decoding on the response. For more information, see the Content Encoding topic.",
            WIN32::ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW => "Returned when an incoming response exceeds an internal WinHTTP size limit.",
            WIN32::ERROR_IPSEC_QM_POLICY_EXISTS => "The specified quick mode policy already exists.",
            WIN32::ERROR_IPSEC_QM_POLICY_NOT_FOUND => "The specified quick mode policy was not found.",
            WIN32::ERROR_IPSEC_QM_POLICY_IN_USE => "The specified quick mode policy is being used.",
            WIN32::ERROR_IPSEC_MM_POLICY_EXISTS => "The specified main mode policy already exists.",
            WIN32::ERROR_IPSEC_MM_POLICY_NOT_FOUND => "The specified main mode policy was not found.",
            WIN32::ERROR_IPSEC_MM_POLICY_IN_USE => "The specified main mode policy is being used.",
            WIN32::ERROR_IPSEC_MM_FILTER_EXISTS => "The specified main mode filter already exists.",
            WIN32::ERROR_IPSEC_MM_FILTER_NOT_FOUND => "The specified main mode filter was not found.",
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_EXISTS => "The specified transport mode filter already exists.",
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND => "The specified transport mode filter does not exist.",
            WIN32::ERROR_IPSEC_MM_AUTH_EXISTS => "The specified main mode authentication list exists.",
            WIN32::ERROR_IPSEC_MM_AUTH_NOT_FOUND => "The specified main mode authentication list was not found.",
            WIN32::ERROR_IPSEC_MM_AUTH_IN_USE => "The specified main mode authentication list is being used.",
            WIN32::ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND => "The specified default main mode policy was not found.",
            WIN32::ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND => "The specified default main mode authentication list was not found.",
            WIN32::ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND => "The specified default quick mode policy was not found.",
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_EXISTS => "The specified tunnel mode filter exists.",
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND => "The specified tunnel mode filter was not found.",
            WIN32::ERROR_IPSEC_MM_FILTER_PENDING_DELETION => "The Main Mode filter is pending deletion.",
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION => "The transport filter is pending deletion.",
            WIN32::ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION => "The transport filter is pending deletion.",
            WIN32::ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION => "The tunnel filter is pending deletion.",
            WIN32::ERROR_IPSEC_MM_POLICY_PENDING_DELETION => "The Main Mode policy is pending deletion.",
            WIN32::ERROR_IPSEC_MM_POLICY_PENDING_ELETION => "The main mode policy is pending deletion.",
            WIN32::ERROR_IPSEC_MM_AUTH_PENDING_DELETION => "The Main Mode authentication bundle is pending deletion.",
            WIN32::ERROR_IPSEC_QM_POLICY_PENDING_DELETION => "The Quick Mode policy is pending deletion.",
            WIN32::WARNING_IPSEC_MM_POLICY_PRUNED => "The Main Mode policy was successfully added, but some of the requested offers are not supported.",
            WIN32::WARNING_IPSEC_QM_POLICY_PRUNED => "The Quick Mode policy was successfully added, but some of the requested offers are not supported.",
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_BEGIN => "ERROR_IPSEC_IKE_NEG_STATUS_BEGIN.",
            WIN32::ERROR_IPSEC_IKE_AUTH_FAIL => "IKE authentication credentials are unacceptable.",
            WIN32::ERROR_IPSEC_IKE_ATTRIB_FAIL => "IKE security attributes are unacceptable.",
            WIN32::ERROR_IPSEC_IKE_NEGOTIATION_PENDING => "IKE Negotiation in progress.",
            WIN32::ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR => "General processing error.",
            WIN32::ERROR_IPSEC_IKE_TIMED_OUT => "Negotiation timed out.",
            WIN32::ERROR_IPSEC_IKE_NO_CERT => "IKE failed to find valid machine certificate. Contact your Network Security Administrator about installing a valid certificate in the appropriate Certificate Store.",
            WIN32::ERROR_IPSEC_IKE_SA_DELETED => "IKE SA deleted by peer before establishment completed.",
            WIN32::ERROR_IPSEC_IKE_SA_REAPED => "IKE SA deleted before establishment completed.",
            WIN32::ERROR_IPSEC_IKE_MM_ACQUIRE_DROP => "Negotiation request sat in Queue too long.",
            WIN32::ERROR_IPSEC_IKE_QM_ACQUIRE_DROP => "Negotiation request sat in Queue too long.",
            WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_MM => "Negotiation request sat in Queue too long.",
            WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM => "Negotiation request sat in Queue too long.",
            WIN32::ERROR_IPSEC_IKE_DROP_NO_RESPONSE => "No response from peer.",
            WIN32::ERROR_IPSEC_IKE_MM_DELAY_DROP => "Negotiation took too long.",
            WIN32::ERROR_IPSEC_IKE_QM_DELAY_DROP => "Negotiation took too long.",
            WIN32::ERROR_IPSEC_IKE_ERROR => "Unknown error occurred.",
            WIN32::ERROR_IPSEC_IKE_CRL_FAILED => "Certificate Revocation Check failed.",
            WIN32::ERROR_IPSEC_IKE_INVALID_KEY_USAGE => "Invalid certificate key usage.",
            WIN32::ERROR_IPSEC_IKE_INVALID_CERT_TYPE => "Invalid certificate type.",
            WIN32::ERROR_IPSEC_IKE_NO_PRIVATE_KEY => "IKE negotiation failed because the machine certificate used does not have a private key. IPsec certificates require a private key. Contact your Network Security administrator about replacing with a certificate that has a private key.",
            WIN32::ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY => "Simultaneous rekeys were detected.",
            WIN32::ERROR_IPSEC_IKE_DH_FAIL => "Failure in Diffie-Hellman computation.",
            WIN32::ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED => "Don't know how to process critical payload.",
            WIN32::ERROR_IPSEC_IKE_INVALID_HEADER => "Invalid header.",
            WIN32::ERROR_IPSEC_IKE_NO_POLICY => "No policy configured.",
            WIN32::ERROR_IPSEC_IKE_INVALID_SIGNATURE => "Failed to verify signature.",
            WIN32::ERROR_IPSEC_IKE_KERBEROS_ERROR => "Failed to authenticate using Kerberos.",
            WIN32::ERROR_IPSEC_IKE_NO_PUBLIC_KEY => "Peer's certificate did not have a public key.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR => "Error processing error payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SA => "Error processing SA payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_PROP => "Error processing Proposal payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_TRANS => "Error processing Transform payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_KE => "Error processing KE payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_ID => "Error processing ID payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT => "Error processing Cert payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ => "Error processing Certificate Request payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_HASH => "Error processing Hash payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SIG => "Error processing Signature payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NONCE => "Error processing Nonce payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY => "Error processing Notify payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_DELETE => "Error processing Delete Payload.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR => "Error processing VendorId payload.",
            WIN32::ERROR_IPSEC_IKE_INVALID_PAYLOAD => "Invalid payload received.",
            WIN32::ERROR_IPSEC_IKE_LOAD_SOFT_SA => "Soft SA loaded.",
            WIN32::ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN => "Soft SA torn down.",
            WIN32::ERROR_IPSEC_IKE_INVALID_COOKIE => "Invalid cookie received.",
            WIN32::ERROR_IPSEC_IKE_NO_PEER_CERT => "Peer failed to send valid machine certificate.",
            WIN32::ERROR_IPSEC_IKE_PEER_CRL_FAILED => "Certification Revocation check of peer's certificate failed.",
            WIN32::ERROR_IPSEC_IKE_POLICY_CHANGE => "New policy invalidated SAs formed with old policy.",
            WIN32::ERROR_IPSEC_IKE_NO_MM_POLICY => "There is no available Main Mode IKE policy.",
            WIN32::ERROR_IPSEC_IKE_NOTCBPRIV => "Failed to enabled TCB privilege.",
            WIN32::ERROR_IPSEC_IKE_SECLOADFAIL => "Failed to load SECURITY.DLL.",
            WIN32::ERROR_IPSEC_IKE_FAILSSPINIT => "Failed to obtain security function table dispatch address from SSPI.",
            WIN32::ERROR_IPSEC_IKE_FAILQUERYSSP => "Failed to query Kerberos package to obtain max token size.",
            WIN32::ERROR_IPSEC_IKE_SRVACQFAIL => "Failed to obtain Kerberos server credentials for ISAKMP/ERROR_IPSEC_IKE service. Kerberos authentication will not function. The most likely reason for this is lack of domain membership. This is normal if your computer is a member of a workgroup.",
            WIN32::ERROR_IPSEC_IKE_SRVQUERYCRED => "Failed to determine SSPI principal name for ISAKMP/ERROR_IPSEC_IKE service (QueryCredentialsAttributes).",
            WIN32::ERROR_IPSEC_IKE_GETSPIFAIL => "Failed to obtain new SPI for the inbound SA from IPsec driver. The most common cause for this is that the driver does not have the correct filter. Check your policy to verify the filters.",
            WIN32::ERROR_IPSEC_IKE_INVALID_FILTER => "Given filter is invalid.",
            WIN32::ERROR_IPSEC_IKE_OUT_OF_MEMORY => "Memory allocation failed.",
            WIN32::ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED => "Failed to add Security Association to IPsec Driver. The most common cause for this is if the IKE negotiation took too long to complete. If the problem persists, reduce the load on the faulting machine.",
            WIN32::ERROR_IPSEC_IKE_INVALID_POLICY => "Invalid policy.",
            WIN32::ERROR_IPSEC_IKE_UNKNOWN_DOI => "Invalid DOI.",
            WIN32::ERROR_IPSEC_IKE_INVALID_SITUATION => "Invalid situation.",
            WIN32::ERROR_IPSEC_IKE_DH_FAILURE => "Diffie-Hellman failure.",
            WIN32::ERROR_IPSEC_IKE_INVALID_GROUP => "Invalid Diffie-Hellman group.",
            WIN32::ERROR_IPSEC_IKE_ENCRYPT => "Error encrypting payload.",
            WIN32::ERROR_IPSEC_IKE_DECRYPT => "Error decrypting payload.",
            WIN32::ERROR_IPSEC_IKE_POLICY_MATCH => "Policy match error.",
            WIN32::ERROR_IPSEC_IKE_UNSUPPORTED_ID => "Unsupported ID.",
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH => "Hash verification failed.",
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH_ALG => "Invalid hash algorithm.",
            WIN32::ERROR_IPSEC_IKE_INVALID_HASH_SIZE => "Invalid hash size.",
            WIN32::ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG => "Invalid encryption algorithm.",
            WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_ALG => "Invalid authentication algorithm.",
            WIN32::ERROR_IPSEC_IKE_INVALID_SIG => "Invalid certificate signature.",
            WIN32::ERROR_IPSEC_IKE_LOAD_FAILED => "Load failed.",
            WIN32::ERROR_IPSEC_IKE_RPC_DELETE => "Deleted via RPC call.",
            WIN32::ERROR_IPSEC_IKE_BENIGN_REINIT => "Temporary state created to perform reinitialization. This is not a real failure.",
            WIN32::ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY => "The lifetime value received in the Responder Lifetime Notify is below the Windows 2000 configured minimum value. Please fix the policy on the peer machine.",
            WIN32::ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION => "The recipient cannot handle version of IKE specified in the header.",
            WIN32::ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN => "Key length in certificate is too small for configured security requirements.",
            WIN32::ERROR_IPSEC_IKE_MM_LIMIT => "Max number of established MM SAs to peer exceeded.",
            WIN32::ERROR_IPSEC_IKE_NEGOTIATION_DISABLED => "IKE received a policy that disables negotiation.",
            WIN32::ERROR_IPSEC_IKE_QM_LIMIT => "Reached maximum quick mode limit for the main mode. New main mode will be started.",
            WIN32::ERROR_IPSEC_IKE_MM_EXPIRED => "Main mode SA lifetime expired or peer sent a main mode delete.",
            WIN32::ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID => "Main mode SA assumed to be invalid because peer stopped responding.",
            WIN32::ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH => "Certificate doesn't chain to a trusted root in IPsec policy.",
            WIN32::ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID => "Received unexpected message ID.",
            WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD => "Received invalid authentication offers.",
            WIN32::ERROR_IPSEC_IKE_INVALID_UMATTS => "Received invalid AuthIP user mode attributes.",
            WIN32::ERROR_IPSEC_IKE_DOS_COOKIE_SENT => "Sent DoS cookie notify to initiator.",
            WIN32::ERROR_IPSEC_IKE_SHUTTING_DOWN => "IKE service is shutting down.",
            WIN32::ERROR_IPSEC_IKE_CGA_AUTH_FAILED => "Could not verify binding between CGA address and certificate.",
            WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NATOA => "Error processing NatOA payload.",
            WIN32::ERROR_IPSEC_IKE_INVALID_MM_FOR_QM => "Parameters of the main mode are invalid for this quick mode.",
            WIN32::ERROR_IPSEC_IKE_QM_EXPIRED => "Quick mode SA was expired by IPsec driver.",
            WIN32::ERROR_IPSEC_IKE_TOO_MANY_FILTERS => "Too many dynamically added IKEEXT filters were detected.",
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_END => "ERROR_IPSEC_IKE_NEG_STATUS_END.",
            WIN32::ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL => "NAP reauth succeeded and must delete the dummy NAP IKEv2 tunnel.",
            WIN32::ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE => "Error in assigning inner IP address to initiator in tunnel mode.",
            WIN32::ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING => "Require configuration payload missing.",
            WIN32::ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING => "A negotiation running as the security principle who issued the connection is in progress.",
            WIN32::ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS => "SA was deleted due to IKEv1/AuthIP co-existence suppress check.",
            WIN32::ERROR_IPSEC_IKE_RATELIMIT_DROP => "Incoming SA request was dropped due to peer IP address rate limiting.",
            WIN32::ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE => "Peer does not support MOBIKE.",
            WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE => "SA establishment is not authorized.",
            WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE => "SA establishment is not authorized because there is not a sufficiently strong PKINIT-based credential.",
            WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY => "SA establishment is not authorized. You may need to enter updated or different credentials such as a smartcard.",
            WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE => "SA establishment is not authorized because there is not a sufficiently strong PKINIT-based credential. This might be related to certificate-to-account mapping failure for the SA.",
            WIN32::ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END => "ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END.",
            WIN32::ERROR_IPSEC_BAD_SPI => "The SPI in the packet does not match a valid IPsec SA.",
            WIN32::ERROR_IPSEC_SA_LIFETIME_EXPIRED => "Packet was received on an IPsec SA whose lifetime has expired.",
            WIN32::ERROR_IPSEC_WRONG_SA => "Packet was received on an IPsec SA that does not match the packet characteristics.",
            WIN32::ERROR_IPSEC_REPLAY_CHECK_FAILED => "Packet sequence number replay check failed.",
            WIN32::ERROR_IPSEC_INVALID_PACKET => "IPsec header and/or trailer in the packet is invalid.",
            WIN32::ERROR_IPSEC_INTEGRITY_CHECK_FAILED => "IPsec integrity check failed.",
            WIN32::ERROR_IPSEC_CLEAR_TEXT_DROP => "IPsec dropped a clear text packet.",
            WIN32::ERROR_IPSEC_AUTH_FIREWALL_DROP => "IPsec dropped an incoming ESP packet in authenticated firewall mode. This drop is benign.",
            WIN32::ERROR_IPSEC_THROTTLE_DROP => "IPsec dropped a packet due to DoS throttling.",
            WIN32::ERROR_IPSEC_DOSP_BLOCK => "IPsec DoS Protection matched an explicit block rule.",
            WIN32::ERROR_IPSEC_DOSP_RECEIVED_MULTICAST => "IPsec DoS Protection received an IPsec specific multicast packet which is not allowed.",
            WIN32::ERROR_IPSEC_DOSP_INVALID_PACKET => "IPsec DoS Protection received an incorrectly formatted packet.",
            WIN32::ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED => "IPsec DoS Protection failed to look up state.",
            WIN32::ERROR_IPSEC_DOSP_MAX_ENTRIES => "IPsec DoS Protection failed to create state because the maximum number of entries allowed by policy has been reached.",
            WIN32::ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED => "IPsec DoS Protection received an IPsec negotiation packet for a keying module which is not allowed by policy.",
            WIN32::ERROR_IPSEC_DOSP_NOT_INSTALLED => "IPsec DoS Protection has not been enabled.",
            WIN32::ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES => "IPsec DoS Protection failed to create a per internal IP rate limit queue because the maximum number of queues allowed by policy has been reached.",
            WIN32::ERROR_SXS_SECTION_NOT_FOUND => "The requested section was not present in the activation context.",
            WIN32::ERROR_SXS_CANT_GEN_ACTCTX => "The application has failed to start because its side-by-side configuration is incorrect. Please see the application event log or use the command-line sxstrace.exe tool for more detail.",
            WIN32::ERROR_SXS_INVALID_ACTCTXDATA_FORMAT => "The application binding data format is invalid.",
            WIN32::ERROR_SXS_ASSEMBLY_NOT_FOUND => "The referenced assembly is not installed on your system.",
            WIN32::ERROR_SXS_MANIFEST_FORMAT_ERROR => "The manifest file does not begin with the required tag and format information.",
            WIN32::ERROR_SXS_MANIFEST_PARSE_ERROR => "The manifest file contains one or more syntax errors.",
            WIN32::ERROR_SXS_ACTIVATION_CONTEXT_DISABLED => "The application attempted to activate a disabled activation context.",
            WIN32::ERROR_SXS_KEY_NOT_FOUND => "The requested lookup key was not found in any active activation context.",
            WIN32::ERROR_SXS_VERSION_CONFLICT => "A component version required by the application conflicts with another component version already active.",
            WIN32::ERROR_SXS_WRONG_SECTION_TYPE => "The type requested activation context section does not match the query API used.",
            WIN32::ERROR_SXS_THREAD_QUERIES_DISABLED => "Lack of system resources has required isolated activation to be disabled for the current thread of execution.",
            WIN32::ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET => "An attempt to set the process default activation context failed because the process default activation context was already set.",
            WIN32::ERROR_SXS_UNKNOWN_ENCODING_GROUP => "The encoding group identifier specified is not recognized.",
            WIN32::ERROR_SXS_UNKNOWN_ENCODING => "The encoding requested is not recognized.",
            WIN32::ERROR_SXS_INVALID_XML_NAMESPACE_URI => "The manifest contains a reference to an invalid URI.",
            WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED => "The application manifest contains a reference to a dependent assembly which is not installed.",
            WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED => "The application manifest contains a reference to a dependent assembly that is not installed.",
            WIN32::ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED => "The manifest for an assembly used by the application has a reference to a dependent assembly which is not installed.",
            WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE => "The manifest contains an attribute for the assembly identity which is not valid.",
            WIN32::ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE => "The manifest is missing the required default namespace specification on the assembly element.",
            WIN32::ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE => "The manifest has a default namespace specified on the assembly element but its value is not .",
            WIN32::ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT => "The private manifest probed has crossed a path with an unsupported reparse point.",
            WIN32::ERROR_SXS_DUPLICATE_DLL_NAME => "Two or more components referenced directly or indirectly by the application manifest have files by the same name.",
            WIN32::ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME => "Two or more components referenced directly or indirectly by the application manifest have window classes with the same name.",
            WIN32::ERROR_SXS_DUPLICATE_CLSID => "Two or more components referenced directly or indirectly by the application manifest have the same COM server CLSIDs.",
            WIN32::ERROR_SXS_DUPLICATE_IID => "Two or more components referenced directly or indirectly by the application manifest have proxies for the same COM interface IIDs.",
            WIN32::ERROR_SXS_DUPLICATE_TLBID => "Two or more components referenced directly or indirectly by the application manifest have the same COM type library TLBIDs.",
            WIN32::ERROR_SXS_DUPLICATE_PROGID => "Two or more components referenced directly or indirectly by the application manifest have the same COM ProgIDs.",
            WIN32::ERROR_SXS_DUPLICATE_ASSEMBLY_NAME => "Two or more components referenced directly or indirectly by the application manifest are different versions of the same component which is not permitted.",
            WIN32::ERROR_SXS_FILE_HASH_MISMATCH => "A component's file does not match the verification information present in the component manifest.",
            WIN32::ERROR_SXS_POLICY_PARSE_ERROR => "The policy manifest contains one or more syntax errors.",
            WIN32::ERROR_SXS_XML_E_MISSINGQUOTE => "Manifest Parse Error: A string literal was expected, but no opening quote character was found.",
            WIN32::ERROR_SXS_XML_E_COMMENTSYNTAX => "Manifest Parse Error: Incorrect syntax was used in a comment.",
            WIN32::ERROR_SXS_XML_E_BADSTARTNAMECHAR => "Manifest Parse Error: A name was started with an invalid character.",
            WIN32::ERROR_SXS_XML_E_BADNAMECHAR => "Manifest Parse Error: A name contained an invalid character.",
            WIN32::ERROR_SXS_XML_E_BADCHARINSTRING => "Manifest Parse Error: A string literal contained an invalid character.",
            WIN32::ERROR_SXS_XML_E_XMLDECLSYNTAX => "Manifest Parse Error: Invalid syntax for an xml declaration.",
            WIN32::ERROR_SXS_XML_E_BADCHARDATA => "Manifest Parse Error: An Invalid character was found in text content.",
            WIN32::ERROR_SXS_XML_E_MISSINGWHITESPACE => "Manifest Parse Error: Required white space was missing.",
            WIN32::ERROR_SXS_XML_E_EXPECTINGTAGEND => "Manifest Parse Error: The character '>' was expected.",
            WIN32::ERROR_SXS_XML_E_MISSINGSEMICOLON => "Manifest Parse Error: A semi colon character was expected.",
            WIN32::ERROR_SXS_XML_E_UNBALANCEDPAREN => "Manifest Parse Error: Unbalanced parentheses.",
            WIN32::ERROR_SXS_XML_E_INTERNALERROR => "Manifest Parse Error: Internal error.",
            WIN32::ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE => "Manifest Parse Error: Whitespace is not allowed at this location.",
            WIN32::ERROR_SXS_XML_E_INCOMPLETE_ENCODING => "Manifest Parse Error: End of file reached in invalid state for current encoding.",
            WIN32::ERROR_SXS_XML_E_MISSING_PAREN => "Manifest Parse Error: Missing parenthesis.",
            WIN32::ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE => "Manifest Parse Error: A single or double closing quote character (\' or \") is missing.",
            WIN32::ERROR_SXS_XML_E_MULTIPLE_COLONS => "Manifest Parse Error: Multiple colons are not allowed in a name.",
            WIN32::ERROR_SXS_XML_E_INVALID_DECIMAL => "Manifest Parse Error: Invalid character for decimal digit.",
            WIN32::ERROR_SXS_XML_E_INVALID_HEXIDECIMAL => "Manifest Parse Error: Invalid character for hexadecimal digit.",
            WIN32::ERROR_SXS_XML_E_INVALID_UNICODE => "Manifest Parse Error: Invalid unicode character value for this platform.",
            WIN32::ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK => "Manifest Parse Error: Expecting whitespace or '?'.",
            WIN32::ERROR_SXS_XML_E_UNEXPECTEDENDTAG => "Manifest Parse Error: End tag was not expected at this location.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDTAG => "Manifest Parse Error: The following tags were not closed: %1.",
            WIN32::ERROR_SXS_XML_E_DUPLICATEATTRIBUTE => "Manifest Parse Error: Duplicate attribute.",
            WIN32::ERROR_SXS_XML_E_MULTIPLEROOTS => "Manifest Parse Error: Only one top level element is allowed in an XML document.",
            WIN32::ERROR_SXS_XML_E_INVALIDATROOTLEVEL => "Manifest Parse Error: Invalid at the top level of the document.",
            WIN32::ERROR_SXS_XML_E_BADXMLDECL => "Manifest Parse Error: Invalid xml declaration.",
            WIN32::ERROR_SXS_XML_E_MISSINGROOT => "Manifest Parse Error: XML document must have a top level element.",
            WIN32::ERROR_SXS_XML_E_UNEXPECTEDEOF => "Manifest Parse Error: Unexpected end of file.",
            WIN32::ERROR_SXS_XML_E_BADPEREFINSUBSET => "Manifest Parse Error: Parameter entities cannot be used inside markup declarations in an internal subset.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDSTARTTAG => "Manifest Parse Error: Element was not closed.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDENDTAG => "Manifest Parse Error: End element was missing the character '>'.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDSTRING => "Manifest Parse Error: A string literal was not closed.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDCOMMENT => "Manifest Parse Error: A comment was not closed.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDDECL => "Manifest Parse Error: A declaration was not closed.",
            WIN32::ERROR_SXS_XML_E_UNCLOSEDCDATA => "Manifest Parse Error: A CDATA section was not closed.",
            WIN32::ERROR_SXS_XML_E_RESERVEDNAMESPACE => "Manifest Parse Error: The namespace prefix is not allowed to start with the reserved string .",
            WIN32::ERROR_SXS_XML_E_INVALIDENCODING => "Manifest Parse Error: System does not support the specified encoding.",
            WIN32::ERROR_SXS_XML_E_INVALIDSWITCH => "Manifest Parse Error: Switch from current encoding to specified encoding not supported.",
            WIN32::ERROR_SXS_XML_E_BADXMLCASE => "Manifest Parse Error: The name 'xml' is reserved and must be lower case.",
            WIN32::ERROR_SXS_XML_E_INVALID_STANDALONE => "Manifest Parse Error: The standalone attribute must have the value 'yes' or 'no'.",
            WIN32::ERROR_SXS_XML_E_UNEXPECTED_STANDALONE => "Manifest Parse Error: The standalone attribute cannot be used in external entities.",
            WIN32::ERROR_SXS_XML_E_INVALID_VERSION => "Manifest Parse Error: Invalid version number.",
            WIN32::ERROR_SXS_XML_E_MISSINGEQUALS => "Manifest Parse Error: Missing equals sign between attribute and attribute value.",
            WIN32::ERROR_SXS_PROTECTION_RECOVERY_FAILED => "Assembly Protection Error: Unable to recover the specified assembly.",
            WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT => "Assembly Protection Error: The public key for an assembly was too short to be allowed.",
            WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT => "Assembly Protection Error: The public key for an assembly was too short to be allowed.",
            WIN32::ERROR_SXS_PROTECTION_CATALOG_NOT_VALID => "Assembly Protection Error: The catalog for an assembly is not valid, or does not match the assembly's manifest.",
            WIN32::ERROR_SXS_UNTRANSLATABLE_HRESULT => "An HRESULT could not be translated to a corresponding Win32 error code.",
            WIN32::ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING => "Assembly Protection Error: The catalog for an assembly is missing.",
            WIN32::ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE => "The supplied assembly identity is missing one or more attributes which must be present in this context.",
            WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME => "The supplied assembly identity has one or more attribute names that contain characters not permitted in XML names.",
            WIN32::ERROR_SXS_ASSEMBLY_MISSING => "The referenced assembly could not be found.",
            WIN32::ERROR_SXS_CORRUPT_ACTIVATION_STACK => "The activation context activation stack for the running thread of execution is corrupt.",
            WIN32::ERROR_SXS_CORRUPTION => "The application isolation metadata for this process or thread has become corrupt.",
            WIN32::ERROR_SXS_EARLY_DEACTIVATION => "The activation context being deactivated is not the most recently activated one.",
            WIN32::ERROR_SXS_INVALID_DEACTIVATION => "The activation context being deactivated is not active for the current thread of execution.",
            WIN32::ERROR_SXS_MULTIPLE_DEACTIVATION => "The activation context being deactivated has already been deactivated.",
            WIN32::ERROR_SXS_PROCESS_TERMINATION_REQUESTED => "A component used by the isolation facility has requested to terminate the process.",
            WIN32::ERROR_SXS_RELEASE_ACTIVATION_CONTEXT => "A kernel mode component is releasing a reference on an activation context.",
            WIN32::ERROR_SXS_RELEASE_ACTIVATION_ONTEXT => "A kernel mode component is releasing a reference on an activation context.",
            WIN32::ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY => "The activation context of system default assembly could not be generated.",
            WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE => "The value of an attribute in an identity is not within the legal range.",
            WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME => "The name of an attribute in an identity is not within the legal range.",
            WIN32::ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE => "An identity contains two definitions for the same attribute.",
            WIN32::ERROR_SXS_IDENTITY_PARSE_ERROR => "The identity string is malformed. This may be due to a trailing comma, more than two unnamed attributes, missing attribute name or missing attribute value.",
            WIN32::ERROR_MALFORMED_SUBSTITUTION_STRING => "A string containing localized substitutable content was malformed. Either a dollar sign ($) was followed by something other than a left parenthesis or another dollar sign or an substitution's right parenthesis was not found.",
            WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN => "The public key token does not correspond to the public key specified.",
            WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN => "The public key token does not correspond to the public key specified.",
            WIN32::ERROR_UNMAPPED_SUBSTITUTION_STRING => "A substitution string had no mapping.",
            WIN32::ERROR_SXS_ASSEMBLY_NOT_LOCKED => "The component must be locked before making the request.",
            WIN32::ERROR_SXS_COMPONENT_STORE_CORRUPT => "The component store has been corrupted.",
            WIN32::ERROR_ADVANCED_INSTALLER_FAILED => "An advanced installer failed during setup or servicing.",
            WIN32::ERROR_XML_ENCODING_MISMATCH => "The character encoding in the XML declaration did not match the encoding used in the document.",
            WIN32::ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT => "The identities of the manifests are identical but their contents are different.",
            WIN32::ERROR_SXS_IDENTITIES_DIFFERENT => "The component identities are different.",
            WIN32::ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT => "The assembly is not a deployment.",
            WIN32::ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY => "The file is not a part of the assembly.",
            WIN32::ERROR_SXS_MANIFEST_TOO_BIG => "The size of the manifest exceeds the maximum allowed.",
            WIN32::ERROR_SXS_SETTING_NOT_REGISTERED => "The setting is not registered.",
            WIN32::ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE => "One or more required members of the transaction are not present.",
            WIN32::ERROR_SMI_PRIMITIVE_INSTALLER_FAILED => "The SMI primitive installer failed during setup or servicing.",
            WIN32::ERROR_GENERIC_COMMAND_FAILED => "A generic command executable returned a result that indicates failure.",
            WIN32::ERROR_SXS_FILE_HASH_MISSING => "A component is missing file verification information in its manifest.",
            WIN32::ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS => "Two or more components referenced directly or indirectly by the application manifest have the same WinRT ActivatableClass IDs.",
            WIN32::ERROR_EVT_INVALID_CHANNEL_PATH => "The specified channel path is invalid.",
            WIN32::ERROR_EVT_INVALID_QUERY => "The specified query is invalid.",
            WIN32::ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND => "The publisher metadata cannot be found in the resource.",
            WIN32::ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND => "The template for an event definition cannot be found in the resource (error = %1).",
            WIN32::ERROR_EVT_INVALID_PUBLISHER_NAME => "The specified publisher name is invalid.",
            WIN32::ERROR_EVT_INVALID_EVENT_DATA => "The event data raised by the publisher is not compatible with the event template definition in the publisher's manifest.",
            WIN32::ERROR_EVT_CHANNEL_NOT_FOUND => "The specified channel could not be found.",
            WIN32::ERROR_EVT_MALFORMED_XML_TEXT => "The specified XML text was not well-formed. See Extended Error for more details.",
            WIN32::ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL => "The events for a direct channel go directly to a log file and cannot be subscribed to.",
            WIN32::ERROR_EVT_CONFIGURATION_ERROR => "Configuration error.",
            WIN32::ERROR_EVT_QUERY_RESULT_STALE => "The query result is stale or invalid and must be recreated. This may be due to the log being cleared or rolling over after the query result was created.",
            WIN32::ERROR_EVT_QUERY_RESULT_INVALID_POSITION => "The query result is currently at an invalid position.",
            WIN32::ERROR_EVT_NON_VALIDATING_MSXML => "Registered MSXML doesn't support validation.",
            WIN32::ERROR_EVT_FILTER_ALREADYSCOPED => "An expression can only be followed by a change-of-scope operation if the expression evaluates to a node set and is not already part of another change-of-scope operation.",
            WIN32::ERROR_EVT_FILTER_NOTELTSET => "Cannot perform a step operation from a term that does not represent an element set.",
            WIN32::ERROR_EVT_FILTER_INVARG => "Left-hand side arguments to binary operators must be either attributes, nodes or variables. Right-hand side arguments must be constants.",
            WIN32::ERROR_EVT_FILTER_INVTEST => "A step operation must involve a node test or, in the case of a predicate, an algebraic expression against which to test each node in the preceeding node set.",
            WIN32::ERROR_EVT_FILTER_INVTYPE => "This data type is currently unsupported.",
            WIN32::ERROR_EVT_FILTER_PARSEERR => "A syntax error occurred at position %1!d!.",
            WIN32::ERROR_EVT_FILTER_UNSUPPORTEDOP => "This operator is unsupported by this implementation of the filter.",
            WIN32::ERROR_EVT_FILTER_UNEXPECTEDTOKEN => "An unexpected token was encountered.",
            WIN32::ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL => "The requested operation cannot be performed over an enabled direct channel. The channel must first be disabled.",
            WIN32::ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE => "Channel property %1!s! contains an invalid value. The value has an invalid type, is outside of its valid range, cannot be changed, or is not supported by this type of channel.",
            WIN32::ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE => "Publisher property %1!s! contains an invalid value. The value has an invalid type, is outside of its valid range, cannot be changed, or is not supported by this type of publisher.",
            WIN32::ERROR_EVT_CHANNEL_CANNOT_ACTIVATE => "The channel failed to activate.",
            WIN32::ERROR_EVT_FILTER_TOO_COMPLEX => "The XPath expression exceeded the supported complexity. Simplify the expression or split it into multiple expressions.",
            WIN32::ERROR_EVT_MESSAGE_NOT_FOUND => "The message resource is present but the message was not found in the message table.",
            WIN32::ERROR_EVT_MESSAGE_ID_NOT_FOUND => "The message ID for the desired message could not be found.",
            WIN32::ERROR_EVT_UNRESOLVED_VALUE_INSERT => "The substitution string for insert index (%1) could not be found.",
            WIN32::ERROR_EVT_UNRESOLVED_PARAMETER_INSERT => "The description string for parameter reference (%1) could not be found.",
            WIN32::ERROR_EVT_MAX_INSERTS_REACHED => "The maximum number of replacements has been reached.",
            WIN32::ERROR_EVT_EVENT_DEFINITION_NOT_FOUND => "The event definition could not be found for event ID (%1).",
            WIN32::ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND => "The locale specific resource for the desired message is not present.",
            WIN32::ERROR_EVT_VERSION_TOO_OLD => "The resource is too old and is not supported.",
            WIN32::ERROR_EVT_VERSION_TOO_NEW => "The resource is too new and is not supported.",
            WIN32::ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY => "The channel at index %1!d! of the query can't be opened.",
            WIN32::ERROR_EVT_PUBLISHER_DISABLED => "The publisher has been disabled and its resource is not available. This usually occurs when the publisher is in the process of being uninstalled or upgraded.",
            WIN32::ERROR_EVT_FILTER_OUT_OF_RANGE => "Attempted to create a numeric type that is outside of its valid range.",
            WIN32::ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE => "The subscription fails to activate.",
            WIN32::ERROR_EC_LOG_DISABLED => "The log of the subscription is in disabled state, and can not be used to forward events to. The log must first be enabled before the subscription can be activated.",
            WIN32::ERROR_EC_CIRCULAR_FORWARDING => "When forwarding events from local machine to itself, the query of the subscription can't contain target log of the subscription.",
            WIN32::ERROR_EC_CREDSTORE_FULL => "The credential store that is used to save credentials is full.",
            WIN32::ERROR_EC_CRED_NOT_FOUND => "The credential used by this subscription can't be found in credential store.",
            WIN32::ERROR_EC_NO_ACTIVE_CHANNEL => "No active channel is found for the query.",
            WIN32::ERROR_MUI_FILE_NOT_FOUND => "The resource loader failed to find MUI file.",
            WIN32::ERROR_MUI_INVALID_FILE => "The resource loader failed to load MUI file because the file fail to pass validation.",
            WIN32::ERROR_MUI_INVALID_RC_CONFIG => "The RC Manifest is corrupted with garbage data or unsupported version or missing required item.",
            WIN32::ERROR_MUI_INVALID_LOCALE_NAME => "The RC Manifest has invalid culture name.",
            WIN32::ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME => "The RC Manifest has invalid ultimatefallback name.",
            WIN32::ERROR_MUI_FILE_NOT_LOADED => "The resource loader cache doesn't have loaded MUI entry.",
            WIN32::ERROR_RESOURCE_ENUM_USER_STOP => "User stopped resource enumeration.",
            WIN32::ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED => "UI language installation failed.",
            WIN32::ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME => "Locale installation failed.",
            WIN32::ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE => "A resource does not have default or neutral value.",
            WIN32::ERROR_MRM_INVALID_PRICONFIG => "Invalid PRI config file.",
            WIN32::ERROR_MRM_INVALID_FILE_TYPE => "Invalid file type.",
            WIN32::ERROR_MRM_UNKNOWN_QUALIFIER => "Unknown qualifier.",
            WIN32::ERROR_MRM_INVALID_QUALIFIER_VALUE => "Invalid qualifier value.",
            WIN32::ERROR_MRM_NO_CANDIDATE => "No Candidate found.",
            WIN32::ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE => "The ResourceMap or NamedResource has an item that does not have default or neutral resource.",
            WIN32::ERROR_MRM_RESOURCE_TYPE_MISMATCH => "Invalid ResourceCandidate type.",
            WIN32::ERROR_MRM_DUPLICATE_MAP_NAME => "Duplicate Resource Map.",
            WIN32::ERROR_MRM_DUPLICATE_ENTRY => "Duplicate Entry.",
            WIN32::ERROR_MRM_INVALID_RESOURCE_IDENTIFIER => "Invalid Resource Identifier.",
            WIN32::ERROR_MRM_FILEPATH_TOO_LONG => "Filepath too long.",
            WIN32::ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE => "Unsupported directory type.",
            WIN32::ERROR_MRM_INVALID_PRI_FILE => "Invalid PRI File.",
            WIN32::ERROR_MRM_NAMED_RESOURCE_NOT_FOUND => "NamedResource Not Found.",
            WIN32::ERROR_MRM_MAP_NOT_FOUND => "ResourceMap Not Found.",
            WIN32::ERROR_MRM_UNSUPPORTED_PROFILE_TYPE => "Unsupported MRT profile type.",
            WIN32::ERROR_MRM_INVALID_QUALIFIER_OPERATOR => "Invalid qualifier operator.",
            WIN32::ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE => "Unable to determine qualifier value or qualifier value has not been set.",
            WIN32::ERROR_MRM_AUTOMERGE_ENABLED => "Automerge is enabled in the PRI file.",
            WIN32::ERROR_MRM_TOO_MANY_RESOURCES => "Too many resources defined for package.",
            WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE => "Resource File can not be used for merge operation.",
            WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE => "Load/UnloadPriFiles cannot be used with resource packages.",
            WIN32::ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD => "Resource Contexts may not be created on threads that do not have a CoreWindow.",
            WIN32::ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST => "The singleton Resource Manager with different profile is already created.",
            WIN32::ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT => "The system component cannot operate given API operation.",
            WIN32::ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE => "The resource is a direct reference to a non-default resource candidate.",
            WIN32::ERROR_MRM_GENERATION_COUNT_MISMATCH => "Resource Map has been re-generated and the query string is not valid anymore.",
            WIN32::ERROR_PRI_MERGE_VERSION_MISMATCH => "The PRI files to be merged have incompatible versions.",
            WIN32::ERROR_PRI_MERGE_MISSING_SCHEMA => "The primary PRI files to be merged does not contain a schema.",
            WIN32::ERROR_PRI_MERGE_LOAD_FILE_FAILED => "Unable to load one of the PRI files to be merged.",
            WIN32::ERROR_PRI_MERGE_ADD_FILE_FAILED => "Unable to add one of the PRI files to the merged file.",
            WIN32::ERROR_PRI_MERGE_WRITE_FILE_FAILED => "Unable to create the merged PRI file.",
            WIN32::ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED => "Packages for a PRI file merge must all be from the same package family.",
            WIN32::ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED => "Packages for a PRI file merge must not include multiple main packages.",
            WIN32::ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED => "Packages for a PRI file merge must not include bundle packages.",
            WIN32::ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED => "Packages for a PRI file merge must include one main package.",
            WIN32::ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED => "Packages for a PRI file merge must include at least one resource package.",
            WIN32::ERROR_PRI_MERGE_INVALID_FILE_NAME => "Invalid name supplied for a canonical merged PRI file.",
            WIN32::ERROR_MRM_PACKAGE_NOT_FOUND => "Unable to find the specified package.",
            WIN32::ERROR_MRM_MISSING_DEFAULT_LANGUAGE => "No default value for language was specified.",
            WIN32::ERROR_MRM_SCOPE_ITEM_CONFLICT => "An entity was defined as both resource and scope, which is not allowed.",
            WIN32::ERROR_MCA_INVALID_CAPABILITIES_STRING => "The monitor returned a DDC/CI capabilities string that did not comply with the ACCESS.bus 3.0, DDC/CI 1.1 or MCCS 2 Revision 1 specification.",
            WIN32::ERROR_MCA_INVALID_VCP_VERSION => "The monitor's VCP Version (0xDF) VCP code returned an invalid version value.",
            WIN32::ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION => "The monitor does not comply with the MCCS specification it claims to support.",
            WIN32::ERROR_MCA_MCCS_VERSION_MISMATCH => "The MCCS version in a monitor's mccs_ver capability does not match the MCCS version the monitor reports when the VCP Version (0xDF) VCP code is used.",
            WIN32::ERROR_MCA_UNSUPPORTED_MCCS_VERSION => "The Monitor Configuration API only works with monitors that support the MCCS 1.0 specification, MCCS 2.0 specification or the MCCS 2.0 Revision 1 specification.",
            WIN32::ERROR_MCA_INTERNAL_ERROR => "An internal Monitor Configuration API error occurred.",
            WIN32::ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED => "The monitor returned an invalid monitor technology type. CRT, Plasma and LCD (TFT) are examples of monitor technology types. This error implies that the monitor violated the MCCS 2.0 or MCCS 2.0 Revision 1 specification.",
            WIN32::ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE => "The caller of SetMonitorColorTemperature specified a color temperature that the current monitor did not support. This error implies that the monitor violated the MCCS 2.0 or MCCS 2.0 Revision 1 specification.",
            WIN32::ERROR_AMBIGUOUS_SYSTEM_DEVICE => "The requested system device cannot be identified due to multiple indistinguishable devices potentially matching the identification criteria.",
            WIN32::ERROR_SYSTEM_DEVICE_NOT_FOUND => "The requested system device cannot be found.",
            WIN32::ERROR_HASH_NOT_SUPPORTED => "Hash generation for the specified hash version and hash type is not enabled on the server.",
            WIN32::ERROR_HASH_NOT_PRESENT => "The hash requested from the server is not available or no longer valid.",
            WIN32::ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED => "The secondary interrupt controller instance that manages the specified interrupt is not registered.",
            WIN32::ERROR_GPIO_CLIENT_INFORMATION_INVALID => "The information supplied by the GPIO client driver is invalid.",
            WIN32::ERROR_GPIO_VERSION_NOT_SUPPORTED => "The version specified by the GPIO client driver is not supported.",
            WIN32::ERROR_GPIO_INVALID_REGISTRATION_PACKET => "The registration packet supplied by the GPIO client driver is not valid.",
            WIN32::ERROR_GPIO_OPERATION_DENIED => "The requested operation is not supported for the specified handle.",
            WIN32::ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE => "The requested connect mode conflicts with an existing mode on one or more of the specified pins.",
            WIN32::ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED => "The interrupt requested to be unmasked is not masked.",
            WIN32::ERROR_CANNOT_SWITCH_RUNLEVEL => "The requested run level switch cannot be completed successfully.",
            WIN32::ERROR_INVALID_RUNLEVEL_SETTING => "The service has an invalid run level setting. The run level for a service.",
            WIN32::ERROR_RUNLEVEL_SWITCH_TIMEOUT => "The requested run level switch cannot be completed successfully since.",
            WIN32::ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT => "A run level switch agent did not respond within the specified timeout.",
            WIN32::ERROR_RUNLEVEL_SWITCH_IN_PROGRESS => "A run level switch is currently in progress.",
            WIN32::ERROR_SERVICES_FAILED_AUTOSTART => "One or more services failed to start during the service startup phase of a run level switch.",
            WIN32::ERROR_COM_TASK_STOP_PENDING => "The task stop request cannot be completed immediately since.",
            WIN32::ERROR_INSTALL_OPEN_PACKAGE_FAILED => "Package could not be opened.",
            WIN32::ERROR_INSTALL_PACKAGE_NOT_FOUND => "Package was not found.",
            WIN32::ERROR_INSTALL_INVALID_PACKAGE => "Package data is invalid.",
            WIN32::ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED => "Package failed updates, dependency or conflict validation.",
            WIN32::ERROR_INSTALL_OUT_OF_DISK_SPACE => "There is not enough disk space on your computer. Please free up some space and try again.",
            WIN32::ERROR_INSTALL_NETWORK_FAILURE => "There was a problem downloading your product.",
            WIN32::ERROR_INSTALL_REGISTRATION_FAILURE => "Package could not be registered.",
            WIN32::ERROR_INSTALL_DEREGISTRATION_FAILURE => "Package could not be unregistered.",
            WIN32::ERROR_INSTALL_CANCEL => "User cancelled the install request.",
            WIN32::ERROR_INSTALL_FAILED => "Install failed. Please contact your software vendor.",
            WIN32::ERROR_REMOVE_FAILED => "Removal failed. Please contact your software vendor.",
            WIN32::ERROR_PACKAGE_ALREADY_EXISTS => "The provided package is already installed, and reinstallation of the package was blocked. Check the AppXDeployment-Server event log for details.",
            WIN32::ERROR_NEEDS_REMEDIATION => "The application cannot be started. Try reinstalling the application to fix the problem.",
            WIN32::ERROR_INSTALL_PREREQUISITE_FAILED => "A Prerequisite for an install could not be satisfied.",
            WIN32::ERROR_PACKAGE_REPOSITORY_CORRUPTED => "The package repository is corrupted.",
            WIN32::ERROR_INSTALL_POLICY_FAILURE => "To install this application you need either a Windows developer license or a sideloading-enabled system.",
            WIN32::ERROR_PACKAGE_UPDATING => "The application cannot be started because it is currently updating.",
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_POLICY => "The package deployment operation is blocked by policy. Please contact your system administrator.",
            WIN32::ERROR_PACKAGES_IN_USE => "The package could not be installed because resources it modifies are currently in use.",
            WIN32::ERROR_RECOVERY_FILE_CORRUPT => "The package could not be recovered because necessary data for recovery have been corrupted.",
            WIN32::ERROR_INVALID_STAGED_SIGNATURE => "The signature is invalid. To register in developer mode, AppxSignature.p7x and AppxBlockMap.xml must be valid or should not be present.",
            WIN32::ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED => "An error occurred while deleting the package's previously existing application data.",
            WIN32::ERROR_INSTALL_PACKAGE_DOWNGRADE => "The package could not be installed because a higher version of this package is already installed.",
            WIN32::ERROR_SYSTEM_NEEDS_REMEDIATION => "An error in a system binary was detected. Try refreshing the PC to fix the problem.",
            WIN32::ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN => "A corrupted CLR NGEN binary was detected on the system.",
            WIN32::ERROR_RESILIENCY_FILE_CORRUPT => "The operation could not be resumed because necessary data for recovery have been corrupted.",
            WIN32::ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING => "The package could not be installed because the Windows Firewall service is not running. Enable the Windows Firewall service and try again.",
            WIN32::ERROR_PACKAGE_MOVE_FAILED => "Package move failed.",
            WIN32::ERROR_INSTALL_VOLUME_NOT_EMPTY => "The deployment operation failed because the volume is not empty.",
            WIN32::ERROR_INSTALL_VOLUME_OFFLINE => "The deployment operation failed because the volume is offline. For a package update, the volume refers to the installed volume of all package versions.",
            WIN32::ERROR_INSTALL_VOLUME_CORRUPT => "The deployment operation failed because the specified volume is corrupt.",
            WIN32::ERROR_NEEDS_REGISTRATION => "The deployment operation failed because the specified application needs to be registered first.",
            WIN32::ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE => "The deployment operation failed because the package targets the wrong processor architecture.",
            WIN32::ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED => "You have reached the maximum number of developer sideloaded packages allowed on this device. Please uninstall a sideloaded package and try again.",
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE => "A main app package is required to install this optional package. Install the main package first and try again.",
            WIN32::ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM => "This app package type is not supported on this filesystem.",
            WIN32::ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING => "Package move operation is blocked until the application has finished streaming.",
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE => "A main or another optional app package has the same application ID as this optional package. Change the application ID for the optional package to avoid conflicts.",
            WIN32::ERROR_PACKAGE_STAGING_ONHOLD => "This staging session has been held to allow another staging operation to be prioritized.",
            WIN32::ERROR_INSTALL_INVALID_RELATED_SET_UPDATE => "A related set cannot be updated because the updated set is invalid. All packages in the related set must be updated at the same time.",
            WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY => "An optional package with a FullTrust entry point requires the main package to have the runFullTrust capability.",
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF => "An error occurred because a user was logged off.",
            WIN32::ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED => "An optional package provision requires the dependency main package to also be provisioned.",
            WIN32::ERROR_PACKAGES_REPUTATION_CHECK_FAILED => "The packages failed the SmartScreen reputation check.",
            WIN32::ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT => "The SmartScreen reputation check operation timed out.",
            WIN32::ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED => "The current deployment option is not supported.",
            WIN32::ERROR_APPINSTALLER_ACTIVATION_BLOCKED => "Activation is blocked due to the .appinstaller update settings for this app.",
            WIN32::ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED => "Remote drives are not supported; use \\\\server\\share to register a remote package.",
            WIN32::ERROR_APPX_RAW_DATA_WRITE_FAILED => "Failed to process and write downloaded APPX package data to disk.",
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE => "The deployment operation was blocked due to a per-package-family policy restricting deployments on a non-system volume. Per policy, this app must be installed to the system drive, but that's not set as the default. In Storage Settings, make the system drive the default location to save new content, then retry the install.",
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE => "The deployment operation was blocked due to a machine-wide policy restricting deployments on a non-system volume. Per policy, this app must be installed to the system drive, but that's not set as the default. In Storage Settings, make the system drive the default location to save new content, then retry the install.",
            WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY => "The deployment operation was blocked because Special profile deployment is not allowed. Please try logging into an account that is not a Special profile. You can try logging out and logging back into the current account, or try logging into a different account.",
            WIN32::ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY => "The deployment operation failed due to a conflicting package's mutable package directory. To install this package remove the existing package with the conflicting mutable package directory.",
            WIN32::ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER => "The package installation failed because a singleton resource was specified and another user with that package installed is logged in. Please make sure that all active users with the package installed are logged out and retry installation.",
            WIN32::ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED => "The package installation failed because a different version of the service is installed. Try installing a newer version of the package.",
            WIN32::ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE => "The package installation failed because a version of the service exists outside of APPX packaging. Please contact your software vendor.",
            WIN32::ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES => "The package installation failed because administrator privileges are required. Please contact an administrator to install this package.",
            WIN32::ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED => "The package deployment failed because the operation would have redirected to default account, when the caller said not to do so.",
            WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST => "The package deployment failed because the package requires a capability to natively target this host.",
            WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT => "The package deployment failed because its content is not valid for an unsigned package.",
            WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE => "The package deployment failed because its publisher is not in the unsigned namespace.",
            WIN32::ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE => "The package deployment failed because its publisher is not in the signed namespace.",
            WIN32::ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED => "The package deployment failed because it must allow external content to be deployed with an external location.",
            WIN32::ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY => "A host runtime dependency resolving to a package with full trust content requires the main package to have the runFullTrust capability.",
            WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS => "The package deployment failed because the package requires a capability for mandatory startup tasks.",
            WIN32::ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED => "Package failed host runtime dependency or conflict validation.",
            WIN32::ERROR_MACHINE_SCOPE_NOT_ALLOWED => "The package deployment failed because it uses a machine scope but doesn't have the required capability.",
            WIN32::ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED => "The package deployment failed because it uses classic compatmode but doesn't have the required capability.",
            WIN32::ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE => "AppxUpdateAgent attempted to stage a package that is not applicable.",
            WIN32::ERROR_PACKAGE_NOT_REGISTERED_FOR_USER => "The application cannot be started for the target user. Please have the user explicitly install this package.",
            WIN32::ERROR_PACKAGE_NAME_MISMATCH => "The provided package name does not match the expected package name. Check the AppXDeployment-Server event log for details.",
            WIN32::ERROR_APPINSTALLER_URI_IN_USE => "The provided .appinstaller URI is already being used by another package family. Check the AppXDeployment-Server event log for details.",
            WIN32::ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM => "The package family's auto update settings are being managed at system priority and cannot be changed at default priority. Please contact your system administrator for help with the error.",
            WIN32::APPMODEL_ERROR_NO_PACKAGE => "The process has no package identity.",
            WIN32::APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT => "The package runtime information is corrupted.",
            WIN32::APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT => "The package identity is corrupted.",
            WIN32::APPMODEL_ERROR_NO_APPLICATION => "The process has no application identity.",
            WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED => "One or more AppModel Runtime group policy values could not be read. Please contact your system administrator with the contents of your AppModel Runtime event log.",
            WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID => "One or more AppModel Runtime group policy values are invalid. Please contact your system administrator with the contents of your AppModel Runtime event log.",
            WIN32::APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE => "The package is currently not available.",
            WIN32::APPMODEL_ERROR_NO_MUTABLE_DIRECTORY => "The package does not have a mutable directory.",
            WIN32::ERROR_STATE_LOAD_STORE_FAILED => "Loading the state store failed.",
            WIN32::ERROR_STATE_GET_VERSION_FAILED => "Retrieving the state version for the application failed.",
            WIN32::ERROR_STATE_SET_VERSION_FAILED => "Setting the state version for the application failed.",
            WIN32::ERROR_STATE_STRUCTURED_RESET_FAILED => "Resetting the structured state of the application failed.",
            WIN32::ERROR_STATE_OPEN_CONTAINER_FAILED => "State Manager failed to open the container.",
            WIN32::ERROR_STATE_CREATE_CONTAINER_FAILED => "State Manager failed to create the container.",
            WIN32::ERROR_STATE_DELETE_CONTAINER_FAILED => "State Manager failed to delete the container.",
            WIN32::ERROR_STATE_READ_SETTING_FAILED => "State Manager failed to read the setting.",
            WIN32::ERROR_STATE_WRITE_SETTING_FAILED => "State Manager failed to write the setting.",
            WIN32::ERROR_STATE_DELETE_SETTING_FAILED => "State Manager failed to delete the setting.",
            WIN32::ERROR_STATE_QUERY_SETTING_FAILED => "State Manager failed to query the setting.",
            WIN32::ERROR_STATE_READ_COMPOSITE_SETTING_FAILED => "State Manager failed to read the composite setting.",
            WIN32::ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED => "State Manager failed to write the composite setting.",
            WIN32::ERROR_STATE_ENUMERATE_CONTAINER_FAILED => "State Manager failed to enumerate the containers.",
            WIN32::ERROR_STATE_ENUMERATE_SETTINGS_FAILED => "State Manager failed to enumerate the settings.",
            WIN32::ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED => "The size of the state manager composite setting value has exceeded the limit.",
            WIN32::ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED => "The size of the state manager setting value has exceeded the limit.",
            WIN32::ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED => "The length of the state manager setting name has exceeded the limit.",
            WIN32::ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED => "The length of the state manager container name has exceeded the limit.",
            WIN32::ERROR_API_UNAVAILABLE => "This API cannot be used in the context of the caller's application type.",
            WIN32::STORE_ERROR_UNLICENSED => "This PC does not have a valid license for the application or product.",
            WIN32::STORE_ERROR_UNLICENSED_USER => "The authenticated user does not have a valid license for the application or product.",
            WIN32::STORE_ERROR_PENDING_COM_TRANSACTION => "The commerce transaction associated with this license is still pending verification.",
            WIN32::STORE_ERROR_LICENSE_REVOKED => "The license has been revoked for this user.",
            WIN32::ERROR_SUCCESS => "The operation completed successfully.",
        }
    }

    pub fn from_name(name: &str) -> WIN32 {
        return match name {
            "ERROR_INVALID_FUNCTION" => WIN32::ERROR_INVALID_FUNCTION,
            "PDH_CSTATUS_NEW_DATA" => WIN32::PDH_CSTATUS_NEW_DATA,
            "ERROR_FILE_NOT_FOUND" => WIN32::ERROR_FILE_NOT_FOUND,
            "ERROR_PATH_NOT_FOUND" => WIN32::ERROR_PATH_NOT_FOUND,
            "E_PATH_NOT_FOUND" => WIN32::E_PATH_NOT_FOUND,
            "ERROR_TOO_MANY_OPEN_FILES" => WIN32::ERROR_TOO_MANY_OPEN_FILES,
            "ERROR_ACCESS_DENIED" => WIN32::ERROR_ACCESS_DENIED,
            "E_ACCESSDENIED" => WIN32::E_ACCESSDENIED,
            "ERROR_INVALID_HANDLE" => WIN32::ERROR_INVALID_HANDLE,
            "E_HANDLE" => WIN32::E_HANDLE,
            "ERROR_ARENA_TRASHED" => WIN32::ERROR_ARENA_TRASHED,
            "ERROR_NOT_ENOUGH_MEMORY" => WIN32::ERROR_NOT_ENOUGH_MEMORY,
            "ERROR_INVALID_BLOCK" => WIN32::ERROR_INVALID_BLOCK,
            "ERROR_BAD_ENVIRONMENT" => WIN32::ERROR_BAD_ENVIRONMENT,
            "ERROR_BAD_FORMAT" => WIN32::ERROR_BAD_FORMAT,
            "ERROR_INVALID_ACCESS" => WIN32::ERROR_INVALID_ACCESS,
            "ERROR_INVALID_DATA" => WIN32::ERROR_INVALID_DATA,
            "E_OUTOFMEMORY" => WIN32::E_OUTOFMEMORY,
            "ERROR_OUTOFMEMORY" => WIN32::ERROR_OUTOFMEMORY,
            "DDERR_OUTOFMEMORY" => WIN32::DDERR_OUTOFMEMORY,
            "ERROR_INVALID_DRIVE" => WIN32::ERROR_INVALID_DRIVE,
            "ERROR_CURRENT_DIRECTORY" => WIN32::ERROR_CURRENT_DIRECTORY,
            "ERROR_NOT_SAME_DEVICE" => WIN32::ERROR_NOT_SAME_DEVICE,
            "ERROR_NO_MORE_FILES" => WIN32::ERROR_NO_MORE_FILES,
            "ERROR_WRITE_PROTECT" => WIN32::ERROR_WRITE_PROTECT,
            "ERROR_BAD_UNIT" => WIN32::ERROR_BAD_UNIT,
            "ERROR_NOT_READY" => WIN32::ERROR_NOT_READY,
            "ERROR_BAD_COMMAND" => WIN32::ERROR_BAD_COMMAND,
            "ERROR_CRC" => WIN32::ERROR_CRC,
            "ERROR_BAD_LENGTH" => WIN32::ERROR_BAD_LENGTH,
            "ERROR_SEEK" => WIN32::ERROR_SEEK,
            "ERROR_NOT_DOS_DISK" => WIN32::ERROR_NOT_DOS_DISK,
            "ERROR_SECTOR_NOT_FOUND" => WIN32::ERROR_SECTOR_NOT_FOUND,
            "ERROR_OUT_OF_PAPER" => WIN32::ERROR_OUT_OF_PAPER,
            "ERROR_WRITE_FAULT" => WIN32::ERROR_WRITE_FAULT,
            "ERROR_READ_FAULT" => WIN32::ERROR_READ_FAULT,
            "ERROR_GEN_FAILURE" => WIN32::ERROR_GEN_FAILURE,
            "ERROR_SHARING_VIOLATION" => WIN32::ERROR_SHARING_VIOLATION,
            "E_SHARING_VIOLATION" => WIN32::E_SHARING_VIOLATION,
            "ERROR_LOCK_VIOLATION" => WIN32::ERROR_LOCK_VIOLATION,
            "ERROR_WRONG_DISK" => WIN32::ERROR_WRONG_DISK,
            "ERROR_SHARING_BUFFER_EXCEEDED" => WIN32::ERROR_SHARING_BUFFER_EXCEEDED,
            "ERROR_HANDLE_EOF" => WIN32::ERROR_HANDLE_EOF,
            "ERROR_HANDLE_DISK_FULL" => WIN32::ERROR_HANDLE_DISK_FULL,
            "ERROR_NOT_SUPPORTED" => WIN32::ERROR_NOT_SUPPORTED,
            "ERROR_REM_NOT_LIST" => WIN32::ERROR_REM_NOT_LIST,
            "ERROR_DUP_NAME" => WIN32::ERROR_DUP_NAME,
            "ERROR_BAD_NETPATH" => WIN32::ERROR_BAD_NETPATH,
            "ERROR_NETWORK_BUSY" => WIN32::ERROR_NETWORK_BUSY,
            "ERROR_DEV_NOT_EXIST" => WIN32::ERROR_DEV_NOT_EXIST,
            "ERROR_TOO_MANY_CMDS" => WIN32::ERROR_TOO_MANY_CMDS,
            "ERROR_ADAP_HDW_ERR" => WIN32::ERROR_ADAP_HDW_ERR,
            "ERROR_BAD_NET_RESP" => WIN32::ERROR_BAD_NET_RESP,
            "ERROR_UNEXP_NET_ERR" => WIN32::ERROR_UNEXP_NET_ERR,
            "ERROR_BAD_REM_ADAP" => WIN32::ERROR_BAD_REM_ADAP,
            "ERROR_PRINTQ_FULL" => WIN32::ERROR_PRINTQ_FULL,
            "ERROR_NO_SPOOL_SPACE" => WIN32::ERROR_NO_SPOOL_SPACE,
            "ERROR_PRINT_CANCELLED" => WIN32::ERROR_PRINT_CANCELLED,
            "ERROR_NETNAME_DELETED" => WIN32::ERROR_NETNAME_DELETED,
            "ERROR_NETWORK_ACCESS_DENIED" => WIN32::ERROR_NETWORK_ACCESS_DENIED,
            "ERROR_BAD_DEV_TYPE" => WIN32::ERROR_BAD_DEV_TYPE,
            "ERROR_BAD_NET_NAME" => WIN32::ERROR_BAD_NET_NAME,
            "ERROR_TOO_MANY_NAMES" => WIN32::ERROR_TOO_MANY_NAMES,
            "ERROR_TOO_MANY_SESS" => WIN32::ERROR_TOO_MANY_SESS,
            "ERROR_SHARING_PAUSED" => WIN32::ERROR_SHARING_PAUSED,
            "ERROR_REQ_NOT_ACCEP" => WIN32::ERROR_REQ_NOT_ACCEP,
            "ERROR_REDIR_PAUSED" => WIN32::ERROR_REDIR_PAUSED,
            "ERROR_FILE_EXISTS" => WIN32::ERROR_FILE_EXISTS,
            "ERROR_CANNOT_MAKE" => WIN32::ERROR_CANNOT_MAKE,
            "ERROR_FAIL_I24" => WIN32::ERROR_FAIL_I24,
            "ERROR_OUT_OF_STRUCTURES" => WIN32::ERROR_OUT_OF_STRUCTURES,
            "ERROR_ALREADY_ASSIGNED" => WIN32::ERROR_ALREADY_ASSIGNED,
            "ERROR_INVALID_PASSWORD" => WIN32::ERROR_INVALID_PASSWORD,
            "ERROR_INVALID_PARAMETER" => WIN32::ERROR_INVALID_PARAMETER,
            "E_INVALIDARG" => WIN32::E_INVALIDARG,
            "DDERR_INVALIDPARAMS" => WIN32::DDERR_INVALIDPARAMS,
            "ERROR_NET_WRITE_FAULT" => WIN32::ERROR_NET_WRITE_FAULT,
            "ERROR_NO_PROC_SLOTS" => WIN32::ERROR_NO_PROC_SLOTS,
            "ERROR_TOO_MANY_SEMAPHORES" => WIN32::ERROR_TOO_MANY_SEMAPHORES,
            "ERROR_EXCL_SEM_ALREADY_OWNED" => WIN32::ERROR_EXCL_SEM_ALREADY_OWNED,
            "ERROR_SEM_IS_SET" => WIN32::ERROR_SEM_IS_SET,
            "ERROR_TOO_MANY_SEM_REQUESTS" => WIN32::ERROR_TOO_MANY_SEM_REQUESTS,
            "ERROR_INVALID_AT_INTERRUPT_TIME" => WIN32::ERROR_INVALID_AT_INTERRUPT_TIME,
            "ERROR_SEM_OWNER_DIED" => WIN32::ERROR_SEM_OWNER_DIED,
            "ERROR_SEM_USER_LIMIT" => WIN32::ERROR_SEM_USER_LIMIT,
            "ERROR_DISK_CHANGE" => WIN32::ERROR_DISK_CHANGE,
            "ERROR_DRIVE_LOCKED" => WIN32::ERROR_DRIVE_LOCKED,
            "ERROR_BROKEN_PIPE" => WIN32::ERROR_BROKEN_PIPE,
            "ERROR_OPEN_FAILED" => WIN32::ERROR_OPEN_FAILED,
            "ERROR_BUFFER_OVERFLOW" => WIN32::ERROR_BUFFER_OVERFLOW,
            "ERROR_DISK_FULL" => WIN32::ERROR_DISK_FULL,
            "ERROR_NO_MORE_SEARCH_HANDLES" => WIN32::ERROR_NO_MORE_SEARCH_HANDLES,
            "ERROR_INVALID_TARGET_HANDLE" => WIN32::ERROR_INVALID_TARGET_HANDLE,
            "ERROR_INVALID_CATEGORY" => WIN32::ERROR_INVALID_CATEGORY,
            "ERROR_INVALID_VERIFY_SWITCH" => WIN32::ERROR_INVALID_VERIFY_SWITCH,
            "ERROR_BAD_DRIVER_LEVEL" => WIN32::ERROR_BAD_DRIVER_LEVEL,
            "ERROR_CALL_NOT_IMPLEMENTED" => WIN32::ERROR_CALL_NOT_IMPLEMENTED,
            "ERROR_SEM_TIMEOUT" => WIN32::ERROR_SEM_TIMEOUT,
            "ERROR_INSUFFICIENT_BUFFER" => WIN32::ERROR_INSUFFICIENT_BUFFER,
            "ERROR_INVALID_NAME" => WIN32::ERROR_INVALID_NAME,
            "ERROR_INVALID_LEVEL" => WIN32::ERROR_INVALID_LEVEL,
            "ERROR_NO_VOLUME_LABEL" => WIN32::ERROR_NO_VOLUME_LABEL,
            "ERROR_MOD_NOT_FOUND" => WIN32::ERROR_MOD_NOT_FOUND,
            "ERROR_PROC_NOT_FOUND" => WIN32::ERROR_PROC_NOT_FOUND,
            "ERROR_WAIT_NO_CHILDREN" => WIN32::ERROR_WAIT_NO_CHILDREN,
            "ERROR_CHILD_NOT_COMPLETE" => WIN32::ERROR_CHILD_NOT_COMPLETE,
            "ERROR_DIRECT_ACCESS_HANDLE" => WIN32::ERROR_DIRECT_ACCESS_HANDLE,
            "ERROR_NEGATIVE_SEEK" => WIN32::ERROR_NEGATIVE_SEEK,
            "ERROR_SEEK_ON_DEVICE" => WIN32::ERROR_SEEK_ON_DEVICE,
            "ERROR_IS_JOIN_TARGET" => WIN32::ERROR_IS_JOIN_TARGET,
            "ERROR_IS_JOINED" => WIN32::ERROR_IS_JOINED,
            "ERROR_IS_SUBSTED" => WIN32::ERROR_IS_SUBSTED,
            "ERROR_NOT_JOINED" => WIN32::ERROR_NOT_JOINED,
            "ERROR_NOT_SUBSTED" => WIN32::ERROR_NOT_SUBSTED,
            "ERROR_JOIN_TO_JOIN" => WIN32::ERROR_JOIN_TO_JOIN,
            "ERROR_SUBST_TO_SUBST" => WIN32::ERROR_SUBST_TO_SUBST,
            "ERROR_JOIN_TO_SUBST" => WIN32::ERROR_JOIN_TO_SUBST,
            "ERROR_SUBST_TO_JOIN" => WIN32::ERROR_SUBST_TO_JOIN,
            "ERROR_BUSY_DRIVE" => WIN32::ERROR_BUSY_DRIVE,
            "ERROR_SAME_DRIVE" => WIN32::ERROR_SAME_DRIVE,
            "ERROR_DIR_NOT_ROOT" => WIN32::ERROR_DIR_NOT_ROOT,
            "ERROR_DIR_NOT_EMPTY" => WIN32::ERROR_DIR_NOT_EMPTY,
            "ERROR_IS_SUBST_PATH" => WIN32::ERROR_IS_SUBST_PATH,
            "ERROR_IS_JOIN_PATH" => WIN32::ERROR_IS_JOIN_PATH,
            "ERROR_PATH_BUSY" => WIN32::ERROR_PATH_BUSY,
            "ERROR_IS_SUBST_TARGET" => WIN32::ERROR_IS_SUBST_TARGET,
            "ERROR_SYSTEM_TRACE" => WIN32::ERROR_SYSTEM_TRACE,
            "ERROR_INVALID_EVENT_COUNT" => WIN32::ERROR_INVALID_EVENT_COUNT,
            "ERROR_TOO_MANY_MUXWAITERS" => WIN32::ERROR_TOO_MANY_MUXWAITERS,
            "ERROR_INVALID_LIST_FORMAT" => WIN32::ERROR_INVALID_LIST_FORMAT,
            "ERROR_LABEL_TOO_LONG" => WIN32::ERROR_LABEL_TOO_LONG,
            "ERROR_TOO_MANY_TCBS" => WIN32::ERROR_TOO_MANY_TCBS,
            "ERROR_SIGNAL_REFUSED" => WIN32::ERROR_SIGNAL_REFUSED,
            "ERROR_DISCARDED" => WIN32::ERROR_DISCARDED,
            "ERROR_NOT_LOCKED" => WIN32::ERROR_NOT_LOCKED,
            "ERROR_BAD_THREADID_ADDR" => WIN32::ERROR_BAD_THREADID_ADDR,
            "ERROR_BAD_ARGUMENTS" => WIN32::ERROR_BAD_ARGUMENTS,
            "ERROR_BAD_PATHNAME" => WIN32::ERROR_BAD_PATHNAME,
            "ERROR_SIGNAL_PENDING" => WIN32::ERROR_SIGNAL_PENDING,
            "ERROR_MAX_THRDS_REACHED" => WIN32::ERROR_MAX_THRDS_REACHED,
            "ERROR_LOCK_FAILED" => WIN32::ERROR_LOCK_FAILED,
            "ERROR_BUSY" => WIN32::ERROR_BUSY,
            "ERROR_DEVICE_SUPPORT_IN_PROGRESS" => WIN32::ERROR_DEVICE_SUPPORT_IN_PROGRESS,
            "ERROR_CANCEL_VIOLATION" => WIN32::ERROR_CANCEL_VIOLATION,
            "ERROR_ATOMIC_LOCKS_NOT_SUPPORTED" => WIN32::ERROR_ATOMIC_LOCKS_NOT_SUPPORTED,
            "ERROR_INVALID_SEGMENT_NUMBER" => WIN32::ERROR_INVALID_SEGMENT_NUMBER,
            "ERROR_INVALID_ORDINAL" => WIN32::ERROR_INVALID_ORDINAL,
            "ERROR_ALREADY_EXISTS" => WIN32::ERROR_ALREADY_EXISTS,
            "ERROR_INVALID_FLAG_NUMBER" => WIN32::ERROR_INVALID_FLAG_NUMBER,
            "ERROR_SEM_NOT_FOUND" => WIN32::ERROR_SEM_NOT_FOUND,
            "ERROR_INVALID_STARTING_CODESEG" => WIN32::ERROR_INVALID_STARTING_CODESEG,
            "ERROR_INVALID_STACKSEG" => WIN32::ERROR_INVALID_STACKSEG,
            "ERROR_INVALID_MODULETYPE" => WIN32::ERROR_INVALID_MODULETYPE,
            "ERROR_INVALID_EXE_SIGNATURE" => WIN32::ERROR_INVALID_EXE_SIGNATURE,
            "ERROR_EXE_MARKED_INVALID" => WIN32::ERROR_EXE_MARKED_INVALID,
            "ERROR_BAD_EXE_FORMAT" => WIN32::ERROR_BAD_EXE_FORMAT,
            "ERROR_ITERATED_DATA_EXCEEDS_64k" => WIN32::ERROR_ITERATED_DATA_EXCEEDS_64k,
            "ERROR_INVALID_MINALLOCSIZE" => WIN32::ERROR_INVALID_MINALLOCSIZE,
            "ERROR_DYNLINK_FROM_INVALID_RING" => WIN32::ERROR_DYNLINK_FROM_INVALID_RING,
            "ERROR_IOPL_NOT_ENABLED" => WIN32::ERROR_IOPL_NOT_ENABLED,
            "ERROR_INVALID_SEGDPL" => WIN32::ERROR_INVALID_SEGDPL,
            "ERROR_AUTODATASEG_EXCEEDS_64k" => WIN32::ERROR_AUTODATASEG_EXCEEDS_64k,
            "ERROR_RING2SEG_MUST_BE_MOVABLE" => WIN32::ERROR_RING2SEG_MUST_BE_MOVABLE,
            "ERROR_RELOC_CHAIN_XEEDS_SEGLIM" => WIN32::ERROR_RELOC_CHAIN_XEEDS_SEGLIM,
            "ERROR_INFLOOP_IN_RELOC_CHAIN" => WIN32::ERROR_INFLOOP_IN_RELOC_CHAIN,
            "ERROR_ENVVAR_NOT_FOUND" => WIN32::ERROR_ENVVAR_NOT_FOUND,
            "ERROR_NO_SIGNAL_SENT" => WIN32::ERROR_NO_SIGNAL_SENT,
            "ERROR_FILENAME_EXCED_RANGE" => WIN32::ERROR_FILENAME_EXCED_RANGE,
            "ERROR_RING2_STACK_IN_USE" => WIN32::ERROR_RING2_STACK_IN_USE,
            "ERROR_META_EXPANSION_TOO_LONG" => WIN32::ERROR_META_EXPANSION_TOO_LONG,
            "ERROR_INVALID_SIGNAL_NUMBER" => WIN32::ERROR_INVALID_SIGNAL_NUMBER,
            "ERROR_THREAD_1_INACTIVE" => WIN32::ERROR_THREAD_1_INACTIVE,
            "ERROR_LOCKED" => WIN32::ERROR_LOCKED,
            "ERROR_TOO_MANY_MODULES" => WIN32::ERROR_TOO_MANY_MODULES,
            "ERROR_NESTING_NOT_ALLOWED" => WIN32::ERROR_NESTING_NOT_ALLOWED,
            "ERROR_EXE_MACHINE_TYPE_MISMATCH" => WIN32::ERROR_EXE_MACHINE_TYPE_MISMATCH,
            "ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY" => WIN32::ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY,
            "ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY" => WIN32::ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY,
            "ERROR_FILE_CHECKED_OUT" => WIN32::ERROR_FILE_CHECKED_OUT,
            "ERROR_CHECKOUT_REQUIRED" => WIN32::ERROR_CHECKOUT_REQUIRED,
            "ERROR_BAD_FILE_TYPE" => WIN32::ERROR_BAD_FILE_TYPE,
            "ERROR_FILE_TOO_LARGE" => WIN32::ERROR_FILE_TOO_LARGE,
            "ERROR_FORMS_AUTH_REQUIRED" => WIN32::ERROR_FORMS_AUTH_REQUIRED,
            "ERROR_VIRUS_INFECTED" => WIN32::ERROR_VIRUS_INFECTED,
            "ERROR_VIRUS_DELETED" => WIN32::ERROR_VIRUS_DELETED,
            "ERROR_PIPE_LOCAL" => WIN32::ERROR_PIPE_LOCAL,
            "ERROR_BAD_PIPE" => WIN32::ERROR_BAD_PIPE,
            "ERROR_PIPE_BUSY" => WIN32::ERROR_PIPE_BUSY,
            "ERROR_NO_DATA" => WIN32::ERROR_NO_DATA,
            "ERROR_PIPE_NOT_CONNECTED" => WIN32::ERROR_PIPE_NOT_CONNECTED,
            "ERROR_MORE_DATA" => WIN32::ERROR_MORE_DATA,
            "ERROR_NO_WORK_DONE" => WIN32::ERROR_NO_WORK_DONE,
            "ERROR_VC_DISCONNECTED" => WIN32::ERROR_VC_DISCONNECTED,
            "ERROR_INVALID_EA_NAME" => WIN32::ERROR_INVALID_EA_NAME,
            "ERROR_EA_LIST_INCONSISTENT" => WIN32::ERROR_EA_LIST_INCONSISTENT,
            "WAIT_TIMEOUT" => WIN32::WAIT_TIMEOUT,
            "ERROR_NO_MORE_ITEMS" => WIN32::ERROR_NO_MORE_ITEMS,
            "ERROR_CANNOT_COPY" => WIN32::ERROR_CANNOT_COPY,
            "ERROR_DIRECTORY" => WIN32::ERROR_DIRECTORY,
            "ERROR_EAS_DIDNT_FIT" => WIN32::ERROR_EAS_DIDNT_FIT,
            "ERROR_EA_FILE_CORRUPT" => WIN32::ERROR_EA_FILE_CORRUPT,
            "ERROR_EA_TABLE_FULL" => WIN32::ERROR_EA_TABLE_FULL,
            "ERROR_INVALID_EA_HANDLE" => WIN32::ERROR_INVALID_EA_HANDLE,
            "ERROR_EAS_NOT_SUPPORTED" => WIN32::ERROR_EAS_NOT_SUPPORTED,
            "ERROR_NOT_OWNER" => WIN32::ERROR_NOT_OWNER,
            "ERROR_TOO_MANY_POSTS" => WIN32::ERROR_TOO_MANY_POSTS,
            "ERROR_PARTIAL_COPY" => WIN32::ERROR_PARTIAL_COPY,
            "ERROR_OPLOCK_NOT_GRANTED" => WIN32::ERROR_OPLOCK_NOT_GRANTED,
            "ERROR_INVALID_OPLOCK_PROTOCOL" => WIN32::ERROR_INVALID_OPLOCK_PROTOCOL,
            "ERROR_DISK_TOO_FRAGMENTED" => WIN32::ERROR_DISK_TOO_FRAGMENTED,
            "ERROR_DELETE_PENDING" => WIN32::ERROR_DELETE_PENDING,
            "ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING" => WIN32::ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING,
            "ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME" => WIN32::ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME,
            "ERROR_SECURITY_STREAM_IS_INCONSISTENT" => WIN32::ERROR_SECURITY_STREAM_IS_INCONSISTENT,
            "ERROR_INVALID_LOCK_RANGE" => WIN32::ERROR_INVALID_LOCK_RANGE,
            "ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT" => WIN32::ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT,
            "ERROR_NOTIFICATION_GUID_ALREADY_DEFINED" => WIN32::ERROR_NOTIFICATION_GUID_ALREADY_DEFINED,
            "ERROR_INVALID_EXCEPTION_HANDLER" => WIN32::ERROR_INVALID_EXCEPTION_HANDLER,
            "ERROR_DUPLICATE_PRIVILEGES" => WIN32::ERROR_DUPLICATE_PRIVILEGES,
            "ERROR_NO_RANGES_PROCESSED" => WIN32::ERROR_NO_RANGES_PROCESSED,
            "ERROR_NOT_ALLOWED_ON_SYSTEM_FILE" => WIN32::ERROR_NOT_ALLOWED_ON_SYSTEM_FILE,
            "ERROR_DISK_RESOURCES_EXHAUSTED" => WIN32::ERROR_DISK_RESOURCES_EXHAUSTED,
            "ERROR_INVALID_TOKEN" => WIN32::ERROR_INVALID_TOKEN,
            "ERROR_DEVICE_FEATURE_NOT_SUPPORTED" => WIN32::ERROR_DEVICE_FEATURE_NOT_SUPPORTED,
            "ERROR_MR_MID_NOT_FOUND" => WIN32::ERROR_MR_MID_NOT_FOUND,
            "ERROR_SCOPE_NOT_FOUND" => WIN32::ERROR_SCOPE_NOT_FOUND,
            "ERROR_UNDEFINED_SCOPE" => WIN32::ERROR_UNDEFINED_SCOPE,
            "ERROR_INVALID_CAP" => WIN32::ERROR_INVALID_CAP,
            "ERROR_DEVICE_UNREACHABLE" => WIN32::ERROR_DEVICE_UNREACHABLE,
            "ERROR_DEVICE_NO_RESOURCES" => WIN32::ERROR_DEVICE_NO_RESOURCES,
            "ERROR_DATA_CHECKSUM_ERROR" => WIN32::ERROR_DATA_CHECKSUM_ERROR,
            "ERROR_INTERMIXED_KERNEL_EA_OPERATION" => WIN32::ERROR_INTERMIXED_KERNEL_EA_OPERATION,
            "ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED" => WIN32::ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED,
            "ERROR_OFFSET_ALIGNMENT_VIOLATION" => WIN32::ERROR_OFFSET_ALIGNMENT_VIOLATION,
            "ERROR_INVALID_FIELD_IN_PARAMETER_LIST" => WIN32::ERROR_INVALID_FIELD_IN_PARAMETER_LIST,
            "ERROR_OPERATION_IN_PROGRESS" => WIN32::ERROR_OPERATION_IN_PROGRESS,
            "ERROR_BAD_DEVICE_PATH" => WIN32::ERROR_BAD_DEVICE_PATH,
            "ERROR_TOO_MANY_DESCRIPTORS" => WIN32::ERROR_TOO_MANY_DESCRIPTORS,
            "ERROR_SCRUB_DATA_DISABLED" => WIN32::ERROR_SCRUB_DATA_DISABLED,
            "ERROR_NOT_REDUNDANT_STORAGE" => WIN32::ERROR_NOT_REDUNDANT_STORAGE,
            "ERROR_RESIDENT_FILE_NOT_SUPPORTED" => WIN32::ERROR_RESIDENT_FILE_NOT_SUPPORTED,
            "ERROR_COMPRESSED_FILE_NOT_SUPPORTED" => WIN32::ERROR_COMPRESSED_FILE_NOT_SUPPORTED,
            "ERROR_DIRECTORY_NOT_SUPPORTED" => WIN32::ERROR_DIRECTORY_NOT_SUPPORTED,
            "ERROR_NOT_READ_FROM_COPY" => WIN32::ERROR_NOT_READ_FROM_COPY,
            "ERROR_FT_WRITE_FAILURE" => WIN32::ERROR_FT_WRITE_FAILURE,
            "ERROR_FT_DI_SCAN_REQUIRED" => WIN32::ERROR_FT_DI_SCAN_REQUIRED,
            "ERROR_INVALID_KERNEL_INFO_VERSION" => WIN32::ERROR_INVALID_KERNEL_INFO_VERSION,
            "ERROR_INVALID_PEP_INFO_VERSION" => WIN32::ERROR_INVALID_PEP_INFO_VERSION,
            "ERROR_OBJECT_NOT_EXTERNALLY_BACKED" => WIN32::ERROR_OBJECT_NOT_EXTERNALLY_BACKED,
            "ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN" => WIN32::ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN,
            "ERROR_COMPRESSION_NOT_BENEFICIAL" => WIN32::ERROR_COMPRESSION_NOT_BENEFICIAL,
            "ERROR_STORAGE_TOPOLOGY_ID_MISMATCH" => WIN32::ERROR_STORAGE_TOPOLOGY_ID_MISMATCH,
            "ERROR_BLOCKED_BY_PARENTAL_CONTROLS" => WIN32::ERROR_BLOCKED_BY_PARENTAL_CONTROLS,
            "ERROR_BLOCK_TOO_MANY_REFERENCES" => WIN32::ERROR_BLOCK_TOO_MANY_REFERENCES,
            "ERROR_MARKED_TO_DISALLOW_WRITES" => WIN32::ERROR_MARKED_TO_DISALLOW_WRITES,
            "ERROR_ENCLAVE_FAILURE" => WIN32::ERROR_ENCLAVE_FAILURE,
            "ERROR_FAIL_NOACTION_REBOOT" => WIN32::ERROR_FAIL_NOACTION_REBOOT,
            "ERROR_FAIL_SHUTDOWN" => WIN32::ERROR_FAIL_SHUTDOWN,
            "ERROR_FAIL_RESTART" => WIN32::ERROR_FAIL_RESTART,
            "ERROR_MAX_SESSIONS_REACHED" => WIN32::ERROR_MAX_SESSIONS_REACHED,
            "ERROR_NETWORK_ACCESS_DENIED_EDP" => WIN32::ERROR_NETWORK_ACCESS_DENIED_EDP,
            "ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL" => WIN32::ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL,
            "ERROR_EDP_POLICY_DENIES_OPERATION" => WIN32::ERROR_EDP_POLICY_DENIES_OPERATION,
            "ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED" => WIN32::ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED,
            "ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT" => WIN32::ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT,
            "ERROR_CLOUD_FILE_PROVIDER_UNKNOWN" => WIN32::ERROR_CLOUD_FILE_PROVIDER_UNKNOWN,
            "ERROR_DEVICE_IN_MAINTENANCE" => WIN32::ERROR_DEVICE_IN_MAINTENANCE,
            "ERROR_NOT_SUPPORTED_ON_DAX" => WIN32::ERROR_NOT_SUPPORTED_ON_DAX,
            "ERROR_DAX_MAPPING_EXISTS" => WIN32::ERROR_DAX_MAPPING_EXISTS,
            "ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING" => WIN32::ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING,
            "ERROR_CLOUD_FILE_METADATA_CORRUPT" => WIN32::ERROR_CLOUD_FILE_METADATA_CORRUPT,
            "ERROR_CLOUD_FILE_METADATA_TOO_LARGE" => WIN32::ERROR_CLOUD_FILE_METADATA_TOO_LARGE,
            "ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE" => WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE,
            "ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH" => WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH,
            "ERROR_CHILD_PROCESS_BLOCKED" => WIN32::ERROR_CHILD_PROCESS_BLOCKED,
            "ERROR_STORAGE_LOST_DATA_PERSISTENCE" => WIN32::ERROR_STORAGE_LOST_DATA_PERSISTENCE,
            "ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE" => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE,
            "ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT" => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT,
            "ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY" => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY,
            "ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN" => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN,
            "ERROR_GDI_HANDLE_LEAK" => WIN32::ERROR_GDI_HANDLE_LEAK,
            "ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS" => WIN32::ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS,
            "ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED" => WIN32::ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED,
            "ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED" => WIN32::ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED,
            "ERROR_NOT_A_CLOUD_FILE" => WIN32::ERROR_NOT_A_CLOUD_FILE,
            "ERROR_CLOUD_FILE_NOT_IN_SYNC" => WIN32::ERROR_CLOUD_FILE_NOT_IN_SYNC,
            "ERROR_CLOUD_FILE_ALREADY_CONNECTED" => WIN32::ERROR_CLOUD_FILE_ALREADY_CONNECTED,
            "ERROR_CLOUD_FILE_NOT_SUPPORTED" => WIN32::ERROR_CLOUD_FILE_NOT_SUPPORTED,
            "ERROR_CLOUD_FILE_INVALID_REQUEST" => WIN32::ERROR_CLOUD_FILE_INVALID_REQUEST,
            "ERROR_CLOUD_FILE_READ_ONLY_VOLUME" => WIN32::ERROR_CLOUD_FILE_READ_ONLY_VOLUME,
            "ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY" => WIN32::ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY,
            "ERROR_CLOUD_FILE_VALIDATION_FAILED" => WIN32::ERROR_CLOUD_FILE_VALIDATION_FAILED,
            "ERROR_SMB1_NOT_AVAILABLE" => WIN32::ERROR_SMB1_NOT_AVAILABLE,
            "ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION" => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION,
            "ERROR_CLOUD_FILE_AUTHENTICATION_FAILED" => WIN32::ERROR_CLOUD_FILE_AUTHENTICATION_FAILED,
            "ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES" => WIN32::ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES,
            "ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE" => WIN32::ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE,
            "ERROR_CLOUD_FILE_UNSUCCESSFUL" => WIN32::ERROR_CLOUD_FILE_UNSUCCESSFUL,
            "ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT" => WIN32::ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT,
            "ERROR_CLOUD_FILE_IN_USE" => WIN32::ERROR_CLOUD_FILE_IN_USE,
            "ERROR_CLOUD_FILE_PINNED" => WIN32::ERROR_CLOUD_FILE_PINNED,
            "ERROR_CLOUD_FILE_REQUEST_ABORTED" => WIN32::ERROR_CLOUD_FILE_REQUEST_ABORTED,
            "ERROR_CLOUD_FILE_PROPERTY_CORRUPT" => WIN32::ERROR_CLOUD_FILE_PROPERTY_CORRUPT,
            "ERROR_CLOUD_FILE_ACCESS_DENIED" => WIN32::ERROR_CLOUD_FILE_ACCESS_DENIED,
            "ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS" => WIN32::ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS,
            "ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT" => WIN32::ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT,
            "ERROR_CLOUD_FILE_REQUEST_CANCELED" => WIN32::ERROR_CLOUD_FILE_REQUEST_CANCELED,
            "ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED" => WIN32::ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED,
            "ERROR_THREAD_MODE_ALREADY_BACKGROUND" => WIN32::ERROR_THREAD_MODE_ALREADY_BACKGROUND,
            "ERROR_THREAD_MODE_NOT_BACKGROUND" => WIN32::ERROR_THREAD_MODE_NOT_BACKGROUND,
            "ERROR_PROCESS_MODE_ALREADY_BACKGROUND" => WIN32::ERROR_PROCESS_MODE_ALREADY_BACKGROUND,
            "ERROR_PROCESS_MODE_NOT_BACKGROUND" => WIN32::ERROR_PROCESS_MODE_NOT_BACKGROUND,
            "ERROR_CLOUD_FILE_PROVIDER_TERMINATED" => WIN32::ERROR_CLOUD_FILE_PROVIDER_TERMINATED,
            "ERROR_NOT_A_CLOUD_SYNC_ROOT" => WIN32::ERROR_NOT_A_CLOUD_SYNC_ROOT,
            "ERROR_FILE_PROTECTED_UNDER_DPL" => WIN32::ERROR_FILE_PROTECTED_UNDER_DPL,
            "ERROR_VOLUME_NOT_CLUSTER_ALIGNED" => WIN32::ERROR_VOLUME_NOT_CLUSTER_ALIGNED,
            "ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND" => WIN32::ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND,
            "ERROR_APPX_FILE_NOT_ENCRYPTED" => WIN32::ERROR_APPX_FILE_NOT_ENCRYPTED,
            "ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED" => WIN32::ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED,
            "ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET" => WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET,
            "ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE" => WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE,
            "ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER" => WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER,
            "ERROR_LINUX_SUBSYSTEM_NOT_PRESENT" => WIN32::ERROR_LINUX_SUBSYSTEM_NOT_PRESENT,
            "ERROR_FT_READ_FAILURE" => WIN32::ERROR_FT_READ_FAILURE,
            "ERROR_STORAGE_RESERVE_ID_INVALID" => WIN32::ERROR_STORAGE_RESERVE_ID_INVALID,
            "ERROR_STORAGE_RESERVE_DOES_NOT_EXIST" => WIN32::ERROR_STORAGE_RESERVE_DOES_NOT_EXIST,
            "ERROR_STORAGE_RESERVE_ALREADY_EXISTS" => WIN32::ERROR_STORAGE_RESERVE_ALREADY_EXISTS,
            "ERROR_STORAGE_RESERVE_NOT_EMPTY" => WIN32::ERROR_STORAGE_RESERVE_NOT_EMPTY,
            "ERROR_NOT_A_DAX_VOLUME" => WIN32::ERROR_NOT_A_DAX_VOLUME,
            "ERROR_NOT_DAX_MAPPABLE" => WIN32::ERROR_NOT_DAX_MAPPABLE,
            "ERROR_TIME_SENSITIVE_THREAD" => WIN32::ERROR_TIME_SENSITIVE_THREAD,
            "ERROR_DPL_NOT_SUPPORTED_FOR_USER" => WIN32::ERROR_DPL_NOT_SUPPORTED_FOR_USER,
            "ERROR_CASE_DIFFERING_NAMES_IN_DIR" => WIN32::ERROR_CASE_DIFFERING_NAMES_IN_DIR,
            "ERROR_FILE_NOT_SUPPORTED" => WIN32::ERROR_FILE_NOT_SUPPORTED,
            "ERROR_CLOUD_FILE_REQUEST_TIMEOUT" => WIN32::ERROR_CLOUD_FILE_REQUEST_TIMEOUT,
            "ERROR_NO_TASK_QUEUE" => WIN32::ERROR_NO_TASK_QUEUE,
            "ERROR_SRC_SRV_DLL_LOAD_FAILED" => WIN32::ERROR_SRC_SRV_DLL_LOAD_FAILED,
            "ERROR_NOT_SUPPORTED_WITH_BTT" => WIN32::ERROR_NOT_SUPPORTED_WITH_BTT,
            "ERROR_ENCRYPTION_DISABLED" => WIN32::ERROR_ENCRYPTION_DISABLED,
            "ERROR_ENCRYPTING_METADATA_DISALLOWED" => WIN32::ERROR_ENCRYPTING_METADATA_DISALLOWED,
            "ERROR_CANT_CLEAR_ENCRYPTION_FLAG" => WIN32::ERROR_CANT_CLEAR_ENCRYPTION_FLAG,
            "ERROR_NO_SUCH_DEVICE" => WIN32::ERROR_NO_SUCH_DEVICE,
            "ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED" => WIN32::ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED,
            "ERROR_FILE_SNAP_IN_PROGRESS" => WIN32::ERROR_FILE_SNAP_IN_PROGRESS,
            "ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED" => WIN32::ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED,
            "ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED" => WIN32::ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED,
            "ERROR_FILE_SNAP_IO_NOT_COORDINATED" => WIN32::ERROR_FILE_SNAP_IO_NOT_COORDINATED,
            "ERROR_FILE_SNAP_UNEXPECTED_ERROR" => WIN32::ERROR_FILE_SNAP_UNEXPECTED_ERROR,
            "ERROR_FILE_SNAP_INVALID_PARAMETER" => WIN32::ERROR_FILE_SNAP_INVALID_PARAMETER,
            "ERROR_UNSATISFIED_DEPENDENCIES" => WIN32::ERROR_UNSATISFIED_DEPENDENCIES,
            "ERROR_CASE_SENSITIVE_PATH" => WIN32::ERROR_CASE_SENSITIVE_PATH,
            "ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR" => WIN32::ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR,
            "ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED" => WIN32::ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED,
            "ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION" => WIN32::ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION,
            "ERROR_DLP_POLICY_DENIES_OPERATION" => WIN32::ERROR_DLP_POLICY_DENIES_OPERATION,
            "ERROR_SECURITY_DENIES_OPERATION" => WIN32::ERROR_SECURITY_DENIES_OPERATION,
            "ERROR_UNTRUSTED_MOUNT_POINT" => WIN32::ERROR_UNTRUSTED_MOUNT_POINT,
            "ERROR_DLP_POLICY_SILENTLY_FAIL" => WIN32::ERROR_DLP_POLICY_SILENTLY_FAIL,
            "ERROR_CAPAUTHZ_NOT_DEVUNLOCKED" => WIN32::ERROR_CAPAUTHZ_NOT_DEVUNLOCKED,
            "ERROR_CAPAUTHZ_CHANGE_TYPE" => WIN32::ERROR_CAPAUTHZ_CHANGE_TYPE,
            "ERROR_CAPAUTHZ_NOT_PROVISIONED" => WIN32::ERROR_CAPAUTHZ_NOT_PROVISIONED,
            "ERROR_CAPAUTHZ_NOT_AUTHORIZED" => WIN32::ERROR_CAPAUTHZ_NOT_AUTHORIZED,
            "ERROR_CAPAUTHZ_NO_POLICY" => WIN32::ERROR_CAPAUTHZ_NO_POLICY,
            "ERROR_CAPAUTHZ_DB_CORRUPTED" => WIN32::ERROR_CAPAUTHZ_DB_CORRUPTED,
            "ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG" => WIN32::ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG,
            "ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY" => WIN32::ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY,
            "ERROR_CAPAUTHZ_SCCD_PARSE_ERROR" => WIN32::ERROR_CAPAUTHZ_SCCD_PARSE_ERROR,
            "ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED" => WIN32::ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED,
            "ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH" => WIN32::ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH,
            "ERROR_CIMFS_IMAGE_CORRUPT" => WIN32::ERROR_CIMFS_IMAGE_CORRUPT,
            "ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED" => WIN32::ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED,
            "ERROR_STORAGE_STACK_ACCESS_DENIED" => WIN32::ERROR_STORAGE_STACK_ACCESS_DENIED,
            "ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES" => WIN32::ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES,
            "ERROR_INDEX_OUT_OF_BOUNDS" => WIN32::ERROR_INDEX_OUT_OF_BOUNDS,
            "ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT" => WIN32::ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT,
            "ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT" => WIN32::ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT,
            "ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT" => WIN32::ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT,
            "ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT" => WIN32::ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT,
            "ERROR_DEVICE_HARDWARE_ERROR" => WIN32::ERROR_DEVICE_HARDWARE_ERROR,
            "ERROR_INVALID_ADDRESS" => WIN32::ERROR_INVALID_ADDRESS,
            "ERROR_HAS_SYSTEM_CRITICAL_FILES" => WIN32::ERROR_HAS_SYSTEM_CRITICAL_FILES,
            "ERROR_ENCRYPTED_FILE_NOT_SUPPORTED" => WIN32::ERROR_ENCRYPTED_FILE_NOT_SUPPORTED,
            "ERROR_SPARSE_FILE_NOT_SUPPORTED" => WIN32::ERROR_SPARSE_FILE_NOT_SUPPORTED,
            "ERROR_PAGEFILE_NOT_SUPPORTED" => WIN32::ERROR_PAGEFILE_NOT_SUPPORTED,
            "ERROR_VOLUME_NOT_SUPPORTED" => WIN32::ERROR_VOLUME_NOT_SUPPORTED,
            "ERROR_NOT_SUPPORTED_WITH_BYPASSIO" => WIN32::ERROR_NOT_SUPPORTED_WITH_BYPASSIO,
            "ERROR_NO_BYPASSIO_DRIVER_SUPPORT" => WIN32::ERROR_NO_BYPASSIO_DRIVER_SUPPORT,
            "ERROR_NOT_SUPPORTED_WITH_ENCRYPTION" => WIN32::ERROR_NOT_SUPPORTED_WITH_ENCRYPTION,
            "ERROR_NOT_SUPPORTED_WITH_COMPRESSION" => WIN32::ERROR_NOT_SUPPORTED_WITH_COMPRESSION,
            "ERROR_NOT_SUPPORTED_WITH_REPLICATION" => WIN32::ERROR_NOT_SUPPORTED_WITH_REPLICATION,
            "ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION" => WIN32::ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION,
            "ERROR_NOT_SUPPORTED_WITH_AUDITING" => WIN32::ERROR_NOT_SUPPORTED_WITH_AUDITING,
            "ERROR_USER_PROFILE_LOAD" => WIN32::ERROR_USER_PROFILE_LOAD,
            "ERROR_SESSION_KEY_TOO_SHORT" => WIN32::ERROR_SESSION_KEY_TOO_SHORT,
            "ERROR_ACCESS_DENIED_APPDATA" => WIN32::ERROR_ACCESS_DENIED_APPDATA,
            "ERROR_NOT_SUPPORTED_WITH_MONITORING" => WIN32::ERROR_NOT_SUPPORTED_WITH_MONITORING,
            "ERROR_NOT_SUPPORTED_WITH_SNAPSHOT" => WIN32::ERROR_NOT_SUPPORTED_WITH_SNAPSHOT,
            "ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION" => WIN32::ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION,
            "ERROR_BYPASSIO_FLT_NOT_SUPPORTED" => WIN32::ERROR_BYPASSIO_FLT_NOT_SUPPORTED,
            "ERROR_DEVICE_RESET_REQUIRED" => WIN32::ERROR_DEVICE_RESET_REQUIRED,
            "ERROR_VOLUME_WRITE_ACCESS_DENIED" => WIN32::ERROR_VOLUME_WRITE_ACCESS_DENIED,
            "ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE" => WIN32::ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE,
            "ERROR_FS_METADATA_INCONSISTENT" => WIN32::ERROR_FS_METADATA_INCONSISTENT,
            "ERROR_BLOCK_WEAK_REFERENCE_INVALID" => WIN32::ERROR_BLOCK_WEAK_REFERENCE_INVALID,
            "ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID" => WIN32::ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID,
            "ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID" => WIN32::ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID,
            "ERROR_BLOCK_SHARED" => WIN32::ERROR_BLOCK_SHARED,
            "ERROR_ARITHMETIC_OVERFLOW" => WIN32::ERROR_ARITHMETIC_OVERFLOW,
            "ERROR_PIPE_CONNECTED" => WIN32::ERROR_PIPE_CONNECTED,
            "ERROR_PIPE_LISTENING" => WIN32::ERROR_PIPE_LISTENING,
            "ERROR_VERIFIER_STOP" => WIN32::ERROR_VERIFIER_STOP,
            "ERROR_ABIOS_ERROR" => WIN32::ERROR_ABIOS_ERROR,
            "ERROR_WX86_WARNING" => WIN32::ERROR_WX86_WARNING,
            "ERROR_WX86_ERROR" => WIN32::ERROR_WX86_ERROR,
            "ERROR_TIMER_NOT_CANCELED" => WIN32::ERROR_TIMER_NOT_CANCELED,
            "ERROR_UNWIND" => WIN32::ERROR_UNWIND,
            "ERROR_BAD_STACK" => WIN32::ERROR_BAD_STACK,
            "ERROR_INVALID_UNWIND_TARGET" => WIN32::ERROR_INVALID_UNWIND_TARGET,
            "ERROR_INVALID_PORT_ATTRIBUTES" => WIN32::ERROR_INVALID_PORT_ATTRIBUTES,
            "ERROR_PORT_MESSAGE_TOO_LONG" => WIN32::ERROR_PORT_MESSAGE_TOO_LONG,
            "ERROR_INVALID_QUOTA_LOWER" => WIN32::ERROR_INVALID_QUOTA_LOWER,
            "ERROR_DEVICE_ALREADY_ATTACHED" => WIN32::ERROR_DEVICE_ALREADY_ATTACHED,
            "ERROR_INSTRUCTION_MISALIGNMENT" => WIN32::ERROR_INSTRUCTION_MISALIGNMENT,
            "ERROR_PROFILING_NOT_STARTED" => WIN32::ERROR_PROFILING_NOT_STARTED,
            "ERROR_PROFILING_NOT_STOPPED" => WIN32::ERROR_PROFILING_NOT_STOPPED,
            "ERROR_COULD_NOT_INTERPRET" => WIN32::ERROR_COULD_NOT_INTERPRET,
            "ERROR_PROFILING_AT_LIMIT" => WIN32::ERROR_PROFILING_AT_LIMIT,
            "ERROR_CANT_WAIT" => WIN32::ERROR_CANT_WAIT,
            "ERROR_CANT_TERMINATE_SELF" => WIN32::ERROR_CANT_TERMINATE_SELF,
            "ERROR_UNEXPECTED_MM_CREATE_ERR" => WIN32::ERROR_UNEXPECTED_MM_CREATE_ERR,
            "ERROR_UNEXPECTED_MM_MAP_ERROR" => WIN32::ERROR_UNEXPECTED_MM_MAP_ERROR,
            "ERROR_UNEXPECTED_MM_EXTEND_ERR" => WIN32::ERROR_UNEXPECTED_MM_EXTEND_ERR,
            "ERROR_BAD_FUNCTION_TABLE" => WIN32::ERROR_BAD_FUNCTION_TABLE,
            "ERROR_NO_GUID_TRANSLATION" => WIN32::ERROR_NO_GUID_TRANSLATION,
            "ERROR_INVALID_LDT_SIZE" => WIN32::ERROR_INVALID_LDT_SIZE,
            "ERROR_INVALID_LDT_OFFSET" => WIN32::ERROR_INVALID_LDT_OFFSET,
            "ERROR_INVALID_LDT_DESCRIPTOR" => WIN32::ERROR_INVALID_LDT_DESCRIPTOR,
            "ERROR_TOO_MANY_THREADS" => WIN32::ERROR_TOO_MANY_THREADS,
            "ERROR_THREAD_NOT_IN_PROCESS" => WIN32::ERROR_THREAD_NOT_IN_PROCESS,
            "ERROR_PAGEFILE_QUOTA_EXCEEDED" => WIN32::ERROR_PAGEFILE_QUOTA_EXCEEDED,
            "ERROR_LOGON_SERVER_CONFLICT" => WIN32::ERROR_LOGON_SERVER_CONFLICT,
            "ERROR_SYNCHRONIZATION_REQUIRED" => WIN32::ERROR_SYNCHRONIZATION_REQUIRED,
            "ERROR_NET_OPEN_FAILED" => WIN32::ERROR_NET_OPEN_FAILED,
            "ERROR_IO_PRIVILEGE_FAILED" => WIN32::ERROR_IO_PRIVILEGE_FAILED,
            "ERROR_CONTROL_C_EXIT" => WIN32::ERROR_CONTROL_C_EXIT,
            "ERROR_MISSING_SYSTEMFILE" => WIN32::ERROR_MISSING_SYSTEMFILE,
            "ERROR_UNHANDLED_EXCEPTION" => WIN32::ERROR_UNHANDLED_EXCEPTION,
            "ERROR_APP_INIT_FAILURE" => WIN32::ERROR_APP_INIT_FAILURE,
            "ERROR_PAGEFILE_CREATE_FAILED" => WIN32::ERROR_PAGEFILE_CREATE_FAILED,
            "ERROR_INVALID_IMAGE_HASH" => WIN32::ERROR_INVALID_IMAGE_HASH,
            "ERROR_NO_PAGEFILE" => WIN32::ERROR_NO_PAGEFILE,
            "ERROR_ILLEGAL_FLOAT_CONTEXT" => WIN32::ERROR_ILLEGAL_FLOAT_CONTEXT,
            "ERROR_NO_EVENT_PAIR" => WIN32::ERROR_NO_EVENT_PAIR,
            "ERROR_DOMAIN_CTRLR_CONFIG_ERROR" => WIN32::ERROR_DOMAIN_CTRLR_CONFIG_ERROR,
            "ERROR_ILLEGAL_CHARACTER" => WIN32::ERROR_ILLEGAL_CHARACTER,
            "ERROR_UNDEFINED_CHARACTER" => WIN32::ERROR_UNDEFINED_CHARACTER,
            "ERROR_FLOPPY_VOLUME" => WIN32::ERROR_FLOPPY_VOLUME,
            "ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT" => WIN32::ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT,
            "ERROR_BACKUP_CONTROLLER" => WIN32::ERROR_BACKUP_CONTROLLER,
            "ERROR_MUTANT_LIMIT_EXCEEDED" => WIN32::ERROR_MUTANT_LIMIT_EXCEEDED,
            "ERROR_FS_DRIVER_REQUIRED" => WIN32::ERROR_FS_DRIVER_REQUIRED,
            "ERROR_CANNOT_LOAD_REGISTRY_FILE" => WIN32::ERROR_CANNOT_LOAD_REGISTRY_FILE,
            "ERROR_DEBUG_ATTACH_FAILED" => WIN32::ERROR_DEBUG_ATTACH_FAILED,
            "ERROR_SYSTEM_PROCESS_TERMINATED" => WIN32::ERROR_SYSTEM_PROCESS_TERMINATED,
            "ERROR_DATA_NOT_ACCEPTED" => WIN32::ERROR_DATA_NOT_ACCEPTED,
            "ERROR_VDM_HARD_ERROR" => WIN32::ERROR_VDM_HARD_ERROR,
            "ERROR_DRIVER_CANCEL_TIMEOUT" => WIN32::ERROR_DRIVER_CANCEL_TIMEOUT,
            "ERROR_REPLY_MESSAGE_MISMATCH" => WIN32::ERROR_REPLY_MESSAGE_MISMATCH,
            "ERROR_LOST_WRITEBEHIND_DATA" => WIN32::ERROR_LOST_WRITEBEHIND_DATA,
            "ERROR_CLIENT_SERVER_PARAMETERS_INVALID" => WIN32::ERROR_CLIENT_SERVER_PARAMETERS_INVALID,
            "ERROR_NOT_TINY_STREAM" => WIN32::ERROR_NOT_TINY_STREAM,
            "ERROR_STACK_OVERFLOW_READ" => WIN32::ERROR_STACK_OVERFLOW_READ,
            "ERROR_CONVERT_TO_LARGE" => WIN32::ERROR_CONVERT_TO_LARGE,
            "ERROR_FOUND_OUT_OF_SCOPE" => WIN32::ERROR_FOUND_OUT_OF_SCOPE,
            "ERROR_ALLOCATE_BUCKET" => WIN32::ERROR_ALLOCATE_BUCKET,
            "ERROR_MARSHALL_OVERFLOW" => WIN32::ERROR_MARSHALL_OVERFLOW,
            "ERROR_INVALID_VARIANT" => WIN32::ERROR_INVALID_VARIANT,
            "ERROR_BAD_COMPRESSION_BUFFER" => WIN32::ERROR_BAD_COMPRESSION_BUFFER,
            "ERROR_AUDIT_FAILED" => WIN32::ERROR_AUDIT_FAILED,
            "ERROR_TIMER_RESOLUTION_NOT_SET" => WIN32::ERROR_TIMER_RESOLUTION_NOT_SET,
            "ERROR_INSUFFICIENT_LOGON_INFO" => WIN32::ERROR_INSUFFICIENT_LOGON_INFO,
            "ERROR_BAD_DLL_ENTRYPOINT" => WIN32::ERROR_BAD_DLL_ENTRYPOINT,
            "ERROR_BAD_SERVICE_ENTRYPOINT" => WIN32::ERROR_BAD_SERVICE_ENTRYPOINT,
            "ERROR_IP_ADDRESS_CONFLICT1" => WIN32::ERROR_IP_ADDRESS_CONFLICT1,
            "ERROR_IP_ADDRESS_CONFLICT2" => WIN32::ERROR_IP_ADDRESS_CONFLICT2,
            "ERROR_REGISTRY_QUOTA_LIMIT" => WIN32::ERROR_REGISTRY_QUOTA_LIMIT,
            "ERROR_NO_CALLBACK_ACTIVE" => WIN32::ERROR_NO_CALLBACK_ACTIVE,
            "ERROR_PWD_TOO_SHORT" => WIN32::ERROR_PWD_TOO_SHORT,
            "ERROR_PWD_TOO_RECENT" => WIN32::ERROR_PWD_TOO_RECENT,
            "ERROR_PWD_HISTORY_CONFLICT" => WIN32::ERROR_PWD_HISTORY_CONFLICT,
            "ERROR_UNSUPPORTED_COMPRESSION" => WIN32::ERROR_UNSUPPORTED_COMPRESSION,
            "ERROR_INVALID_HW_PROFILE" => WIN32::ERROR_INVALID_HW_PROFILE,
            "ERROR_INVALID_PLUGPLAY_DEVICE_PATH" => WIN32::ERROR_INVALID_PLUGPLAY_DEVICE_PATH,
            "ERROR_QUOTA_LIST_INCONSISTENT" => WIN32::ERROR_QUOTA_LIST_INCONSISTENT,
            "ERROR_EVALUATION_EXPIRATION" => WIN32::ERROR_EVALUATION_EXPIRATION,
            "ERROR_ILLEGAL_DLL_RELOCATION" => WIN32::ERROR_ILLEGAL_DLL_RELOCATION,
            "ERROR_DLL_INIT_FAILED_LOGOFF" => WIN32::ERROR_DLL_INIT_FAILED_LOGOFF,
            "ERROR_VALIDATE_CONTINUE" => WIN32::ERROR_VALIDATE_CONTINUE,
            "ERROR_NO_MORE_MATCHES" => WIN32::ERROR_NO_MORE_MATCHES,
            "ERROR_RANGE_LIST_CONFLICT" => WIN32::ERROR_RANGE_LIST_CONFLICT,
            "ERROR_SERVER_SID_MISMATCH" => WIN32::ERROR_SERVER_SID_MISMATCH,
            "ERROR_CANT_ENABLE_DENY_ONLY" => WIN32::ERROR_CANT_ENABLE_DENY_ONLY,
            "ERROR_FLOAT_MULTIPLE_FAULTS" => WIN32::ERROR_FLOAT_MULTIPLE_FAULTS,
            "ERROR_FLOAT_MULTIPLE_TRAPS" => WIN32::ERROR_FLOAT_MULTIPLE_TRAPS,
            "ERROR_NOINTERFACE" => WIN32::ERROR_NOINTERFACE,
            "ERROR_DRIVER_FAILED_SLEEP" => WIN32::ERROR_DRIVER_FAILED_SLEEP,
            "ERROR_CORRUPT_SYSTEM_FILE" => WIN32::ERROR_CORRUPT_SYSTEM_FILE,
            "ERROR_COMMITMENT_MINIMUM" => WIN32::ERROR_COMMITMENT_MINIMUM,
            "ERROR_PNP_RESTART_ENUMERATION" => WIN32::ERROR_PNP_RESTART_ENUMERATION,
            "ERROR_SYSTEM_IMAGE_BAD_SIGNATURE" => WIN32::ERROR_SYSTEM_IMAGE_BAD_SIGNATURE,
            "ERROR_PNP_REBOOT_REQUIRED" => WIN32::ERROR_PNP_REBOOT_REQUIRED,
            "ERROR_INSUFFICIENT_POWER" => WIN32::ERROR_INSUFFICIENT_POWER,
            "ERROR_MULTIPLE_FAULT_VIOLATION" => WIN32::ERROR_MULTIPLE_FAULT_VIOLATION,
            "ERROR_SYSTEM_SHUTDOWN" => WIN32::ERROR_SYSTEM_SHUTDOWN,
            "ERROR_PORT_NOT_SET" => WIN32::ERROR_PORT_NOT_SET,
            "ERROR_DS_VERSION_CHECK_FAILURE" => WIN32::ERROR_DS_VERSION_CHECK_FAILURE,
            "ERROR_RANGE_NOT_FOUND" => WIN32::ERROR_RANGE_NOT_FOUND,
            "ERROR_NOT_SAFE_MODE_DRIVER" => WIN32::ERROR_NOT_SAFE_MODE_DRIVER,
            "ERROR_FAILED_DRIVER_ENTRY" => WIN32::ERROR_FAILED_DRIVER_ENTRY,
            "ERROR_DEVICE_ENUMERATION_ERROR" => WIN32::ERROR_DEVICE_ENUMERATION_ERROR,
            "ERROR_MOUNT_POINT_NOT_RESOLVED" => WIN32::ERROR_MOUNT_POINT_NOT_RESOLVED,
            "ERROR_INVALID_DEVICE_OBJECT_PARAMETER" => WIN32::ERROR_INVALID_DEVICE_OBJECT_PARAMETER,
            "ERROR_MCA_OCCURED" => WIN32::ERROR_MCA_OCCURED,
            "ERROR_DRIVER_DATABASE_ERROR" => WIN32::ERROR_DRIVER_DATABASE_ERROR,
            "ERROR_SYSTEM_HIVE_TOO_LARGE" => WIN32::ERROR_SYSTEM_HIVE_TOO_LARGE,
            "ERROR_DRIVER_FAILED_PRIOR_UNLOAD" => WIN32::ERROR_DRIVER_FAILED_PRIOR_UNLOAD,
            "ERROR_VOLSNAP_PREPARE_HIBERNATE" => WIN32::ERROR_VOLSNAP_PREPARE_HIBERNATE,
            "ERROR_HIBERNATION_FAILURE" => WIN32::ERROR_HIBERNATION_FAILURE,
            "ERROR_PWD_TOO_LONG" => WIN32::ERROR_PWD_TOO_LONG,
            "ERROR_FILE_SYSTEM_LIMITATION" => WIN32::ERROR_FILE_SYSTEM_LIMITATION,
            "ERROR_ASSERTION_FAILURE" => WIN32::ERROR_ASSERTION_FAILURE,
            "ERROR_ACPI_ERROR" => WIN32::ERROR_ACPI_ERROR,
            "ERROR_WOW_ASSERTION" => WIN32::ERROR_WOW_ASSERTION,
            "ERROR_PNP_BAD_MPS_TABLE" => WIN32::ERROR_PNP_BAD_MPS_TABLE,
            "ERROR_PNP_TRANSLATION_FAILED" => WIN32::ERROR_PNP_TRANSLATION_FAILED,
            "ERROR_PNP_IRQ_TRANSLATION_FAILED" => WIN32::ERROR_PNP_IRQ_TRANSLATION_FAILED,
            "ERROR_PNP_INVALID_ID" => WIN32::ERROR_PNP_INVALID_ID,
            "ERROR_WAKE_SYSTEM_DEBUGGER" => WIN32::ERROR_WAKE_SYSTEM_DEBUGGER,
            "ERROR_HANDLES_CLOSED" => WIN32::ERROR_HANDLES_CLOSED,
            "ERROR_EXTRANEOUS_INFORMATION" => WIN32::ERROR_EXTRANEOUS_INFORMATION,
            "ERROR_RXACT_COMMIT_NECESSARY" => WIN32::ERROR_RXACT_COMMIT_NECESSARY,
            "ERROR_MEDIA_CHECK" => WIN32::ERROR_MEDIA_CHECK,
            "ERROR_GUID_SUBSTITUTION_MADE" => WIN32::ERROR_GUID_SUBSTITUTION_MADE,
            "ERROR_STOPPED_ON_SYMLINK" => WIN32::ERROR_STOPPED_ON_SYMLINK,
            "ERROR_LONGJUMP" => WIN32::ERROR_LONGJUMP,
            "ERROR_PLUGPLAY_QUERY_VETOED" => WIN32::ERROR_PLUGPLAY_QUERY_VETOED,
            "ERROR_UNWIND_CONSOLIDATE" => WIN32::ERROR_UNWIND_CONSOLIDATE,
            "ERROR_REGISTRY_HIVE_RECOVERED" => WIN32::ERROR_REGISTRY_HIVE_RECOVERED,
            "ERROR_DLL_MIGHT_BE_INSECURE" => WIN32::ERROR_DLL_MIGHT_BE_INSECURE,
            "ERROR_DLL_MIGHT_BE_INCOMPATIBLE" => WIN32::ERROR_DLL_MIGHT_BE_INCOMPATIBLE,
            "ERROR_DBG_EXCEPTION_NOT_HANDLED" => WIN32::ERROR_DBG_EXCEPTION_NOT_HANDLED,
            "ERROR_DBG_REPLY_LATER" => WIN32::ERROR_DBG_REPLY_LATER,
            "ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE" => WIN32::ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE,
            "ERROR_DBG_TERMINATE_THREAD" => WIN32::ERROR_DBG_TERMINATE_THREAD,
            "ERROR_DBG_TERMINATE_PROCESS" => WIN32::ERROR_DBG_TERMINATE_PROCESS,
            "ERROR_DBG_CONTROL_C" => WIN32::ERROR_DBG_CONTROL_C,
            "ERROR_DBG_PRINTEXCEPTION_C" => WIN32::ERROR_DBG_PRINTEXCEPTION_C,
            "ERROR_DBG_RIPEXCEPTION" => WIN32::ERROR_DBG_RIPEXCEPTION,
            "ERROR_DBG_CONTROL_BREAK" => WIN32::ERROR_DBG_CONTROL_BREAK,
            "ERROR_DBG_COMMAND_EXCEPTION" => WIN32::ERROR_DBG_COMMAND_EXCEPTION,
            "ERROR_OBJECT_NAME_EXISTS" => WIN32::ERROR_OBJECT_NAME_EXISTS,
            "ERROR_THREAD_WAS_SUSPENDED" => WIN32::ERROR_THREAD_WAS_SUSPENDED,
            "ERROR_IMAGE_NOT_AT_BASE" => WIN32::ERROR_IMAGE_NOT_AT_BASE,
            "ERROR_RXACT_STATE_CREATED" => WIN32::ERROR_RXACT_STATE_CREATED,
            "ERROR_SEGMENT_NOTIFICATION" => WIN32::ERROR_SEGMENT_NOTIFICATION,
            "ERROR_BAD_CURRENT_DIRECTORY" => WIN32::ERROR_BAD_CURRENT_DIRECTORY,
            "ERROR_FT_READ_RECOVERY_FROM_BACKUP" => WIN32::ERROR_FT_READ_RECOVERY_FROM_BACKUP,
            "ERROR_FT_WRITE_RECOVERY" => WIN32::ERROR_FT_WRITE_RECOVERY,
            "ERROR_IMAGE_MACHINE_TYPE_MISMATCH" => WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH,
            "ERROR_RECEIVE_PARTIAL" => WIN32::ERROR_RECEIVE_PARTIAL,
            "ERROR_RECEIVE_EXPEDITED" => WIN32::ERROR_RECEIVE_EXPEDITED,
            "ERROR_RECEIVE_PARTIAL_EXPEDITED" => WIN32::ERROR_RECEIVE_PARTIAL_EXPEDITED,
            "ERROR_EVENT_DONE" => WIN32::ERROR_EVENT_DONE,
            "ERROR_EVENT_PENDING" => WIN32::ERROR_EVENT_PENDING,
            "ERROR_CHECKING_FILE_SYSTEM" => WIN32::ERROR_CHECKING_FILE_SYSTEM,
            "ERROR_FATAL_APP_EXIT" => WIN32::ERROR_FATAL_APP_EXIT,
            "ERROR_PREDEFINED_HANDLE" => WIN32::ERROR_PREDEFINED_HANDLE,
            "ERROR_WAS_UNLOCKED" => WIN32::ERROR_WAS_UNLOCKED,
            "ERROR_SERVICE_NOTIFICATION" => WIN32::ERROR_SERVICE_NOTIFICATION,
            "ERROR_WAS_LOCKED" => WIN32::ERROR_WAS_LOCKED,
            "ERROR_LOG_HARD_ERROR" => WIN32::ERROR_LOG_HARD_ERROR,
            "ERROR_ALREADY_WIN32" => WIN32::ERROR_ALREADY_WIN32,
            "ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE" => WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE,
            "ERROR_NO_YIELD_PERFORMED" => WIN32::ERROR_NO_YIELD_PERFORMED,
            "ERROR_TIMER_RESUME_IGNORED" => WIN32::ERROR_TIMER_RESUME_IGNORED,
            "ERROR_ARBITRATION_UNHANDLED" => WIN32::ERROR_ARBITRATION_UNHANDLED,
            "ERROR_CARDBUS_NOT_SUPPORTED" => WIN32::ERROR_CARDBUS_NOT_SUPPORTED,
            "ERROR_MP_PROCESSOR_MISMATCH" => WIN32::ERROR_MP_PROCESSOR_MISMATCH,
            "ERROR_HIBERNATED" => WIN32::ERROR_HIBERNATED,
            "ERROR_RESUME_HIBERNATION" => WIN32::ERROR_RESUME_HIBERNATION,
            "ERROR_FIRMWARE_UPDATED" => WIN32::ERROR_FIRMWARE_UPDATED,
            "ERROR_DRIVERS_LEAKING_LOCKED_PAGES" => WIN32::ERROR_DRIVERS_LEAKING_LOCKED_PAGES,
            "ERROR_WAKE_SYSTEM" => WIN32::ERROR_WAKE_SYSTEM,
            "ERROR_WAIT_1" => WIN32::ERROR_WAIT_1,
            "ERROR_WAIT_2" => WIN32::ERROR_WAIT_2,
            "ERROR_WAIT_3" => WIN32::ERROR_WAIT_3,
            "ERROR_WAIT_63" => WIN32::ERROR_WAIT_63,
            "ERROR_ABANDONED_WAIT_0" => WIN32::ERROR_ABANDONED_WAIT_0,
            "ERROR_ABANDONED_WAIT_63" => WIN32::ERROR_ABANDONED_WAIT_63,
            "ERROR_USER_APC" => WIN32::ERROR_USER_APC,
            "ERROR_KERNEL_APC" => WIN32::ERROR_KERNEL_APC,
            "ERROR_ALERTED" => WIN32::ERROR_ALERTED,
            "ERROR_ELEVATION_REQUIRED" => WIN32::ERROR_ELEVATION_REQUIRED,
            "ERROR_REPARSE" => WIN32::ERROR_REPARSE,
            "ERROR_OPLOCK_BREAK_IN_PROGRESS" => WIN32::ERROR_OPLOCK_BREAK_IN_PROGRESS,
            "ERROR_VOLUME_MOUNTED" => WIN32::ERROR_VOLUME_MOUNTED,
            "ERROR_RXACT_COMMITTED" => WIN32::ERROR_RXACT_COMMITTED,
            "ERROR_NOTIFY_CLEANUP" => WIN32::ERROR_NOTIFY_CLEANUP,
            "ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED" => WIN32::ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED,
            "ERROR_PAGE_FAULT_TRANSITION" => WIN32::ERROR_PAGE_FAULT_TRANSITION,
            "ERROR_PAGE_FAULT_DEMAND_ZERO" => WIN32::ERROR_PAGE_FAULT_DEMAND_ZERO,
            "ERROR_PAGE_FAULT_COPY_ON_WRITE" => WIN32::ERROR_PAGE_FAULT_COPY_ON_WRITE,
            "ERROR_PAGE_FAULT_GUARD_PAGE" => WIN32::ERROR_PAGE_FAULT_GUARD_PAGE,
            "ERROR_PAGE_FAULT_PAGING_FILE" => WIN32::ERROR_PAGE_FAULT_PAGING_FILE,
            "ERROR_CACHE_PAGE_LOCKED" => WIN32::ERROR_CACHE_PAGE_LOCKED,
            "ERROR_CRASH_DUMP" => WIN32::ERROR_CRASH_DUMP,
            "ERROR_BUFFER_ALL_ZEROS" => WIN32::ERROR_BUFFER_ALL_ZEROS,
            "ERROR_REPARSE_OBJECT" => WIN32::ERROR_REPARSE_OBJECT,
            "ERROR_RESOURCE_REQUIREMENTS_CHANGED" => WIN32::ERROR_RESOURCE_REQUIREMENTS_CHANGED,
            "ERROR_TRANSLATION_COMPLETE" => WIN32::ERROR_TRANSLATION_COMPLETE,
            "ERROR_NOTHING_TO_TERMINATE" => WIN32::ERROR_NOTHING_TO_TERMINATE,
            "ERROR_PROCESS_NOT_IN_JOB" => WIN32::ERROR_PROCESS_NOT_IN_JOB,
            "ERROR_PROCESS_IN_JOB" => WIN32::ERROR_PROCESS_IN_JOB,
            "ERROR_VOLSNAP_HIBERNATE_READY" => WIN32::ERROR_VOLSNAP_HIBERNATE_READY,
            "ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY" => WIN32::ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY,
            "ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED" => WIN32::ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED,
            "ERROR_INTERRUPT_STILL_CONNECTED" => WIN32::ERROR_INTERRUPT_STILL_CONNECTED,
            "ERROR_WAIT_FOR_OPLOCK" => WIN32::ERROR_WAIT_FOR_OPLOCK,
            "ERROR_DBG_EXCEPTION_HANDLED" => WIN32::ERROR_DBG_EXCEPTION_HANDLED,
            "ERROR_DBG_CONTINUE" => WIN32::ERROR_DBG_CONTINUE,
            "ERROR_CALLBACK_POP_STACK" => WIN32::ERROR_CALLBACK_POP_STACK,
            "ERROR_COMPRESSION_DISABLED" => WIN32::ERROR_COMPRESSION_DISABLED,
            "ERROR_CANTFETCHBACKWARDS" => WIN32::ERROR_CANTFETCHBACKWARDS,
            "ERROR_CANTSCROLLBACKWARDS" => WIN32::ERROR_CANTSCROLLBACKWARDS,
            "ERROR_ROWSNOTRELEASED" => WIN32::ERROR_ROWSNOTRELEASED,
            "ERROR_BAD_ACCESSOR_FLAGS" => WIN32::ERROR_BAD_ACCESSOR_FLAGS,
            "ERROR_ERRORS_ENCOUNTERED" => WIN32::ERROR_ERRORS_ENCOUNTERED,
            "ERROR_NOT_CAPABLE" => WIN32::ERROR_NOT_CAPABLE,
            "ERROR_REQUEST_OUT_OF_SEQUENCE" => WIN32::ERROR_REQUEST_OUT_OF_SEQUENCE,
            "ERROR_VERSION_PARSE_ERROR" => WIN32::ERROR_VERSION_PARSE_ERROR,
            "ERROR_BADSTARTPOSITION" => WIN32::ERROR_BADSTARTPOSITION,
            "ERROR_MEMORY_HARDWARE" => WIN32::ERROR_MEMORY_HARDWARE,
            "ERROR_DISK_REPAIR_DISABLED" => WIN32::ERROR_DISK_REPAIR_DISABLED,
            "ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE" => WIN32::ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE,
            "ERROR_SYSTEM_POWERSTATE_TRANSITION" => WIN32::ERROR_SYSTEM_POWERSTATE_TRANSITION,
            "ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION" => WIN32::ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION,
            "ERROR_MCA_EXCEPTION" => WIN32::ERROR_MCA_EXCEPTION,
            "ERROR_ACCESS_AUDIT_BY_POLICY" => WIN32::ERROR_ACCESS_AUDIT_BY_POLICY,
            "ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY" => WIN32::ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY,
            "ERROR_ABANDON_HIBERFILE" => WIN32::ERROR_ABANDON_HIBERFILE,
            "ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED" => WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED,
            "ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR" => WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR,
            "ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR" => WIN32::ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR,
            "ERROR_BAD_MCFG_TABLE" => WIN32::ERROR_BAD_MCFG_TABLE,
            "ERROR_DISK_REPAIR_REDIRECTED" => WIN32::ERROR_DISK_REPAIR_REDIRECTED,
            "ERROR_DISK_REPAIR_UNSUCCESSFUL" => WIN32::ERROR_DISK_REPAIR_UNSUCCESSFUL,
            "ERROR_CORRUPT_LOG_OVERFULL" => WIN32::ERROR_CORRUPT_LOG_OVERFULL,
            "ERROR_CORRUPT_LOG_CORRUPTED" => WIN32::ERROR_CORRUPT_LOG_CORRUPTED,
            "ERROR_CORRUPT_LOG_UNAVAILABLE" => WIN32::ERROR_CORRUPT_LOG_UNAVAILABLE,
            "ERROR_CORRUPT_LOG_DELETED_FULL" => WIN32::ERROR_CORRUPT_LOG_DELETED_FULL,
            "ERROR_CORRUPT_LOG_CLEARED" => WIN32::ERROR_CORRUPT_LOG_CLEARED,
            "ERROR_ORPHAN_NAME_EXHAUSTED" => WIN32::ERROR_ORPHAN_NAME_EXHAUSTED,
            "ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE" => WIN32::ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE,
            "ERROR_CANNOT_GRANT_REQUESTED_OPLOCK" => WIN32::ERROR_CANNOT_GRANT_REQUESTED_OPLOCK,
            "ERROR_CANNOT_BREAK_OPLOCK" => WIN32::ERROR_CANNOT_BREAK_OPLOCK,
            "ERROR_OPLOCK_HANDLE_CLOSED" => WIN32::ERROR_OPLOCK_HANDLE_CLOSED,
            "ERROR_NO_ACE_CONDITION" => WIN32::ERROR_NO_ACE_CONDITION,
            "ERROR_INVALID_ACE_CONDITION" => WIN32::ERROR_INVALID_ACE_CONDITION,
            "ERROR_FILE_HANDLE_REVOKED" => WIN32::ERROR_FILE_HANDLE_REVOKED,
            "ERROR_IMAGE_AT_DIFFERENT_BASE" => WIN32::ERROR_IMAGE_AT_DIFFERENT_BASE,
            "ERROR_ENCRYPTED_IO_NOT_POSSIBLE" => WIN32::ERROR_ENCRYPTED_IO_NOT_POSSIBLE,
            "ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS" => WIN32::ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS,
            "ERROR_QUOTA_ACTIVITY" => WIN32::ERROR_QUOTA_ACTIVITY,
            "ERROR_HANDLE_REVOKED" => WIN32::ERROR_HANDLE_REVOKED,
            "ERROR_CALLBACK_INVOKE_INLINE" => WIN32::ERROR_CALLBACK_INVOKE_INLINE,
            "ERROR_CPU_SET_INVALID" => WIN32::ERROR_CPU_SET_INVALID,
            "ERROR_ENCLAVE_NOT_TERMINATED" => WIN32::ERROR_ENCLAVE_NOT_TERMINATED,
            "ERROR_ENCLAVE_VIOLATION" => WIN32::ERROR_ENCLAVE_VIOLATION,
            "ERROR_SERVER_TRANSPORT_CONFLICT" => WIN32::ERROR_SERVER_TRANSPORT_CONFLICT,
            "ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT" => WIN32::ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT,
            "ERROR_FT_READ_FROM_COPY_FAILURE" => WIN32::ERROR_FT_READ_FROM_COPY_FAILURE,
            "ERROR_SECTION_DIRECT_MAP_ONLY" => WIN32::ERROR_SECTION_DIRECT_MAP_ONLY,
            "ERROR_EA_ACCESS_DENIED" => WIN32::ERROR_EA_ACCESS_DENIED,
            "ERROR_OPERATION_ABORTED" => WIN32::ERROR_OPERATION_ABORTED,
            "ERROR_IO_INCOMPLETE" => WIN32::ERROR_IO_INCOMPLETE,
            "ERROR_IO_PENDING" => WIN32::ERROR_IO_PENDING,
            "ERROR_NOACCESS" => WIN32::ERROR_NOACCESS,
            "ERROR_SWAPERROR" => WIN32::ERROR_SWAPERROR,
            "ERROR_STACK_OVERFLOW" => WIN32::ERROR_STACK_OVERFLOW,
            "ERROR_INVALID_MESSAGE" => WIN32::ERROR_INVALID_MESSAGE,
            "ERROR_CAN_NOT_COMPLETE" => WIN32::ERROR_CAN_NOT_COMPLETE,
            "ERROR_INVALID_FLAGS" => WIN32::ERROR_INVALID_FLAGS,
            "ERROR_UNRECOGNIZED_VOLUME" => WIN32::ERROR_UNRECOGNIZED_VOLUME,
            "ERROR_FILE_INVALID" => WIN32::ERROR_FILE_INVALID,
            "ERROR_FULLSCREEN_MODE" => WIN32::ERROR_FULLSCREEN_MODE,
            "ERROR_NO_TOKEN" => WIN32::ERROR_NO_TOKEN,
            "ERROR_BADDB" => WIN32::ERROR_BADDB,
            "ERROR_BADKEY" => WIN32::ERROR_BADKEY,
            "ERROR_CANTOPEN" => WIN32::ERROR_CANTOPEN,
            "ERROR_CANTREAD" => WIN32::ERROR_CANTREAD,
            "ERROR_CANTWRITE" => WIN32::ERROR_CANTWRITE,
            "ERROR_REGISTRY_RECOVERED" => WIN32::ERROR_REGISTRY_RECOVERED,
            "ERROR_REGISTRY_CORRUPT" => WIN32::ERROR_REGISTRY_CORRUPT,
            "ERROR_REGISTRY_IO_FAILED" => WIN32::ERROR_REGISTRY_IO_FAILED,
            "ERROR_NOT_REGISTRY_FILE" => WIN32::ERROR_NOT_REGISTRY_FILE,
            "ERROR_KEY_DELETED" => WIN32::ERROR_KEY_DELETED,
            "ERROR_NO_LOG_SPACE" => WIN32::ERROR_NO_LOG_SPACE,
            "ERROR_KEY_HAS_CHILDREN" => WIN32::ERROR_KEY_HAS_CHILDREN,
            "ERROR_CHILD_MUST_BE_VOLATILE" => WIN32::ERROR_CHILD_MUST_BE_VOLATILE,
            "ERROR_NOTIFY_ENUM_DIR" => WIN32::ERROR_NOTIFY_ENUM_DIR,
            "ERROR_DEPENDENT_SERVICES_RUNNING" => WIN32::ERROR_DEPENDENT_SERVICES_RUNNING,
            "ERROR_INVALID_SERVICE_CONTROL" => WIN32::ERROR_INVALID_SERVICE_CONTROL,
            "ERROR_SERVICE_REQUEST_TIMEOUT" => WIN32::ERROR_SERVICE_REQUEST_TIMEOUT,
            "ERROR_SERVICE_NO_THREAD" => WIN32::ERROR_SERVICE_NO_THREAD,
            "ERROR_SERVICE_DATABASE_LOCKED" => WIN32::ERROR_SERVICE_DATABASE_LOCKED,
            "ERROR_SERVICE_ALREADY_RUNNING" => WIN32::ERROR_SERVICE_ALREADY_RUNNING,
            "ERROR_INVALID_SERVICE_ACCOUNT" => WIN32::ERROR_INVALID_SERVICE_ACCOUNT,
            "ERROR_SERVICE_DISABLED" => WIN32::ERROR_SERVICE_DISABLED,
            "ERROR_CIRCULAR_DEPENDENCY" => WIN32::ERROR_CIRCULAR_DEPENDENCY,
            "ERROR_SERVICE_DOES_NOT_EXIST" => WIN32::ERROR_SERVICE_DOES_NOT_EXIST,
            "ERROR_SERVICE_CANNOT_ACCEPT_CTRL" => WIN32::ERROR_SERVICE_CANNOT_ACCEPT_CTRL,
            "ERROR_SERVICE_NOT_ACTIVE" => WIN32::ERROR_SERVICE_NOT_ACTIVE,
            "ERROR_FAILED_SERVICE_CONTROLLER_CONNECT" => WIN32::ERROR_FAILED_SERVICE_CONTROLLER_CONNECT,
            "ERROR_EXCEPTION_IN_SERVICE" => WIN32::ERROR_EXCEPTION_IN_SERVICE,
            "ERROR_DATABASE_DOES_NOT_EXIST" => WIN32::ERROR_DATABASE_DOES_NOT_EXIST,
            "ERROR_SERVICE_SPECIFIC_ERROR" => WIN32::ERROR_SERVICE_SPECIFIC_ERROR,
            "ERROR_PROCESS_ABORTED" => WIN32::ERROR_PROCESS_ABORTED,
            "ERROR_SERVICE_DEPENDENCY_FAIL" => WIN32::ERROR_SERVICE_DEPENDENCY_FAIL,
            "ERROR_SERVICE_LOGON_FAILED" => WIN32::ERROR_SERVICE_LOGON_FAILED,
            "ERROR_SERVICE_START_HANG" => WIN32::ERROR_SERVICE_START_HANG,
            "ERROR_INVALID_SERVICE_LOCK" => WIN32::ERROR_INVALID_SERVICE_LOCK,
            "ERROR_SERVICE_MARKED_FOR_DELETE" => WIN32::ERROR_SERVICE_MARKED_FOR_DELETE,
            "ERROR_SERVICE_EXISTS" => WIN32::ERROR_SERVICE_EXISTS,
            "ERROR_ALREADY_RUNNING_LKG" => WIN32::ERROR_ALREADY_RUNNING_LKG,
            "ERROR_SERVICE_DEPENDENCY_DELETED" => WIN32::ERROR_SERVICE_DEPENDENCY_DELETED,
            "ERROR_BOOT_ALREADY_ACCEPTED" => WIN32::ERROR_BOOT_ALREADY_ACCEPTED,
            "ERROR_SERVICE_NEVER_STARTED" => WIN32::ERROR_SERVICE_NEVER_STARTED,
            "ERROR_DUPLICATE_SERVICE_NAME" => WIN32::ERROR_DUPLICATE_SERVICE_NAME,
            "ERROR_DIFFERENT_SERVICE_ACCOUNT" => WIN32::ERROR_DIFFERENT_SERVICE_ACCOUNT,
            "ERROR_CANNOT_DETECT_DRIVER_FAILURE" => WIN32::ERROR_CANNOT_DETECT_DRIVER_FAILURE,
            "ERROR_CANNOT_DETECT_PROCESS_ABORT" => WIN32::ERROR_CANNOT_DETECT_PROCESS_ABORT,
            "ERROR_NO_RECOVERY_PROGRAM" => WIN32::ERROR_NO_RECOVERY_PROGRAM,
            "ERROR_SERVICE_NOT_IN_EXE" => WIN32::ERROR_SERVICE_NOT_IN_EXE,
            "ERROR_NOT_SAFEBOOT_SERVICE" => WIN32::ERROR_NOT_SAFEBOOT_SERVICE,
            "ERROR_END_OF_MEDIA" => WIN32::ERROR_END_OF_MEDIA,
            "ERROR_FILEMARK_DETECTED" => WIN32::ERROR_FILEMARK_DETECTED,
            "ERROR_BEGINNING_OF_MEDIA" => WIN32::ERROR_BEGINNING_OF_MEDIA,
            "ERROR_SETMARK_DETECTED" => WIN32::ERROR_SETMARK_DETECTED,
            "ERROR_NO_DATA_DETECTED" => WIN32::ERROR_NO_DATA_DETECTED,
            "ERROR_PARTITION_FAILURE" => WIN32::ERROR_PARTITION_FAILURE,
            "ERROR_INVALID_BLOCK_LENGTH" => WIN32::ERROR_INVALID_BLOCK_LENGTH,
            "ERROR_DEVICE_NOT_PARTITIONED" => WIN32::ERROR_DEVICE_NOT_PARTITIONED,
            "ERROR_UNABLE_TO_LOCK_MEDIA" => WIN32::ERROR_UNABLE_TO_LOCK_MEDIA,
            "ERROR_UNABLE_TO_UNLOAD_MEDIA" => WIN32::ERROR_UNABLE_TO_UNLOAD_MEDIA,
            "ERROR_MEDIA_CHANGED" => WIN32::ERROR_MEDIA_CHANGED,
            "ERROR_BUS_RESET" => WIN32::ERROR_BUS_RESET,
            "ERROR_NO_MEDIA_IN_DRIVE" => WIN32::ERROR_NO_MEDIA_IN_DRIVE,
            "ERROR_NO_UNICODE_TRANSLATION" => WIN32::ERROR_NO_UNICODE_TRANSLATION,
            "ERROR_DLL_INIT_FAILED" => WIN32::ERROR_DLL_INIT_FAILED,
            "ERROR_SHUTDOWN_IN_PROGRESS" => WIN32::ERROR_SHUTDOWN_IN_PROGRESS,
            "ERROR_NO_SHUTDOWN_IN_PROGRESS" => WIN32::ERROR_NO_SHUTDOWN_IN_PROGRESS,
            "ERROR_IO_DEVICE" => WIN32::ERROR_IO_DEVICE,
            "ERROR_SERIAL_NO_DEVICE" => WIN32::ERROR_SERIAL_NO_DEVICE,
            "ERROR_IRQ_BUSY" => WIN32::ERROR_IRQ_BUSY,
            "ERROR_MORE_WRITES" => WIN32::ERROR_MORE_WRITES,
            "ERROR_COUNTER_TIMEOUT" => WIN32::ERROR_COUNTER_TIMEOUT,
            "ERROR_FLOPPY_ID_MARK_NOT_FOUND" => WIN32::ERROR_FLOPPY_ID_MARK_NOT_FOUND,
            "ERROR_FLOPPY_WRONG_CYLINDER" => WIN32::ERROR_FLOPPY_WRONG_CYLINDER,
            "ERROR_FLOPPY_UNKNOWN_ERROR" => WIN32::ERROR_FLOPPY_UNKNOWN_ERROR,
            "ERROR_FLOPPY_BAD_REGISTERS" => WIN32::ERROR_FLOPPY_BAD_REGISTERS,
            "ERROR_DISK_RECALIBRATE_FAILED" => WIN32::ERROR_DISK_RECALIBRATE_FAILED,
            "ERROR_DISK_OPERATION_FAILED" => WIN32::ERROR_DISK_OPERATION_FAILED,
            "ERROR_DISK_RESET_FAILED" => WIN32::ERROR_DISK_RESET_FAILED,
            "ERROR_EOM_OVERFLOW" => WIN32::ERROR_EOM_OVERFLOW,
            "ERROR_NOT_ENOUGH_SERVER_MEMORY" => WIN32::ERROR_NOT_ENOUGH_SERVER_MEMORY,
            "ERROR_POSSIBLE_DEADLOCK" => WIN32::ERROR_POSSIBLE_DEADLOCK,
            "ERROR_MAPPED_ALIGNMENT" => WIN32::ERROR_MAPPED_ALIGNMENT,
            "ERROR_SET_POWER_STATE_VETOED" => WIN32::ERROR_SET_POWER_STATE_VETOED,
            "ERROR_SET_POWER_STATE_FAILED" => WIN32::ERROR_SET_POWER_STATE_FAILED,
            "ERROR_TOO_MANY_LINKS" => WIN32::ERROR_TOO_MANY_LINKS,
            "ERROR_OLD_WIN_VERSION" => WIN32::ERROR_OLD_WIN_VERSION,
            "ERROR_APP_WRONG_OS" => WIN32::ERROR_APP_WRONG_OS,
            "ERROR_SINGLE_INSTANCE_APP" => WIN32::ERROR_SINGLE_INSTANCE_APP,
            "ERROR_RMODE_APP" => WIN32::ERROR_RMODE_APP,
            "ERROR_INVALID_DLL" => WIN32::ERROR_INVALID_DLL,
            "ERROR_NO_ASSOCIATION" => WIN32::ERROR_NO_ASSOCIATION,
            "ERROR_DDE_FAIL" => WIN32::ERROR_DDE_FAIL,
            "ERROR_DLL_NOT_FOUND" => WIN32::ERROR_DLL_NOT_FOUND,
            "ERROR_NO_MORE_USER_HANDLES" => WIN32::ERROR_NO_MORE_USER_HANDLES,
            "ERROR_MESSAGE_SYNC_ONLY" => WIN32::ERROR_MESSAGE_SYNC_ONLY,
            "ERROR_SOURCE_ELEMENT_EMPTY" => WIN32::ERROR_SOURCE_ELEMENT_EMPTY,
            "ERROR_DESTINATION_ELEMENT_FULL" => WIN32::ERROR_DESTINATION_ELEMENT_FULL,
            "ERROR_ILLEGAL_ELEMENT_ADDRESS" => WIN32::ERROR_ILLEGAL_ELEMENT_ADDRESS,
            "ERROR_MAGAZINE_NOT_PRESENT" => WIN32::ERROR_MAGAZINE_NOT_PRESENT,
            "ERROR_DEVICE_REINITIALIZATION_NEEDED" => WIN32::ERROR_DEVICE_REINITIALIZATION_NEEDED,
            "ERROR_DEVICE_REQUIRES_CLEANING" => WIN32::ERROR_DEVICE_REQUIRES_CLEANING,
            "ERROR_DEVICE_DOOR_OPEN" => WIN32::ERROR_DEVICE_DOOR_OPEN,
            "ERROR_DEVICE_NOT_CONNECTED" => WIN32::ERROR_DEVICE_NOT_CONNECTED,
            "ERROR_NOT_FOUND" => WIN32::ERROR_NOT_FOUND,
            "E_PROP_ID_UNSUPPORTED" => WIN32::E_PROP_ID_UNSUPPORTED,
            "ERROR_NO_MATCH" => WIN32::ERROR_NO_MATCH,
            "ERROR_SET_NOT_FOUND" => WIN32::ERROR_SET_NOT_FOUND,
            "E_PROP_SET_UNSUPPORTED" => WIN32::E_PROP_SET_UNSUPPORTED,
            "ERROR_POINT_NOT_FOUND" => WIN32::ERROR_POINT_NOT_FOUND,
            "ERROR_NO_TRACKING_SERVICE" => WIN32::ERROR_NO_TRACKING_SERVICE,
            "ERROR_NO_VOLUME_ID" => WIN32::ERROR_NO_VOLUME_ID,
            "ERROR_UNABLE_TO_REMOVE_REPLACED" => WIN32::ERROR_UNABLE_TO_REMOVE_REPLACED,
            "ERROR_UNABLE_TO_MOVE_REPLACEMENT" => WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT,
            "ERROR_UNABLE_TO_MOVE_REPLACEMENT_2" => WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT_2,
            "ERROR_JOURNAL_DELETE_IN_PROGRESS" => WIN32::ERROR_JOURNAL_DELETE_IN_PROGRESS,
            "ERROR_JOURNAL_NOT_ACTIVE" => WIN32::ERROR_JOURNAL_NOT_ACTIVE,
            "ERROR_POTENTIAL_FILE_FOUND" => WIN32::ERROR_POTENTIAL_FILE_FOUND,
            "ERROR_JOURNAL_ENTRY_DELETED" => WIN32::ERROR_JOURNAL_ENTRY_DELETED,
            "ERROR_VRF_CFG_ENABLED" => WIN32::ERROR_VRF_CFG_ENABLED,
            "ERROR_PARTITION_TERMINATING" => WIN32::ERROR_PARTITION_TERMINATING,
            "ERROR_SHUTDOWN_IS_SCHEDULED" => WIN32::ERROR_SHUTDOWN_IS_SCHEDULED,
            "ERROR_SHUTDOWN_USERS_LOGGED_ON" => WIN32::ERROR_SHUTDOWN_USERS_LOGGED_ON,
            "ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE" => WIN32::ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE,
            "ERROR_BAD_DEVICE" => WIN32::ERROR_BAD_DEVICE,
            "ERROR_CONNECTION_UNAVAIL" => WIN32::ERROR_CONNECTION_UNAVAIL,
            "ERROR_DEVICE_ALREADY_REMEMBERED" => WIN32::ERROR_DEVICE_ALREADY_REMEMBERED,
            "ERROR_NO_NET_OR_BAD_PATH" => WIN32::ERROR_NO_NET_OR_BAD_PATH,
            "ERROR_BAD_PROVIDER" => WIN32::ERROR_BAD_PROVIDER,
            "ERROR_CANNOT_OPEN_PROFILE" => WIN32::ERROR_CANNOT_OPEN_PROFILE,
            "ERROR_BAD_PROFILE" => WIN32::ERROR_BAD_PROFILE,
            "ERROR_NOT_CONTAINER" => WIN32::ERROR_NOT_CONTAINER,
            "ERROR_EXTENDED_ERROR" => WIN32::ERROR_EXTENDED_ERROR,
            "ERROR_INVALID_GROUPNAME" => WIN32::ERROR_INVALID_GROUPNAME,
            "ERROR_INVALID_COMPUTERNAME" => WIN32::ERROR_INVALID_COMPUTERNAME,
            "ERROR_INVALID_EVENTNAME" => WIN32::ERROR_INVALID_EVENTNAME,
            "ERROR_INVALID_DOMAINNAME" => WIN32::ERROR_INVALID_DOMAINNAME,
            "ERROR_INVALID_SERVICENAME" => WIN32::ERROR_INVALID_SERVICENAME,
            "ERROR_INVALID_NETNAME" => WIN32::ERROR_INVALID_NETNAME,
            "ERROR_INVALID_SHARENAME" => WIN32::ERROR_INVALID_SHARENAME,
            "ERROR_INVALID_PASSWORDNAME" => WIN32::ERROR_INVALID_PASSWORDNAME,
            "ERROR_INVALID_MESSAGENAME" => WIN32::ERROR_INVALID_MESSAGENAME,
            "ERROR_INVALID_MESSAGEDEST" => WIN32::ERROR_INVALID_MESSAGEDEST,
            "ERROR_SESSION_CREDENTIAL_CONFLICT" => WIN32::ERROR_SESSION_CREDENTIAL_CONFLICT,
            "ERROR_REMOTE_SESSION_LIMIT_EXCEEDED" => WIN32::ERROR_REMOTE_SESSION_LIMIT_EXCEEDED,
            "ERROR_DUP_DOMAINNAME" => WIN32::ERROR_DUP_DOMAINNAME,
            "ERROR_NO_NETWORK" => WIN32::ERROR_NO_NETWORK,
            "ERROR_CANCELLED" => WIN32::ERROR_CANCELLED,
            "ERROR_USER_MAPPED_FILE" => WIN32::ERROR_USER_MAPPED_FILE,
            "ERROR_CONNECTION_REFUSED" => WIN32::ERROR_CONNECTION_REFUSED,
            "ERROR_GRACEFUL_DISCONNECT" => WIN32::ERROR_GRACEFUL_DISCONNECT,
            "ERROR_ADDRESS_ALREADY_ASSOCIATED" => WIN32::ERROR_ADDRESS_ALREADY_ASSOCIATED,
            "ERROR_ADDRESS_NOT_ASSOCIATED" => WIN32::ERROR_ADDRESS_NOT_ASSOCIATED,
            "ERROR_CONNECTION_INVALID" => WIN32::ERROR_CONNECTION_INVALID,
            "ERROR_CONNECTION_ACTIVE" => WIN32::ERROR_CONNECTION_ACTIVE,
            "ERROR_NETWORK_UNREACHABLE" => WIN32::ERROR_NETWORK_UNREACHABLE,
            "ERROR_HOST_UNREACHABLE" => WIN32::ERROR_HOST_UNREACHABLE,
            "ERROR_PROTOCOL_UNREACHABLE" => WIN32::ERROR_PROTOCOL_UNREACHABLE,
            "ERROR_PORT_UNREACHABLE" => WIN32::ERROR_PORT_UNREACHABLE,
            "ERROR_REQUEST_ABORTED" => WIN32::ERROR_REQUEST_ABORTED,
            "ERROR_CONNECTION_ABORTED" => WIN32::ERROR_CONNECTION_ABORTED,
            "ERROR_RETRY" => WIN32::ERROR_RETRY,
            "ERROR_CONNECTION_COUNT_LIMIT" => WIN32::ERROR_CONNECTION_COUNT_LIMIT,
            "ERROR_LOGIN_TIME_RESTRICTION" => WIN32::ERROR_LOGIN_TIME_RESTRICTION,
            "ERROR_LOGIN_WKSTA_RESTRICTION" => WIN32::ERROR_LOGIN_WKSTA_RESTRICTION,
            "ERROR_INCORRECT_ADDRESS" => WIN32::ERROR_INCORRECT_ADDRESS,
            "ERROR_ALREADY_REGISTERED" => WIN32::ERROR_ALREADY_REGISTERED,
            "ERROR_SERVICE_NOT_FOUND" => WIN32::ERROR_SERVICE_NOT_FOUND,
            "ERROR_NOT_AUTHENTICATED" => WIN32::ERROR_NOT_AUTHENTICATED,
            "ERROR_NOT_LOGGED_ON" => WIN32::ERROR_NOT_LOGGED_ON,
            "ERROR_CONTINUE" => WIN32::ERROR_CONTINUE,
            "ERROR_ALREADY_INITIALIZED" => WIN32::ERROR_ALREADY_INITIALIZED,
            "ERROR_NO_MORE_DEVICES" => WIN32::ERROR_NO_MORE_DEVICES,
            "ERROR_NO_SUCH_SITE" => WIN32::ERROR_NO_SUCH_SITE,
            "ERROR_DOMAIN_CONTROLLER_EXISTS" => WIN32::ERROR_DOMAIN_CONTROLLER_EXISTS,
            "ERROR_ONLY_IF_CONNECTED" => WIN32::ERROR_ONLY_IF_CONNECTED,
            "ERROR_OVERRIDE_NOCHANGES" => WIN32::ERROR_OVERRIDE_NOCHANGES,
            "ERROR_BAD_USER_PROFILE" => WIN32::ERROR_BAD_USER_PROFILE,
            "ERROR_NOT_SUPPORTED_ON_SBS" => WIN32::ERROR_NOT_SUPPORTED_ON_SBS,
            "ERROR_SERVER_SHUTDOWN_IN_PROGRESS" => WIN32::ERROR_SERVER_SHUTDOWN_IN_PROGRESS,
            "ERROR_HOST_DOWN" => WIN32::ERROR_HOST_DOWN,
            "ERROR_NON_ACCOUNT_SID" => WIN32::ERROR_NON_ACCOUNT_SID,
            "ERROR_NON_DOMAIN_SID" => WIN32::ERROR_NON_DOMAIN_SID,
            "ERROR_APPHELP_BLOCK" => WIN32::ERROR_APPHELP_BLOCK,
            "ERROR_ACCESS_DISABLED_BY_POLICY" => WIN32::ERROR_ACCESS_DISABLED_BY_POLICY,
            "ERROR_REG_NAT_CONSUMPTION" => WIN32::ERROR_REG_NAT_CONSUMPTION,
            "ERROR_CSCSHARE_OFFLINE" => WIN32::ERROR_CSCSHARE_OFFLINE,
            "ERROR_PKINIT_FAILURE" => WIN32::ERROR_PKINIT_FAILURE,
            "ERROR_SMARTCARD_SUBSYSTEM_FAILURE" => WIN32::ERROR_SMARTCARD_SUBSYSTEM_FAILURE,
            "ERROR_DOWNGRADE_DETECTED" => WIN32::ERROR_DOWNGRADE_DETECTED,
            "ERROR_MACHINE_LOCKED" => WIN32::ERROR_MACHINE_LOCKED,
            "ERROR_SMB_GUEST_LOGON_BLOCKED" => WIN32::ERROR_SMB_GUEST_LOGON_BLOCKED,
            "ERROR_CALLBACK_SUPPLIED_INVALID_DATA" => WIN32::ERROR_CALLBACK_SUPPLIED_INVALID_DATA,
            "ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED" => WIN32::ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED,
            "ERROR_DRIVER_BLOCKED" => WIN32::ERROR_DRIVER_BLOCKED,
            "ERROR_INVALID_IMPORT_OF_NON_DLL" => WIN32::ERROR_INVALID_IMPORT_OF_NON_DLL,
            "ERROR_ACCESS_DISABLED_WEBBLADE" => WIN32::ERROR_ACCESS_DISABLED_WEBBLADE,
            "ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER" => WIN32::ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER,
            "ERROR_RECOVERY_FAILURE" => WIN32::ERROR_RECOVERY_FAILURE,
            "ERROR_ALREADY_FIBER" => WIN32::ERROR_ALREADY_FIBER,
            "ERROR_ALREADY_THREAD" => WIN32::ERROR_ALREADY_THREAD,
            "ERROR_STACK_BUFFER_OVERRUN" => WIN32::ERROR_STACK_BUFFER_OVERRUN,
            "ERROR_PARAMETER_QUOTA_EXCEEDED" => WIN32::ERROR_PARAMETER_QUOTA_EXCEEDED,
            "ERROR_DEBUGGER_INACTIVE" => WIN32::ERROR_DEBUGGER_INACTIVE,
            "ERROR_DELAY_LOAD_FAILED" => WIN32::ERROR_DELAY_LOAD_FAILED,
            "ERROR_VDM_DISALLOWED" => WIN32::ERROR_VDM_DISALLOWED,
            "ERROR_UNIDENTIFIED_ERROR" => WIN32::ERROR_UNIDENTIFIED_ERROR,
            "ERROR_INVALID_CRUNTIME_PARAMETER" => WIN32::ERROR_INVALID_CRUNTIME_PARAMETER,
            "ERROR_BEYOND_VDL" => WIN32::ERROR_BEYOND_VDL,
            "ERROR_INCOMPATIBLE_SERVICE_SID_TYPE" => WIN32::ERROR_INCOMPATIBLE_SERVICE_SID_TYPE,
            "ERROR_DRIVER_PROCESS_TERMINATED" => WIN32::ERROR_DRIVER_PROCESS_TERMINATED,
            "ERROR_IMPLEMENTATION_LIMIT" => WIN32::ERROR_IMPLEMENTATION_LIMIT,
            "ERROR_PROCESS_IS_PROTECTED" => WIN32::ERROR_PROCESS_IS_PROTECTED,
            "ERROR_SERVICE_NOTIFY_CLIENT_LAGGING" => WIN32::ERROR_SERVICE_NOTIFY_CLIENT_LAGGING,
            "ERROR_DISK_QUOTA_EXCEEDED" => WIN32::ERROR_DISK_QUOTA_EXCEEDED,
            "ERROR_CONTENT_BLOCKED" => WIN32::ERROR_CONTENT_BLOCKED,
            "ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE" => WIN32::ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE,
            "ERROR_APP_HANG" => WIN32::ERROR_APP_HANG,
            "ERROR_INVALID_LABEL" => WIN32::ERROR_INVALID_LABEL,
            "ERROR_NOT_ALL_ASSIGNED" => WIN32::ERROR_NOT_ALL_ASSIGNED,
            "ERROR_SOME_NOT_MAPPED" => WIN32::ERROR_SOME_NOT_MAPPED,
            "ERROR_NO_QUOTAS_FOR_ACCOUNT" => WIN32::ERROR_NO_QUOTAS_FOR_ACCOUNT,
            "ERROR_LOCAL_USER_SESSION_KEY" => WIN32::ERROR_LOCAL_USER_SESSION_KEY,
            "ERROR_NULL_LM_PASSWORD" => WIN32::ERROR_NULL_LM_PASSWORD,
            "ERROR_UNKNOWN_REVISION" => WIN32::ERROR_UNKNOWN_REVISION,
            "ERROR_REVISION_MISMATCH" => WIN32::ERROR_REVISION_MISMATCH,
            "ERROR_INVALID_OWNER" => WIN32::ERROR_INVALID_OWNER,
            "ERROR_INVALID_PRIMARY_GROUP" => WIN32::ERROR_INVALID_PRIMARY_GROUP,
            "ERROR_NO_IMPERSONATION_TOKEN" => WIN32::ERROR_NO_IMPERSONATION_TOKEN,
            "ERROR_CANT_DISABLE_MANDATORY" => WIN32::ERROR_CANT_DISABLE_MANDATORY,
            "ERROR_NO_LOGON_SERVERS" => WIN32::ERROR_NO_LOGON_SERVERS,
            "ERROR_NO_SUCH_LOGON_SESSION" => WIN32::ERROR_NO_SUCH_LOGON_SESSION,
            "ERROR_NO_SUCH_PRIVILEGE" => WIN32::ERROR_NO_SUCH_PRIVILEGE,
            "ERROR_PRIVILEGE_NOT_HELD" => WIN32::ERROR_PRIVILEGE_NOT_HELD,
            "ERROR_INVALID_ACCOUNT_NAME" => WIN32::ERROR_INVALID_ACCOUNT_NAME,
            "ERROR_USER_EXISTS" => WIN32::ERROR_USER_EXISTS,
            "ERROR_NO_SUCH_USER" => WIN32::ERROR_NO_SUCH_USER,
            "ERROR_GROUP_EXISTS" => WIN32::ERROR_GROUP_EXISTS,
            "ERROR_NO_SUCH_GROUP" => WIN32::ERROR_NO_SUCH_GROUP,
            "ERROR_MEMBER_IN_GROUP" => WIN32::ERROR_MEMBER_IN_GROUP,
            "ERROR_MEMBER_NOT_IN_GROUP" => WIN32::ERROR_MEMBER_NOT_IN_GROUP,
            "ERROR_LAST_ADMIN" => WIN32::ERROR_LAST_ADMIN,
            "ERROR_WRONG_PASSWORD" => WIN32::ERROR_WRONG_PASSWORD,
            "ERROR_ILL_FORMED_PASSWORD" => WIN32::ERROR_ILL_FORMED_PASSWORD,
            "ERROR_PASSWORD_RESTRICTION" => WIN32::ERROR_PASSWORD_RESTRICTION,
            "ERROR_LOGON_FAILURE" => WIN32::ERROR_LOGON_FAILURE,
            "ERROR_ACCOUNT_RESTRICTION" => WIN32::ERROR_ACCOUNT_RESTRICTION,
            "ERROR_INVALID_LOGON_HOURS" => WIN32::ERROR_INVALID_LOGON_HOURS,
            "ERROR_INVALID_WORKSTATION" => WIN32::ERROR_INVALID_WORKSTATION,
            "ERROR_PASSWORD_EXPIRED" => WIN32::ERROR_PASSWORD_EXPIRED,
            "ERROR_ACCOUNT_DISABLED" => WIN32::ERROR_ACCOUNT_DISABLED,
            "ERROR_NONE_MAPPED" => WIN32::ERROR_NONE_MAPPED,
            "ERROR_TOO_MANY_LUIDS_REQUESTED" => WIN32::ERROR_TOO_MANY_LUIDS_REQUESTED,
            "ERROR_LUIDS_EXHAUSTED" => WIN32::ERROR_LUIDS_EXHAUSTED,
            "ERROR_INVALID_SUB_AUTHORITY" => WIN32::ERROR_INVALID_SUB_AUTHORITY,
            "ERROR_INVALID_ACL" => WIN32::ERROR_INVALID_ACL,
            "ERROR_INVALID_SID" => WIN32::ERROR_INVALID_SID,
            "ERROR_INVALID_SECURITY_DESCR" => WIN32::ERROR_INVALID_SECURITY_DESCR,
            "ERROR_BAD_INHERITANCE_ACL" => WIN32::ERROR_BAD_INHERITANCE_ACL,
            "ERROR_SERVER_DISABLED" => WIN32::ERROR_SERVER_DISABLED,
            "ERROR_SERVER_NOT_DISABLED" => WIN32::ERROR_SERVER_NOT_DISABLED,
            "ERROR_INVALID_ID_AUTHORITY" => WIN32::ERROR_INVALID_ID_AUTHORITY,
            "ERROR_ALLOTTED_SPACE_EXCEEDED" => WIN32::ERROR_ALLOTTED_SPACE_EXCEEDED,
            "ERROR_INVALID_GROUP_ATTRIBUTES" => WIN32::ERROR_INVALID_GROUP_ATTRIBUTES,
            "ERROR_BAD_IMPERSONATION_LEVEL" => WIN32::ERROR_BAD_IMPERSONATION_LEVEL,
            "ERROR_CANT_OPEN_ANONYMOUS" => WIN32::ERROR_CANT_OPEN_ANONYMOUS,
            "ERROR_BAD_VALIDATION_CLASS" => WIN32::ERROR_BAD_VALIDATION_CLASS,
            "ERROR_BAD_TOKEN_TYPE" => WIN32::ERROR_BAD_TOKEN_TYPE,
            "ERROR_NO_SECURITY_ON_OBJECT" => WIN32::ERROR_NO_SECURITY_ON_OBJECT,
            "ERROR_CANT_ACCESS_DOMAIN_INFO" => WIN32::ERROR_CANT_ACCESS_DOMAIN_INFO,
            "ERROR_INVALID_SERVER_STATE" => WIN32::ERROR_INVALID_SERVER_STATE,
            "ERROR_INVALID_DOMAIN_STATE" => WIN32::ERROR_INVALID_DOMAIN_STATE,
            "ERROR_INVALID_DOMAIN_ROLE" => WIN32::ERROR_INVALID_DOMAIN_ROLE,
            "ERROR_NO_SUCH_DOMAIN" => WIN32::ERROR_NO_SUCH_DOMAIN,
            "ERROR_DOMAIN_EXISTS" => WIN32::ERROR_DOMAIN_EXISTS,
            "ERROR_DOMAIN_LIMIT_EXCEEDED" => WIN32::ERROR_DOMAIN_LIMIT_EXCEEDED,
            "ERROR_INTERNAL_DB_CORRUPTION" => WIN32::ERROR_INTERNAL_DB_CORRUPTION,
            "ERROR_INTERNAL_ERROR" => WIN32::ERROR_INTERNAL_ERROR,
            "ERROR_GENERIC_NOT_MAPPED" => WIN32::ERROR_GENERIC_NOT_MAPPED,
            "ERROR_BAD_DESCRIPTOR_FORMAT" => WIN32::ERROR_BAD_DESCRIPTOR_FORMAT,
            "ERROR_NOT_LOGON_PROCESS" => WIN32::ERROR_NOT_LOGON_PROCESS,
            "ERROR_LOGON_SESSION_EXISTS" => WIN32::ERROR_LOGON_SESSION_EXISTS,
            "ERROR_NO_SUCH_PACKAGE" => WIN32::ERROR_NO_SUCH_PACKAGE,
            "ERROR_BAD_LOGON_SESSION_STATE" => WIN32::ERROR_BAD_LOGON_SESSION_STATE,
            "ERROR_LOGON_SESSION_COLLISION" => WIN32::ERROR_LOGON_SESSION_COLLISION,
            "ERROR_INVALID_LOGON_TYPE" => WIN32::ERROR_INVALID_LOGON_TYPE,
            "ERROR_CANNOT_IMPERSONATE" => WIN32::ERROR_CANNOT_IMPERSONATE,
            "ERROR_RXACT_INVALID_STATE" => WIN32::ERROR_RXACT_INVALID_STATE,
            "ERROR_RXACT_COMMIT_FAILURE" => WIN32::ERROR_RXACT_COMMIT_FAILURE,
            "ERROR_SPECIAL_ACCOUNT" => WIN32::ERROR_SPECIAL_ACCOUNT,
            "ERROR_SPECIAL_GROUP" => WIN32::ERROR_SPECIAL_GROUP,
            "ERROR_SPECIAL_USER" => WIN32::ERROR_SPECIAL_USER,
            "ERROR_MEMBERS_PRIMARY_GROUP" => WIN32::ERROR_MEMBERS_PRIMARY_GROUP,
            "ERROR_TOKEN_ALREADY_IN_USE" => WIN32::ERROR_TOKEN_ALREADY_IN_USE,
            "ERROR_NO_SUCH_ALIAS" => WIN32::ERROR_NO_SUCH_ALIAS,
            "ERROR_MEMBER_NOT_IN_ALIAS" => WIN32::ERROR_MEMBER_NOT_IN_ALIAS,
            "ERROR_MEMBER_IN_ALIAS" => WIN32::ERROR_MEMBER_IN_ALIAS,
            "ERROR_ALIAS_EXISTS" => WIN32::ERROR_ALIAS_EXISTS,
            "ERROR_LOGON_NOT_GRANTED" => WIN32::ERROR_LOGON_NOT_GRANTED,
            "ERROR_TOO_MANY_SECRETS" => WIN32::ERROR_TOO_MANY_SECRETS,
            "ERROR_SECRET_TOO_LONG" => WIN32::ERROR_SECRET_TOO_LONG,
            "ERROR_INTERNAL_DB_ERROR" => WIN32::ERROR_INTERNAL_DB_ERROR,
            "ERROR_TOO_MANY_CONTEXT_IDS" => WIN32::ERROR_TOO_MANY_CONTEXT_IDS,
            "ERROR_LOGON_TYPE_NOT_GRANTED" => WIN32::ERROR_LOGON_TYPE_NOT_GRANTED,
            "ERROR_NT_CROSS_ENCRYPTION_REQUIRED" => WIN32::ERROR_NT_CROSS_ENCRYPTION_REQUIRED,
            "ERROR_NO_SUCH_MEMBER" => WIN32::ERROR_NO_SUCH_MEMBER,
            "ERROR_INVALID_MEMBER" => WIN32::ERROR_INVALID_MEMBER,
            "ERROR_TOO_MANY_SIDS" => WIN32::ERROR_TOO_MANY_SIDS,
            "ERROR_LM_CROSS_ENCRYPTION_REQUIRED" => WIN32::ERROR_LM_CROSS_ENCRYPTION_REQUIRED,
            "ERROR_NO_INHERITANCE" => WIN32::ERROR_NO_INHERITANCE,
            "ERROR_FILE_CORRUPT" => WIN32::ERROR_FILE_CORRUPT,
            "ERROR_DISK_CORRUPT" => WIN32::ERROR_DISK_CORRUPT,
            "ERROR_NO_USER_SESSION_KEY" => WIN32::ERROR_NO_USER_SESSION_KEY,
            "ERROR_LICENSE_QUOTA_EXCEEDED" => WIN32::ERROR_LICENSE_QUOTA_EXCEEDED,
            "ERROR_WRONG_TARGET_NAME" => WIN32::ERROR_WRONG_TARGET_NAME,
            "ERROR_MUTUAL_AUTH_FAILED" => WIN32::ERROR_MUTUAL_AUTH_FAILED,
            "ERROR_TIME_SKEW" => WIN32::ERROR_TIME_SKEW,
            "ERROR_CURRENT_DOMAIN_NOT_ALLOWED" => WIN32::ERROR_CURRENT_DOMAIN_NOT_ALLOWED,
            "ERROR_INVALID_WINDOW_HANDLE" => WIN32::ERROR_INVALID_WINDOW_HANDLE,
            "ERROR_INVALID_MENU_HANDLE" => WIN32::ERROR_INVALID_MENU_HANDLE,
            "ERROR_INVALID_CURSOR_HANDLE" => WIN32::ERROR_INVALID_CURSOR_HANDLE,
            "ERROR_INVALID_ACCEL_HANDLE" => WIN32::ERROR_INVALID_ACCEL_HANDLE,
            "ERROR_INVALID_HOOK_HANDLE" => WIN32::ERROR_INVALID_HOOK_HANDLE,
            "ERROR_INVALID_DWP_HANDLE" => WIN32::ERROR_INVALID_DWP_HANDLE,
            "ERROR_TLW_WITH_WSCHILD" => WIN32::ERROR_TLW_WITH_WSCHILD,
            "ERROR_CANNOT_FIND_WND_CLASS" => WIN32::ERROR_CANNOT_FIND_WND_CLASS,
            "ERROR_WINDOW_OF_OTHER_THREAD" => WIN32::ERROR_WINDOW_OF_OTHER_THREAD,
            "ERROR_HOTKEY_ALREADY_REGISTERED" => WIN32::ERROR_HOTKEY_ALREADY_REGISTERED,
            "ERROR_CLASS_ALREADY_EXISTS" => WIN32::ERROR_CLASS_ALREADY_EXISTS,
            "ERROR_CLASS_DOES_NOT_EXIST" => WIN32::ERROR_CLASS_DOES_NOT_EXIST,
            "ERROR_CLASS_HAS_WINDOWS" => WIN32::ERROR_CLASS_HAS_WINDOWS,
            "ERROR_INVALID_INDEX" => WIN32::ERROR_INVALID_INDEX,
            "ERROR_INVALID_ICON_HANDLE" => WIN32::ERROR_INVALID_ICON_HANDLE,
            "ERROR_PRIVATE_DIALOG_INDEX" => WIN32::ERROR_PRIVATE_DIALOG_INDEX,
            "ERROR_LISTBOX_ID_NOT_FOUND" => WIN32::ERROR_LISTBOX_ID_NOT_FOUND,
            "ERROR_NO_WILDCARD_CHARACTERS" => WIN32::ERROR_NO_WILDCARD_CHARACTERS,
            "ERROR_CLIPBOARD_NOT_OPEN" => WIN32::ERROR_CLIPBOARD_NOT_OPEN,
            "ERROR_HOTKEY_NOT_REGISTERED" => WIN32::ERROR_HOTKEY_NOT_REGISTERED,
            "ERROR_WINDOW_NOT_DIALOG" => WIN32::ERROR_WINDOW_NOT_DIALOG,
            "ERROR_CONTROL_ID_NOT_FOUND" => WIN32::ERROR_CONTROL_ID_NOT_FOUND,
            "ERROR_INVALID_COMBOBOX_MESSAGE" => WIN32::ERROR_INVALID_COMBOBOX_MESSAGE,
            "ERROR_WINDOW_NOT_COMBOBOX" => WIN32::ERROR_WINDOW_NOT_COMBOBOX,
            "ERROR_INVALID_EDIT_HEIGHT" => WIN32::ERROR_INVALID_EDIT_HEIGHT,
            "ERROR_DC_NOT_FOUND" => WIN32::ERROR_DC_NOT_FOUND,
            "ERROR_INVALID_HOOK_FILTER" => WIN32::ERROR_INVALID_HOOK_FILTER,
            "ERROR_INVALID_FILTER_PROC" => WIN32::ERROR_INVALID_FILTER_PROC,
            "ERROR_HOOK_NEEDS_HMOD" => WIN32::ERROR_HOOK_NEEDS_HMOD,
            "ERROR_GLOBAL_ONLY_HOOK" => WIN32::ERROR_GLOBAL_ONLY_HOOK,
            "ERROR_JOURNAL_HOOK_SET" => WIN32::ERROR_JOURNAL_HOOK_SET,
            "ERROR_HOOK_NOT_INSTALLED" => WIN32::ERROR_HOOK_NOT_INSTALLED,
            "ERROR_INVALID_LB_MESSAGE" => WIN32::ERROR_INVALID_LB_MESSAGE,
            "ERROR_SETCOUNT_ON_BAD_LB" => WIN32::ERROR_SETCOUNT_ON_BAD_LB,
            "ERROR_LB_WITHOUT_TABSTOPS" => WIN32::ERROR_LB_WITHOUT_TABSTOPS,
            "ERROR_DESTROY_OBJECT_OF_OTHER_THREAD" => WIN32::ERROR_DESTROY_OBJECT_OF_OTHER_THREAD,
            "ERROR_CHILD_WINDOW_MENU" => WIN32::ERROR_CHILD_WINDOW_MENU,
            "ERROR_NO_SYSTEM_MENU" => WIN32::ERROR_NO_SYSTEM_MENU,
            "ERROR_INVALID_MSGBOX_STYLE" => WIN32::ERROR_INVALID_MSGBOX_STYLE,
            "ERROR_INVALID_SPI_VALUE" => WIN32::ERROR_INVALID_SPI_VALUE,
            "ERROR_SCREEN_ALREADY_LOCKED" => WIN32::ERROR_SCREEN_ALREADY_LOCKED,
            "ERROR_HWNDS_HAVE_DIFF_PARENT" => WIN32::ERROR_HWNDS_HAVE_DIFF_PARENT,
            "ERROR_NOT_CHILD_WINDOW" => WIN32::ERROR_NOT_CHILD_WINDOW,
            "ERROR_INVALID_GW_COMMAND" => WIN32::ERROR_INVALID_GW_COMMAND,
            "ERROR_INVALID_THREAD_ID" => WIN32::ERROR_INVALID_THREAD_ID,
            "ERROR_NON_MDICHILD_WINDOW" => WIN32::ERROR_NON_MDICHILD_WINDOW,
            "ERROR_POPUP_ALREADY_ACTIVE" => WIN32::ERROR_POPUP_ALREADY_ACTIVE,
            "ERROR_NO_SCROLLBARS" => WIN32::ERROR_NO_SCROLLBARS,
            "ERROR_INVALID_SCROLLBAR_RANGE" => WIN32::ERROR_INVALID_SCROLLBAR_RANGE,
            "ERROR_INVALID_SHOWWIN_COMMAND" => WIN32::ERROR_INVALID_SHOWWIN_COMMAND,
            "ERROR_NO_SYSTEM_RESOURCES" => WIN32::ERROR_NO_SYSTEM_RESOURCES,
            "ERROR_NONPAGED_SYSTEM_RESOURCES" => WIN32::ERROR_NONPAGED_SYSTEM_RESOURCES,
            "ERROR_PAGED_SYSTEM_RESOURCES" => WIN32::ERROR_PAGED_SYSTEM_RESOURCES,
            "ERROR_WORKING_SET_QUOTA" => WIN32::ERROR_WORKING_SET_QUOTA,
            "ERROR_PAGEFILE_QUOTA" => WIN32::ERROR_PAGEFILE_QUOTA,
            "ERROR_COMMITMENT_LIMIT" => WIN32::ERROR_COMMITMENT_LIMIT,
            "ERROR_MENU_ITEM_NOT_FOUND" => WIN32::ERROR_MENU_ITEM_NOT_FOUND,
            "ERROR_INVALID_KEYBOARD_HANDLE" => WIN32::ERROR_INVALID_KEYBOARD_HANDLE,
            "ERROR_HOOK_TYPE_NOT_ALLOWED" => WIN32::ERROR_HOOK_TYPE_NOT_ALLOWED,
            "ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION" => WIN32::ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION,
            "ERROR_TIMEOUT" => WIN32::ERROR_TIMEOUT,
            "E_TIMEOUT" => WIN32::E_TIMEOUT,
            "ERROR_INVALID_MONITOR_HANDLE" => WIN32::ERROR_INVALID_MONITOR_HANDLE,
            "ERROR_INCORRECT_SIZE" => WIN32::ERROR_INCORRECT_SIZE,
            "ERROR_SYMLINK_CLASS_DISABLED" => WIN32::ERROR_SYMLINK_CLASS_DISABLED,
            "ERROR_SYMLINK_NOT_SUPPORTED" => WIN32::ERROR_SYMLINK_NOT_SUPPORTED,
            "ERROR_XML_PARSE_ERROR" => WIN32::ERROR_XML_PARSE_ERROR,
            "ERROR_XMLDSIG_ERROR" => WIN32::ERROR_XMLDSIG_ERROR,
            "ERROR_RESTART_APPLICATION" => WIN32::ERROR_RESTART_APPLICATION,
            "ERROR_WRONG_COMPARTMENT" => WIN32::ERROR_WRONG_COMPARTMENT,
            "ERROR_AUTHIP_FAILURE" => WIN32::ERROR_AUTHIP_FAILURE,
            "ERROR_NO_NVRAM_RESOURCES" => WIN32::ERROR_NO_NVRAM_RESOURCES,
            "ERROR_NOT_GUI_PROCESS" => WIN32::ERROR_NOT_GUI_PROCESS,
            "ERROR_EVENTLOG_FILE_CORRUPT" => WIN32::ERROR_EVENTLOG_FILE_CORRUPT,
            "ERROR_EVENTLOG_CANT_START" => WIN32::ERROR_EVENTLOG_CANT_START,
            "ERROR_LOG_FILE_FULL" => WIN32::ERROR_LOG_FILE_FULL,
            "ERROR_EVENTLOG_FILE_CHANGED" => WIN32::ERROR_EVENTLOG_FILE_CHANGED,
            "ERROR_CONTAINER_ASSIGNED" => WIN32::ERROR_CONTAINER_ASSIGNED,
            "ERROR_JOB_NO_CONTAINER" => WIN32::ERROR_JOB_NO_CONTAINER,
            "ERROR_INVALID_TASK_NAME" => WIN32::ERROR_INVALID_TASK_NAME,
            "ERROR_INVALID_TASK_INDEX" => WIN32::ERROR_INVALID_TASK_INDEX,
            "ERROR_THREAD_ALREADY_IN_TASK" => WIN32::ERROR_THREAD_ALREADY_IN_TASK,
            "ERROR_INSTALL_SERVICE_FAILURE" => WIN32::ERROR_INSTALL_SERVICE_FAILURE,
            "ERROR_INSTALL_USEREXIT" => WIN32::ERROR_INSTALL_USEREXIT,
            "ERROR_INSTALL_FAILURE" => WIN32::ERROR_INSTALL_FAILURE,
            "ERROR_INSTALL_SUSPEND" => WIN32::ERROR_INSTALL_SUSPEND,
            "ERROR_UNKNOWN_PRODUCT" => WIN32::ERROR_UNKNOWN_PRODUCT,
            "ERROR_UNKNOWN_FEATURE" => WIN32::ERROR_UNKNOWN_FEATURE,
            "ERROR_UNKNOWN_COMPONENT" => WIN32::ERROR_UNKNOWN_COMPONENT,
            "ERROR_UNKNOWN_PROPERTY" => WIN32::ERROR_UNKNOWN_PROPERTY,
            "ERROR_INVALID_HANDLE_STATE" => WIN32::ERROR_INVALID_HANDLE_STATE,
            "ERROR_BAD_CONFIGURATION" => WIN32::ERROR_BAD_CONFIGURATION,
            "ERROR_INDEX_ABSENT" => WIN32::ERROR_INDEX_ABSENT,
            "ERROR_INSTALL_SOURCE_ABSENT" => WIN32::ERROR_INSTALL_SOURCE_ABSENT,
            "ERROR_INSTALL_PACKAGE_VERSION" => WIN32::ERROR_INSTALL_PACKAGE_VERSION,
            "ERROR_PRODUCT_UNINSTALLED" => WIN32::ERROR_PRODUCT_UNINSTALLED,
            "ERROR_BAD_QUERY_SYNTAX" => WIN32::ERROR_BAD_QUERY_SYNTAX,
            "ERROR_INVALID_FIELD" => WIN32::ERROR_INVALID_FIELD,
            "ERROR_DEVICE_REMOVED" => WIN32::ERROR_DEVICE_REMOVED,
            "ERROR_INSTALL_ALREADY_RUNNING" => WIN32::ERROR_INSTALL_ALREADY_RUNNING,
            "ERROR_INSTALL_PACKAGE_OPEN_FAILED" => WIN32::ERROR_INSTALL_PACKAGE_OPEN_FAILED,
            "ERROR_INSTALL_PACKAGE_INVALID" => WIN32::ERROR_INSTALL_PACKAGE_INVALID,
            "ERROR_INSTALL_UI_FAILURE" => WIN32::ERROR_INSTALL_UI_FAILURE,
            "ERROR_INSTALL_LOG_FAILURE" => WIN32::ERROR_INSTALL_LOG_FAILURE,
            "ERROR_INSTALL_LANGUAGE_UNSUPPORTED" => WIN32::ERROR_INSTALL_LANGUAGE_UNSUPPORTED,
            "ERROR_INSTALL_TRANSFORM_FAILURE" => WIN32::ERROR_INSTALL_TRANSFORM_FAILURE,
            "ERROR_INSTALL_PACKAGE_REJECTED" => WIN32::ERROR_INSTALL_PACKAGE_REJECTED,
            "ERROR_FUNCTION_NOT_CALLED" => WIN32::ERROR_FUNCTION_NOT_CALLED,
            "ERROR_FUNCTION_FAILED" => WIN32::ERROR_FUNCTION_FAILED,
            "ERROR_INVALID_TABLE" => WIN32::ERROR_INVALID_TABLE,
            "ERROR_DATATYPE_MISMATCH" => WIN32::ERROR_DATATYPE_MISMATCH,
            "ERROR_UNSUPPORTED_TYPE" => WIN32::ERROR_UNSUPPORTED_TYPE,
            "ERROR_CREATE_FAILED" => WIN32::ERROR_CREATE_FAILED,
            "ERROR_INSTALL_TEMP_UNWRITABLE" => WIN32::ERROR_INSTALL_TEMP_UNWRITABLE,
            "ERROR_INSTALL_PLATFORM_UNSUPPORTED" => WIN32::ERROR_INSTALL_PLATFORM_UNSUPPORTED,
            "ERROR_INSTALL_NOTUSED" => WIN32::ERROR_INSTALL_NOTUSED,
            "ERROR_PATCH_PACKAGE_OPEN_FAILED" => WIN32::ERROR_PATCH_PACKAGE_OPEN_FAILED,
            "ERROR_PATCH_PACKAGE_INVALID" => WIN32::ERROR_PATCH_PACKAGE_INVALID,
            "ERROR_PATCH_PACKAGE_UNSUPPORTED" => WIN32::ERROR_PATCH_PACKAGE_UNSUPPORTED,
            "ERROR_PRODUCT_VERSION" => WIN32::ERROR_PRODUCT_VERSION,
            "ERROR_INVALID_COMMAND_LINE" => WIN32::ERROR_INVALID_COMMAND_LINE,
            "ERROR_INSTALL_REMOTE_DISALLOWED" => WIN32::ERROR_INSTALL_REMOTE_DISALLOWED,
            "ERROR_SUCCESS_REBOOT_INITIATED" => WIN32::ERROR_SUCCESS_REBOOT_INITIATED,
            "ERROR_PATCH_TARGET_NOT_FOUND" => WIN32::ERROR_PATCH_TARGET_NOT_FOUND,
            "ERROR_PATCH_PACKAGE_REJECTED" => WIN32::ERROR_PATCH_PACKAGE_REJECTED,
            "ERROR_INSTALL_TRANSFORM_REJECTED" => WIN32::ERROR_INSTALL_TRANSFORM_REJECTED,
            "ERROR_INSTALL_REMOTE_PROHIBITED" => WIN32::ERROR_INSTALL_REMOTE_PROHIBITED,
            "ERROR_PATCH_REMOVAL_UNSUPPORTED" => WIN32::ERROR_PATCH_REMOVAL_UNSUPPORTED,
            "ERROR_UNKNOWN_PATCH" => WIN32::ERROR_UNKNOWN_PATCH,
            "ERROR_PATCH_NO_SEQUENCE" => WIN32::ERROR_PATCH_NO_SEQUENCE,
            "ERROR_PATCH_REMOVAL_DISALLOWED" => WIN32::ERROR_PATCH_REMOVAL_DISALLOWED,
            "ERROR_INVALID_PATCH_XML" => WIN32::ERROR_INVALID_PATCH_XML,
            "ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT" => WIN32::ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT,
            "ERROR_INSTALL_SERVICE_SAFEBOOT" => WIN32::ERROR_INSTALL_SERVICE_SAFEBOOT,
            "ERROR_FAIL_FAST_EXCEPTION" => WIN32::ERROR_FAIL_FAST_EXCEPTION,
            "ERROR_INSTALL_REJECTED" => WIN32::ERROR_INSTALL_REJECTED,
            "ERROR_DYNAMIC_CODE_BLOCKED" => WIN32::ERROR_DYNAMIC_CODE_BLOCKED,
            "ERROR_NOT_SAME_OBJECT" => WIN32::ERROR_NOT_SAME_OBJECT,
            "ERROR_STRICT_CFG_VIOLATION" => WIN32::ERROR_STRICT_CFG_VIOLATION,
            "ERROR_STRICT_RFG_VIOLATION" => WIN32::ERROR_STRICT_RFG_VIOLATION,
            "ERROR_RFG_ACCESS_VIOLATION" => WIN32::ERROR_RFG_ACCESS_VIOLATION,
            "ERROR_SET_CONTEXT_DENIED" => WIN32::ERROR_SET_CONTEXT_DENIED,
            "ERROR_CROSS_PARTITION_VIOLATION" => WIN32::ERROR_CROSS_PARTITION_VIOLATION,
            "ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT" => WIN32::ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT,
            "RPC_S_INVALID_STRING_BINDING" => WIN32::RPC_S_INVALID_STRING_BINDING,
            "RPC_S_WRONG_KIND_OF_BINDING" => WIN32::RPC_S_WRONG_KIND_OF_BINDING,
            "RPC_S_INVALID_BINDING" => WIN32::RPC_S_INVALID_BINDING,
            "RPC_S_PROTSEQ_NOT_SUPPORTED" => WIN32::RPC_S_PROTSEQ_NOT_SUPPORTED,
            "RPC_S_INVALID_RPC_PROTSEQ" => WIN32::RPC_S_INVALID_RPC_PROTSEQ,
            "RPC_S_INVALID_STRING_UUID" => WIN32::RPC_S_INVALID_STRING_UUID,
            "RPC_S_INVALID_ENDPOINT_FORMAT" => WIN32::RPC_S_INVALID_ENDPOINT_FORMAT,
            "RPC_S_INVALID_NET_ADDR" => WIN32::RPC_S_INVALID_NET_ADDR,
            "RPC_S_NO_ENDPOINT_FOUND" => WIN32::RPC_S_NO_ENDPOINT_FOUND,
            "RPC_S_INVALID_TIMEOUT" => WIN32::RPC_S_INVALID_TIMEOUT,
            "RPC_S_OBJECT_NOT_FOUND" => WIN32::RPC_S_OBJECT_NOT_FOUND,
            "RPC_S_ALREADY_REGISTERED" => WIN32::RPC_S_ALREADY_REGISTERED,
            "RPC_S_TYPE_ALREADY_REGISTERED" => WIN32::RPC_S_TYPE_ALREADY_REGISTERED,
            "RPC_S_ALREADY_LISTENING" => WIN32::RPC_S_ALREADY_LISTENING,
            "RPC_S_NO_PROTSEQS_REGISTERED" => WIN32::RPC_S_NO_PROTSEQS_REGISTERED,
            "RPC_S_NOT_LISTENING" => WIN32::RPC_S_NOT_LISTENING,
            "RPC_S_UNKNOWN_MGR_TYPE" => WIN32::RPC_S_UNKNOWN_MGR_TYPE,
            "RPC_S_UNKNOWN_IF" => WIN32::RPC_S_UNKNOWN_IF,
            "RPC_S_NO_BINDINGS" => WIN32::RPC_S_NO_BINDINGS,
            "RPC_S_NO_PROTSEQS" => WIN32::RPC_S_NO_PROTSEQS,
            "RPC_S_CANT_CREATE_ENDPOINT" => WIN32::RPC_S_CANT_CREATE_ENDPOINT,
            "RPC_S_OUT_OF_RESOURCES" => WIN32::RPC_S_OUT_OF_RESOURCES,
            "RPC_S_SERVER_UNAVAILABLE" => WIN32::RPC_S_SERVER_UNAVAILABLE,
            "RPC_S_SERVER_TOO_BUSY" => WIN32::RPC_S_SERVER_TOO_BUSY,
            "RPC_S_INVALID_NETWORK_OPTIONS" => WIN32::RPC_S_INVALID_NETWORK_OPTIONS,
            "RPC_S_NO_CALL_ACTIVE" => WIN32::RPC_S_NO_CALL_ACTIVE,
            "RPC_S_CALL_FAILED" => WIN32::RPC_S_CALL_FAILED,
            "RPC_S_CALL_FAILED_DNE" => WIN32::RPC_S_CALL_FAILED_DNE,
            "RPC_S_PROTOCOL_ERROR" => WIN32::RPC_S_PROTOCOL_ERROR,
            "RPC_S_PROXY_ACCESS_DENIED" => WIN32::RPC_S_PROXY_ACCESS_DENIED,
            "RPC_S_UNSUPPORTED_TRANS_SYN" => WIN32::RPC_S_UNSUPPORTED_TRANS_SYN,
            "RPC_S_UNSUPPORTED_TYPE" => WIN32::RPC_S_UNSUPPORTED_TYPE,
            "RPC_S_INVALID_TAG" => WIN32::RPC_S_INVALID_TAG,
            "RPC_S_INVALID_BOUND" => WIN32::RPC_S_INVALID_BOUND,
            "RPC_S_NO_ENTRY_NAME" => WIN32::RPC_S_NO_ENTRY_NAME,
            "RPC_S_INVALID_NAME_SYNTAX" => WIN32::RPC_S_INVALID_NAME_SYNTAX,
            "RPC_S_UNSUPPORTED_NAME_SYNTAX" => WIN32::RPC_S_UNSUPPORTED_NAME_SYNTAX,
            "RPC_S_UUID_NO_ADDRESS" => WIN32::RPC_S_UUID_NO_ADDRESS,
            "RPC_S_DUPLICATE_ENDPOINT" => WIN32::RPC_S_DUPLICATE_ENDPOINT,
            "RPC_S_UNKNOWN_AUTHN_TYPE" => WIN32::RPC_S_UNKNOWN_AUTHN_TYPE,
            "RPC_S_MAX_CALLS_TOO_SMALL" => WIN32::RPC_S_MAX_CALLS_TOO_SMALL,
            "RPC_S_STRING_TOO_LONG" => WIN32::RPC_S_STRING_TOO_LONG,
            "RPC_S_PROTSEQ_NOT_FOUND" => WIN32::RPC_S_PROTSEQ_NOT_FOUND,
            "RPC_S_PROCNUM_OUT_OF_RANGE" => WIN32::RPC_S_PROCNUM_OUT_OF_RANGE,
            "RPC_S_BINDING_HAS_NO_AUTH" => WIN32::RPC_S_BINDING_HAS_NO_AUTH,
            "RPC_S_UNKNOWN_AUTHN_SERVICE" => WIN32::RPC_S_UNKNOWN_AUTHN_SERVICE,
            "RPC_S_UNKNOWN_AUTHN_LEVEL" => WIN32::RPC_S_UNKNOWN_AUTHN_LEVEL,
            "RPC_S_INVALID_AUTH_IDENTITY" => WIN32::RPC_S_INVALID_AUTH_IDENTITY,
            "RPC_S_UNKNOWN_AUTHZ_SERVICE" => WIN32::RPC_S_UNKNOWN_AUTHZ_SERVICE,
            "EPT_S_INVALID_ENTRY" => WIN32::EPT_S_INVALID_ENTRY,
            "EPT_S_CANT_PERFORM_OP" => WIN32::EPT_S_CANT_PERFORM_OP,
            "EPT_S_NOT_REGISTERED" => WIN32::EPT_S_NOT_REGISTERED,
            "RPC_S_NOTHING_TO_EXPORT" => WIN32::RPC_S_NOTHING_TO_EXPORT,
            "RPC_S_INCOMPLETE_NAME" => WIN32::RPC_S_INCOMPLETE_NAME,
            "RPC_S_INVALID_VERS_OPTION" => WIN32::RPC_S_INVALID_VERS_OPTION,
            "RPC_S_NO_MORE_MEMBERS" => WIN32::RPC_S_NO_MORE_MEMBERS,
            "RPC_S_NOT_ALL_OBJS_UNEXPORTED" => WIN32::RPC_S_NOT_ALL_OBJS_UNEXPORTED,
            "RPC_S_INTERFACE_NOT_FOUND" => WIN32::RPC_S_INTERFACE_NOT_FOUND,
            "RPC_S_ENTRY_ALREADY_EXISTS" => WIN32::RPC_S_ENTRY_ALREADY_EXISTS,
            "RPC_S_ENTRY_NOT_FOUND" => WIN32::RPC_S_ENTRY_NOT_FOUND,
            "RPC_S_NAME_SERVICE_UNAVAILABLE" => WIN32::RPC_S_NAME_SERVICE_UNAVAILABLE,
            "RPC_S_INVALID_NAF_ID" => WIN32::RPC_S_INVALID_NAF_ID,
            "RPC_S_CANNOT_SUPPORT" => WIN32::RPC_S_CANNOT_SUPPORT,
            "RPC_S_NO_CONTEXT_AVAILABLE" => WIN32::RPC_S_NO_CONTEXT_AVAILABLE,
            "RPC_S_INTERNAL_ERROR" => WIN32::RPC_S_INTERNAL_ERROR,
            "RPC_S_ZERO_DIVIDE" => WIN32::RPC_S_ZERO_DIVIDE,
            "RPC_S_ADDRESS_ERROR" => WIN32::RPC_S_ADDRESS_ERROR,
            "RPC_S_FP_DIV_ZERO" => WIN32::RPC_S_FP_DIV_ZERO,
            "RPC_S_FP_UNDERFLOW" => WIN32::RPC_S_FP_UNDERFLOW,
            "RPC_S_FP_OVERFLOW" => WIN32::RPC_S_FP_OVERFLOW,
            "RPC_X_NO_MORE_ENTRIES" => WIN32::RPC_X_NO_MORE_ENTRIES,
            "RPC_X_SS_CHAR_TRANS_OPEN_FAIL" => WIN32::RPC_X_SS_CHAR_TRANS_OPEN_FAIL,
            "RPC_X_SS_CHAR_TRANS_SHORT_FILE" => WIN32::RPC_X_SS_CHAR_TRANS_SHORT_FILE,
            "RPC_X_SS_IN_NULL_CONTEXT" => WIN32::RPC_X_SS_IN_NULL_CONTEXT,
            "RPC_X_SS_CONTEXT_DAMAGED" => WIN32::RPC_X_SS_CONTEXT_DAMAGED,
            "RPC_X_SS_HANDLES_MISMATCH" => WIN32::RPC_X_SS_HANDLES_MISMATCH,
            "RPC_X_SS_CANNOT_GET_CALL_HANDLE" => WIN32::RPC_X_SS_CANNOT_GET_CALL_HANDLE,
            "RPC_X_NULL_REF_POINTER" => WIN32::RPC_X_NULL_REF_POINTER,
            "RPC_X_ENUM_VALUE_OUT_OF_RANGE" => WIN32::RPC_X_ENUM_VALUE_OUT_OF_RANGE,
            "RPC_X_BYTE_COUNT_TOO_SMALL" => WIN32::RPC_X_BYTE_COUNT_TOO_SMALL,
            "RPC_X_BAD_STUB_DATA" => WIN32::RPC_X_BAD_STUB_DATA,
            "ERROR_INVALID_USER_BUFFER" => WIN32::ERROR_INVALID_USER_BUFFER,
            "ERROR_UNRECOGNIZED_MEDIA" => WIN32::ERROR_UNRECOGNIZED_MEDIA,
            "ERROR_NO_TRUST_LSA_SECRET" => WIN32::ERROR_NO_TRUST_LSA_SECRET,
            "ERROR_NO_TRUST_SAM_ACCOUNT" => WIN32::ERROR_NO_TRUST_SAM_ACCOUNT,
            "ERROR_TRUSTED_DOMAIN_FAILURE" => WIN32::ERROR_TRUSTED_DOMAIN_FAILURE,
            "ERROR_TRUSTED_RELATIONSHIP_FAILURE" => WIN32::ERROR_TRUSTED_RELATIONSHIP_FAILURE,
            "ERROR_TRUST_FAILURE" => WIN32::ERROR_TRUST_FAILURE,
            "RPC_S_CALL_IN_PROGRESS" => WIN32::RPC_S_CALL_IN_PROGRESS,
            "ERROR_NETLOGON_NOT_STARTED" => WIN32::ERROR_NETLOGON_NOT_STARTED,
            "ERROR_ACCOUNT_EXPIRED" => WIN32::ERROR_ACCOUNT_EXPIRED,
            "ERROR_REDIRECTOR_HAS_OPEN_HANDLES" => WIN32::ERROR_REDIRECTOR_HAS_OPEN_HANDLES,
            "ERROR_PRINTER_DRIVER_ALREADY_INSTALLED" => WIN32::ERROR_PRINTER_DRIVER_ALREADY_INSTALLED,
            "ERROR_UNKNOWN_PORT" => WIN32::ERROR_UNKNOWN_PORT,
            "ERROR_UNKNOWN_PRINTER_DRIVER" => WIN32::ERROR_UNKNOWN_PRINTER_DRIVER,
            "ERROR_UNKNOWN_PRINTPROCESSOR" => WIN32::ERROR_UNKNOWN_PRINTPROCESSOR,
            "ERROR_INVALID_SEPARATOR_FILE" => WIN32::ERROR_INVALID_SEPARATOR_FILE,
            "ERROR_INVALID_PRIORITY" => WIN32::ERROR_INVALID_PRIORITY,
            "ERROR_INVALID_PRINTER_NAME" => WIN32::ERROR_INVALID_PRINTER_NAME,
            "ERROR_PRINTER_ALREADY_EXISTS" => WIN32::ERROR_PRINTER_ALREADY_EXISTS,
            "ERROR_INVALID_PRINTER_COMMAND" => WIN32::ERROR_INVALID_PRINTER_COMMAND,
            "ERROR_INVALID_DATATYPE" => WIN32::ERROR_INVALID_DATATYPE,
            "ERROR_INVALID_ENVIRONMENT" => WIN32::ERROR_INVALID_ENVIRONMENT,
            "RPC_S_NO_MORE_BINDINGS" => WIN32::RPC_S_NO_MORE_BINDINGS,
            "ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT" => WIN32::ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT,
            "ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT" => WIN32::ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT,
            "ERROR_NOLOGON_SERVER_TRUST_ACCOUNT" => WIN32::ERROR_NOLOGON_SERVER_TRUST_ACCOUNT,
            "ERROR_DOMAIN_TRUST_INCONSISTENT" => WIN32::ERROR_DOMAIN_TRUST_INCONSISTENT,
            "ERROR_SERVER_HAS_OPEN_HANDLES" => WIN32::ERROR_SERVER_HAS_OPEN_HANDLES,
            "ERROR_RESOURCE_DATA_NOT_FOUND" => WIN32::ERROR_RESOURCE_DATA_NOT_FOUND,
            "ERROR_RESOURCE_TYPE_NOT_FOUND" => WIN32::ERROR_RESOURCE_TYPE_NOT_FOUND,
            "ERROR_RESOURCE_NAME_NOT_FOUND" => WIN32::ERROR_RESOURCE_NAME_NOT_FOUND,
            "ERROR_RESOURCE_LANG_NOT_FOUND" => WIN32::ERROR_RESOURCE_LANG_NOT_FOUND,
            "ERROR_NOT_ENOUGH_QUOTA" => WIN32::ERROR_NOT_ENOUGH_QUOTA,
            "RPC_S_NO_INTERFACES" => WIN32::RPC_S_NO_INTERFACES,
            "RPC_S_CALL_CANCELLED" => WIN32::RPC_S_CALL_CANCELLED,
            "RPC_S_BINDING_INCOMPLETE" => WIN32::RPC_S_BINDING_INCOMPLETE,
            "RPC_S_COMM_FAILURE" => WIN32::RPC_S_COMM_FAILURE,
            "RPC_S_UNSUPPORTED_AUTHN_LEVEL" => WIN32::RPC_S_UNSUPPORTED_AUTHN_LEVEL,
            "RPC_S_NO_PRINC_NAME" => WIN32::RPC_S_NO_PRINC_NAME,
            "RPC_S_NOT_RPC_ERROR" => WIN32::RPC_S_NOT_RPC_ERROR,
            "RPC_S_UUID_LOCAL_ONLY" => WIN32::RPC_S_UUID_LOCAL_ONLY,
            "RPC_S_SEC_PKG_ERROR" => WIN32::RPC_S_SEC_PKG_ERROR,
            "RPC_S_NOT_CANCELLED" => WIN32::RPC_S_NOT_CANCELLED,
            "RPC_X_INVALID_ES_ACTION" => WIN32::RPC_X_INVALID_ES_ACTION,
            "RPC_X_WRONG_ES_VERSION" => WIN32::RPC_X_WRONG_ES_VERSION,
            "RPC_X_WRONG_STUB_VERSION" => WIN32::RPC_X_WRONG_STUB_VERSION,
            "RPC_X_INVALID_PIPE_OBJECT" => WIN32::RPC_X_INVALID_PIPE_OBJECT,
            "RPC_X_WRONG_PIPE_ORDER" => WIN32::RPC_X_WRONG_PIPE_ORDER,
            "RPC_X_WRONG_PIPE_VERSION" => WIN32::RPC_X_WRONG_PIPE_VERSION,
            "RPC_S_COOKIE_AUTH_FAILED" => WIN32::RPC_S_COOKIE_AUTH_FAILED,
            "RPC_S_DO_NOT_DISTURB" => WIN32::RPC_S_DO_NOT_DISTURB,
            "RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED" => WIN32::RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED,
            "RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH" => WIN32::RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH,
            "RPC_S_GROUP_MEMBER_NOT_FOUND" => WIN32::RPC_S_GROUP_MEMBER_NOT_FOUND,
            "EPT_S_CANT_CREATE" => WIN32::EPT_S_CANT_CREATE,
            "RPC_S_INVALID_OBJECT" => WIN32::RPC_S_INVALID_OBJECT,
            "ERROR_INVALID_TIME" => WIN32::ERROR_INVALID_TIME,
            "ERROR_INVALID_FORM_NAME" => WIN32::ERROR_INVALID_FORM_NAME,
            "ERROR_INVALID_FORM_SIZE" => WIN32::ERROR_INVALID_FORM_SIZE,
            "ERROR_ALREADY_WAITING" => WIN32::ERROR_ALREADY_WAITING,
            "ERROR_PRINTER_DELETED" => WIN32::ERROR_PRINTER_DELETED,
            "ERROR_INVALID_PRINTER_STATE" => WIN32::ERROR_INVALID_PRINTER_STATE,
            "ERROR_PASSWORD_MUST_CHANGE" => WIN32::ERROR_PASSWORD_MUST_CHANGE,
            "ERROR_DOMAIN_CONTROLLER_NOT_FOUND" => WIN32::ERROR_DOMAIN_CONTROLLER_NOT_FOUND,
            "ERROR_ACCOUNT_LOCKED_OUT" => WIN32::ERROR_ACCOUNT_LOCKED_OUT,
            "OR_INVALID_OXID" => WIN32::OR_INVALID_OXID,
            "OR_INVALID_OID" => WIN32::OR_INVALID_OID,
            "OR_INVALID_SET" => WIN32::OR_INVALID_SET,
            "RPC_S_SEND_INCOMPLETE" => WIN32::RPC_S_SEND_INCOMPLETE,
            "RPC_S_INVALID_ASYNC_HANDLE" => WIN32::RPC_S_INVALID_ASYNC_HANDLE,
            "RPC_S_INVALID_ASYNC_CALL" => WIN32::RPC_S_INVALID_ASYNC_CALL,
            "RPC_X_PIPE_CLOSED" => WIN32::RPC_X_PIPE_CLOSED,
            "RPC_X_PIPE_DISCIPLINE_ERROR" => WIN32::RPC_X_PIPE_DISCIPLINE_ERROR,
            "RPC_X_PIPE_EMPTY" => WIN32::RPC_X_PIPE_EMPTY,
            "ERROR_NO_SITENAME" => WIN32::ERROR_NO_SITENAME,
            "ERROR_CANT_ACCESS_FILE" => WIN32::ERROR_CANT_ACCESS_FILE,
            "ERROR_CANT_RESOLVE_FILENAME" => WIN32::ERROR_CANT_RESOLVE_FILENAME,
            "RPC_S_ENTRY_TYPE_MISMATCH" => WIN32::RPC_S_ENTRY_TYPE_MISMATCH,
            "RPC_S_NOT_ALL_OBJS_EXPORTED" => WIN32::RPC_S_NOT_ALL_OBJS_EXPORTED,
            "RPC_S_INTERFACE_NOT_EXPORTED" => WIN32::RPC_S_INTERFACE_NOT_EXPORTED,
            "RPC_S_PROFILE_NOT_ADDED" => WIN32::RPC_S_PROFILE_NOT_ADDED,
            "RPC_S_PRF_ELT_NOT_ADDED" => WIN32::RPC_S_PRF_ELT_NOT_ADDED,
            "RPC_S_PRF_ELT_NOT_REMOVED" => WIN32::RPC_S_PRF_ELT_NOT_REMOVED,
            "RPC_S_GRP_ELT_NOT_ADDED" => WIN32::RPC_S_GRP_ELT_NOT_ADDED,
            "RPC_S_GRP_ELT_NOT_REMOVED" => WIN32::RPC_S_GRP_ELT_NOT_REMOVED,
            "ERROR_KM_DRIVER_BLOCKED" => WIN32::ERROR_KM_DRIVER_BLOCKED,
            "ERROR_CONTEXT_EXPIRED" => WIN32::ERROR_CONTEXT_EXPIRED,
            "ERROR_PER_USER_TRUST_QUOTA_EXCEEDED" => WIN32::ERROR_PER_USER_TRUST_QUOTA_EXCEEDED,
            "ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED" => WIN32::ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED,
            "ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED" => WIN32::ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED,
            "ERROR_AUTHENTICATION_FIREWALL_FAILED" => WIN32::ERROR_AUTHENTICATION_FIREWALL_FAILED,
            "ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED" => WIN32::ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED,
            "ERROR_NTLM_BLOCKED" => WIN32::ERROR_NTLM_BLOCKED,
            "ERROR_PASSWORD_CHANGE_REQUIRED" => WIN32::ERROR_PASSWORD_CHANGE_REQUIRED,
            "ERROR_LOST_MODE_LOGON_RESTRICTION" => WIN32::ERROR_LOST_MODE_LOGON_RESTRICTION,
            "ERROR_INVALID_PIXEL_FORMAT" => WIN32::ERROR_INVALID_PIXEL_FORMAT,
            "ERROR_BAD_DRIVER" => WIN32::ERROR_BAD_DRIVER,
            "ERROR_INVALID_WINDOW_STYLE" => WIN32::ERROR_INVALID_WINDOW_STYLE,
            "ERROR_METAFILE_NOT_SUPPORTED" => WIN32::ERROR_METAFILE_NOT_SUPPORTED,
            "ERROR_TRANSFORM_NOT_SUPPORTED" => WIN32::ERROR_TRANSFORM_NOT_SUPPORTED,
            "ERROR_CLIPPING_NOT_SUPPORTED" => WIN32::ERROR_CLIPPING_NOT_SUPPORTED,
            "ERROR_INVALID_CMM" => WIN32::ERROR_INVALID_CMM,
            "ERROR_INVALID_PROFILE" => WIN32::ERROR_INVALID_PROFILE,
            "ERROR_TAG_NOT_FOUND" => WIN32::ERROR_TAG_NOT_FOUND,
            "ERROR_TAG_NOT_PRESENT" => WIN32::ERROR_TAG_NOT_PRESENT,
            "ERROR_DUPLICATE_TAG" => WIN32::ERROR_DUPLICATE_TAG,
            "ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE" => WIN32::ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE,
            "ERROR_PROFILE_NOT_FOUND" => WIN32::ERROR_PROFILE_NOT_FOUND,
            "ERROR_INVALID_COLORSPACE" => WIN32::ERROR_INVALID_COLORSPACE,
            "ERROR_ICM_NOT_ENABLED" => WIN32::ERROR_ICM_NOT_ENABLED,
            "ERROR_DELETING_ICM_XFORM" => WIN32::ERROR_DELETING_ICM_XFORM,
            "ERROR_INVALID_TRANSFORM" => WIN32::ERROR_INVALID_TRANSFORM,
            "ERROR_COLORSPACE_MISMATCH" => WIN32::ERROR_COLORSPACE_MISMATCH,
            "ERROR_INVALID_COLORINDEX" => WIN32::ERROR_INVALID_COLORINDEX,
            "ERROR_PROFILE_DOES_NOT_MATCH_DEVICE" => WIN32::ERROR_PROFILE_DOES_NOT_MATCH_DEVICE,
            "NERR_NetNotStarted" => WIN32::NERR_NetNotStarted,
            "NERR_UnknownServer" => WIN32::NERR_UnknownServer,
            "NERR_ShareMem" => WIN32::NERR_ShareMem,
            "NERR_NoNetworkResource" => WIN32::NERR_NoNetworkResource,
            "NERR_RemoteOnly" => WIN32::NERR_RemoteOnly,
            "NERR_DevNotRedirected" => WIN32::NERR_DevNotRedirected,
            "ERROR_CONNECTED_OTHER_PASSWORD" => WIN32::ERROR_CONNECTED_OTHER_PASSWORD,
            "ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT" => WIN32::ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT,
            "NERR_ServerNotStarted" => WIN32::NERR_ServerNotStarted,
            "NERR_ItemNotFound" => WIN32::NERR_ItemNotFound,
            "NERR_UnknownDevDir" => WIN32::NERR_UnknownDevDir,
            "NERR_RedirectedPath" => WIN32::NERR_RedirectedPath,
            "NERR_DuplicateShare" => WIN32::NERR_DuplicateShare,
            "NERR_NoRoom" => WIN32::NERR_NoRoom,
            "NERR_TooManyItems" => WIN32::NERR_TooManyItems,
            "NERR_InvalidMaxUsers" => WIN32::NERR_InvalidMaxUsers,
            "NERR_BufTooSmall" => WIN32::NERR_BufTooSmall,
            "NERR_RemoteErr" => WIN32::NERR_RemoteErr,
            "NERR_LanmanIniError" => WIN32::NERR_LanmanIniError,
            "NERR_NetworkError" => WIN32::NERR_NetworkError,
            "NERR_WkstaInconsistentState" => WIN32::NERR_WkstaInconsistentState,
            "NERR_WkstaNotStarted" => WIN32::NERR_WkstaNotStarted,
            "NERR_BrowserNotStarted" => WIN32::NERR_BrowserNotStarted,
            "NERR_InternalError" => WIN32::NERR_InternalError,
            "NERR_BadTransactConfig" => WIN32::NERR_BadTransactConfig,
            "NERR_InvalidAPI" => WIN32::NERR_InvalidAPI,
            "NERR_BadEventName" => WIN32::NERR_BadEventName,
            "NERR_DupNameReboot" => WIN32::NERR_DupNameReboot,
            "NERR_CfgCompNotFound" => WIN32::NERR_CfgCompNotFound,
            "NERR_CfgParamNotFound" => WIN32::NERR_CfgParamNotFound,
            "NERR_LineTooLong" => WIN32::NERR_LineTooLong,
            "NERR_QNotFound" => WIN32::NERR_QNotFound,
            "NERR_JobNotFound" => WIN32::NERR_JobNotFound,
            "NERR_DestNotFound" => WIN32::NERR_DestNotFound,
            "NERR_DestExists" => WIN32::NERR_DestExists,
            "NERR_QExists" => WIN32::NERR_QExists,
            "NERR_QNoRoom" => WIN32::NERR_QNoRoom,
            "NERR_JobNoRoom" => WIN32::NERR_JobNoRoom,
            "NERR_DestNoRoom" => WIN32::NERR_DestNoRoom,
            "NERR_DestIdle" => WIN32::NERR_DestIdle,
            "NERR_DestInvalidOp" => WIN32::NERR_DestInvalidOp,
            "NERR_ProcNoRespond" => WIN32::NERR_ProcNoRespond,
            "NERR_SpoolerNotLoaded" => WIN32::NERR_SpoolerNotLoaded,
            "NERR_DestInvalidState" => WIN32::NERR_DestInvalidState,
            "NERR_QinvalidState" => WIN32::NERR_QinvalidState,
            "NERR_JobInvalidState" => WIN32::NERR_JobInvalidState,
            "NERR_SpoolNoMemory" => WIN32::NERR_SpoolNoMemory,
            "NERR_DriverNotFound" => WIN32::NERR_DriverNotFound,
            "NERR_DataTypeInvalid" => WIN32::NERR_DataTypeInvalid,
            "NERR_ProcNotFound" => WIN32::NERR_ProcNotFound,
            "NERR_ServiceTableLocked" => WIN32::NERR_ServiceTableLocked,
            "NERR_ServiceTableFull" => WIN32::NERR_ServiceTableFull,
            "NERR_ServiceInstalled" => WIN32::NERR_ServiceInstalled,
            "NERR_ServiceEntryLocked" => WIN32::NERR_ServiceEntryLocked,
            "NERR_ServiceNotInstalled" => WIN32::NERR_ServiceNotInstalled,
            "NERR_BadServiceName" => WIN32::NERR_BadServiceName,
            "NERR_ServiceCtlTimeout" => WIN32::NERR_ServiceCtlTimeout,
            "NERR_ServiceCtlBusy" => WIN32::NERR_ServiceCtlBusy,
            "NERR_BadServiceProgName" => WIN32::NERR_BadServiceProgName,
            "NERR_ServiceNotCtrl" => WIN32::NERR_ServiceNotCtrl,
            "NERR_ServiceKillProc" => WIN32::NERR_ServiceKillProc,
            "NERR_ServiceCtlNotValid" => WIN32::NERR_ServiceCtlNotValid,
            "NERR_NotInDispatchTbl" => WIN32::NERR_NotInDispatchTbl,
            "NERR_BadControlRecv" => WIN32::NERR_BadControlRecv,
            "NERR_ServiceNotStarting" => WIN32::NERR_ServiceNotStarting,
            "NERR_AlreadyLoggedOn" => WIN32::NERR_AlreadyLoggedOn,
            "NERR_NotLoggedOn" => WIN32::NERR_NotLoggedOn,
            "ERROR_BAD_USERNAME" => WIN32::ERROR_BAD_USERNAME,
            "NERR_BadUsername" => WIN32::NERR_BadUsername,
            "NERR_BadPassword" => WIN32::NERR_BadPassword,
            "NERR_UnableToAddName_W" => WIN32::NERR_UnableToAddName_W,
            "NERR_UnableToAddName_F" => WIN32::NERR_UnableToAddName_F,
            "NERR_UnableToDelName_W" => WIN32::NERR_UnableToDelName_W,
            "NERR_UnableToDelName_F" => WIN32::NERR_UnableToDelName_F,
            "NERR_LogonsPaused" => WIN32::NERR_LogonsPaused,
            "NERR_LogonServerConflict" => WIN32::NERR_LogonServerConflict,
            "NERR_LogonNoUserPath" => WIN32::NERR_LogonNoUserPath,
            "NERR_LogonScriptError" => WIN32::NERR_LogonScriptError,
            "NERR_StandaloneLogon" => WIN32::NERR_StandaloneLogon,
            "NERR_LogonServerNotFound" => WIN32::NERR_LogonServerNotFound,
            "NERR_LogonDomainExists" => WIN32::NERR_LogonDomainExists,
            "NERR_NonValidatedLogon" => WIN32::NERR_NonValidatedLogon,
            "NERR_ACFNotFound" => WIN32::NERR_ACFNotFound,
            "NERR_GroupNotFound" => WIN32::NERR_GroupNotFound,
            "NERR_UserNotFound" => WIN32::NERR_UserNotFound,
            "NERR_ResourceNotFound" => WIN32::NERR_ResourceNotFound,
            "NERR_GroupExists" => WIN32::NERR_GroupExists,
            "NERR_UserExists" => WIN32::NERR_UserExists,
            "NERR_ResourceExists" => WIN32::NERR_ResourceExists,
            "NERR_NotPrimary" => WIN32::NERR_NotPrimary,
            "NERR_ACFNotLoaded" => WIN32::NERR_ACFNotLoaded,
            "NERR_ACFNoRoom" => WIN32::NERR_ACFNoRoom,
            "NERR_ACFFileIOFail" => WIN32::NERR_ACFFileIOFail,
            "NERR_ACFTooManyLists" => WIN32::NERR_ACFTooManyLists,
            "NERR_UserLogon" => WIN32::NERR_UserLogon,
            "NERR_ACFNoParent" => WIN32::NERR_ACFNoParent,
            "NERR_CanNotGrowSegment" => WIN32::NERR_CanNotGrowSegment,
            "NERR_SpeGroupOp" => WIN32::NERR_SpeGroupOp,
            "NERR_NotInCache" => WIN32::NERR_NotInCache,
            "NERR_UserInGroup" => WIN32::NERR_UserInGroup,
            "NERR_UserNotInGroup" => WIN32::NERR_UserNotInGroup,
            "NERR_AccountUndefined" => WIN32::NERR_AccountUndefined,
            "NERR_AccountExpired" => WIN32::NERR_AccountExpired,
            "NERR_InvalidWorkstation" => WIN32::NERR_InvalidWorkstation,
            "NERR_InvalidLogonHours" => WIN32::NERR_InvalidLogonHours,
            "NERR_PasswordExpired" => WIN32::NERR_PasswordExpired,
            "NERR_PasswordCantChange" => WIN32::NERR_PasswordCantChange,
            "NERR_PasswordHistConflict" => WIN32::NERR_PasswordHistConflict,
            "NERR_PasswordTooShort" => WIN32::NERR_PasswordTooShort,
            "NERR_PasswordTooRecent" => WIN32::NERR_PasswordTooRecent,
            "NERR_InvalidDatabase" => WIN32::NERR_InvalidDatabase,
            "NERR_DatabaseUpToDate" => WIN32::NERR_DatabaseUpToDate,
            "NERR_SyncRequired" => WIN32::NERR_SyncRequired,
            "ERROR_NOT_CONNECTED" => WIN32::ERROR_NOT_CONNECTED,
            "NERR_UseNotFound" => WIN32::NERR_UseNotFound,
            "NERR_BadAsgType" => WIN32::NERR_BadAsgType,
            "NERR_DeviceIsShared" => WIN32::NERR_DeviceIsShared,
            "NERR_NoComputerName" => WIN32::NERR_NoComputerName,
            "NERR_MsgAlreadyStarted" => WIN32::NERR_MsgAlreadyStarted,
            "NERR_MsgInitFailed" => WIN32::NERR_MsgInitFailed,
            "NERR_NameNotFound" => WIN32::NERR_NameNotFound,
            "NERR_AlreadyForwarded" => WIN32::NERR_AlreadyForwarded,
            "NERR_AddForwarded" => WIN32::NERR_AddForwarded,
            "NERR_AlreadyExists" => WIN32::NERR_AlreadyExists,
            "NERR_TooManyNames" => WIN32::NERR_TooManyNames,
            "NERR_DelComputerName" => WIN32::NERR_DelComputerName,
            "NERR_LocalForward" => WIN32::NERR_LocalForward,
            "NERR_GrpMsgProcessor" => WIN32::NERR_GrpMsgProcessor,
            "NERR_PausedRemote" => WIN32::NERR_PausedRemote,
            "NERR_BadReceive" => WIN32::NERR_BadReceive,
            "NERR_NameInUse" => WIN32::NERR_NameInUse,
            "NERR_MsgNotStarted" => WIN32::NERR_MsgNotStarted,
            "NERR_NotLocalName" => WIN32::NERR_NotLocalName,
            "NERR_NoForwardName" => WIN32::NERR_NoForwardName,
            "NERR_RemoteFull" => WIN32::NERR_RemoteFull,
            "NERR_NameNotForwarded" => WIN32::NERR_NameNotForwarded,
            "NERR_TruncatedBroadcast" => WIN32::NERR_TruncatedBroadcast,
            "NERR_InvalidDevice" => WIN32::NERR_InvalidDevice,
            "NERR_WriteFault" => WIN32::NERR_WriteFault,
            "NERR_DuplicateName" => WIN32::NERR_DuplicateName,
            "NERR_DeleteLater" => WIN32::NERR_DeleteLater,
            "NERR_IncompleteDel" => WIN32::NERR_IncompleteDel,
            "NERR_MultipleNets" => WIN32::NERR_MultipleNets,
            "NERR_NetNameNotFound" => WIN32::NERR_NetNameNotFound,
            "NERR_DeviceNotShared" => WIN32::NERR_DeviceNotShared,
            "NERR_ClientNameNotFound" => WIN32::NERR_ClientNameNotFound,
            "NERR_FileIdNotFound" => WIN32::NERR_FileIdNotFound,
            "NERR_ExecFailure" => WIN32::NERR_ExecFailure,
            "NERR_TmpFile" => WIN32::NERR_TmpFile,
            "NERR_TooMuchData" => WIN32::NERR_TooMuchData,
            "NERR_DeviceShareConflict" => WIN32::NERR_DeviceShareConflict,
            "NERR_BrowserTableIncomplete" => WIN32::NERR_BrowserTableIncomplete,
            "NERR_NotLocalDomain" => WIN32::NERR_NotLocalDomain,
            "NERR_IsDfsShare" => WIN32::NERR_IsDfsShare,
            "NERR_DevInvalidOpCode" => WIN32::NERR_DevInvalidOpCode,
            "NERR_DevNotFound" => WIN32::NERR_DevNotFound,
            "NERR_DevNotOpen" => WIN32::NERR_DevNotOpen,
            "NERR_BadQueueDevString" => WIN32::NERR_BadQueueDevString,
            "NERR_BadQueuePriority" => WIN32::NERR_BadQueuePriority,
            "NERR_NoCommDevs" => WIN32::NERR_NoCommDevs,
            "NERR_QueueNotFound" => WIN32::NERR_QueueNotFound,
            "NERR_BadDevString" => WIN32::NERR_BadDevString,
            "NERR_BadDev" => WIN32::NERR_BadDev,
            "NERR_InUseBySpooler" => WIN32::NERR_InUseBySpooler,
            "NERR_CommDevInUse" => WIN32::NERR_CommDevInUse,
            "NERR_InvalidComputer" => WIN32::NERR_InvalidComputer,
            "NERR_MaxLenExceeded" => WIN32::NERR_MaxLenExceeded,
            "NERR_BadComponent" => WIN32::NERR_BadComponent,
            "NERR_CantType" => WIN32::NERR_CantType,
            "NERR_TooManyEntries" => WIN32::NERR_TooManyEntries,
            "NERR_ProfileFileTooBig" => WIN32::NERR_ProfileFileTooBig,
            "NERR_ProfileOffset" => WIN32::NERR_ProfileOffset,
            "NERR_ProfileCleanup" => WIN32::NERR_ProfileCleanup,
            "NERR_ProfileUnknownCmd" => WIN32::NERR_ProfileUnknownCmd,
            "NERR_ProfileLoadErr" => WIN32::NERR_ProfileLoadErr,
            "NERR_ProfileSaveErr" => WIN32::NERR_ProfileSaveErr,
            "NERR_LogOverflow" => WIN32::NERR_LogOverflow,
            "NERR_LogFileChanged" => WIN32::NERR_LogFileChanged,
            "NERR_LogFileCorrupt" => WIN32::NERR_LogFileCorrupt,
            "NERR_SourceIsDir" => WIN32::NERR_SourceIsDir,
            "NERR_BadSource" => WIN32::NERR_BadSource,
            "NERR_BadDest" => WIN32::NERR_BadDest,
            "NERR_DifferentServers" => WIN32::NERR_DifferentServers,
            "NERR_RunSrvPaused" => WIN32::NERR_RunSrvPaused,
            "NERR_ErrCommRunSrv" => WIN32::NERR_ErrCommRunSrv,
            "NERR_ErrorExecingGhost" => WIN32::NERR_ErrorExecingGhost,
            "NERR_ShareNotFound" => WIN32::NERR_ShareNotFound,
            "NERR_InvalidLana" => WIN32::NERR_InvalidLana,
            "ERROR_OPEN_FILES" => WIN32::ERROR_OPEN_FILES,
            "NERR_OpenFiles" => WIN32::NERR_OpenFiles,
            "ERROR_ACTIVE_CONNECTIONS" => WIN32::ERROR_ACTIVE_CONNECTIONS,
            "NERR_ActiveConns" => WIN32::NERR_ActiveConns,
            "NERR_BadPasswordCore" => WIN32::NERR_BadPasswordCore,
            "ERROR_DEVICE_IN_USE" => WIN32::ERROR_DEVICE_IN_USE,
            "NERR_DevInUse" => WIN32::NERR_DevInUse,
            "NERR_LocalDrive" => WIN32::NERR_LocalDrive,
            "NERR_AlertExists" => WIN32::NERR_AlertExists,
            "NERR_TooManyAlerts" => WIN32::NERR_TooManyAlerts,
            "NERR_NoSuchAlert" => WIN32::NERR_NoSuchAlert,
            "NERR_BadRecipient" => WIN32::NERR_BadRecipient,
            "NERR_AcctLimitExceeded" => WIN32::NERR_AcctLimitExceeded,
            "NERR_InvalidLogSeek" => WIN32::NERR_InvalidLogSeek,
            "NERR_BadUasConfig" => WIN32::NERR_BadUasConfig,
            "NERR_InvalidUASOp" => WIN32::NERR_InvalidUASOp,
            "NERR_LastAdmin" => WIN32::NERR_LastAdmin,
            "NERR_DCNotFound" => WIN32::NERR_DCNotFound,
            "NERR_LogonTrackingError" => WIN32::NERR_LogonTrackingError,
            "NERR_NetlogonNotStarted" => WIN32::NERR_NetlogonNotStarted,
            "NERR_CanNotGrowUASFile" => WIN32::NERR_CanNotGrowUASFile,
            "NERR_TimeDiffAtDC" => WIN32::NERR_TimeDiffAtDC,
            "NERR_PasswordMismatch" => WIN32::NERR_PasswordMismatch,
            "NERR_NoSuchServer" => WIN32::NERR_NoSuchServer,
            "NERR_NoSuchSession" => WIN32::NERR_NoSuchSession,
            "NERR_NoSuchConnection" => WIN32::NERR_NoSuchConnection,
            "NERR_TooManyServers" => WIN32::NERR_TooManyServers,
            "NERR_TooManySessions" => WIN32::NERR_TooManySessions,
            "NERR_TooManyConnections" => WIN32::NERR_TooManyConnections,
            "NERR_TooManyFiles" => WIN32::NERR_TooManyFiles,
            "NERR_NoAlternateServers" => WIN32::NERR_NoAlternateServers,
            "NERR_TryDownLevel" => WIN32::NERR_TryDownLevel,
            "NERR_UPSDriverNotStarted" => WIN32::NERR_UPSDriverNotStarted,
            "NERR_UPSInvalidConfig" => WIN32::NERR_UPSInvalidConfig,
            "NERR_UPSInvalidCommPort" => WIN32::NERR_UPSInvalidCommPort,
            "NERR_UPSSignalAsserted" => WIN32::NERR_UPSSignalAsserted,
            "NERR_UPSShutdownFailed" => WIN32::NERR_UPSShutdownFailed,
            "NERR_BadDosRetCode" => WIN32::NERR_BadDosRetCode,
            "NERR_ProgNeedsExtraMem" => WIN32::NERR_ProgNeedsExtraMem,
            "NERR_BadDosFunction" => WIN32::NERR_BadDosFunction,
            "NERR_RemoteBootFailed" => WIN32::NERR_RemoteBootFailed,
            "NERR_BadFileCheckSum" => WIN32::NERR_BadFileCheckSum,
            "NERR_NoRplBootSystem" => WIN32::NERR_NoRplBootSystem,
            "NERR_RplLoadrNetBiosErr" => WIN32::NERR_RplLoadrNetBiosErr,
            "NERR_RplLoadrDiskErr" => WIN32::NERR_RplLoadrDiskErr,
            "NERR_ImageParamErr" => WIN32::NERR_ImageParamErr,
            "NERR_TooManyImageParams" => WIN32::NERR_TooManyImageParams,
            "NERR_NonDosFloppyUsed" => WIN32::NERR_NonDosFloppyUsed,
            "NERR_RplBootRestart" => WIN32::NERR_RplBootRestart,
            "NERR_RplSrvrCallFailed" => WIN32::NERR_RplSrvrCallFailed,
            "NERR_CantConnectRplSrvr" => WIN32::NERR_CantConnectRplSrvr,
            "NERR_CantOpenImageFile" => WIN32::NERR_CantOpenImageFile,
            "NERR_CallingRplSrvr" => WIN32::NERR_CallingRplSrvr,
            "NERR_StartingRplBoot" => WIN32::NERR_StartingRplBoot,
            "NERR_RplBootServiceTerm" => WIN32::NERR_RplBootServiceTerm,
            "NERR_RplBootStartFailed" => WIN32::NERR_RplBootStartFailed,
            "NERR_RPL_CONNECTED" => WIN32::NERR_RPL_CONNECTED,
            "NERR_BrowserConfiguredToNotRun" => WIN32::NERR_BrowserConfiguredToNotRun,
            "NERR_RplNoAdaptersStarted" => WIN32::NERR_RplNoAdaptersStarted,
            "NERR_RplBadRegistry" => WIN32::NERR_RplBadRegistry,
            "NERR_RplBadDatabase" => WIN32::NERR_RplBadDatabase,
            "NERR_RplRplfilesShare" => WIN32::NERR_RplRplfilesShare,
            "NERR_RplNotRplServer" => WIN32::NERR_RplNotRplServer,
            "NERR_RplCannotEnum" => WIN32::NERR_RplCannotEnum,
            "NERR_RplWkstaInfoCorrupted" => WIN32::NERR_RplWkstaInfoCorrupted,
            "NERR_RplWkstaNotFound" => WIN32::NERR_RplWkstaNotFound,
            "NERR_RplWkstaNameUnavailable" => WIN32::NERR_RplWkstaNameUnavailable,
            "NERR_RplProfileInfoCorrupted" => WIN32::NERR_RplProfileInfoCorrupted,
            "NERR_RplProfileNotFound" => WIN32::NERR_RplProfileNotFound,
            "NERR_RplProfileNameUnavailable" => WIN32::NERR_RplProfileNameUnavailable,
            "NERR_RplProfileNotEmpty" => WIN32::NERR_RplProfileNotEmpty,
            "NERR_RplConfigInfoCorrupted" => WIN32::NERR_RplConfigInfoCorrupted,
            "NERR_RplConfigNotFound" => WIN32::NERR_RplConfigNotFound,
            "NERR_RplAdapterInfoCorrupted" => WIN32::NERR_RplAdapterInfoCorrupted,
            "NERR_RplInternal" => WIN32::NERR_RplInternal,
            "NERR_RplVendorInfoCorrupted" => WIN32::NERR_RplVendorInfoCorrupted,
            "NERR_RplBootInfoCorrupted" => WIN32::NERR_RplBootInfoCorrupted,
            "NERR_RplWkstaNeedsUserAcct" => WIN32::NERR_RplWkstaNeedsUserAcct,
            "NERR_RplNeedsRPLUSERAcct" => WIN32::NERR_RplNeedsRPLUSERAcct,
            "NERR_RplBootNotFound" => WIN32::NERR_RplBootNotFound,
            "NERR_RplIncompatibleProfile" => WIN32::NERR_RplIncompatibleProfile,
            "NERR_RplAdapterNameUnavailable" => WIN32::NERR_RplAdapterNameUnavailable,
            "NERR_RplConfigNotEmpty" => WIN32::NERR_RplConfigNotEmpty,
            "NERR_RplBootInUse" => WIN32::NERR_RplBootInUse,
            "NERR_RplBackupDatabase" => WIN32::NERR_RplBackupDatabase,
            "NERR_RplAdapterNotFound" => WIN32::NERR_RplAdapterNotFound,
            "NERR_RplVendorNotFound" => WIN32::NERR_RplVendorNotFound,
            "NERR_RplVendorNameUnavailable" => WIN32::NERR_RplVendorNameUnavailable,
            "NERR_RplBootNameUnavailable" => WIN32::NERR_RplBootNameUnavailable,
            "NERR_RplConfigNameUnavailable" => WIN32::NERR_RplConfigNameUnavailable,
            "NERR_DfsInternalCorruption" => WIN32::NERR_DfsInternalCorruption,
            "NERR_DfsVolumeDataCorrupt" => WIN32::NERR_DfsVolumeDataCorrupt,
            "NERR_DfsNoSuchVolume" => WIN32::NERR_DfsNoSuchVolume,
            "NERR_DfsVolumeAlreadyExists" => WIN32::NERR_DfsVolumeAlreadyExists,
            "NERR_DfsAlreadyShared" => WIN32::NERR_DfsAlreadyShared,
            "NERR_DfsNoSuchShare" => WIN32::NERR_DfsNoSuchShare,
            "NERR_DfsNotALeafVolume" => WIN32::NERR_DfsNotALeafVolume,
            "NERR_DfsLeafVolume" => WIN32::NERR_DfsLeafVolume,
            "NERR_DfsVolumeHasMultipleServers" => WIN32::NERR_DfsVolumeHasMultipleServers,
            "NERR_DfsCantCreateJunctionPoint" => WIN32::NERR_DfsCantCreateJunctionPoint,
            "NERR_DfsServerNotDfsAware" => WIN32::NERR_DfsServerNotDfsAware,
            "NERR_DfsBadRenamePath" => WIN32::NERR_DfsBadRenamePath,
            "NERR_DfsVolumeIsOffline" => WIN32::NERR_DfsVolumeIsOffline,
            "NERR_DfsNoSuchServer" => WIN32::NERR_DfsNoSuchServer,
            "NERR_DfsCyclicalName" => WIN32::NERR_DfsCyclicalName,
            "NERR_DfsNotSupportedInServerDfs" => WIN32::NERR_DfsNotSupportedInServerDfs,
            "NERR_DfsDuplicateService" => WIN32::NERR_DfsDuplicateService,
            "NERR_DfsCantRemoveLastServerShare" => WIN32::NERR_DfsCantRemoveLastServerShare,
            "NERR_DfsVolumeIsInterDfs" => WIN32::NERR_DfsVolumeIsInterDfs,
            "NERR_DfsInconsistent" => WIN32::NERR_DfsInconsistent,
            "NERR_DfsServerUpgraded" => WIN32::NERR_DfsServerUpgraded,
            "NERR_DfsDataIsIdentical" => WIN32::NERR_DfsDataIsIdentical,
            "NERR_DfsCantRemoveDfsRoot" => WIN32::NERR_DfsCantRemoveDfsRoot,
            "NERR_DfsChildOrParentInDfs" => WIN32::NERR_DfsChildOrParentInDfs,
            "NERR_DfsInternalError" => WIN32::NERR_DfsInternalError,
            "NERR_SetupAlreadyJoined" => WIN32::NERR_SetupAlreadyJoined,
            "NERR_SetupNotJoined" => WIN32::NERR_SetupNotJoined,
            "NERR_SetupDomainController" => WIN32::NERR_SetupDomainController,
            "NERR_DefaultJoinRequired" => WIN32::NERR_DefaultJoinRequired,
            "NERR_InvalidWorkgroupName" => WIN32::NERR_InvalidWorkgroupName,
            "NERR_NameUsesIncompatibleCodePage" => WIN32::NERR_NameUsesIncompatibleCodePage,
            "NERR_ComputerAccountNotFound" => WIN32::NERR_ComputerAccountNotFound,
            "NERR_PersonalSku" => WIN32::NERR_PersonalSku,
            "NERR_PasswordMustChange" => WIN32::NERR_PasswordMustChange,
            "NERR_AccountLockedOut" => WIN32::NERR_AccountLockedOut,
            "NERR_PasswordTooLong" => WIN32::NERR_PasswordTooLong,
            "NERR_PasswordNotComplexEnough" => WIN32::NERR_PasswordNotComplexEnough,
            "NERR_PasswordFilterError" => WIN32::NERR_PasswordFilterError,
            "ERROR_UNKNOWN_PRINT_MONITOR" => WIN32::ERROR_UNKNOWN_PRINT_MONITOR,
            "ERROR_PRINTER_DRIVER_IN_USE" => WIN32::ERROR_PRINTER_DRIVER_IN_USE,
            "ERROR_SPOOL_FILE_NOT_FOUND" => WIN32::ERROR_SPOOL_FILE_NOT_FOUND,
            "ERROR_SPL_NO_STARTDOC" => WIN32::ERROR_SPL_NO_STARTDOC,
            "ERROR_SPL_NO_ADDJOB" => WIN32::ERROR_SPL_NO_ADDJOB,
            "ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED" => WIN32::ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED,
            "ERROR_PRINT_MONITOR_ALREADY_INSTALLED" => WIN32::ERROR_PRINT_MONITOR_ALREADY_INSTALLED,
            "ERROR_INVALID_PRINT_MONITOR" => WIN32::ERROR_INVALID_PRINT_MONITOR,
            "ERROR_PRINT_MONITOR_IN_USE" => WIN32::ERROR_PRINT_MONITOR_IN_USE,
            "ERROR_PRINTER_HAS_JOBS_QUEUED" => WIN32::ERROR_PRINTER_HAS_JOBS_QUEUED,
            "ERROR_SUCCESS_REBOOT_REQUIRED" => WIN32::ERROR_SUCCESS_REBOOT_REQUIRED,
            "ERROR_SUCCESS_RESTART_REQUIRED" => WIN32::ERROR_SUCCESS_RESTART_REQUIRED,
            "ERROR_PRINTER_NOT_FOUND" => WIN32::ERROR_PRINTER_NOT_FOUND,
            "ERROR_PRINTER_DRIVER_WARNED" => WIN32::ERROR_PRINTER_DRIVER_WARNED,
            "ERROR_PRINTER_DRIVER_BLOCKED" => WIN32::ERROR_PRINTER_DRIVER_BLOCKED,
            "ERROR_PRINTER_DRIVER_PACKAGE_IN_USE" => WIN32::ERROR_PRINTER_DRIVER_PACKAGE_IN_USE,
            "ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND" => WIN32::ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND,
            "ERROR_FAIL_REBOOT_REQUIRED" => WIN32::ERROR_FAIL_REBOOT_REQUIRED,
            "ERROR_FAIL_REBOOT_INITIATED" => WIN32::ERROR_FAIL_REBOOT_INITIATED,
            "ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED" => WIN32::ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED,
            "ERROR_PRINT_JOB_RESTART_REQUIRED" => WIN32::ERROR_PRINT_JOB_RESTART_REQUIRED,
            "ERROR_INVALID_PRINTER_DRIVER_MANIFEST" => WIN32::ERROR_INVALID_PRINTER_DRIVER_MANIFEST,
            "ERROR_PRINTER_NOT_SHAREABLE" => WIN32::ERROR_PRINTER_NOT_SHAREABLE,
            "ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1" => WIN32::ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1,
            "ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED" => WIN32::ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED,
            "ERROR_REQUEST_PAUSED" => WIN32::ERROR_REQUEST_PAUSED,
            "ERROR_APPEXEC_CONDITION_NOT_SATISFIED" => WIN32::ERROR_APPEXEC_CONDITION_NOT_SATISFIED,
            "ERROR_APPEXEC_HANDLE_INVALIDATED" => WIN32::ERROR_APPEXEC_HANDLE_INVALIDATED,
            "ERROR_APPEXEC_INVALID_HOST_GENERATION" => WIN32::ERROR_APPEXEC_INVALID_HOST_GENERATION,
            "ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION" => WIN32::ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION,
            "ERROR_APPEXEC_INVALID_HOST_STATE" => WIN32::ERROR_APPEXEC_INVALID_HOST_STATE,
            "ERROR_APPEXEC_NO_DONOR" => WIN32::ERROR_APPEXEC_NO_DONOR,
            "ERROR_APPEXEC_HOST_ID_MISMATCH" => WIN32::ERROR_APPEXEC_HOST_ID_MISMATCH,
            "ERROR_APPEXEC_UNKNOWN_USER" => WIN32::ERROR_APPEXEC_UNKNOWN_USER,
            "ERROR_APPEXEC_APP_COMPAT_BLOCK" => WIN32::ERROR_APPEXEC_APP_COMPAT_BLOCK,
            "ERROR_APPEXEC_CALLER_WAIT_TIMEOUT" => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT,
            "ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION" => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION,
            "ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING" => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING,
            "ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES" => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES,
            "ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED" => WIN32::ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED,
            "ERROR_VRF_VOLATILE_NOT_STOPPABLE" => WIN32::ERROR_VRF_VOLATILE_NOT_STOPPABLE,
            "ERROR_VRF_VOLATILE_SAFE_MODE" => WIN32::ERROR_VRF_VOLATILE_SAFE_MODE,
            "ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM" => WIN32::ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM,
            "ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS" => WIN32::ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS,
            "ERROR_VRF_VOLATILE_PROTECTED_DRIVER" => WIN32::ERROR_VRF_VOLATILE_PROTECTED_DRIVER,
            "ERROR_VRF_VOLATILE_NMI_REGISTERED" => WIN32::ERROR_VRF_VOLATILE_NMI_REGISTERED,
            "ERROR_VRF_VOLATILE_SETTINGS_CONFLICT" => WIN32::ERROR_VRF_VOLATILE_SETTINGS_CONFLICT,
            "ERROR_DIF_IOCALLBACK_NOT_REPLACED" => WIN32::ERROR_DIF_IOCALLBACK_NOT_REPLACED,
            "ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED" => WIN32::ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED,
            "ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED" => WIN32::ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED,
            "ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED" => WIN32::ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED,
            "ERROR_DIF_VOLATILE_INVALID_INFO" => WIN32::ERROR_DIF_VOLATILE_INVALID_INFO,
            "ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING" => WIN32::ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING,
            "ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING" => WIN32::ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING,
            "ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED" => WIN32::ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED,
            "ERROR_DIF_VOLATILE_NOT_ALLOWED" => WIN32::ERROR_DIF_VOLATILE_NOT_ALLOWED,
            "ERROR_DIF_BINDING_API_NOT_FOUND" => WIN32::ERROR_DIF_BINDING_API_NOT_FOUND,
            "ERROR_IO_REISSUE_AS_CACHED" => WIN32::ERROR_IO_REISSUE_AS_CACHED,
            "ERROR_WINS_INTERNAL" => WIN32::ERROR_WINS_INTERNAL,
            "ERROR_CAN_NOT_DEL_LOCAL_WINS" => WIN32::ERROR_CAN_NOT_DEL_LOCAL_WINS,
            "ERROR_STATIC_INIT" => WIN32::ERROR_STATIC_INIT,
            "ERROR_INC_BACKUP" => WIN32::ERROR_INC_BACKUP,
            "ERROR_FULL_BACKUP" => WIN32::ERROR_FULL_BACKUP,
            "ERROR_REC_NON_EXISTENT" => WIN32::ERROR_REC_NON_EXISTENT,
            "ERROR_RPL_NOT_ALLOWED" => WIN32::ERROR_RPL_NOT_ALLOWED,
            "PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED" => WIN32::PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED,
            "PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO" => WIN32::PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO,
            "PEERDIST_ERROR_MISSING_DATA" => WIN32::PEERDIST_ERROR_MISSING_DATA,
            "PEERDIST_ERROR_NO_MORE" => WIN32::PEERDIST_ERROR_NO_MORE,
            "PEERDIST_ERROR_NOT_INITIALIZED" => WIN32::PEERDIST_ERROR_NOT_INITIALIZED,
            "PEERDIST_ERROR_ALREADY_INITIALIZED" => WIN32::PEERDIST_ERROR_ALREADY_INITIALIZED,
            "PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS" => WIN32::PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS,
            "PEERDIST_ERROR_INVALIDATED" => WIN32::PEERDIST_ERROR_INVALIDATED,
            "PEERDIST_ERROR_ALREADY_EXISTS" => WIN32::PEERDIST_ERROR_ALREADY_EXISTS,
            "PEERDIST_ERROR_OPERATION_NOTFOUND" => WIN32::PEERDIST_ERROR_OPERATION_NOTFOUND,
            "PEERDIST_ERROR_ALREADY_COMPLETED" => WIN32::PEERDIST_ERROR_ALREADY_COMPLETED,
            "PEERDIST_ERROR_OUT_OF_BOUNDS" => WIN32::PEERDIST_ERROR_OUT_OF_BOUNDS,
            "PEERDIST_ERROR_VERSION_UNSUPPORTED" => WIN32::PEERDIST_ERROR_VERSION_UNSUPPORTED,
            "PEERDIST_ERROR_INVALID_CONFIGURATION" => WIN32::PEERDIST_ERROR_INVALID_CONFIGURATION,
            "PEERDIST_ERROR_NOT_LICENSED" => WIN32::PEERDIST_ERROR_NOT_LICENSED,
            "PEERDIST_ERROR_SERVICE_UNAVAILABLE" => WIN32::PEERDIST_ERROR_SERVICE_UNAVAILABLE,
            "PEERDIST_ERROR_TRUST_FAILURE" => WIN32::PEERDIST_ERROR_TRUST_FAILURE,
            "ERROR_DHCP_ADDRESS_CONFLICT" => WIN32::ERROR_DHCP_ADDRESS_CONFLICT,
            "ERROR_WMI_GUID_NOT_FOUND" => WIN32::ERROR_WMI_GUID_NOT_FOUND,
            "ERROR_WMI_INSTANCE_NOT_FOUND" => WIN32::ERROR_WMI_INSTANCE_NOT_FOUND,
            "ERROR_WMI_ITEMID_NOT_FOUND" => WIN32::ERROR_WMI_ITEMID_NOT_FOUND,
            "ERROR_WMI_TRY_AGAIN" => WIN32::ERROR_WMI_TRY_AGAIN,
            "ERROR_WMI_DP_NOT_FOUND" => WIN32::ERROR_WMI_DP_NOT_FOUND,
            "ERROR_WMI_UNRESOLVED_INSTANCE_REF" => WIN32::ERROR_WMI_UNRESOLVED_INSTANCE_REF,
            "ERROR_WMI_ALREADY_ENABLED" => WIN32::ERROR_WMI_ALREADY_ENABLED,
            "ERROR_WMI_GUID_DISCONNECTED" => WIN32::ERROR_WMI_GUID_DISCONNECTED,
            "ERROR_WMI_SERVER_UNAVAILABLE" => WIN32::ERROR_WMI_SERVER_UNAVAILABLE,
            "ERROR_WMI_DP_FAILED" => WIN32::ERROR_WMI_DP_FAILED,
            "ERROR_WMI_INVALID_MOF" => WIN32::ERROR_WMI_INVALID_MOF,
            "ERROR_WMI_INVALID_REGINFO" => WIN32::ERROR_WMI_INVALID_REGINFO,
            "ERROR_WMI_ALREADY_DISABLED" => WIN32::ERROR_WMI_ALREADY_DISABLED,
            "ERROR_WMI_READ_ONLY" => WIN32::ERROR_WMI_READ_ONLY,
            "ERROR_WMI_SET_FAILURE" => WIN32::ERROR_WMI_SET_FAILURE,
            "ERROR_NOT_APPCONTAINER" => WIN32::ERROR_NOT_APPCONTAINER,
            "ERROR_APPCONTAINER_REQUIRED" => WIN32::ERROR_APPCONTAINER_REQUIRED,
            "ERROR_NOT_SUPPORTED_IN_APPCONTAINER" => WIN32::ERROR_NOT_SUPPORTED_IN_APPCONTAINER,
            "ERROR_INVALID_PACKAGE_SID_LENGTH" => WIN32::ERROR_INVALID_PACKAGE_SID_LENGTH,
            "ERROR_INVALID_MEDIA" => WIN32::ERROR_INVALID_MEDIA,
            "ERROR_INVALID_LIBRARY" => WIN32::ERROR_INVALID_LIBRARY,
            "ERROR_INVALID_MEDIA_POOL" => WIN32::ERROR_INVALID_MEDIA_POOL,
            "ERROR_DRIVE_MEDIA_MISMATCH" => WIN32::ERROR_DRIVE_MEDIA_MISMATCH,
            "ERROR_MEDIA_OFFLINE" => WIN32::ERROR_MEDIA_OFFLINE,
            "ERROR_LIBRARY_OFFLINE" => WIN32::ERROR_LIBRARY_OFFLINE,
            "ERROR_EMPTY" => WIN32::ERROR_EMPTY,
            "ERROR_NOT_EMPTY" => WIN32::ERROR_NOT_EMPTY,
            "ERROR_MEDIA_UNAVAILABLE" => WIN32::ERROR_MEDIA_UNAVAILABLE,
            "ERROR_RESOURCE_DISABLED" => WIN32::ERROR_RESOURCE_DISABLED,
            "ERROR_INVALID_CLEANER" => WIN32::ERROR_INVALID_CLEANER,
            "ERROR_UNABLE_TO_CLEAN" => WIN32::ERROR_UNABLE_TO_CLEAN,
            "ERROR_OBJECT_NOT_FOUND" => WIN32::ERROR_OBJECT_NOT_FOUND,
            "ERROR_DATABASE_FAILURE" => WIN32::ERROR_DATABASE_FAILURE,
            "ERROR_DATABASE_FULL" => WIN32::ERROR_DATABASE_FULL,
            "ERROR_MEDIA_INCOMPATIBLE" => WIN32::ERROR_MEDIA_INCOMPATIBLE,
            "ERROR_RESOURCE_NOT_PRESENT" => WIN32::ERROR_RESOURCE_NOT_PRESENT,
            "ERROR_INVALID_OPERATION" => WIN32::ERROR_INVALID_OPERATION,
            "ERROR_MEDIA_NOT_AVAILABLE" => WIN32::ERROR_MEDIA_NOT_AVAILABLE,
            "ERROR_DEVICE_NOT_AVAILABLE" => WIN32::ERROR_DEVICE_NOT_AVAILABLE,
            "ERROR_REQUEST_REFUSED" => WIN32::ERROR_REQUEST_REFUSED,
            "ERROR_INVALID_DRIVE_OBJECT" => WIN32::ERROR_INVALID_DRIVE_OBJECT,
            "ERROR_LIBRARY_FULL" => WIN32::ERROR_LIBRARY_FULL,
            "ERROR_MEDIUM_NOT_ACCESSIBLE" => WIN32::ERROR_MEDIUM_NOT_ACCESSIBLE,
            "ERROR_UNABLE_TO_LOAD_MEDIUM" => WIN32::ERROR_UNABLE_TO_LOAD_MEDIUM,
            "ERROR_UNABLE_TO_INVENTORY_DRIVE" => WIN32::ERROR_UNABLE_TO_INVENTORY_DRIVE,
            "ERROR_UNABLE_TO_INVENTORY_SLOT" => WIN32::ERROR_UNABLE_TO_INVENTORY_SLOT,
            "ERROR_UNABLE_TO_INVENTORY_TRANSPORT" => WIN32::ERROR_UNABLE_TO_INVENTORY_TRANSPORT,
            "ERROR_TRANSPORT_FULL" => WIN32::ERROR_TRANSPORT_FULL,
            "ERROR_CONTROLLING_IEPORT" => WIN32::ERROR_CONTROLLING_IEPORT,
            "ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA" => WIN32::ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA,
            "ERROR_CLEANER_SLOT_SET" => WIN32::ERROR_CLEANER_SLOT_SET,
            "ERROR_CLEANER_SLOT_NOT_SET" => WIN32::ERROR_CLEANER_SLOT_NOT_SET,
            "ERROR_CLEANER_CARTRIDGE_SPENT" => WIN32::ERROR_CLEANER_CARTRIDGE_SPENT,
            "ERROR_UNEXPECTED_OMID" => WIN32::ERROR_UNEXPECTED_OMID,
            "ERROR_CANT_DELETE_LAST_ITEM" => WIN32::ERROR_CANT_DELETE_LAST_ITEM,
            "ERROR_MESSAGE_EXCEEDS_MAX_SIZE" => WIN32::ERROR_MESSAGE_EXCEEDS_MAX_SIZE,
            "ERROR_VOLUME_CONTAINS_SYS_FILES" => WIN32::ERROR_VOLUME_CONTAINS_SYS_FILES,
            "ERROR_INDIGENOUS_TYPE" => WIN32::ERROR_INDIGENOUS_TYPE,
            "ERROR_NO_SUPPORTING_DRIVES" => WIN32::ERROR_NO_SUPPORTING_DRIVES,
            "ERROR_CLEANER_CARTRIDGE_INSTALLED" => WIN32::ERROR_CLEANER_CARTRIDGE_INSTALLED,
            "ERROR_IEPORT_FULL" => WIN32::ERROR_IEPORT_FULL,
            "ERROR_FILE_OFFLINE" => WIN32::ERROR_FILE_OFFLINE,
            "ERROR_REMOTE_STORAGE_NOT_ACTIVE" => WIN32::ERROR_REMOTE_STORAGE_NOT_ACTIVE,
            "ERROR_REMOTE_STORAGE_MEDIA_ERROR" => WIN32::ERROR_REMOTE_STORAGE_MEDIA_ERROR,
            "ERROR_NOT_A_REPARSE_POINT" => WIN32::ERROR_NOT_A_REPARSE_POINT,
            "ERROR_REPARSE_ATTRIBUTE_CONFLICT" => WIN32::ERROR_REPARSE_ATTRIBUTE_CONFLICT,
            "ERROR_INVALID_REPARSE_DATA" => WIN32::ERROR_INVALID_REPARSE_DATA,
            "ERROR_REPARSE_TAG_INVALID" => WIN32::ERROR_REPARSE_TAG_INVALID,
            "ERROR_REPARSE_TAG_MISMATCH" => WIN32::ERROR_REPARSE_TAG_MISMATCH,
            "ERROR_REPARSE_POINT_ENCOUNTERED" => WIN32::ERROR_REPARSE_POINT_ENCOUNTERED,
            "ERROR_APP_DATA_NOT_FOUND" => WIN32::ERROR_APP_DATA_NOT_FOUND,
            "ERROR_APP_DATA_EXPIRED" => WIN32::ERROR_APP_DATA_EXPIRED,
            "ERROR_APP_DATA_CORRUPT" => WIN32::ERROR_APP_DATA_CORRUPT,
            "ERROR_APP_DATA_LIMIT_EXCEEDED" => WIN32::ERROR_APP_DATA_LIMIT_EXCEEDED,
            "ERROR_APP_DATA_REBOOT_REQUIRED" => WIN32::ERROR_APP_DATA_REBOOT_REQUIRED,
            "ERROR_SECUREBOOT_ROLLBACK_DETECTED" => WIN32::ERROR_SECUREBOOT_ROLLBACK_DETECTED,
            "ERROR_SECUREBOOT_POLICY_VIOLATION" => WIN32::ERROR_SECUREBOOT_POLICY_VIOLATION,
            "ERROR_SECUREBOOT_INVALID_POLICY" => WIN32::ERROR_SECUREBOOT_INVALID_POLICY,
            "ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND" => WIN32::ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND,
            "ERROR_SECUREBOOT_POLICY_NOT_SIGNED" => WIN32::ERROR_SECUREBOOT_POLICY_NOT_SIGNED,
            "ERROR_SECUREBOOT_NOT_ENABLED" => WIN32::ERROR_SECUREBOOT_NOT_ENABLED,
            "ERROR_SECUREBOOT_FILE_REPLACED" => WIN32::ERROR_SECUREBOOT_FILE_REPLACED,
            "ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED" => WIN32::ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED,
            "ERROR_SECUREBOOT_POLICY_UNKNOWN" => WIN32::ERROR_SECUREBOOT_POLICY_UNKNOWN,
            "ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION" => WIN32::ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION,
            "ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH" => WIN32::ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH,
            "ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED" => WIN32::ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED,
            "ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH" => WIN32::ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH,
            "ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING" => WIN32::ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING,
            "ERROR_SECUREBOOT_NOT_BASE_POLICY" => WIN32::ERROR_SECUREBOOT_NOT_BASE_POLICY,
            "ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY" => WIN32::ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY,
            "ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED" => WIN32::ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED,
            "ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED" => WIN32::ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED,
            "ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED" => WIN32::ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED,
            "ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED" => WIN32::ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED,
            "ERROR_ALREADY_HAS_STREAM_ID" => WIN32::ERROR_ALREADY_HAS_STREAM_ID,
            "ERROR_SMR_GARBAGE_COLLECTION_REQUIRED" => WIN32::ERROR_SMR_GARBAGE_COLLECTION_REQUIRED,
            "ERROR_WOF_WIM_HEADER_CORRUPT" => WIN32::ERROR_WOF_WIM_HEADER_CORRUPT,
            "ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT" => WIN32::ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT,
            "ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT" => WIN32::ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT,
            "ERROR_OBJECT_IS_IMMUTABLE" => WIN32::ERROR_OBJECT_IS_IMMUTABLE,
            "ERROR_VOLUME_NOT_SIS_ENABLED" => WIN32::ERROR_VOLUME_NOT_SIS_ENABLED,
            "ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED" => WIN32::ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED,
            "ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION" => WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION,
            "ERROR_SYSTEM_INTEGRITY_INVALID_POLICY" => WIN32::ERROR_SYSTEM_INTEGRITY_INVALID_POLICY,
            "ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED" => WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED,
            "ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES" => WIN32::ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES,
            "ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED" => WIN32::ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE,
            "ERROR_VSM_NOT_INITIALIZED" => WIN32::ERROR_VSM_NOT_INITIALIZED,
            "ERROR_VSM_DMA_PROTECTION_NOT_IN_USE" => WIN32::ERROR_VSM_DMA_PROTECTION_NOT_IN_USE,
            "ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED" => WIN32::ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED,
            "ERROR_PLATFORM_MANIFEST_INVALID" => WIN32::ERROR_PLATFORM_MANIFEST_INVALID,
            "ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED" => WIN32::ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED,
            "ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED" => WIN32::ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED,
            "ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND" => WIN32::ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND,
            "ERROR_PLATFORM_MANIFEST_NOT_ACTIVE" => WIN32::ERROR_PLATFORM_MANIFEST_NOT_ACTIVE,
            "ERROR_PLATFORM_MANIFEST_NOT_SIGNED" => WIN32::ERROR_PLATFORM_MANIFEST_NOT_SIGNED,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE,
            "ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE" => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE,
            "ERROR_DEPENDENT_RESOURCE_EXISTS" => WIN32::ERROR_DEPENDENT_RESOURCE_EXISTS,
            "ERROR_DEPENDENCY_NOT_FOUND" => WIN32::ERROR_DEPENDENCY_NOT_FOUND,
            "ERROR_DEPENDENCY_ALREADY_EXISTS" => WIN32::ERROR_DEPENDENCY_ALREADY_EXISTS,
            "ERROR_RESOURCE_NOT_ONLINE" => WIN32::ERROR_RESOURCE_NOT_ONLINE,
            "ERROR_HOST_NODE_NOT_AVAILABLE" => WIN32::ERROR_HOST_NODE_NOT_AVAILABLE,
            "ERROR_RESOURCE_NOT_AVAILABLE" => WIN32::ERROR_RESOURCE_NOT_AVAILABLE,
            "ERROR_RESOURCE_NOT_FOUND" => WIN32::ERROR_RESOURCE_NOT_FOUND,
            "ERROR_SHUTDOWN_CLUSTER" => WIN32::ERROR_SHUTDOWN_CLUSTER,
            "ERROR_CANT_EVICT_ACTIVE_NODE" => WIN32::ERROR_CANT_EVICT_ACTIVE_NODE,
            "ERROR_OBJECT_ALREADY_EXISTS" => WIN32::ERROR_OBJECT_ALREADY_EXISTS,
            "ERROR_OBJECT_IN_LIST" => WIN32::ERROR_OBJECT_IN_LIST,
            "ERROR_GROUP_NOT_AVAILABLE" => WIN32::ERROR_GROUP_NOT_AVAILABLE,
            "ERROR_GROUP_NOT_FOUND" => WIN32::ERROR_GROUP_NOT_FOUND,
            "ERROR_GROUP_NOT_ONLINE" => WIN32::ERROR_GROUP_NOT_ONLINE,
            "ERROR_HOST_NODE_NOT_RESOURCE_OWNER" => WIN32::ERROR_HOST_NODE_NOT_RESOURCE_OWNER,
            "ERROR_HOST_NODE_NOT_GROUP_OWNER" => WIN32::ERROR_HOST_NODE_NOT_GROUP_OWNER,
            "ERROR_RESMON_CREATE_FAILED" => WIN32::ERROR_RESMON_CREATE_FAILED,
            "ERROR_RESMON_ONLINE_FAILED" => WIN32::ERROR_RESMON_ONLINE_FAILED,
            "ERROR_RESOURCE_ONLINE" => WIN32::ERROR_RESOURCE_ONLINE,
            "ERROR_QUORUM_RESOURCE" => WIN32::ERROR_QUORUM_RESOURCE,
            "ERROR_NOT_QUORUM_CAPABLE" => WIN32::ERROR_NOT_QUORUM_CAPABLE,
            "ERROR_CLUSTER_SHUTTING_DOWN" => WIN32::ERROR_CLUSTER_SHUTTING_DOWN,
            "ERROR_INVALID_STATE" => WIN32::ERROR_INVALID_STATE,
            "ERROR_RESOURCE_PROPERTIES_STORED" => WIN32::ERROR_RESOURCE_PROPERTIES_STORED,
            "ERROR_NOT_QUORUM_CLASS" => WIN32::ERROR_NOT_QUORUM_CLASS,
            "ERROR_CORE_RESOURCE" => WIN32::ERROR_CORE_RESOURCE,
            "ERROR_QUORUM_RESOURCE_ONLINE_FAILED" => WIN32::ERROR_QUORUM_RESOURCE_ONLINE_FAILED,
            "ERROR_QUORUMLOG_OPEN_FAILED" => WIN32::ERROR_QUORUMLOG_OPEN_FAILED,
            "ERROR_CLUSTERLOG_CORRUPT" => WIN32::ERROR_CLUSTERLOG_CORRUPT,
            "ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE" => WIN32::ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE,
            "ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE" => WIN32::ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE,
            "ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND" => WIN32::ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND,
            "ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE" => WIN32::ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE,
            "ERROR_QUORUM_OWNER_ALIVE" => WIN32::ERROR_QUORUM_OWNER_ALIVE,
            "ERROR_NETWORK_NOT_AVAILABLE" => WIN32::ERROR_NETWORK_NOT_AVAILABLE,
            "ERROR_NODE_NOT_AVAILABLE" => WIN32::ERROR_NODE_NOT_AVAILABLE,
            "ERROR_ALL_NODES_NOT_AVAILABLE" => WIN32::ERROR_ALL_NODES_NOT_AVAILABLE,
            "ERROR_RESOURCE_FAILED" => WIN32::ERROR_RESOURCE_FAILED,
            "ERROR_CLUSTER_INVALID_NODE" => WIN32::ERROR_CLUSTER_INVALID_NODE,
            "ERROR_CLUSTER_NODE_EXISTS" => WIN32::ERROR_CLUSTER_NODE_EXISTS,
            "ERROR_CLUSTER_JOIN_IN_PROGRESS" => WIN32::ERROR_CLUSTER_JOIN_IN_PROGRESS,
            "ERROR_CLUSTER_NODE_NOT_FOUND" => WIN32::ERROR_CLUSTER_NODE_NOT_FOUND,
            "ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND" => WIN32::ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND,
            "ERROR_CLUSTER_NETWORK_EXISTS" => WIN32::ERROR_CLUSTER_NETWORK_EXISTS,
            "ERROR_CLUSTER_NETWORK_NOT_FOUND" => WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND,
            "ERROR_CLUSTER_NETINTERFACE_EXISTS" => WIN32::ERROR_CLUSTER_NETINTERFACE_EXISTS,
            "ERROR_CLUSTER_NETINTERFACE_NOT_FOUND" => WIN32::ERROR_CLUSTER_NETINTERFACE_NOT_FOUND,
            "ERROR_CLUSTER_INVALID_REQUEST" => WIN32::ERROR_CLUSTER_INVALID_REQUEST,
            "ERROR_CLUSTER_INVALID_NETWORK_PROVIDER" => WIN32::ERROR_CLUSTER_INVALID_NETWORK_PROVIDER,
            "ERROR_CLUSTER_NODE_DOWN" => WIN32::ERROR_CLUSTER_NODE_DOWN,
            "ERROR_CLUSTER_NODE_UNREACHABLE" => WIN32::ERROR_CLUSTER_NODE_UNREACHABLE,
            "ERROR_CLUSTER_NODE_NOT_MEMBER" => WIN32::ERROR_CLUSTER_NODE_NOT_MEMBER,
            "ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS" => WIN32::ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS,
            "ERROR_CLUSTER_INVALID_NETWORK" => WIN32::ERROR_CLUSTER_INVALID_NETWORK,
            "ERROR_CLUSTER_NODE_UP" => WIN32::ERROR_CLUSTER_NODE_UP,
            "ERROR_CLUSTER_IPADDR_IN_USE" => WIN32::ERROR_CLUSTER_IPADDR_IN_USE,
            "ERROR_CLUSTER_NODE_NOT_PAUSED" => WIN32::ERROR_CLUSTER_NODE_NOT_PAUSED,
            "ERROR_CLUSTER_NO_SECURITY_CONTEXT" => WIN32::ERROR_CLUSTER_NO_SECURITY_CONTEXT,
            "ERROR_CLUSTER_NETWORK_NOT_INTERNAL" => WIN32::ERROR_CLUSTER_NETWORK_NOT_INTERNAL,
            "ERROR_CLUSTER_NODE_ALREADY_UP" => WIN32::ERROR_CLUSTER_NODE_ALREADY_UP,
            "ERROR_CLUSTER_NODE_ALREADY_DOWN" => WIN32::ERROR_CLUSTER_NODE_ALREADY_DOWN,
            "ERROR_CLUSTER_NETWORK_ALREADY_ONLINE" => WIN32::ERROR_CLUSTER_NETWORK_ALREADY_ONLINE,
            "ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE" => WIN32::ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE,
            "ERROR_CLUSTER_NODE_ALREADY_MEMBER" => WIN32::ERROR_CLUSTER_NODE_ALREADY_MEMBER,
            "ERROR_CLUSTER_LAST_INTERNAL_NETWORK" => WIN32::ERROR_CLUSTER_LAST_INTERNAL_NETWORK,
            "ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS" => WIN32::ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS,
            "ERROR_INVALID_OPERATION_ON_QUORUM" => WIN32::ERROR_INVALID_OPERATION_ON_QUORUM,
            "ERROR_DEPENDENCY_NOT_ALLOWED" => WIN32::ERROR_DEPENDENCY_NOT_ALLOWED,
            "ERROR_CLUSTER_NODE_PAUSED" => WIN32::ERROR_CLUSTER_NODE_PAUSED,
            "ERROR_NODE_CANT_HOST_RESOURCE" => WIN32::ERROR_NODE_CANT_HOST_RESOURCE,
            "ERROR_CLUSTER_NODE_NOT_READY" => WIN32::ERROR_CLUSTER_NODE_NOT_READY,
            "ERROR_CLUSTER_NODE_SHUTTING_DOWN" => WIN32::ERROR_CLUSTER_NODE_SHUTTING_DOWN,
            "ERROR_CLUSTER_JOIN_ABORTED" => WIN32::ERROR_CLUSTER_JOIN_ABORTED,
            "ERROR_CLUSTER_INCOMPATIBLE_VERSIONS" => WIN32::ERROR_CLUSTER_INCOMPATIBLE_VERSIONS,
            "ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED" => WIN32::ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED,
            "ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED" => WIN32::ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED,
            "ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND" => WIN32::ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND,
            "ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED" => WIN32::ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED,
            "ERROR_CLUSTER_RESNAME_NOT_FOUND" => WIN32::ERROR_CLUSTER_RESNAME_NOT_FOUND,
            "ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED" => WIN32::ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED,
            "ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST" => WIN32::ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST,
            "ERROR_CLUSTER_DATABASE_SEQMISMATCH" => WIN32::ERROR_CLUSTER_DATABASE_SEQMISMATCH,
            "ERROR_RESMON_INVALID_STATE" => WIN32::ERROR_RESMON_INVALID_STATE,
            "ERROR_CLUSTER_GUM_NOT_LOCKER" => WIN32::ERROR_CLUSTER_GUM_NOT_LOCKER,
            "ERROR_QUORUM_DISK_NOT_FOUND" => WIN32::ERROR_QUORUM_DISK_NOT_FOUND,
            "ERROR_DATABASE_BACKUP_CORRUPT" => WIN32::ERROR_DATABASE_BACKUP_CORRUPT,
            "ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT" => WIN32::ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT,
            "ERROR_RESOURCE_PROPERTY_UNCHANGEABLE" => WIN32::ERROR_RESOURCE_PROPERTY_UNCHANGEABLE,
            "ERROR_NO_ADMIN_ACCESS_POINT" => WIN32::ERROR_NO_ADMIN_ACCESS_POINT,
            "ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE" => WIN32::ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE,
            "ERROR_CLUSTER_QUORUMLOG_NOT_FOUND" => WIN32::ERROR_CLUSTER_QUORUMLOG_NOT_FOUND,
            "ERROR_CLUSTER_MEMBERSHIP_HALT" => WIN32::ERROR_CLUSTER_MEMBERSHIP_HALT,
            "ERROR_CLUSTER_INSTANCE_ID_MISMATCH" => WIN32::ERROR_CLUSTER_INSTANCE_ID_MISMATCH,
            "ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP" => WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP,
            "ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH" => WIN32::ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH,
            "ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP" => WIN32::ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP,
            "ERROR_CLUSTER_PARAMETER_MISMATCH" => WIN32::ERROR_CLUSTER_PARAMETER_MISMATCH,
            "ERROR_NODE_CANNOT_BE_CLUSTERED" => WIN32::ERROR_NODE_CANNOT_BE_CLUSTERED,
            "ERROR_CLUSTER_WRONG_OS_VERSION" => WIN32::ERROR_CLUSTER_WRONG_OS_VERSION,
            "ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME" => WIN32::ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME,
            "ERROR_CLUSCFG_ALREADY_COMMITTED" => WIN32::ERROR_CLUSCFG_ALREADY_COMMITTED,
            "ERROR_CLUSCFG_ROLLBACK_FAILED" => WIN32::ERROR_CLUSCFG_ROLLBACK_FAILED,
            "ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT" => WIN32::ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT,
            "ERROR_CLUSTER_OLD_VERSION" => WIN32::ERROR_CLUSTER_OLD_VERSION,
            "ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME" => WIN32::ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME,
            "ERROR_CLUSTER_NO_NET_ADAPTERS" => WIN32::ERROR_CLUSTER_NO_NET_ADAPTERS,
            "ERROR_CLUSTER_POISONED" => WIN32::ERROR_CLUSTER_POISONED,
            "ERROR_CLUSTER_GROUP_MOVING" => WIN32::ERROR_CLUSTER_GROUP_MOVING,
            "ERROR_CLUSTER_RESOURCE_TYPE_BUSY" => WIN32::ERROR_CLUSTER_RESOURCE_TYPE_BUSY,
            "ERROR_RESOURCE_CALL_TIMED_OUT" => WIN32::ERROR_RESOURCE_CALL_TIMED_OUT,
            "ERROR_INVALID_CLUSTER_IPV6_ADDRESS" => WIN32::ERROR_INVALID_CLUSTER_IPV6_ADDRESS,
            "ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION" => WIN32::ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION,
            "ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS" => WIN32::ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS,
            "ERROR_CLUSTER_PARTIAL_SEND" => WIN32::ERROR_CLUSTER_PARTIAL_SEND,
            "ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION" => WIN32::ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION,
            "ERROR_CLUSTER_INVALID_STRING_TERMINATION" => WIN32::ERROR_CLUSTER_INVALID_STRING_TERMINATION,
            "ERROR_CLUSTER_INVALID_STRING_FORMAT" => WIN32::ERROR_CLUSTER_INVALID_STRING_FORMAT,
            "ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS" => WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS,
            "ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS" => WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS,
            "ERROR_CLUSTER_NULL_DATA" => WIN32::ERROR_CLUSTER_NULL_DATA,
            "ERROR_CLUSTER_PARTIAL_READ" => WIN32::ERROR_CLUSTER_PARTIAL_READ,
            "ERROR_CLUSTER_PARTIAL_WRITE" => WIN32::ERROR_CLUSTER_PARTIAL_WRITE,
            "ERROR_CLUSTER_CANT_DESERIALIZE_DATA" => WIN32::ERROR_CLUSTER_CANT_DESERIALIZE_DATA,
            "ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT" => WIN32::ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT,
            "ERROR_CLUSTER_NO_QUORUM" => WIN32::ERROR_CLUSTER_NO_QUORUM,
            "ERROR_CLUSTER_INVALID_IPV6_NETWORK" => WIN32::ERROR_CLUSTER_INVALID_IPV6_NETWORK,
            "ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK" => WIN32::ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK,
            "ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP" => WIN32::ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP,
            "ERROR_DEPENDENCY_TREE_TOO_COMPLEX" => WIN32::ERROR_DEPENDENCY_TREE_TOO_COMPLEX,
            "ERROR_EXCEPTION_IN_RESOURCE_CALL" => WIN32::ERROR_EXCEPTION_IN_RESOURCE_CALL,
            "ERROR_CLUSTER_RHS_FAILED_INITIALIZATION" => WIN32::ERROR_CLUSTER_RHS_FAILED_INITIALIZATION,
            "ERROR_CLUSTER_NOT_INSTALLED" => WIN32::ERROR_CLUSTER_NOT_INSTALLED,
            "ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE" => WIN32::ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE,
            "ERROR_CLUSTER_MAX_NODES_IN_CLUSTER" => WIN32::ERROR_CLUSTER_MAX_NODES_IN_CLUSTER,
            "ERROR_CLUSTER_TOO_MANY_NODES" => WIN32::ERROR_CLUSTER_TOO_MANY_NODES,
            "ERROR_CLUSTER_OBJECT_ALREADY_USED" => WIN32::ERROR_CLUSTER_OBJECT_ALREADY_USED,
            "ERROR_NONCORE_GROUPS_FOUND" => WIN32::ERROR_NONCORE_GROUPS_FOUND,
            "ERROR_FILE_SHARE_RESOURCE_CONFLICT" => WIN32::ERROR_FILE_SHARE_RESOURCE_CONFLICT,
            "ERROR_CLUSTER_EVICT_INVALID_REQUEST" => WIN32::ERROR_CLUSTER_EVICT_INVALID_REQUEST,
            "ERROR_CLUSTER_SINGLETON_RESOURCE" => WIN32::ERROR_CLUSTER_SINGLETON_RESOURCE,
            "ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE" => WIN32::ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE,
            "ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED" => WIN32::ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED,
            "ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR" => WIN32::ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR,
            "ERROR_CLUSTER_GROUP_BUSY" => WIN32::ERROR_CLUSTER_GROUP_BUSY,
            "ERROR_CLUSTER_NOT_SHARED_VOLUME" => WIN32::ERROR_CLUSTER_NOT_SHARED_VOLUME,
            "ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR" => WIN32::ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR,
            "ERROR_CLUSTER_SHARED_VOLUMES_IN_USE" => WIN32::ERROR_CLUSTER_SHARED_VOLUMES_IN_USE,
            "ERROR_CLUSTER_USE_SHARED_VOLUMES_API" => WIN32::ERROR_CLUSTER_USE_SHARED_VOLUMES_API,
            "ERROR_CLUSTER_BACKUP_IN_PROGRESS" => WIN32::ERROR_CLUSTER_BACKUP_IN_PROGRESS,
            "ERROR_NON_CSV_PATH" => WIN32::ERROR_NON_CSV_PATH,
            "ERROR_CSV_VOLUME_NOT_LOCAL" => WIN32::ERROR_CSV_VOLUME_NOT_LOCAL,
            "ERROR_CLUSTER_WATCHDOG_TERMINATING" => WIN32::ERROR_CLUSTER_WATCHDOG_TERMINATING,
            "ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES" => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES,
            "ERROR_CLUSTER_INVALID_NODE_WEIGHT" => WIN32::ERROR_CLUSTER_INVALID_NODE_WEIGHT,
            "ERROR_CLUSTER_RESOURCE_VETOED_CALL" => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_CALL,
            "ERROR_RESMON_SYSTEM_RESOURCES_LACKING" => WIN32::ERROR_RESMON_SYSTEM_RESOURCES_LACKING,
            "ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION" => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION,
            "ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE" => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE,
            "ERROR_CLUSTER_GROUP_QUEUED" => WIN32::ERROR_CLUSTER_GROUP_QUEUED,
            "ERROR_CLUSTER_RESOURCE_LOCKED_STATUS" => WIN32::ERROR_CLUSTER_RESOURCE_LOCKED_STATUS,
            "ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED" => WIN32::ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED,
            "ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS" => WIN32::ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS,
            "ERROR_CLUSTER_DISK_NOT_CONNECTED" => WIN32::ERROR_CLUSTER_DISK_NOT_CONNECTED,
            "ERROR_DISK_NOT_CSV_CAPABLE" => WIN32::ERROR_DISK_NOT_CSV_CAPABLE,
            "ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE" => WIN32::ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE,
            "ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED" => WIN32::ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED,
            "ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED" => WIN32::ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED,
            "ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES" => WIN32::ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES,
            "ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES" => WIN32::ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES,
            "ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE" => WIN32::ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE,
            "ERROR_CLUSTER_AFFINITY_CONFLICT" => WIN32::ERROR_CLUSTER_AFFINITY_CONFLICT,
            "ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE" => WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE,
            "ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS" => WIN32::ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS,
            "ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED" => WIN32::ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED,
            "ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED" => WIN32::ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED,
            "ERROR_CLUSTER_UPGRADE_IN_PROGRESS" => WIN32::ERROR_CLUSTER_UPGRADE_IN_PROGRESS,
            "ERROR_CLUSTER_UPGRADE_INCOMPLETE" => WIN32::ERROR_CLUSTER_UPGRADE_INCOMPLETE,
            "ERROR_CLUSTER_NODE_IN_GRACE_PERIOD" => WIN32::ERROR_CLUSTER_NODE_IN_GRACE_PERIOD,
            "ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT" => WIN32::ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT,
            "ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER" => WIN32::ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER,
            "ERROR_CLUSTER_RESOURCE_NOT_MONITORED" => WIN32::ERROR_CLUSTER_RESOURCE_NOT_MONITORED,
            "ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED" => WIN32::ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED,
            "ERROR_CLUSTER_RESOURCE_IS_REPLICATED" => WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICATED,
            "ERROR_CLUSTER_NODE_ISOLATED" => WIN32::ERROR_CLUSTER_NODE_ISOLATED,
            "ERROR_CLUSTER_NODE_QUARANTINED" => WIN32::ERROR_CLUSTER_NODE_QUARANTINED,
            "ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED" => WIN32::ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED,
            "ERROR_CLUSTER_SPACE_DEGRADED" => WIN32::ERROR_CLUSTER_SPACE_DEGRADED,
            "ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED" => WIN32::ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED,
            "ERROR_CLUSTER_CSV_INVALID_HANDLE" => WIN32::ERROR_CLUSTER_CSV_INVALID_HANDLE,
            "ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR" => WIN32::ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR,
            "ERROR_GROUPSET_NOT_AVAILABLE" => WIN32::ERROR_GROUPSET_NOT_AVAILABLE,
            "ERROR_GROUPSET_NOT_FOUND" => WIN32::ERROR_GROUPSET_NOT_FOUND,
            "ERROR_GROUPSET_CANT_PROVIDE" => WIN32::ERROR_GROUPSET_CANT_PROVIDE,
            "ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND" => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND,
            "ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY" => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY,
            "ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION" => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION,
            "ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS" => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS,
            "ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME" => WIN32::ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME,
            "ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE" => WIN32::ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE,
            "ERROR_ENCRYPTION_FAILED" => WIN32::ERROR_ENCRYPTION_FAILED,
            "ERROR_DECRYPTION_FAILED" => WIN32::ERROR_DECRYPTION_FAILED,
            "ERROR_FILE_ENCRYPTED" => WIN32::ERROR_FILE_ENCRYPTED,
            "ERROR_NO_RECOVERY_POLICY" => WIN32::ERROR_NO_RECOVERY_POLICY,
            "ERROR_NO_EFS" => WIN32::ERROR_NO_EFS,
            "ERROR_WRONG_EFS" => WIN32::ERROR_WRONG_EFS,
            "ERROR_NO_USER_KEYS" => WIN32::ERROR_NO_USER_KEYS,
            "ERROR_FILE_NOT_ENCRYPTED" => WIN32::ERROR_FILE_NOT_ENCRYPTED,
            "ERROR_NOT_EXPORT_FORMAT" => WIN32::ERROR_NOT_EXPORT_FORMAT,
            "ERROR_FILE_READ_ONLY" => WIN32::ERROR_FILE_READ_ONLY,
            "ERROR_DIR_EFS_DISALLOWED" => WIN32::ERROR_DIR_EFS_DISALLOWED,
            "ERROR_EFS_SERVER_NOT_TRUSTED" => WIN32::ERROR_EFS_SERVER_NOT_TRUSTED,
            "ERROR_BAD_RECOVERY_POLICY" => WIN32::ERROR_BAD_RECOVERY_POLICY,
            "ERROR_EFS_ALG_BLOB_TOO_BIG" => WIN32::ERROR_EFS_ALG_BLOB_TOO_BIG,
            "ERROR_VOLUME_NOT_SUPPORT_EFS" => WIN32::ERROR_VOLUME_NOT_SUPPORT_EFS,
            "ERROR_EFS_DISABLED" => WIN32::ERROR_EFS_DISABLED,
            "ERROR_EFS_VERSION_NOT_SUPPORT" => WIN32::ERROR_EFS_VERSION_NOT_SUPPORT,
            "ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE" => WIN32::ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE,
            "ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER" => WIN32::ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER,
            "ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE" => WIN32::ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE,
            "ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE" => WIN32::ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE,
            "ERROR_CS_ENCRYPTION_FILE_NOT_CSE" => WIN32::ERROR_CS_ENCRYPTION_FILE_NOT_CSE,
            "ERROR_ENCRYPTION_POLICY_DENIES_OPERATION" => WIN32::ERROR_ENCRYPTION_POLICY_DENIES_OPERATION,
            "ERROR_WIP_ENCRYPTION_FAILED" => WIN32::ERROR_WIP_ENCRYPTION_FAILED,
            "ERROR_NO_BROWSER_SERVERS_FOUND" => WIN32::ERROR_NO_BROWSER_SERVERS_FOUND,
            "SCHED_E_SERVICE_NOT_LOCALSYSTEM" => WIN32::SCHED_E_SERVICE_NOT_LOCALSYSTEM,
            "ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM" => WIN32::ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM,
            "ERROR_LOG_SECTOR_INVALID" => WIN32::ERROR_LOG_SECTOR_INVALID,
            "ERROR_LOG_SECTOR_PARITY_INVALID" => WIN32::ERROR_LOG_SECTOR_PARITY_INVALID,
            "ERROR_LOG_SECTOR_REMAPPED" => WIN32::ERROR_LOG_SECTOR_REMAPPED,
            "ERROR_LOG_BLOCK_INCOMPLETE" => WIN32::ERROR_LOG_BLOCK_INCOMPLETE,
            "ERROR_LOG_INVALID_RANGE" => WIN32::ERROR_LOG_INVALID_RANGE,
            "ERROR_LOG_BLOCKS_EXHAUSTED" => WIN32::ERROR_LOG_BLOCKS_EXHAUSTED,
            "ERROR_LOG_READ_CONTEXT_INVALID" => WIN32::ERROR_LOG_READ_CONTEXT_INVALID,
            "ERROR_LOG_RESTART_INVALID" => WIN32::ERROR_LOG_RESTART_INVALID,
            "ERROR_LOG_BLOCK_VERSION" => WIN32::ERROR_LOG_BLOCK_VERSION,
            "ERROR_LOG_BLOCK_INVALID" => WIN32::ERROR_LOG_BLOCK_INVALID,
            "ERROR_LOG_READ_MODE_INVALID" => WIN32::ERROR_LOG_READ_MODE_INVALID,
            "ERROR_LOG_NO_RESTART" => WIN32::ERROR_LOG_NO_RESTART,
            "ERROR_LOG_METADATA_CORRUPT" => WIN32::ERROR_LOG_METADATA_CORRUPT,
            "ERROR_LOG_METADATA_INVALID" => WIN32::ERROR_LOG_METADATA_INVALID,
            "ERROR_LOG_METADATA_INCONSISTENT" => WIN32::ERROR_LOG_METADATA_INCONSISTENT,
            "ERROR_LOG_RESERVATION_INVALID" => WIN32::ERROR_LOG_RESERVATION_INVALID,
            "ERROR_LOG_CANT_DELETE" => WIN32::ERROR_LOG_CANT_DELETE,
            "ERROR_LOG_CONTAINER_LIMIT_EXCEEDED" => WIN32::ERROR_LOG_CONTAINER_LIMIT_EXCEEDED,
            "ERROR_LOG_START_OF_LOG" => WIN32::ERROR_LOG_START_OF_LOG,
            "ERROR_LOG_POLICY_ALREADY_INSTALLED" => WIN32::ERROR_LOG_POLICY_ALREADY_INSTALLED,
            "ERROR_LOG_POLICY_NOT_INSTALLED" => WIN32::ERROR_LOG_POLICY_NOT_INSTALLED,
            "ERROR_LOG_POLICY_INVALID" => WIN32::ERROR_LOG_POLICY_INVALID,
            "ERROR_LOG_POLICY_CONFLICT" => WIN32::ERROR_LOG_POLICY_CONFLICT,
            "ERROR_LOG_PINNED_ARCHIVE_TAIL" => WIN32::ERROR_LOG_PINNED_ARCHIVE_TAIL,
            "ERROR_LOG_RECORD_NONEXISTENT" => WIN32::ERROR_LOG_RECORD_NONEXISTENT,
            "ERROR_LOG_RECORDS_RESERVED_INVALID" => WIN32::ERROR_LOG_RECORDS_RESERVED_INVALID,
            "ERROR_LOG_SPACE_RESERVED_INVALID" => WIN32::ERROR_LOG_SPACE_RESERVED_INVALID,
            "ERROR_LOG_TAIL_INVALID" => WIN32::ERROR_LOG_TAIL_INVALID,
            "ERROR_LOG_FULL" => WIN32::ERROR_LOG_FULL,
            "ERROR_COULD_NOT_RESIZE_LOG" => WIN32::ERROR_COULD_NOT_RESIZE_LOG,
            "ERROR_LOG_MULTIPLEXED" => WIN32::ERROR_LOG_MULTIPLEXED,
            "ERROR_LOG_DEDICATED" => WIN32::ERROR_LOG_DEDICATED,
            "ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS" => WIN32::ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS,
            "ERROR_LOG_ARCHIVE_IN_PROGRESS" => WIN32::ERROR_LOG_ARCHIVE_IN_PROGRESS,
            "ERROR_LOG_EPHEMERAL" => WIN32::ERROR_LOG_EPHEMERAL,
            "ERROR_LOG_NOT_ENOUGH_CONTAINERS" => WIN32::ERROR_LOG_NOT_ENOUGH_CONTAINERS,
            "ERROR_LOG_CLIENT_ALREADY_REGISTERED" => WIN32::ERROR_LOG_CLIENT_ALREADY_REGISTERED,
            "ERROR_LOG_CLIENT_NOT_REGISTERED" => WIN32::ERROR_LOG_CLIENT_NOT_REGISTERED,
            "ERROR_LOG_FULL_HANDLER_IN_PROGRESS" => WIN32::ERROR_LOG_FULL_HANDLER_IN_PROGRESS,
            "ERROR_LOG_CONTAINER_READ_FAILED" => WIN32::ERROR_LOG_CONTAINER_READ_FAILED,
            "ERROR_LOG_CONTAINER_WRITE_FAILED" => WIN32::ERROR_LOG_CONTAINER_WRITE_FAILED,
            "ERROR_LOG_CONTAINER_OPEN_FAILED" => WIN32::ERROR_LOG_CONTAINER_OPEN_FAILED,
            "ERROR_LOG_CONTAINER_STATE_INVALID" => WIN32::ERROR_LOG_CONTAINER_STATE_INVALID,
            "ERROR_LOG_STATE_INVALID" => WIN32::ERROR_LOG_STATE_INVALID,
            "ERROR_LOG_PINNED" => WIN32::ERROR_LOG_PINNED,
            "ERROR_LOG_METADATA_FLUSH_FAILED" => WIN32::ERROR_LOG_METADATA_FLUSH_FAILED,
            "ERROR_LOG_INCONSISTENT_SECURITY" => WIN32::ERROR_LOG_INCONSISTENT_SECURITY,
            "ERROR_LOG_APPENDED_FLUSH_FAILED" => WIN32::ERROR_LOG_APPENDED_FLUSH_FAILED,
            "ERROR_LOG_PINNED_RESERVATION" => WIN32::ERROR_LOG_PINNED_RESERVATION,
            "ERROR_INVALID_TRANSACTION" => WIN32::ERROR_INVALID_TRANSACTION,
            "ERROR_TRANSACTION_NOT_ACTIVE" => WIN32::ERROR_TRANSACTION_NOT_ACTIVE,
            "ERROR_TRANSACTION_REQUEST_NOT_VALID" => WIN32::ERROR_TRANSACTION_REQUEST_NOT_VALID,
            "ERROR_TRANSACTION_NOT_REQUESTED" => WIN32::ERROR_TRANSACTION_NOT_REQUESTED,
            "ERROR_TRANSACTION_ALREADY_ABORTED" => WIN32::ERROR_TRANSACTION_ALREADY_ABORTED,
            "ERROR_TRANSACTION_ALREADY_COMMITTED" => WIN32::ERROR_TRANSACTION_ALREADY_COMMITTED,
            "ERROR_TM_INITIALIZATION_FAILED" => WIN32::ERROR_TM_INITIALIZATION_FAILED,
            "ERROR_RESOURCEMANAGER_READ_ONLY" => WIN32::ERROR_RESOURCEMANAGER_READ_ONLY,
            "ERROR_TRANSACTION_NOT_JOINED" => WIN32::ERROR_TRANSACTION_NOT_JOINED,
            "ERROR_TRANSACTION_SUPERIOR_EXISTS" => WIN32::ERROR_TRANSACTION_SUPERIOR_EXISTS,
            "ERROR_CRM_PROTOCOL_ALREADY_EXISTS" => WIN32::ERROR_CRM_PROTOCOL_ALREADY_EXISTS,
            "ERROR_TRANSACTION_PROPAGATION_FAILED" => WIN32::ERROR_TRANSACTION_PROPAGATION_FAILED,
            "ERROR_CRM_PROTOCOL_NOT_FOUND" => WIN32::ERROR_CRM_PROTOCOL_NOT_FOUND,
            "ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER" => WIN32::ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER,
            "ERROR_CURRENT_TRANSACTION_NOT_VALID" => WIN32::ERROR_CURRENT_TRANSACTION_NOT_VALID,
            "ERROR_TRANSACTION_NOT_FOUND" => WIN32::ERROR_TRANSACTION_NOT_FOUND,
            "ERROR_RESOURCEMANAGER_NOT_FOUND" => WIN32::ERROR_RESOURCEMANAGER_NOT_FOUND,
            "ERROR_ENLISTMENT_NOT_FOUND" => WIN32::ERROR_ENLISTMENT_NOT_FOUND,
            "ERROR_TRANSACTIONMANAGER_NOT_FOUND" => WIN32::ERROR_TRANSACTIONMANAGER_NOT_FOUND,
            "ERROR_TRANSACTIONMANAGER_NOT_ONLINE" => WIN32::ERROR_TRANSACTIONMANAGER_NOT_ONLINE,
            "ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION" => WIN32::ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION,
            "ERROR_TRANSACTION_NOT_ROOT" => WIN32::ERROR_TRANSACTION_NOT_ROOT,
            "ERROR_TRANSACTION_OBJECT_EXPIRED" => WIN32::ERROR_TRANSACTION_OBJECT_EXPIRED,
            "ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED" => WIN32::ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED,
            "ERROR_TRANSACTION_RECORD_TOO_LONG" => WIN32::ERROR_TRANSACTION_RECORD_TOO_LONG,
            "ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED" => WIN32::ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED,
            "ERROR_TRANSACTION_INTEGRITY_VIOLATED" => WIN32::ERROR_TRANSACTION_INTEGRITY_VIOLATED,
            "ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH" => WIN32::ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH,
            "ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT" => WIN32::ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT,
            "ERROR_TRANSACTION_MUST_WRITETHROUGH" => WIN32::ERROR_TRANSACTION_MUST_WRITETHROUGH,
            "ERROR_TRANSACTION_NO_SUPERIOR" => WIN32::ERROR_TRANSACTION_NO_SUPERIOR,
            "ERROR_HEURISTIC_DAMAGE_POSSIBLE" => WIN32::ERROR_HEURISTIC_DAMAGE_POSSIBLE,
            "ERROR_TRANSACTIONAL_CONFLICT" => WIN32::ERROR_TRANSACTIONAL_CONFLICT,
            "ERROR_RM_NOT_ACTIVE" => WIN32::ERROR_RM_NOT_ACTIVE,
            "ERROR_RM_METADATA_CORRUPT" => WIN32::ERROR_RM_METADATA_CORRUPT,
            "ERROR_DIRECTORY_NOT_RM" => WIN32::ERROR_DIRECTORY_NOT_RM,
            "ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE" => WIN32::ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE,
            "ERROR_LOG_RESIZE_INVALID_SIZE" => WIN32::ERROR_LOG_RESIZE_INVALID_SIZE,
            "ERROR_OBJECT_NO_LONGER_EXISTS" => WIN32::ERROR_OBJECT_NO_LONGER_EXISTS,
            "ERROR_STREAM_MINIVERSION_NOT_FOUND" => WIN32::ERROR_STREAM_MINIVERSION_NOT_FOUND,
            "ERROR_STREAM_MINIVERSION_NOT_VALID" => WIN32::ERROR_STREAM_MINIVERSION_NOT_VALID,
            "ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION" => WIN32::ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION,
            "ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT" => WIN32::ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT,
            "ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS" => WIN32::ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS,
            "ERROR_REMOTE_FILE_VERSION_MISMATCH" => WIN32::ERROR_REMOTE_FILE_VERSION_MISMATCH,
            "ERROR_HANDLE_NO_LONGER_VALID" => WIN32::ERROR_HANDLE_NO_LONGER_VALID,
            "ERROR_NO_TXF_METADATA" => WIN32::ERROR_NO_TXF_METADATA,
            "ERROR_LOG_CORRUPTION_DETECTED" => WIN32::ERROR_LOG_CORRUPTION_DETECTED,
            "ERROR_CANT_RECOVER_WITH_HANDLE_OPEN" => WIN32::ERROR_CANT_RECOVER_WITH_HANDLE_OPEN,
            "ERROR_RM_DISCONNECTED" => WIN32::ERROR_RM_DISCONNECTED,
            "ERROR_ENLISTMENT_NOT_SUPERIOR" => WIN32::ERROR_ENLISTMENT_NOT_SUPERIOR,
            "ERROR_RECOVERY_NOT_NEEDED" => WIN32::ERROR_RECOVERY_NOT_NEEDED,
            "ERROR_RM_ALREADY_STARTED" => WIN32::ERROR_RM_ALREADY_STARTED,
            "ERROR_FILE_IDENTITY_NOT_PERSISTENT" => WIN32::ERROR_FILE_IDENTITY_NOT_PERSISTENT,
            "ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY" => WIN32::ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY,
            "ERROR_CANT_CROSS_RM_BOUNDARY" => WIN32::ERROR_CANT_CROSS_RM_BOUNDARY,
            "ERROR_TXF_DIR_NOT_EMPTY" => WIN32::ERROR_TXF_DIR_NOT_EMPTY,
            "ERROR_INDOUBT_TRANSACTIONS_EXIST" => WIN32::ERROR_INDOUBT_TRANSACTIONS_EXIST,
            "ERROR_TM_VOLATILE" => WIN32::ERROR_TM_VOLATILE,
            "ERROR_ROLLBACK_TIMER_EXPIRED" => WIN32::ERROR_ROLLBACK_TIMER_EXPIRED,
            "ERROR_TXF_ATTRIBUTE_CORRUPT" => WIN32::ERROR_TXF_ATTRIBUTE_CORRUPT,
            "ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION" => WIN32::ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION,
            "ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED" => WIN32::ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED,
            "ERROR_LOG_GROWTH_FAILED" => WIN32::ERROR_LOG_GROWTH_FAILED,
            "ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE" => WIN32::ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE,
            "ERROR_TXF_METADATA_ALREADY_PRESENT" => WIN32::ERROR_TXF_METADATA_ALREADY_PRESENT,
            "ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET" => WIN32::ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET,
            "ERROR_TRANSACTION_REQUIRED_PROMOTION" => WIN32::ERROR_TRANSACTION_REQUIRED_PROMOTION,
            "ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION" => WIN32::ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION,
            "ERROR_TRANSACTIONS_NOT_FROZEN" => WIN32::ERROR_TRANSACTIONS_NOT_FROZEN,
            "ERROR_TRANSACTION_FREEZE_IN_PROGRESS" => WIN32::ERROR_TRANSACTION_FREEZE_IN_PROGRESS,
            "ERROR_NOT_SNAPSHOT_VOLUME" => WIN32::ERROR_NOT_SNAPSHOT_VOLUME,
            "ERROR_NO_SAVEPOINT_WITH_OPEN_FILES" => WIN32::ERROR_NO_SAVEPOINT_WITH_OPEN_FILES,
            "ERROR_DATA_LOST_REPAIR" => WIN32::ERROR_DATA_LOST_REPAIR,
            "ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION" => WIN32::ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION,
            "ERROR_TM_IDENTITY_MISMATCH" => WIN32::ERROR_TM_IDENTITY_MISMATCH,
            "ERROR_FLOATED_SECTION" => WIN32::ERROR_FLOATED_SECTION,
            "ERROR_CANNOT_ACCEPT_TRANSACTED_WORK" => WIN32::ERROR_CANNOT_ACCEPT_TRANSACTED_WORK,
            "ERROR_CANNOT_ABORT_TRANSACTIONS" => WIN32::ERROR_CANNOT_ABORT_TRANSACTIONS,
            "ERROR_BAD_CLUSTERS" => WIN32::ERROR_BAD_CLUSTERS,
            "ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION" => WIN32::ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION,
            "ERROR_VOLUME_DIRTY" => WIN32::ERROR_VOLUME_DIRTY,
            "ERROR_NO_LINK_TRACKING_IN_TRANSACTION" => WIN32::ERROR_NO_LINK_TRACKING_IN_TRANSACTION,
            "ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION" => WIN32::ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION,
            "ERROR_EXPIRED_HANDLE" => WIN32::ERROR_EXPIRED_HANDLE,
            "ERROR_TRANSACTION_NOT_ENLISTED" => WIN32::ERROR_TRANSACTION_NOT_ENLISTED,
            "ERROR_CTX_WINSTATION_NAME_INVALID" => WIN32::ERROR_CTX_WINSTATION_NAME_INVALID,
            "ERROR_CTX_INVALID_PD" => WIN32::ERROR_CTX_INVALID_PD,
            "ERROR_CTX_PD_NOT_FOUND" => WIN32::ERROR_CTX_PD_NOT_FOUND,
            "ERROR_CTX_WD_NOT_FOUND" => WIN32::ERROR_CTX_WD_NOT_FOUND,
            "ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY" => WIN32::ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY,
            "ERROR_CTX_SERVICE_NAME_COLLISION" => WIN32::ERROR_CTX_SERVICE_NAME_COLLISION,
            "ERROR_CTX_CLOSE_PENDING" => WIN32::ERROR_CTX_CLOSE_PENDING,
            "ERROR_CTX_NO_OUTBUF" => WIN32::ERROR_CTX_NO_OUTBUF,
            "ERROR_CTX_MODEM_INF_NOT_FOUND" => WIN32::ERROR_CTX_MODEM_INF_NOT_FOUND,
            "ERROR_CTX_INVALID_MODEMNAME" => WIN32::ERROR_CTX_INVALID_MODEMNAME,
            "ERROR_CTX_MODEM_RESPONSE_ERROR" => WIN32::ERROR_CTX_MODEM_RESPONSE_ERROR,
            "ERROR_CTX_MODEM_RESPONSE_TIMEOUT" => WIN32::ERROR_CTX_MODEM_RESPONSE_TIMEOUT,
            "ERROR_CTX_MODEM_RESPONSE_NO_CARRIER" => WIN32::ERROR_CTX_MODEM_RESPONSE_NO_CARRIER,
            "ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE" => WIN32::ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE,
            "ERROR_CTX_MODEM_RESPONSE_BUSY" => WIN32::ERROR_CTX_MODEM_RESPONSE_BUSY,
            "ERROR_CTX_MODEM_RESPONSE_VOICE" => WIN32::ERROR_CTX_MODEM_RESPONSE_VOICE,
            "ERROR_CTX_TD_ERROR" => WIN32::ERROR_CTX_TD_ERROR,
            "ERROR_CTX_WINSTATION_NOT_FOUND" => WIN32::ERROR_CTX_WINSTATION_NOT_FOUND,
            "ERROR_CTX_WINSTATION_ALREADY_EXISTS" => WIN32::ERROR_CTX_WINSTATION_ALREADY_EXISTS,
            "ERROR_CTX_WINSTATION_BUSY" => WIN32::ERROR_CTX_WINSTATION_BUSY,
            "ERROR_CTX_BAD_VIDEO_MODE" => WIN32::ERROR_CTX_BAD_VIDEO_MODE,
            "ERROR_CTX_GRAPHICS_INVALID" => WIN32::ERROR_CTX_GRAPHICS_INVALID,
            "ERROR_CTX_LOGON_DISABLED" => WIN32::ERROR_CTX_LOGON_DISABLED,
            "ERROR_CTX_NOT_CONSOLE" => WIN32::ERROR_CTX_NOT_CONSOLE,
            "ERROR_CTX_CLIENT_QUERY_TIMEOUT" => WIN32::ERROR_CTX_CLIENT_QUERY_TIMEOUT,
            "ERROR_CTX_CONSOLE_DISCONNECT" => WIN32::ERROR_CTX_CONSOLE_DISCONNECT,
            "ERROR_CTX_CONSOLE_CONNECT" => WIN32::ERROR_CTX_CONSOLE_CONNECT,
            "ERROR_CTX_SHADOW_DENIED" => WIN32::ERROR_CTX_SHADOW_DENIED,
            "ERROR_CTX_WINSTATION_ACCESS_DENIED" => WIN32::ERROR_CTX_WINSTATION_ACCESS_DENIED,
            "ERROR_CTX_INVALID_WD" => WIN32::ERROR_CTX_INVALID_WD,
            "ERROR_CTX_SHADOW_INVALID" => WIN32::ERROR_CTX_SHADOW_INVALID,
            "ERROR_CTX_SHADOW_DISABLED" => WIN32::ERROR_CTX_SHADOW_DISABLED,
            "ERROR_CTX_CLIENT_LICENSE_IN_USE" => WIN32::ERROR_CTX_CLIENT_LICENSE_IN_USE,
            "ERROR_CTX_CLIENT_LICENSE_NOT_SET" => WIN32::ERROR_CTX_CLIENT_LICENSE_NOT_SET,
            "ERROR_CTX_LICENSE_NOT_AVAILABLE" => WIN32::ERROR_CTX_LICENSE_NOT_AVAILABLE,
            "ERROR_CTX_LICENSE_CLIENT_INVALID" => WIN32::ERROR_CTX_LICENSE_CLIENT_INVALID,
            "ERROR_CTX_LICENSE_EXPIRED" => WIN32::ERROR_CTX_LICENSE_EXPIRED,
            "ERROR_CTX_SHADOW_NOT_RUNNING" => WIN32::ERROR_CTX_SHADOW_NOT_RUNNING,
            "ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE" => WIN32::ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE,
            "ERROR_ACTIVATION_COUNT_EXCEEDED" => WIN32::ERROR_ACTIVATION_COUNT_EXCEEDED,
            "ERROR_CTX_WINSTATIONS_DISABLED" => WIN32::ERROR_CTX_WINSTATIONS_DISABLED,
            "ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED" => WIN32::ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED,
            "ERROR_CTX_SESSION_IN_USE" => WIN32::ERROR_CTX_SESSION_IN_USE,
            "ERROR_CTX_NO_FORCE_LOGOFF" => WIN32::ERROR_CTX_NO_FORCE_LOGOFF,
            "ERROR_CTX_ACCOUNT_RESTRICTION" => WIN32::ERROR_CTX_ACCOUNT_RESTRICTION,
            "ERROR_RDP_PROTOCOL_ERROR" => WIN32::ERROR_RDP_PROTOCOL_ERROR,
            "ERROR_CTX_CDM_CONNECT" => WIN32::ERROR_CTX_CDM_CONNECT,
            "ERROR_CTX_CDM_DISCONNECT" => WIN32::ERROR_CTX_CDM_DISCONNECT,
            "ERROR_CTX_SECURITY_LAYER_ERROR" => WIN32::ERROR_CTX_SECURITY_LAYER_ERROR,
            "ERROR_TS_INCOMPATIBLE_SESSIONS" => WIN32::ERROR_TS_INCOMPATIBLE_SESSIONS,
            "ERROR_TS_VIDEO_SUBSYSTEM_ERROR" => WIN32::ERROR_TS_VIDEO_SUBSYSTEM_ERROR,
            "FRS_ERR_INVALID_API_SEQUENCE" => WIN32::FRS_ERR_INVALID_API_SEQUENCE,
            "FRS_ERR_STARTING_SERVICE" => WIN32::FRS_ERR_STARTING_SERVICE,
            "FRS_ERR_STOPPING_SERVICE" => WIN32::FRS_ERR_STOPPING_SERVICE,
            "FRS_ERR_INTERNAL_API" => WIN32::FRS_ERR_INTERNAL_API,
            "FRS_ERR_INTERNAL" => WIN32::FRS_ERR_INTERNAL,
            "FRS_ERR_SERVICE_COMM" => WIN32::FRS_ERR_SERVICE_COMM,
            "FRS_ERR_INSUFFICIENT_PRIV" => WIN32::FRS_ERR_INSUFFICIENT_PRIV,
            "FRS_ERR_AUTHENTICATION" => WIN32::FRS_ERR_AUTHENTICATION,
            "FRS_ERR_PARENT_INSUFFICIENT_PRIV" => WIN32::FRS_ERR_PARENT_INSUFFICIENT_PRIV,
            "FRS_ERR_PARENT_AUTHENTICATION" => WIN32::FRS_ERR_PARENT_AUTHENTICATION,
            "FRS_ERR_CHILD_TO_PARENT_COMM" => WIN32::FRS_ERR_CHILD_TO_PARENT_COMM,
            "FRS_ERR_PARENT_TO_CHILD_COMM" => WIN32::FRS_ERR_PARENT_TO_CHILD_COMM,
            "FRS_ERR_SYSVOL_POPULATE" => WIN32::FRS_ERR_SYSVOL_POPULATE,
            "FRS_ERR_SYSVOL_POPULATE_TIMEOUT" => WIN32::FRS_ERR_SYSVOL_POPULATE_TIMEOUT,
            "FRS_ERR_SYSVOL_IS_BUSY" => WIN32::FRS_ERR_SYSVOL_IS_BUSY,
            "FRS_ERR_SYSVOL_DEMOTE" => WIN32::FRS_ERR_SYSVOL_DEMOTE,
            "FRS_ERR_INVALID_SERVICE_PARAMETER" => WIN32::FRS_ERR_INVALID_SERVICE_PARAMETER,
            "ERROR_DS_NOT_INSTALLED" => WIN32::ERROR_DS_NOT_INSTALLED,
            "ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY" => WIN32::ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY,
            "ERROR_DS_NO_ATTRIBUTE_OR_VALUE" => WIN32::ERROR_DS_NO_ATTRIBUTE_OR_VALUE,
            "ERROR_DS_INVALID_ATTRIBUTE_SYNTAX" => WIN32::ERROR_DS_INVALID_ATTRIBUTE_SYNTAX,
            "ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED" => WIN32::ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED,
            "ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS" => WIN32::ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS,
            "ERROR_DS_BUSY" => WIN32::ERROR_DS_BUSY,
            "ERROR_DS_UNAVAILABLE" => WIN32::ERROR_DS_UNAVAILABLE,
            "ERROR_DS_NO_RIDS_ALLOCATED" => WIN32::ERROR_DS_NO_RIDS_ALLOCATED,
            "ERROR_DS_NO_MORE_RIDS" => WIN32::ERROR_DS_NO_MORE_RIDS,
            "ERROR_DS_INCORRECT_ROLE_OWNER" => WIN32::ERROR_DS_INCORRECT_ROLE_OWNER,
            "ERROR_DS_RIDMGR_INIT_ERROR" => WIN32::ERROR_DS_RIDMGR_INIT_ERROR,
            "ERROR_DS_OBJ_CLASS_VIOLATION" => WIN32::ERROR_DS_OBJ_CLASS_VIOLATION,
            "ERROR_DS_CANT_ON_NON_LEAF" => WIN32::ERROR_DS_CANT_ON_NON_LEAF,
            "ERROR_DS_CANT_ON_RDN" => WIN32::ERROR_DS_CANT_ON_RDN,
            "ERROR_DS_CANT_MOD_OBJ_CLASS" => WIN32::ERROR_DS_CANT_MOD_OBJ_CLASS,
            "ERROR_DS_CROSS_DOM_MOVE_ERROR" => WIN32::ERROR_DS_CROSS_DOM_MOVE_ERROR,
            "ERROR_DS_GC_NOT_AVAILABLE" => WIN32::ERROR_DS_GC_NOT_AVAILABLE,
            "ERROR_SHARED_POLICY" => WIN32::ERROR_SHARED_POLICY,
            "ERROR_POLICY_OBJECT_NOT_FOUND" => WIN32::ERROR_POLICY_OBJECT_NOT_FOUND,
            "ERROR_POLICY_ONLY_IN_DS" => WIN32::ERROR_POLICY_ONLY_IN_DS,
            "ERROR_PROMOTION_ACTIVE" => WIN32::ERROR_PROMOTION_ACTIVE,
            "ERROR_NO_PROMOTION_ACTIVE" => WIN32::ERROR_NO_PROMOTION_ACTIVE,
            "ERROR_DS_OPERATIONS_ERROR" => WIN32::ERROR_DS_OPERATIONS_ERROR,
            "ERROR_DS_PROTOCOL_ERROR" => WIN32::ERROR_DS_PROTOCOL_ERROR,
            "ERROR_DS_TIMELIMIT_EXCEEDED" => WIN32::ERROR_DS_TIMELIMIT_EXCEEDED,
            "ERROR_DS_SIZELIMIT_EXCEEDED" => WIN32::ERROR_DS_SIZELIMIT_EXCEEDED,
            "ERROR_DS_ADMIN_LIMIT_EXCEEDED" => WIN32::ERROR_DS_ADMIN_LIMIT_EXCEEDED,
            "ERROR_DS_COMPARE_FALSE" => WIN32::ERROR_DS_COMPARE_FALSE,
            "ERROR_DS_COMPARE_TRUE" => WIN32::ERROR_DS_COMPARE_TRUE,
            "ERROR_DS_AUTH_METHOD_NOT_SUPPORTED" => WIN32::ERROR_DS_AUTH_METHOD_NOT_SUPPORTED,
            "ERROR_DS_STRONG_AUTH_REQUIRED" => WIN32::ERROR_DS_STRONG_AUTH_REQUIRED,
            "ERROR_DS_INAPPROPRIATE_AUTH" => WIN32::ERROR_DS_INAPPROPRIATE_AUTH,
            "ERROR_DS_AUTH_UNKNOWN" => WIN32::ERROR_DS_AUTH_UNKNOWN,
            "ERROR_DS_REFERRAL" => WIN32::ERROR_DS_REFERRAL,
            "ERROR_DS_UNAVAILABLE_CRIT_EXTENSION" => WIN32::ERROR_DS_UNAVAILABLE_CRIT_EXTENSION,
            "ERROR_DS_CONFIDENTIALITY_REQUIRED" => WIN32::ERROR_DS_CONFIDENTIALITY_REQUIRED,
            "ERROR_DS_INAPPROPRIATE_MATCHING" => WIN32::ERROR_DS_INAPPROPRIATE_MATCHING,
            "ERROR_DS_CONSTRAINT_VIOLATION" => WIN32::ERROR_DS_CONSTRAINT_VIOLATION,
            "ERROR_DS_NO_SUCH_OBJECT" => WIN32::ERROR_DS_NO_SUCH_OBJECT,
            "ERROR_DS_ALIAS_PROBLEM" => WIN32::ERROR_DS_ALIAS_PROBLEM,
            "ERROR_DS_INVALID_DN_SYNTAX" => WIN32::ERROR_DS_INVALID_DN_SYNTAX,
            "ERROR_DS_IS_LEAF" => WIN32::ERROR_DS_IS_LEAF,
            "ERROR_DS_ALIAS_DEREF_PROBLEM" => WIN32::ERROR_DS_ALIAS_DEREF_PROBLEM,
            "ERROR_DS_UNWILLING_TO_PERFORM" => WIN32::ERROR_DS_UNWILLING_TO_PERFORM,
            "ERROR_DS_LOOP_DETECT" => WIN32::ERROR_DS_LOOP_DETECT,
            "ERROR_DS_NAMING_VIOLATION" => WIN32::ERROR_DS_NAMING_VIOLATION,
            "ERROR_DS_OBJECT_RESULTS_TOO_LARGE" => WIN32::ERROR_DS_OBJECT_RESULTS_TOO_LARGE,
            "ERROR_DS_AFFECTS_MULTIPLE_DSAS" => WIN32::ERROR_DS_AFFECTS_MULTIPLE_DSAS,
            "ERROR_DS_SERVER_DOWN" => WIN32::ERROR_DS_SERVER_DOWN,
            "ERROR_DS_LOCAL_ERROR" => WIN32::ERROR_DS_LOCAL_ERROR,
            "ERROR_DS_ENCODING_ERROR" => WIN32::ERROR_DS_ENCODING_ERROR,
            "ERROR_DS_DECODING_ERROR" => WIN32::ERROR_DS_DECODING_ERROR,
            "ERROR_DS_FILTER_UNKNOWN" => WIN32::ERROR_DS_FILTER_UNKNOWN,
            "ERROR_DS_PARAM_ERROR" => WIN32::ERROR_DS_PARAM_ERROR,
            "ERROR_DS_NOT_SUPPORTED" => WIN32::ERROR_DS_NOT_SUPPORTED,
            "ERROR_DS_NO_RESULTS_RETURNED" => WIN32::ERROR_DS_NO_RESULTS_RETURNED,
            "ERROR_DS_CONTROL_NOT_FOUND" => WIN32::ERROR_DS_CONTROL_NOT_FOUND,
            "ERROR_DS_CLIENT_LOOP" => WIN32::ERROR_DS_CLIENT_LOOP,
            "ERROR_DS_REFERRAL_LIMIT_EXCEEDED" => WIN32::ERROR_DS_REFERRAL_LIMIT_EXCEEDED,
            "ERROR_DS_SORT_CONTROL_MISSING" => WIN32::ERROR_DS_SORT_CONTROL_MISSING,
            "ERROR_DS_OFFSET_RANGE_ERROR" => WIN32::ERROR_DS_OFFSET_RANGE_ERROR,
            "ERROR_DS_RIDMGR_DISABLED" => WIN32::ERROR_DS_RIDMGR_DISABLED,
            "ERROR_DS_ROOT_MUST_BE_NC" => WIN32::ERROR_DS_ROOT_MUST_BE_NC,
            "ERROR_DS_ADD_REPLICA_INHIBITED" => WIN32::ERROR_DS_ADD_REPLICA_INHIBITED,
            "ERROR_DS_ATT_NOT_DEF_IN_SCHEMA" => WIN32::ERROR_DS_ATT_NOT_DEF_IN_SCHEMA,
            "ERROR_DS_MAX_OBJ_SIZE_EXCEEDED" => WIN32::ERROR_DS_MAX_OBJ_SIZE_EXCEEDED,
            "ERROR_DS_OBJ_STRING_NAME_EXISTS" => WIN32::ERROR_DS_OBJ_STRING_NAME_EXISTS,
            "ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA" => WIN32::ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA,
            "ERROR_DS_RDN_DOESNT_MATCH_SCHEMA" => WIN32::ERROR_DS_RDN_DOESNT_MATCH_SCHEMA,
            "ERROR_DS_NO_REQUESTED_ATTS_FOUND" => WIN32::ERROR_DS_NO_REQUESTED_ATTS_FOUND,
            "ERROR_DS_USER_BUFFER_TO_SMALL" => WIN32::ERROR_DS_USER_BUFFER_TO_SMALL,
            "ERROR_DS_ATT_IS_NOT_ON_OBJ" => WIN32::ERROR_DS_ATT_IS_NOT_ON_OBJ,
            "ERROR_DS_ILLEGAL_MOD_OPERATION" => WIN32::ERROR_DS_ILLEGAL_MOD_OPERATION,
            "ERROR_DS_OBJ_TOO_LARGE" => WIN32::ERROR_DS_OBJ_TOO_LARGE,
            "ERROR_DS_BAD_INSTANCE_TYPE" => WIN32::ERROR_DS_BAD_INSTANCE_TYPE,
            "ERROR_DS_MASTERDSA_REQUIRED" => WIN32::ERROR_DS_MASTERDSA_REQUIRED,
            "ERROR_DS_OBJECT_CLASS_REQUIRED" => WIN32::ERROR_DS_OBJECT_CLASS_REQUIRED,
            "ERROR_DS_MISSING_REQUIRED_ATT" => WIN32::ERROR_DS_MISSING_REQUIRED_ATT,
            "ERROR_DS_ATT_NOT_DEF_FOR_CLASS" => WIN32::ERROR_DS_ATT_NOT_DEF_FOR_CLASS,
            "ERROR_DS_ATT_ALREADY_EXISTS" => WIN32::ERROR_DS_ATT_ALREADY_EXISTS,
            "ERROR_DS_CANT_ADD_ATT_VALUES" => WIN32::ERROR_DS_CANT_ADD_ATT_VALUES,
            "ERROR_DS_SINGLE_VALUE_CONSTRAINT" => WIN32::ERROR_DS_SINGLE_VALUE_CONSTRAINT,
            "ERROR_DS_RANGE_CONSTRAINT" => WIN32::ERROR_DS_RANGE_CONSTRAINT,
            "ERROR_DS_ATT_VAL_ALREADY_EXISTS" => WIN32::ERROR_DS_ATT_VAL_ALREADY_EXISTS,
            "ERROR_DS_CANT_REM_MISSING_ATT" => WIN32::ERROR_DS_CANT_REM_MISSING_ATT,
            "ERROR_DS_CANT_REM_MISSING_ATT_VAL" => WIN32::ERROR_DS_CANT_REM_MISSING_ATT_VAL,
            "ERROR_DS_ROOT_CANT_BE_SUBREF" => WIN32::ERROR_DS_ROOT_CANT_BE_SUBREF,
            "ERROR_DS_NO_CHAINING" => WIN32::ERROR_DS_NO_CHAINING,
            "ERROR_DS_NO_CHAINED_EVAL" => WIN32::ERROR_DS_NO_CHAINED_EVAL,
            "ERROR_DS_NO_PARENT_OBJECT" => WIN32::ERROR_DS_NO_PARENT_OBJECT,
            "ERROR_DS_PARENT_IS_AN_ALIAS" => WIN32::ERROR_DS_PARENT_IS_AN_ALIAS,
            "ERROR_DS_CANT_MIX_MASTER_AND_REPS" => WIN32::ERROR_DS_CANT_MIX_MASTER_AND_REPS,
            "ERROR_DS_CHILDREN_EXIST" => WIN32::ERROR_DS_CHILDREN_EXIST,
            "ERROR_DS_OBJ_NOT_FOUND" => WIN32::ERROR_DS_OBJ_NOT_FOUND,
            "ERROR_DS_ALIASED_OBJ_MISSING" => WIN32::ERROR_DS_ALIASED_OBJ_MISSING,
            "ERROR_DS_BAD_NAME_SYNTAX" => WIN32::ERROR_DS_BAD_NAME_SYNTAX,
            "ERROR_DS_ALIAS_POINTS_TO_ALIAS" => WIN32::ERROR_DS_ALIAS_POINTS_TO_ALIAS,
            "ERROR_DS_CANT_DEREF_ALIAS" => WIN32::ERROR_DS_CANT_DEREF_ALIAS,
            "ERROR_DS_OUT_OF_SCOPE" => WIN32::ERROR_DS_OUT_OF_SCOPE,
            "ERROR_DS_OBJECT_BEING_REMOVED" => WIN32::ERROR_DS_OBJECT_BEING_REMOVED,
            "ERROR_DS_CANT_DELETE_DSA_OBJ" => WIN32::ERROR_DS_CANT_DELETE_DSA_OBJ,
            "ERROR_DS_GENERIC_ERROR" => WIN32::ERROR_DS_GENERIC_ERROR,
            "ERROR_DS_DSA_MUST_BE_INT_MASTER" => WIN32::ERROR_DS_DSA_MUST_BE_INT_MASTER,
            "ERROR_DS_CLASS_NOT_DSA" => WIN32::ERROR_DS_CLASS_NOT_DSA,
            "ERROR_DS_INSUFF_ACCESS_RIGHTS" => WIN32::ERROR_DS_INSUFF_ACCESS_RIGHTS,
            "ERROR_DS_ILLEGAL_SUPERIOR" => WIN32::ERROR_DS_ILLEGAL_SUPERIOR,
            "ERROR_DS_ATTRIBUTE_OWNED_BY_SAM" => WIN32::ERROR_DS_ATTRIBUTE_OWNED_BY_SAM,
            "ERROR_DS_NAME_TOO_MANY_PARTS" => WIN32::ERROR_DS_NAME_TOO_MANY_PARTS,
            "ERROR_DS_NAME_TOO_LONG" => WIN32::ERROR_DS_NAME_TOO_LONG,
            "ERROR_DS_NAME_VALUE_TOO_LONG" => WIN32::ERROR_DS_NAME_VALUE_TOO_LONG,
            "ERROR_DS_NAME_UNPARSEABLE" => WIN32::ERROR_DS_NAME_UNPARSEABLE,
            "ERROR_DS_NAME_TYPE_UNKNOWN" => WIN32::ERROR_DS_NAME_TYPE_UNKNOWN,
            "ERROR_DS_NOT_AN_OBJECT" => WIN32::ERROR_DS_NOT_AN_OBJECT,
            "ERROR_DS_SEC_DESC_TOO_SHORT" => WIN32::ERROR_DS_SEC_DESC_TOO_SHORT,
            "ERROR_DS_SEC_DESC_INVALID" => WIN32::ERROR_DS_SEC_DESC_INVALID,
            "ERROR_DS_NO_DELETED_NAME" => WIN32::ERROR_DS_NO_DELETED_NAME,
            "ERROR_DS_SUBREF_MUST_HAVE_PARENT" => WIN32::ERROR_DS_SUBREF_MUST_HAVE_PARENT,
            "ERROR_DS_NCNAME_MUST_BE_NC" => WIN32::ERROR_DS_NCNAME_MUST_BE_NC,
            "ERROR_DS_CANT_ADD_SYSTEM_ONLY" => WIN32::ERROR_DS_CANT_ADD_SYSTEM_ONLY,
            "ERROR_DS_CLASS_MUST_BE_CONCRETE" => WIN32::ERROR_DS_CLASS_MUST_BE_CONCRETE,
            "ERROR_DS_INVALID_DMD" => WIN32::ERROR_DS_INVALID_DMD,
            "ERROR_DS_OBJ_GUID_EXISTS" => WIN32::ERROR_DS_OBJ_GUID_EXISTS,
            "ERROR_DS_NOT_ON_BACKLINK" => WIN32::ERROR_DS_NOT_ON_BACKLINK,
            "ERROR_DS_NO_CROSSREF_FOR_NC" => WIN32::ERROR_DS_NO_CROSSREF_FOR_NC,
            "ERROR_DS_SHUTTING_DOWN" => WIN32::ERROR_DS_SHUTTING_DOWN,
            "ERROR_DS_UNKNOWN_OPERATION" => WIN32::ERROR_DS_UNKNOWN_OPERATION,
            "ERROR_DS_INVALID_ROLE_OWNER" => WIN32::ERROR_DS_INVALID_ROLE_OWNER,
            "ERROR_DS_COULDNT_CONTACT_FSMO" => WIN32::ERROR_DS_COULDNT_CONTACT_FSMO,
            "ERROR_DS_CROSS_NC_DN_RENAME" => WIN32::ERROR_DS_CROSS_NC_DN_RENAME,
            "ERROR_DS_CANT_MOD_SYSTEM_ONLY" => WIN32::ERROR_DS_CANT_MOD_SYSTEM_ONLY,
            "ERROR_DS_REPLICATOR_ONLY" => WIN32::ERROR_DS_REPLICATOR_ONLY,
            "ERROR_DS_OBJ_CLASS_NOT_DEFINED" => WIN32::ERROR_DS_OBJ_CLASS_NOT_DEFINED,
            "ERROR_DS_OBJ_CLASS_NOT_SUBCLASS" => WIN32::ERROR_DS_OBJ_CLASS_NOT_SUBCLASS,
            "ERROR_DS_NAME_REFERENCE_INVALID" => WIN32::ERROR_DS_NAME_REFERENCE_INVALID,
            "ERROR_DS_CROSS_REF_EXISTS" => WIN32::ERROR_DS_CROSS_REF_EXISTS,
            "ERROR_DS_CANT_DEL_MASTER_CROSSREF" => WIN32::ERROR_DS_CANT_DEL_MASTER_CROSSREF,
            "ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD" => WIN32::ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD,
            "ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX" => WIN32::ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX,
            "ERROR_DS_DUP_RDN" => WIN32::ERROR_DS_DUP_RDN,
            "ERROR_DS_DUP_OID" => WIN32::ERROR_DS_DUP_OID,
            "ERROR_DS_DUP_MAPI_ID" => WIN32::ERROR_DS_DUP_MAPI_ID,
            "ERROR_DS_DUP_SCHEMA_ID_GUID" => WIN32::ERROR_DS_DUP_SCHEMA_ID_GUID,
            "ERROR_DS_DUP_LDAP_DISPLAY_NAME" => WIN32::ERROR_DS_DUP_LDAP_DISPLAY_NAME,
            "ERROR_DS_SEMANTIC_ATT_TEST" => WIN32::ERROR_DS_SEMANTIC_ATT_TEST,
            "ERROR_DS_SYNTAX_MISMATCH" => WIN32::ERROR_DS_SYNTAX_MISMATCH,
            "ERROR_DS_EXISTS_IN_MUST_HAVE" => WIN32::ERROR_DS_EXISTS_IN_MUST_HAVE,
            "ERROR_DS_EXISTS_IN_MAY_HAVE" => WIN32::ERROR_DS_EXISTS_IN_MAY_HAVE,
            "ERROR_DS_NONEXISTENT_MAY_HAVE" => WIN32::ERROR_DS_NONEXISTENT_MAY_HAVE,
            "ERROR_DS_NONEXISTENT_MUST_HAVE" => WIN32::ERROR_DS_NONEXISTENT_MUST_HAVE,
            "ERROR_DS_AUX_CLS_TEST_FAIL" => WIN32::ERROR_DS_AUX_CLS_TEST_FAIL,
            "ERROR_DS_NONEXISTENT_POSS_SUP" => WIN32::ERROR_DS_NONEXISTENT_POSS_SUP,
            "ERROR_DS_SUB_CLS_TEST_FAIL" => WIN32::ERROR_DS_SUB_CLS_TEST_FAIL,
            "ERROR_DS_BAD_RDN_ATT_ID_SYNTAX" => WIN32::ERROR_DS_BAD_RDN_ATT_ID_SYNTAX,
            "ERROR_DS_EXISTS_IN_AUX_CLS" => WIN32::ERROR_DS_EXISTS_IN_AUX_CLS,
            "ERROR_DS_EXISTS_IN_SUB_CLS" => WIN32::ERROR_DS_EXISTS_IN_SUB_CLS,
            "ERROR_DS_EXISTS_IN_POSS_SUP" => WIN32::ERROR_DS_EXISTS_IN_POSS_SUP,
            "ERROR_DS_RECALCSCHEMA_FAILED" => WIN32::ERROR_DS_RECALCSCHEMA_FAILED,
            "ERROR_DS_TREE_DELETE_NOT_FINISHED" => WIN32::ERROR_DS_TREE_DELETE_NOT_FINISHED,
            "ERROR_DS_CANT_DELETE" => WIN32::ERROR_DS_CANT_DELETE,
            "ERROR_DS_ATT_SCHEMA_REQ_ID" => WIN32::ERROR_DS_ATT_SCHEMA_REQ_ID,
            "ERROR_DS_BAD_ATT_SCHEMA_SYNTAX" => WIN32::ERROR_DS_BAD_ATT_SCHEMA_SYNTAX,
            "ERROR_DS_CANT_CACHE_ATT" => WIN32::ERROR_DS_CANT_CACHE_ATT,
            "ERROR_DS_CANT_CACHE_CLASS" => WIN32::ERROR_DS_CANT_CACHE_CLASS,
            "ERROR_DS_CANT_REMOVE_ATT_CACHE" => WIN32::ERROR_DS_CANT_REMOVE_ATT_CACHE,
            "ERROR_DS_CANT_REMOVE_CLASS_CACHE" => WIN32::ERROR_DS_CANT_REMOVE_CLASS_CACHE,
            "ERROR_DS_CANT_RETRIEVE_DN" => WIN32::ERROR_DS_CANT_RETRIEVE_DN,
            "ERROR_DS_MISSING_SUPREF" => WIN32::ERROR_DS_MISSING_SUPREF,
            "ERROR_DS_CANT_RETRIEVE_INSTANCE" => WIN32::ERROR_DS_CANT_RETRIEVE_INSTANCE,
            "ERROR_DS_CODE_INCONSISTENCY" => WIN32::ERROR_DS_CODE_INCONSISTENCY,
            "ERROR_DS_DATABASE_ERROR" => WIN32::ERROR_DS_DATABASE_ERROR,
            "ERROR_DS_GOVERNSID_MISSING" => WIN32::ERROR_DS_GOVERNSID_MISSING,
            "ERROR_DS_MISSING_EXPECTED_ATT" => WIN32::ERROR_DS_MISSING_EXPECTED_ATT,
            "ERROR_DS_NCNAME_MISSING_CR_REF" => WIN32::ERROR_DS_NCNAME_MISSING_CR_REF,
            "ERROR_DS_SECURITY_CHECKING_ERROR" => WIN32::ERROR_DS_SECURITY_CHECKING_ERROR,
            "ERROR_DS_SCHEMA_NOT_LOADED" => WIN32::ERROR_DS_SCHEMA_NOT_LOADED,
            "ERROR_DS_SCHEMA_ALLOC_FAILED" => WIN32::ERROR_DS_SCHEMA_ALLOC_FAILED,
            "ERROR_DS_ATT_SCHEMA_REQ_SYNTAX" => WIN32::ERROR_DS_ATT_SCHEMA_REQ_SYNTAX,
            "ERROR_DS_GCVERIFY_ERROR" => WIN32::ERROR_DS_GCVERIFY_ERROR,
            "ERROR_DS_DRA_SCHEMA_MISMATCH" => WIN32::ERROR_DS_DRA_SCHEMA_MISMATCH,
            "ERROR_DS_CANT_FIND_DSA_OBJ" => WIN32::ERROR_DS_CANT_FIND_DSA_OBJ,
            "ERROR_DS_CANT_FIND_EXPECTED_NC" => WIN32::ERROR_DS_CANT_FIND_EXPECTED_NC,
            "ERROR_DS_CANT_FIND_NC_IN_CACHE" => WIN32::ERROR_DS_CANT_FIND_NC_IN_CACHE,
            "ERROR_DS_CANT_RETRIEVE_CHILD" => WIN32::ERROR_DS_CANT_RETRIEVE_CHILD,
            "ERROR_DS_SECURITY_ILLEGAL_MODIFY" => WIN32::ERROR_DS_SECURITY_ILLEGAL_MODIFY,
            "ERROR_DS_CANT_REPLACE_HIDDEN_REC" => WIN32::ERROR_DS_CANT_REPLACE_HIDDEN_REC,
            "ERROR_DS_BAD_HIERARCHY_FILE" => WIN32::ERROR_DS_BAD_HIERARCHY_FILE,
            "ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED" => WIN32::ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED,
            "ERROR_DS_CONFIG_PARAM_MISSING" => WIN32::ERROR_DS_CONFIG_PARAM_MISSING,
            "ERROR_DS_COUNTING_AB_INDICES_FAILED" => WIN32::ERROR_DS_COUNTING_AB_INDICES_FAILED,
            "ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED" => WIN32::ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED,
            "ERROR_DS_INTERNAL_FAILURE" => WIN32::ERROR_DS_INTERNAL_FAILURE,
            "ERROR_DS_UNKNOWN_ERROR" => WIN32::ERROR_DS_UNKNOWN_ERROR,
            "ERROR_DS_ROOT_REQUIRES_CLASS_TOP" => WIN32::ERROR_DS_ROOT_REQUIRES_CLASS_TOP,
            "ERROR_DS_REFUSING_FSMO_ROLES" => WIN32::ERROR_DS_REFUSING_FSMO_ROLES,
            "ERROR_DS_MISSING_FSMO_SETTINGS" => WIN32::ERROR_DS_MISSING_FSMO_SETTINGS,
            "ERROR_DS_UNABLE_TO_SURRENDER_ROLES" => WIN32::ERROR_DS_UNABLE_TO_SURRENDER_ROLES,
            "ERROR_DS_DRA_GENERIC" => WIN32::ERROR_DS_DRA_GENERIC,
            "ERROR_DS_DRA_INVALID_PARAMETER" => WIN32::ERROR_DS_DRA_INVALID_PARAMETER,
            "ERROR_DS_DRA_BUSY" => WIN32::ERROR_DS_DRA_BUSY,
            "ERROR_DS_DRA_BAD_DN" => WIN32::ERROR_DS_DRA_BAD_DN,
            "ERROR_DS_DRA_BAD_NC" => WIN32::ERROR_DS_DRA_BAD_NC,
            "ERROR_DS_DRA_DN_EXISTS" => WIN32::ERROR_DS_DRA_DN_EXISTS,
            "ERROR_DS_DRA_INTERNAL_ERROR" => WIN32::ERROR_DS_DRA_INTERNAL_ERROR,
            "ERROR_DS_DRA_INCONSISTENT_DIT" => WIN32::ERROR_DS_DRA_INCONSISTENT_DIT,
            "ERROR_DS_DRA_CONNECTION_FAILED" => WIN32::ERROR_DS_DRA_CONNECTION_FAILED,
            "ERROR_DS_DRA_BAD_INSTANCE_TYPE" => WIN32::ERROR_DS_DRA_BAD_INSTANCE_TYPE,
            "ERROR_DS_DRA_OUT_OF_MEM" => WIN32::ERROR_DS_DRA_OUT_OF_MEM,
            "ERROR_DS_DRA_MAIL_PROBLEM" => WIN32::ERROR_DS_DRA_MAIL_PROBLEM,
            "ERROR_DS_DRA_REF_ALREADY_EXISTS" => WIN32::ERROR_DS_DRA_REF_ALREADY_EXISTS,
            "ERROR_DS_DRA_REF_NOT_FOUND" => WIN32::ERROR_DS_DRA_REF_NOT_FOUND,
            "ERROR_DS_DRA_OBJ_IS_REP_SOURCE" => WIN32::ERROR_DS_DRA_OBJ_IS_REP_SOURCE,
            "ERROR_DS_DRA_DB_ERROR" => WIN32::ERROR_DS_DRA_DB_ERROR,
            "ERROR_DS_DRA_NO_REPLICA" => WIN32::ERROR_DS_DRA_NO_REPLICA,
            "ERROR_DS_DRA_ACCESS_DENIED" => WIN32::ERROR_DS_DRA_ACCESS_DENIED,
            "ERROR_DS_DRA_NOT_SUPPORTED" => WIN32::ERROR_DS_DRA_NOT_SUPPORTED,
            "ERROR_DS_DRA_RPC_CANCELLED" => WIN32::ERROR_DS_DRA_RPC_CANCELLED,
            "ERROR_DS_DRA_SOURCE_DISABLED" => WIN32::ERROR_DS_DRA_SOURCE_DISABLED,
            "ERROR_DS_DRA_SINK_DISABLED" => WIN32::ERROR_DS_DRA_SINK_DISABLED,
            "ERROR_DS_DRA_NAME_COLLISION" => WIN32::ERROR_DS_DRA_NAME_COLLISION,
            "ERROR_DS_DRA_SOURCE_REINSTALLED" => WIN32::ERROR_DS_DRA_SOURCE_REINSTALLED,
            "ERROR_DS_DRA_MISSING_PARENT" => WIN32::ERROR_DS_DRA_MISSING_PARENT,
            "ERROR_DS_DRA_PREEMPTED" => WIN32::ERROR_DS_DRA_PREEMPTED,
            "ERROR_DS_DRA_ABANDON_SYNC" => WIN32::ERROR_DS_DRA_ABANDON_SYNC,
            "ERROR_DS_DRA_SHUTDOWN" => WIN32::ERROR_DS_DRA_SHUTDOWN,
            "ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET" => WIN32::ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET,
            "ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA" => WIN32::ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA,
            "ERROR_DS_DRA_EXTN_CONNECTION_FAILED" => WIN32::ERROR_DS_DRA_EXTN_CONNECTION_FAILED,
            "ERROR_DS_INSTALL_SCHEMA_MISMATCH" => WIN32::ERROR_DS_INSTALL_SCHEMA_MISMATCH,
            "ERROR_DS_DUP_LINK_ID" => WIN32::ERROR_DS_DUP_LINK_ID,
            "ERROR_DS_NAME_ERROR_RESOLVING" => WIN32::ERROR_DS_NAME_ERROR_RESOLVING,
            "ERROR_DS_NAME_ERROR_NOT_FOUND" => WIN32::ERROR_DS_NAME_ERROR_NOT_FOUND,
            "ERROR_DS_NAME_ERROR_NOT_UNIQUE" => WIN32::ERROR_DS_NAME_ERROR_NOT_UNIQUE,
            "ERROR_DS_NAME_ERROR_NO_MAPPING" => WIN32::ERROR_DS_NAME_ERROR_NO_MAPPING,
            "ERROR_DS_NAME_ERROR_DOMAIN_ONLY" => WIN32::ERROR_DS_NAME_ERROR_DOMAIN_ONLY,
            "ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING" => WIN32::ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING,
            "ERROR_DS_CONSTRUCTED_ATT_MOD" => WIN32::ERROR_DS_CONSTRUCTED_ATT_MOD,
            "ERROR_DS_WRONG_OM_OBJ_CLASS" => WIN32::ERROR_DS_WRONG_OM_OBJ_CLASS,
            "ERROR_DS_DRA_REPL_PENDING" => WIN32::ERROR_DS_DRA_REPL_PENDING,
            "ERROR_DS_DS_REQUIRED" => WIN32::ERROR_DS_DS_REQUIRED,
            "ERROR_DS_INVALID_LDAP_DISPLAY_NAME" => WIN32::ERROR_DS_INVALID_LDAP_DISPLAY_NAME,
            "ERROR_DS_NON_BASE_SEARCH" => WIN32::ERROR_DS_NON_BASE_SEARCH,
            "ERROR_DS_CANT_RETRIEVE_ATTS" => WIN32::ERROR_DS_CANT_RETRIEVE_ATTS,
            "ERROR_DS_BACKLINK_WITHOUT_LINK" => WIN32::ERROR_DS_BACKLINK_WITHOUT_LINK,
            "ERROR_DS_EPOCH_MISMATCH" => WIN32::ERROR_DS_EPOCH_MISMATCH,
            "ERROR_DS_SRC_NAME_MISMATCH" => WIN32::ERROR_DS_SRC_NAME_MISMATCH,
            "ERROR_DS_SRC_AND_DST_NC_IDENTICAL" => WIN32::ERROR_DS_SRC_AND_DST_NC_IDENTICAL,
            "ERROR_DS_DST_NC_MISMATCH" => WIN32::ERROR_DS_DST_NC_MISMATCH,
            "ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC" => WIN32::ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC,
            "ERROR_DS_SRC_GUID_MISMATCH" => WIN32::ERROR_DS_SRC_GUID_MISMATCH,
            "ERROR_DS_CANT_MOVE_DELETED_OBJECT" => WIN32::ERROR_DS_CANT_MOVE_DELETED_OBJECT,
            "ERROR_DS_PDC_OPERATION_IN_PROGRESS" => WIN32::ERROR_DS_PDC_OPERATION_IN_PROGRESS,
            "ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD" => WIN32::ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD,
            "ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION" => WIN32::ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION,
            "ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS" => WIN32::ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS,
            "ERROR_DS_NC_MUST_HAVE_NC_PARENT" => WIN32::ERROR_DS_NC_MUST_HAVE_NC_PARENT,
            "ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE" => WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE,
            "ERROR_DS_DST_DOMAIN_NOT_NATIVE" => WIN32::ERROR_DS_DST_DOMAIN_NOT_NATIVE,
            "ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER" => WIN32::ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER,
            "ERROR_DS_CANT_MOVE_ACCOUNT_GROUP" => WIN32::ERROR_DS_CANT_MOVE_ACCOUNT_GROUP,
            "ERROR_DS_CANT_MOVE_RESOURCE_GROUP" => WIN32::ERROR_DS_CANT_MOVE_RESOURCE_GROUP,
            "ERROR_DS_INVALID_SEARCH_FLAG" => WIN32::ERROR_DS_INVALID_SEARCH_FLAG,
            "ERROR_DS_NO_TREE_DELETE_ABOVE_NC" => WIN32::ERROR_DS_NO_TREE_DELETE_ABOVE_NC,
            "ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE" => WIN32::ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE,
            "ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE" => WIN32::ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE,
            "ERROR_DS_SAM_INIT_FAILURE" => WIN32::ERROR_DS_SAM_INIT_FAILURE,
            "ERROR_DS_SENSITIVE_GROUP_VIOLATION" => WIN32::ERROR_DS_SENSITIVE_GROUP_VIOLATION,
            "ERROR_DS_CANT_MOD_PRIMARYGROUPID" => WIN32::ERROR_DS_CANT_MOD_PRIMARYGROUPID,
            "ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD" => WIN32::ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD,
            "ERROR_DS_NONSAFE_SCHEMA_CHANGE" => WIN32::ERROR_DS_NONSAFE_SCHEMA_CHANGE,
            "ERROR_DS_SCHEMA_UPDATE_DISALLOWED" => WIN32::ERROR_DS_SCHEMA_UPDATE_DISALLOWED,
            "ERROR_DS_CANT_CREATE_UNDER_SCHEMA" => WIN32::ERROR_DS_CANT_CREATE_UNDER_SCHEMA,
            "ERROR_DS_INSTALL_NO_SRC_SCH_VERSION" => WIN32::ERROR_DS_INSTALL_NO_SRC_SCH_VERSION,
            "ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE" => WIN32::ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE,
            "ERROR_DS_INVALID_GROUP_TYPE" => WIN32::ERROR_DS_INVALID_GROUP_TYPE,
            "ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN" => WIN32::ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN,
            "ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN" => WIN32::ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN,
            "ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER" => WIN32::ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER,
            "ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER" => WIN32::ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER,
            "ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER" => WIN32::ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER,
            "ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER" => WIN32::ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER,
            "ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER" => WIN32::ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER,
            "ERROR_DS_HAVE_PRIMARY_MEMBERS" => WIN32::ERROR_DS_HAVE_PRIMARY_MEMBERS,
            "ERROR_DS_STRING_SD_CONVERSION_FAILED" => WIN32::ERROR_DS_STRING_SD_CONVERSION_FAILED,
            "ERROR_DS_NAMING_MASTER_GC" => WIN32::ERROR_DS_NAMING_MASTER_GC,
            "ERROR_DS_DNS_LOOKUP_FAILURE" => WIN32::ERROR_DS_DNS_LOOKUP_FAILURE,
            "ERROR_DS_COULDNT_UPDATE_SPNS" => WIN32::ERROR_DS_COULDNT_UPDATE_SPNS,
            "ERROR_DS_CANT_RETRIEVE_SD" => WIN32::ERROR_DS_CANT_RETRIEVE_SD,
            "ERROR_DS_KEY_NOT_UNIQUE" => WIN32::ERROR_DS_KEY_NOT_UNIQUE,
            "ERROR_DS_WRONG_LINKED_ATT_SYNTAX" => WIN32::ERROR_DS_WRONG_LINKED_ATT_SYNTAX,
            "ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD" => WIN32::ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD,
            "ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY" => WIN32::ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY,
            "ERROR_DS_CANT_START" => WIN32::ERROR_DS_CANT_START,
            "ERROR_DS_INIT_FAILURE" => WIN32::ERROR_DS_INIT_FAILURE,
            "ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION" => WIN32::ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION,
            "ERROR_DS_SOURCE_DOMAIN_IN_FOREST" => WIN32::ERROR_DS_SOURCE_DOMAIN_IN_FOREST,
            "ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST" => WIN32::ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST,
            "ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED" => WIN32::ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED,
            "ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN" => WIN32::ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN,
            "ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER" => WIN32::ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER,
            "ERROR_DS_SRC_SID_EXISTS_IN_FOREST" => WIN32::ERROR_DS_SRC_SID_EXISTS_IN_FOREST,
            "ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH" => WIN32::ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH,
            "ERROR_SAM_INIT_FAILURE" => WIN32::ERROR_SAM_INIT_FAILURE,
            "ERROR_DS_DRA_SCHEMA_INFO_SHIP" => WIN32::ERROR_DS_DRA_SCHEMA_INFO_SHIP,
            "ERROR_DS_DRA_SCHEMA_CONFLICT" => WIN32::ERROR_DS_DRA_SCHEMA_CONFLICT,
            "ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT" => WIN32::ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT,
            "ERROR_DS_DRA_OBJ_NC_MISMATCH" => WIN32::ERROR_DS_DRA_OBJ_NC_MISMATCH,
            "ERROR_DS_NC_STILL_HAS_DSAS" => WIN32::ERROR_DS_NC_STILL_HAS_DSAS,
            "ERROR_DS_GC_REQUIRED" => WIN32::ERROR_DS_GC_REQUIRED,
            "ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY" => WIN32::ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY,
            "ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS" => WIN32::ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS,
            "ERROR_DS_CANT_ADD_TO_GC" => WIN32::ERROR_DS_CANT_ADD_TO_GC,
            "ERROR_DS_NO_CHECKPOINT_WITH_PDC" => WIN32::ERROR_DS_NO_CHECKPOINT_WITH_PDC,
            "ERROR_DS_SOURCE_AUDITING_NOT_ENABLED" => WIN32::ERROR_DS_SOURCE_AUDITING_NOT_ENABLED,
            "ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC" => WIN32::ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC,
            "ERROR_DS_INVALID_NAME_FOR_SPN" => WIN32::ERROR_DS_INVALID_NAME_FOR_SPN,
            "ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS" => WIN32::ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS,
            "ERROR_DS_UNICODEPWD_NOT_IN_QUOTES" => WIN32::ERROR_DS_UNICODEPWD_NOT_IN_QUOTES,
            "ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED" => WIN32::ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED,
            "ERROR_DS_MUST_BE_RUN_ON_DST_DC" => WIN32::ERROR_DS_MUST_BE_RUN_ON_DST_DC,
            "ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER" => WIN32::ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER,
            "ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ" => WIN32::ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ,
            "ERROR_DS_INIT_FAILURE_CONSOLE" => WIN32::ERROR_DS_INIT_FAILURE_CONSOLE,
            "ERROR_DS_SAM_INIT_FAILURE_CONSOLE" => WIN32::ERROR_DS_SAM_INIT_FAILURE_CONSOLE,
            "ERROR_DS_FOREST_VERSION_TOO_HIGH" => WIN32::ERROR_DS_FOREST_VERSION_TOO_HIGH,
            "ERROR_DS_DOMAIN_VERSION_TOO_HIGH" => WIN32::ERROR_DS_DOMAIN_VERSION_TOO_HIGH,
            "ERROR_DS_FOREST_VERSION_TOO_LOW" => WIN32::ERROR_DS_FOREST_VERSION_TOO_LOW,
            "ERROR_DS_DOMAIN_VERSION_TOO_LOW" => WIN32::ERROR_DS_DOMAIN_VERSION_TOO_LOW,
            "ERROR_DS_INCOMPATIBLE_VERSION" => WIN32::ERROR_DS_INCOMPATIBLE_VERSION,
            "ERROR_DS_LOW_DSA_VERSION" => WIN32::ERROR_DS_LOW_DSA_VERSION,
            "ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN" => WIN32::ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN,
            "ERROR_DS_NOT_SUPPORTED_SORT_ORDER" => WIN32::ERROR_DS_NOT_SUPPORTED_SORT_ORDER,
            "ERROR_DS_NAME_NOT_UNIQUE" => WIN32::ERROR_DS_NAME_NOT_UNIQUE,
            "ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4" => WIN32::ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4,
            "ERROR_DS_OUT_OF_VERSION_STORE" => WIN32::ERROR_DS_OUT_OF_VERSION_STORE,
            "ERROR_DS_INCOMPATIBLE_CONTROLS_USED" => WIN32::ERROR_DS_INCOMPATIBLE_CONTROLS_USED,
            "ERROR_DS_NO_REF_DOMAIN" => WIN32::ERROR_DS_NO_REF_DOMAIN,
            "ERROR_DS_RESERVED_LINK_ID" => WIN32::ERROR_DS_RESERVED_LINK_ID,
            "ERROR_DS_LINK_ID_NOT_AVAILABLE" => WIN32::ERROR_DS_LINK_ID_NOT_AVAILABLE,
            "ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER" => WIN32::ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER,
            "ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE" => WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE,
            "ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC" => WIN32::ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC,
            "ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG" => WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG,
            "ERROR_DS_MODIFYDN_WRONG_GRANDPARENT" => WIN32::ERROR_DS_MODIFYDN_WRONG_GRANDPARENT,
            "ERROR_DS_NAME_ERROR_TRUST_REFERRAL" => WIN32::ERROR_DS_NAME_ERROR_TRUST_REFERRAL,
            "ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER" => WIN32::ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER,
            "ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD" => WIN32::ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD,
            "ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2" => WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2,
            "ERROR_DS_THREAD_LIMIT_EXCEEDED" => WIN32::ERROR_DS_THREAD_LIMIT_EXCEEDED,
            "ERROR_DS_NOT_CLOSEST" => WIN32::ERROR_DS_NOT_CLOSEST,
            "ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF" => WIN32::ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF,
            "ERROR_DS_SINGLE_USER_MODE_FAILED" => WIN32::ERROR_DS_SINGLE_USER_MODE_FAILED,
            "ERROR_DS_NTDSCRIPT_SYNTAX_ERROR" => WIN32::ERROR_DS_NTDSCRIPT_SYNTAX_ERROR,
            "ERROR_DS_NTDSCRIPT_PROCESS_ERROR" => WIN32::ERROR_DS_NTDSCRIPT_PROCESS_ERROR,
            "ERROR_DS_DIFFERENT_REPL_EPOCHS" => WIN32::ERROR_DS_DIFFERENT_REPL_EPOCHS,
            "ERROR_DS_DRS_EXTENSIONS_CHANGED" => WIN32::ERROR_DS_DRS_EXTENSIONS_CHANGED,
            "ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR" => WIN32::ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR,
            "ERROR_DS_NO_MSDS_INTID" => WIN32::ERROR_DS_NO_MSDS_INTID,
            "ERROR_DS_DUP_MSDS_INTID" => WIN32::ERROR_DS_DUP_MSDS_INTID,
            "ERROR_DS_EXISTS_IN_RDNATTID" => WIN32::ERROR_DS_EXISTS_IN_RDNATTID,
            "ERROR_DS_AUTHORIZATION_FAILED" => WIN32::ERROR_DS_AUTHORIZATION_FAILED,
            "ERROR_DS_INVALID_SCRIPT" => WIN32::ERROR_DS_INVALID_SCRIPT,
            "ERROR_DS_REMOTE_CROSSREF_OP_FAILED" => WIN32::ERROR_DS_REMOTE_CROSSREF_OP_FAILED,
            "ERROR_DS_CROSS_REF_BUSY" => WIN32::ERROR_DS_CROSS_REF_BUSY,
            "ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN" => WIN32::ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN,
            "ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC" => WIN32::ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC,
            "ERROR_DS_DUPLICATE_ID_FOUND" => WIN32::ERROR_DS_DUPLICATE_ID_FOUND,
            "ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT" => WIN32::ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT,
            "ERROR_DS_GROUP_CONVERSION_ERROR" => WIN32::ERROR_DS_GROUP_CONVERSION_ERROR,
            "ERROR_DS_CANT_MOVE_APP_BASIC_GROUP" => WIN32::ERROR_DS_CANT_MOVE_APP_BASIC_GROUP,
            "ERROR_DS_CANT_MOVE_APP_QUERY_GROUP" => WIN32::ERROR_DS_CANT_MOVE_APP_QUERY_GROUP,
            "ERROR_DS_ROLE_NOT_VERIFIED" => WIN32::ERROR_DS_ROLE_NOT_VERIFIED,
            "ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL" => WIN32::ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL,
            "ERROR_DS_DOMAIN_RENAME_IN_PROGRESS" => WIN32::ERROR_DS_DOMAIN_RENAME_IN_PROGRESS,
            "ERROR_DS_EXISTING_AD_CHILD_NC" => WIN32::ERROR_DS_EXISTING_AD_CHILD_NC,
            "ERROR_DS_REPL_LIFETIME_EXCEEDED" => WIN32::ERROR_DS_REPL_LIFETIME_EXCEEDED,
            "ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER" => WIN32::ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER,
            "ERROR_DS_LDAP_SEND_QUEUE_FULL" => WIN32::ERROR_DS_LDAP_SEND_QUEUE_FULL,
            "ERROR_DS_DRA_OUT_SCHEDULE_WINDOW" => WIN32::ERROR_DS_DRA_OUT_SCHEDULE_WINDOW,
            "ERROR_DS_POLICY_NOT_KNOWN" => WIN32::ERROR_DS_POLICY_NOT_KNOWN,
            "ERROR_NO_SITE_SETTINGS_OBJECT" => WIN32::ERROR_NO_SITE_SETTINGS_OBJECT,
            "ERROR_NO_SECRETS" => WIN32::ERROR_NO_SECRETS,
            "ERROR_NO_WRITABLE_DC_FOUND" => WIN32::ERROR_NO_WRITABLE_DC_FOUND,
            "ERROR_DS_NO_SERVER_OBJECT" => WIN32::ERROR_DS_NO_SERVER_OBJECT,
            "ERROR_DS_NO_NTDSA_OBJECT" => WIN32::ERROR_DS_NO_NTDSA_OBJECT,
            "ERROR_DS_NON_ASQ_SEARCH" => WIN32::ERROR_DS_NON_ASQ_SEARCH,
            "ERROR_DS_AUDIT_FAILURE" => WIN32::ERROR_DS_AUDIT_FAILURE,
            "ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE" => WIN32::ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE,
            "ERROR_DS_INVALID_SEARCH_FLAG_TUPLE" => WIN32::ERROR_DS_INVALID_SEARCH_FLAG_TUPLE,
            "ERROR_DS_HIERARCHY_TABLE_TOO_DEEP" => WIN32::ERROR_DS_HIERARCHY_TABLE_TOO_DEEP,
            "ERROR_DS_DRA_CORRUPT_UTD_VECTOR" => WIN32::ERROR_DS_DRA_CORRUPT_UTD_VECTOR,
            "ERROR_DS_DRA_SECRETS_DENIED" => WIN32::ERROR_DS_DRA_SECRETS_DENIED,
            "ERROR_DS_RESERVED_MAPI_ID" => WIN32::ERROR_DS_RESERVED_MAPI_ID,
            "ERROR_DS_MAPI_ID_NOT_AVAILABLE" => WIN32::ERROR_DS_MAPI_ID_NOT_AVAILABLE,
            "ERROR_DS_DRA_MISSING_KRBTGT_SECRET" => WIN32::ERROR_DS_DRA_MISSING_KRBTGT_SECRET,
            "ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST" => WIN32::ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST,
            "ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST" => WIN32::ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST,
            "ERROR_INVALID_USER_PRINCIPAL_NAME" => WIN32::ERROR_INVALID_USER_PRINCIPAL_NAME,
            "ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS" => WIN32::ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS,
            "ERROR_DS_OID_NOT_FOUND" => WIN32::ERROR_DS_OID_NOT_FOUND,
            "ERROR_DS_DRA_RECYCLED_TARGET" => WIN32::ERROR_DS_DRA_RECYCLED_TARGET,
            "ERROR_DS_DISALLOWED_NC_REDIRECT" => WIN32::ERROR_DS_DISALLOWED_NC_REDIRECT,
            "ERROR_DS_HIGH_ADLDS_FFL" => WIN32::ERROR_DS_HIGH_ADLDS_FFL,
            "ERROR_DS_HIGH_DSA_VERSION" => WIN32::ERROR_DS_HIGH_DSA_VERSION,
            "ERROR_DS_LOW_ADLDS_FFL" => WIN32::ERROR_DS_LOW_ADLDS_FFL,
            "ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION" => WIN32::ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION,
            "ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED" => WIN32::ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED,
            "ERROR_INCORRECT_ACCOUNT_TYPE" => WIN32::ERROR_INCORRECT_ACCOUNT_TYPE,
            "ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST" => WIN32::ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST,
            "ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST" => WIN32::ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST,
            "ERROR_DS_MISSING_FOREST_TRUST" => WIN32::ERROR_DS_MISSING_FOREST_TRUST,
            "ERROR_DS_VALUE_KEY_NOT_UNIQUE" => WIN32::ERROR_DS_VALUE_KEY_NOT_UNIQUE,
            "ERROR_WEAK_WHFBKEY_BLOCKED" => WIN32::ERROR_WEAK_WHFBKEY_BLOCKED,
            "ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD" => WIN32::ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD,
            "ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED" => WIN32::ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED,
            "ERROR_POLICY_CONTROLLED_ACCOUNT" => WIN32::ERROR_POLICY_CONTROLLED_ACCOUNT,
            "ERROR_LAPS_LEGACY_SCHEMA_MISSING" => WIN32::ERROR_LAPS_LEGACY_SCHEMA_MISSING,
            "ERROR_LAPS_SCHEMA_MISSING" => WIN32::ERROR_LAPS_SCHEMA_MISSING,
            "ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL" => WIN32::ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL,
            "DNS_ERROR_RCODE_FORMAT_ERROR" => WIN32::DNS_ERROR_RCODE_FORMAT_ERROR,
            "DNS_ERROR_RCODE_SERVER_FAILURE" => WIN32::DNS_ERROR_RCODE_SERVER_FAILURE,
            "DNS_ERROR_RCODE_NAME_ERROR" => WIN32::DNS_ERROR_RCODE_NAME_ERROR,
            "DNS_ERROR_RCODE_NOT_IMPLEMENTED" => WIN32::DNS_ERROR_RCODE_NOT_IMPLEMENTED,
            "DNS_ERROR_RCODE_REFUSED" => WIN32::DNS_ERROR_RCODE_REFUSED,
            "DNS_ERROR_RCODE_YXDOMAIN" => WIN32::DNS_ERROR_RCODE_YXDOMAIN,
            "DNS_ERROR_RCODE_YXRRSET" => WIN32::DNS_ERROR_RCODE_YXRRSET,
            "DNS_ERROR_RCODE_NXRRSET" => WIN32::DNS_ERROR_RCODE_NXRRSET,
            "DNS_ERROR_RCODE_NOTAUTH" => WIN32::DNS_ERROR_RCODE_NOTAUTH,
            "DNS_ERROR_RCODE_NOTZONE" => WIN32::DNS_ERROR_RCODE_NOTZONE,
            "DNS_ERROR_RCODE_BADSIG" => WIN32::DNS_ERROR_RCODE_BADSIG,
            "DNS_ERROR_RCODE_BADKEY" => WIN32::DNS_ERROR_RCODE_BADKEY,
            "DNS_ERROR_RCODE_BADTIME" => WIN32::DNS_ERROR_RCODE_BADTIME,
            "DNS_ERROR_KEYMASTER_REQUIRED" => WIN32::DNS_ERROR_KEYMASTER_REQUIRED,
            "DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE" => WIN32::DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE,
            "DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1" => WIN32::DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1,
            "DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS" => WIN32::DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS,
            "DNS_ERROR_UNSUPPORTED_ALGORITHM" => WIN32::DNS_ERROR_UNSUPPORTED_ALGORITHM,
            "DNS_ERROR_INVALID_KEY_SIZE" => WIN32::DNS_ERROR_INVALID_KEY_SIZE,
            "DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE" => WIN32::DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE,
            "DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION" => WIN32::DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION,
            "DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR" => WIN32::DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR,
            "DNS_ERROR_UNEXPECTED_CNG_ERROR" => WIN32::DNS_ERROR_UNEXPECTED_CNG_ERROR,
            "DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION" => WIN32::DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION,
            "DNS_ERROR_KSP_NOT_ACCESSIBLE" => WIN32::DNS_ERROR_KSP_NOT_ACCESSIBLE,
            "DNS_ERROR_TOO_MANY_SKDS" => WIN32::DNS_ERROR_TOO_MANY_SKDS,
            "DNS_ERROR_INVALID_ROLLOVER_PERIOD" => WIN32::DNS_ERROR_INVALID_ROLLOVER_PERIOD,
            "DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET" => WIN32::DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET,
            "DNS_ERROR_ROLLOVER_IN_PROGRESS" => WIN32::DNS_ERROR_ROLLOVER_IN_PROGRESS,
            "DNS_ERROR_STANDBY_KEY_NOT_PRESENT" => WIN32::DNS_ERROR_STANDBY_KEY_NOT_PRESENT,
            "DNS_ERROR_NOT_ALLOWED_ON_ZSK" => WIN32::DNS_ERROR_NOT_ALLOWED_ON_ZSK,
            "DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD" => WIN32::DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD,
            "DNS_ERROR_ROLLOVER_ALREADY_QUEUED" => WIN32::DNS_ERROR_ROLLOVER_ALREADY_QUEUED,
            "DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE" => WIN32::DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE,
            "DNS_ERROR_BAD_KEYMASTER" => WIN32::DNS_ERROR_BAD_KEYMASTER,
            "DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD" => WIN32::DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD,
            "DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT" => WIN32::DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT,
            "DNS_ERROR_DNSSEC_IS_DISABLED" => WIN32::DNS_ERROR_DNSSEC_IS_DISABLED,
            "DNS_ERROR_INVALID_XML" => WIN32::DNS_ERROR_INVALID_XML,
            "DNS_ERROR_NO_VALID_TRUST_ANCHORS" => WIN32::DNS_ERROR_NO_VALID_TRUST_ANCHORS,
            "DNS_ERROR_ROLLOVER_NOT_POKEABLE" => WIN32::DNS_ERROR_ROLLOVER_NOT_POKEABLE,
            "DNS_ERROR_NSEC3_NAME_COLLISION" => WIN32::DNS_ERROR_NSEC3_NAME_COLLISION,
            "DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1" => WIN32::DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1,
            "DNS_INFO_NO_RECORDS" => WIN32::DNS_INFO_NO_RECORDS,
            "DNS_ERROR_BAD_PACKET" => WIN32::DNS_ERROR_BAD_PACKET,
            "DNS_ERROR_NO_PACKET" => WIN32::DNS_ERROR_NO_PACKET,
            "DNS_ERROR_RCODE" => WIN32::DNS_ERROR_RCODE,
            "DNS_ERROR_UNSECURE_PACKET" => WIN32::DNS_ERROR_UNSECURE_PACKET,
            "DNS_REQUEST_PENDING" => WIN32::DNS_REQUEST_PENDING,
            "DNS_ERROR_INVALID_TYPE" => WIN32::DNS_ERROR_INVALID_TYPE,
            "DNS_ERROR_INVALID_IP_ADDRESS" => WIN32::DNS_ERROR_INVALID_IP_ADDRESS,
            "DNS_ERROR_INVALID_PROPERTY" => WIN32::DNS_ERROR_INVALID_PROPERTY,
            "DNS_ERROR_TRY_AGAIN_LATER" => WIN32::DNS_ERROR_TRY_AGAIN_LATER,
            "DNS_ERROR_NOT_UNIQUE" => WIN32::DNS_ERROR_NOT_UNIQUE,
            "DNS_ERROR_NON_RFC_NAME" => WIN32::DNS_ERROR_NON_RFC_NAME,
            "DNS_STATUS_FQDN" => WIN32::DNS_STATUS_FQDN,
            "DNS_STATUS_DOTTED_NAME" => WIN32::DNS_STATUS_DOTTED_NAME,
            "DNS_STATUS_SINGLE_PART_NAME" => WIN32::DNS_STATUS_SINGLE_PART_NAME,
            "DNS_ERROR_INVALID_NAME_CHAR" => WIN32::DNS_ERROR_INVALID_NAME_CHAR,
            "DNS_ERROR_NUMERIC_NAME" => WIN32::DNS_ERROR_NUMERIC_NAME,
            "DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER" => WIN32::DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER,
            "DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION" => WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION,
            "DNS_ERROR_CANNOT_FIND_ROOT_HINTS" => WIN32::DNS_ERROR_CANNOT_FIND_ROOT_HINTS,
            "DNS_ERROR_INCONSISTENT_ROOT_HINTS" => WIN32::DNS_ERROR_INCONSISTENT_ROOT_HINTS,
            "DNS_ERROR_DWORD_VALUE_TOO_SMALL" => WIN32::DNS_ERROR_DWORD_VALUE_TOO_SMALL,
            "DNS_ERROR_DWORD_VALUE_TOO_LARGE" => WIN32::DNS_ERROR_DWORD_VALUE_TOO_LARGE,
            "DNS_ERROR_BACKGROUND_LOADING" => WIN32::DNS_ERROR_BACKGROUND_LOADING,
            "DNS_ERROR_NOT_ALLOWED_ON_RODC" => WIN32::DNS_ERROR_NOT_ALLOWED_ON_RODC,
            "DNS_ERROR_NOT_ALLOWED_UNDER_DNAME" => WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DNAME,
            "DNS_ERROR_DELEGATION_REQUIRED" => WIN32::DNS_ERROR_DELEGATION_REQUIRED,
            "DNS_ERROR_INVALID_POLICY_TABLE" => WIN32::DNS_ERROR_INVALID_POLICY_TABLE,
            "DNS_ERROR_ADDRESS_REQUIRED" => WIN32::DNS_ERROR_ADDRESS_REQUIRED,
            "DNS_ERROR_ZONE_DOES_NOT_EXIST" => WIN32::DNS_ERROR_ZONE_DOES_NOT_EXIST,
            "DNS_ERROR_NO_ZONE_INFO" => WIN32::DNS_ERROR_NO_ZONE_INFO,
            "DNS_ERROR_INVALID_ZONE_OPERATION" => WIN32::DNS_ERROR_INVALID_ZONE_OPERATION,
            "DNS_ERROR_ZONE_CONFIGURATION_ERROR" => WIN32::DNS_ERROR_ZONE_CONFIGURATION_ERROR,
            "DNS_ERROR_ZONE_HAS_NO_SOA_RECORD" => WIN32::DNS_ERROR_ZONE_HAS_NO_SOA_RECORD,
            "DNS_ERROR_ZONE_HAS_NO_NS_RECORDS" => WIN32::DNS_ERROR_ZONE_HAS_NO_NS_RECORDS,
            "DNS_ERROR_ZONE_LOCKED" => WIN32::DNS_ERROR_ZONE_LOCKED,
            "DNS_ERROR_ZONE_CREATION_FAILED" => WIN32::DNS_ERROR_ZONE_CREATION_FAILED,
            "DNS_ERROR_ZONE_ALREADY_EXISTS" => WIN32::DNS_ERROR_ZONE_ALREADY_EXISTS,
            "DNS_ERROR_AUTOZONE_ALREADY_EXISTS" => WIN32::DNS_ERROR_AUTOZONE_ALREADY_EXISTS,
            "DNS_ERROR_INVALID_ZONE_TYPE" => WIN32::DNS_ERROR_INVALID_ZONE_TYPE,
            "DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP" => WIN32::DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP,
            "DNS_ERROR_ZONE_NOT_SECONDARY" => WIN32::DNS_ERROR_ZONE_NOT_SECONDARY,
            "DNS_ERROR_NEED_SECONDARY_ADDRESSES" => WIN32::DNS_ERROR_NEED_SECONDARY_ADDRESSES,
            "DNS_ERROR_WINS_INIT_FAILED" => WIN32::DNS_ERROR_WINS_INIT_FAILED,
            "DNS_ERROR_NEED_WINS_SERVERS" => WIN32::DNS_ERROR_NEED_WINS_SERVERS,
            "DNS_ERROR_NBSTAT_INIT_FAILED" => WIN32::DNS_ERROR_NBSTAT_INIT_FAILED,
            "DNS_ERROR_SOA_DELETE_INVALID" => WIN32::DNS_ERROR_SOA_DELETE_INVALID,
            "DNS_ERROR_FORWARDER_ALREADY_EXISTS" => WIN32::DNS_ERROR_FORWARDER_ALREADY_EXISTS,
            "DNS_ERROR_ZONE_REQUIRES_MASTER_IP" => WIN32::DNS_ERROR_ZONE_REQUIRES_MASTER_IP,
            "DNS_ERROR_ZONE_IS_SHUTDOWN" => WIN32::DNS_ERROR_ZONE_IS_SHUTDOWN,
            "DNS_ERROR_ZONE_LOCKED_FOR_SIGNING" => WIN32::DNS_ERROR_ZONE_LOCKED_FOR_SIGNING,
            "DNS_ERROR_PRIMARY_REQUIRES_DATAFILE" => WIN32::DNS_ERROR_PRIMARY_REQUIRES_DATAFILE,
            "DNS_ERROR_INVALID_DATAFILE_NAME" => WIN32::DNS_ERROR_INVALID_DATAFILE_NAME,
            "DNS_ERROR_DATAFILE_OPEN_FAILURE" => WIN32::DNS_ERROR_DATAFILE_OPEN_FAILURE,
            "DNS_ERROR_FILE_WRITEBACK_FAILED" => WIN32::DNS_ERROR_FILE_WRITEBACK_FAILED,
            "DNS_ERROR_DATAFILE_PARSING" => WIN32::DNS_ERROR_DATAFILE_PARSING,
            "DNS_ERROR_RECORD_DOES_NOT_EXIST" => WIN32::DNS_ERROR_RECORD_DOES_NOT_EXIST,
            "DNS_ERROR_RECORD_FORMAT" => WIN32::DNS_ERROR_RECORD_FORMAT,
            "DNS_ERROR_NODE_CREATION_FAILED" => WIN32::DNS_ERROR_NODE_CREATION_FAILED,
            "DNS_ERROR_UNKNOWN_RECORD_TYPE" => WIN32::DNS_ERROR_UNKNOWN_RECORD_TYPE,
            "DNS_ERROR_RECORD_TIMED_OUT" => WIN32::DNS_ERROR_RECORD_TIMED_OUT,
            "DNS_ERROR_NAME_NOT_IN_ZONE" => WIN32::DNS_ERROR_NAME_NOT_IN_ZONE,
            "DNS_ERROR_CNAME_LOOP" => WIN32::DNS_ERROR_CNAME_LOOP,
            "DNS_ERROR_NODE_IS_CNAME" => WIN32::DNS_ERROR_NODE_IS_CNAME,
            "DNS_ERROR_CNAME_COLLISION" => WIN32::DNS_ERROR_CNAME_COLLISION,
            "DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT" => WIN32::DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT,
            "DNS_ERROR_RECORD_ALREADY_EXISTS" => WIN32::DNS_ERROR_RECORD_ALREADY_EXISTS,
            "DNS_ERROR_SECONDARY_DATA" => WIN32::DNS_ERROR_SECONDARY_DATA,
            "DNS_ERROR_NO_CREATE_CACHE_DATA" => WIN32::DNS_ERROR_NO_CREATE_CACHE_DATA,
            "DNS_ERROR_NAME_DOES_NOT_EXIST" => WIN32::DNS_ERROR_NAME_DOES_NOT_EXIST,
            "DNS_WARNING_PTR_CREATE_FAILED" => WIN32::DNS_WARNING_PTR_CREATE_FAILED,
            "DNS_WARNING_DOMAIN_UNDELETED" => WIN32::DNS_WARNING_DOMAIN_UNDELETED,
            "DNS_ERROR_DS_UNAVAILABLE" => WIN32::DNS_ERROR_DS_UNAVAILABLE,
            "DNS_ERROR_DS_ZONE_ALREADY_EXISTS" => WIN32::DNS_ERROR_DS_ZONE_ALREADY_EXISTS,
            "DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE" => WIN32::DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE,
            "DNS_ERROR_NODE_IS_DNAME" => WIN32::DNS_ERROR_NODE_IS_DNAME,
            "DNS_ERROR_DNAME_COLLISION" => WIN32::DNS_ERROR_DNAME_COLLISION,
            "DNS_ERROR_ALIAS_LOOP" => WIN32::DNS_ERROR_ALIAS_LOOP,
            "DNS_INFO_AXFR_COMPLETE" => WIN32::DNS_INFO_AXFR_COMPLETE,
            "DNS_ERROR_AXFR" => WIN32::DNS_ERROR_AXFR,
            "DNS_INFO_ADDED_LOCAL_WINS" => WIN32::DNS_INFO_ADDED_LOCAL_WINS,
            "DNS_STATUS_CONTINUE_NEEDED" => WIN32::DNS_STATUS_CONTINUE_NEEDED,
            "DNS_ERROR_NO_TCPIP" => WIN32::DNS_ERROR_NO_TCPIP,
            "DNS_ERROR_NO_DNS_SERVERS" => WIN32::DNS_ERROR_NO_DNS_SERVERS,
            "DNS_ERROR_DP_DOES_NOT_EXIST" => WIN32::DNS_ERROR_DP_DOES_NOT_EXIST,
            "DNS_ERROR_DP_ALREADY_EXISTS" => WIN32::DNS_ERROR_DP_ALREADY_EXISTS,
            "DNS_ERROR_DP_NOT_ENLISTED" => WIN32::DNS_ERROR_DP_NOT_ENLISTED,
            "DNS_ERROR_DP_ALREADY_ENLISTED" => WIN32::DNS_ERROR_DP_ALREADY_ENLISTED,
            "DNS_ERROR_DP_NOT_AVAILABLE" => WIN32::DNS_ERROR_DP_NOT_AVAILABLE,
            "DNS_ERROR_DP_FSMO_ERROR" => WIN32::DNS_ERROR_DP_FSMO_ERROR,
            "DNS_ERROR_RRL_NOT_ENABLED" => WIN32::DNS_ERROR_RRL_NOT_ENABLED,
            "DNS_ERROR_RRL_INVALID_WINDOW_SIZE" => WIN32::DNS_ERROR_RRL_INVALID_WINDOW_SIZE,
            "DNS_ERROR_RRL_INVALID_IPV4_PREFIX" => WIN32::DNS_ERROR_RRL_INVALID_IPV4_PREFIX,
            "DNS_ERROR_RRL_INVALID_IPV6_PREFIX" => WIN32::DNS_ERROR_RRL_INVALID_IPV6_PREFIX,
            "DNS_ERROR_RRL_INVALID_TC_RATE" => WIN32::DNS_ERROR_RRL_INVALID_TC_RATE,
            "DNS_ERROR_RRL_INVALID_LEAK_RATE" => WIN32::DNS_ERROR_RRL_INVALID_LEAK_RATE,
            "DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE" => WIN32::DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE,
            "DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS" => WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS,
            "DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST" => WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST,
            "DNS_ERROR_VIRTUALIZATION_TREE_LOCKED" => WIN32::DNS_ERROR_VIRTUALIZATION_TREE_LOCKED,
            "DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME" => WIN32::DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME,
            "DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE" => WIN32::DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE,
            "DNS_ERROR_ZONESCOPE_ALREADY_EXISTS" => WIN32::DNS_ERROR_ZONESCOPE_ALREADY_EXISTS,
            "DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST" => WIN32::DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST,
            "DNS_ERROR_DEFAULT_ZONESCOPE" => WIN32::DNS_ERROR_DEFAULT_ZONESCOPE,
            "DNS_ERROR_INVALID_ZONESCOPE_NAME" => WIN32::DNS_ERROR_INVALID_ZONESCOPE_NAME,
            "DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES" => WIN32::DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES,
            "DNS_ERROR_LOAD_ZONESCOPE_FAILED" => WIN32::DNS_ERROR_LOAD_ZONESCOPE_FAILED,
            "DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED" => WIN32::DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED,
            "DNS_ERROR_INVALID_SCOPE_NAME" => WIN32::DNS_ERROR_INVALID_SCOPE_NAME,
            "DNS_ERROR_SCOPE_DOES_NOT_EXIST" => WIN32::DNS_ERROR_SCOPE_DOES_NOT_EXIST,
            "DNS_ERROR_DEFAULT_SCOPE" => WIN32::DNS_ERROR_DEFAULT_SCOPE,
            "DNS_ERROR_INVALID_SCOPE_OPERATION" => WIN32::DNS_ERROR_INVALID_SCOPE_OPERATION,
            "DNS_ERROR_SCOPE_LOCKED" => WIN32::DNS_ERROR_SCOPE_LOCKED,
            "DNS_ERROR_SCOPE_ALREADY_EXISTS" => WIN32::DNS_ERROR_SCOPE_ALREADY_EXISTS,
            "DNS_ERROR_POLICY_ALREADY_EXISTS" => WIN32::DNS_ERROR_POLICY_ALREADY_EXISTS,
            "DNS_ERROR_POLICY_DOES_NOT_EXIST" => WIN32::DNS_ERROR_POLICY_DOES_NOT_EXIST,
            "DNS_ERROR_POLICY_INVALID_CRITERIA" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA,
            "DNS_ERROR_POLICY_INVALID_SETTINGS" => WIN32::DNS_ERROR_POLICY_INVALID_SETTINGS,
            "DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED" => WIN32::DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED,
            "DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST" => WIN32::DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST,
            "DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS" => WIN32::DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS,
            "DNS_ERROR_SUBNET_DOES_NOT_EXIST" => WIN32::DNS_ERROR_SUBNET_DOES_NOT_EXIST,
            "DNS_ERROR_SUBNET_ALREADY_EXISTS" => WIN32::DNS_ERROR_SUBNET_ALREADY_EXISTS,
            "DNS_ERROR_POLICY_LOCKED" => WIN32::DNS_ERROR_POLICY_LOCKED,
            "DNS_ERROR_POLICY_INVALID_WEIGHT" => WIN32::DNS_ERROR_POLICY_INVALID_WEIGHT,
            "DNS_ERROR_POLICY_INVALID_NAME" => WIN32::DNS_ERROR_POLICY_INVALID_NAME,
            "DNS_ERROR_POLICY_MISSING_CRITERIA" => WIN32::DNS_ERROR_POLICY_MISSING_CRITERIA,
            "DNS_ERROR_INVALID_CLIENT_SUBNET_NAME" => WIN32::DNS_ERROR_INVALID_CLIENT_SUBNET_NAME,
            "DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID" => WIN32::DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID,
            "DNS_ERROR_POLICY_SCOPE_MISSING" => WIN32::DNS_ERROR_POLICY_SCOPE_MISSING,
            "DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED" => WIN32::DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED,
            "DNS_ERROR_SERVERSCOPE_IS_REFERENCED" => WIN32::DNS_ERROR_SERVERSCOPE_IS_REFERENCED,
            "DNS_ERROR_ZONESCOPE_IS_REFERENCED" => WIN32::DNS_ERROR_ZONESCOPE_IS_REFERENCED,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE,
            "DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY" => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY,
            "WSAEINTR" => WIN32::WSAEINTR,
            "WSAEBADF" => WIN32::WSAEBADF,
            "WSAEACCES" => WIN32::WSAEACCES,
            "WSAEFAULT" => WIN32::WSAEFAULT,
            "WSAEINVAL" => WIN32::WSAEINVAL,
            "WSAEMFILE" => WIN32::WSAEMFILE,
            "WSAEWOULDBLOCK" => WIN32::WSAEWOULDBLOCK,
            "WSAEINPROGRESS" => WIN32::WSAEINPROGRESS,
            "WSAEALREADY" => WIN32::WSAEALREADY,
            "WSAENOTSOCK" => WIN32::WSAENOTSOCK,
            "WSAEDESTADDRREQ" => WIN32::WSAEDESTADDRREQ,
            "WSAEMSGSIZE" => WIN32::WSAEMSGSIZE,
            "WSAEPROTOTYPE" => WIN32::WSAEPROTOTYPE,
            "WSAENOPROTOOPT" => WIN32::WSAENOPROTOOPT,
            "WSAEPROTONOSUPPORT" => WIN32::WSAEPROTONOSUPPORT,
            "WSAESOCKTNOSUPPORT" => WIN32::WSAESOCKTNOSUPPORT,
            "WSAEOPNOTSUPP" => WIN32::WSAEOPNOTSUPP,
            "WSAEPFNOSUPPORT" => WIN32::WSAEPFNOSUPPORT,
            "WSAEAFNOSUPPORT" => WIN32::WSAEAFNOSUPPORT,
            "WSAEADDRINUSE" => WIN32::WSAEADDRINUSE,
            "WSAEADDRNOTAVAIL" => WIN32::WSAEADDRNOTAVAIL,
            "WSAENETDOWN" => WIN32::WSAENETDOWN,
            "WSAENETUNREACH" => WIN32::WSAENETUNREACH,
            "WSAENETRESET" => WIN32::WSAENETRESET,
            "WSAECONNABORTED" => WIN32::WSAECONNABORTED,
            "WSAECONNRESET" => WIN32::WSAECONNRESET,
            "WSAENOBUFS" => WIN32::WSAENOBUFS,
            "WSAEISCONN" => WIN32::WSAEISCONN,
            "WSAENOTCONN" => WIN32::WSAENOTCONN,
            "WSAESHUTDOWN" => WIN32::WSAESHUTDOWN,
            "WSAETOOMANYREFS" => WIN32::WSAETOOMANYREFS,
            "WSAETIMEDOUT" => WIN32::WSAETIMEDOUT,
            "WSAECONNREFUSED" => WIN32::WSAECONNREFUSED,
            "WSAELOOP" => WIN32::WSAELOOP,
            "WSAENAMETOOLONG" => WIN32::WSAENAMETOOLONG,
            "WSAEHOSTDOWN" => WIN32::WSAEHOSTDOWN,
            "WSAEHOSTUNREACH" => WIN32::WSAEHOSTUNREACH,
            "WSAENOTEMPTY" => WIN32::WSAENOTEMPTY,
            "WSAEPROCLIM" => WIN32::WSAEPROCLIM,
            "WSAEUSERS" => WIN32::WSAEUSERS,
            "WSAEDQUOT" => WIN32::WSAEDQUOT,
            "WSAESTALE" => WIN32::WSAESTALE,
            "WSAEREMOTE" => WIN32::WSAEREMOTE,
            "WSASYSNOTREADY" => WIN32::WSASYSNOTREADY,
            "WSAVERNOTSUPPORTED" => WIN32::WSAVERNOTSUPPORTED,
            "WSANOTINITIALISED" => WIN32::WSANOTINITIALISED,
            "WSAEDISCON" => WIN32::WSAEDISCON,
            "WSAENOMORE" => WIN32::WSAENOMORE,
            "WSAECANCELLED" => WIN32::WSAECANCELLED,
            "WSAEINVALIDPROCTABLE" => WIN32::WSAEINVALIDPROCTABLE,
            "WSAEINVALIDPROVIDER" => WIN32::WSAEINVALIDPROVIDER,
            "WSAEPROVIDERFAILEDINIT" => WIN32::WSAEPROVIDERFAILEDINIT,
            "WSASYSCALLFAILURE" => WIN32::WSASYSCALLFAILURE,
            "WSASERVICE_NOT_FOUND" => WIN32::WSASERVICE_NOT_FOUND,
            "WSATYPE_NOT_FOUND" => WIN32::WSATYPE_NOT_FOUND,
            "WSA_E_NO_MORE" => WIN32::WSA_E_NO_MORE,
            "WSA_E_CANCELLED" => WIN32::WSA_E_CANCELLED,
            "WSAEREFUSED" => WIN32::WSAEREFUSED,
            "WSAHOST_NOT_FOUND" => WIN32::WSAHOST_NOT_FOUND,
            "WSATRY_AGAIN" => WIN32::WSATRY_AGAIN,
            "WSANO_RECOVERY" => WIN32::WSANO_RECOVERY,
            "WSANO_DATA" => WIN32::WSANO_DATA,
            "WSA_QOS_RECEIVERS" => WIN32::WSA_QOS_RECEIVERS,
            "WSA_QOS_SENDERS" => WIN32::WSA_QOS_SENDERS,
            "WSA_QOS_NO_SENDERS" => WIN32::WSA_QOS_NO_SENDERS,
            "WSA_QOS_NO_RECEIVERS" => WIN32::WSA_QOS_NO_RECEIVERS,
            "WSA_QOS_REQUEST_CONFIRMED" => WIN32::WSA_QOS_REQUEST_CONFIRMED,
            "WSA_QOS_ADMISSION_FAILURE" => WIN32::WSA_QOS_ADMISSION_FAILURE,
            "WSA_QOS_POLICY_FAILURE" => WIN32::WSA_QOS_POLICY_FAILURE,
            "WSA_QOS_BAD_STYLE" => WIN32::WSA_QOS_BAD_STYLE,
            "WSA_QOS_BAD_OBJECT" => WIN32::WSA_QOS_BAD_OBJECT,
            "WSA_QOS_TRAFFIC_CTRL_ERROR" => WIN32::WSA_QOS_TRAFFIC_CTRL_ERROR,
            "WSA_QOS_GENERIC_ERROR" => WIN32::WSA_QOS_GENERIC_ERROR,
            "WSA_QOS_ESERVICETYPE" => WIN32::WSA_QOS_ESERVICETYPE,
            "WSA_QOS_EFLOWSPEC" => WIN32::WSA_QOS_EFLOWSPEC,
            "WSA_QOS_EPROVSPECBUF" => WIN32::WSA_QOS_EPROVSPECBUF,
            "WSA_QOS_EFILTERSTYLE" => WIN32::WSA_QOS_EFILTERSTYLE,
            "WSA_QOS_EFILTERTYPE" => WIN32::WSA_QOS_EFILTERTYPE,
            "WSA_QOS_EFILTERCOUNT" => WIN32::WSA_QOS_EFILTERCOUNT,
            "WSA_QOS_EOBJLENGTH" => WIN32::WSA_QOS_EOBJLENGTH,
            "WSA_QOS_EFLOWCOUNT" => WIN32::WSA_QOS_EFLOWCOUNT,
            "WSA_QOS_EUNKOWNPSOBJ" => WIN32::WSA_QOS_EUNKOWNPSOBJ,
            "WSA_QOS_EPOLICYOBJ" => WIN32::WSA_QOS_EPOLICYOBJ,
            "WSA_QOS_EFLOWDESC" => WIN32::WSA_QOS_EFLOWDESC,
            "WSA_QOS_EPSFLOWSPEC" => WIN32::WSA_QOS_EPSFLOWSPEC,
            "WSA_QOS_EPSFILTERSPEC" => WIN32::WSA_QOS_EPSFILTERSPEC,
            "WSA_QOS_ESDMODEOBJ" => WIN32::WSA_QOS_ESDMODEOBJ,
            "WSA_QOS_ESHAPERATEOBJ" => WIN32::WSA_QOS_ESHAPERATEOBJ,
            "WSA_QOS_RESERVED_PETYPE" => WIN32::WSA_QOS_RESERVED_PETYPE,
            "WSA_SECURE_HOST_NOT_FOUND" => WIN32::WSA_SECURE_HOST_NOT_FOUND,
            "WSA_IPSEC_NAME_POLICY_ERROR" => WIN32::WSA_IPSEC_NAME_POLICY_ERROR,
            "PEER_E_CLOUD_NOT_FOUND" => WIN32::PEER_E_CLOUD_NOT_FOUND,
            "PEER_E_CLOUD_DISABLED" => WIN32::PEER_E_CLOUD_DISABLED,
            "PEER_E_INVALID_IDENTITY" => WIN32::PEER_E_INVALID_IDENTITY,
            "PEER_E_TOO_MUCH_LOAD" => WIN32::PEER_E_TOO_MUCH_LOAD,
            "PEER_E_CLOUD_IS_SEARCH_ONLY" => WIN32::PEER_E_CLOUD_IS_SEARCH_ONLY,
            "PEER_E_CLIENT_INVALID_COMPARTMENT_ID" => WIN32::PEER_E_CLIENT_INVALID_COMPARTMENT_ID,
            "PEER_E_DUPLICATE_PEER_NAME" => WIN32::PEER_E_DUPLICATE_PEER_NAME,
            "PEER_E_CLOUD_IS_DEAD" => WIN32::PEER_E_CLOUD_IS_DEAD,
            "ERROR_INTERNET_" => WIN32::ERROR_INTERNET_,
            "WININET_E_OUT_OF_HANDLES" => WIN32::WININET_E_OUT_OF_HANDLES,
            "ERROR_INTERNET_OUT_OF_HANDLES" => WIN32::ERROR_INTERNET_OUT_OF_HANDLES,
            "WININET_E_TIMEOUT" => WIN32::WININET_E_TIMEOUT,
            "ERROR_INTERNET_TIMEOUT" => WIN32::ERROR_INTERNET_TIMEOUT,
            "ERROR_WINHTTP_TIMEOUT" => WIN32::ERROR_WINHTTP_TIMEOUT,
            "WININET_E_EXTENDED_ERROR" => WIN32::WININET_E_EXTENDED_ERROR,
            "ERROR_INTERNET_EXTENDED_ERROR" => WIN32::ERROR_INTERNET_EXTENDED_ERROR,
            "WININET_E_INTERNAL_ERROR" => WIN32::WININET_E_INTERNAL_ERROR,
            "ERROR_INTERNET_INTERNAL_ERROR" => WIN32::ERROR_INTERNET_INTERNAL_ERROR,
            "ERROR_WINHTTP_INTERNAL_ERROR" => WIN32::ERROR_WINHTTP_INTERNAL_ERROR,
            "WININET_E_INVALID_URL" => WIN32::WININET_E_INVALID_URL,
            "ERROR_INTERNET_INVALID_URL" => WIN32::ERROR_INTERNET_INVALID_URL,
            "ERROR_WINHTTP_INVALID_URL" => WIN32::ERROR_WINHTTP_INVALID_URL,
            "WININET_E_UNRECOGNIZED_SCHEME" => WIN32::WININET_E_UNRECOGNIZED_SCHEME,
            "ERROR_INTERNET_UNRECOGNIZED_SCHEME" => WIN32::ERROR_INTERNET_UNRECOGNIZED_SCHEME,
            "ERROR_WINHTTP_UNRECOGNIZED_SCHEME" => WIN32::ERROR_WINHTTP_UNRECOGNIZED_SCHEME,
            "WININET_E_NAME_NOT_RESOLVED" => WIN32::WININET_E_NAME_NOT_RESOLVED,
            "ERROR_INTERNET_NAME_NOT_RESOLVED" => WIN32::ERROR_INTERNET_NAME_NOT_RESOLVED,
            "ERROR_WINHTTP_NAME_NOT_RESOLVED" => WIN32::ERROR_WINHTTP_NAME_NOT_RESOLVED,
            "WININET_E_PROTOCOL_NOT_FOUND" => WIN32::WININET_E_PROTOCOL_NOT_FOUND,
            "ERROR_INTERNET_PROTOCOL_NOT_FOUND" => WIN32::ERROR_INTERNET_PROTOCOL_NOT_FOUND,
            "WININET_E_INVALID_OPTION" => WIN32::WININET_E_INVALID_OPTION,
            "ERROR_INTERNET_INVALID_OPTION" => WIN32::ERROR_INTERNET_INVALID_OPTION,
            "ERROR_WINHTTP_INVALID_OPTION" => WIN32::ERROR_WINHTTP_INVALID_OPTION,
            "WININET_E_BAD_OPTION_LENGTH" => WIN32::WININET_E_BAD_OPTION_LENGTH,
            "ERROR_INTERNET_BAD_OPTION_LENGTH" => WIN32::ERROR_INTERNET_BAD_OPTION_LENGTH,
            "WININET_E_OPTION_NOT_SETTABLE" => WIN32::WININET_E_OPTION_NOT_SETTABLE,
            "ERROR_INTERNET_OPTION_NOT_SETTABLE" => WIN32::ERROR_INTERNET_OPTION_NOT_SETTABLE,
            "WININET_E_SHUTDOWN" => WIN32::WININET_E_SHUTDOWN,
            "ERROR_INTERNET_SHUTDOWN" => WIN32::ERROR_INTERNET_SHUTDOWN,
            "ERROR_WINHTTP_SHUTDOWN" => WIN32::ERROR_WINHTTP_SHUTDOWN,
            "WININET_E_INCORRECT_USER_NAME" => WIN32::WININET_E_INCORRECT_USER_NAME,
            "ERROR_INTERNET_INCORRECT_USER_NAME" => WIN32::ERROR_INTERNET_INCORRECT_USER_NAME,
            "WININET_E_INCORRECT_PASSWORD" => WIN32::WININET_E_INCORRECT_PASSWORD,
            "ERROR_INTERNET_INCORRECT_PASSWORD" => WIN32::ERROR_INTERNET_INCORRECT_PASSWORD,
            "WININET_E_LOGIN_FAILURE" => WIN32::WININET_E_LOGIN_FAILURE,
            "ERROR_INTERNET_LOGIN_FAILURE" => WIN32::ERROR_INTERNET_LOGIN_FAILURE,
            "ERROR_WINHTTP_LOGIN_FAILURE" => WIN32::ERROR_WINHTTP_LOGIN_FAILURE,
            "WININET_E_INVALID_OPERATION" => WIN32::WININET_E_INVALID_OPERATION,
            "ERROR_INTERNET_INVALID_OPERATION" => WIN32::ERROR_INTERNET_INVALID_OPERATION,
            "WININET_E_OPERATION_CANCELLED" => WIN32::WININET_E_OPERATION_CANCELLED,
            "ERROR_INTERNET_OPERATION_CANCELLED" => WIN32::ERROR_INTERNET_OPERATION_CANCELLED,
            "ERROR_WINHTTP_OPERATION_CANCELLED" => WIN32::ERROR_WINHTTP_OPERATION_CANCELLED,
            "WININET_E_INCORRECT_HANDLE_TYPE" => WIN32::WININET_E_INCORRECT_HANDLE_TYPE,
            "ERROR_INTERNET_INCORRECT_HANDLE_TYPE" => WIN32::ERROR_INTERNET_INCORRECT_HANDLE_TYPE,
            "WININET_E_INCORRECT_HANDLE_STATE" => WIN32::WININET_E_INCORRECT_HANDLE_STATE,
            "ERROR_INTERNET_INCORRECT_HANDLE_STATE" => WIN32::ERROR_INTERNET_INCORRECT_HANDLE_STATE,
            "ERROR_WINHTTP_INCORRECT_HANDLE_STATE" => WIN32::ERROR_WINHTTP_INCORRECT_HANDLE_STATE,
            "WININET_E_NOT_PROXY_REQUEST" => WIN32::WININET_E_NOT_PROXY_REQUEST,
            "ERROR_INTERNET_NOT_PROXY_REQUEST" => WIN32::ERROR_INTERNET_NOT_PROXY_REQUEST,
            "WININET_E_REGISTRY_VALUE_NOT_FOUND" => WIN32::WININET_E_REGISTRY_VALUE_NOT_FOUND,
            "ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND" => WIN32::ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND,
            "WININET_E_BAD_REGISTRY_PARAMETER" => WIN32::WININET_E_BAD_REGISTRY_PARAMETER,
            "ERROR_INTERNET_BAD_REGISTRY_PARAMETER" => WIN32::ERROR_INTERNET_BAD_REGISTRY_PARAMETER,
            "WININET_E_NO_DIRECT_ACCESS" => WIN32::WININET_E_NO_DIRECT_ACCESS,
            "ERROR_INTERNET_NO_DIRECT_ACCESS" => WIN32::ERROR_INTERNET_NO_DIRECT_ACCESS,
            "WININET_E_NO_CONTEXT" => WIN32::WININET_E_NO_CONTEXT,
            "ERROR_INTERNET_NO_CONTEXT" => WIN32::ERROR_INTERNET_NO_CONTEXT,
            "WININET_E_NO_CALLBACK" => WIN32::WININET_E_NO_CALLBACK,
            "ERROR_INTERNET_NO_CALLBACK" => WIN32::ERROR_INTERNET_NO_CALLBACK,
            "WININET_E_REQUEST_PENDING" => WIN32::WININET_E_REQUEST_PENDING,
            "ERROR_INTERNET_REQUEST_PENDING" => WIN32::ERROR_INTERNET_REQUEST_PENDING,
            "WININET_E_INCORRECT_FORMAT" => WIN32::WININET_E_INCORRECT_FORMAT,
            "ERROR_INTERNET_INCORRECT_FORMAT" => WIN32::ERROR_INTERNET_INCORRECT_FORMAT,
            "WININET_E_ITEM_NOT_FOUND" => WIN32::WININET_E_ITEM_NOT_FOUND,
            "ERROR_INTERNET_ITEM_NOT_FOUND" => WIN32::ERROR_INTERNET_ITEM_NOT_FOUND,
            "WININET_E_CANNOT_CONNECT" => WIN32::WININET_E_CANNOT_CONNECT,
            "ERROR_INTERNET_CANNOT_CONNECT" => WIN32::ERROR_INTERNET_CANNOT_CONNECT,
            "ERROR_WINHTTP_CANNOT_CONNECT" => WIN32::ERROR_WINHTTP_CANNOT_CONNECT,
            "WININET_E_CONNECTION_ABORTED" => WIN32::WININET_E_CONNECTION_ABORTED,
            "ERROR_INTERNET_CONNECTION_ABORTED" => WIN32::ERROR_INTERNET_CONNECTION_ABORTED,
            "ERROR_WINHTTP_CONNECTION_ABORTED" => WIN32::ERROR_WINHTTP_CONNECTION_ABORTED,
            "WININET_E_CONNECTION_RESET" => WIN32::WININET_E_CONNECTION_RESET,
            "ERROR_INTERNET_CONNECTION_RESET" => WIN32::ERROR_INTERNET_CONNECTION_RESET,
            "ERROR_WINHTTP_CONNECTION_RESET" => WIN32::ERROR_WINHTTP_CONNECTION_RESET,
            "WININET_E_FORCE_RETRY" => WIN32::WININET_E_FORCE_RETRY,
            "ERROR_INTERNET_FORCE_RETRY" => WIN32::ERROR_INTERNET_FORCE_RETRY,
            "WININET_E_INVALID_PROXY_REQUEST" => WIN32::WININET_E_INVALID_PROXY_REQUEST,
            "ERROR_INTERNET_INVALID_PROXY_REQUEST" => WIN32::ERROR_INTERNET_INVALID_PROXY_REQUEST,
            "WININET_E_NEED_UI" => WIN32::WININET_E_NEED_UI,
            "ERROR_INTERNET_NEED_UI" => WIN32::ERROR_INTERNET_NEED_UI,
            "WININET_E_HANDLE_EXISTS" => WIN32::WININET_E_HANDLE_EXISTS,
            "ERROR_INTERNET_HANDLE_EXISTS" => WIN32::ERROR_INTERNET_HANDLE_EXISTS,
            "WININET_E_SEC_CERT_DATE_INVALID" => WIN32::WININET_E_SEC_CERT_DATE_INVALID,
            "ERROR_INTERNET_SEC_CERT_DATE_INVALID" => WIN32::ERROR_INTERNET_SEC_CERT_DATE_INVALID,
            "ERROR_WINHTTP_SEC_CERT_DATE_INVALID" => WIN32::ERROR_WINHTTP_SEC_CERT_DATE_INVALID,
            "WININET_E_SEC_CERT_CN_INVALID" => WIN32::WININET_E_SEC_CERT_CN_INVALID,
            "ERROR_INTERNET_SEC_CERT_CN_INVALID" => WIN32::ERROR_INTERNET_SEC_CERT_CN_INVALID,
            "ERROR_WINHTTP_SEC_CERT_CN_INVALID" => WIN32::ERROR_WINHTTP_SEC_CERT_CN_INVALID,
            "WININET_E_HTTP_TO_HTTPS_ON_REDIR" => WIN32::WININET_E_HTTP_TO_HTTPS_ON_REDIR,
            "ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR" => WIN32::ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR,
            "WININET_E_HTTPS_TO_HTTP_ON_REDIR" => WIN32::WININET_E_HTTPS_TO_HTTP_ON_REDIR,
            "ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR" => WIN32::ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR,
            "WININET_E_MIXED_SECURITY" => WIN32::WININET_E_MIXED_SECURITY,
            "ERROR_INTERNET_MIXED_SECURITY" => WIN32::ERROR_INTERNET_MIXED_SECURITY,
            "WININET_E_CHG_POST_IS_NON_SECURE" => WIN32::WININET_E_CHG_POST_IS_NON_SECURE,
            "ERROR_INTERNET_CHG_POST_IS_NON_SECURE" => WIN32::ERROR_INTERNET_CHG_POST_IS_NON_SECURE,
            "WININET_E_POST_IS_NON_SECURE" => WIN32::WININET_E_POST_IS_NON_SECURE,
            "ERROR_INTERNET_POST_IS_NON_SECURE" => WIN32::ERROR_INTERNET_POST_IS_NON_SECURE,
            "WININET_E_CLIENT_AUTH_CERT_NEEDED" => WIN32::WININET_E_CLIENT_AUTH_CERT_NEEDED,
            "ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED" => WIN32::ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED,
            "ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED" => WIN32::ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED,
            "WININET_E_INVALID_CA" => WIN32::WININET_E_INVALID_CA,
            "ERROR_INTERNET_INVALID_CA" => WIN32::ERROR_INTERNET_INVALID_CA,
            "ERROR_WINHTTP_INVALID_CA" => WIN32::ERROR_WINHTTP_INVALID_CA,
            "WININET_E_CLIENT_AUTH_NOT_SETUP" => WIN32::WININET_E_CLIENT_AUTH_NOT_SETUP,
            "ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP" => WIN32::ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP,
            "WININET_E_ASYNC_THREAD_FAILED" => WIN32::WININET_E_ASYNC_THREAD_FAILED,
            "ERROR_INTERNET_ASYNC_THREAD_FAILED" => WIN32::ERROR_INTERNET_ASYNC_THREAD_FAILED,
            "WININET_E_REDIRECT_SCHEME_CHANGE" => WIN32::WININET_E_REDIRECT_SCHEME_CHANGE,
            "ERROR_INTERNET_REDIRECT_SCHEME_CHANGE" => WIN32::ERROR_INTERNET_REDIRECT_SCHEME_CHANGE,
            "WININET_E_DIALOG_PENDING" => WIN32::WININET_E_DIALOG_PENDING,
            "ERROR_INTERNET_DIALOG_PENDING" => WIN32::ERROR_INTERNET_DIALOG_PENDING,
            "WININET_E_RETRY_DIALOG" => WIN32::WININET_E_RETRY_DIALOG,
            "ERROR_INTERNET_RETRY_DIALOG" => WIN32::ERROR_INTERNET_RETRY_DIALOG,
            "WININET_E_NO_NEW_CONTAINERS" => WIN32::WININET_E_NO_NEW_CONTAINERS,
            "WININET_E_HTTPS_HTTP_SUBMIT_REDIR" => WIN32::WININET_E_HTTPS_HTTP_SUBMIT_REDIR,
            "ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR" => WIN32::ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR,
            "ERROR_INTERNET_INSERT_CDROM" => WIN32::ERROR_INTERNET_INSERT_CDROM,
            "ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED" => WIN32::ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED,
            "WININET_E_SEC_CERT_ERRORS" => WIN32::WININET_E_SEC_CERT_ERRORS,
            "ERROR_INTERNET_SEC_CERT_ERRORS" => WIN32::ERROR_INTERNET_SEC_CERT_ERRORS,
            "ERROR_INTERNET_SEC_CERT_NO_REV" => WIN32::ERROR_INTERNET_SEC_CERT_NO_REV,
            "WININET_E_SEC_CERT_REV_FAILED" => WIN32::WININET_E_SEC_CERT_REV_FAILED,
            "ERROR_INTERNET_SEC_CERT_REV_FAILED" => WIN32::ERROR_INTERNET_SEC_CERT_REV_FAILED,
            "ERROR_WINHTTP_NO_CM_CONNECTION" => WIN32::ERROR_WINHTTP_NO_CM_CONNECTION,
            "ERROR_FTP_TRANSFER_IN_PROGRESS" => WIN32::ERROR_FTP_TRANSFER_IN_PROGRESS,
            "ERROR_FTP_DROPPED" => WIN32::ERROR_FTP_DROPPED,
            "ERROR_FTP_NO_PASSIVE_MODE" => WIN32::ERROR_FTP_NO_PASSIVE_MODE,
            "ERROR_GOPHER_PROTOCOL_ERROR" => WIN32::ERROR_GOPHER_PROTOCOL_ERROR,
            "ERROR_GOPHER_NOT_FILE" => WIN32::ERROR_GOPHER_NOT_FILE,
            "ERROR_GOPHER_DATA_ERROR" => WIN32::ERROR_GOPHER_DATA_ERROR,
            "ERROR_GOPHER_END_OF_DATA" => WIN32::ERROR_GOPHER_END_OF_DATA,
            "ERROR_GOPHER_INVALID_LOCATOR" => WIN32::ERROR_GOPHER_INVALID_LOCATOR,
            "ERROR_GOPHER_INCORRECT_LOCATOR_TYPE" => WIN32::ERROR_GOPHER_INCORRECT_LOCATOR_TYPE,
            "ERROR_GOPHER_NOT_GOPHER_PLUS" => WIN32::ERROR_GOPHER_NOT_GOPHER_PLUS,
            "ERROR_GOPHER_ATTRIBUTE_NOT_FOUND" => WIN32::ERROR_GOPHER_ATTRIBUTE_NOT_FOUND,
            "ERROR_GOPHER_UNKNOWN_LOCATOR" => WIN32::ERROR_GOPHER_UNKNOWN_LOCATOR,
            "WININET_E_HEADER_NOT_FOUND" => WIN32::WININET_E_HEADER_NOT_FOUND,
            "ERROR_HTTP_HEADER_NOT_FOUND" => WIN32::ERROR_HTTP_HEADER_NOT_FOUND,
            "ERROR_WINHTTP_HEADER_NOT_FOUND" => WIN32::ERROR_WINHTTP_HEADER_NOT_FOUND,
            "WININET_E_DOWNLEVEL_SERVER" => WIN32::WININET_E_DOWNLEVEL_SERVER,
            "ERROR_HTTP_DOWNLEVEL_SERVER" => WIN32::ERROR_HTTP_DOWNLEVEL_SERVER,
            "WININET_E_INVALID_SERVER_RESPONSE" => WIN32::WININET_E_INVALID_SERVER_RESPONSE,
            "ERROR_HTTP_INVALID_SERVER_RESPONSE" => WIN32::ERROR_HTTP_INVALID_SERVER_RESPONSE,
            "ERROR_WINHTTP_INVALID_SERVER_RESPONSE" => WIN32::ERROR_WINHTTP_INVALID_SERVER_RESPONSE,
            "WININET_E_INVALID_HEADER" => WIN32::WININET_E_INVALID_HEADER,
            "ERROR_HTTP_INVALID_HEADER" => WIN32::ERROR_HTTP_INVALID_HEADER,
            "WININET_E_INVALID_QUERY_REQUEST" => WIN32::WININET_E_INVALID_QUERY_REQUEST,
            "ERROR_HTTP_INVALID_QUERY_REQUEST" => WIN32::ERROR_HTTP_INVALID_QUERY_REQUEST,
            "ERROR_WINHTTP_INVALID_QUERY_REQUEST" => WIN32::ERROR_WINHTTP_INVALID_QUERY_REQUEST,
            "WININET_E_HEADER_ALREADY_EXISTS" => WIN32::WININET_E_HEADER_ALREADY_EXISTS,
            "ERROR_HTTP_HEADER_ALREADY_EXISTS" => WIN32::ERROR_HTTP_HEADER_ALREADY_EXISTS,
            "WININET_E_REDIRECT_FAILED" => WIN32::WININET_E_REDIRECT_FAILED,
            "ERROR_HTTP_REDIRECT_FAILED" => WIN32::ERROR_HTTP_REDIRECT_FAILED,
            "ERROR_WINHTTP_REDIRECT_FAILED" => WIN32::ERROR_WINHTTP_REDIRECT_FAILED,
            "WININET_E_SECURITY_CHANNEL_ERROR" => WIN32::WININET_E_SECURITY_CHANNEL_ERROR,
            "ERROR_INTERNET_SECURITY_CHANNEL_ERROR" => WIN32::ERROR_INTERNET_SECURITY_CHANNEL_ERROR,
            "ERROR_WINHTTP_SECURE_CHANNEL_ERROR" => WIN32::ERROR_WINHTTP_SECURE_CHANNEL_ERROR,
            "WININET_E_UNABLE_TO_CACHE_FILE" => WIN32::WININET_E_UNABLE_TO_CACHE_FILE,
            "ERROR_INTERNET_UNABLE_TO_CACHE_FILE" => WIN32::ERROR_INTERNET_UNABLE_TO_CACHE_FILE,
            "WININET_E_TCPIP_NOT_INSTALLED" => WIN32::WININET_E_TCPIP_NOT_INSTALLED,
            "ERROR_INTERNET_TCPIP_NOT_INSTALLED" => WIN32::ERROR_INTERNET_TCPIP_NOT_INSTALLED,
            "WININET_E_NOT_REDIRECTED" => WIN32::WININET_E_NOT_REDIRECTED,
            "ERROR_HTTP_NOT_REDIRECTED" => WIN32::ERROR_HTTP_NOT_REDIRECTED,
            "WININET_E_COOKIE_NEEDS_CONFIRMATION" => WIN32::WININET_E_COOKIE_NEEDS_CONFIRMATION,
            "ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION" => WIN32::ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION,
            "WININET_E_COOKIE_DECLINED" => WIN32::WININET_E_COOKIE_DECLINED,
            "ERROR_HTTP_COOKIE_DECLINED" => WIN32::ERROR_HTTP_COOKIE_DECLINED,
            "WININET_E_DISCONNECTED" => WIN32::WININET_E_DISCONNECTED,
            "ERROR_INTERNET_DISCONNECTED" => WIN32::ERROR_INTERNET_DISCONNECTED,
            "WININET_E_SERVER_UNREACHABLE" => WIN32::WININET_E_SERVER_UNREACHABLE,
            "ERROR_INTERNET_SERVER_UNREACHABLE" => WIN32::ERROR_INTERNET_SERVER_UNREACHABLE,
            "WININET_E_PROXY_SERVER_UNREACHABLE" => WIN32::WININET_E_PROXY_SERVER_UNREACHABLE,
            "ERROR_INTERNET_PROXY_SERVER_UNREACHABLE" => WIN32::ERROR_INTERNET_PROXY_SERVER_UNREACHABLE,
            "WININET_E_BAD_AUTO_PROXY_SCRIPT" => WIN32::WININET_E_BAD_AUTO_PROXY_SCRIPT,
            "ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT" => WIN32::ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT,
            "WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT" => WIN32::WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT,
            "ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT" => WIN32::ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT,
            "WININET_E_REDIRECT_NEEDS_CONFIRMATION" => WIN32::WININET_E_REDIRECT_NEEDS_CONFIRMATION,
            "ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION" => WIN32::ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION,
            "WININET_E_SEC_INVALID_CERT" => WIN32::WININET_E_SEC_INVALID_CERT,
            "ERROR_INTERNET_SEC_INVALID_CERT" => WIN32::ERROR_INTERNET_SEC_INVALID_CERT,
            "ERROR_WINHTTP_SECURE_INVALID_CERT" => WIN32::ERROR_WINHTTP_SECURE_INVALID_CERT,
            "WININET_E_SEC_CERT_REVOKED" => WIN32::WININET_E_SEC_CERT_REVOKED,
            "ERROR_INTERNET_SEC_CERT_REVOKED" => WIN32::ERROR_INTERNET_SEC_CERT_REVOKED,
            "WININET_E_FAILED_DUETOSECURITYCHECK" => WIN32::WININET_E_FAILED_DUETOSECURITYCHECK,
            "ERROR_INTERNET_FAILED_DUETOSECURITYCHECK" => WIN32::ERROR_INTERNET_FAILED_DUETOSECURITYCHECK,
            "WININET_E_NOT_INITIALIZED" => WIN32::WININET_E_NOT_INITIALIZED,
            "ERROR_INTERNET_NOT_INITIALIZED" => WIN32::ERROR_INTERNET_NOT_INITIALIZED,
            "ERROR_INTERNET_NEED_MSN_SSPI_PKG" => WIN32::ERROR_INTERNET_NEED_MSN_SSPI_PKG,
            "WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY" => WIN32::WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY,
            "ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY" => WIN32::ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY,
            "WININET_E_DECODING_FAILED" => WIN32::WININET_E_DECODING_FAILED,
            "ERROR_INTERNET_DECODING_FAILED" => WIN32::ERROR_INTERNET_DECODING_FAILED,
            "ERROR_WINHTTP_SECURE_FAILURE" => WIN32::ERROR_WINHTTP_SECURE_FAILURE,
            "ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW" => WIN32::ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW,
            "ERROR_IPSEC_QM_POLICY_EXISTS" => WIN32::ERROR_IPSEC_QM_POLICY_EXISTS,
            "ERROR_IPSEC_QM_POLICY_NOT_FOUND" => WIN32::ERROR_IPSEC_QM_POLICY_NOT_FOUND,
            "ERROR_IPSEC_QM_POLICY_IN_USE" => WIN32::ERROR_IPSEC_QM_POLICY_IN_USE,
            "ERROR_IPSEC_MM_POLICY_EXISTS" => WIN32::ERROR_IPSEC_MM_POLICY_EXISTS,
            "ERROR_IPSEC_MM_POLICY_NOT_FOUND" => WIN32::ERROR_IPSEC_MM_POLICY_NOT_FOUND,
            "ERROR_IPSEC_MM_POLICY_IN_USE" => WIN32::ERROR_IPSEC_MM_POLICY_IN_USE,
            "ERROR_IPSEC_MM_FILTER_EXISTS" => WIN32::ERROR_IPSEC_MM_FILTER_EXISTS,
            "ERROR_IPSEC_MM_FILTER_NOT_FOUND" => WIN32::ERROR_IPSEC_MM_FILTER_NOT_FOUND,
            "ERROR_IPSEC_TRANSPORT_FILTER_EXISTS" => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_EXISTS,
            "ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND" => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND,
            "ERROR_IPSEC_MM_AUTH_EXISTS" => WIN32::ERROR_IPSEC_MM_AUTH_EXISTS,
            "ERROR_IPSEC_MM_AUTH_NOT_FOUND" => WIN32::ERROR_IPSEC_MM_AUTH_NOT_FOUND,
            "ERROR_IPSEC_MM_AUTH_IN_USE" => WIN32::ERROR_IPSEC_MM_AUTH_IN_USE,
            "ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND" => WIN32::ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND,
            "ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND" => WIN32::ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND,
            "ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND" => WIN32::ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND,
            "ERROR_IPSEC_TUNNEL_FILTER_EXISTS" => WIN32::ERROR_IPSEC_TUNNEL_FILTER_EXISTS,
            "ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND" => WIN32::ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND,
            "ERROR_IPSEC_MM_FILTER_PENDING_DELETION" => WIN32::ERROR_IPSEC_MM_FILTER_PENDING_DELETION,
            "ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION" => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION,
            "ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION" => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION,
            "ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION" => WIN32::ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION,
            "ERROR_IPSEC_MM_POLICY_PENDING_DELETION" => WIN32::ERROR_IPSEC_MM_POLICY_PENDING_DELETION,
            "ERROR_IPSEC_MM_POLICY_PENDING_ELETION" => WIN32::ERROR_IPSEC_MM_POLICY_PENDING_ELETION,
            "ERROR_IPSEC_MM_AUTH_PENDING_DELETION" => WIN32::ERROR_IPSEC_MM_AUTH_PENDING_DELETION,
            "ERROR_IPSEC_QM_POLICY_PENDING_DELETION" => WIN32::ERROR_IPSEC_QM_POLICY_PENDING_DELETION,
            "WARNING_IPSEC_MM_POLICY_PRUNED" => WIN32::WARNING_IPSEC_MM_POLICY_PRUNED,
            "WARNING_IPSEC_QM_POLICY_PRUNED" => WIN32::WARNING_IPSEC_QM_POLICY_PRUNED,
            "ERROR_IPSEC_IKE_NEG_STATUS_BEGIN" => WIN32::ERROR_IPSEC_IKE_NEG_STATUS_BEGIN,
            "ERROR_IPSEC_IKE_AUTH_FAIL" => WIN32::ERROR_IPSEC_IKE_AUTH_FAIL,
            "ERROR_IPSEC_IKE_ATTRIB_FAIL" => WIN32::ERROR_IPSEC_IKE_ATTRIB_FAIL,
            "ERROR_IPSEC_IKE_NEGOTIATION_PENDING" => WIN32::ERROR_IPSEC_IKE_NEGOTIATION_PENDING,
            "ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR" => WIN32::ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR,
            "ERROR_IPSEC_IKE_TIMED_OUT" => WIN32::ERROR_IPSEC_IKE_TIMED_OUT,
            "ERROR_IPSEC_IKE_NO_CERT" => WIN32::ERROR_IPSEC_IKE_NO_CERT,
            "ERROR_IPSEC_IKE_SA_DELETED" => WIN32::ERROR_IPSEC_IKE_SA_DELETED,
            "ERROR_IPSEC_IKE_SA_REAPED" => WIN32::ERROR_IPSEC_IKE_SA_REAPED,
            "ERROR_IPSEC_IKE_MM_ACQUIRE_DROP" => WIN32::ERROR_IPSEC_IKE_MM_ACQUIRE_DROP,
            "ERROR_IPSEC_IKE_QM_ACQUIRE_DROP" => WIN32::ERROR_IPSEC_IKE_QM_ACQUIRE_DROP,
            "ERROR_IPSEC_IKE_QUEUE_DROP_MM" => WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_MM,
            "ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM" => WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM,
            "ERROR_IPSEC_IKE_DROP_NO_RESPONSE" => WIN32::ERROR_IPSEC_IKE_DROP_NO_RESPONSE,
            "ERROR_IPSEC_IKE_MM_DELAY_DROP" => WIN32::ERROR_IPSEC_IKE_MM_DELAY_DROP,
            "ERROR_IPSEC_IKE_QM_DELAY_DROP" => WIN32::ERROR_IPSEC_IKE_QM_DELAY_DROP,
            "ERROR_IPSEC_IKE_ERROR" => WIN32::ERROR_IPSEC_IKE_ERROR,
            "ERROR_IPSEC_IKE_CRL_FAILED" => WIN32::ERROR_IPSEC_IKE_CRL_FAILED,
            "ERROR_IPSEC_IKE_INVALID_KEY_USAGE" => WIN32::ERROR_IPSEC_IKE_INVALID_KEY_USAGE,
            "ERROR_IPSEC_IKE_INVALID_CERT_TYPE" => WIN32::ERROR_IPSEC_IKE_INVALID_CERT_TYPE,
            "ERROR_IPSEC_IKE_NO_PRIVATE_KEY" => WIN32::ERROR_IPSEC_IKE_NO_PRIVATE_KEY,
            "ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY" => WIN32::ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY,
            "ERROR_IPSEC_IKE_DH_FAIL" => WIN32::ERROR_IPSEC_IKE_DH_FAIL,
            "ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED" => WIN32::ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED,
            "ERROR_IPSEC_IKE_INVALID_HEADER" => WIN32::ERROR_IPSEC_IKE_INVALID_HEADER,
            "ERROR_IPSEC_IKE_NO_POLICY" => WIN32::ERROR_IPSEC_IKE_NO_POLICY,
            "ERROR_IPSEC_IKE_INVALID_SIGNATURE" => WIN32::ERROR_IPSEC_IKE_INVALID_SIGNATURE,
            "ERROR_IPSEC_IKE_KERBEROS_ERROR" => WIN32::ERROR_IPSEC_IKE_KERBEROS_ERROR,
            "ERROR_IPSEC_IKE_NO_PUBLIC_KEY" => WIN32::ERROR_IPSEC_IKE_NO_PUBLIC_KEY,
            "ERROR_IPSEC_IKE_PROCESS_ERR" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR,
            "ERROR_IPSEC_IKE_PROCESS_ERR_SA" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SA,
            "ERROR_IPSEC_IKE_PROCESS_ERR_PROP" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_PROP,
            "ERROR_IPSEC_IKE_PROCESS_ERR_TRANS" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_TRANS,
            "ERROR_IPSEC_IKE_PROCESS_ERR_KE" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_KE,
            "ERROR_IPSEC_IKE_PROCESS_ERR_ID" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_ID,
            "ERROR_IPSEC_IKE_PROCESS_ERR_CERT" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT,
            "ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ,
            "ERROR_IPSEC_IKE_PROCESS_ERR_HASH" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_HASH,
            "ERROR_IPSEC_IKE_PROCESS_ERR_SIG" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SIG,
            "ERROR_IPSEC_IKE_PROCESS_ERR_NONCE" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NONCE,
            "ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY,
            "ERROR_IPSEC_IKE_PROCESS_ERR_DELETE" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_DELETE,
            "ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR,
            "ERROR_IPSEC_IKE_INVALID_PAYLOAD" => WIN32::ERROR_IPSEC_IKE_INVALID_PAYLOAD,
            "ERROR_IPSEC_IKE_LOAD_SOFT_SA" => WIN32::ERROR_IPSEC_IKE_LOAD_SOFT_SA,
            "ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN" => WIN32::ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN,
            "ERROR_IPSEC_IKE_INVALID_COOKIE" => WIN32::ERROR_IPSEC_IKE_INVALID_COOKIE,
            "ERROR_IPSEC_IKE_NO_PEER_CERT" => WIN32::ERROR_IPSEC_IKE_NO_PEER_CERT,
            "ERROR_IPSEC_IKE_PEER_CRL_FAILED" => WIN32::ERROR_IPSEC_IKE_PEER_CRL_FAILED,
            "ERROR_IPSEC_IKE_POLICY_CHANGE" => WIN32::ERROR_IPSEC_IKE_POLICY_CHANGE,
            "ERROR_IPSEC_IKE_NO_MM_POLICY" => WIN32::ERROR_IPSEC_IKE_NO_MM_POLICY,
            "ERROR_IPSEC_IKE_NOTCBPRIV" => WIN32::ERROR_IPSEC_IKE_NOTCBPRIV,
            "ERROR_IPSEC_IKE_SECLOADFAIL" => WIN32::ERROR_IPSEC_IKE_SECLOADFAIL,
            "ERROR_IPSEC_IKE_FAILSSPINIT" => WIN32::ERROR_IPSEC_IKE_FAILSSPINIT,
            "ERROR_IPSEC_IKE_FAILQUERYSSP" => WIN32::ERROR_IPSEC_IKE_FAILQUERYSSP,
            "ERROR_IPSEC_IKE_SRVACQFAIL" => WIN32::ERROR_IPSEC_IKE_SRVACQFAIL,
            "ERROR_IPSEC_IKE_SRVQUERYCRED" => WIN32::ERROR_IPSEC_IKE_SRVQUERYCRED,
            "ERROR_IPSEC_IKE_GETSPIFAIL" => WIN32::ERROR_IPSEC_IKE_GETSPIFAIL,
            "ERROR_IPSEC_IKE_INVALID_FILTER" => WIN32::ERROR_IPSEC_IKE_INVALID_FILTER,
            "ERROR_IPSEC_IKE_OUT_OF_MEMORY" => WIN32::ERROR_IPSEC_IKE_OUT_OF_MEMORY,
            "ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED" => WIN32::ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED,
            "ERROR_IPSEC_IKE_INVALID_POLICY" => WIN32::ERROR_IPSEC_IKE_INVALID_POLICY,
            "ERROR_IPSEC_IKE_UNKNOWN_DOI" => WIN32::ERROR_IPSEC_IKE_UNKNOWN_DOI,
            "ERROR_IPSEC_IKE_INVALID_SITUATION" => WIN32::ERROR_IPSEC_IKE_INVALID_SITUATION,
            "ERROR_IPSEC_IKE_DH_FAILURE" => WIN32::ERROR_IPSEC_IKE_DH_FAILURE,
            "ERROR_IPSEC_IKE_INVALID_GROUP" => WIN32::ERROR_IPSEC_IKE_INVALID_GROUP,
            "ERROR_IPSEC_IKE_ENCRYPT" => WIN32::ERROR_IPSEC_IKE_ENCRYPT,
            "ERROR_IPSEC_IKE_DECRYPT" => WIN32::ERROR_IPSEC_IKE_DECRYPT,
            "ERROR_IPSEC_IKE_POLICY_MATCH" => WIN32::ERROR_IPSEC_IKE_POLICY_MATCH,
            "ERROR_IPSEC_IKE_UNSUPPORTED_ID" => WIN32::ERROR_IPSEC_IKE_UNSUPPORTED_ID,
            "ERROR_IPSEC_IKE_INVALID_HASH" => WIN32::ERROR_IPSEC_IKE_INVALID_HASH,
            "ERROR_IPSEC_IKE_INVALID_HASH_ALG" => WIN32::ERROR_IPSEC_IKE_INVALID_HASH_ALG,
            "ERROR_IPSEC_IKE_INVALID_HASH_SIZE" => WIN32::ERROR_IPSEC_IKE_INVALID_HASH_SIZE,
            "ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG" => WIN32::ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG,
            "ERROR_IPSEC_IKE_INVALID_AUTH_ALG" => WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_ALG,
            "ERROR_IPSEC_IKE_INVALID_SIG" => WIN32::ERROR_IPSEC_IKE_INVALID_SIG,
            "ERROR_IPSEC_IKE_LOAD_FAILED" => WIN32::ERROR_IPSEC_IKE_LOAD_FAILED,
            "ERROR_IPSEC_IKE_RPC_DELETE" => WIN32::ERROR_IPSEC_IKE_RPC_DELETE,
            "ERROR_IPSEC_IKE_BENIGN_REINIT" => WIN32::ERROR_IPSEC_IKE_BENIGN_REINIT,
            "ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY" => WIN32::ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY,
            "ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION" => WIN32::ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION,
            "ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN" => WIN32::ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN,
            "ERROR_IPSEC_IKE_MM_LIMIT" => WIN32::ERROR_IPSEC_IKE_MM_LIMIT,
            "ERROR_IPSEC_IKE_NEGOTIATION_DISABLED" => WIN32::ERROR_IPSEC_IKE_NEGOTIATION_DISABLED,
            "ERROR_IPSEC_IKE_QM_LIMIT" => WIN32::ERROR_IPSEC_IKE_QM_LIMIT,
            "ERROR_IPSEC_IKE_MM_EXPIRED" => WIN32::ERROR_IPSEC_IKE_MM_EXPIRED,
            "ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID" => WIN32::ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID,
            "ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH" => WIN32::ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH,
            "ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID" => WIN32::ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID,
            "ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD" => WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD,
            "ERROR_IPSEC_IKE_INVALID_UMATTS" => WIN32::ERROR_IPSEC_IKE_INVALID_UMATTS,
            "ERROR_IPSEC_IKE_DOS_COOKIE_SENT" => WIN32::ERROR_IPSEC_IKE_DOS_COOKIE_SENT,
            "ERROR_IPSEC_IKE_SHUTTING_DOWN" => WIN32::ERROR_IPSEC_IKE_SHUTTING_DOWN,
            "ERROR_IPSEC_IKE_CGA_AUTH_FAILED" => WIN32::ERROR_IPSEC_IKE_CGA_AUTH_FAILED,
            "ERROR_IPSEC_IKE_PROCESS_ERR_NATOA" => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NATOA,
            "ERROR_IPSEC_IKE_INVALID_MM_FOR_QM" => WIN32::ERROR_IPSEC_IKE_INVALID_MM_FOR_QM,
            "ERROR_IPSEC_IKE_QM_EXPIRED" => WIN32::ERROR_IPSEC_IKE_QM_EXPIRED,
            "ERROR_IPSEC_IKE_TOO_MANY_FILTERS" => WIN32::ERROR_IPSEC_IKE_TOO_MANY_FILTERS,
            "ERROR_IPSEC_IKE_NEG_STATUS_END" => WIN32::ERROR_IPSEC_IKE_NEG_STATUS_END,
            "ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL" => WIN32::ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL,
            "ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE" => WIN32::ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE,
            "ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING" => WIN32::ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING,
            "ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING" => WIN32::ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING,
            "ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS" => WIN32::ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS,
            "ERROR_IPSEC_IKE_RATELIMIT_DROP" => WIN32::ERROR_IPSEC_IKE_RATELIMIT_DROP,
            "ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE" => WIN32::ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE,
            "ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE" => WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE,
            "ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE" => WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE,
            "ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY" => WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY,
            "ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE" => WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE,
            "ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END" => WIN32::ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END,
            "ERROR_IPSEC_BAD_SPI" => WIN32::ERROR_IPSEC_BAD_SPI,
            "ERROR_IPSEC_SA_LIFETIME_EXPIRED" => WIN32::ERROR_IPSEC_SA_LIFETIME_EXPIRED,
            "ERROR_IPSEC_WRONG_SA" => WIN32::ERROR_IPSEC_WRONG_SA,
            "ERROR_IPSEC_REPLAY_CHECK_FAILED" => WIN32::ERROR_IPSEC_REPLAY_CHECK_FAILED,
            "ERROR_IPSEC_INVALID_PACKET" => WIN32::ERROR_IPSEC_INVALID_PACKET,
            "ERROR_IPSEC_INTEGRITY_CHECK_FAILED" => WIN32::ERROR_IPSEC_INTEGRITY_CHECK_FAILED,
            "ERROR_IPSEC_CLEAR_TEXT_DROP" => WIN32::ERROR_IPSEC_CLEAR_TEXT_DROP,
            "ERROR_IPSEC_AUTH_FIREWALL_DROP" => WIN32::ERROR_IPSEC_AUTH_FIREWALL_DROP,
            "ERROR_IPSEC_THROTTLE_DROP" => WIN32::ERROR_IPSEC_THROTTLE_DROP,
            "ERROR_IPSEC_DOSP_BLOCK" => WIN32::ERROR_IPSEC_DOSP_BLOCK,
            "ERROR_IPSEC_DOSP_RECEIVED_MULTICAST" => WIN32::ERROR_IPSEC_DOSP_RECEIVED_MULTICAST,
            "ERROR_IPSEC_DOSP_INVALID_PACKET" => WIN32::ERROR_IPSEC_DOSP_INVALID_PACKET,
            "ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED" => WIN32::ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED,
            "ERROR_IPSEC_DOSP_MAX_ENTRIES" => WIN32::ERROR_IPSEC_DOSP_MAX_ENTRIES,
            "ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED" => WIN32::ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED,
            "ERROR_IPSEC_DOSP_NOT_INSTALLED" => WIN32::ERROR_IPSEC_DOSP_NOT_INSTALLED,
            "ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES" => WIN32::ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES,
            "ERROR_SXS_SECTION_NOT_FOUND" => WIN32::ERROR_SXS_SECTION_NOT_FOUND,
            "ERROR_SXS_CANT_GEN_ACTCTX" => WIN32::ERROR_SXS_CANT_GEN_ACTCTX,
            "ERROR_SXS_INVALID_ACTCTXDATA_FORMAT" => WIN32::ERROR_SXS_INVALID_ACTCTXDATA_FORMAT,
            "ERROR_SXS_ASSEMBLY_NOT_FOUND" => WIN32::ERROR_SXS_ASSEMBLY_NOT_FOUND,
            "ERROR_SXS_MANIFEST_FORMAT_ERROR" => WIN32::ERROR_SXS_MANIFEST_FORMAT_ERROR,
            "ERROR_SXS_MANIFEST_PARSE_ERROR" => WIN32::ERROR_SXS_MANIFEST_PARSE_ERROR,
            "ERROR_SXS_ACTIVATION_CONTEXT_DISABLED" => WIN32::ERROR_SXS_ACTIVATION_CONTEXT_DISABLED,
            "ERROR_SXS_KEY_NOT_FOUND" => WIN32::ERROR_SXS_KEY_NOT_FOUND,
            "ERROR_SXS_VERSION_CONFLICT" => WIN32::ERROR_SXS_VERSION_CONFLICT,
            "ERROR_SXS_WRONG_SECTION_TYPE" => WIN32::ERROR_SXS_WRONG_SECTION_TYPE,
            "ERROR_SXS_THREAD_QUERIES_DISABLED" => WIN32::ERROR_SXS_THREAD_QUERIES_DISABLED,
            "ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET" => WIN32::ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET,
            "ERROR_SXS_UNKNOWN_ENCODING_GROUP" => WIN32::ERROR_SXS_UNKNOWN_ENCODING_GROUP,
            "ERROR_SXS_UNKNOWN_ENCODING" => WIN32::ERROR_SXS_UNKNOWN_ENCODING,
            "ERROR_SXS_INVALID_XML_NAMESPACE_URI" => WIN32::ERROR_SXS_INVALID_XML_NAMESPACE_URI,
            "ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED" => WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED,
            "ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED" => WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED,
            "ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED" => WIN32::ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED,
            "ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE" => WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE,
            "ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE" => WIN32::ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE,
            "ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE" => WIN32::ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE,
            "ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT" => WIN32::ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT,
            "ERROR_SXS_DUPLICATE_DLL_NAME" => WIN32::ERROR_SXS_DUPLICATE_DLL_NAME,
            "ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME" => WIN32::ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME,
            "ERROR_SXS_DUPLICATE_CLSID" => WIN32::ERROR_SXS_DUPLICATE_CLSID,
            "ERROR_SXS_DUPLICATE_IID" => WIN32::ERROR_SXS_DUPLICATE_IID,
            "ERROR_SXS_DUPLICATE_TLBID" => WIN32::ERROR_SXS_DUPLICATE_TLBID,
            "ERROR_SXS_DUPLICATE_PROGID" => WIN32::ERROR_SXS_DUPLICATE_PROGID,
            "ERROR_SXS_DUPLICATE_ASSEMBLY_NAME" => WIN32::ERROR_SXS_DUPLICATE_ASSEMBLY_NAME,
            "ERROR_SXS_FILE_HASH_MISMATCH" => WIN32::ERROR_SXS_FILE_HASH_MISMATCH,
            "ERROR_SXS_POLICY_PARSE_ERROR" => WIN32::ERROR_SXS_POLICY_PARSE_ERROR,
            "ERROR_SXS_XML_E_MISSINGQUOTE" => WIN32::ERROR_SXS_XML_E_MISSINGQUOTE,
            "ERROR_SXS_XML_E_COMMENTSYNTAX" => WIN32::ERROR_SXS_XML_E_COMMENTSYNTAX,
            "ERROR_SXS_XML_E_BADSTARTNAMECHAR" => WIN32::ERROR_SXS_XML_E_BADSTARTNAMECHAR,
            "ERROR_SXS_XML_E_BADNAMECHAR" => WIN32::ERROR_SXS_XML_E_BADNAMECHAR,
            "ERROR_SXS_XML_E_BADCHARINSTRING" => WIN32::ERROR_SXS_XML_E_BADCHARINSTRING,
            "ERROR_SXS_XML_E_XMLDECLSYNTAX" => WIN32::ERROR_SXS_XML_E_XMLDECLSYNTAX,
            "ERROR_SXS_XML_E_BADCHARDATA" => WIN32::ERROR_SXS_XML_E_BADCHARDATA,
            "ERROR_SXS_XML_E_MISSINGWHITESPACE" => WIN32::ERROR_SXS_XML_E_MISSINGWHITESPACE,
            "ERROR_SXS_XML_E_EXPECTINGTAGEND" => WIN32::ERROR_SXS_XML_E_EXPECTINGTAGEND,
            "ERROR_SXS_XML_E_MISSINGSEMICOLON" => WIN32::ERROR_SXS_XML_E_MISSINGSEMICOLON,
            "ERROR_SXS_XML_E_UNBALANCEDPAREN" => WIN32::ERROR_SXS_XML_E_UNBALANCEDPAREN,
            "ERROR_SXS_XML_E_INTERNALERROR" => WIN32::ERROR_SXS_XML_E_INTERNALERROR,
            "ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE" => WIN32::ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE,
            "ERROR_SXS_XML_E_INCOMPLETE_ENCODING" => WIN32::ERROR_SXS_XML_E_INCOMPLETE_ENCODING,
            "ERROR_SXS_XML_E_MISSING_PAREN" => WIN32::ERROR_SXS_XML_E_MISSING_PAREN,
            "ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE" => WIN32::ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE,
            "ERROR_SXS_XML_E_MULTIPLE_COLONS" => WIN32::ERROR_SXS_XML_E_MULTIPLE_COLONS,
            "ERROR_SXS_XML_E_INVALID_DECIMAL" => WIN32::ERROR_SXS_XML_E_INVALID_DECIMAL,
            "ERROR_SXS_XML_E_INVALID_HEXIDECIMAL" => WIN32::ERROR_SXS_XML_E_INVALID_HEXIDECIMAL,
            "ERROR_SXS_XML_E_INVALID_UNICODE" => WIN32::ERROR_SXS_XML_E_INVALID_UNICODE,
            "ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK" => WIN32::ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK,
            "ERROR_SXS_XML_E_UNEXPECTEDENDTAG" => WIN32::ERROR_SXS_XML_E_UNEXPECTEDENDTAG,
            "ERROR_SXS_XML_E_UNCLOSEDTAG" => WIN32::ERROR_SXS_XML_E_UNCLOSEDTAG,
            "ERROR_SXS_XML_E_DUPLICATEATTRIBUTE" => WIN32::ERROR_SXS_XML_E_DUPLICATEATTRIBUTE,
            "ERROR_SXS_XML_E_MULTIPLEROOTS" => WIN32::ERROR_SXS_XML_E_MULTIPLEROOTS,
            "ERROR_SXS_XML_E_INVALIDATROOTLEVEL" => WIN32::ERROR_SXS_XML_E_INVALIDATROOTLEVEL,
            "ERROR_SXS_XML_E_BADXMLDECL" => WIN32::ERROR_SXS_XML_E_BADXMLDECL,
            "ERROR_SXS_XML_E_MISSINGROOT" => WIN32::ERROR_SXS_XML_E_MISSINGROOT,
            "ERROR_SXS_XML_E_UNEXPECTEDEOF" => WIN32::ERROR_SXS_XML_E_UNEXPECTEDEOF,
            "ERROR_SXS_XML_E_BADPEREFINSUBSET" => WIN32::ERROR_SXS_XML_E_BADPEREFINSUBSET,
            "ERROR_SXS_XML_E_UNCLOSEDSTARTTAG" => WIN32::ERROR_SXS_XML_E_UNCLOSEDSTARTTAG,
            "ERROR_SXS_XML_E_UNCLOSEDENDTAG" => WIN32::ERROR_SXS_XML_E_UNCLOSEDENDTAG,
            "ERROR_SXS_XML_E_UNCLOSEDSTRING" => WIN32::ERROR_SXS_XML_E_UNCLOSEDSTRING,
            "ERROR_SXS_XML_E_UNCLOSEDCOMMENT" => WIN32::ERROR_SXS_XML_E_UNCLOSEDCOMMENT,
            "ERROR_SXS_XML_E_UNCLOSEDDECL" => WIN32::ERROR_SXS_XML_E_UNCLOSEDDECL,
            "ERROR_SXS_XML_E_UNCLOSEDCDATA" => WIN32::ERROR_SXS_XML_E_UNCLOSEDCDATA,
            "ERROR_SXS_XML_E_RESERVEDNAMESPACE" => WIN32::ERROR_SXS_XML_E_RESERVEDNAMESPACE,
            "ERROR_SXS_XML_E_INVALIDENCODING" => WIN32::ERROR_SXS_XML_E_INVALIDENCODING,
            "ERROR_SXS_XML_E_INVALIDSWITCH" => WIN32::ERROR_SXS_XML_E_INVALIDSWITCH,
            "ERROR_SXS_XML_E_BADXMLCASE" => WIN32::ERROR_SXS_XML_E_BADXMLCASE,
            "ERROR_SXS_XML_E_INVALID_STANDALONE" => WIN32::ERROR_SXS_XML_E_INVALID_STANDALONE,
            "ERROR_SXS_XML_E_UNEXPECTED_STANDALONE" => WIN32::ERROR_SXS_XML_E_UNEXPECTED_STANDALONE,
            "ERROR_SXS_XML_E_INVALID_VERSION" => WIN32::ERROR_SXS_XML_E_INVALID_VERSION,
            "ERROR_SXS_XML_E_MISSINGEQUALS" => WIN32::ERROR_SXS_XML_E_MISSINGEQUALS,
            "ERROR_SXS_PROTECTION_RECOVERY_FAILED" => WIN32::ERROR_SXS_PROTECTION_RECOVERY_FAILED,
            "ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT" => WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT,
            "ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT" => WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT,
            "ERROR_SXS_PROTECTION_CATALOG_NOT_VALID" => WIN32::ERROR_SXS_PROTECTION_CATALOG_NOT_VALID,
            "ERROR_SXS_UNTRANSLATABLE_HRESULT" => WIN32::ERROR_SXS_UNTRANSLATABLE_HRESULT,
            "ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING" => WIN32::ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING,
            "ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE" => WIN32::ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE,
            "ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME" => WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME,
            "ERROR_SXS_ASSEMBLY_MISSING" => WIN32::ERROR_SXS_ASSEMBLY_MISSING,
            "ERROR_SXS_CORRUPT_ACTIVATION_STACK" => WIN32::ERROR_SXS_CORRUPT_ACTIVATION_STACK,
            "ERROR_SXS_CORRUPTION" => WIN32::ERROR_SXS_CORRUPTION,
            "ERROR_SXS_EARLY_DEACTIVATION" => WIN32::ERROR_SXS_EARLY_DEACTIVATION,
            "ERROR_SXS_INVALID_DEACTIVATION" => WIN32::ERROR_SXS_INVALID_DEACTIVATION,
            "ERROR_SXS_MULTIPLE_DEACTIVATION" => WIN32::ERROR_SXS_MULTIPLE_DEACTIVATION,
            "ERROR_SXS_PROCESS_TERMINATION_REQUESTED" => WIN32::ERROR_SXS_PROCESS_TERMINATION_REQUESTED,
            "ERROR_SXS_RELEASE_ACTIVATION_CONTEXT" => WIN32::ERROR_SXS_RELEASE_ACTIVATION_CONTEXT,
            "ERROR_SXS_RELEASE_ACTIVATION_ONTEXT" => WIN32::ERROR_SXS_RELEASE_ACTIVATION_ONTEXT,
            "ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY" => WIN32::ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY,
            "ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE" => WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE,
            "ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME" => WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME,
            "ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE" => WIN32::ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE,
            "ERROR_SXS_IDENTITY_PARSE_ERROR" => WIN32::ERROR_SXS_IDENTITY_PARSE_ERROR,
            "ERROR_MALFORMED_SUBSTITUTION_STRING" => WIN32::ERROR_MALFORMED_SUBSTITUTION_STRING,
            "ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN" => WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN,
            "ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN" => WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN,
            "ERROR_UNMAPPED_SUBSTITUTION_STRING" => WIN32::ERROR_UNMAPPED_SUBSTITUTION_STRING,
            "ERROR_SXS_ASSEMBLY_NOT_LOCKED" => WIN32::ERROR_SXS_ASSEMBLY_NOT_LOCKED,
            "ERROR_SXS_COMPONENT_STORE_CORRUPT" => WIN32::ERROR_SXS_COMPONENT_STORE_CORRUPT,
            "ERROR_ADVANCED_INSTALLER_FAILED" => WIN32::ERROR_ADVANCED_INSTALLER_FAILED,
            "ERROR_XML_ENCODING_MISMATCH" => WIN32::ERROR_XML_ENCODING_MISMATCH,
            "ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT" => WIN32::ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT,
            "ERROR_SXS_IDENTITIES_DIFFERENT" => WIN32::ERROR_SXS_IDENTITIES_DIFFERENT,
            "ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT" => WIN32::ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT,
            "ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY" => WIN32::ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY,
            "ERROR_SXS_MANIFEST_TOO_BIG" => WIN32::ERROR_SXS_MANIFEST_TOO_BIG,
            "ERROR_SXS_SETTING_NOT_REGISTERED" => WIN32::ERROR_SXS_SETTING_NOT_REGISTERED,
            "ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE" => WIN32::ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE,
            "ERROR_SMI_PRIMITIVE_INSTALLER_FAILED" => WIN32::ERROR_SMI_PRIMITIVE_INSTALLER_FAILED,
            "ERROR_GENERIC_COMMAND_FAILED" => WIN32::ERROR_GENERIC_COMMAND_FAILED,
            "ERROR_SXS_FILE_HASH_MISSING" => WIN32::ERROR_SXS_FILE_HASH_MISSING,
            "ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS" => WIN32::ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS,
            "ERROR_EVT_INVALID_CHANNEL_PATH" => WIN32::ERROR_EVT_INVALID_CHANNEL_PATH,
            "ERROR_EVT_INVALID_QUERY" => WIN32::ERROR_EVT_INVALID_QUERY,
            "ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND" => WIN32::ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND,
            "ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND" => WIN32::ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND,
            "ERROR_EVT_INVALID_PUBLISHER_NAME" => WIN32::ERROR_EVT_INVALID_PUBLISHER_NAME,
            "ERROR_EVT_INVALID_EVENT_DATA" => WIN32::ERROR_EVT_INVALID_EVENT_DATA,
            "ERROR_EVT_CHANNEL_NOT_FOUND" => WIN32::ERROR_EVT_CHANNEL_NOT_FOUND,
            "ERROR_EVT_MALFORMED_XML_TEXT" => WIN32::ERROR_EVT_MALFORMED_XML_TEXT,
            "ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL" => WIN32::ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL,
            "ERROR_EVT_CONFIGURATION_ERROR" => WIN32::ERROR_EVT_CONFIGURATION_ERROR,
            "ERROR_EVT_QUERY_RESULT_STALE" => WIN32::ERROR_EVT_QUERY_RESULT_STALE,
            "ERROR_EVT_QUERY_RESULT_INVALID_POSITION" => WIN32::ERROR_EVT_QUERY_RESULT_INVALID_POSITION,
            "ERROR_EVT_NON_VALIDATING_MSXML" => WIN32::ERROR_EVT_NON_VALIDATING_MSXML,
            "ERROR_EVT_FILTER_ALREADYSCOPED" => WIN32::ERROR_EVT_FILTER_ALREADYSCOPED,
            "ERROR_EVT_FILTER_NOTELTSET" => WIN32::ERROR_EVT_FILTER_NOTELTSET,
            "ERROR_EVT_FILTER_INVARG" => WIN32::ERROR_EVT_FILTER_INVARG,
            "ERROR_EVT_FILTER_INVTEST" => WIN32::ERROR_EVT_FILTER_INVTEST,
            "ERROR_EVT_FILTER_INVTYPE" => WIN32::ERROR_EVT_FILTER_INVTYPE,
            "ERROR_EVT_FILTER_PARSEERR" => WIN32::ERROR_EVT_FILTER_PARSEERR,
            "ERROR_EVT_FILTER_UNSUPPORTEDOP" => WIN32::ERROR_EVT_FILTER_UNSUPPORTEDOP,
            "ERROR_EVT_FILTER_UNEXPECTEDTOKEN" => WIN32::ERROR_EVT_FILTER_UNEXPECTEDTOKEN,
            "ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL" => WIN32::ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL,
            "ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE" => WIN32::ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE,
            "ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE" => WIN32::ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE,
            "ERROR_EVT_CHANNEL_CANNOT_ACTIVATE" => WIN32::ERROR_EVT_CHANNEL_CANNOT_ACTIVATE,
            "ERROR_EVT_FILTER_TOO_COMPLEX" => WIN32::ERROR_EVT_FILTER_TOO_COMPLEX,
            "ERROR_EVT_MESSAGE_NOT_FOUND" => WIN32::ERROR_EVT_MESSAGE_NOT_FOUND,
            "ERROR_EVT_MESSAGE_ID_NOT_FOUND" => WIN32::ERROR_EVT_MESSAGE_ID_NOT_FOUND,
            "ERROR_EVT_UNRESOLVED_VALUE_INSERT" => WIN32::ERROR_EVT_UNRESOLVED_VALUE_INSERT,
            "ERROR_EVT_UNRESOLVED_PARAMETER_INSERT" => WIN32::ERROR_EVT_UNRESOLVED_PARAMETER_INSERT,
            "ERROR_EVT_MAX_INSERTS_REACHED" => WIN32::ERROR_EVT_MAX_INSERTS_REACHED,
            "ERROR_EVT_EVENT_DEFINITION_NOT_FOUND" => WIN32::ERROR_EVT_EVENT_DEFINITION_NOT_FOUND,
            "ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND" => WIN32::ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND,
            "ERROR_EVT_VERSION_TOO_OLD" => WIN32::ERROR_EVT_VERSION_TOO_OLD,
            "ERROR_EVT_VERSION_TOO_NEW" => WIN32::ERROR_EVT_VERSION_TOO_NEW,
            "ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY" => WIN32::ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY,
            "ERROR_EVT_PUBLISHER_DISABLED" => WIN32::ERROR_EVT_PUBLISHER_DISABLED,
            "ERROR_EVT_FILTER_OUT_OF_RANGE" => WIN32::ERROR_EVT_FILTER_OUT_OF_RANGE,
            "ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE" => WIN32::ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE,
            "ERROR_EC_LOG_DISABLED" => WIN32::ERROR_EC_LOG_DISABLED,
            "ERROR_EC_CIRCULAR_FORWARDING" => WIN32::ERROR_EC_CIRCULAR_FORWARDING,
            "ERROR_EC_CREDSTORE_FULL" => WIN32::ERROR_EC_CREDSTORE_FULL,
            "ERROR_EC_CRED_NOT_FOUND" => WIN32::ERROR_EC_CRED_NOT_FOUND,
            "ERROR_EC_NO_ACTIVE_CHANNEL" => WIN32::ERROR_EC_NO_ACTIVE_CHANNEL,
            "ERROR_MUI_FILE_NOT_FOUND" => WIN32::ERROR_MUI_FILE_NOT_FOUND,
            "ERROR_MUI_INVALID_FILE" => WIN32::ERROR_MUI_INVALID_FILE,
            "ERROR_MUI_INVALID_RC_CONFIG" => WIN32::ERROR_MUI_INVALID_RC_CONFIG,
            "ERROR_MUI_INVALID_LOCALE_NAME" => WIN32::ERROR_MUI_INVALID_LOCALE_NAME,
            "ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME" => WIN32::ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME,
            "ERROR_MUI_FILE_NOT_LOADED" => WIN32::ERROR_MUI_FILE_NOT_LOADED,
            "ERROR_RESOURCE_ENUM_USER_STOP" => WIN32::ERROR_RESOURCE_ENUM_USER_STOP,
            "ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED" => WIN32::ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED,
            "ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME" => WIN32::ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME,
            "ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE" => WIN32::ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE,
            "ERROR_MRM_INVALID_PRICONFIG" => WIN32::ERROR_MRM_INVALID_PRICONFIG,
            "ERROR_MRM_INVALID_FILE_TYPE" => WIN32::ERROR_MRM_INVALID_FILE_TYPE,
            "ERROR_MRM_UNKNOWN_QUALIFIER" => WIN32::ERROR_MRM_UNKNOWN_QUALIFIER,
            "ERROR_MRM_INVALID_QUALIFIER_VALUE" => WIN32::ERROR_MRM_INVALID_QUALIFIER_VALUE,
            "ERROR_MRM_NO_CANDIDATE" => WIN32::ERROR_MRM_NO_CANDIDATE,
            "ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE" => WIN32::ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE,
            "ERROR_MRM_RESOURCE_TYPE_MISMATCH" => WIN32::ERROR_MRM_RESOURCE_TYPE_MISMATCH,
            "ERROR_MRM_DUPLICATE_MAP_NAME" => WIN32::ERROR_MRM_DUPLICATE_MAP_NAME,
            "ERROR_MRM_DUPLICATE_ENTRY" => WIN32::ERROR_MRM_DUPLICATE_ENTRY,
            "ERROR_MRM_INVALID_RESOURCE_IDENTIFIER" => WIN32::ERROR_MRM_INVALID_RESOURCE_IDENTIFIER,
            "ERROR_MRM_FILEPATH_TOO_LONG" => WIN32::ERROR_MRM_FILEPATH_TOO_LONG,
            "ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE" => WIN32::ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE,
            "ERROR_MRM_INVALID_PRI_FILE" => WIN32::ERROR_MRM_INVALID_PRI_FILE,
            "ERROR_MRM_NAMED_RESOURCE_NOT_FOUND" => WIN32::ERROR_MRM_NAMED_RESOURCE_NOT_FOUND,
            "ERROR_MRM_MAP_NOT_FOUND" => WIN32::ERROR_MRM_MAP_NOT_FOUND,
            "ERROR_MRM_UNSUPPORTED_PROFILE_TYPE" => WIN32::ERROR_MRM_UNSUPPORTED_PROFILE_TYPE,
            "ERROR_MRM_INVALID_QUALIFIER_OPERATOR" => WIN32::ERROR_MRM_INVALID_QUALIFIER_OPERATOR,
            "ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE" => WIN32::ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE,
            "ERROR_MRM_AUTOMERGE_ENABLED" => WIN32::ERROR_MRM_AUTOMERGE_ENABLED,
            "ERROR_MRM_TOO_MANY_RESOURCES" => WIN32::ERROR_MRM_TOO_MANY_RESOURCES,
            "ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE" => WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE,
            "ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE" => WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE,
            "ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD" => WIN32::ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD,
            "ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST" => WIN32::ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST,
            "ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT" => WIN32::ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT,
            "ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE" => WIN32::ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE,
            "ERROR_MRM_GENERATION_COUNT_MISMATCH" => WIN32::ERROR_MRM_GENERATION_COUNT_MISMATCH,
            "ERROR_PRI_MERGE_VERSION_MISMATCH" => WIN32::ERROR_PRI_MERGE_VERSION_MISMATCH,
            "ERROR_PRI_MERGE_MISSING_SCHEMA" => WIN32::ERROR_PRI_MERGE_MISSING_SCHEMA,
            "ERROR_PRI_MERGE_LOAD_FILE_FAILED" => WIN32::ERROR_PRI_MERGE_LOAD_FILE_FAILED,
            "ERROR_PRI_MERGE_ADD_FILE_FAILED" => WIN32::ERROR_PRI_MERGE_ADD_FILE_FAILED,
            "ERROR_PRI_MERGE_WRITE_FILE_FAILED" => WIN32::ERROR_PRI_MERGE_WRITE_FILE_FAILED,
            "ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED" => WIN32::ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED,
            "ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED" => WIN32::ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED,
            "ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED" => WIN32::ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED,
            "ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED" => WIN32::ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED,
            "ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED" => WIN32::ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED,
            "ERROR_PRI_MERGE_INVALID_FILE_NAME" => WIN32::ERROR_PRI_MERGE_INVALID_FILE_NAME,
            "ERROR_MRM_PACKAGE_NOT_FOUND" => WIN32::ERROR_MRM_PACKAGE_NOT_FOUND,
            "ERROR_MRM_MISSING_DEFAULT_LANGUAGE" => WIN32::ERROR_MRM_MISSING_DEFAULT_LANGUAGE,
            "ERROR_MRM_SCOPE_ITEM_CONFLICT" => WIN32::ERROR_MRM_SCOPE_ITEM_CONFLICT,
            "ERROR_MCA_INVALID_CAPABILITIES_STRING" => WIN32::ERROR_MCA_INVALID_CAPABILITIES_STRING,
            "ERROR_MCA_INVALID_VCP_VERSION" => WIN32::ERROR_MCA_INVALID_VCP_VERSION,
            "ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION" => WIN32::ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION,
            "ERROR_MCA_MCCS_VERSION_MISMATCH" => WIN32::ERROR_MCA_MCCS_VERSION_MISMATCH,
            "ERROR_MCA_UNSUPPORTED_MCCS_VERSION" => WIN32::ERROR_MCA_UNSUPPORTED_MCCS_VERSION,
            "ERROR_MCA_INTERNAL_ERROR" => WIN32::ERROR_MCA_INTERNAL_ERROR,
            "ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED" => WIN32::ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED,
            "ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE" => WIN32::ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE,
            "ERROR_AMBIGUOUS_SYSTEM_DEVICE" => WIN32::ERROR_AMBIGUOUS_SYSTEM_DEVICE,
            "ERROR_SYSTEM_DEVICE_NOT_FOUND" => WIN32::ERROR_SYSTEM_DEVICE_NOT_FOUND,
            "ERROR_HASH_NOT_SUPPORTED" => WIN32::ERROR_HASH_NOT_SUPPORTED,
            "ERROR_HASH_NOT_PRESENT" => WIN32::ERROR_HASH_NOT_PRESENT,
            "ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED" => WIN32::ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED,
            "ERROR_GPIO_CLIENT_INFORMATION_INVALID" => WIN32::ERROR_GPIO_CLIENT_INFORMATION_INVALID,
            "ERROR_GPIO_VERSION_NOT_SUPPORTED" => WIN32::ERROR_GPIO_VERSION_NOT_SUPPORTED,
            "ERROR_GPIO_INVALID_REGISTRATION_PACKET" => WIN32::ERROR_GPIO_INVALID_REGISTRATION_PACKET,
            "ERROR_GPIO_OPERATION_DENIED" => WIN32::ERROR_GPIO_OPERATION_DENIED,
            "ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE" => WIN32::ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE,
            "ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED" => WIN32::ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED,
            "ERROR_CANNOT_SWITCH_RUNLEVEL" => WIN32::ERROR_CANNOT_SWITCH_RUNLEVEL,
            "ERROR_INVALID_RUNLEVEL_SETTING" => WIN32::ERROR_INVALID_RUNLEVEL_SETTING,
            "ERROR_RUNLEVEL_SWITCH_TIMEOUT" => WIN32::ERROR_RUNLEVEL_SWITCH_TIMEOUT,
            "ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT" => WIN32::ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT,
            "ERROR_RUNLEVEL_SWITCH_IN_PROGRESS" => WIN32::ERROR_RUNLEVEL_SWITCH_IN_PROGRESS,
            "ERROR_SERVICES_FAILED_AUTOSTART" => WIN32::ERROR_SERVICES_FAILED_AUTOSTART,
            "ERROR_COM_TASK_STOP_PENDING" => WIN32::ERROR_COM_TASK_STOP_PENDING,
            "ERROR_INSTALL_OPEN_PACKAGE_FAILED" => WIN32::ERROR_INSTALL_OPEN_PACKAGE_FAILED,
            "ERROR_INSTALL_PACKAGE_NOT_FOUND" => WIN32::ERROR_INSTALL_PACKAGE_NOT_FOUND,
            "ERROR_INSTALL_INVALID_PACKAGE" => WIN32::ERROR_INSTALL_INVALID_PACKAGE,
            "ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED" => WIN32::ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED,
            "ERROR_INSTALL_OUT_OF_DISK_SPACE" => WIN32::ERROR_INSTALL_OUT_OF_DISK_SPACE,
            "ERROR_INSTALL_NETWORK_FAILURE" => WIN32::ERROR_INSTALL_NETWORK_FAILURE,
            "ERROR_INSTALL_REGISTRATION_FAILURE" => WIN32::ERROR_INSTALL_REGISTRATION_FAILURE,
            "ERROR_INSTALL_DEREGISTRATION_FAILURE" => WIN32::ERROR_INSTALL_DEREGISTRATION_FAILURE,
            "ERROR_INSTALL_CANCEL" => WIN32::ERROR_INSTALL_CANCEL,
            "ERROR_INSTALL_FAILED" => WIN32::ERROR_INSTALL_FAILED,
            "ERROR_REMOVE_FAILED" => WIN32::ERROR_REMOVE_FAILED,
            "ERROR_PACKAGE_ALREADY_EXISTS" => WIN32::ERROR_PACKAGE_ALREADY_EXISTS,
            "ERROR_NEEDS_REMEDIATION" => WIN32::ERROR_NEEDS_REMEDIATION,
            "ERROR_INSTALL_PREREQUISITE_FAILED" => WIN32::ERROR_INSTALL_PREREQUISITE_FAILED,
            "ERROR_PACKAGE_REPOSITORY_CORRUPTED" => WIN32::ERROR_PACKAGE_REPOSITORY_CORRUPTED,
            "ERROR_INSTALL_POLICY_FAILURE" => WIN32::ERROR_INSTALL_POLICY_FAILURE,
            "ERROR_PACKAGE_UPDATING" => WIN32::ERROR_PACKAGE_UPDATING,
            "ERROR_DEPLOYMENT_BLOCKED_BY_POLICY" => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_POLICY,
            "ERROR_PACKAGES_IN_USE" => WIN32::ERROR_PACKAGES_IN_USE,
            "ERROR_RECOVERY_FILE_CORRUPT" => WIN32::ERROR_RECOVERY_FILE_CORRUPT,
            "ERROR_INVALID_STAGED_SIGNATURE" => WIN32::ERROR_INVALID_STAGED_SIGNATURE,
            "ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED" => WIN32::ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED,
            "ERROR_INSTALL_PACKAGE_DOWNGRADE" => WIN32::ERROR_INSTALL_PACKAGE_DOWNGRADE,
            "ERROR_SYSTEM_NEEDS_REMEDIATION" => WIN32::ERROR_SYSTEM_NEEDS_REMEDIATION,
            "ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN" => WIN32::ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN,
            "ERROR_RESILIENCY_FILE_CORRUPT" => WIN32::ERROR_RESILIENCY_FILE_CORRUPT,
            "ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING" => WIN32::ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING,
            "ERROR_PACKAGE_MOVE_FAILED" => WIN32::ERROR_PACKAGE_MOVE_FAILED,
            "ERROR_INSTALL_VOLUME_NOT_EMPTY" => WIN32::ERROR_INSTALL_VOLUME_NOT_EMPTY,
            "ERROR_INSTALL_VOLUME_OFFLINE" => WIN32::ERROR_INSTALL_VOLUME_OFFLINE,
            "ERROR_INSTALL_VOLUME_CORRUPT" => WIN32::ERROR_INSTALL_VOLUME_CORRUPT,
            "ERROR_NEEDS_REGISTRATION" => WIN32::ERROR_NEEDS_REGISTRATION,
            "ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE" => WIN32::ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE,
            "ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED" => WIN32::ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED,
            "ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE" => WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE,
            "ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM" => WIN32::ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM,
            "ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING" => WIN32::ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING,
            "ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE" => WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE,
            "ERROR_PACKAGE_STAGING_ONHOLD" => WIN32::ERROR_PACKAGE_STAGING_ONHOLD,
            "ERROR_INSTALL_INVALID_RELATED_SET_UPDATE" => WIN32::ERROR_INSTALL_INVALID_RELATED_SET_UPDATE,
            "ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY" => WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY,
            "ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF" => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF,
            "ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED" => WIN32::ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED,
            "ERROR_PACKAGES_REPUTATION_CHECK_FAILED" => WIN32::ERROR_PACKAGES_REPUTATION_CHECK_FAILED,
            "ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT" => WIN32::ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT,
            "ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED" => WIN32::ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED,
            "ERROR_APPINSTALLER_ACTIVATION_BLOCKED" => WIN32::ERROR_APPINSTALLER_ACTIVATION_BLOCKED,
            "ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED" => WIN32::ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED,
            "ERROR_APPX_RAW_DATA_WRITE_FAILED" => WIN32::ERROR_APPX_RAW_DATA_WRITE_FAILED,
            "ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE" => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE,
            "ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE" => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE,
            "ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY" => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY,
            "ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY" => WIN32::ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY,
            "ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER" => WIN32::ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER,
            "ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED" => WIN32::ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED,
            "ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE" => WIN32::ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE,
            "ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES" => WIN32::ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES,
            "ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED" => WIN32::ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED,
            "ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST" => WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST,
            "ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT" => WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT,
            "ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE" => WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE,
            "ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE" => WIN32::ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE,
            "ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED" => WIN32::ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED,
            "ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY" => WIN32::ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY,
            "ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS" => WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS,
            "ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED" => WIN32::ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED,
            "ERROR_MACHINE_SCOPE_NOT_ALLOWED" => WIN32::ERROR_MACHINE_SCOPE_NOT_ALLOWED,
            "ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED" => WIN32::ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED,
            "ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE" => WIN32::ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE,
            "ERROR_PACKAGE_NOT_REGISTERED_FOR_USER" => WIN32::ERROR_PACKAGE_NOT_REGISTERED_FOR_USER,
            "ERROR_PACKAGE_NAME_MISMATCH" => WIN32::ERROR_PACKAGE_NAME_MISMATCH,
            "ERROR_APPINSTALLER_URI_IN_USE" => WIN32::ERROR_APPINSTALLER_URI_IN_USE,
            "ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM" => WIN32::ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM,
            "APPMODEL_ERROR_NO_PACKAGE" => WIN32::APPMODEL_ERROR_NO_PACKAGE,
            "APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT" => WIN32::APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT,
            "APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT" => WIN32::APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT,
            "APPMODEL_ERROR_NO_APPLICATION" => WIN32::APPMODEL_ERROR_NO_APPLICATION,
            "APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED" => WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED,
            "APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID" => WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID,
            "APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE" => WIN32::APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE,
            "APPMODEL_ERROR_NO_MUTABLE_DIRECTORY" => WIN32::APPMODEL_ERROR_NO_MUTABLE_DIRECTORY,
            "ERROR_STATE_LOAD_STORE_FAILED" => WIN32::ERROR_STATE_LOAD_STORE_FAILED,
            "ERROR_STATE_GET_VERSION_FAILED" => WIN32::ERROR_STATE_GET_VERSION_FAILED,
            "ERROR_STATE_SET_VERSION_FAILED" => WIN32::ERROR_STATE_SET_VERSION_FAILED,
            "ERROR_STATE_STRUCTURED_RESET_FAILED" => WIN32::ERROR_STATE_STRUCTURED_RESET_FAILED,
            "ERROR_STATE_OPEN_CONTAINER_FAILED" => WIN32::ERROR_STATE_OPEN_CONTAINER_FAILED,
            "ERROR_STATE_CREATE_CONTAINER_FAILED" => WIN32::ERROR_STATE_CREATE_CONTAINER_FAILED,
            "ERROR_STATE_DELETE_CONTAINER_FAILED" => WIN32::ERROR_STATE_DELETE_CONTAINER_FAILED,
            "ERROR_STATE_READ_SETTING_FAILED" => WIN32::ERROR_STATE_READ_SETTING_FAILED,
            "ERROR_STATE_WRITE_SETTING_FAILED" => WIN32::ERROR_STATE_WRITE_SETTING_FAILED,
            "ERROR_STATE_DELETE_SETTING_FAILED" => WIN32::ERROR_STATE_DELETE_SETTING_FAILED,
            "ERROR_STATE_QUERY_SETTING_FAILED" => WIN32::ERROR_STATE_QUERY_SETTING_FAILED,
            "ERROR_STATE_READ_COMPOSITE_SETTING_FAILED" => WIN32::ERROR_STATE_READ_COMPOSITE_SETTING_FAILED,
            "ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED" => WIN32::ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED,
            "ERROR_STATE_ENUMERATE_CONTAINER_FAILED" => WIN32::ERROR_STATE_ENUMERATE_CONTAINER_FAILED,
            "ERROR_STATE_ENUMERATE_SETTINGS_FAILED" => WIN32::ERROR_STATE_ENUMERATE_SETTINGS_FAILED,
            "ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED" => WIN32::ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED,
            "ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED" => WIN32::ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED,
            "ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED" => WIN32::ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED,
            "ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED" => WIN32::ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED,
            "ERROR_API_UNAVAILABLE" => WIN32::ERROR_API_UNAVAILABLE,
            "STORE_ERROR_UNLICENSED" => WIN32::STORE_ERROR_UNLICENSED,
            "STORE_ERROR_UNLICENSED_USER" => WIN32::STORE_ERROR_UNLICENSED_USER,
            "STORE_ERROR_PENDING_COM_TRANSACTION" => WIN32::STORE_ERROR_PENDING_COM_TRANSACTION,
            "STORE_ERROR_LICENSE_REVOKED" => WIN32::STORE_ERROR_LICENSE_REVOKED,
            "ERROR_SUCCESS" => WIN32::ERROR_SUCCESS,
        }
    }
    pub fn from_code(code: u32) -> WIN32 {
        return match code {
            0x80070001 => WIN32::ERROR_INVALID_FUNCTION,
            0x80070001 => WIN32::PDH_CSTATUS_NEW_DATA,
            0x80070002 => WIN32::ERROR_FILE_NOT_FOUND,
            0x80070003 => WIN32::ERROR_PATH_NOT_FOUND,
            0x80070003 => WIN32::E_PATH_NOT_FOUND,
            0x80070004 => WIN32::ERROR_TOO_MANY_OPEN_FILES,
            0x80070005 => WIN32::ERROR_ACCESS_DENIED,
            0x80070005 => WIN32::E_ACCESSDENIED,
            0x80070006 => WIN32::ERROR_INVALID_HANDLE,
            0x80070006 => WIN32::E_HANDLE,
            0x80070007 => WIN32::ERROR_ARENA_TRASHED,
            0x80070008 => WIN32::ERROR_NOT_ENOUGH_MEMORY,
            0x80070009 => WIN32::ERROR_INVALID_BLOCK,
            0x8007000A => WIN32::ERROR_BAD_ENVIRONMENT,
            0x8007000B => WIN32::ERROR_BAD_FORMAT,
            0x8007000C => WIN32::ERROR_INVALID_ACCESS,
            0x8007000D => WIN32::ERROR_INVALID_DATA,
            0x8007000E => WIN32::E_OUTOFMEMORY,
            0x8007000E => WIN32::ERROR_OUTOFMEMORY,
            0x8007000E => WIN32::DDERR_OUTOFMEMORY,
            0x8007000F => WIN32::ERROR_INVALID_DRIVE,
            0x80070010 => WIN32::ERROR_CURRENT_DIRECTORY,
            0x80070011 => WIN32::ERROR_NOT_SAME_DEVICE,
            0x80070012 => WIN32::ERROR_NO_MORE_FILES,
            0x80070013 => WIN32::ERROR_WRITE_PROTECT,
            0x80070014 => WIN32::ERROR_BAD_UNIT,
            0x80070015 => WIN32::ERROR_NOT_READY,
            0x80070016 => WIN32::ERROR_BAD_COMMAND,
            0x80070017 => WIN32::ERROR_CRC,
            0x80070018 => WIN32::ERROR_BAD_LENGTH,
            0x80070019 => WIN32::ERROR_SEEK,
            0x8007001A => WIN32::ERROR_NOT_DOS_DISK,
            0x8007001B => WIN32::ERROR_SECTOR_NOT_FOUND,
            0x8007001C => WIN32::ERROR_OUT_OF_PAPER,
            0x8007001D => WIN32::ERROR_WRITE_FAULT,
            0x8007001E => WIN32::ERROR_READ_FAULT,
            0x8007001F => WIN32::ERROR_GEN_FAILURE,
            0x80070020 => WIN32::ERROR_SHARING_VIOLATION,
            0x80070020 => WIN32::E_SHARING_VIOLATION,
            0x80070021 => WIN32::ERROR_LOCK_VIOLATION,
            0x80070022 => WIN32::ERROR_WRONG_DISK,
            0x80070024 => WIN32::ERROR_SHARING_BUFFER_EXCEEDED,
            0x80070026 => WIN32::ERROR_HANDLE_EOF,
            0x80070027 => WIN32::ERROR_HANDLE_DISK_FULL,
            0x80070032 => WIN32::ERROR_NOT_SUPPORTED,
            0x80070033 => WIN32::ERROR_REM_NOT_LIST,
            0x80070034 => WIN32::ERROR_DUP_NAME,
            0x80070035 => WIN32::ERROR_BAD_NETPATH,
            0x80070036 => WIN32::ERROR_NETWORK_BUSY,
            0x80070037 => WIN32::ERROR_DEV_NOT_EXIST,
            0x80070038 => WIN32::ERROR_TOO_MANY_CMDS,
            0x80070039 => WIN32::ERROR_ADAP_HDW_ERR,
            0x8007003A => WIN32::ERROR_BAD_NET_RESP,
            0x8007003B => WIN32::ERROR_UNEXP_NET_ERR,
            0x8007003C => WIN32::ERROR_BAD_REM_ADAP,
            0x8007003D => WIN32::ERROR_PRINTQ_FULL,
            0x8007003E => WIN32::ERROR_NO_SPOOL_SPACE,
            0x8007003F => WIN32::ERROR_PRINT_CANCELLED,
            0x80070040 => WIN32::ERROR_NETNAME_DELETED,
            0x80070041 => WIN32::ERROR_NETWORK_ACCESS_DENIED,
            0x80070042 => WIN32::ERROR_BAD_DEV_TYPE,
            0x80070043 => WIN32::ERROR_BAD_NET_NAME,
            0x80070044 => WIN32::ERROR_TOO_MANY_NAMES,
            0x80070045 => WIN32::ERROR_TOO_MANY_SESS,
            0x80070046 => WIN32::ERROR_SHARING_PAUSED,
            0x80070047 => WIN32::ERROR_REQ_NOT_ACCEP,
            0x80070048 => WIN32::ERROR_REDIR_PAUSED,
            0x80070050 => WIN32::ERROR_FILE_EXISTS,
            0x80070052 => WIN32::ERROR_CANNOT_MAKE,
            0x80070053 => WIN32::ERROR_FAIL_I24,
            0x80070054 => WIN32::ERROR_OUT_OF_STRUCTURES,
            0x80070055 => WIN32::ERROR_ALREADY_ASSIGNED,
            0x80070056 => WIN32::ERROR_INVALID_PASSWORD,
            0x80070057 => WIN32::ERROR_INVALID_PARAMETER,
            0x80070057 => WIN32::E_INVALIDARG,
            0x80070057 => WIN32::DDERR_INVALIDPARAMS,
            0x80070058 => WIN32::ERROR_NET_WRITE_FAULT,
            0x80070059 => WIN32::ERROR_NO_PROC_SLOTS,
            0x80070064 => WIN32::ERROR_TOO_MANY_SEMAPHORES,
            0x80070065 => WIN32::ERROR_EXCL_SEM_ALREADY_OWNED,
            0x80070066 => WIN32::ERROR_SEM_IS_SET,
            0x80070067 => WIN32::ERROR_TOO_MANY_SEM_REQUESTS,
            0x80070068 => WIN32::ERROR_INVALID_AT_INTERRUPT_TIME,
            0x80070069 => WIN32::ERROR_SEM_OWNER_DIED,
            0x8007006A => WIN32::ERROR_SEM_USER_LIMIT,
            0x8007006B => WIN32::ERROR_DISK_CHANGE,
            0x8007006C => WIN32::ERROR_DRIVE_LOCKED,
            0x8007006D => WIN32::ERROR_BROKEN_PIPE,
            0x8007006E => WIN32::ERROR_OPEN_FAILED,
            0x8007006F => WIN32::ERROR_BUFFER_OVERFLOW,
            0x80070070 => WIN32::ERROR_DISK_FULL,
            0x80070071 => WIN32::ERROR_NO_MORE_SEARCH_HANDLES,
            0x80070072 => WIN32::ERROR_INVALID_TARGET_HANDLE,
            0x80070075 => WIN32::ERROR_INVALID_CATEGORY,
            0x80070076 => WIN32::ERROR_INVALID_VERIFY_SWITCH,
            0x80070077 => WIN32::ERROR_BAD_DRIVER_LEVEL,
            0x80070078 => WIN32::ERROR_CALL_NOT_IMPLEMENTED,
            0x80070079 => WIN32::ERROR_SEM_TIMEOUT,
            0x8007007A => WIN32::ERROR_INSUFFICIENT_BUFFER,
            0x8007007B => WIN32::ERROR_INVALID_NAME,
            0x8007007C => WIN32::ERROR_INVALID_LEVEL,
            0x8007007D => WIN32::ERROR_NO_VOLUME_LABEL,
            0x8007007E => WIN32::ERROR_MOD_NOT_FOUND,
            0x8007007F => WIN32::ERROR_PROC_NOT_FOUND,
            0x80070080 => WIN32::ERROR_WAIT_NO_CHILDREN,
            0x80070081 => WIN32::ERROR_CHILD_NOT_COMPLETE,
            0x80070082 => WIN32::ERROR_DIRECT_ACCESS_HANDLE,
            0x80070083 => WIN32::ERROR_NEGATIVE_SEEK,
            0x80070084 => WIN32::ERROR_SEEK_ON_DEVICE,
            0x80070085 => WIN32::ERROR_IS_JOIN_TARGET,
            0x80070086 => WIN32::ERROR_IS_JOINED,
            0x80070087 => WIN32::ERROR_IS_SUBSTED,
            0x80070088 => WIN32::ERROR_NOT_JOINED,
            0x80070089 => WIN32::ERROR_NOT_SUBSTED,
            0x8007008A => WIN32::ERROR_JOIN_TO_JOIN,
            0x8007008B => WIN32::ERROR_SUBST_TO_SUBST,
            0x8007008C => WIN32::ERROR_JOIN_TO_SUBST,
            0x8007008D => WIN32::ERROR_SUBST_TO_JOIN,
            0x8007008E => WIN32::ERROR_BUSY_DRIVE,
            0x8007008F => WIN32::ERROR_SAME_DRIVE,
            0x80070090 => WIN32::ERROR_DIR_NOT_ROOT,
            0x80070091 => WIN32::ERROR_DIR_NOT_EMPTY,
            0x80070092 => WIN32::ERROR_IS_SUBST_PATH,
            0x80070093 => WIN32::ERROR_IS_JOIN_PATH,
            0x80070094 => WIN32::ERROR_PATH_BUSY,
            0x80070095 => WIN32::ERROR_IS_SUBST_TARGET,
            0x80070096 => WIN32::ERROR_SYSTEM_TRACE,
            0x80070097 => WIN32::ERROR_INVALID_EVENT_COUNT,
            0x80070098 => WIN32::ERROR_TOO_MANY_MUXWAITERS,
            0x80070099 => WIN32::ERROR_INVALID_LIST_FORMAT,
            0x8007009A => WIN32::ERROR_LABEL_TOO_LONG,
            0x8007009B => WIN32::ERROR_TOO_MANY_TCBS,
            0x8007009C => WIN32::ERROR_SIGNAL_REFUSED,
            0x8007009D => WIN32::ERROR_DISCARDED,
            0x8007009E => WIN32::ERROR_NOT_LOCKED,
            0x8007009F => WIN32::ERROR_BAD_THREADID_ADDR,
            0x800700A0 => WIN32::ERROR_BAD_ARGUMENTS,
            0x800700A1 => WIN32::ERROR_BAD_PATHNAME,
            0x800700A2 => WIN32::ERROR_SIGNAL_PENDING,
            0x800700A4 => WIN32::ERROR_MAX_THRDS_REACHED,
            0x800700A7 => WIN32::ERROR_LOCK_FAILED,
            0x800700AA => WIN32::ERROR_BUSY,
            0x800700AB => WIN32::ERROR_DEVICE_SUPPORT_IN_PROGRESS,
            0x800700AD => WIN32::ERROR_CANCEL_VIOLATION,
            0x800700AE => WIN32::ERROR_ATOMIC_LOCKS_NOT_SUPPORTED,
            0x800700B4 => WIN32::ERROR_INVALID_SEGMENT_NUMBER,
            0x800700B6 => WIN32::ERROR_INVALID_ORDINAL,
            0x800700B7 => WIN32::ERROR_ALREADY_EXISTS,
            0x800700BA => WIN32::ERROR_INVALID_FLAG_NUMBER,
            0x800700BB => WIN32::ERROR_SEM_NOT_FOUND,
            0x800700BC => WIN32::ERROR_INVALID_STARTING_CODESEG,
            0x800700BD => WIN32::ERROR_INVALID_STACKSEG,
            0x800700BE => WIN32::ERROR_INVALID_MODULETYPE,
            0x800700BF => WIN32::ERROR_INVALID_EXE_SIGNATURE,
            0x800700C0 => WIN32::ERROR_EXE_MARKED_INVALID,
            0x800700C1 => WIN32::ERROR_BAD_EXE_FORMAT,
            0x800700C2 => WIN32::ERROR_ITERATED_DATA_EXCEEDS_64k,
            0x800700C3 => WIN32::ERROR_INVALID_MINALLOCSIZE,
            0x800700C4 => WIN32::ERROR_DYNLINK_FROM_INVALID_RING,
            0x800700C5 => WIN32::ERROR_IOPL_NOT_ENABLED,
            0x800700C6 => WIN32::ERROR_INVALID_SEGDPL,
            0x800700C7 => WIN32::ERROR_AUTODATASEG_EXCEEDS_64k,
            0x800700C8 => WIN32::ERROR_RING2SEG_MUST_BE_MOVABLE,
            0x800700C9 => WIN32::ERROR_RELOC_CHAIN_XEEDS_SEGLIM,
            0x800700CA => WIN32::ERROR_INFLOOP_IN_RELOC_CHAIN,
            0x800700CB => WIN32::ERROR_ENVVAR_NOT_FOUND,
            0x800700CD => WIN32::ERROR_NO_SIGNAL_SENT,
            0x800700CE => WIN32::ERROR_FILENAME_EXCED_RANGE,
            0x800700CF => WIN32::ERROR_RING2_STACK_IN_USE,
            0x800700D0 => WIN32::ERROR_META_EXPANSION_TOO_LONG,
            0x800700D1 => WIN32::ERROR_INVALID_SIGNAL_NUMBER,
            0x800700D2 => WIN32::ERROR_THREAD_1_INACTIVE,
            0x800700D4 => WIN32::ERROR_LOCKED,
            0x800700D6 => WIN32::ERROR_TOO_MANY_MODULES,
            0x800700D7 => WIN32::ERROR_NESTING_NOT_ALLOWED,
            0x800700D8 => WIN32::ERROR_EXE_MACHINE_TYPE_MISMATCH,
            0x800700D9 => WIN32::ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY,
            0x800700DA => WIN32::ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY,
            0x800700DC => WIN32::ERROR_FILE_CHECKED_OUT,
            0x800700DD => WIN32::ERROR_CHECKOUT_REQUIRED,
            0x800700DE => WIN32::ERROR_BAD_FILE_TYPE,
            0x800700DF => WIN32::ERROR_FILE_TOO_LARGE,
            0x800700E0 => WIN32::ERROR_FORMS_AUTH_REQUIRED,
            0x800700E1 => WIN32::ERROR_VIRUS_INFECTED,
            0x800700E2 => WIN32::ERROR_VIRUS_DELETED,
            0x800700E5 => WIN32::ERROR_PIPE_LOCAL,
            0x800700E6 => WIN32::ERROR_BAD_PIPE,
            0x800700E7 => WIN32::ERROR_PIPE_BUSY,
            0x800700E8 => WIN32::ERROR_NO_DATA,
            0x800700E9 => WIN32::ERROR_PIPE_NOT_CONNECTED,
            0x800700EA => WIN32::ERROR_MORE_DATA,
            0x800700EB => WIN32::ERROR_NO_WORK_DONE,
            0x800700F0 => WIN32::ERROR_VC_DISCONNECTED,
            0x800700FE => WIN32::ERROR_INVALID_EA_NAME,
            0x800700FF => WIN32::ERROR_EA_LIST_INCONSISTENT,
            0x80070102 => WIN32::WAIT_TIMEOUT,
            0x80070103 => WIN32::ERROR_NO_MORE_ITEMS,
            0x8007010A => WIN32::ERROR_CANNOT_COPY,
            0x8007010B => WIN32::ERROR_DIRECTORY,
            0x80070113 => WIN32::ERROR_EAS_DIDNT_FIT,
            0x80070114 => WIN32::ERROR_EA_FILE_CORRUPT,
            0x80070115 => WIN32::ERROR_EA_TABLE_FULL,
            0x80070116 => WIN32::ERROR_INVALID_EA_HANDLE,
            0x8007011A => WIN32::ERROR_EAS_NOT_SUPPORTED,
            0x80070120 => WIN32::ERROR_NOT_OWNER,
            0x8007012A => WIN32::ERROR_TOO_MANY_POSTS,
            0x8007012B => WIN32::ERROR_PARTIAL_COPY,
            0x8007012C => WIN32::ERROR_OPLOCK_NOT_GRANTED,
            0x8007012D => WIN32::ERROR_INVALID_OPLOCK_PROTOCOL,
            0x8007012E => WIN32::ERROR_DISK_TOO_FRAGMENTED,
            0x8007012F => WIN32::ERROR_DELETE_PENDING,
            0x80070130 => WIN32::ERROR_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING,
            0x80070131 => WIN32::ERROR_SHORT_NAMES_NOT_ENABLED_ON_VOLUME,
            0x80070132 => WIN32::ERROR_SECURITY_STREAM_IS_INCONSISTENT,
            0x80070133 => WIN32::ERROR_INVALID_LOCK_RANGE,
            0x80070134 => WIN32::ERROR_IMAGE_SUBSYSTEM_NOT_PRESENT,
            0x80070135 => WIN32::ERROR_NOTIFICATION_GUID_ALREADY_DEFINED,
            0x80070136 => WIN32::ERROR_INVALID_EXCEPTION_HANDLER,
            0x80070137 => WIN32::ERROR_DUPLICATE_PRIVILEGES,
            0x80070138 => WIN32::ERROR_NO_RANGES_PROCESSED,
            0x80070139 => WIN32::ERROR_NOT_ALLOWED_ON_SYSTEM_FILE,
            0x8007013A => WIN32::ERROR_DISK_RESOURCES_EXHAUSTED,
            0x8007013B => WIN32::ERROR_INVALID_TOKEN,
            0x8007013C => WIN32::ERROR_DEVICE_FEATURE_NOT_SUPPORTED,
            0x8007013D => WIN32::ERROR_MR_MID_NOT_FOUND,
            0x8007013E => WIN32::ERROR_SCOPE_NOT_FOUND,
            0x8007013F => WIN32::ERROR_UNDEFINED_SCOPE,
            0x80070140 => WIN32::ERROR_INVALID_CAP,
            0x80070141 => WIN32::ERROR_DEVICE_UNREACHABLE,
            0x80070142 => WIN32::ERROR_DEVICE_NO_RESOURCES,
            0x80070143 => WIN32::ERROR_DATA_CHECKSUM_ERROR,
            0x80070144 => WIN32::ERROR_INTERMIXED_KERNEL_EA_OPERATION,
            0x80070146 => WIN32::ERROR_FILE_LEVEL_TRIM_NOT_SUPPORTED,
            0x80070147 => WIN32::ERROR_OFFSET_ALIGNMENT_VIOLATION,
            0x80070148 => WIN32::ERROR_INVALID_FIELD_IN_PARAMETER_LIST,
            0x80070149 => WIN32::ERROR_OPERATION_IN_PROGRESS,
            0x8007014A => WIN32::ERROR_BAD_DEVICE_PATH,
            0x8007014B => WIN32::ERROR_TOO_MANY_DESCRIPTORS,
            0x8007014C => WIN32::ERROR_SCRUB_DATA_DISABLED,
            0x8007014D => WIN32::ERROR_NOT_REDUNDANT_STORAGE,
            0x8007014E => WIN32::ERROR_RESIDENT_FILE_NOT_SUPPORTED,
            0x8007014F => WIN32::ERROR_COMPRESSED_FILE_NOT_SUPPORTED,
            0x80070150 => WIN32::ERROR_DIRECTORY_NOT_SUPPORTED,
            0x80070151 => WIN32::ERROR_NOT_READ_FROM_COPY,
            0x80070152 => WIN32::ERROR_FT_WRITE_FAILURE,
            0x80070153 => WIN32::ERROR_FT_DI_SCAN_REQUIRED,
            0x80070154 => WIN32::ERROR_INVALID_KERNEL_INFO_VERSION,
            0x80070155 => WIN32::ERROR_INVALID_PEP_INFO_VERSION,
            0x80070156 => WIN32::ERROR_OBJECT_NOT_EXTERNALLY_BACKED,
            0x80070157 => WIN32::ERROR_EXTERNAL_BACKING_PROVIDER_UNKNOWN,
            0x80070158 => WIN32::ERROR_COMPRESSION_NOT_BENEFICIAL,
            0x80070159 => WIN32::ERROR_STORAGE_TOPOLOGY_ID_MISMATCH,
            0x8007015A => WIN32::ERROR_BLOCKED_BY_PARENTAL_CONTROLS,
            0x8007015B => WIN32::ERROR_BLOCK_TOO_MANY_REFERENCES,
            0x8007015C => WIN32::ERROR_MARKED_TO_DISALLOW_WRITES,
            0x8007015D => WIN32::ERROR_ENCLAVE_FAILURE,
            0x8007015E => WIN32::ERROR_FAIL_NOACTION_REBOOT,
            0x8007015F => WIN32::ERROR_FAIL_SHUTDOWN,
            0x80070160 => WIN32::ERROR_FAIL_RESTART,
            0x80070161 => WIN32::ERROR_MAX_SESSIONS_REACHED,
            0x80070162 => WIN32::ERROR_NETWORK_ACCESS_DENIED_EDP,
            0x80070163 => WIN32::ERROR_DEVICE_HINT_NAME_BUFFER_TOO_SMALL,
            0x80070164 => WIN32::ERROR_EDP_POLICY_DENIES_OPERATION,
            0x80070165 => WIN32::ERROR_EDP_DPL_POLICY_CANT_BE_SATISFIED,
            0x80070166 => WIN32::ERROR_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT,
            0x80070166 => WIN32::ERROR_CLOUD_FILE_PROVIDER_UNKNOWN,
            0x80070167 => WIN32::ERROR_DEVICE_IN_MAINTENANCE,
            0x80070168 => WIN32::ERROR_NOT_SUPPORTED_ON_DAX,
            0x80070169 => WIN32::ERROR_DAX_MAPPING_EXISTS,
            0x8007016A => WIN32::ERROR_CLOUD_FILE_PROVIDER_NOT_RUNNING,
            0x8007016B => WIN32::ERROR_CLOUD_FILE_METADATA_CORRUPT,
            0x8007016C => WIN32::ERROR_CLOUD_FILE_METADATA_TOO_LARGE,
            0x8007016D => WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE,
            0x8007016E => WIN32::ERROR_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH,
            0x8007016F => WIN32::ERROR_CHILD_PROCESS_BLOCKED,
            0x80070170 => WIN32::ERROR_STORAGE_LOST_DATA_PERSISTENCE,
            0x80070171 => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE,
            0x80070172 => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT,
            0x80070173 => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_BUSY,
            0x80070174 => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN,
            0x80070175 => WIN32::ERROR_GDI_HANDLE_LEAK,
            0x80070176 => WIN32::ERROR_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS,
            0x80070177 => WIN32::ERROR_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED,
            0x80070177 => WIN32::ERROR_CLOUD_FILE_METADATA_VERSION_NOT_SUPPORTED,
            0x80070178 => WIN32::ERROR_NOT_A_CLOUD_FILE,
            0x80070179 => WIN32::ERROR_CLOUD_FILE_NOT_IN_SYNC,
            0x8007017A => WIN32::ERROR_CLOUD_FILE_ALREADY_CONNECTED,
            0x8007017B => WIN32::ERROR_CLOUD_FILE_NOT_SUPPORTED,
            0x8007017C => WIN32::ERROR_CLOUD_FILE_INVALID_REQUEST,
            0x8007017D => WIN32::ERROR_CLOUD_FILE_READ_ONLY_VOLUME,
            0x8007017E => WIN32::ERROR_CLOUD_FILE_CONNECTED_PROVIDER_ONLY,
            0x8007017F => WIN32::ERROR_CLOUD_FILE_VALIDATION_FAILED,
            0x80070180 => WIN32::ERROR_SMB1_NOT_AVAILABLE,
            0x80070181 => WIN32::ERROR_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION,
            0x80070182 => WIN32::ERROR_CLOUD_FILE_AUTHENTICATION_FAILED,
            0x80070183 => WIN32::ERROR_CLOUD_FILE_INSUFFICIENT_RESOURCES,
            0x80070184 => WIN32::ERROR_CLOUD_FILE_NETWORK_UNAVAILABLE,
            0x80070185 => WIN32::ERROR_CLOUD_FILE_UNSUCCESSFUL,
            0x80070186 => WIN32::ERROR_CLOUD_FILE_NOT_UNDER_SYNC_ROOT,
            0x80070187 => WIN32::ERROR_CLOUD_FILE_IN_USE,
            0x80070188 => WIN32::ERROR_CLOUD_FILE_PINNED,
            0x80070189 => WIN32::ERROR_CLOUD_FILE_REQUEST_ABORTED,
            0x8007018A => WIN32::ERROR_CLOUD_FILE_PROPERTY_CORRUPT,
            0x8007018B => WIN32::ERROR_CLOUD_FILE_ACCESS_DENIED,
            0x8007018C => WIN32::ERROR_CLOUD_FILE_INCOMPATIBLE_HARDLINKS,
            0x8007018D => WIN32::ERROR_CLOUD_FILE_PROPERTY_LOCK_CONFLICT,
            0x8007018E => WIN32::ERROR_CLOUD_FILE_REQUEST_CANCELED,
            0x8007018F => WIN32::ERROR_EXTERNAL_SYSKEY_NOT_SUPPORTED,
            0x80070190 => WIN32::ERROR_THREAD_MODE_ALREADY_BACKGROUND,
            0x80070191 => WIN32::ERROR_THREAD_MODE_NOT_BACKGROUND,
            0x80070192 => WIN32::ERROR_PROCESS_MODE_ALREADY_BACKGROUND,
            0x80070193 => WIN32::ERROR_PROCESS_MODE_NOT_BACKGROUND,
            0x80070194 => WIN32::ERROR_CLOUD_FILE_PROVIDER_TERMINATED,
            0x80070195 => WIN32::ERROR_NOT_A_CLOUD_SYNC_ROOT,
            0x80070196 => WIN32::ERROR_FILE_PROTECTED_UNDER_DPL,
            0x80070197 => WIN32::ERROR_VOLUME_NOT_CLUSTER_ALIGNED,
            0x80070198 => WIN32::ERROR_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND,
            0x80070199 => WIN32::ERROR_APPX_FILE_NOT_ENCRYPTED,
            0x8007019A => WIN32::ERROR_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED,
            0x8007019B => WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET,
            0x8007019C => WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE,
            0x8007019D => WIN32::ERROR_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER,
            0x8007019E => WIN32::ERROR_LINUX_SUBSYSTEM_NOT_PRESENT,
            0x8007019F => WIN32::ERROR_FT_READ_FAILURE,
            0x800701A0 => WIN32::ERROR_STORAGE_RESERVE_ID_INVALID,
            0x800701A1 => WIN32::ERROR_STORAGE_RESERVE_DOES_NOT_EXIST,
            0x800701A2 => WIN32::ERROR_STORAGE_RESERVE_ALREADY_EXISTS,
            0x800701A3 => WIN32::ERROR_STORAGE_RESERVE_NOT_EMPTY,
            0x800701A4 => WIN32::ERROR_NOT_A_DAX_VOLUME,
            0x800701A5 => WIN32::ERROR_NOT_DAX_MAPPABLE,
            0x800701A6 => WIN32::ERROR_TIME_SENSITIVE_THREAD,
            0x800701A7 => WIN32::ERROR_DPL_NOT_SUPPORTED_FOR_USER,
            0x800701A8 => WIN32::ERROR_CASE_DIFFERING_NAMES_IN_DIR,
            0x800701A9 => WIN32::ERROR_FILE_NOT_SUPPORTED,
            0x800701AA => WIN32::ERROR_CLOUD_FILE_REQUEST_TIMEOUT,
            0x800701AB => WIN32::ERROR_NO_TASK_QUEUE,
            0x800701AC => WIN32::ERROR_SRC_SRV_DLL_LOAD_FAILED,
            0x800701AD => WIN32::ERROR_NOT_SUPPORTED_WITH_BTT,
            0x800701AE => WIN32::ERROR_ENCRYPTION_DISABLED,
            0x800701AF => WIN32::ERROR_ENCRYPTING_METADATA_DISALLOWED,
            0x800701B0 => WIN32::ERROR_CANT_CLEAR_ENCRYPTION_FLAG,
            0x800701B1 => WIN32::ERROR_NO_SUCH_DEVICE,
            0x800701B2 => WIN32::ERROR_CLOUD_FILE_DEHYDRATION_DISALLOWED,
            0x800701B3 => WIN32::ERROR_FILE_SNAP_IN_PROGRESS,
            0x800701B4 => WIN32::ERROR_FILE_SNAP_USER_SECTION_NOT_SUPPORTED,
            0x800701B5 => WIN32::ERROR_FILE_SNAP_MODIFY_NOT_SUPPORTED,
            0x800701B6 => WIN32::ERROR_FILE_SNAP_IO_NOT_COORDINATED,
            0x800701B7 => WIN32::ERROR_FILE_SNAP_UNEXPECTED_ERROR,
            0x800701B8 => WIN32::ERROR_FILE_SNAP_INVALID_PARAMETER,
            0x800701B9 => WIN32::ERROR_UNSATISFIED_DEPENDENCIES,
            0x800701BA => WIN32::ERROR_CASE_SENSITIVE_PATH,
            0x800701BB => WIN32::ERROR_UNEXPECTED_NTCACHEMANAGER_ERROR,
            0x800701BC => WIN32::ERROR_LINUX_SUBSYSTEM_UPDATE_REQUIRED,
            0x800701BD => WIN32::ERROR_DLP_POLICY_WARNS_AGAINST_OPERATION,
            0x800701BE => WIN32::ERROR_DLP_POLICY_DENIES_OPERATION,
            0x800701BF => WIN32::ERROR_SECURITY_DENIES_OPERATION,
            0x800701C0 => WIN32::ERROR_UNTRUSTED_MOUNT_POINT,
            0x800701C1 => WIN32::ERROR_DLP_POLICY_SILENTLY_FAIL,
            0x800701C2 => WIN32::ERROR_CAPAUTHZ_NOT_DEVUNLOCKED,
            0x800701C3 => WIN32::ERROR_CAPAUTHZ_CHANGE_TYPE,
            0x800701C4 => WIN32::ERROR_CAPAUTHZ_NOT_PROVISIONED,
            0x800701C5 => WIN32::ERROR_CAPAUTHZ_NOT_AUTHORIZED,
            0x800701C6 => WIN32::ERROR_CAPAUTHZ_NO_POLICY,
            0x800701C7 => WIN32::ERROR_CAPAUTHZ_DB_CORRUPTED,
            0x800701C8 => WIN32::ERROR_CAPAUTHZ_SCCD_INVALID_CATALOG,
            0x800701C9 => WIN32::ERROR_CAPAUTHZ_SCCD_NO_AUTH_ENTITY,
            0x800701CA => WIN32::ERROR_CAPAUTHZ_SCCD_PARSE_ERROR,
            0x800701CB => WIN32::ERROR_CAPAUTHZ_SCCD_DEV_MODE_REQUIRED,
            0x800701CC => WIN32::ERROR_CAPAUTHZ_SCCD_NO_CAPABILITY_MATCH,
            0x800701D6 => WIN32::ERROR_CIMFS_IMAGE_CORRUPT,
            0x800701D7 => WIN32::ERROR_CIMFS_IMAGE_VERSION_NOT_SUPPORTED,
            0x800701D8 => WIN32::ERROR_STORAGE_STACK_ACCESS_DENIED,
            0x800701D9 => WIN32::ERROR_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES,
            0x800701DA => WIN32::ERROR_INDEX_OUT_OF_BOUNDS,
            0x800701DB => WIN32::ERROR_CLOUD_FILE_US_MESSAGE_TIMEOUT,
            0x800701E0 => WIN32::ERROR_PNP_QUERY_REMOVE_DEVICE_TIMEOUT,
            0x800701E1 => WIN32::ERROR_PNP_QUERY_REMOVE_RELATED_DEVICE_TIMEOUT,
            0x800701E2 => WIN32::ERROR_PNP_QUERY_REMOVE_UNRELATED_DEVICE_TIMEOUT,
            0x800701E3 => WIN32::ERROR_DEVICE_HARDWARE_ERROR,
            0x800701E7 => WIN32::ERROR_INVALID_ADDRESS,
            0x800701E8 => WIN32::ERROR_HAS_SYSTEM_CRITICAL_FILES,
            0x800701E9 => WIN32::ERROR_ENCRYPTED_FILE_NOT_SUPPORTED,
            0x800701EA => WIN32::ERROR_SPARSE_FILE_NOT_SUPPORTED,
            0x800701EB => WIN32::ERROR_PAGEFILE_NOT_SUPPORTED,
            0x800701EC => WIN32::ERROR_VOLUME_NOT_SUPPORTED,
            0x800701ED => WIN32::ERROR_NOT_SUPPORTED_WITH_BYPASSIO,
            0x800701EE => WIN32::ERROR_NO_BYPASSIO_DRIVER_SUPPORT,
            0x800701EF => WIN32::ERROR_NOT_SUPPORTED_WITH_ENCRYPTION,
            0x800701F0 => WIN32::ERROR_NOT_SUPPORTED_WITH_COMPRESSION,
            0x800701F1 => WIN32::ERROR_NOT_SUPPORTED_WITH_REPLICATION,
            0x800701F2 => WIN32::ERROR_NOT_SUPPORTED_WITH_DEDUPLICATION,
            0x800701F3 => WIN32::ERROR_NOT_SUPPORTED_WITH_AUDITING,
            0x800701F4 => WIN32::ERROR_USER_PROFILE_LOAD,
            0x800701F5 => WIN32::ERROR_SESSION_KEY_TOO_SHORT,
            0x800701F6 => WIN32::ERROR_ACCESS_DENIED_APPDATA,
            0x800701F7 => WIN32::ERROR_NOT_SUPPORTED_WITH_MONITORING,
            0x800701F8 => WIN32::ERROR_NOT_SUPPORTED_WITH_SNAPSHOT,
            0x800701F9 => WIN32::ERROR_NOT_SUPPORTED_WITH_VIRTUALIZATION,
            0x800701FA => WIN32::ERROR_BYPASSIO_FLT_NOT_SUPPORTED,
            0x800701FB => WIN32::ERROR_DEVICE_RESET_REQUIRED,
            0x800701FC => WIN32::ERROR_VOLUME_WRITE_ACCESS_DENIED,
            0x800701FD => WIN32::ERROR_NOT_SUPPORTED_WITH_CACHED_HANDLE,
            0x800701FE => WIN32::ERROR_FS_METADATA_INCONSISTENT,
            0x800701FF => WIN32::ERROR_BLOCK_WEAK_REFERENCE_INVALID,
            0x80070200 => WIN32::ERROR_BLOCK_SOURCE_WEAK_REFERENCE_INVALID,
            0x80070201 => WIN32::ERROR_BLOCK_TARGET_WEAK_REFERENCE_INVALID,
            0x80070202 => WIN32::ERROR_BLOCK_SHARED,
            0x80070216 => WIN32::ERROR_ARITHMETIC_OVERFLOW,
            0x80070217 => WIN32::ERROR_PIPE_CONNECTED,
            0x80070218 => WIN32::ERROR_PIPE_LISTENING,
            0x80070219 => WIN32::ERROR_VERIFIER_STOP,
            0x8007021A => WIN32::ERROR_ABIOS_ERROR,
            0x8007021B => WIN32::ERROR_WX86_WARNING,
            0x8007021C => WIN32::ERROR_WX86_ERROR,
            0x8007021D => WIN32::ERROR_TIMER_NOT_CANCELED,
            0x8007021E => WIN32::ERROR_UNWIND,
            0x8007021F => WIN32::ERROR_BAD_STACK,
            0x80070220 => WIN32::ERROR_INVALID_UNWIND_TARGET,
            0x80070221 => WIN32::ERROR_INVALID_PORT_ATTRIBUTES,
            0x80070222 => WIN32::ERROR_PORT_MESSAGE_TOO_LONG,
            0x80070223 => WIN32::ERROR_INVALID_QUOTA_LOWER,
            0x80070224 => WIN32::ERROR_DEVICE_ALREADY_ATTACHED,
            0x80070225 => WIN32::ERROR_INSTRUCTION_MISALIGNMENT,
            0x80070226 => WIN32::ERROR_PROFILING_NOT_STARTED,
            0x80070227 => WIN32::ERROR_PROFILING_NOT_STOPPED,
            0x80070228 => WIN32::ERROR_COULD_NOT_INTERPRET,
            0x80070229 => WIN32::ERROR_PROFILING_AT_LIMIT,
            0x8007022A => WIN32::ERROR_CANT_WAIT,
            0x8007022B => WIN32::ERROR_CANT_TERMINATE_SELF,
            0x8007022C => WIN32::ERROR_UNEXPECTED_MM_CREATE_ERR,
            0x8007022D => WIN32::ERROR_UNEXPECTED_MM_MAP_ERROR,
            0x8007022E => WIN32::ERROR_UNEXPECTED_MM_EXTEND_ERR,
            0x8007022F => WIN32::ERROR_BAD_FUNCTION_TABLE,
            0x80070230 => WIN32::ERROR_NO_GUID_TRANSLATION,
            0x80070231 => WIN32::ERROR_INVALID_LDT_SIZE,
            0x80070233 => WIN32::ERROR_INVALID_LDT_OFFSET,
            0x80070234 => WIN32::ERROR_INVALID_LDT_DESCRIPTOR,
            0x80070235 => WIN32::ERROR_TOO_MANY_THREADS,
            0x80070236 => WIN32::ERROR_THREAD_NOT_IN_PROCESS,
            0x80070237 => WIN32::ERROR_PAGEFILE_QUOTA_EXCEEDED,
            0x80070238 => WIN32::ERROR_LOGON_SERVER_CONFLICT,
            0x80070239 => WIN32::ERROR_SYNCHRONIZATION_REQUIRED,
            0x8007023A => WIN32::ERROR_NET_OPEN_FAILED,
            0x8007023B => WIN32::ERROR_IO_PRIVILEGE_FAILED,
            0x8007023C => WIN32::ERROR_CONTROL_C_EXIT,
            0x8007023D => WIN32::ERROR_MISSING_SYSTEMFILE,
            0x8007023E => WIN32::ERROR_UNHANDLED_EXCEPTION,
            0x8007023F => WIN32::ERROR_APP_INIT_FAILURE,
            0x80070240 => WIN32::ERROR_PAGEFILE_CREATE_FAILED,
            0x80070241 => WIN32::ERROR_INVALID_IMAGE_HASH,
            0x80070242 => WIN32::ERROR_NO_PAGEFILE,
            0x80070243 => WIN32::ERROR_ILLEGAL_FLOAT_CONTEXT,
            0x80070244 => WIN32::ERROR_NO_EVENT_PAIR,
            0x80070245 => WIN32::ERROR_DOMAIN_CTRLR_CONFIG_ERROR,
            0x80070246 => WIN32::ERROR_ILLEGAL_CHARACTER,
            0x80070247 => WIN32::ERROR_UNDEFINED_CHARACTER,
            0x80070248 => WIN32::ERROR_FLOPPY_VOLUME,
            0x80070249 => WIN32::ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT,
            0x8007024A => WIN32::ERROR_BACKUP_CONTROLLER,
            0x8007024B => WIN32::ERROR_MUTANT_LIMIT_EXCEEDED,
            0x8007024C => WIN32::ERROR_FS_DRIVER_REQUIRED,
            0x8007024D => WIN32::ERROR_CANNOT_LOAD_REGISTRY_FILE,
            0x8007024E => WIN32::ERROR_DEBUG_ATTACH_FAILED,
            0x8007024F => WIN32::ERROR_SYSTEM_PROCESS_TERMINATED,
            0x80070250 => WIN32::ERROR_DATA_NOT_ACCEPTED,
            0x80070251 => WIN32::ERROR_VDM_HARD_ERROR,
            0x80070252 => WIN32::ERROR_DRIVER_CANCEL_TIMEOUT,
            0x80070253 => WIN32::ERROR_REPLY_MESSAGE_MISMATCH,
            0x80070254 => WIN32::ERROR_LOST_WRITEBEHIND_DATA,
            0x80070255 => WIN32::ERROR_CLIENT_SERVER_PARAMETERS_INVALID,
            0x80070256 => WIN32::ERROR_NOT_TINY_STREAM,
            0x80070257 => WIN32::ERROR_STACK_OVERFLOW_READ,
            0x80070258 => WIN32::ERROR_CONVERT_TO_LARGE,
            0x80070259 => WIN32::ERROR_FOUND_OUT_OF_SCOPE,
            0x8007025A => WIN32::ERROR_ALLOCATE_BUCKET,
            0x8007025B => WIN32::ERROR_MARSHALL_OVERFLOW,
            0x8007025C => WIN32::ERROR_INVALID_VARIANT,
            0x8007025D => WIN32::ERROR_BAD_COMPRESSION_BUFFER,
            0x8007025E => WIN32::ERROR_AUDIT_FAILED,
            0x8007025F => WIN32::ERROR_TIMER_RESOLUTION_NOT_SET,
            0x80070260 => WIN32::ERROR_INSUFFICIENT_LOGON_INFO,
            0x80070261 => WIN32::ERROR_BAD_DLL_ENTRYPOINT,
            0x80070262 => WIN32::ERROR_BAD_SERVICE_ENTRYPOINT,
            0x80070263 => WIN32::ERROR_IP_ADDRESS_CONFLICT1,
            0x80070264 => WIN32::ERROR_IP_ADDRESS_CONFLICT2,
            0x80070265 => WIN32::ERROR_REGISTRY_QUOTA_LIMIT,
            0x80070266 => WIN32::ERROR_NO_CALLBACK_ACTIVE,
            0x80070267 => WIN32::ERROR_PWD_TOO_SHORT,
            0x80070268 => WIN32::ERROR_PWD_TOO_RECENT,
            0x80070269 => WIN32::ERROR_PWD_HISTORY_CONFLICT,
            0x8007026A => WIN32::ERROR_UNSUPPORTED_COMPRESSION,
            0x8007026B => WIN32::ERROR_INVALID_HW_PROFILE,
            0x8007026C => WIN32::ERROR_INVALID_PLUGPLAY_DEVICE_PATH,
            0x8007026D => WIN32::ERROR_QUOTA_LIST_INCONSISTENT,
            0x8007026E => WIN32::ERROR_EVALUATION_EXPIRATION,
            0x8007026F => WIN32::ERROR_ILLEGAL_DLL_RELOCATION,
            0x80070270 => WIN32::ERROR_DLL_INIT_FAILED_LOGOFF,
            0x80070271 => WIN32::ERROR_VALIDATE_CONTINUE,
            0x80070272 => WIN32::ERROR_NO_MORE_MATCHES,
            0x80070273 => WIN32::ERROR_RANGE_LIST_CONFLICT,
            0x80070274 => WIN32::ERROR_SERVER_SID_MISMATCH,
            0x80070275 => WIN32::ERROR_CANT_ENABLE_DENY_ONLY,
            0x80070276 => WIN32::ERROR_FLOAT_MULTIPLE_FAULTS,
            0x80070277 => WIN32::ERROR_FLOAT_MULTIPLE_TRAPS,
            0x80070278 => WIN32::ERROR_NOINTERFACE,
            0x80070279 => WIN32::ERROR_DRIVER_FAILED_SLEEP,
            0x8007027A => WIN32::ERROR_CORRUPT_SYSTEM_FILE,
            0x8007027B => WIN32::ERROR_COMMITMENT_MINIMUM,
            0x8007027C => WIN32::ERROR_PNP_RESTART_ENUMERATION,
            0x8007027D => WIN32::ERROR_SYSTEM_IMAGE_BAD_SIGNATURE,
            0x8007027E => WIN32::ERROR_PNP_REBOOT_REQUIRED,
            0x8007027F => WIN32::ERROR_INSUFFICIENT_POWER,
            0x80070280 => WIN32::ERROR_MULTIPLE_FAULT_VIOLATION,
            0x80070281 => WIN32::ERROR_SYSTEM_SHUTDOWN,
            0x80070282 => WIN32::ERROR_PORT_NOT_SET,
            0x80070283 => WIN32::ERROR_DS_VERSION_CHECK_FAILURE,
            0x80070284 => WIN32::ERROR_RANGE_NOT_FOUND,
            0x80070286 => WIN32::ERROR_NOT_SAFE_MODE_DRIVER,
            0x80070287 => WIN32::ERROR_FAILED_DRIVER_ENTRY,
            0x80070288 => WIN32::ERROR_DEVICE_ENUMERATION_ERROR,
            0x80070289 => WIN32::ERROR_MOUNT_POINT_NOT_RESOLVED,
            0x8007028A => WIN32::ERROR_INVALID_DEVICE_OBJECT_PARAMETER,
            0x8007028B => WIN32::ERROR_MCA_OCCURED,
            0x8007028C => WIN32::ERROR_DRIVER_DATABASE_ERROR,
            0x8007028D => WIN32::ERROR_SYSTEM_HIVE_TOO_LARGE,
            0x8007028E => WIN32::ERROR_DRIVER_FAILED_PRIOR_UNLOAD,
            0x8007028F => WIN32::ERROR_VOLSNAP_PREPARE_HIBERNATE,
            0x80070290 => WIN32::ERROR_HIBERNATION_FAILURE,
            0x80070291 => WIN32::ERROR_PWD_TOO_LONG,
            0x80070299 => WIN32::ERROR_FILE_SYSTEM_LIMITATION,
            0x8007029C => WIN32::ERROR_ASSERTION_FAILURE,
            0x8007029D => WIN32::ERROR_ACPI_ERROR,
            0x8007029E => WIN32::ERROR_WOW_ASSERTION,
            0x8007029F => WIN32::ERROR_PNP_BAD_MPS_TABLE,
            0x800702A0 => WIN32::ERROR_PNP_TRANSLATION_FAILED,
            0x800702A1 => WIN32::ERROR_PNP_IRQ_TRANSLATION_FAILED,
            0x800702A2 => WIN32::ERROR_PNP_INVALID_ID,
            0x800702A3 => WIN32::ERROR_WAKE_SYSTEM_DEBUGGER,
            0x800702A4 => WIN32::ERROR_HANDLES_CLOSED,
            0x800702A5 => WIN32::ERROR_EXTRANEOUS_INFORMATION,
            0x800702A6 => WIN32::ERROR_RXACT_COMMIT_NECESSARY,
            0x800702A7 => WIN32::ERROR_MEDIA_CHECK,
            0x800702A8 => WIN32::ERROR_GUID_SUBSTITUTION_MADE,
            0x800702A9 => WIN32::ERROR_STOPPED_ON_SYMLINK,
            0x800702AA => WIN32::ERROR_LONGJUMP,
            0x800702AB => WIN32::ERROR_PLUGPLAY_QUERY_VETOED,
            0x800702AC => WIN32::ERROR_UNWIND_CONSOLIDATE,
            0x800702AD => WIN32::ERROR_REGISTRY_HIVE_RECOVERED,
            0x800702AE => WIN32::ERROR_DLL_MIGHT_BE_INSECURE,
            0x800702AF => WIN32::ERROR_DLL_MIGHT_BE_INCOMPATIBLE,
            0x800702B0 => WIN32::ERROR_DBG_EXCEPTION_NOT_HANDLED,
            0x800702B1 => WIN32::ERROR_DBG_REPLY_LATER,
            0x800702B2 => WIN32::ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE,
            0x800702B3 => WIN32::ERROR_DBG_TERMINATE_THREAD,
            0x800702B4 => WIN32::ERROR_DBG_TERMINATE_PROCESS,
            0x800702B5 => WIN32::ERROR_DBG_CONTROL_C,
            0x800702B6 => WIN32::ERROR_DBG_PRINTEXCEPTION_C,
            0x800702B7 => WIN32::ERROR_DBG_RIPEXCEPTION,
            0x800702B8 => WIN32::ERROR_DBG_CONTROL_BREAK,
            0x800702B9 => WIN32::ERROR_DBG_COMMAND_EXCEPTION,
            0x800702BA => WIN32::ERROR_OBJECT_NAME_EXISTS,
            0x800702BB => WIN32::ERROR_THREAD_WAS_SUSPENDED,
            0x800702BC => WIN32::ERROR_IMAGE_NOT_AT_BASE,
            0x800702BD => WIN32::ERROR_RXACT_STATE_CREATED,
            0x800702BE => WIN32::ERROR_SEGMENT_NOTIFICATION,
            0x800702BF => WIN32::ERROR_BAD_CURRENT_DIRECTORY,
            0x800702C0 => WIN32::ERROR_FT_READ_RECOVERY_FROM_BACKUP,
            0x800702C1 => WIN32::ERROR_FT_WRITE_RECOVERY,
            0x800702C2 => WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH,
            0x800702C3 => WIN32::ERROR_RECEIVE_PARTIAL,
            0x800702C4 => WIN32::ERROR_RECEIVE_EXPEDITED,
            0x800702C5 => WIN32::ERROR_RECEIVE_PARTIAL_EXPEDITED,
            0x800702C6 => WIN32::ERROR_EVENT_DONE,
            0x800702C7 => WIN32::ERROR_EVENT_PENDING,
            0x800702C8 => WIN32::ERROR_CHECKING_FILE_SYSTEM,
            0x800702C9 => WIN32::ERROR_FATAL_APP_EXIT,
            0x800702CA => WIN32::ERROR_PREDEFINED_HANDLE,
            0x800702CB => WIN32::ERROR_WAS_UNLOCKED,
            0x800702CC => WIN32::ERROR_SERVICE_NOTIFICATION,
            0x800702CD => WIN32::ERROR_WAS_LOCKED,
            0x800702CE => WIN32::ERROR_LOG_HARD_ERROR,
            0x800702CF => WIN32::ERROR_ALREADY_WIN32,
            0x800702D0 => WIN32::ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE,
            0x800702D1 => WIN32::ERROR_NO_YIELD_PERFORMED,
            0x800702D2 => WIN32::ERROR_TIMER_RESUME_IGNORED,
            0x800702D3 => WIN32::ERROR_ARBITRATION_UNHANDLED,
            0x800702D4 => WIN32::ERROR_CARDBUS_NOT_SUPPORTED,
            0x800702D5 => WIN32::ERROR_MP_PROCESSOR_MISMATCH,
            0x800702D6 => WIN32::ERROR_HIBERNATED,
            0x800702D7 => WIN32::ERROR_RESUME_HIBERNATION,
            0x800702D8 => WIN32::ERROR_FIRMWARE_UPDATED,
            0x800702D9 => WIN32::ERROR_DRIVERS_LEAKING_LOCKED_PAGES,
            0x800702DA => WIN32::ERROR_WAKE_SYSTEM,
            0x800702DB => WIN32::ERROR_WAIT_1,
            0x800702DC => WIN32::ERROR_WAIT_2,
            0x800702DD => WIN32::ERROR_WAIT_3,
            0x800702DE => WIN32::ERROR_WAIT_63,
            0x800702DF => WIN32::ERROR_ABANDONED_WAIT_0,
            0x800702E0 => WIN32::ERROR_ABANDONED_WAIT_63,
            0x800702E1 => WIN32::ERROR_USER_APC,
            0x800702E2 => WIN32::ERROR_KERNEL_APC,
            0x800702E3 => WIN32::ERROR_ALERTED,
            0x800702E4 => WIN32::ERROR_ELEVATION_REQUIRED,
            0x800702E5 => WIN32::ERROR_REPARSE,
            0x800702E6 => WIN32::ERROR_OPLOCK_BREAK_IN_PROGRESS,
            0x800702E7 => WIN32::ERROR_VOLUME_MOUNTED,
            0x800702E8 => WIN32::ERROR_RXACT_COMMITTED,
            0x800702E9 => WIN32::ERROR_NOTIFY_CLEANUP,
            0x800702EA => WIN32::ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED,
            0x800702EB => WIN32::ERROR_PAGE_FAULT_TRANSITION,
            0x800702EC => WIN32::ERROR_PAGE_FAULT_DEMAND_ZERO,
            0x800702ED => WIN32::ERROR_PAGE_FAULT_COPY_ON_WRITE,
            0x800702EE => WIN32::ERROR_PAGE_FAULT_GUARD_PAGE,
            0x800702EF => WIN32::ERROR_PAGE_FAULT_PAGING_FILE,
            0x800702F0 => WIN32::ERROR_CACHE_PAGE_LOCKED,
            0x800702F1 => WIN32::ERROR_CRASH_DUMP,
            0x800702F2 => WIN32::ERROR_BUFFER_ALL_ZEROS,
            0x800702F3 => WIN32::ERROR_REPARSE_OBJECT,
            0x800702F4 => WIN32::ERROR_RESOURCE_REQUIREMENTS_CHANGED,
            0x800702F5 => WIN32::ERROR_TRANSLATION_COMPLETE,
            0x800702F6 => WIN32::ERROR_NOTHING_TO_TERMINATE,
            0x800702F7 => WIN32::ERROR_PROCESS_NOT_IN_JOB,
            0x800702F8 => WIN32::ERROR_PROCESS_IN_JOB,
            0x800702F9 => WIN32::ERROR_VOLSNAP_HIBERNATE_READY,
            0x800702FA => WIN32::ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY,
            0x800702FB => WIN32::ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED,
            0x800702FC => WIN32::ERROR_INTERRUPT_STILL_CONNECTED,
            0x800702FD => WIN32::ERROR_WAIT_FOR_OPLOCK,
            0x800702FE => WIN32::ERROR_DBG_EXCEPTION_HANDLED,
            0x800702FF => WIN32::ERROR_DBG_CONTINUE,
            0x80070300 => WIN32::ERROR_CALLBACK_POP_STACK,
            0x80070301 => WIN32::ERROR_COMPRESSION_DISABLED,
            0x80070302 => WIN32::ERROR_CANTFETCHBACKWARDS,
            0x80070303 => WIN32::ERROR_CANTSCROLLBACKWARDS,
            0x80070304 => WIN32::ERROR_ROWSNOTRELEASED,
            0x80070305 => WIN32::ERROR_BAD_ACCESSOR_FLAGS,
            0x80070306 => WIN32::ERROR_ERRORS_ENCOUNTERED,
            0x80070307 => WIN32::ERROR_NOT_CAPABLE,
            0x80070308 => WIN32::ERROR_REQUEST_OUT_OF_SEQUENCE,
            0x80070309 => WIN32::ERROR_VERSION_PARSE_ERROR,
            0x8007030A => WIN32::ERROR_BADSTARTPOSITION,
            0x8007030B => WIN32::ERROR_MEMORY_HARDWARE,
            0x8007030C => WIN32::ERROR_DISK_REPAIR_DISABLED,
            0x8007030D => WIN32::ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE,
            0x8007030E => WIN32::ERROR_SYSTEM_POWERSTATE_TRANSITION,
            0x8007030F => WIN32::ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION,
            0x80070310 => WIN32::ERROR_MCA_EXCEPTION,
            0x80070311 => WIN32::ERROR_ACCESS_AUDIT_BY_POLICY,
            0x80070312 => WIN32::ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY,
            0x80070313 => WIN32::ERROR_ABANDON_HIBERFILE,
            0x80070314 => WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED,
            0x80070315 => WIN32::ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR,
            0x80070316 => WIN32::ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR,
            0x80070317 => WIN32::ERROR_BAD_MCFG_TABLE,
            0x80070318 => WIN32::ERROR_DISK_REPAIR_REDIRECTED,
            0x80070319 => WIN32::ERROR_DISK_REPAIR_UNSUCCESSFUL,
            0x8007031A => WIN32::ERROR_CORRUPT_LOG_OVERFULL,
            0x8007031B => WIN32::ERROR_CORRUPT_LOG_CORRUPTED,
            0x8007031C => WIN32::ERROR_CORRUPT_LOG_UNAVAILABLE,
            0x8007031D => WIN32::ERROR_CORRUPT_LOG_DELETED_FULL,
            0x8007031E => WIN32::ERROR_CORRUPT_LOG_CLEARED,
            0x8007031F => WIN32::ERROR_ORPHAN_NAME_EXHAUSTED,
            0x80070320 => WIN32::ERROR_OPLOCK_SWITCHED_TO_NEW_HANDLE,
            0x80070321 => WIN32::ERROR_CANNOT_GRANT_REQUESTED_OPLOCK,
            0x80070322 => WIN32::ERROR_CANNOT_BREAK_OPLOCK,
            0x80070323 => WIN32::ERROR_OPLOCK_HANDLE_CLOSED,
            0x80070324 => WIN32::ERROR_NO_ACE_CONDITION,
            0x80070325 => WIN32::ERROR_INVALID_ACE_CONDITION,
            0x80070326 => WIN32::ERROR_FILE_HANDLE_REVOKED,
            0x80070327 => WIN32::ERROR_IMAGE_AT_DIFFERENT_BASE,
            0x80070328 => WIN32::ERROR_ENCRYPTED_IO_NOT_POSSIBLE,
            0x80070329 => WIN32::ERROR_FILE_METADATA_OPTIMIZATION_IN_PROGRESS,
            0x8007032A => WIN32::ERROR_QUOTA_ACTIVITY,
            0x8007032B => WIN32::ERROR_HANDLE_REVOKED,
            0x8007032C => WIN32::ERROR_CALLBACK_INVOKE_INLINE,
            0x8007032D => WIN32::ERROR_CPU_SET_INVALID,
            0x8007032E => WIN32::ERROR_ENCLAVE_NOT_TERMINATED,
            0x8007032F => WIN32::ERROR_ENCLAVE_VIOLATION,
            0x80070330 => WIN32::ERROR_SERVER_TRANSPORT_CONFLICT,
            0x80070331 => WIN32::ERROR_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT,
            0x80070332 => WIN32::ERROR_FT_READ_FROM_COPY_FAILURE,
            0x80070333 => WIN32::ERROR_SECTION_DIRECT_MAP_ONLY,
            0x800703E2 => WIN32::ERROR_EA_ACCESS_DENIED,
            0x800703E3 => WIN32::ERROR_OPERATION_ABORTED,
            0x800703E4 => WIN32::ERROR_IO_INCOMPLETE,
            0x800703E5 => WIN32::ERROR_IO_PENDING,
            0x800703E6 => WIN32::ERROR_NOACCESS,
            0x800703E7 => WIN32::ERROR_SWAPERROR,
            0x800703E9 => WIN32::ERROR_STACK_OVERFLOW,
            0x800703EA => WIN32::ERROR_INVALID_MESSAGE,
            0x800703EB => WIN32::ERROR_CAN_NOT_COMPLETE,
            0x800703EC => WIN32::ERROR_INVALID_FLAGS,
            0x800703ED => WIN32::ERROR_UNRECOGNIZED_VOLUME,
            0x800703EE => WIN32::ERROR_FILE_INVALID,
            0x800703EF => WIN32::ERROR_FULLSCREEN_MODE,
            0x800703F0 => WIN32::ERROR_NO_TOKEN,
            0x800703F1 => WIN32::ERROR_BADDB,
            0x800703F2 => WIN32::ERROR_BADKEY,
            0x800703F3 => WIN32::ERROR_CANTOPEN,
            0x800703F4 => WIN32::ERROR_CANTREAD,
            0x800703F5 => WIN32::ERROR_CANTWRITE,
            0x800703F6 => WIN32::ERROR_REGISTRY_RECOVERED,
            0x800703F7 => WIN32::ERROR_REGISTRY_CORRUPT,
            0x800703F8 => WIN32::ERROR_REGISTRY_IO_FAILED,
            0x800703F9 => WIN32::ERROR_NOT_REGISTRY_FILE,
            0x800703FA => WIN32::ERROR_KEY_DELETED,
            0x800703FB => WIN32::ERROR_NO_LOG_SPACE,
            0x800703FC => WIN32::ERROR_KEY_HAS_CHILDREN,
            0x800703FD => WIN32::ERROR_CHILD_MUST_BE_VOLATILE,
            0x800703FE => WIN32::ERROR_NOTIFY_ENUM_DIR,
            0x8007041B => WIN32::ERROR_DEPENDENT_SERVICES_RUNNING,
            0x8007041C => WIN32::ERROR_INVALID_SERVICE_CONTROL,
            0x8007041D => WIN32::ERROR_SERVICE_REQUEST_TIMEOUT,
            0x8007041E => WIN32::ERROR_SERVICE_NO_THREAD,
            0x8007041F => WIN32::ERROR_SERVICE_DATABASE_LOCKED,
            0x80070420 => WIN32::ERROR_SERVICE_ALREADY_RUNNING,
            0x80070421 => WIN32::ERROR_INVALID_SERVICE_ACCOUNT,
            0x80070422 => WIN32::ERROR_SERVICE_DISABLED,
            0x80070423 => WIN32::ERROR_CIRCULAR_DEPENDENCY,
            0x80070424 => WIN32::ERROR_SERVICE_DOES_NOT_EXIST,
            0x80070425 => WIN32::ERROR_SERVICE_CANNOT_ACCEPT_CTRL,
            0x80070426 => WIN32::ERROR_SERVICE_NOT_ACTIVE,
            0x80070427 => WIN32::ERROR_FAILED_SERVICE_CONTROLLER_CONNECT,
            0x80070428 => WIN32::ERROR_EXCEPTION_IN_SERVICE,
            0x80070429 => WIN32::ERROR_DATABASE_DOES_NOT_EXIST,
            0x8007042A => WIN32::ERROR_SERVICE_SPECIFIC_ERROR,
            0x8007042B => WIN32::ERROR_PROCESS_ABORTED,
            0x8007042C => WIN32::ERROR_SERVICE_DEPENDENCY_FAIL,
            0x8007042D => WIN32::ERROR_SERVICE_LOGON_FAILED,
            0x8007042E => WIN32::ERROR_SERVICE_START_HANG,
            0x8007042F => WIN32::ERROR_INVALID_SERVICE_LOCK,
            0x80070430 => WIN32::ERROR_SERVICE_MARKED_FOR_DELETE,
            0x80070431 => WIN32::ERROR_SERVICE_EXISTS,
            0x80070432 => WIN32::ERROR_ALREADY_RUNNING_LKG,
            0x80070433 => WIN32::ERROR_SERVICE_DEPENDENCY_DELETED,
            0x80070434 => WIN32::ERROR_BOOT_ALREADY_ACCEPTED,
            0x80070435 => WIN32::ERROR_SERVICE_NEVER_STARTED,
            0x80070436 => WIN32::ERROR_DUPLICATE_SERVICE_NAME,
            0x80070437 => WIN32::ERROR_DIFFERENT_SERVICE_ACCOUNT,
            0x80070438 => WIN32::ERROR_CANNOT_DETECT_DRIVER_FAILURE,
            0x80070439 => WIN32::ERROR_CANNOT_DETECT_PROCESS_ABORT,
            0x8007043A => WIN32::ERROR_NO_RECOVERY_PROGRAM,
            0x8007043B => WIN32::ERROR_SERVICE_NOT_IN_EXE,
            0x8007043C => WIN32::ERROR_NOT_SAFEBOOT_SERVICE,
            0x8007044C => WIN32::ERROR_END_OF_MEDIA,
            0x8007044D => WIN32::ERROR_FILEMARK_DETECTED,
            0x8007044E => WIN32::ERROR_BEGINNING_OF_MEDIA,
            0x8007044F => WIN32::ERROR_SETMARK_DETECTED,
            0x80070450 => WIN32::ERROR_NO_DATA_DETECTED,
            0x80070451 => WIN32::ERROR_PARTITION_FAILURE,
            0x80070452 => WIN32::ERROR_INVALID_BLOCK_LENGTH,
            0x80070453 => WIN32::ERROR_DEVICE_NOT_PARTITIONED,
            0x80070454 => WIN32::ERROR_UNABLE_TO_LOCK_MEDIA,
            0x80070455 => WIN32::ERROR_UNABLE_TO_UNLOAD_MEDIA,
            0x80070456 => WIN32::ERROR_MEDIA_CHANGED,
            0x80070457 => WIN32::ERROR_BUS_RESET,
            0x80070458 => WIN32::ERROR_NO_MEDIA_IN_DRIVE,
            0x80070459 => WIN32::ERROR_NO_UNICODE_TRANSLATION,
            0x8007045A => WIN32::ERROR_DLL_INIT_FAILED,
            0x8007045B => WIN32::ERROR_SHUTDOWN_IN_PROGRESS,
            0x8007045C => WIN32::ERROR_NO_SHUTDOWN_IN_PROGRESS,
            0x8007045D => WIN32::ERROR_IO_DEVICE,
            0x8007045E => WIN32::ERROR_SERIAL_NO_DEVICE,
            0x8007045F => WIN32::ERROR_IRQ_BUSY,
            0x80070460 => WIN32::ERROR_MORE_WRITES,
            0x80070461 => WIN32::ERROR_COUNTER_TIMEOUT,
            0x80070462 => WIN32::ERROR_FLOPPY_ID_MARK_NOT_FOUND,
            0x80070463 => WIN32::ERROR_FLOPPY_WRONG_CYLINDER,
            0x80070464 => WIN32::ERROR_FLOPPY_UNKNOWN_ERROR,
            0x80070465 => WIN32::ERROR_FLOPPY_BAD_REGISTERS,
            0x80070466 => WIN32::ERROR_DISK_RECALIBRATE_FAILED,
            0x80070467 => WIN32::ERROR_DISK_OPERATION_FAILED,
            0x80070468 => WIN32::ERROR_DISK_RESET_FAILED,
            0x80070469 => WIN32::ERROR_EOM_OVERFLOW,
            0x8007046A => WIN32::ERROR_NOT_ENOUGH_SERVER_MEMORY,
            0x8007046B => WIN32::ERROR_POSSIBLE_DEADLOCK,
            0x8007046C => WIN32::ERROR_MAPPED_ALIGNMENT,
            0x80070474 => WIN32::ERROR_SET_POWER_STATE_VETOED,
            0x80070475 => WIN32::ERROR_SET_POWER_STATE_FAILED,
            0x80070476 => WIN32::ERROR_TOO_MANY_LINKS,
            0x8007047E => WIN32::ERROR_OLD_WIN_VERSION,
            0x8007047F => WIN32::ERROR_APP_WRONG_OS,
            0x80070480 => WIN32::ERROR_SINGLE_INSTANCE_APP,
            0x80070481 => WIN32::ERROR_RMODE_APP,
            0x80070482 => WIN32::ERROR_INVALID_DLL,
            0x80070483 => WIN32::ERROR_NO_ASSOCIATION,
            0x80070484 => WIN32::ERROR_DDE_FAIL,
            0x80070485 => WIN32::ERROR_DLL_NOT_FOUND,
            0x80070486 => WIN32::ERROR_NO_MORE_USER_HANDLES,
            0x80070487 => WIN32::ERROR_MESSAGE_SYNC_ONLY,
            0x80070488 => WIN32::ERROR_SOURCE_ELEMENT_EMPTY,
            0x80070489 => WIN32::ERROR_DESTINATION_ELEMENT_FULL,
            0x8007048A => WIN32::ERROR_ILLEGAL_ELEMENT_ADDRESS,
            0x8007048B => WIN32::ERROR_MAGAZINE_NOT_PRESENT,
            0x8007048C => WIN32::ERROR_DEVICE_REINITIALIZATION_NEEDED,
            0x8007048D => WIN32::ERROR_DEVICE_REQUIRES_CLEANING,
            0x8007048E => WIN32::ERROR_DEVICE_DOOR_OPEN,
            0x8007048F => WIN32::ERROR_DEVICE_NOT_CONNECTED,
            0x80070490 => WIN32::ERROR_NOT_FOUND,
            0x80070490 => WIN32::E_PROP_ID_UNSUPPORTED,
            0x80070491 => WIN32::ERROR_NO_MATCH,
            0x80070492 => WIN32::ERROR_SET_NOT_FOUND,
            0x80070492 => WIN32::E_PROP_SET_UNSUPPORTED,
            0x80070493 => WIN32::ERROR_POINT_NOT_FOUND,
            0x80070494 => WIN32::ERROR_NO_TRACKING_SERVICE,
            0x80070495 => WIN32::ERROR_NO_VOLUME_ID,
            0x80070497 => WIN32::ERROR_UNABLE_TO_REMOVE_REPLACED,
            0x80070498 => WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT,
            0x80070499 => WIN32::ERROR_UNABLE_TO_MOVE_REPLACEMENT_2,
            0x8007049A => WIN32::ERROR_JOURNAL_DELETE_IN_PROGRESS,
            0x8007049B => WIN32::ERROR_JOURNAL_NOT_ACTIVE,
            0x8007049C => WIN32::ERROR_POTENTIAL_FILE_FOUND,
            0x8007049D => WIN32::ERROR_JOURNAL_ENTRY_DELETED,
            0x8007049F => WIN32::ERROR_VRF_CFG_ENABLED,
            0x800704A0 => WIN32::ERROR_PARTITION_TERMINATING,
            0x800704A6 => WIN32::ERROR_SHUTDOWN_IS_SCHEDULED,
            0x800704A7 => WIN32::ERROR_SHUTDOWN_USERS_LOGGED_ON,
            0x800704A8 => WIN32::ERROR_SHUTDOWN_DISKS_NOT_IN_MAINTENANCE_MODE,
            0x800704B0 => WIN32::ERROR_BAD_DEVICE,
            0x800704B1 => WIN32::ERROR_CONNECTION_UNAVAIL,
            0x800704B2 => WIN32::ERROR_DEVICE_ALREADY_REMEMBERED,
            0x800704B3 => WIN32::ERROR_NO_NET_OR_BAD_PATH,
            0x800704B4 => WIN32::ERROR_BAD_PROVIDER,
            0x800704B5 => WIN32::ERROR_CANNOT_OPEN_PROFILE,
            0x800704B6 => WIN32::ERROR_BAD_PROFILE,
            0x800704B7 => WIN32::ERROR_NOT_CONTAINER,
            0x800704B8 => WIN32::ERROR_EXTENDED_ERROR,
            0x800704B9 => WIN32::ERROR_INVALID_GROUPNAME,
            0x800704BA => WIN32::ERROR_INVALID_COMPUTERNAME,
            0x800704BB => WIN32::ERROR_INVALID_EVENTNAME,
            0x800704BC => WIN32::ERROR_INVALID_DOMAINNAME,
            0x800704BD => WIN32::ERROR_INVALID_SERVICENAME,
            0x800704BE => WIN32::ERROR_INVALID_NETNAME,
            0x800704BF => WIN32::ERROR_INVALID_SHARENAME,
            0x800704C0 => WIN32::ERROR_INVALID_PASSWORDNAME,
            0x800704C1 => WIN32::ERROR_INVALID_MESSAGENAME,
            0x800704C2 => WIN32::ERROR_INVALID_MESSAGEDEST,
            0x800704C3 => WIN32::ERROR_SESSION_CREDENTIAL_CONFLICT,
            0x800704C4 => WIN32::ERROR_REMOTE_SESSION_LIMIT_EXCEEDED,
            0x800704C5 => WIN32::ERROR_DUP_DOMAINNAME,
            0x800704C6 => WIN32::ERROR_NO_NETWORK,
            0x800704C7 => WIN32::ERROR_CANCELLED,
            0x800704C8 => WIN32::ERROR_USER_MAPPED_FILE,
            0x800704C9 => WIN32::ERROR_CONNECTION_REFUSED,
            0x800704CA => WIN32::ERROR_GRACEFUL_DISCONNECT,
            0x800704CB => WIN32::ERROR_ADDRESS_ALREADY_ASSOCIATED,
            0x800704CC => WIN32::ERROR_ADDRESS_NOT_ASSOCIATED,
            0x800704CD => WIN32::ERROR_CONNECTION_INVALID,
            0x800704CE => WIN32::ERROR_CONNECTION_ACTIVE,
            0x800704CF => WIN32::ERROR_NETWORK_UNREACHABLE,
            0x800704D0 => WIN32::ERROR_HOST_UNREACHABLE,
            0x800704D1 => WIN32::ERROR_PROTOCOL_UNREACHABLE,
            0x800704D2 => WIN32::ERROR_PORT_UNREACHABLE,
            0x800704D3 => WIN32::ERROR_REQUEST_ABORTED,
            0x800704D4 => WIN32::ERROR_CONNECTION_ABORTED,
            0x800704D5 => WIN32::ERROR_RETRY,
            0x800704D6 => WIN32::ERROR_CONNECTION_COUNT_LIMIT,
            0x800704D7 => WIN32::ERROR_LOGIN_TIME_RESTRICTION,
            0x800704D8 => WIN32::ERROR_LOGIN_WKSTA_RESTRICTION,
            0x800704D9 => WIN32::ERROR_INCORRECT_ADDRESS,
            0x800704DA => WIN32::ERROR_ALREADY_REGISTERED,
            0x800704DB => WIN32::ERROR_SERVICE_NOT_FOUND,
            0x800704DC => WIN32::ERROR_NOT_AUTHENTICATED,
            0x800704DD => WIN32::ERROR_NOT_LOGGED_ON,
            0x800704DE => WIN32::ERROR_CONTINUE,
            0x800704DF => WIN32::ERROR_ALREADY_INITIALIZED,
            0x800704E0 => WIN32::ERROR_NO_MORE_DEVICES,
            0x800704E1 => WIN32::ERROR_NO_SUCH_SITE,
            0x800704E2 => WIN32::ERROR_DOMAIN_CONTROLLER_EXISTS,
            0x800704E3 => WIN32::ERROR_ONLY_IF_CONNECTED,
            0x800704E4 => WIN32::ERROR_OVERRIDE_NOCHANGES,
            0x800704E5 => WIN32::ERROR_BAD_USER_PROFILE,
            0x800704E6 => WIN32::ERROR_NOT_SUPPORTED_ON_SBS,
            0x800704E7 => WIN32::ERROR_SERVER_SHUTDOWN_IN_PROGRESS,
            0x800704E8 => WIN32::ERROR_HOST_DOWN,
            0x800704E9 => WIN32::ERROR_NON_ACCOUNT_SID,
            0x800704EA => WIN32::ERROR_NON_DOMAIN_SID,
            0x800704EB => WIN32::ERROR_APPHELP_BLOCK,
            0x800704EC => WIN32::ERROR_ACCESS_DISABLED_BY_POLICY,
            0x800704ED => WIN32::ERROR_REG_NAT_CONSUMPTION,
            0x800704EE => WIN32::ERROR_CSCSHARE_OFFLINE,
            0x800704EF => WIN32::ERROR_PKINIT_FAILURE,
            0x800704F0 => WIN32::ERROR_SMARTCARD_SUBSYSTEM_FAILURE,
            0x800704F1 => WIN32::ERROR_DOWNGRADE_DETECTED,
            0x800704F7 => WIN32::ERROR_MACHINE_LOCKED,
            0x800704F8 => WIN32::ERROR_SMB_GUEST_LOGON_BLOCKED,
            0x800704F9 => WIN32::ERROR_CALLBACK_SUPPLIED_INVALID_DATA,
            0x800704FA => WIN32::ERROR_SYNC_FOREGROUND_REFRESH_REQUIRED,
            0x800704FB => WIN32::ERROR_DRIVER_BLOCKED,
            0x800704FC => WIN32::ERROR_INVALID_IMPORT_OF_NON_DLL,
            0x800704FD => WIN32::ERROR_ACCESS_DISABLED_WEBBLADE,
            0x800704FE => WIN32::ERROR_ACCESS_DISABLED_WEBBLADE_TAMPER,
            0x800704FF => WIN32::ERROR_RECOVERY_FAILURE,
            0x80070500 => WIN32::ERROR_ALREADY_FIBER,
            0x80070501 => WIN32::ERROR_ALREADY_THREAD,
            0x80070502 => WIN32::ERROR_STACK_BUFFER_OVERRUN,
            0x80070503 => WIN32::ERROR_PARAMETER_QUOTA_EXCEEDED,
            0x80070504 => WIN32::ERROR_DEBUGGER_INACTIVE,
            0x80070505 => WIN32::ERROR_DELAY_LOAD_FAILED,
            0x80070506 => WIN32::ERROR_VDM_DISALLOWED,
            0x80070507 => WIN32::ERROR_UNIDENTIFIED_ERROR,
            0x80070508 => WIN32::ERROR_INVALID_CRUNTIME_PARAMETER,
            0x80070509 => WIN32::ERROR_BEYOND_VDL,
            0x8007050A => WIN32::ERROR_INCOMPATIBLE_SERVICE_SID_TYPE,
            0x8007050B => WIN32::ERROR_DRIVER_PROCESS_TERMINATED,
            0x8007050C => WIN32::ERROR_IMPLEMENTATION_LIMIT,
            0x8007050D => WIN32::ERROR_PROCESS_IS_PROTECTED,
            0x8007050E => WIN32::ERROR_SERVICE_NOTIFY_CLIENT_LAGGING,
            0x8007050F => WIN32::ERROR_DISK_QUOTA_EXCEEDED,
            0x80070510 => WIN32::ERROR_CONTENT_BLOCKED,
            0x80070511 => WIN32::ERROR_INCOMPATIBLE_SERVICE_PRIVILEGE,
            0x80070512 => WIN32::ERROR_APP_HANG,
            0x80070513 => WIN32::ERROR_INVALID_LABEL,
            0x80070514 => WIN32::ERROR_NOT_ALL_ASSIGNED,
            0x80070515 => WIN32::ERROR_SOME_NOT_MAPPED,
            0x80070516 => WIN32::ERROR_NO_QUOTAS_FOR_ACCOUNT,
            0x80070517 => WIN32::ERROR_LOCAL_USER_SESSION_KEY,
            0x80070518 => WIN32::ERROR_NULL_LM_PASSWORD,
            0x80070519 => WIN32::ERROR_UNKNOWN_REVISION,
            0x8007051A => WIN32::ERROR_REVISION_MISMATCH,
            0x8007051B => WIN32::ERROR_INVALID_OWNER,
            0x8007051C => WIN32::ERROR_INVALID_PRIMARY_GROUP,
            0x8007051D => WIN32::ERROR_NO_IMPERSONATION_TOKEN,
            0x8007051E => WIN32::ERROR_CANT_DISABLE_MANDATORY,
            0x8007051F => WIN32::ERROR_NO_LOGON_SERVERS,
            0x80070520 => WIN32::ERROR_NO_SUCH_LOGON_SESSION,
            0x80070521 => WIN32::ERROR_NO_SUCH_PRIVILEGE,
            0x80070522 => WIN32::ERROR_PRIVILEGE_NOT_HELD,
            0x80070523 => WIN32::ERROR_INVALID_ACCOUNT_NAME,
            0x80070524 => WIN32::ERROR_USER_EXISTS,
            0x80070525 => WIN32::ERROR_NO_SUCH_USER,
            0x80070526 => WIN32::ERROR_GROUP_EXISTS,
            0x80070527 => WIN32::ERROR_NO_SUCH_GROUP,
            0x80070528 => WIN32::ERROR_MEMBER_IN_GROUP,
            0x80070529 => WIN32::ERROR_MEMBER_NOT_IN_GROUP,
            0x8007052A => WIN32::ERROR_LAST_ADMIN,
            0x8007052B => WIN32::ERROR_WRONG_PASSWORD,
            0x8007052C => WIN32::ERROR_ILL_FORMED_PASSWORD,
            0x8007052D => WIN32::ERROR_PASSWORD_RESTRICTION,
            0x8007052E => WIN32::ERROR_LOGON_FAILURE,
            0x8007052F => WIN32::ERROR_ACCOUNT_RESTRICTION,
            0x80070530 => WIN32::ERROR_INVALID_LOGON_HOURS,
            0x80070531 => WIN32::ERROR_INVALID_WORKSTATION,
            0x80070532 => WIN32::ERROR_PASSWORD_EXPIRED,
            0x80070533 => WIN32::ERROR_ACCOUNT_DISABLED,
            0x80070534 => WIN32::ERROR_NONE_MAPPED,
            0x80070535 => WIN32::ERROR_TOO_MANY_LUIDS_REQUESTED,
            0x80070536 => WIN32::ERROR_LUIDS_EXHAUSTED,
            0x80070537 => WIN32::ERROR_INVALID_SUB_AUTHORITY,
            0x80070538 => WIN32::ERROR_INVALID_ACL,
            0x80070539 => WIN32::ERROR_INVALID_SID,
            0x8007053A => WIN32::ERROR_INVALID_SECURITY_DESCR,
            0x8007053C => WIN32::ERROR_BAD_INHERITANCE_ACL,
            0x8007053D => WIN32::ERROR_SERVER_DISABLED,
            0x8007053E => WIN32::ERROR_SERVER_NOT_DISABLED,
            0x8007053F => WIN32::ERROR_INVALID_ID_AUTHORITY,
            0x80070540 => WIN32::ERROR_ALLOTTED_SPACE_EXCEEDED,
            0x80070541 => WIN32::ERROR_INVALID_GROUP_ATTRIBUTES,
            0x80070542 => WIN32::ERROR_BAD_IMPERSONATION_LEVEL,
            0x80070543 => WIN32::ERROR_CANT_OPEN_ANONYMOUS,
            0x80070544 => WIN32::ERROR_BAD_VALIDATION_CLASS,
            0x80070545 => WIN32::ERROR_BAD_TOKEN_TYPE,
            0x80070546 => WIN32::ERROR_NO_SECURITY_ON_OBJECT,
            0x80070547 => WIN32::ERROR_CANT_ACCESS_DOMAIN_INFO,
            0x80070548 => WIN32::ERROR_INVALID_SERVER_STATE,
            0x80070549 => WIN32::ERROR_INVALID_DOMAIN_STATE,
            0x8007054A => WIN32::ERROR_INVALID_DOMAIN_ROLE,
            0x8007054B => WIN32::ERROR_NO_SUCH_DOMAIN,
            0x8007054C => WIN32::ERROR_DOMAIN_EXISTS,
            0x8007054D => WIN32::ERROR_DOMAIN_LIMIT_EXCEEDED,
            0x8007054E => WIN32::ERROR_INTERNAL_DB_CORRUPTION,
            0x8007054F => WIN32::ERROR_INTERNAL_ERROR,
            0x80070550 => WIN32::ERROR_GENERIC_NOT_MAPPED,
            0x80070551 => WIN32::ERROR_BAD_DESCRIPTOR_FORMAT,
            0x80070552 => WIN32::ERROR_NOT_LOGON_PROCESS,
            0x80070553 => WIN32::ERROR_LOGON_SESSION_EXISTS,
            0x80070554 => WIN32::ERROR_NO_SUCH_PACKAGE,
            0x80070555 => WIN32::ERROR_BAD_LOGON_SESSION_STATE,
            0x80070556 => WIN32::ERROR_LOGON_SESSION_COLLISION,
            0x80070557 => WIN32::ERROR_INVALID_LOGON_TYPE,
            0x80070558 => WIN32::ERROR_CANNOT_IMPERSONATE,
            0x80070559 => WIN32::ERROR_RXACT_INVALID_STATE,
            0x8007055A => WIN32::ERROR_RXACT_COMMIT_FAILURE,
            0x8007055B => WIN32::ERROR_SPECIAL_ACCOUNT,
            0x8007055C => WIN32::ERROR_SPECIAL_GROUP,
            0x8007055D => WIN32::ERROR_SPECIAL_USER,
            0x8007055E => WIN32::ERROR_MEMBERS_PRIMARY_GROUP,
            0x8007055F => WIN32::ERROR_TOKEN_ALREADY_IN_USE,
            0x80070560 => WIN32::ERROR_NO_SUCH_ALIAS,
            0x80070561 => WIN32::ERROR_MEMBER_NOT_IN_ALIAS,
            0x80070562 => WIN32::ERROR_MEMBER_IN_ALIAS,
            0x80070563 => WIN32::ERROR_ALIAS_EXISTS,
            0x80070564 => WIN32::ERROR_LOGON_NOT_GRANTED,
            0x80070565 => WIN32::ERROR_TOO_MANY_SECRETS,
            0x80070566 => WIN32::ERROR_SECRET_TOO_LONG,
            0x80070567 => WIN32::ERROR_INTERNAL_DB_ERROR,
            0x80070568 => WIN32::ERROR_TOO_MANY_CONTEXT_IDS,
            0x80070569 => WIN32::ERROR_LOGON_TYPE_NOT_GRANTED,
            0x8007056A => WIN32::ERROR_NT_CROSS_ENCRYPTION_REQUIRED,
            0x8007056B => WIN32::ERROR_NO_SUCH_MEMBER,
            0x8007056C => WIN32::ERROR_INVALID_MEMBER,
            0x8007056D => WIN32::ERROR_TOO_MANY_SIDS,
            0x8007056E => WIN32::ERROR_LM_CROSS_ENCRYPTION_REQUIRED,
            0x8007056F => WIN32::ERROR_NO_INHERITANCE,
            0x80070570 => WIN32::ERROR_FILE_CORRUPT,
            0x80070571 => WIN32::ERROR_DISK_CORRUPT,
            0x80070572 => WIN32::ERROR_NO_USER_SESSION_KEY,
            0x80070573 => WIN32::ERROR_LICENSE_QUOTA_EXCEEDED,
            0x80070574 => WIN32::ERROR_WRONG_TARGET_NAME,
            0x80070575 => WIN32::ERROR_MUTUAL_AUTH_FAILED,
            0x80070576 => WIN32::ERROR_TIME_SKEW,
            0x80070577 => WIN32::ERROR_CURRENT_DOMAIN_NOT_ALLOWED,
            0x80070578 => WIN32::ERROR_INVALID_WINDOW_HANDLE,
            0x80070579 => WIN32::ERROR_INVALID_MENU_HANDLE,
            0x8007057A => WIN32::ERROR_INVALID_CURSOR_HANDLE,
            0x8007057B => WIN32::ERROR_INVALID_ACCEL_HANDLE,
            0x8007057C => WIN32::ERROR_INVALID_HOOK_HANDLE,
            0x8007057D => WIN32::ERROR_INVALID_DWP_HANDLE,
            0x8007057E => WIN32::ERROR_TLW_WITH_WSCHILD,
            0x8007057F => WIN32::ERROR_CANNOT_FIND_WND_CLASS,
            0x80070580 => WIN32::ERROR_WINDOW_OF_OTHER_THREAD,
            0x80070581 => WIN32::ERROR_HOTKEY_ALREADY_REGISTERED,
            0x80070582 => WIN32::ERROR_CLASS_ALREADY_EXISTS,
            0x80070583 => WIN32::ERROR_CLASS_DOES_NOT_EXIST,
            0x80070584 => WIN32::ERROR_CLASS_HAS_WINDOWS,
            0x80070585 => WIN32::ERROR_INVALID_INDEX,
            0x80070586 => WIN32::ERROR_INVALID_ICON_HANDLE,
            0x80070587 => WIN32::ERROR_PRIVATE_DIALOG_INDEX,
            0x80070588 => WIN32::ERROR_LISTBOX_ID_NOT_FOUND,
            0x80070589 => WIN32::ERROR_NO_WILDCARD_CHARACTERS,
            0x8007058A => WIN32::ERROR_CLIPBOARD_NOT_OPEN,
            0x8007058B => WIN32::ERROR_HOTKEY_NOT_REGISTERED,
            0x8007058C => WIN32::ERROR_WINDOW_NOT_DIALOG,
            0x8007058D => WIN32::ERROR_CONTROL_ID_NOT_FOUND,
            0x8007058E => WIN32::ERROR_INVALID_COMBOBOX_MESSAGE,
            0x8007058F => WIN32::ERROR_WINDOW_NOT_COMBOBOX,
            0x80070590 => WIN32::ERROR_INVALID_EDIT_HEIGHT,
            0x80070591 => WIN32::ERROR_DC_NOT_FOUND,
            0x80070592 => WIN32::ERROR_INVALID_HOOK_FILTER,
            0x80070593 => WIN32::ERROR_INVALID_FILTER_PROC,
            0x80070594 => WIN32::ERROR_HOOK_NEEDS_HMOD,
            0x80070595 => WIN32::ERROR_GLOBAL_ONLY_HOOK,
            0x80070596 => WIN32::ERROR_JOURNAL_HOOK_SET,
            0x80070597 => WIN32::ERROR_HOOK_NOT_INSTALLED,
            0x80070598 => WIN32::ERROR_INVALID_LB_MESSAGE,
            0x80070599 => WIN32::ERROR_SETCOUNT_ON_BAD_LB,
            0x8007059A => WIN32::ERROR_LB_WITHOUT_TABSTOPS,
            0x8007059B => WIN32::ERROR_DESTROY_OBJECT_OF_OTHER_THREAD,
            0x8007059C => WIN32::ERROR_CHILD_WINDOW_MENU,
            0x8007059D => WIN32::ERROR_NO_SYSTEM_MENU,
            0x8007059E => WIN32::ERROR_INVALID_MSGBOX_STYLE,
            0x8007059F => WIN32::ERROR_INVALID_SPI_VALUE,
            0x800705A0 => WIN32::ERROR_SCREEN_ALREADY_LOCKED,
            0x800705A1 => WIN32::ERROR_HWNDS_HAVE_DIFF_PARENT,
            0x800705A2 => WIN32::ERROR_NOT_CHILD_WINDOW,
            0x800705A3 => WIN32::ERROR_INVALID_GW_COMMAND,
            0x800705A4 => WIN32::ERROR_INVALID_THREAD_ID,
            0x800705A5 => WIN32::ERROR_NON_MDICHILD_WINDOW,
            0x800705A6 => WIN32::ERROR_POPUP_ALREADY_ACTIVE,
            0x800705A7 => WIN32::ERROR_NO_SCROLLBARS,
            0x800705A8 => WIN32::ERROR_INVALID_SCROLLBAR_RANGE,
            0x800705A9 => WIN32::ERROR_INVALID_SHOWWIN_COMMAND,
            0x800705AA => WIN32::ERROR_NO_SYSTEM_RESOURCES,
            0x800705AB => WIN32::ERROR_NONPAGED_SYSTEM_RESOURCES,
            0x800705AC => WIN32::ERROR_PAGED_SYSTEM_RESOURCES,
            0x800705AD => WIN32::ERROR_WORKING_SET_QUOTA,
            0x800705AE => WIN32::ERROR_PAGEFILE_QUOTA,
            0x800705AF => WIN32::ERROR_COMMITMENT_LIMIT,
            0x800705B0 => WIN32::ERROR_MENU_ITEM_NOT_FOUND,
            0x800705B1 => WIN32::ERROR_INVALID_KEYBOARD_HANDLE,
            0x800705B2 => WIN32::ERROR_HOOK_TYPE_NOT_ALLOWED,
            0x800705B3 => WIN32::ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION,
            0x800705B4 => WIN32::ERROR_TIMEOUT,
            0x800705B4 => WIN32::E_TIMEOUT,
            0x800705B5 => WIN32::ERROR_INVALID_MONITOR_HANDLE,
            0x800705B6 => WIN32::ERROR_INCORRECT_SIZE,
            0x800705B7 => WIN32::ERROR_SYMLINK_CLASS_DISABLED,
            0x800705B8 => WIN32::ERROR_SYMLINK_NOT_SUPPORTED,
            0x800705B9 => WIN32::ERROR_XML_PARSE_ERROR,
            0x800705BA => WIN32::ERROR_XMLDSIG_ERROR,
            0x800705BB => WIN32::ERROR_RESTART_APPLICATION,
            0x800705BC => WIN32::ERROR_WRONG_COMPARTMENT,
            0x800705BD => WIN32::ERROR_AUTHIP_FAILURE,
            0x800705BE => WIN32::ERROR_NO_NVRAM_RESOURCES,
            0x800705BF => WIN32::ERROR_NOT_GUI_PROCESS,
            0x800705DC => WIN32::ERROR_EVENTLOG_FILE_CORRUPT,
            0x800705DD => WIN32::ERROR_EVENTLOG_CANT_START,
            0x800705DE => WIN32::ERROR_LOG_FILE_FULL,
            0x800705DF => WIN32::ERROR_EVENTLOG_FILE_CHANGED,
            0x800705E0 => WIN32::ERROR_CONTAINER_ASSIGNED,
            0x800705E1 => WIN32::ERROR_JOB_NO_CONTAINER,
            0x8007060E => WIN32::ERROR_INVALID_TASK_NAME,
            0x8007060F => WIN32::ERROR_INVALID_TASK_INDEX,
            0x80070610 => WIN32::ERROR_THREAD_ALREADY_IN_TASK,
            0x80070641 => WIN32::ERROR_INSTALL_SERVICE_FAILURE,
            0x80070642 => WIN32::ERROR_INSTALL_USEREXIT,
            0x80070643 => WIN32::ERROR_INSTALL_FAILURE,
            0x80070644 => WIN32::ERROR_INSTALL_SUSPEND,
            0x80070645 => WIN32::ERROR_UNKNOWN_PRODUCT,
            0x80070646 => WIN32::ERROR_UNKNOWN_FEATURE,
            0x80070647 => WIN32::ERROR_UNKNOWN_COMPONENT,
            0x80070648 => WIN32::ERROR_UNKNOWN_PROPERTY,
            0x80070649 => WIN32::ERROR_INVALID_HANDLE_STATE,
            0x8007064A => WIN32::ERROR_BAD_CONFIGURATION,
            0x8007064B => WIN32::ERROR_INDEX_ABSENT,
            0x8007064C => WIN32::ERROR_INSTALL_SOURCE_ABSENT,
            0x8007064D => WIN32::ERROR_INSTALL_PACKAGE_VERSION,
            0x8007064E => WIN32::ERROR_PRODUCT_UNINSTALLED,
            0x8007064F => WIN32::ERROR_BAD_QUERY_SYNTAX,
            0x80070650 => WIN32::ERROR_INVALID_FIELD,
            0x80070651 => WIN32::ERROR_DEVICE_REMOVED,
            0x80070652 => WIN32::ERROR_INSTALL_ALREADY_RUNNING,
            0x80070653 => WIN32::ERROR_INSTALL_PACKAGE_OPEN_FAILED,
            0x80070654 => WIN32::ERROR_INSTALL_PACKAGE_INVALID,
            0x80070655 => WIN32::ERROR_INSTALL_UI_FAILURE,
            0x80070656 => WIN32::ERROR_INSTALL_LOG_FAILURE,
            0x80070657 => WIN32::ERROR_INSTALL_LANGUAGE_UNSUPPORTED,
            0x80070658 => WIN32::ERROR_INSTALL_TRANSFORM_FAILURE,
            0x80070659 => WIN32::ERROR_INSTALL_PACKAGE_REJECTED,
            0x8007065A => WIN32::ERROR_FUNCTION_NOT_CALLED,
            0x8007065B => WIN32::ERROR_FUNCTION_FAILED,
            0x8007065C => WIN32::ERROR_INVALID_TABLE,
            0x8007065D => WIN32::ERROR_DATATYPE_MISMATCH,
            0x8007065E => WIN32::ERROR_UNSUPPORTED_TYPE,
            0x8007065F => WIN32::ERROR_CREATE_FAILED,
            0x80070660 => WIN32::ERROR_INSTALL_TEMP_UNWRITABLE,
            0x80070661 => WIN32::ERROR_INSTALL_PLATFORM_UNSUPPORTED,
            0x80070662 => WIN32::ERROR_INSTALL_NOTUSED,
            0x80070663 => WIN32::ERROR_PATCH_PACKAGE_OPEN_FAILED,
            0x80070664 => WIN32::ERROR_PATCH_PACKAGE_INVALID,
            0x80070665 => WIN32::ERROR_PATCH_PACKAGE_UNSUPPORTED,
            0x80070666 => WIN32::ERROR_PRODUCT_VERSION,
            0x80070667 => WIN32::ERROR_INVALID_COMMAND_LINE,
            0x80070668 => WIN32::ERROR_INSTALL_REMOTE_DISALLOWED,
            0x80070669 => WIN32::ERROR_SUCCESS_REBOOT_INITIATED,
            0x8007066A => WIN32::ERROR_PATCH_TARGET_NOT_FOUND,
            0x8007066B => WIN32::ERROR_PATCH_PACKAGE_REJECTED,
            0x8007066C => WIN32::ERROR_INSTALL_TRANSFORM_REJECTED,
            0x8007066D => WIN32::ERROR_INSTALL_REMOTE_PROHIBITED,
            0x8007066E => WIN32::ERROR_PATCH_REMOVAL_UNSUPPORTED,
            0x8007066F => WIN32::ERROR_UNKNOWN_PATCH,
            0x80070670 => WIN32::ERROR_PATCH_NO_SEQUENCE,
            0x80070671 => WIN32::ERROR_PATCH_REMOVAL_DISALLOWED,
            0x80070672 => WIN32::ERROR_INVALID_PATCH_XML,
            0x80070673 => WIN32::ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT,
            0x80070674 => WIN32::ERROR_INSTALL_SERVICE_SAFEBOOT,
            0x80070675 => WIN32::ERROR_FAIL_FAST_EXCEPTION,
            0x80070676 => WIN32::ERROR_INSTALL_REJECTED,
            0x80070677 => WIN32::ERROR_DYNAMIC_CODE_BLOCKED,
            0x80070678 => WIN32::ERROR_NOT_SAME_OBJECT,
            0x80070679 => WIN32::ERROR_STRICT_CFG_VIOLATION,
            0x8007067A => WIN32::ERROR_STRICT_RFG_VIOLATION,
            0x8007067B => WIN32::ERROR_RFG_ACCESS_VIOLATION,
            0x8007067C => WIN32::ERROR_SET_CONTEXT_DENIED,
            0x8007067D => WIN32::ERROR_CROSS_PARTITION_VIOLATION,
            0x8007067E => WIN32::ERROR_RETURN_ADDRESS_HIJACK_ATTEMPT,
            0x800706A4 => WIN32::RPC_S_INVALID_STRING_BINDING,
            0x800706A5 => WIN32::RPC_S_WRONG_KIND_OF_BINDING,
            0x800706A6 => WIN32::RPC_S_INVALID_BINDING,
            0x800706A7 => WIN32::RPC_S_PROTSEQ_NOT_SUPPORTED,
            0x800706A8 => WIN32::RPC_S_INVALID_RPC_PROTSEQ,
            0x800706A9 => WIN32::RPC_S_INVALID_STRING_UUID,
            0x800706AA => WIN32::RPC_S_INVALID_ENDPOINT_FORMAT,
            0x800706AB => WIN32::RPC_S_INVALID_NET_ADDR,
            0x800706AC => WIN32::RPC_S_NO_ENDPOINT_FOUND,
            0x800706AD => WIN32::RPC_S_INVALID_TIMEOUT,
            0x800706AE => WIN32::RPC_S_OBJECT_NOT_FOUND,
            0x800706AF => WIN32::RPC_S_ALREADY_REGISTERED,
            0x800706B0 => WIN32::RPC_S_TYPE_ALREADY_REGISTERED,
            0x800706B1 => WIN32::RPC_S_ALREADY_LISTENING,
            0x800706B2 => WIN32::RPC_S_NO_PROTSEQS_REGISTERED,
            0x800706B3 => WIN32::RPC_S_NOT_LISTENING,
            0x800706B4 => WIN32::RPC_S_UNKNOWN_MGR_TYPE,
            0x800706B5 => WIN32::RPC_S_UNKNOWN_IF,
            0x800706B6 => WIN32::RPC_S_NO_BINDINGS,
            0x800706B7 => WIN32::RPC_S_NO_PROTSEQS,
            0x800706B8 => WIN32::RPC_S_CANT_CREATE_ENDPOINT,
            0x800706B9 => WIN32::RPC_S_OUT_OF_RESOURCES,
            0x800706BA => WIN32::RPC_S_SERVER_UNAVAILABLE,
            0x800706BB => WIN32::RPC_S_SERVER_TOO_BUSY,
            0x800706BC => WIN32::RPC_S_INVALID_NETWORK_OPTIONS,
            0x800706BD => WIN32::RPC_S_NO_CALL_ACTIVE,
            0x800706BE => WIN32::RPC_S_CALL_FAILED,
            0x800706BF => WIN32::RPC_S_CALL_FAILED_DNE,
            0x800706C0 => WIN32::RPC_S_PROTOCOL_ERROR,
            0x800706C1 => WIN32::RPC_S_PROXY_ACCESS_DENIED,
            0x800706C2 => WIN32::RPC_S_UNSUPPORTED_TRANS_SYN,
            0x800706C4 => WIN32::RPC_S_UNSUPPORTED_TYPE,
            0x800706C5 => WIN32::RPC_S_INVALID_TAG,
            0x800706C6 => WIN32::RPC_S_INVALID_BOUND,
            0x800706C7 => WIN32::RPC_S_NO_ENTRY_NAME,
            0x800706C8 => WIN32::RPC_S_INVALID_NAME_SYNTAX,
            0x800706C9 => WIN32::RPC_S_UNSUPPORTED_NAME_SYNTAX,
            0x800706CB => WIN32::RPC_S_UUID_NO_ADDRESS,
            0x800706CC => WIN32::RPC_S_DUPLICATE_ENDPOINT,
            0x800706CD => WIN32::RPC_S_UNKNOWN_AUTHN_TYPE,
            0x800706CE => WIN32::RPC_S_MAX_CALLS_TOO_SMALL,
            0x800706CF => WIN32::RPC_S_STRING_TOO_LONG,
            0x800706D0 => WIN32::RPC_S_PROTSEQ_NOT_FOUND,
            0x800706D1 => WIN32::RPC_S_PROCNUM_OUT_OF_RANGE,
            0x800706D2 => WIN32::RPC_S_BINDING_HAS_NO_AUTH,
            0x800706D3 => WIN32::RPC_S_UNKNOWN_AUTHN_SERVICE,
            0x800706D4 => WIN32::RPC_S_UNKNOWN_AUTHN_LEVEL,
            0x800706D5 => WIN32::RPC_S_INVALID_AUTH_IDENTITY,
            0x800706D6 => WIN32::RPC_S_UNKNOWN_AUTHZ_SERVICE,
            0x800706D7 => WIN32::EPT_S_INVALID_ENTRY,
            0x800706D8 => WIN32::EPT_S_CANT_PERFORM_OP,
            0x800706D9 => WIN32::EPT_S_NOT_REGISTERED,
            0x800706DA => WIN32::RPC_S_NOTHING_TO_EXPORT,
            0x800706DB => WIN32::RPC_S_INCOMPLETE_NAME,
            0x800706DC => WIN32::RPC_S_INVALID_VERS_OPTION,
            0x800706DD => WIN32::RPC_S_NO_MORE_MEMBERS,
            0x800706DE => WIN32::RPC_S_NOT_ALL_OBJS_UNEXPORTED,
            0x800706DF => WIN32::RPC_S_INTERFACE_NOT_FOUND,
            0x800706E0 => WIN32::RPC_S_ENTRY_ALREADY_EXISTS,
            0x800706E1 => WIN32::RPC_S_ENTRY_NOT_FOUND,
            0x800706E2 => WIN32::RPC_S_NAME_SERVICE_UNAVAILABLE,
            0x800706E3 => WIN32::RPC_S_INVALID_NAF_ID,
            0x800706E4 => WIN32::RPC_S_CANNOT_SUPPORT,
            0x800706E5 => WIN32::RPC_S_NO_CONTEXT_AVAILABLE,
            0x800706E6 => WIN32::RPC_S_INTERNAL_ERROR,
            0x800706E7 => WIN32::RPC_S_ZERO_DIVIDE,
            0x800706E8 => WIN32::RPC_S_ADDRESS_ERROR,
            0x800706E9 => WIN32::RPC_S_FP_DIV_ZERO,
            0x800706EA => WIN32::RPC_S_FP_UNDERFLOW,
            0x800706EB => WIN32::RPC_S_FP_OVERFLOW,
            0x800706EC => WIN32::RPC_X_NO_MORE_ENTRIES,
            0x800706ED => WIN32::RPC_X_SS_CHAR_TRANS_OPEN_FAIL,
            0x800706EE => WIN32::RPC_X_SS_CHAR_TRANS_SHORT_FILE,
            0x800706EF => WIN32::RPC_X_SS_IN_NULL_CONTEXT,
            0x800706F1 => WIN32::RPC_X_SS_CONTEXT_DAMAGED,
            0x800706F2 => WIN32::RPC_X_SS_HANDLES_MISMATCH,
            0x800706F3 => WIN32::RPC_X_SS_CANNOT_GET_CALL_HANDLE,
            0x800706F4 => WIN32::RPC_X_NULL_REF_POINTER,
            0x800706F5 => WIN32::RPC_X_ENUM_VALUE_OUT_OF_RANGE,
            0x800706F6 => WIN32::RPC_X_BYTE_COUNT_TOO_SMALL,
            0x800706F7 => WIN32::RPC_X_BAD_STUB_DATA,
            0x800706F8 => WIN32::ERROR_INVALID_USER_BUFFER,
            0x800706F9 => WIN32::ERROR_UNRECOGNIZED_MEDIA,
            0x800706FA => WIN32::ERROR_NO_TRUST_LSA_SECRET,
            0x800706FB => WIN32::ERROR_NO_TRUST_SAM_ACCOUNT,
            0x800706FC => WIN32::ERROR_TRUSTED_DOMAIN_FAILURE,
            0x800706FD => WIN32::ERROR_TRUSTED_RELATIONSHIP_FAILURE,
            0x800706FE => WIN32::ERROR_TRUST_FAILURE,
            0x800706FF => WIN32::RPC_S_CALL_IN_PROGRESS,
            0x80070700 => WIN32::ERROR_NETLOGON_NOT_STARTED,
            0x80070701 => WIN32::ERROR_ACCOUNT_EXPIRED,
            0x80070702 => WIN32::ERROR_REDIRECTOR_HAS_OPEN_HANDLES,
            0x80070703 => WIN32::ERROR_PRINTER_DRIVER_ALREADY_INSTALLED,
            0x80070704 => WIN32::ERROR_UNKNOWN_PORT,
            0x80070705 => WIN32::ERROR_UNKNOWN_PRINTER_DRIVER,
            0x80070706 => WIN32::ERROR_UNKNOWN_PRINTPROCESSOR,
            0x80070707 => WIN32::ERROR_INVALID_SEPARATOR_FILE,
            0x80070708 => WIN32::ERROR_INVALID_PRIORITY,
            0x80070709 => WIN32::ERROR_INVALID_PRINTER_NAME,
            0x8007070A => WIN32::ERROR_PRINTER_ALREADY_EXISTS,
            0x8007070B => WIN32::ERROR_INVALID_PRINTER_COMMAND,
            0x8007070C => WIN32::ERROR_INVALID_DATATYPE,
            0x8007070D => WIN32::ERROR_INVALID_ENVIRONMENT,
            0x8007070E => WIN32::RPC_S_NO_MORE_BINDINGS,
            0x8007070F => WIN32::ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT,
            0x80070710 => WIN32::ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT,
            0x80070711 => WIN32::ERROR_NOLOGON_SERVER_TRUST_ACCOUNT,
            0x80070712 => WIN32::ERROR_DOMAIN_TRUST_INCONSISTENT,
            0x80070713 => WIN32::ERROR_SERVER_HAS_OPEN_HANDLES,
            0x80070714 => WIN32::ERROR_RESOURCE_DATA_NOT_FOUND,
            0x80070715 => WIN32::ERROR_RESOURCE_TYPE_NOT_FOUND,
            0x80070716 => WIN32::ERROR_RESOURCE_NAME_NOT_FOUND,
            0x80070717 => WIN32::ERROR_RESOURCE_LANG_NOT_FOUND,
            0x80070718 => WIN32::ERROR_NOT_ENOUGH_QUOTA,
            0x80070719 => WIN32::RPC_S_NO_INTERFACES,
            0x8007071A => WIN32::RPC_S_CALL_CANCELLED,
            0x8007071B => WIN32::RPC_S_BINDING_INCOMPLETE,
            0x8007071C => WIN32::RPC_S_COMM_FAILURE,
            0x8007071D => WIN32::RPC_S_UNSUPPORTED_AUTHN_LEVEL,
            0x8007071E => WIN32::RPC_S_NO_PRINC_NAME,
            0x8007071F => WIN32::RPC_S_NOT_RPC_ERROR,
            0x80070720 => WIN32::RPC_S_UUID_LOCAL_ONLY,
            0x80070721 => WIN32::RPC_S_SEC_PKG_ERROR,
            0x80070722 => WIN32::RPC_S_NOT_CANCELLED,
            0x80070723 => WIN32::RPC_X_INVALID_ES_ACTION,
            0x80070724 => WIN32::RPC_X_WRONG_ES_VERSION,
            0x80070725 => WIN32::RPC_X_WRONG_STUB_VERSION,
            0x80070726 => WIN32::RPC_X_INVALID_PIPE_OBJECT,
            0x80070727 => WIN32::RPC_X_WRONG_PIPE_ORDER,
            0x80070728 => WIN32::RPC_X_WRONG_PIPE_VERSION,
            0x80070729 => WIN32::RPC_S_COOKIE_AUTH_FAILED,
            0x8007072A => WIN32::RPC_S_DO_NOT_DISTURB,
            0x8007072B => WIN32::RPC_S_SYSTEM_HANDLE_COUNT_EXCEEDED,
            0x8007072C => WIN32::RPC_S_SYSTEM_HANDLE_TYPE_MISMATCH,
            0x8007076A => WIN32::RPC_S_GROUP_MEMBER_NOT_FOUND,
            0x8007076B => WIN32::EPT_S_CANT_CREATE,
            0x8007076C => WIN32::RPC_S_INVALID_OBJECT,
            0x8007076D => WIN32::ERROR_INVALID_TIME,
            0x8007076E => WIN32::ERROR_INVALID_FORM_NAME,
            0x8007076F => WIN32::ERROR_INVALID_FORM_SIZE,
            0x80070770 => WIN32::ERROR_ALREADY_WAITING,
            0x80070771 => WIN32::ERROR_PRINTER_DELETED,
            0x80070772 => WIN32::ERROR_INVALID_PRINTER_STATE,
            0x80070773 => WIN32::ERROR_PASSWORD_MUST_CHANGE,
            0x80070774 => WIN32::ERROR_DOMAIN_CONTROLLER_NOT_FOUND,
            0x80070775 => WIN32::ERROR_ACCOUNT_LOCKED_OUT,
            0x80070776 => WIN32::OR_INVALID_OXID,
            0x80070777 => WIN32::OR_INVALID_OID,
            0x80070778 => WIN32::OR_INVALID_SET,
            0x80070779 => WIN32::RPC_S_SEND_INCOMPLETE,
            0x8007077A => WIN32::RPC_S_INVALID_ASYNC_HANDLE,
            0x8007077B => WIN32::RPC_S_INVALID_ASYNC_CALL,
            0x8007077C => WIN32::RPC_X_PIPE_CLOSED,
            0x8007077D => WIN32::RPC_X_PIPE_DISCIPLINE_ERROR,
            0x8007077E => WIN32::RPC_X_PIPE_EMPTY,
            0x8007077F => WIN32::ERROR_NO_SITENAME,
            0x80070780 => WIN32::ERROR_CANT_ACCESS_FILE,
            0x80070781 => WIN32::ERROR_CANT_RESOLVE_FILENAME,
            0x80070782 => WIN32::RPC_S_ENTRY_TYPE_MISMATCH,
            0x80070783 => WIN32::RPC_S_NOT_ALL_OBJS_EXPORTED,
            0x80070784 => WIN32::RPC_S_INTERFACE_NOT_EXPORTED,
            0x80070785 => WIN32::RPC_S_PROFILE_NOT_ADDED,
            0x80070786 => WIN32::RPC_S_PRF_ELT_NOT_ADDED,
            0x80070787 => WIN32::RPC_S_PRF_ELT_NOT_REMOVED,
            0x80070788 => WIN32::RPC_S_GRP_ELT_NOT_ADDED,
            0x80070789 => WIN32::RPC_S_GRP_ELT_NOT_REMOVED,
            0x8007078A => WIN32::ERROR_KM_DRIVER_BLOCKED,
            0x8007078B => WIN32::ERROR_CONTEXT_EXPIRED,
            0x8007078C => WIN32::ERROR_PER_USER_TRUST_QUOTA_EXCEEDED,
            0x8007078D => WIN32::ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED,
            0x8007078E => WIN32::ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED,
            0x8007078F => WIN32::ERROR_AUTHENTICATION_FIREWALL_FAILED,
            0x80070790 => WIN32::ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED,
            0x80070791 => WIN32::ERROR_NTLM_BLOCKED,
            0x80070792 => WIN32::ERROR_PASSWORD_CHANGE_REQUIRED,
            0x80070793 => WIN32::ERROR_LOST_MODE_LOGON_RESTRICTION,
            0x800707D0 => WIN32::ERROR_INVALID_PIXEL_FORMAT,
            0x800707D1 => WIN32::ERROR_BAD_DRIVER,
            0x800707D2 => WIN32::ERROR_INVALID_WINDOW_STYLE,
            0x800707D3 => WIN32::ERROR_METAFILE_NOT_SUPPORTED,
            0x800707D4 => WIN32::ERROR_TRANSFORM_NOT_SUPPORTED,
            0x800707D5 => WIN32::ERROR_CLIPPING_NOT_SUPPORTED,
            0x800707DA => WIN32::ERROR_INVALID_CMM,
            0x800707DB => WIN32::ERROR_INVALID_PROFILE,
            0x800707DC => WIN32::ERROR_TAG_NOT_FOUND,
            0x800707DD => WIN32::ERROR_TAG_NOT_PRESENT,
            0x800707DE => WIN32::ERROR_DUPLICATE_TAG,
            0x800707DF => WIN32::ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE,
            0x800707E0 => WIN32::ERROR_PROFILE_NOT_FOUND,
            0x800707E1 => WIN32::ERROR_INVALID_COLORSPACE,
            0x800707E2 => WIN32::ERROR_ICM_NOT_ENABLED,
            0x800707E3 => WIN32::ERROR_DELETING_ICM_XFORM,
            0x800707E4 => WIN32::ERROR_INVALID_TRANSFORM,
            0x800707E5 => WIN32::ERROR_COLORSPACE_MISMATCH,
            0x800707E6 => WIN32::ERROR_INVALID_COLORINDEX,
            0x800707E7 => WIN32::ERROR_PROFILE_DOES_NOT_MATCH_DEVICE,
            0x80070836 => WIN32::NERR_NetNotStarted,
            0x80070837 => WIN32::NERR_UnknownServer,
            0x80070838 => WIN32::NERR_ShareMem,
            0x80070839 => WIN32::NERR_NoNetworkResource,
            0x8007083A => WIN32::NERR_RemoteOnly,
            0x8007083B => WIN32::NERR_DevNotRedirected,
            0x8007083C => WIN32::ERROR_CONNECTED_OTHER_PASSWORD,
            0x8007083D => WIN32::ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT,
            0x80070842 => WIN32::NERR_ServerNotStarted,
            0x80070843 => WIN32::NERR_ItemNotFound,
            0x80070844 => WIN32::NERR_UnknownDevDir,
            0x80070845 => WIN32::NERR_RedirectedPath,
            0x80070846 => WIN32::NERR_DuplicateShare,
            0x80070847 => WIN32::NERR_NoRoom,
            0x80070849 => WIN32::NERR_TooManyItems,
            0x8007084A => WIN32::NERR_InvalidMaxUsers,
            0x8007084B => WIN32::NERR_BufTooSmall,
            0x8007084F => WIN32::NERR_RemoteErr,
            0x80070853 => WIN32::NERR_LanmanIniError,
            0x80070858 => WIN32::NERR_NetworkError,
            0x80070859 => WIN32::NERR_WkstaInconsistentState,
            0x8007085A => WIN32::NERR_WkstaNotStarted,
            0x8007085B => WIN32::NERR_BrowserNotStarted,
            0x8007085C => WIN32::NERR_InternalError,
            0x8007085D => WIN32::NERR_BadTransactConfig,
            0x8007085E => WIN32::NERR_InvalidAPI,
            0x8007085F => WIN32::NERR_BadEventName,
            0x80070860 => WIN32::NERR_DupNameReboot,
            0x80070862 => WIN32::NERR_CfgCompNotFound,
            0x80070863 => WIN32::NERR_CfgParamNotFound,
            0x80070865 => WIN32::NERR_LineTooLong,
            0x80070866 => WIN32::NERR_QNotFound,
            0x80070867 => WIN32::NERR_JobNotFound,
            0x80070868 => WIN32::NERR_DestNotFound,
            0x80070869 => WIN32::NERR_DestExists,
            0x8007086A => WIN32::NERR_QExists,
            0x8007086B => WIN32::NERR_QNoRoom,
            0x8007086C => WIN32::NERR_JobNoRoom,
            0x8007086D => WIN32::NERR_DestNoRoom,
            0x8007086E => WIN32::NERR_DestIdle,
            0x8007086F => WIN32::NERR_DestInvalidOp,
            0x80070870 => WIN32::NERR_ProcNoRespond,
            0x80070871 => WIN32::NERR_SpoolerNotLoaded,
            0x80070872 => WIN32::NERR_DestInvalidState,
            0x80070873 => WIN32::NERR_QinvalidState,
            0x80070874 => WIN32::NERR_JobInvalidState,
            0x80070875 => WIN32::NERR_SpoolNoMemory,
            0x80070876 => WIN32::NERR_DriverNotFound,
            0x80070877 => WIN32::NERR_DataTypeInvalid,
            0x80070878 => WIN32::NERR_ProcNotFound,
            0x80070884 => WIN32::NERR_ServiceTableLocked,
            0x80070885 => WIN32::NERR_ServiceTableFull,
            0x80070886 => WIN32::NERR_ServiceInstalled,
            0x80070887 => WIN32::NERR_ServiceEntryLocked,
            0x80070888 => WIN32::NERR_ServiceNotInstalled,
            0x80070889 => WIN32::NERR_BadServiceName,
            0x8007088A => WIN32::NERR_ServiceCtlTimeout,
            0x8007088B => WIN32::NERR_ServiceCtlBusy,
            0x8007088C => WIN32::NERR_BadServiceProgName,
            0x8007088D => WIN32::NERR_ServiceNotCtrl,
            0x8007088E => WIN32::NERR_ServiceKillProc,
            0x8007088F => WIN32::NERR_ServiceCtlNotValid,
            0x80070890 => WIN32::NERR_NotInDispatchTbl,
            0x80070891 => WIN32::NERR_BadControlRecv,
            0x80070892 => WIN32::NERR_ServiceNotStarting,
            0x80070898 => WIN32::NERR_AlreadyLoggedOn,
            0x80070899 => WIN32::NERR_NotLoggedOn,
            0x8007089A => WIN32::ERROR_BAD_USERNAME,
            0x8007089A => WIN32::NERR_BadUsername,
            0x8007089B => WIN32::NERR_BadPassword,
            0x8007089C => WIN32::NERR_UnableToAddName_W,
            0x8007089D => WIN32::NERR_UnableToAddName_F,
            0x8007089E => WIN32::NERR_UnableToDelName_W,
            0x8007089F => WIN32::NERR_UnableToDelName_F,
            0x800708A1 => WIN32::NERR_LogonsPaused,
            0x800708A2 => WIN32::NERR_LogonServerConflict,
            0x800708A3 => WIN32::NERR_LogonNoUserPath,
            0x800708A4 => WIN32::NERR_LogonScriptError,
            0x800708A6 => WIN32::NERR_StandaloneLogon,
            0x800708A7 => WIN32::NERR_LogonServerNotFound,
            0x800708A8 => WIN32::NERR_LogonDomainExists,
            0x800708A9 => WIN32::NERR_NonValidatedLogon,
            0x800708AB => WIN32::NERR_ACFNotFound,
            0x800708AC => WIN32::NERR_GroupNotFound,
            0x800708AD => WIN32::NERR_UserNotFound,
            0x800708AE => WIN32::NERR_ResourceNotFound,
            0x800708AF => WIN32::NERR_GroupExists,
            0x800708B0 => WIN32::NERR_UserExists,
            0x800708B1 => WIN32::NERR_ResourceExists,
            0x800708B2 => WIN32::NERR_NotPrimary,
            0x800708B3 => WIN32::NERR_ACFNotLoaded,
            0x800708B4 => WIN32::NERR_ACFNoRoom,
            0x800708B5 => WIN32::NERR_ACFFileIOFail,
            0x800708B6 => WIN32::NERR_ACFTooManyLists,
            0x800708B7 => WIN32::NERR_UserLogon,
            0x800708B8 => WIN32::NERR_ACFNoParent,
            0x800708B9 => WIN32::NERR_CanNotGrowSegment,
            0x800708BA => WIN32::NERR_SpeGroupOp,
            0x800708BB => WIN32::NERR_NotInCache,
            0x800708BC => WIN32::NERR_UserInGroup,
            0x800708BD => WIN32::NERR_UserNotInGroup,
            0x800708BE => WIN32::NERR_AccountUndefined,
            0x800708BF => WIN32::NERR_AccountExpired,
            0x800708C0 => WIN32::NERR_InvalidWorkstation,
            0x800708C1 => WIN32::NERR_InvalidLogonHours,
            0x800708C2 => WIN32::NERR_PasswordExpired,
            0x800708C3 => WIN32::NERR_PasswordCantChange,
            0x800708C4 => WIN32::NERR_PasswordHistConflict,
            0x800708C5 => WIN32::NERR_PasswordTooShort,
            0x800708C6 => WIN32::NERR_PasswordTooRecent,
            0x800708C7 => WIN32::NERR_InvalidDatabase,
            0x800708C8 => WIN32::NERR_DatabaseUpToDate,
            0x800708C9 => WIN32::NERR_SyncRequired,
            0x800708CA => WIN32::ERROR_NOT_CONNECTED,
            0x800708CA => WIN32::NERR_UseNotFound,
            0x800708CB => WIN32::NERR_BadAsgType,
            0x800708CC => WIN32::NERR_DeviceIsShared,
            0x800708DE => WIN32::NERR_NoComputerName,
            0x800708DF => WIN32::NERR_MsgAlreadyStarted,
            0x800708E0 => WIN32::NERR_MsgInitFailed,
            0x800708E1 => WIN32::NERR_NameNotFound,
            0x800708E2 => WIN32::NERR_AlreadyForwarded,
            0x800708E3 => WIN32::NERR_AddForwarded,
            0x800708E4 => WIN32::NERR_AlreadyExists,
            0x800708E5 => WIN32::NERR_TooManyNames,
            0x800708E6 => WIN32::NERR_DelComputerName,
            0x800708E7 => WIN32::NERR_LocalForward,
            0x800708E8 => WIN32::NERR_GrpMsgProcessor,
            0x800708E9 => WIN32::NERR_PausedRemote,
            0x800708EA => WIN32::NERR_BadReceive,
            0x800708EB => WIN32::NERR_NameInUse,
            0x800708EC => WIN32::NERR_MsgNotStarted,
            0x800708ED => WIN32::NERR_NotLocalName,
            0x800708EE => WIN32::NERR_NoForwardName,
            0x800708EF => WIN32::NERR_RemoteFull,
            0x800708F0 => WIN32::NERR_NameNotForwarded,
            0x800708F1 => WIN32::NERR_TruncatedBroadcast,
            0x800708F6 => WIN32::NERR_InvalidDevice,
            0x800708F7 => WIN32::NERR_WriteFault,
            0x800708F9 => WIN32::NERR_DuplicateName,
            0x800708FA => WIN32::NERR_DeleteLater,
            0x800708FB => WIN32::NERR_IncompleteDel,
            0x800708FC => WIN32::NERR_MultipleNets,
            0x80070906 => WIN32::NERR_NetNameNotFound,
            0x80070907 => WIN32::NERR_DeviceNotShared,
            0x80070908 => WIN32::NERR_ClientNameNotFound,
            0x8007090A => WIN32::NERR_FileIdNotFound,
            0x8007090B => WIN32::NERR_ExecFailure,
            0x8007090C => WIN32::NERR_TmpFile,
            0x8007090D => WIN32::NERR_TooMuchData,
            0x8007090E => WIN32::NERR_DeviceShareConflict,
            0x8007090F => WIN32::NERR_BrowserTableIncomplete,
            0x80070910 => WIN32::NERR_NotLocalDomain,
            0x80070911 => WIN32::NERR_IsDfsShare,
            0x8007091B => WIN32::NERR_DevInvalidOpCode,
            0x8007091C => WIN32::NERR_DevNotFound,
            0x8007091D => WIN32::NERR_DevNotOpen,
            0x8007091E => WIN32::NERR_BadQueueDevString,
            0x8007091F => WIN32::NERR_BadQueuePriority,
            0x80070921 => WIN32::NERR_NoCommDevs,
            0x80070922 => WIN32::NERR_QueueNotFound,
            0x80070924 => WIN32::NERR_BadDevString,
            0x80070925 => WIN32::NERR_BadDev,
            0x80070926 => WIN32::NERR_InUseBySpooler,
            0x80070927 => WIN32::NERR_CommDevInUse,
            0x8007092F => WIN32::NERR_InvalidComputer,
            0x80070932 => WIN32::NERR_MaxLenExceeded,
            0x80070934 => WIN32::NERR_BadComponent,
            0x80070935 => WIN32::NERR_CantType,
            0x8007093A => WIN32::NERR_TooManyEntries,
            0x80070942 => WIN32::NERR_ProfileFileTooBig,
            0x80070943 => WIN32::NERR_ProfileOffset,
            0x80070944 => WIN32::NERR_ProfileCleanup,
            0x80070945 => WIN32::NERR_ProfileUnknownCmd,
            0x80070946 => WIN32::NERR_ProfileLoadErr,
            0x80070947 => WIN32::NERR_ProfileSaveErr,
            0x80070949 => WIN32::NERR_LogOverflow,
            0x8007094A => WIN32::NERR_LogFileChanged,
            0x8007094B => WIN32::NERR_LogFileCorrupt,
            0x8007094C => WIN32::NERR_SourceIsDir,
            0x8007094D => WIN32::NERR_BadSource,
            0x8007094E => WIN32::NERR_BadDest,
            0x8007094F => WIN32::NERR_DifferentServers,
            0x80070951 => WIN32::NERR_RunSrvPaused,
            0x80070955 => WIN32::NERR_ErrCommRunSrv,
            0x80070957 => WIN32::NERR_ErrorExecingGhost,
            0x80070958 => WIN32::NERR_ShareNotFound,
            0x80070960 => WIN32::NERR_InvalidLana,
            0x80070961 => WIN32::ERROR_OPEN_FILES,
            0x80070961 => WIN32::NERR_OpenFiles,
            0x80070962 => WIN32::ERROR_ACTIVE_CONNECTIONS,
            0x80070962 => WIN32::NERR_ActiveConns,
            0x80070963 => WIN32::NERR_BadPasswordCore,
            0x80070964 => WIN32::ERROR_DEVICE_IN_USE,
            0x80070964 => WIN32::NERR_DevInUse,
            0x80070965 => WIN32::NERR_LocalDrive,
            0x8007097E => WIN32::NERR_AlertExists,
            0x8007097F => WIN32::NERR_TooManyAlerts,
            0x80070980 => WIN32::NERR_NoSuchAlert,
            0x80070981 => WIN32::NERR_BadRecipient,
            0x80070982 => WIN32::NERR_AcctLimitExceeded,
            0x80070988 => WIN32::NERR_InvalidLogSeek,
            0x80070992 => WIN32::NERR_BadUasConfig,
            0x80070993 => WIN32::NERR_InvalidUASOp,
            0x80070994 => WIN32::NERR_LastAdmin,
            0x80070995 => WIN32::NERR_DCNotFound,
            0x80070996 => WIN32::NERR_LogonTrackingError,
            0x80070997 => WIN32::NERR_NetlogonNotStarted,
            0x80070998 => WIN32::NERR_CanNotGrowUASFile,
            0x80070999 => WIN32::NERR_TimeDiffAtDC,
            0x8007099A => WIN32::NERR_PasswordMismatch,
            0x8007099C => WIN32::NERR_NoSuchServer,
            0x8007099D => WIN32::NERR_NoSuchSession,
            0x8007099E => WIN32::NERR_NoSuchConnection,
            0x8007099F => WIN32::NERR_TooManyServers,
            0x800709A0 => WIN32::NERR_TooManySessions,
            0x800709A1 => WIN32::NERR_TooManyConnections,
            0x800709A2 => WIN32::NERR_TooManyFiles,
            0x800709A3 => WIN32::NERR_NoAlternateServers,
            0x800709A6 => WIN32::NERR_TryDownLevel,
            0x800709B0 => WIN32::NERR_UPSDriverNotStarted,
            0x800709B1 => WIN32::NERR_UPSInvalidConfig,
            0x800709B2 => WIN32::NERR_UPSInvalidCommPort,
            0x800709B3 => WIN32::NERR_UPSSignalAsserted,
            0x800709B4 => WIN32::NERR_UPSShutdownFailed,
            0x800709C4 => WIN32::NERR_BadDosRetCode,
            0x800709C5 => WIN32::NERR_ProgNeedsExtraMem,
            0x800709C6 => WIN32::NERR_BadDosFunction,
            0x800709C7 => WIN32::NERR_RemoteBootFailed,
            0x800709C8 => WIN32::NERR_BadFileCheckSum,
            0x800709C9 => WIN32::NERR_NoRplBootSystem,
            0x800709CA => WIN32::NERR_RplLoadrNetBiosErr,
            0x800709CB => WIN32::NERR_RplLoadrDiskErr,
            0x800709CC => WIN32::NERR_ImageParamErr,
            0x800709CD => WIN32::NERR_TooManyImageParams,
            0x800709CE => WIN32::NERR_NonDosFloppyUsed,
            0x800709CF => WIN32::NERR_RplBootRestart,
            0x800709D0 => WIN32::NERR_RplSrvrCallFailed,
            0x800709D1 => WIN32::NERR_CantConnectRplSrvr,
            0x800709D2 => WIN32::NERR_CantOpenImageFile,
            0x800709D3 => WIN32::NERR_CallingRplSrvr,
            0x800709D4 => WIN32::NERR_StartingRplBoot,
            0x800709D5 => WIN32::NERR_RplBootServiceTerm,
            0x800709D6 => WIN32::NERR_RplBootStartFailed,
            0x800709D7 => WIN32::NERR_RPL_CONNECTED,
            0x800709F6 => WIN32::NERR_BrowserConfiguredToNotRun,
            0x80070A32 => WIN32::NERR_RplNoAdaptersStarted,
            0x80070A33 => WIN32::NERR_RplBadRegistry,
            0x80070A34 => WIN32::NERR_RplBadDatabase,
            0x80070A35 => WIN32::NERR_RplRplfilesShare,
            0x80070A36 => WIN32::NERR_RplNotRplServer,
            0x80070A37 => WIN32::NERR_RplCannotEnum,
            0x80070A38 => WIN32::NERR_RplWkstaInfoCorrupted,
            0x80070A39 => WIN32::NERR_RplWkstaNotFound,
            0x80070A3A => WIN32::NERR_RplWkstaNameUnavailable,
            0x80070A3B => WIN32::NERR_RplProfileInfoCorrupted,
            0x80070A3C => WIN32::NERR_RplProfileNotFound,
            0x80070A3D => WIN32::NERR_RplProfileNameUnavailable,
            0x80070A3E => WIN32::NERR_RplProfileNotEmpty,
            0x80070A3F => WIN32::NERR_RplConfigInfoCorrupted,
            0x80070A40 => WIN32::NERR_RplConfigNotFound,
            0x80070A41 => WIN32::NERR_RplAdapterInfoCorrupted,
            0x80070A42 => WIN32::NERR_RplInternal,
            0x80070A43 => WIN32::NERR_RplVendorInfoCorrupted,
            0x80070A44 => WIN32::NERR_RplBootInfoCorrupted,
            0x80070A45 => WIN32::NERR_RplWkstaNeedsUserAcct,
            0x80070A46 => WIN32::NERR_RplNeedsRPLUSERAcct,
            0x80070A47 => WIN32::NERR_RplBootNotFound,
            0x80070A48 => WIN32::NERR_RplIncompatibleProfile,
            0x80070A49 => WIN32::NERR_RplAdapterNameUnavailable,
            0x80070A4A => WIN32::NERR_RplConfigNotEmpty,
            0x80070A4B => WIN32::NERR_RplBootInUse,
            0x80070A4C => WIN32::NERR_RplBackupDatabase,
            0x80070A4D => WIN32::NERR_RplAdapterNotFound,
            0x80070A4E => WIN32::NERR_RplVendorNotFound,
            0x80070A4F => WIN32::NERR_RplVendorNameUnavailable,
            0x80070A50 => WIN32::NERR_RplBootNameUnavailable,
            0x80070A51 => WIN32::NERR_RplConfigNameUnavailable,
            0x80070A64 => WIN32::NERR_DfsInternalCorruption,
            0x80070A65 => WIN32::NERR_DfsVolumeDataCorrupt,
            0x80070A66 => WIN32::NERR_DfsNoSuchVolume,
            0x80070A67 => WIN32::NERR_DfsVolumeAlreadyExists,
            0x80070A68 => WIN32::NERR_DfsAlreadyShared,
            0x80070A69 => WIN32::NERR_DfsNoSuchShare,
            0x80070A6A => WIN32::NERR_DfsNotALeafVolume,
            0x80070A6B => WIN32::NERR_DfsLeafVolume,
            0x80070A6C => WIN32::NERR_DfsVolumeHasMultipleServers,
            0x80070A6D => WIN32::NERR_DfsCantCreateJunctionPoint,
            0x80070A6E => WIN32::NERR_DfsServerNotDfsAware,
            0x80070A6F => WIN32::NERR_DfsBadRenamePath,
            0x80070A70 => WIN32::NERR_DfsVolumeIsOffline,
            0x80070A71 => WIN32::NERR_DfsNoSuchServer,
            0x80070A72 => WIN32::NERR_DfsCyclicalName,
            0x80070A73 => WIN32::NERR_DfsNotSupportedInServerDfs,
            0x80070A74 => WIN32::NERR_DfsDuplicateService,
            0x80070A75 => WIN32::NERR_DfsCantRemoveLastServerShare,
            0x80070A76 => WIN32::NERR_DfsVolumeIsInterDfs,
            0x80070A77 => WIN32::NERR_DfsInconsistent,
            0x80070A78 => WIN32::NERR_DfsServerUpgraded,
            0x80070A79 => WIN32::NERR_DfsDataIsIdentical,
            0x80070A7A => WIN32::NERR_DfsCantRemoveDfsRoot,
            0x80070A7B => WIN32::NERR_DfsChildOrParentInDfs,
            0x80070A82 => WIN32::NERR_DfsInternalError,
            0x80070A83 => WIN32::NERR_SetupAlreadyJoined,
            0x80070A84 => WIN32::NERR_SetupNotJoined,
            0x80070A85 => WIN32::NERR_SetupDomainController,
            0x80070A86 => WIN32::NERR_DefaultJoinRequired,
            0x80070A87 => WIN32::NERR_InvalidWorkgroupName,
            0x80070A88 => WIN32::NERR_NameUsesIncompatibleCodePage,
            0x80070A89 => WIN32::NERR_ComputerAccountNotFound,
            0x80070A8A => WIN32::NERR_PersonalSku,
            0x80070A8D => WIN32::NERR_PasswordMustChange,
            0x80070A8E => WIN32::NERR_AccountLockedOut,
            0x80070A8F => WIN32::NERR_PasswordTooLong,
            0x80070A90 => WIN32::NERR_PasswordNotComplexEnough,
            0x80070A91 => WIN32::NERR_PasswordFilterError,
            0x80070BB8 => WIN32::ERROR_UNKNOWN_PRINT_MONITOR,
            0x80070BB9 => WIN32::ERROR_PRINTER_DRIVER_IN_USE,
            0x80070BBA => WIN32::ERROR_SPOOL_FILE_NOT_FOUND,
            0x80070BBB => WIN32::ERROR_SPL_NO_STARTDOC,
            0x80070BBC => WIN32::ERROR_SPL_NO_ADDJOB,
            0x80070BBD => WIN32::ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED,
            0x80070BBE => WIN32::ERROR_PRINT_MONITOR_ALREADY_INSTALLED,
            0x80070BBF => WIN32::ERROR_INVALID_PRINT_MONITOR,
            0x80070BC0 => WIN32::ERROR_PRINT_MONITOR_IN_USE,
            0x80070BC1 => WIN32::ERROR_PRINTER_HAS_JOBS_QUEUED,
            0x80070BC2 => WIN32::ERROR_SUCCESS_REBOOT_REQUIRED,
            0x80070BC3 => WIN32::ERROR_SUCCESS_RESTART_REQUIRED,
            0x80070BC4 => WIN32::ERROR_PRINTER_NOT_FOUND,
            0x80070BC5 => WIN32::ERROR_PRINTER_DRIVER_WARNED,
            0x80070BC6 => WIN32::ERROR_PRINTER_DRIVER_BLOCKED,
            0x80070BC7 => WIN32::ERROR_PRINTER_DRIVER_PACKAGE_IN_USE,
            0x80070BC8 => WIN32::ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND,
            0x80070BC9 => WIN32::ERROR_FAIL_REBOOT_REQUIRED,
            0x80070BCA => WIN32::ERROR_FAIL_REBOOT_INITIATED,
            0x80070BCB => WIN32::ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED,
            0x80070BCC => WIN32::ERROR_PRINT_JOB_RESTART_REQUIRED,
            0x80070BCD => WIN32::ERROR_INVALID_PRINTER_DRIVER_MANIFEST,
            0x80070BCE => WIN32::ERROR_PRINTER_NOT_SHAREABLE,
            0x80070BCF => WIN32::ERROR_SERVER_SERVICE_CALL_REQUIRES_SMB1,
            0x80070BD0 => WIN32::ERROR_NETWORK_AUTHENTICATION_PROMPT_CANCELED,
            0x80070BEA => WIN32::ERROR_REQUEST_PAUSED,
            0x80070BF4 => WIN32::ERROR_APPEXEC_CONDITION_NOT_SATISFIED,
            0x80070BF5 => WIN32::ERROR_APPEXEC_HANDLE_INVALIDATED,
            0x80070BF6 => WIN32::ERROR_APPEXEC_INVALID_HOST_GENERATION,
            0x80070BF7 => WIN32::ERROR_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION,
            0x80070BF8 => WIN32::ERROR_APPEXEC_INVALID_HOST_STATE,
            0x80070BF9 => WIN32::ERROR_APPEXEC_NO_DONOR,
            0x80070BFA => WIN32::ERROR_APPEXEC_HOST_ID_MISMATCH,
            0x80070BFB => WIN32::ERROR_APPEXEC_UNKNOWN_USER,
            0x80070BFC => WIN32::ERROR_APPEXEC_APP_COMPAT_BLOCK,
            0x80070BFD => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT,
            0x80070BFE => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION,
            0x80070BFF => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING,
            0x80070C00 => WIN32::ERROR_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES,
            0x80070C08 => WIN32::ERROR_VRF_VOLATILE_CFG_AND_IO_ENABLED,
            0x80070C09 => WIN32::ERROR_VRF_VOLATILE_NOT_STOPPABLE,
            0x80070C0A => WIN32::ERROR_VRF_VOLATILE_SAFE_MODE,
            0x80070C0B => WIN32::ERROR_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM,
            0x80070C0C => WIN32::ERROR_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS,
            0x80070C0D => WIN32::ERROR_VRF_VOLATILE_PROTECTED_DRIVER,
            0x80070C0E => WIN32::ERROR_VRF_VOLATILE_NMI_REGISTERED,
            0x80070C0F => WIN32::ERROR_VRF_VOLATILE_SETTINGS_CONFLICT,
            0x80070C76 => WIN32::ERROR_DIF_IOCALLBACK_NOT_REPLACED,
            0x80070C77 => WIN32::ERROR_DIF_LIVEDUMP_LIMIT_EXCEEDED,
            0x80070C78 => WIN32::ERROR_DIF_VOLATILE_SECTION_NOT_LOCKED,
            0x80070C79 => WIN32::ERROR_DIF_VOLATILE_DRIVER_HOTPATCHED,
            0x80070C7A => WIN32::ERROR_DIF_VOLATILE_INVALID_INFO,
            0x80070C7B => WIN32::ERROR_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING,
            0x80070C7C => WIN32::ERROR_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING,
            0x80070C7D => WIN32::ERROR_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED,
            0x80070C7E => WIN32::ERROR_DIF_VOLATILE_NOT_ALLOWED,
            0x80070C7F => WIN32::ERROR_DIF_BINDING_API_NOT_FOUND,
            0x80070F6E => WIN32::ERROR_IO_REISSUE_AS_CACHED,
            0x80070FA0 => WIN32::ERROR_WINS_INTERNAL,
            0x80070FA1 => WIN32::ERROR_CAN_NOT_DEL_LOCAL_WINS,
            0x80070FA2 => WIN32::ERROR_STATIC_INIT,
            0x80070FA3 => WIN32::ERROR_INC_BACKUP,
            0x80070FA4 => WIN32::ERROR_FULL_BACKUP,
            0x80070FA5 => WIN32::ERROR_REC_NON_EXISTENT,
            0x80070FA6 => WIN32::ERROR_RPL_NOT_ALLOWED,
            0x80070FD2 => WIN32::PEERDIST_ERROR_CONTENTINFO_VERSION_UNSUPPORTED,
            0x80070FD3 => WIN32::PEERDIST_ERROR_CANNOT_PARSE_CONTENTINFO,
            0x80070FD4 => WIN32::PEERDIST_ERROR_MISSING_DATA,
            0x80070FD5 => WIN32::PEERDIST_ERROR_NO_MORE,
            0x80070FD6 => WIN32::PEERDIST_ERROR_NOT_INITIALIZED,
            0x80070FD7 => WIN32::PEERDIST_ERROR_ALREADY_INITIALIZED,
            0x80070FD8 => WIN32::PEERDIST_ERROR_SHUTDOWN_IN_PROGRESS,
            0x80070FD9 => WIN32::PEERDIST_ERROR_INVALIDATED,
            0x80070FDA => WIN32::PEERDIST_ERROR_ALREADY_EXISTS,
            0x80070FDB => WIN32::PEERDIST_ERROR_OPERATION_NOTFOUND,
            0x80070FDC => WIN32::PEERDIST_ERROR_ALREADY_COMPLETED,
            0x80070FDD => WIN32::PEERDIST_ERROR_OUT_OF_BOUNDS,
            0x80070FDE => WIN32::PEERDIST_ERROR_VERSION_UNSUPPORTED,
            0x80070FDF => WIN32::PEERDIST_ERROR_INVALID_CONFIGURATION,
            0x80070FE0 => WIN32::PEERDIST_ERROR_NOT_LICENSED,
            0x80070FE1 => WIN32::PEERDIST_ERROR_SERVICE_UNAVAILABLE,
            0x80070FE2 => WIN32::PEERDIST_ERROR_TRUST_FAILURE,
            0x80071004 => WIN32::ERROR_DHCP_ADDRESS_CONFLICT,
            0x80071068 => WIN32::ERROR_WMI_GUID_NOT_FOUND,
            0x80071069 => WIN32::ERROR_WMI_INSTANCE_NOT_FOUND,
            0x8007106A => WIN32::ERROR_WMI_ITEMID_NOT_FOUND,
            0x8007106B => WIN32::ERROR_WMI_TRY_AGAIN,
            0x8007106C => WIN32::ERROR_WMI_DP_NOT_FOUND,
            0x8007106D => WIN32::ERROR_WMI_UNRESOLVED_INSTANCE_REF,
            0x8007106E => WIN32::ERROR_WMI_ALREADY_ENABLED,
            0x8007106F => WIN32::ERROR_WMI_GUID_DISCONNECTED,
            0x80071070 => WIN32::ERROR_WMI_SERVER_UNAVAILABLE,
            0x80071071 => WIN32::ERROR_WMI_DP_FAILED,
            0x80071072 => WIN32::ERROR_WMI_INVALID_MOF,
            0x80071073 => WIN32::ERROR_WMI_INVALID_REGINFO,
            0x80071074 => WIN32::ERROR_WMI_ALREADY_DISABLED,
            0x80071075 => WIN32::ERROR_WMI_READ_ONLY,
            0x80071076 => WIN32::ERROR_WMI_SET_FAILURE,
            0x8007109A => WIN32::ERROR_NOT_APPCONTAINER,
            0x8007109B => WIN32::ERROR_APPCONTAINER_REQUIRED,
            0x8007109C => WIN32::ERROR_NOT_SUPPORTED_IN_APPCONTAINER,
            0x8007109D => WIN32::ERROR_INVALID_PACKAGE_SID_LENGTH,
            0x800710CC => WIN32::ERROR_INVALID_MEDIA,
            0x800710CD => WIN32::ERROR_INVALID_LIBRARY,
            0x800710CE => WIN32::ERROR_INVALID_MEDIA_POOL,
            0x800710CF => WIN32::ERROR_DRIVE_MEDIA_MISMATCH,
            0x800710D0 => WIN32::ERROR_MEDIA_OFFLINE,
            0x800710D1 => WIN32::ERROR_LIBRARY_OFFLINE,
            0x800710D2 => WIN32::ERROR_EMPTY,
            0x800710D3 => WIN32::ERROR_NOT_EMPTY,
            0x800710D4 => WIN32::ERROR_MEDIA_UNAVAILABLE,
            0x800710D5 => WIN32::ERROR_RESOURCE_DISABLED,
            0x800710D6 => WIN32::ERROR_INVALID_CLEANER,
            0x800710D7 => WIN32::ERROR_UNABLE_TO_CLEAN,
            0x800710D8 => WIN32::ERROR_OBJECT_NOT_FOUND,
            0x800710D9 => WIN32::ERROR_DATABASE_FAILURE,
            0x800710DA => WIN32::ERROR_DATABASE_FULL,
            0x800710DB => WIN32::ERROR_MEDIA_INCOMPATIBLE,
            0x800710DC => WIN32::ERROR_RESOURCE_NOT_PRESENT,
            0x800710DD => WIN32::ERROR_INVALID_OPERATION,
            0x800710DE => WIN32::ERROR_MEDIA_NOT_AVAILABLE,
            0x800710DF => WIN32::ERROR_DEVICE_NOT_AVAILABLE,
            0x800710E0 => WIN32::ERROR_REQUEST_REFUSED,
            0x800710E1 => WIN32::ERROR_INVALID_DRIVE_OBJECT,
            0x800710E2 => WIN32::ERROR_LIBRARY_FULL,
            0x800710E3 => WIN32::ERROR_MEDIUM_NOT_ACCESSIBLE,
            0x800710E4 => WIN32::ERROR_UNABLE_TO_LOAD_MEDIUM,
            0x800710E5 => WIN32::ERROR_UNABLE_TO_INVENTORY_DRIVE,
            0x800710E6 => WIN32::ERROR_UNABLE_TO_INVENTORY_SLOT,
            0x800710E7 => WIN32::ERROR_UNABLE_TO_INVENTORY_TRANSPORT,
            0x800710E8 => WIN32::ERROR_TRANSPORT_FULL,
            0x800710E9 => WIN32::ERROR_CONTROLLING_IEPORT,
            0x800710EA => WIN32::ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA,
            0x800710EB => WIN32::ERROR_CLEANER_SLOT_SET,
            0x800710EC => WIN32::ERROR_CLEANER_SLOT_NOT_SET,
            0x800710ED => WIN32::ERROR_CLEANER_CARTRIDGE_SPENT,
            0x800710EE => WIN32::ERROR_UNEXPECTED_OMID,
            0x800710EF => WIN32::ERROR_CANT_DELETE_LAST_ITEM,
            0x800710F0 => WIN32::ERROR_MESSAGE_EXCEEDS_MAX_SIZE,
            0x800710F1 => WIN32::ERROR_VOLUME_CONTAINS_SYS_FILES,
            0x800710F2 => WIN32::ERROR_INDIGENOUS_TYPE,
            0x800710F3 => WIN32::ERROR_NO_SUPPORTING_DRIVES,
            0x800710F4 => WIN32::ERROR_CLEANER_CARTRIDGE_INSTALLED,
            0x800710F5 => WIN32::ERROR_IEPORT_FULL,
            0x800710FE => WIN32::ERROR_FILE_OFFLINE,
            0x800710FF => WIN32::ERROR_REMOTE_STORAGE_NOT_ACTIVE,
            0x80071100 => WIN32::ERROR_REMOTE_STORAGE_MEDIA_ERROR,
            0x80071126 => WIN32::ERROR_NOT_A_REPARSE_POINT,
            0x80071127 => WIN32::ERROR_REPARSE_ATTRIBUTE_CONFLICT,
            0x80071128 => WIN32::ERROR_INVALID_REPARSE_DATA,
            0x80071129 => WIN32::ERROR_REPARSE_TAG_INVALID,
            0x8007112A => WIN32::ERROR_REPARSE_TAG_MISMATCH,
            0x8007112B => WIN32::ERROR_REPARSE_POINT_ENCOUNTERED,
            0x80071130 => WIN32::ERROR_APP_DATA_NOT_FOUND,
            0x80071131 => WIN32::ERROR_APP_DATA_EXPIRED,
            0x80071132 => WIN32::ERROR_APP_DATA_CORRUPT,
            0x80071133 => WIN32::ERROR_APP_DATA_LIMIT_EXCEEDED,
            0x80071134 => WIN32::ERROR_APP_DATA_REBOOT_REQUIRED,
            0x80071144 => WIN32::ERROR_SECUREBOOT_ROLLBACK_DETECTED,
            0x80071145 => WIN32::ERROR_SECUREBOOT_POLICY_VIOLATION,
            0x80071146 => WIN32::ERROR_SECUREBOOT_INVALID_POLICY,
            0x80071147 => WIN32::ERROR_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND,
            0x80071148 => WIN32::ERROR_SECUREBOOT_POLICY_NOT_SIGNED,
            0x80071149 => WIN32::ERROR_SECUREBOOT_NOT_ENABLED,
            0x8007114A => WIN32::ERROR_SECUREBOOT_FILE_REPLACED,
            0x8007114B => WIN32::ERROR_SECUREBOOT_POLICY_NOT_AUTHORIZED,
            0x8007114C => WIN32::ERROR_SECUREBOOT_POLICY_UNKNOWN,
            0x8007114D => WIN32::ERROR_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION,
            0x8007114E => WIN32::ERROR_SECUREBOOT_PLATFORM_ID_MISMATCH,
            0x8007114F => WIN32::ERROR_SECUREBOOT_POLICY_ROLLBACK_DETECTED,
            0x80071150 => WIN32::ERROR_SECUREBOOT_POLICY_UPGRADE_MISMATCH,
            0x80071151 => WIN32::ERROR_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING,
            0x80071152 => WIN32::ERROR_SECUREBOOT_NOT_BASE_POLICY,
            0x80071153 => WIN32::ERROR_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY,
            0x80071158 => WIN32::ERROR_OFFLOAD_READ_FLT_NOT_SUPPORTED,
            0x80071159 => WIN32::ERROR_OFFLOAD_WRITE_FLT_NOT_SUPPORTED,
            0x8007115A => WIN32::ERROR_OFFLOAD_READ_FILE_NOT_SUPPORTED,
            0x8007115B => WIN32::ERROR_OFFLOAD_WRITE_FILE_NOT_SUPPORTED,
            0x8007115C => WIN32::ERROR_ALREADY_HAS_STREAM_ID,
            0x8007115D => WIN32::ERROR_SMR_GARBAGE_COLLECTION_REQUIRED,
            0x8007115E => WIN32::ERROR_WOF_WIM_HEADER_CORRUPT,
            0x8007115F => WIN32::ERROR_WOF_WIM_RESOURCE_TABLE_CORRUPT,
            0x80071160 => WIN32::ERROR_WOF_FILE_RESOURCE_TABLE_CORRUPT,
            0x80071161 => WIN32::ERROR_OBJECT_IS_IMMUTABLE,
            0x80071194 => WIN32::ERROR_VOLUME_NOT_SIS_ENABLED,
            0x800711C6 => WIN32::ERROR_SYSTEM_INTEGRITY_ROLLBACK_DETECTED,
            0x800711C7 => WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_VIOLATION,
            0x800711C8 => WIN32::ERROR_SYSTEM_INTEGRITY_INVALID_POLICY,
            0x800711C9 => WIN32::ERROR_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED,
            0x800711CA => WIN32::ERROR_SYSTEM_INTEGRITY_TOO_MANY_POLICIES,
            0x800711CB => WIN32::ERROR_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED,
            0x800711CC => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS,
            0x800711CD => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_PUA,
            0x800711CE => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT,
            0x800711CF => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_OFFLINE,
            0x800711D0 => WIN32::ERROR_VSM_NOT_INITIALIZED,
            0x800711D1 => WIN32::ERROR_VSM_DMA_PROTECTION_NOT_IN_USE,
            0x800711DA => WIN32::ERROR_PLATFORM_MANIFEST_NOT_AUTHORIZED,
            0x800711DB => WIN32::ERROR_PLATFORM_MANIFEST_INVALID,
            0x800711DC => WIN32::ERROR_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED,
            0x800711DD => WIN32::ERROR_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED,
            0x800711DE => WIN32::ERROR_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND,
            0x800711DF => WIN32::ERROR_PLATFORM_MANIFEST_NOT_ACTIVE,
            0x800711E0 => WIN32::ERROR_PLATFORM_MANIFEST_NOT_SIGNED,
            0x800711E4 => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE,
            0x800711E5 => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE,
            0x800711E6 => WIN32::ERROR_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE,
            0x80071389 => WIN32::ERROR_DEPENDENT_RESOURCE_EXISTS,
            0x8007138A => WIN32::ERROR_DEPENDENCY_NOT_FOUND,
            0x8007138B => WIN32::ERROR_DEPENDENCY_ALREADY_EXISTS,
            0x8007138C => WIN32::ERROR_RESOURCE_NOT_ONLINE,
            0x8007138D => WIN32::ERROR_HOST_NODE_NOT_AVAILABLE,
            0x8007138E => WIN32::ERROR_RESOURCE_NOT_AVAILABLE,
            0x8007138F => WIN32::ERROR_RESOURCE_NOT_FOUND,
            0x80071390 => WIN32::ERROR_SHUTDOWN_CLUSTER,
            0x80071391 => WIN32::ERROR_CANT_EVICT_ACTIVE_NODE,
            0x80071392 => WIN32::ERROR_OBJECT_ALREADY_EXISTS,
            0x80071393 => WIN32::ERROR_OBJECT_IN_LIST,
            0x80071394 => WIN32::ERROR_GROUP_NOT_AVAILABLE,
            0x80071395 => WIN32::ERROR_GROUP_NOT_FOUND,
            0x80071396 => WIN32::ERROR_GROUP_NOT_ONLINE,
            0x80071397 => WIN32::ERROR_HOST_NODE_NOT_RESOURCE_OWNER,
            0x80071398 => WIN32::ERROR_HOST_NODE_NOT_GROUP_OWNER,
            0x80071399 => WIN32::ERROR_RESMON_CREATE_FAILED,
            0x8007139A => WIN32::ERROR_RESMON_ONLINE_FAILED,
            0x8007139B => WIN32::ERROR_RESOURCE_ONLINE,
            0x8007139C => WIN32::ERROR_QUORUM_RESOURCE,
            0x8007139D => WIN32::ERROR_NOT_QUORUM_CAPABLE,
            0x8007139E => WIN32::ERROR_CLUSTER_SHUTTING_DOWN,
            0x8007139F => WIN32::ERROR_INVALID_STATE,
            0x800713A0 => WIN32::ERROR_RESOURCE_PROPERTIES_STORED,
            0x800713A1 => WIN32::ERROR_NOT_QUORUM_CLASS,
            0x800713A2 => WIN32::ERROR_CORE_RESOURCE,
            0x800713A3 => WIN32::ERROR_QUORUM_RESOURCE_ONLINE_FAILED,
            0x800713A4 => WIN32::ERROR_QUORUMLOG_OPEN_FAILED,
            0x800713A5 => WIN32::ERROR_CLUSTERLOG_CORRUPT,
            0x800713A6 => WIN32::ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE,
            0x800713A7 => WIN32::ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE,
            0x800713A8 => WIN32::ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND,
            0x800713A9 => WIN32::ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE,
            0x800713AA => WIN32::ERROR_QUORUM_OWNER_ALIVE,
            0x800713AB => WIN32::ERROR_NETWORK_NOT_AVAILABLE,
            0x800713AC => WIN32::ERROR_NODE_NOT_AVAILABLE,
            0x800713AD => WIN32::ERROR_ALL_NODES_NOT_AVAILABLE,
            0x800713AE => WIN32::ERROR_RESOURCE_FAILED,
            0x800713AF => WIN32::ERROR_CLUSTER_INVALID_NODE,
            0x800713B0 => WIN32::ERROR_CLUSTER_NODE_EXISTS,
            0x800713B1 => WIN32::ERROR_CLUSTER_JOIN_IN_PROGRESS,
            0x800713B2 => WIN32::ERROR_CLUSTER_NODE_NOT_FOUND,
            0x800713B3 => WIN32::ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND,
            0x800713B4 => WIN32::ERROR_CLUSTER_NETWORK_EXISTS,
            0x800713B5 => WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND,
            0x800713B6 => WIN32::ERROR_CLUSTER_NETINTERFACE_EXISTS,
            0x800713B7 => WIN32::ERROR_CLUSTER_NETINTERFACE_NOT_FOUND,
            0x800713B8 => WIN32::ERROR_CLUSTER_INVALID_REQUEST,
            0x800713B9 => WIN32::ERROR_CLUSTER_INVALID_NETWORK_PROVIDER,
            0x800713BA => WIN32::ERROR_CLUSTER_NODE_DOWN,
            0x800713BB => WIN32::ERROR_CLUSTER_NODE_UNREACHABLE,
            0x800713BC => WIN32::ERROR_CLUSTER_NODE_NOT_MEMBER,
            0x800713BD => WIN32::ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS,
            0x800713BE => WIN32::ERROR_CLUSTER_INVALID_NETWORK,
            0x800713C0 => WIN32::ERROR_CLUSTER_NODE_UP,
            0x800713C1 => WIN32::ERROR_CLUSTER_IPADDR_IN_USE,
            0x800713C2 => WIN32::ERROR_CLUSTER_NODE_NOT_PAUSED,
            0x800713C3 => WIN32::ERROR_CLUSTER_NO_SECURITY_CONTEXT,
            0x800713C4 => WIN32::ERROR_CLUSTER_NETWORK_NOT_INTERNAL,
            0x800713C5 => WIN32::ERROR_CLUSTER_NODE_ALREADY_UP,
            0x800713C6 => WIN32::ERROR_CLUSTER_NODE_ALREADY_DOWN,
            0x800713C7 => WIN32::ERROR_CLUSTER_NETWORK_ALREADY_ONLINE,
            0x800713C8 => WIN32::ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE,
            0x800713C9 => WIN32::ERROR_CLUSTER_NODE_ALREADY_MEMBER,
            0x800713CA => WIN32::ERROR_CLUSTER_LAST_INTERNAL_NETWORK,
            0x800713CB => WIN32::ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS,
            0x800713CC => WIN32::ERROR_INVALID_OPERATION_ON_QUORUM,
            0x800713CD => WIN32::ERROR_DEPENDENCY_NOT_ALLOWED,
            0x800713CE => WIN32::ERROR_CLUSTER_NODE_PAUSED,
            0x800713CF => WIN32::ERROR_NODE_CANT_HOST_RESOURCE,
            0x800713D0 => WIN32::ERROR_CLUSTER_NODE_NOT_READY,
            0x800713D1 => WIN32::ERROR_CLUSTER_NODE_SHUTTING_DOWN,
            0x800713D2 => WIN32::ERROR_CLUSTER_JOIN_ABORTED,
            0x800713D3 => WIN32::ERROR_CLUSTER_INCOMPATIBLE_VERSIONS,
            0x800713D4 => WIN32::ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED,
            0x800713D5 => WIN32::ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED,
            0x800713D6 => WIN32::ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND,
            0x800713D7 => WIN32::ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED,
            0x800713D8 => WIN32::ERROR_CLUSTER_RESNAME_NOT_FOUND,
            0x800713D9 => WIN32::ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED,
            0x800713DA => WIN32::ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST,
            0x800713DB => WIN32::ERROR_CLUSTER_DATABASE_SEQMISMATCH,
            0x800713DC => WIN32::ERROR_RESMON_INVALID_STATE,
            0x800713DD => WIN32::ERROR_CLUSTER_GUM_NOT_LOCKER,
            0x800713DE => WIN32::ERROR_QUORUM_DISK_NOT_FOUND,
            0x800713DF => WIN32::ERROR_DATABASE_BACKUP_CORRUPT,
            0x800713E0 => WIN32::ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT,
            0x800713E1 => WIN32::ERROR_RESOURCE_PROPERTY_UNCHANGEABLE,
            0x800713E2 => WIN32::ERROR_NO_ADMIN_ACCESS_POINT,
            0x80071702 => WIN32::ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE,
            0x80071703 => WIN32::ERROR_CLUSTER_QUORUMLOG_NOT_FOUND,
            0x80071704 => WIN32::ERROR_CLUSTER_MEMBERSHIP_HALT,
            0x80071705 => WIN32::ERROR_CLUSTER_INSTANCE_ID_MISMATCH,
            0x80071706 => WIN32::ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP,
            0x80071707 => WIN32::ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH,
            0x80071708 => WIN32::ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP,
            0x80071709 => WIN32::ERROR_CLUSTER_PARAMETER_MISMATCH,
            0x8007170A => WIN32::ERROR_NODE_CANNOT_BE_CLUSTERED,
            0x8007170B => WIN32::ERROR_CLUSTER_WRONG_OS_VERSION,
            0x8007170C => WIN32::ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME,
            0x8007170D => WIN32::ERROR_CLUSCFG_ALREADY_COMMITTED,
            0x8007170E => WIN32::ERROR_CLUSCFG_ROLLBACK_FAILED,
            0x8007170F => WIN32::ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT,
            0x80071710 => WIN32::ERROR_CLUSTER_OLD_VERSION,
            0x80071711 => WIN32::ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME,
            0x80071712 => WIN32::ERROR_CLUSTER_NO_NET_ADAPTERS,
            0x80071713 => WIN32::ERROR_CLUSTER_POISONED,
            0x80071714 => WIN32::ERROR_CLUSTER_GROUP_MOVING,
            0x80071715 => WIN32::ERROR_CLUSTER_RESOURCE_TYPE_BUSY,
            0x80071716 => WIN32::ERROR_RESOURCE_CALL_TIMED_OUT,
            0x80071717 => WIN32::ERROR_INVALID_CLUSTER_IPV6_ADDRESS,
            0x80071718 => WIN32::ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION,
            0x80071719 => WIN32::ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS,
            0x8007171A => WIN32::ERROR_CLUSTER_PARTIAL_SEND,
            0x8007171B => WIN32::ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION,
            0x8007171C => WIN32::ERROR_CLUSTER_INVALID_STRING_TERMINATION,
            0x8007171D => WIN32::ERROR_CLUSTER_INVALID_STRING_FORMAT,
            0x8007171E => WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS,
            0x8007171F => WIN32::ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS,
            0x80071720 => WIN32::ERROR_CLUSTER_NULL_DATA,
            0x80071721 => WIN32::ERROR_CLUSTER_PARTIAL_READ,
            0x80071722 => WIN32::ERROR_CLUSTER_PARTIAL_WRITE,
            0x80071723 => WIN32::ERROR_CLUSTER_CANT_DESERIALIZE_DATA,
            0x80071724 => WIN32::ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT,
            0x80071725 => WIN32::ERROR_CLUSTER_NO_QUORUM,
            0x80071726 => WIN32::ERROR_CLUSTER_INVALID_IPV6_NETWORK,
            0x80071727 => WIN32::ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK,
            0x80071728 => WIN32::ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP,
            0x80071729 => WIN32::ERROR_DEPENDENCY_TREE_TOO_COMPLEX,
            0x8007172A => WIN32::ERROR_EXCEPTION_IN_RESOURCE_CALL,
            0x8007172B => WIN32::ERROR_CLUSTER_RHS_FAILED_INITIALIZATION,
            0x8007172C => WIN32::ERROR_CLUSTER_NOT_INSTALLED,
            0x8007172D => WIN32::ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE,
            0x8007172E => WIN32::ERROR_CLUSTER_MAX_NODES_IN_CLUSTER,
            0x8007172F => WIN32::ERROR_CLUSTER_TOO_MANY_NODES,
            0x80071730 => WIN32::ERROR_CLUSTER_OBJECT_ALREADY_USED,
            0x80071731 => WIN32::ERROR_NONCORE_GROUPS_FOUND,
            0x80071732 => WIN32::ERROR_FILE_SHARE_RESOURCE_CONFLICT,
            0x80071733 => WIN32::ERROR_CLUSTER_EVICT_INVALID_REQUEST,
            0x80071734 => WIN32::ERROR_CLUSTER_SINGLETON_RESOURCE,
            0x80071735 => WIN32::ERROR_CLUSTER_GROUP_SINGLETON_RESOURCE,
            0x80071736 => WIN32::ERROR_CLUSTER_RESOURCE_PROVIDER_FAILED,
            0x80071737 => WIN32::ERROR_CLUSTER_RESOURCE_CONFIGURATION_ERROR,
            0x80071738 => WIN32::ERROR_CLUSTER_GROUP_BUSY,
            0x80071739 => WIN32::ERROR_CLUSTER_NOT_SHARED_VOLUME,
            0x8007173A => WIN32::ERROR_CLUSTER_INVALID_SECURITY_DESCRIPTOR,
            0x8007173B => WIN32::ERROR_CLUSTER_SHARED_VOLUMES_IN_USE,
            0x8007173C => WIN32::ERROR_CLUSTER_USE_SHARED_VOLUMES_API,
            0x8007173D => WIN32::ERROR_CLUSTER_BACKUP_IN_PROGRESS,
            0x8007173E => WIN32::ERROR_NON_CSV_PATH,
            0x8007173F => WIN32::ERROR_CSV_VOLUME_NOT_LOCAL,
            0x80071740 => WIN32::ERROR_CLUSTER_WATCHDOG_TERMINATING,
            0x80071741 => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_INCOMPATIBLE_NODES,
            0x80071742 => WIN32::ERROR_CLUSTER_INVALID_NODE_WEIGHT,
            0x80071743 => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_CALL,
            0x80071744 => WIN32::ERROR_RESMON_SYSTEM_RESOURCES_LACKING,
            0x80071745 => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_DESTINATION,
            0x80071746 => WIN32::ERROR_CLUSTER_RESOURCE_VETOED_MOVE_NOT_ENOUGH_RESOURCES_ON_SOURCE,
            0x80071747 => WIN32::ERROR_CLUSTER_GROUP_QUEUED,
            0x80071748 => WIN32::ERROR_CLUSTER_RESOURCE_LOCKED_STATUS,
            0x80071749 => WIN32::ERROR_CLUSTER_SHARED_VOLUME_FAILOVER_NOT_ALLOWED,
            0x8007174A => WIN32::ERROR_CLUSTER_NODE_DRAIN_IN_PROGRESS,
            0x8007174B => WIN32::ERROR_CLUSTER_DISK_NOT_CONNECTED,
            0x8007174C => WIN32::ERROR_DISK_NOT_CSV_CAPABLE,
            0x8007174D => WIN32::ERROR_RESOURCE_NOT_IN_AVAILABLE_STORAGE,
            0x8007174E => WIN32::ERROR_CLUSTER_SHARED_VOLUME_REDIRECTED,
            0x8007174F => WIN32::ERROR_CLUSTER_SHARED_VOLUME_NOT_REDIRECTED,
            0x80071750 => WIN32::ERROR_CLUSTER_CANNOT_RETURN_PROPERTIES,
            0x80071751 => WIN32::ERROR_CLUSTER_RESOURCE_CONTAINS_UNSUPPORTED_DIFF_AREA_FOR_SHARED_VOLUMES,
            0x80071752 => WIN32::ERROR_CLUSTER_RESOURCE_IS_IN_MAINTENANCE_MODE,
            0x80071753 => WIN32::ERROR_CLUSTER_AFFINITY_CONFLICT,
            0x80071754 => WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICA_VIRTUAL_MACHINE,
            0x80071755 => WIN32::ERROR_CLUSTER_UPGRADE_INCOMPATIBLE_VERSIONS,
            0x80071756 => WIN32::ERROR_CLUSTER_UPGRADE_FIX_QUORUM_NOT_SUPPORTED,
            0x80071757 => WIN32::ERROR_CLUSTER_UPGRADE_RESTART_REQUIRED,
            0x80071758 => WIN32::ERROR_CLUSTER_UPGRADE_IN_PROGRESS,
            0x80071759 => WIN32::ERROR_CLUSTER_UPGRADE_INCOMPLETE,
            0x8007175A => WIN32::ERROR_CLUSTER_NODE_IN_GRACE_PERIOD,
            0x8007175B => WIN32::ERROR_CLUSTER_CSV_IO_PAUSE_TIMEOUT,
            0x8007175C => WIN32::ERROR_NODE_NOT_ACTIVE_CLUSTER_MEMBER,
            0x8007175D => WIN32::ERROR_CLUSTER_RESOURCE_NOT_MONITORED,
            0x8007175E => WIN32::ERROR_CLUSTER_RESOURCE_DOES_NOT_SUPPORT_UNMONITORED,
            0x8007175F => WIN32::ERROR_CLUSTER_RESOURCE_IS_REPLICATED,
            0x80071760 => WIN32::ERROR_CLUSTER_NODE_ISOLATED,
            0x80071761 => WIN32::ERROR_CLUSTER_NODE_QUARANTINED,
            0x80071762 => WIN32::ERROR_CLUSTER_DATABASE_UPDATE_CONDITION_FAILED,
            0x80071763 => WIN32::ERROR_CLUSTER_SPACE_DEGRADED,
            0x80071764 => WIN32::ERROR_CLUSTER_TOKEN_DELEGATION_NOT_SUPPORTED,
            0x80071765 => WIN32::ERROR_CLUSTER_CSV_INVALID_HANDLE,
            0x80071766 => WIN32::ERROR_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR,
            0x80071767 => WIN32::ERROR_GROUPSET_NOT_AVAILABLE,
            0x80071768 => WIN32::ERROR_GROUPSET_NOT_FOUND,
            0x80071769 => WIN32::ERROR_GROUPSET_CANT_PROVIDE,
            0x8007176A => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_PARENT_NOT_FOUND,
            0x8007176B => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_INVALID_HIERARCHY,
            0x8007176C => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_FAILED_S2D_VALIDATION,
            0x8007176D => WIN32::ERROR_CLUSTER_FAULT_DOMAIN_S2D_CONNECTIVITY_LOSS,
            0x8007176E => WIN32::ERROR_CLUSTER_INVALID_INFRASTRUCTURE_FILESERVER_NAME,
            0x8007176F => WIN32::ERROR_CLUSTERSET_MANAGEMENT_CLUSTER_UNREACHABLE,
            0x80071770 => WIN32::ERROR_ENCRYPTION_FAILED,
            0x80071771 => WIN32::ERROR_DECRYPTION_FAILED,
            0x80071772 => WIN32::ERROR_FILE_ENCRYPTED,
            0x80071773 => WIN32::ERROR_NO_RECOVERY_POLICY,
            0x80071774 => WIN32::ERROR_NO_EFS,
            0x80071775 => WIN32::ERROR_WRONG_EFS,
            0x80071776 => WIN32::ERROR_NO_USER_KEYS,
            0x80071777 => WIN32::ERROR_FILE_NOT_ENCRYPTED,
            0x80071778 => WIN32::ERROR_NOT_EXPORT_FORMAT,
            0x80071779 => WIN32::ERROR_FILE_READ_ONLY,
            0x8007177A => WIN32::ERROR_DIR_EFS_DISALLOWED,
            0x8007177B => WIN32::ERROR_EFS_SERVER_NOT_TRUSTED,
            0x8007177C => WIN32::ERROR_BAD_RECOVERY_POLICY,
            0x8007177D => WIN32::ERROR_EFS_ALG_BLOB_TOO_BIG,
            0x8007177E => WIN32::ERROR_VOLUME_NOT_SUPPORT_EFS,
            0x8007177F => WIN32::ERROR_EFS_DISABLED,
            0x80071780 => WIN32::ERROR_EFS_VERSION_NOT_SUPPORT,
            0x80071781 => WIN32::ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE,
            0x80071782 => WIN32::ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER,
            0x80071783 => WIN32::ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE,
            0x80071784 => WIN32::ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE,
            0x80071785 => WIN32::ERROR_CS_ENCRYPTION_FILE_NOT_CSE,
            0x80071786 => WIN32::ERROR_ENCRYPTION_POLICY_DENIES_OPERATION,
            0x80071787 => WIN32::ERROR_WIP_ENCRYPTION_FAILED,
            0x800717E6 => WIN32::ERROR_NO_BROWSER_SERVERS_FOUND,
            0x80071838 => WIN32::SCHED_E_SERVICE_NOT_LOCALSYSTEM,
            0x8007186A => WIN32::ERROR_CLUSTER_OBJECT_IS_CLUSTER_SET_VM,
            0x800719C8 => WIN32::ERROR_LOG_SECTOR_INVALID,
            0x800719C9 => WIN32::ERROR_LOG_SECTOR_PARITY_INVALID,
            0x800719CA => WIN32::ERROR_LOG_SECTOR_REMAPPED,
            0x800719CB => WIN32::ERROR_LOG_BLOCK_INCOMPLETE,
            0x800719CC => WIN32::ERROR_LOG_INVALID_RANGE,
            0x800719CD => WIN32::ERROR_LOG_BLOCKS_EXHAUSTED,
            0x800719CE => WIN32::ERROR_LOG_READ_CONTEXT_INVALID,
            0x800719CF => WIN32::ERROR_LOG_RESTART_INVALID,
            0x800719D0 => WIN32::ERROR_LOG_BLOCK_VERSION,
            0x800719D1 => WIN32::ERROR_LOG_BLOCK_INVALID,
            0x800719D2 => WIN32::ERROR_LOG_READ_MODE_INVALID,
            0x800719D3 => WIN32::ERROR_LOG_NO_RESTART,
            0x800719D4 => WIN32::ERROR_LOG_METADATA_CORRUPT,
            0x800719D5 => WIN32::ERROR_LOG_METADATA_INVALID,
            0x800719D6 => WIN32::ERROR_LOG_METADATA_INCONSISTENT,
            0x800719D7 => WIN32::ERROR_LOG_RESERVATION_INVALID,
            0x800719D8 => WIN32::ERROR_LOG_CANT_DELETE,
            0x800719D9 => WIN32::ERROR_LOG_CONTAINER_LIMIT_EXCEEDED,
            0x800719DA => WIN32::ERROR_LOG_START_OF_LOG,
            0x800719DB => WIN32::ERROR_LOG_POLICY_ALREADY_INSTALLED,
            0x800719DC => WIN32::ERROR_LOG_POLICY_NOT_INSTALLED,
            0x800719DD => WIN32::ERROR_LOG_POLICY_INVALID,
            0x800719DE => WIN32::ERROR_LOG_POLICY_CONFLICT,
            0x800719DF => WIN32::ERROR_LOG_PINNED_ARCHIVE_TAIL,
            0x800719E0 => WIN32::ERROR_LOG_RECORD_NONEXISTENT,
            0x800719E1 => WIN32::ERROR_LOG_RECORDS_RESERVED_INVALID,
            0x800719E2 => WIN32::ERROR_LOG_SPACE_RESERVED_INVALID,
            0x800719E3 => WIN32::ERROR_LOG_TAIL_INVALID,
            0x800719E4 => WIN32::ERROR_LOG_FULL,
            0x800719E5 => WIN32::ERROR_COULD_NOT_RESIZE_LOG,
            0x800719E6 => WIN32::ERROR_LOG_MULTIPLEXED,
            0x800719E7 => WIN32::ERROR_LOG_DEDICATED,
            0x800719E8 => WIN32::ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS,
            0x800719E9 => WIN32::ERROR_LOG_ARCHIVE_IN_PROGRESS,
            0x800719EA => WIN32::ERROR_LOG_EPHEMERAL,
            0x800719EB => WIN32::ERROR_LOG_NOT_ENOUGH_CONTAINERS,
            0x800719EC => WIN32::ERROR_LOG_CLIENT_ALREADY_REGISTERED,
            0x800719ED => WIN32::ERROR_LOG_CLIENT_NOT_REGISTERED,
            0x800719EE => WIN32::ERROR_LOG_FULL_HANDLER_IN_PROGRESS,
            0x800719EF => WIN32::ERROR_LOG_CONTAINER_READ_FAILED,
            0x800719F0 => WIN32::ERROR_LOG_CONTAINER_WRITE_FAILED,
            0x800719F1 => WIN32::ERROR_LOG_CONTAINER_OPEN_FAILED,
            0x800719F2 => WIN32::ERROR_LOG_CONTAINER_STATE_INVALID,
            0x800719F3 => WIN32::ERROR_LOG_STATE_INVALID,
            0x800719F4 => WIN32::ERROR_LOG_PINNED,
            0x800719F5 => WIN32::ERROR_LOG_METADATA_FLUSH_FAILED,
            0x800719F6 => WIN32::ERROR_LOG_INCONSISTENT_SECURITY,
            0x800719F7 => WIN32::ERROR_LOG_APPENDED_FLUSH_FAILED,
            0x800719F8 => WIN32::ERROR_LOG_PINNED_RESERVATION,
            0x80071A2C => WIN32::ERROR_INVALID_TRANSACTION,
            0x80071A2D => WIN32::ERROR_TRANSACTION_NOT_ACTIVE,
            0x80071A2E => WIN32::ERROR_TRANSACTION_REQUEST_NOT_VALID,
            0x80071A2F => WIN32::ERROR_TRANSACTION_NOT_REQUESTED,
            0x80071A30 => WIN32::ERROR_TRANSACTION_ALREADY_ABORTED,
            0x80071A31 => WIN32::ERROR_TRANSACTION_ALREADY_COMMITTED,
            0x80071A32 => WIN32::ERROR_TM_INITIALIZATION_FAILED,
            0x80071A33 => WIN32::ERROR_RESOURCEMANAGER_READ_ONLY,
            0x80071A34 => WIN32::ERROR_TRANSACTION_NOT_JOINED,
            0x80071A35 => WIN32::ERROR_TRANSACTION_SUPERIOR_EXISTS,
            0x80071A36 => WIN32::ERROR_CRM_PROTOCOL_ALREADY_EXISTS,
            0x80071A37 => WIN32::ERROR_TRANSACTION_PROPAGATION_FAILED,
            0x80071A38 => WIN32::ERROR_CRM_PROTOCOL_NOT_FOUND,
            0x80071A39 => WIN32::ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER,
            0x80071A3A => WIN32::ERROR_CURRENT_TRANSACTION_NOT_VALID,
            0x80071A3B => WIN32::ERROR_TRANSACTION_NOT_FOUND,
            0x80071A3C => WIN32::ERROR_RESOURCEMANAGER_NOT_FOUND,
            0x80071A3D => WIN32::ERROR_ENLISTMENT_NOT_FOUND,
            0x80071A3E => WIN32::ERROR_TRANSACTIONMANAGER_NOT_FOUND,
            0x80071A3F => WIN32::ERROR_TRANSACTIONMANAGER_NOT_ONLINE,
            0x80071A40 => WIN32::ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION,
            0x80071A41 => WIN32::ERROR_TRANSACTION_NOT_ROOT,
            0x80071A42 => WIN32::ERROR_TRANSACTION_OBJECT_EXPIRED,
            0x80071A43 => WIN32::ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED,
            0x80071A44 => WIN32::ERROR_TRANSACTION_RECORD_TOO_LONG,
            0x80071A45 => WIN32::ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED,
            0x80071A46 => WIN32::ERROR_TRANSACTION_INTEGRITY_VIOLATED,
            0x80071A47 => WIN32::ERROR_TRANSACTIONMANAGER_IDENTITY_MISMATCH,
            0x80071A48 => WIN32::ERROR_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT,
            0x80071A49 => WIN32::ERROR_TRANSACTION_MUST_WRITETHROUGH,
            0x80071A4A => WIN32::ERROR_TRANSACTION_NO_SUPERIOR,
            0x80071A4B => WIN32::ERROR_HEURISTIC_DAMAGE_POSSIBLE,
            0x80071A90 => WIN32::ERROR_TRANSACTIONAL_CONFLICT,
            0x80071A91 => WIN32::ERROR_RM_NOT_ACTIVE,
            0x80071A92 => WIN32::ERROR_RM_METADATA_CORRUPT,
            0x80071A93 => WIN32::ERROR_DIRECTORY_NOT_RM,
            0x80071A95 => WIN32::ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE,
            0x80071A96 => WIN32::ERROR_LOG_RESIZE_INVALID_SIZE,
            0x80071A97 => WIN32::ERROR_OBJECT_NO_LONGER_EXISTS,
            0x80071A98 => WIN32::ERROR_STREAM_MINIVERSION_NOT_FOUND,
            0x80071A99 => WIN32::ERROR_STREAM_MINIVERSION_NOT_VALID,
            0x80071A9A => WIN32::ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION,
            0x80071A9B => WIN32::ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT,
            0x80071A9C => WIN32::ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS,
            0x80071A9E => WIN32::ERROR_REMOTE_FILE_VERSION_MISMATCH,
            0x80071A9F => WIN32::ERROR_HANDLE_NO_LONGER_VALID,
            0x80071AA0 => WIN32::ERROR_NO_TXF_METADATA,
            0x80071AA1 => WIN32::ERROR_LOG_CORRUPTION_DETECTED,
            0x80071AA2 => WIN32::ERROR_CANT_RECOVER_WITH_HANDLE_OPEN,
            0x80071AA3 => WIN32::ERROR_RM_DISCONNECTED,
            0x80071AA4 => WIN32::ERROR_ENLISTMENT_NOT_SUPERIOR,
            0x80071AA5 => WIN32::ERROR_RECOVERY_NOT_NEEDED,
            0x80071AA6 => WIN32::ERROR_RM_ALREADY_STARTED,
            0x80071AA7 => WIN32::ERROR_FILE_IDENTITY_NOT_PERSISTENT,
            0x80071AA8 => WIN32::ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY,
            0x80071AA9 => WIN32::ERROR_CANT_CROSS_RM_BOUNDARY,
            0x80071AAA => WIN32::ERROR_TXF_DIR_NOT_EMPTY,
            0x80071AAB => WIN32::ERROR_INDOUBT_TRANSACTIONS_EXIST,
            0x80071AAC => WIN32::ERROR_TM_VOLATILE,
            0x80071AAD => WIN32::ERROR_ROLLBACK_TIMER_EXPIRED,
            0x80071AAE => WIN32::ERROR_TXF_ATTRIBUTE_CORRUPT,
            0x80071AAF => WIN32::ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION,
            0x80071AB0 => WIN32::ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED,
            0x80071AB1 => WIN32::ERROR_LOG_GROWTH_FAILED,
            0x80071AB2 => WIN32::ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE,
            0x80071AB3 => WIN32::ERROR_TXF_METADATA_ALREADY_PRESENT,
            0x80071AB4 => WIN32::ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET,
            0x80071AB5 => WIN32::ERROR_TRANSACTION_REQUIRED_PROMOTION,
            0x80071AB6 => WIN32::ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION,
            0x80071AB7 => WIN32::ERROR_TRANSACTIONS_NOT_FROZEN,
            0x80071AB8 => WIN32::ERROR_TRANSACTION_FREEZE_IN_PROGRESS,
            0x80071AB9 => WIN32::ERROR_NOT_SNAPSHOT_VOLUME,
            0x80071ABA => WIN32::ERROR_NO_SAVEPOINT_WITH_OPEN_FILES,
            0x80071ABB => WIN32::ERROR_DATA_LOST_REPAIR,
            0x80071ABC => WIN32::ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION,
            0x80071ABD => WIN32::ERROR_TM_IDENTITY_MISMATCH,
            0x80071ABE => WIN32::ERROR_FLOATED_SECTION,
            0x80071ABF => WIN32::ERROR_CANNOT_ACCEPT_TRANSACTED_WORK,
            0x80071AC0 => WIN32::ERROR_CANNOT_ABORT_TRANSACTIONS,
            0x80071AC1 => WIN32::ERROR_BAD_CLUSTERS,
            0x80071AC2 => WIN32::ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION,
            0x80071AC3 => WIN32::ERROR_VOLUME_DIRTY,
            0x80071AC4 => WIN32::ERROR_NO_LINK_TRACKING_IN_TRANSACTION,
            0x80071AC5 => WIN32::ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION,
            0x80071AC6 => WIN32::ERROR_EXPIRED_HANDLE,
            0x80071AC7 => WIN32::ERROR_TRANSACTION_NOT_ENLISTED,
            0x80071B59 => WIN32::ERROR_CTX_WINSTATION_NAME_INVALID,
            0x80071B5A => WIN32::ERROR_CTX_INVALID_PD,
            0x80071B5B => WIN32::ERROR_CTX_PD_NOT_FOUND,
            0x80071B5C => WIN32::ERROR_CTX_WD_NOT_FOUND,
            0x80071B5D => WIN32::ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY,
            0x80071B5E => WIN32::ERROR_CTX_SERVICE_NAME_COLLISION,
            0x80071B5F => WIN32::ERROR_CTX_CLOSE_PENDING,
            0x80071B60 => WIN32::ERROR_CTX_NO_OUTBUF,
            0x80071B61 => WIN32::ERROR_CTX_MODEM_INF_NOT_FOUND,
            0x80071B62 => WIN32::ERROR_CTX_INVALID_MODEMNAME,
            0x80071B63 => WIN32::ERROR_CTX_MODEM_RESPONSE_ERROR,
            0x80071B64 => WIN32::ERROR_CTX_MODEM_RESPONSE_TIMEOUT,
            0x80071B65 => WIN32::ERROR_CTX_MODEM_RESPONSE_NO_CARRIER,
            0x80071B66 => WIN32::ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE,
            0x80071B67 => WIN32::ERROR_CTX_MODEM_RESPONSE_BUSY,
            0x80071B68 => WIN32::ERROR_CTX_MODEM_RESPONSE_VOICE,
            0x80071B69 => WIN32::ERROR_CTX_TD_ERROR,
            0x80071B6E => WIN32::ERROR_CTX_WINSTATION_NOT_FOUND,
            0x80071B6F => WIN32::ERROR_CTX_WINSTATION_ALREADY_EXISTS,
            0x80071B70 => WIN32::ERROR_CTX_WINSTATION_BUSY,
            0x80071B71 => WIN32::ERROR_CTX_BAD_VIDEO_MODE,
            0x80071B7B => WIN32::ERROR_CTX_GRAPHICS_INVALID,
            0x80071B7D => WIN32::ERROR_CTX_LOGON_DISABLED,
            0x80071B7E => WIN32::ERROR_CTX_NOT_CONSOLE,
            0x80071B80 => WIN32::ERROR_CTX_CLIENT_QUERY_TIMEOUT,
            0x80071B81 => WIN32::ERROR_CTX_CONSOLE_DISCONNECT,
            0x80071B82 => WIN32::ERROR_CTX_CONSOLE_CONNECT,
            0x80071B84 => WIN32::ERROR_CTX_SHADOW_DENIED,
            0x80071B85 => WIN32::ERROR_CTX_WINSTATION_ACCESS_DENIED,
            0x80071B89 => WIN32::ERROR_CTX_INVALID_WD,
            0x80071B8A => WIN32::ERROR_CTX_SHADOW_INVALID,
            0x80071B8B => WIN32::ERROR_CTX_SHADOW_DISABLED,
            0x80071B8C => WIN32::ERROR_CTX_CLIENT_LICENSE_IN_USE,
            0x80071B8D => WIN32::ERROR_CTX_CLIENT_LICENSE_NOT_SET,
            0x80071B8E => WIN32::ERROR_CTX_LICENSE_NOT_AVAILABLE,
            0x80071B8F => WIN32::ERROR_CTX_LICENSE_CLIENT_INVALID,
            0x80071B90 => WIN32::ERROR_CTX_LICENSE_EXPIRED,
            0x80071B91 => WIN32::ERROR_CTX_SHADOW_NOT_RUNNING,
            0x80071B92 => WIN32::ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE,
            0x80071B93 => WIN32::ERROR_ACTIVATION_COUNT_EXCEEDED,
            0x80071B94 => WIN32::ERROR_CTX_WINSTATIONS_DISABLED,
            0x80071B95 => WIN32::ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED,
            0x80071B96 => WIN32::ERROR_CTX_SESSION_IN_USE,
            0x80071B97 => WIN32::ERROR_CTX_NO_FORCE_LOGOFF,
            0x80071B98 => WIN32::ERROR_CTX_ACCOUNT_RESTRICTION,
            0x80071B99 => WIN32::ERROR_RDP_PROTOCOL_ERROR,
            0x80071B9A => WIN32::ERROR_CTX_CDM_CONNECT,
            0x80071B9B => WIN32::ERROR_CTX_CDM_DISCONNECT,
            0x80071B9C => WIN32::ERROR_CTX_SECURITY_LAYER_ERROR,
            0x80071B9D => WIN32::ERROR_TS_INCOMPATIBLE_SESSIONS,
            0x80071B9E => WIN32::ERROR_TS_VIDEO_SUBSYSTEM_ERROR,
            0x80071F41 => WIN32::FRS_ERR_INVALID_API_SEQUENCE,
            0x80071F42 => WIN32::FRS_ERR_STARTING_SERVICE,
            0x80071F43 => WIN32::FRS_ERR_STOPPING_SERVICE,
            0x80071F44 => WIN32::FRS_ERR_INTERNAL_API,
            0x80071F45 => WIN32::FRS_ERR_INTERNAL,
            0x80071F46 => WIN32::FRS_ERR_SERVICE_COMM,
            0x80071F47 => WIN32::FRS_ERR_INSUFFICIENT_PRIV,
            0x80071F48 => WIN32::FRS_ERR_AUTHENTICATION,
            0x80071F49 => WIN32::FRS_ERR_PARENT_INSUFFICIENT_PRIV,
            0x80071F4A => WIN32::FRS_ERR_PARENT_AUTHENTICATION,
            0x80071F4B => WIN32::FRS_ERR_CHILD_TO_PARENT_COMM,
            0x80071F4C => WIN32::FRS_ERR_PARENT_TO_CHILD_COMM,
            0x80071F4D => WIN32::FRS_ERR_SYSVOL_POPULATE,
            0x80071F4E => WIN32::FRS_ERR_SYSVOL_POPULATE_TIMEOUT,
            0x80071F4F => WIN32::FRS_ERR_SYSVOL_IS_BUSY,
            0x80071F50 => WIN32::FRS_ERR_SYSVOL_DEMOTE,
            0x80071F51 => WIN32::FRS_ERR_INVALID_SERVICE_PARAMETER,
            0x80072008 => WIN32::ERROR_DS_NOT_INSTALLED,
            0x80072009 => WIN32::ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY,
            0x8007200A => WIN32::ERROR_DS_NO_ATTRIBUTE_OR_VALUE,
            0x8007200B => WIN32::ERROR_DS_INVALID_ATTRIBUTE_SYNTAX,
            0x8007200C => WIN32::ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED,
            0x8007200D => WIN32::ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS,
            0x8007200E => WIN32::ERROR_DS_BUSY,
            0x8007200F => WIN32::ERROR_DS_UNAVAILABLE,
            0x80072010 => WIN32::ERROR_DS_NO_RIDS_ALLOCATED,
            0x80072011 => WIN32::ERROR_DS_NO_MORE_RIDS,
            0x80072012 => WIN32::ERROR_DS_INCORRECT_ROLE_OWNER,
            0x80072013 => WIN32::ERROR_DS_RIDMGR_INIT_ERROR,
            0x80072014 => WIN32::ERROR_DS_OBJ_CLASS_VIOLATION,
            0x80072015 => WIN32::ERROR_DS_CANT_ON_NON_LEAF,
            0x80072016 => WIN32::ERROR_DS_CANT_ON_RDN,
            0x80072017 => WIN32::ERROR_DS_CANT_MOD_OBJ_CLASS,
            0x80072018 => WIN32::ERROR_DS_CROSS_DOM_MOVE_ERROR,
            0x80072019 => WIN32::ERROR_DS_GC_NOT_AVAILABLE,
            0x8007201A => WIN32::ERROR_SHARED_POLICY,
            0x8007201B => WIN32::ERROR_POLICY_OBJECT_NOT_FOUND,
            0x8007201C => WIN32::ERROR_POLICY_ONLY_IN_DS,
            0x8007201D => WIN32::ERROR_PROMOTION_ACTIVE,
            0x8007201E => WIN32::ERROR_NO_PROMOTION_ACTIVE,
            0x80072020 => WIN32::ERROR_DS_OPERATIONS_ERROR,
            0x80072021 => WIN32::ERROR_DS_PROTOCOL_ERROR,
            0x80072022 => WIN32::ERROR_DS_TIMELIMIT_EXCEEDED,
            0x80072023 => WIN32::ERROR_DS_SIZELIMIT_EXCEEDED,
            0x80072024 => WIN32::ERROR_DS_ADMIN_LIMIT_EXCEEDED,
            0x80072025 => WIN32::ERROR_DS_COMPARE_FALSE,
            0x80072026 => WIN32::ERROR_DS_COMPARE_TRUE,
            0x80072027 => WIN32::ERROR_DS_AUTH_METHOD_NOT_SUPPORTED,
            0x80072028 => WIN32::ERROR_DS_STRONG_AUTH_REQUIRED,
            0x80072029 => WIN32::ERROR_DS_INAPPROPRIATE_AUTH,
            0x8007202A => WIN32::ERROR_DS_AUTH_UNKNOWN,
            0x8007202B => WIN32::ERROR_DS_REFERRAL,
            0x8007202C => WIN32::ERROR_DS_UNAVAILABLE_CRIT_EXTENSION,
            0x8007202D => WIN32::ERROR_DS_CONFIDENTIALITY_REQUIRED,
            0x8007202E => WIN32::ERROR_DS_INAPPROPRIATE_MATCHING,
            0x8007202F => WIN32::ERROR_DS_CONSTRAINT_VIOLATION,
            0x80072030 => WIN32::ERROR_DS_NO_SUCH_OBJECT,
            0x80072031 => WIN32::ERROR_DS_ALIAS_PROBLEM,
            0x80072032 => WIN32::ERROR_DS_INVALID_DN_SYNTAX,
            0x80072033 => WIN32::ERROR_DS_IS_LEAF,
            0x80072034 => WIN32::ERROR_DS_ALIAS_DEREF_PROBLEM,
            0x80072035 => WIN32::ERROR_DS_UNWILLING_TO_PERFORM,
            0x80072036 => WIN32::ERROR_DS_LOOP_DETECT,
            0x80072037 => WIN32::ERROR_DS_NAMING_VIOLATION,
            0x80072038 => WIN32::ERROR_DS_OBJECT_RESULTS_TOO_LARGE,
            0x80072039 => WIN32::ERROR_DS_AFFECTS_MULTIPLE_DSAS,
            0x8007203A => WIN32::ERROR_DS_SERVER_DOWN,
            0x8007203B => WIN32::ERROR_DS_LOCAL_ERROR,
            0x8007203C => WIN32::ERROR_DS_ENCODING_ERROR,
            0x8007203D => WIN32::ERROR_DS_DECODING_ERROR,
            0x8007203E => WIN32::ERROR_DS_FILTER_UNKNOWN,
            0x8007203F => WIN32::ERROR_DS_PARAM_ERROR,
            0x80072040 => WIN32::ERROR_DS_NOT_SUPPORTED,
            0x80072041 => WIN32::ERROR_DS_NO_RESULTS_RETURNED,
            0x80072042 => WIN32::ERROR_DS_CONTROL_NOT_FOUND,
            0x80072043 => WIN32::ERROR_DS_CLIENT_LOOP,
            0x80072044 => WIN32::ERROR_DS_REFERRAL_LIMIT_EXCEEDED,
            0x80072045 => WIN32::ERROR_DS_SORT_CONTROL_MISSING,
            0x80072046 => WIN32::ERROR_DS_OFFSET_RANGE_ERROR,
            0x80072047 => WIN32::ERROR_DS_RIDMGR_DISABLED,
            0x8007206D => WIN32::ERROR_DS_ROOT_MUST_BE_NC,
            0x8007206E => WIN32::ERROR_DS_ADD_REPLICA_INHIBITED,
            0x8007206F => WIN32::ERROR_DS_ATT_NOT_DEF_IN_SCHEMA,
            0x80072070 => WIN32::ERROR_DS_MAX_OBJ_SIZE_EXCEEDED,
            0x80072071 => WIN32::ERROR_DS_OBJ_STRING_NAME_EXISTS,
            0x80072072 => WIN32::ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA,
            0x80072073 => WIN32::ERROR_DS_RDN_DOESNT_MATCH_SCHEMA,
            0x80072074 => WIN32::ERROR_DS_NO_REQUESTED_ATTS_FOUND,
            0x80072075 => WIN32::ERROR_DS_USER_BUFFER_TO_SMALL,
            0x80072076 => WIN32::ERROR_DS_ATT_IS_NOT_ON_OBJ,
            0x80072077 => WIN32::ERROR_DS_ILLEGAL_MOD_OPERATION,
            0x80072078 => WIN32::ERROR_DS_OBJ_TOO_LARGE,
            0x80072079 => WIN32::ERROR_DS_BAD_INSTANCE_TYPE,
            0x8007207A => WIN32::ERROR_DS_MASTERDSA_REQUIRED,
            0x8007207B => WIN32::ERROR_DS_OBJECT_CLASS_REQUIRED,
            0x8007207C => WIN32::ERROR_DS_MISSING_REQUIRED_ATT,
            0x8007207D => WIN32::ERROR_DS_ATT_NOT_DEF_FOR_CLASS,
            0x8007207E => WIN32::ERROR_DS_ATT_ALREADY_EXISTS,
            0x80072080 => WIN32::ERROR_DS_CANT_ADD_ATT_VALUES,
            0x80072081 => WIN32::ERROR_DS_SINGLE_VALUE_CONSTRAINT,
            0x80072082 => WIN32::ERROR_DS_RANGE_CONSTRAINT,
            0x80072083 => WIN32::ERROR_DS_ATT_VAL_ALREADY_EXISTS,
            0x80072084 => WIN32::ERROR_DS_CANT_REM_MISSING_ATT,
            0x80072085 => WIN32::ERROR_DS_CANT_REM_MISSING_ATT_VAL,
            0x80072086 => WIN32::ERROR_DS_ROOT_CANT_BE_SUBREF,
            0x80072087 => WIN32::ERROR_DS_NO_CHAINING,
            0x80072088 => WIN32::ERROR_DS_NO_CHAINED_EVAL,
            0x80072089 => WIN32::ERROR_DS_NO_PARENT_OBJECT,
            0x8007208A => WIN32::ERROR_DS_PARENT_IS_AN_ALIAS,
            0x8007208B => WIN32::ERROR_DS_CANT_MIX_MASTER_AND_REPS,
            0x8007208C => WIN32::ERROR_DS_CHILDREN_EXIST,
            0x8007208D => WIN32::ERROR_DS_OBJ_NOT_FOUND,
            0x8007208E => WIN32::ERROR_DS_ALIASED_OBJ_MISSING,
            0x8007208F => WIN32::ERROR_DS_BAD_NAME_SYNTAX,
            0x80072090 => WIN32::ERROR_DS_ALIAS_POINTS_TO_ALIAS,
            0x80072091 => WIN32::ERROR_DS_CANT_DEREF_ALIAS,
            0x80072092 => WIN32::ERROR_DS_OUT_OF_SCOPE,
            0x80072093 => WIN32::ERROR_DS_OBJECT_BEING_REMOVED,
            0x80072094 => WIN32::ERROR_DS_CANT_DELETE_DSA_OBJ,
            0x80072095 => WIN32::ERROR_DS_GENERIC_ERROR,
            0x80072096 => WIN32::ERROR_DS_DSA_MUST_BE_INT_MASTER,
            0x80072097 => WIN32::ERROR_DS_CLASS_NOT_DSA,
            0x80072098 => WIN32::ERROR_DS_INSUFF_ACCESS_RIGHTS,
            0x80072099 => WIN32::ERROR_DS_ILLEGAL_SUPERIOR,
            0x8007209A => WIN32::ERROR_DS_ATTRIBUTE_OWNED_BY_SAM,
            0x8007209B => WIN32::ERROR_DS_NAME_TOO_MANY_PARTS,
            0x8007209C => WIN32::ERROR_DS_NAME_TOO_LONG,
            0x8007209D => WIN32::ERROR_DS_NAME_VALUE_TOO_LONG,
            0x8007209E => WIN32::ERROR_DS_NAME_UNPARSEABLE,
            0x8007209F => WIN32::ERROR_DS_NAME_TYPE_UNKNOWN,
            0x800720A0 => WIN32::ERROR_DS_NOT_AN_OBJECT,
            0x800720A1 => WIN32::ERROR_DS_SEC_DESC_TOO_SHORT,
            0x800720A2 => WIN32::ERROR_DS_SEC_DESC_INVALID,
            0x800720A3 => WIN32::ERROR_DS_NO_DELETED_NAME,
            0x800720A4 => WIN32::ERROR_DS_SUBREF_MUST_HAVE_PARENT,
            0x800720A5 => WIN32::ERROR_DS_NCNAME_MUST_BE_NC,
            0x800720A6 => WIN32::ERROR_DS_CANT_ADD_SYSTEM_ONLY,
            0x800720A7 => WIN32::ERROR_DS_CLASS_MUST_BE_CONCRETE,
            0x800720A8 => WIN32::ERROR_DS_INVALID_DMD,
            0x800720A9 => WIN32::ERROR_DS_OBJ_GUID_EXISTS,
            0x800720AA => WIN32::ERROR_DS_NOT_ON_BACKLINK,
            0x800720AB => WIN32::ERROR_DS_NO_CROSSREF_FOR_NC,
            0x800720AC => WIN32::ERROR_DS_SHUTTING_DOWN,
            0x800720AD => WIN32::ERROR_DS_UNKNOWN_OPERATION,
            0x800720AE => WIN32::ERROR_DS_INVALID_ROLE_OWNER,
            0x800720AF => WIN32::ERROR_DS_COULDNT_CONTACT_FSMO,
            0x800720B0 => WIN32::ERROR_DS_CROSS_NC_DN_RENAME,
            0x800720B1 => WIN32::ERROR_DS_CANT_MOD_SYSTEM_ONLY,
            0x800720B2 => WIN32::ERROR_DS_REPLICATOR_ONLY,
            0x800720B3 => WIN32::ERROR_DS_OBJ_CLASS_NOT_DEFINED,
            0x800720B4 => WIN32::ERROR_DS_OBJ_CLASS_NOT_SUBCLASS,
            0x800720B5 => WIN32::ERROR_DS_NAME_REFERENCE_INVALID,
            0x800720B6 => WIN32::ERROR_DS_CROSS_REF_EXISTS,
            0x800720B7 => WIN32::ERROR_DS_CANT_DEL_MASTER_CROSSREF,
            0x800720B8 => WIN32::ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD,
            0x800720B9 => WIN32::ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX,
            0x800720BA => WIN32::ERROR_DS_DUP_RDN,
            0x800720BB => WIN32::ERROR_DS_DUP_OID,
            0x800720BC => WIN32::ERROR_DS_DUP_MAPI_ID,
            0x800720BD => WIN32::ERROR_DS_DUP_SCHEMA_ID_GUID,
            0x800720BE => WIN32::ERROR_DS_DUP_LDAP_DISPLAY_NAME,
            0x800720BF => WIN32::ERROR_DS_SEMANTIC_ATT_TEST,
            0x800720C0 => WIN32::ERROR_DS_SYNTAX_MISMATCH,
            0x800720C1 => WIN32::ERROR_DS_EXISTS_IN_MUST_HAVE,
            0x800720C2 => WIN32::ERROR_DS_EXISTS_IN_MAY_HAVE,
            0x800720C3 => WIN32::ERROR_DS_NONEXISTENT_MAY_HAVE,
            0x800720C4 => WIN32::ERROR_DS_NONEXISTENT_MUST_HAVE,
            0x800720C5 => WIN32::ERROR_DS_AUX_CLS_TEST_FAIL,
            0x800720C6 => WIN32::ERROR_DS_NONEXISTENT_POSS_SUP,
            0x800720C7 => WIN32::ERROR_DS_SUB_CLS_TEST_FAIL,
            0x800720C8 => WIN32::ERROR_DS_BAD_RDN_ATT_ID_SYNTAX,
            0x800720C9 => WIN32::ERROR_DS_EXISTS_IN_AUX_CLS,
            0x800720CA => WIN32::ERROR_DS_EXISTS_IN_SUB_CLS,
            0x800720CB => WIN32::ERROR_DS_EXISTS_IN_POSS_SUP,
            0x800720CC => WIN32::ERROR_DS_RECALCSCHEMA_FAILED,
            0x800720CD => WIN32::ERROR_DS_TREE_DELETE_NOT_FINISHED,
            0x800720CE => WIN32::ERROR_DS_CANT_DELETE,
            0x800720CF => WIN32::ERROR_DS_ATT_SCHEMA_REQ_ID,
            0x800720D0 => WIN32::ERROR_DS_BAD_ATT_SCHEMA_SYNTAX,
            0x800720D1 => WIN32::ERROR_DS_CANT_CACHE_ATT,
            0x800720D2 => WIN32::ERROR_DS_CANT_CACHE_CLASS,
            0x800720D3 => WIN32::ERROR_DS_CANT_REMOVE_ATT_CACHE,
            0x800720D4 => WIN32::ERROR_DS_CANT_REMOVE_CLASS_CACHE,
            0x800720D5 => WIN32::ERROR_DS_CANT_RETRIEVE_DN,
            0x800720D6 => WIN32::ERROR_DS_MISSING_SUPREF,
            0x800720D7 => WIN32::ERROR_DS_CANT_RETRIEVE_INSTANCE,
            0x800720D8 => WIN32::ERROR_DS_CODE_INCONSISTENCY,
            0x800720D9 => WIN32::ERROR_DS_DATABASE_ERROR,
            0x800720DA => WIN32::ERROR_DS_GOVERNSID_MISSING,
            0x800720DB => WIN32::ERROR_DS_MISSING_EXPECTED_ATT,
            0x800720DC => WIN32::ERROR_DS_NCNAME_MISSING_CR_REF,
            0x800720DD => WIN32::ERROR_DS_SECURITY_CHECKING_ERROR,
            0x800720DE => WIN32::ERROR_DS_SCHEMA_NOT_LOADED,
            0x800720DF => WIN32::ERROR_DS_SCHEMA_ALLOC_FAILED,
            0x800720E0 => WIN32::ERROR_DS_ATT_SCHEMA_REQ_SYNTAX,
            0x800720E1 => WIN32::ERROR_DS_GCVERIFY_ERROR,
            0x800720E2 => WIN32::ERROR_DS_DRA_SCHEMA_MISMATCH,
            0x800720E3 => WIN32::ERROR_DS_CANT_FIND_DSA_OBJ,
            0x800720E4 => WIN32::ERROR_DS_CANT_FIND_EXPECTED_NC,
            0x800720E5 => WIN32::ERROR_DS_CANT_FIND_NC_IN_CACHE,
            0x800720E6 => WIN32::ERROR_DS_CANT_RETRIEVE_CHILD,
            0x800720E7 => WIN32::ERROR_DS_SECURITY_ILLEGAL_MODIFY,
            0x800720E8 => WIN32::ERROR_DS_CANT_REPLACE_HIDDEN_REC,
            0x800720E9 => WIN32::ERROR_DS_BAD_HIERARCHY_FILE,
            0x800720EA => WIN32::ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED,
            0x800720EB => WIN32::ERROR_DS_CONFIG_PARAM_MISSING,
            0x800720EC => WIN32::ERROR_DS_COUNTING_AB_INDICES_FAILED,
            0x800720ED => WIN32::ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED,
            0x800720EE => WIN32::ERROR_DS_INTERNAL_FAILURE,
            0x800720EF => WIN32::ERROR_DS_UNKNOWN_ERROR,
            0x800720F0 => WIN32::ERROR_DS_ROOT_REQUIRES_CLASS_TOP,
            0x800720F1 => WIN32::ERROR_DS_REFUSING_FSMO_ROLES,
            0x800720F2 => WIN32::ERROR_DS_MISSING_FSMO_SETTINGS,
            0x800720F3 => WIN32::ERROR_DS_UNABLE_TO_SURRENDER_ROLES,
            0x800720F4 => WIN32::ERROR_DS_DRA_GENERIC,
            0x800720F5 => WIN32::ERROR_DS_DRA_INVALID_PARAMETER,
            0x800720F6 => WIN32::ERROR_DS_DRA_BUSY,
            0x800720F7 => WIN32::ERROR_DS_DRA_BAD_DN,
            0x800720F8 => WIN32::ERROR_DS_DRA_BAD_NC,
            0x800720F9 => WIN32::ERROR_DS_DRA_DN_EXISTS,
            0x800720FA => WIN32::ERROR_DS_DRA_INTERNAL_ERROR,
            0x800720FB => WIN32::ERROR_DS_DRA_INCONSISTENT_DIT,
            0x800720FC => WIN32::ERROR_DS_DRA_CONNECTION_FAILED,
            0x800720FD => WIN32::ERROR_DS_DRA_BAD_INSTANCE_TYPE,
            0x800720FE => WIN32::ERROR_DS_DRA_OUT_OF_MEM,
            0x800720FF => WIN32::ERROR_DS_DRA_MAIL_PROBLEM,
            0x80072100 => WIN32::ERROR_DS_DRA_REF_ALREADY_EXISTS,
            0x80072101 => WIN32::ERROR_DS_DRA_REF_NOT_FOUND,
            0x80072102 => WIN32::ERROR_DS_DRA_OBJ_IS_REP_SOURCE,
            0x80072103 => WIN32::ERROR_DS_DRA_DB_ERROR,
            0x80072104 => WIN32::ERROR_DS_DRA_NO_REPLICA,
            0x80072105 => WIN32::ERROR_DS_DRA_ACCESS_DENIED,
            0x80072106 => WIN32::ERROR_DS_DRA_NOT_SUPPORTED,
            0x80072107 => WIN32::ERROR_DS_DRA_RPC_CANCELLED,
            0x80072108 => WIN32::ERROR_DS_DRA_SOURCE_DISABLED,
            0x80072109 => WIN32::ERROR_DS_DRA_SINK_DISABLED,
            0x8007210A => WIN32::ERROR_DS_DRA_NAME_COLLISION,
            0x8007210B => WIN32::ERROR_DS_DRA_SOURCE_REINSTALLED,
            0x8007210C => WIN32::ERROR_DS_DRA_MISSING_PARENT,
            0x8007210D => WIN32::ERROR_DS_DRA_PREEMPTED,
            0x8007210E => WIN32::ERROR_DS_DRA_ABANDON_SYNC,
            0x8007210F => WIN32::ERROR_DS_DRA_SHUTDOWN,
            0x80072110 => WIN32::ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET,
            0x80072111 => WIN32::ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA,
            0x80072112 => WIN32::ERROR_DS_DRA_EXTN_CONNECTION_FAILED,
            0x80072113 => WIN32::ERROR_DS_INSTALL_SCHEMA_MISMATCH,
            0x80072114 => WIN32::ERROR_DS_DUP_LINK_ID,
            0x80072115 => WIN32::ERROR_DS_NAME_ERROR_RESOLVING,
            0x80072116 => WIN32::ERROR_DS_NAME_ERROR_NOT_FOUND,
            0x80072117 => WIN32::ERROR_DS_NAME_ERROR_NOT_UNIQUE,
            0x80072118 => WIN32::ERROR_DS_NAME_ERROR_NO_MAPPING,
            0x80072119 => WIN32::ERROR_DS_NAME_ERROR_DOMAIN_ONLY,
            0x8007211A => WIN32::ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING,
            0x8007211B => WIN32::ERROR_DS_CONSTRUCTED_ATT_MOD,
            0x8007211C => WIN32::ERROR_DS_WRONG_OM_OBJ_CLASS,
            0x8007211D => WIN32::ERROR_DS_DRA_REPL_PENDING,
            0x8007211E => WIN32::ERROR_DS_DS_REQUIRED,
            0x8007211F => WIN32::ERROR_DS_INVALID_LDAP_DISPLAY_NAME,
            0x80072120 => WIN32::ERROR_DS_NON_BASE_SEARCH,
            0x80072121 => WIN32::ERROR_DS_CANT_RETRIEVE_ATTS,
            0x80072122 => WIN32::ERROR_DS_BACKLINK_WITHOUT_LINK,
            0x80072123 => WIN32::ERROR_DS_EPOCH_MISMATCH,
            0x80072124 => WIN32::ERROR_DS_SRC_NAME_MISMATCH,
            0x80072125 => WIN32::ERROR_DS_SRC_AND_DST_NC_IDENTICAL,
            0x80072126 => WIN32::ERROR_DS_DST_NC_MISMATCH,
            0x80072127 => WIN32::ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC,
            0x80072128 => WIN32::ERROR_DS_SRC_GUID_MISMATCH,
            0x80072129 => WIN32::ERROR_DS_CANT_MOVE_DELETED_OBJECT,
            0x8007212A => WIN32::ERROR_DS_PDC_OPERATION_IN_PROGRESS,
            0x8007212B => WIN32::ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD,
            0x8007212C => WIN32::ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION,
            0x8007212D => WIN32::ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS,
            0x8007212E => WIN32::ERROR_DS_NC_MUST_HAVE_NC_PARENT,
            0x8007212F => WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE,
            0x80072130 => WIN32::ERROR_DS_DST_DOMAIN_NOT_NATIVE,
            0x80072131 => WIN32::ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER,
            0x80072132 => WIN32::ERROR_DS_CANT_MOVE_ACCOUNT_GROUP,
            0x80072133 => WIN32::ERROR_DS_CANT_MOVE_RESOURCE_GROUP,
            0x80072134 => WIN32::ERROR_DS_INVALID_SEARCH_FLAG,
            0x80072135 => WIN32::ERROR_DS_NO_TREE_DELETE_ABOVE_NC,
            0x80072136 => WIN32::ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE,
            0x80072137 => WIN32::ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE,
            0x80072138 => WIN32::ERROR_DS_SAM_INIT_FAILURE,
            0x80072139 => WIN32::ERROR_DS_SENSITIVE_GROUP_VIOLATION,
            0x8007213A => WIN32::ERROR_DS_CANT_MOD_PRIMARYGROUPID,
            0x8007213B => WIN32::ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD,
            0x8007213C => WIN32::ERROR_DS_NONSAFE_SCHEMA_CHANGE,
            0x8007213D => WIN32::ERROR_DS_SCHEMA_UPDATE_DISALLOWED,
            0x8007213E => WIN32::ERROR_DS_CANT_CREATE_UNDER_SCHEMA,
            0x8007213F => WIN32::ERROR_DS_INSTALL_NO_SRC_SCH_VERSION,
            0x80072140 => WIN32::ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE,
            0x80072141 => WIN32::ERROR_DS_INVALID_GROUP_TYPE,
            0x80072142 => WIN32::ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN,
            0x80072143 => WIN32::ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN,
            0x80072144 => WIN32::ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER,
            0x80072145 => WIN32::ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER,
            0x80072146 => WIN32::ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER,
            0x80072147 => WIN32::ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER,
            0x80072148 => WIN32::ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER,
            0x80072149 => WIN32::ERROR_DS_HAVE_PRIMARY_MEMBERS,
            0x8007214A => WIN32::ERROR_DS_STRING_SD_CONVERSION_FAILED,
            0x8007214B => WIN32::ERROR_DS_NAMING_MASTER_GC,
            0x8007214C => WIN32::ERROR_DS_DNS_LOOKUP_FAILURE,
            0x8007214D => WIN32::ERROR_DS_COULDNT_UPDATE_SPNS,
            0x8007214E => WIN32::ERROR_DS_CANT_RETRIEVE_SD,
            0x8007214F => WIN32::ERROR_DS_KEY_NOT_UNIQUE,
            0x80072150 => WIN32::ERROR_DS_WRONG_LINKED_ATT_SYNTAX,
            0x80072151 => WIN32::ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD,
            0x80072152 => WIN32::ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY,
            0x80072153 => WIN32::ERROR_DS_CANT_START,
            0x80072154 => WIN32::ERROR_DS_INIT_FAILURE,
            0x80072155 => WIN32::ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION,
            0x80072156 => WIN32::ERROR_DS_SOURCE_DOMAIN_IN_FOREST,
            0x80072157 => WIN32::ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST,
            0x80072158 => WIN32::ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED,
            0x80072159 => WIN32::ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN,
            0x8007215A => WIN32::ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER,
            0x8007215B => WIN32::ERROR_DS_SRC_SID_EXISTS_IN_FOREST,
            0x8007215C => WIN32::ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH,
            0x8007215D => WIN32::ERROR_SAM_INIT_FAILURE,
            0x8007215E => WIN32::ERROR_DS_DRA_SCHEMA_INFO_SHIP,
            0x8007215F => WIN32::ERROR_DS_DRA_SCHEMA_CONFLICT,
            0x80072160 => WIN32::ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT,
            0x80072161 => WIN32::ERROR_DS_DRA_OBJ_NC_MISMATCH,
            0x80072162 => WIN32::ERROR_DS_NC_STILL_HAS_DSAS,
            0x80072163 => WIN32::ERROR_DS_GC_REQUIRED,
            0x80072164 => WIN32::ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY,
            0x80072165 => WIN32::ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS,
            0x80072166 => WIN32::ERROR_DS_CANT_ADD_TO_GC,
            0x80072167 => WIN32::ERROR_DS_NO_CHECKPOINT_WITH_PDC,
            0x80072168 => WIN32::ERROR_DS_SOURCE_AUDITING_NOT_ENABLED,
            0x80072169 => WIN32::ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC,
            0x8007216A => WIN32::ERROR_DS_INVALID_NAME_FOR_SPN,
            0x8007216B => WIN32::ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS,
            0x8007216C => WIN32::ERROR_DS_UNICODEPWD_NOT_IN_QUOTES,
            0x8007216D => WIN32::ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED,
            0x8007216E => WIN32::ERROR_DS_MUST_BE_RUN_ON_DST_DC,
            0x8007216F => WIN32::ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER,
            0x80072170 => WIN32::ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ,
            0x80072171 => WIN32::ERROR_DS_INIT_FAILURE_CONSOLE,
            0x80072172 => WIN32::ERROR_DS_SAM_INIT_FAILURE_CONSOLE,
            0x80072173 => WIN32::ERROR_DS_FOREST_VERSION_TOO_HIGH,
            0x80072174 => WIN32::ERROR_DS_DOMAIN_VERSION_TOO_HIGH,
            0x80072175 => WIN32::ERROR_DS_FOREST_VERSION_TOO_LOW,
            0x80072176 => WIN32::ERROR_DS_DOMAIN_VERSION_TOO_LOW,
            0x80072177 => WIN32::ERROR_DS_INCOMPATIBLE_VERSION,
            0x80072178 => WIN32::ERROR_DS_LOW_DSA_VERSION,
            0x80072179 => WIN32::ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN,
            0x8007217A => WIN32::ERROR_DS_NOT_SUPPORTED_SORT_ORDER,
            0x8007217B => WIN32::ERROR_DS_NAME_NOT_UNIQUE,
            0x8007217C => WIN32::ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4,
            0x8007217D => WIN32::ERROR_DS_OUT_OF_VERSION_STORE,
            0x8007217E => WIN32::ERROR_DS_INCOMPATIBLE_CONTROLS_USED,
            0x8007217F => WIN32::ERROR_DS_NO_REF_DOMAIN,
            0x80072180 => WIN32::ERROR_DS_RESERVED_LINK_ID,
            0x80072181 => WIN32::ERROR_DS_LINK_ID_NOT_AVAILABLE,
            0x80072182 => WIN32::ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER,
            0x80072183 => WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE,
            0x80072184 => WIN32::ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC,
            0x80072185 => WIN32::ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG,
            0x80072186 => WIN32::ERROR_DS_MODIFYDN_WRONG_GRANDPARENT,
            0x80072187 => WIN32::ERROR_DS_NAME_ERROR_TRUST_REFERRAL,
            0x80072188 => WIN32::ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER,
            0x80072189 => WIN32::ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD,
            0x8007218A => WIN32::ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2,
            0x8007218B => WIN32::ERROR_DS_THREAD_LIMIT_EXCEEDED,
            0x8007218C => WIN32::ERROR_DS_NOT_CLOSEST,
            0x8007218D => WIN32::ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF,
            0x8007218E => WIN32::ERROR_DS_SINGLE_USER_MODE_FAILED,
            0x8007218F => WIN32::ERROR_DS_NTDSCRIPT_SYNTAX_ERROR,
            0x80072190 => WIN32::ERROR_DS_NTDSCRIPT_PROCESS_ERROR,
            0x80072191 => WIN32::ERROR_DS_DIFFERENT_REPL_EPOCHS,
            0x80072192 => WIN32::ERROR_DS_DRS_EXTENSIONS_CHANGED,
            0x80072193 => WIN32::ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR,
            0x80072194 => WIN32::ERROR_DS_NO_MSDS_INTID,
            0x80072195 => WIN32::ERROR_DS_DUP_MSDS_INTID,
            0x80072196 => WIN32::ERROR_DS_EXISTS_IN_RDNATTID,
            0x80072197 => WIN32::ERROR_DS_AUTHORIZATION_FAILED,
            0x80072198 => WIN32::ERROR_DS_INVALID_SCRIPT,
            0x80072199 => WIN32::ERROR_DS_REMOTE_CROSSREF_OP_FAILED,
            0x8007219A => WIN32::ERROR_DS_CROSS_REF_BUSY,
            0x8007219B => WIN32::ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN,
            0x8007219C => WIN32::ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC,
            0x8007219D => WIN32::ERROR_DS_DUPLICATE_ID_FOUND,
            0x8007219E => WIN32::ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT,
            0x8007219F => WIN32::ERROR_DS_GROUP_CONVERSION_ERROR,
            0x800721A0 => WIN32::ERROR_DS_CANT_MOVE_APP_BASIC_GROUP,
            0x800721A1 => WIN32::ERROR_DS_CANT_MOVE_APP_QUERY_GROUP,
            0x800721A2 => WIN32::ERROR_DS_ROLE_NOT_VERIFIED,
            0x800721A3 => WIN32::ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL,
            0x800721A4 => WIN32::ERROR_DS_DOMAIN_RENAME_IN_PROGRESS,
            0x800721A5 => WIN32::ERROR_DS_EXISTING_AD_CHILD_NC,
            0x800721A6 => WIN32::ERROR_DS_REPL_LIFETIME_EXCEEDED,
            0x800721A7 => WIN32::ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER,
            0x800721A8 => WIN32::ERROR_DS_LDAP_SEND_QUEUE_FULL,
            0x800721A9 => WIN32::ERROR_DS_DRA_OUT_SCHEDULE_WINDOW,
            0x800721AA => WIN32::ERROR_DS_POLICY_NOT_KNOWN,
            0x800721AB => WIN32::ERROR_NO_SITE_SETTINGS_OBJECT,
            0x800721AC => WIN32::ERROR_NO_SECRETS,
            0x800721AD => WIN32::ERROR_NO_WRITABLE_DC_FOUND,
            0x800721AE => WIN32::ERROR_DS_NO_SERVER_OBJECT,
            0x800721AF => WIN32::ERROR_DS_NO_NTDSA_OBJECT,
            0x800721B0 => WIN32::ERROR_DS_NON_ASQ_SEARCH,
            0x800721B1 => WIN32::ERROR_DS_AUDIT_FAILURE,
            0x800721B2 => WIN32::ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE,
            0x800721B3 => WIN32::ERROR_DS_INVALID_SEARCH_FLAG_TUPLE,
            0x800721B4 => WIN32::ERROR_DS_HIERARCHY_TABLE_TOO_DEEP,
            0x800721B5 => WIN32::ERROR_DS_DRA_CORRUPT_UTD_VECTOR,
            0x800721B6 => WIN32::ERROR_DS_DRA_SECRETS_DENIED,
            0x800721B7 => WIN32::ERROR_DS_RESERVED_MAPI_ID,
            0x800721B8 => WIN32::ERROR_DS_MAPI_ID_NOT_AVAILABLE,
            0x800721B9 => WIN32::ERROR_DS_DRA_MISSING_KRBTGT_SECRET,
            0x800721BA => WIN32::ERROR_DS_DOMAIN_NAME_EXISTS_IN_FOREST,
            0x800721BB => WIN32::ERROR_DS_FLAT_NAME_EXISTS_IN_FOREST,
            0x800721BC => WIN32::ERROR_INVALID_USER_PRINCIPAL_NAME,
            0x800721BD => WIN32::ERROR_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS,
            0x800721BE => WIN32::ERROR_DS_OID_NOT_FOUND,
            0x800721BF => WIN32::ERROR_DS_DRA_RECYCLED_TARGET,
            0x800721C0 => WIN32::ERROR_DS_DISALLOWED_NC_REDIRECT,
            0x800721C1 => WIN32::ERROR_DS_HIGH_ADLDS_FFL,
            0x800721C2 => WIN32::ERROR_DS_HIGH_DSA_VERSION,
            0x800721C3 => WIN32::ERROR_DS_LOW_ADLDS_FFL,
            0x800721C4 => WIN32::ERROR_DOMAIN_SID_SAME_AS_LOCAL_WORKSTATION,
            0x800721C5 => WIN32::ERROR_DS_UNDELETE_SAM_VALIDATION_FAILED,
            0x800721C6 => WIN32::ERROR_INCORRECT_ACCOUNT_TYPE,
            0x800721C7 => WIN32::ERROR_DS_SPN_VALUE_NOT_UNIQUE_IN_FOREST,
            0x800721C8 => WIN32::ERROR_DS_UPN_VALUE_NOT_UNIQUE_IN_FOREST,
            0x800721C9 => WIN32::ERROR_DS_MISSING_FOREST_TRUST,
            0x800721CA => WIN32::ERROR_DS_VALUE_KEY_NOT_UNIQUE,
            0x800721CB => WIN32::ERROR_WEAK_WHFBKEY_BLOCKED,
            0x800721CC => WIN32::ERROR_DS_PER_ATTRIBUTE_AUTHZ_FAILED_DURING_ADD,
            0x800721CD => WIN32::ERROR_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED,
            0x800721CE => WIN32::ERROR_POLICY_CONTROLLED_ACCOUNT,
            0x800721CF => WIN32::ERROR_LAPS_LEGACY_SCHEMA_MISSING,
            0x800721D0 => WIN32::ERROR_LAPS_SCHEMA_MISSING,
            0x800721D1 => WIN32::ERROR_LAPS_ENCRYPTION_REQUIRES_2016_DFL,
            0x80072329 => WIN32::DNS_ERROR_RCODE_FORMAT_ERROR,
            0x8007232A => WIN32::DNS_ERROR_RCODE_SERVER_FAILURE,
            0x8007232B => WIN32::DNS_ERROR_RCODE_NAME_ERROR,
            0x8007232C => WIN32::DNS_ERROR_RCODE_NOT_IMPLEMENTED,
            0x8007232D => WIN32::DNS_ERROR_RCODE_REFUSED,
            0x8007232E => WIN32::DNS_ERROR_RCODE_YXDOMAIN,
            0x8007232F => WIN32::DNS_ERROR_RCODE_YXRRSET,
            0x80072330 => WIN32::DNS_ERROR_RCODE_NXRRSET,
            0x80072331 => WIN32::DNS_ERROR_RCODE_NOTAUTH,
            0x80072332 => WIN32::DNS_ERROR_RCODE_NOTZONE,
            0x80072338 => WIN32::DNS_ERROR_RCODE_BADSIG,
            0x80072339 => WIN32::DNS_ERROR_RCODE_BADKEY,
            0x8007233A => WIN32::DNS_ERROR_RCODE_BADTIME,
            0x8007238D => WIN32::DNS_ERROR_KEYMASTER_REQUIRED,
            0x8007238E => WIN32::DNS_ERROR_NOT_ALLOWED_ON_SIGNED_ZONE,
            0x8007238F => WIN32::DNS_ERROR_NSEC3_INCOMPATIBLE_WITH_RSA_SHA1,
            0x80072390 => WIN32::DNS_ERROR_NOT_ENOUGH_SIGNING_KEY_DESCRIPTORS,
            0x80072391 => WIN32::DNS_ERROR_UNSUPPORTED_ALGORITHM,
            0x80072392 => WIN32::DNS_ERROR_INVALID_KEY_SIZE,
            0x80072393 => WIN32::DNS_ERROR_SIGNING_KEY_NOT_ACCESSIBLE,
            0x80072394 => WIN32::DNS_ERROR_KSP_DOES_NOT_SUPPORT_PROTECTION,
            0x80072395 => WIN32::DNS_ERROR_UNEXPECTED_DATA_PROTECTION_ERROR,
            0x80072396 => WIN32::DNS_ERROR_UNEXPECTED_CNG_ERROR,
            0x80072397 => WIN32::DNS_ERROR_UNKNOWN_SIGNING_PARAMETER_VERSION,
            0x80072398 => WIN32::DNS_ERROR_KSP_NOT_ACCESSIBLE,
            0x80072399 => WIN32::DNS_ERROR_TOO_MANY_SKDS,
            0x8007239A => WIN32::DNS_ERROR_INVALID_ROLLOVER_PERIOD,
            0x8007239B => WIN32::DNS_ERROR_INVALID_INITIAL_ROLLOVER_OFFSET,
            0x8007239C => WIN32::DNS_ERROR_ROLLOVER_IN_PROGRESS,
            0x8007239D => WIN32::DNS_ERROR_STANDBY_KEY_NOT_PRESENT,
            0x8007239E => WIN32::DNS_ERROR_NOT_ALLOWED_ON_ZSK,
            0x8007239F => WIN32::DNS_ERROR_NOT_ALLOWED_ON_ACTIVE_SKD,
            0x800723A0 => WIN32::DNS_ERROR_ROLLOVER_ALREADY_QUEUED,
            0x800723A1 => WIN32::DNS_ERROR_NOT_ALLOWED_ON_UNSIGNED_ZONE,
            0x800723A2 => WIN32::DNS_ERROR_BAD_KEYMASTER,
            0x800723A3 => WIN32::DNS_ERROR_INVALID_SIGNATURE_VALIDITY_PERIOD,
            0x800723A4 => WIN32::DNS_ERROR_INVALID_NSEC3_ITERATION_COUNT,
            0x800723A5 => WIN32::DNS_ERROR_DNSSEC_IS_DISABLED,
            0x800723A6 => WIN32::DNS_ERROR_INVALID_XML,
            0x800723A7 => WIN32::DNS_ERROR_NO_VALID_TRUST_ANCHORS,
            0x800723A8 => WIN32::DNS_ERROR_ROLLOVER_NOT_POKEABLE,
            0x800723A9 => WIN32::DNS_ERROR_NSEC3_NAME_COLLISION,
            0x800723AA => WIN32::DNS_ERROR_NSEC_INCOMPATIBLE_WITH_NSEC3_RSA_SHA1,
            0x8007251D => WIN32::DNS_INFO_NO_RECORDS,
            0x8007251E => WIN32::DNS_ERROR_BAD_PACKET,
            0x8007251F => WIN32::DNS_ERROR_NO_PACKET,
            0x80072520 => WIN32::DNS_ERROR_RCODE,
            0x80072521 => WIN32::DNS_ERROR_UNSECURE_PACKET,
            0x80072522 => WIN32::DNS_REQUEST_PENDING,
            0x8007254F => WIN32::DNS_ERROR_INVALID_TYPE,
            0x80072550 => WIN32::DNS_ERROR_INVALID_IP_ADDRESS,
            0x80072551 => WIN32::DNS_ERROR_INVALID_PROPERTY,
            0x80072552 => WIN32::DNS_ERROR_TRY_AGAIN_LATER,
            0x80072553 => WIN32::DNS_ERROR_NOT_UNIQUE,
            0x80072554 => WIN32::DNS_ERROR_NON_RFC_NAME,
            0x80072555 => WIN32::DNS_STATUS_FQDN,
            0x80072556 => WIN32::DNS_STATUS_DOTTED_NAME,
            0x80072557 => WIN32::DNS_STATUS_SINGLE_PART_NAME,
            0x80072558 => WIN32::DNS_ERROR_INVALID_NAME_CHAR,
            0x80072559 => WIN32::DNS_ERROR_NUMERIC_NAME,
            0x8007255A => WIN32::DNS_ERROR_NOT_ALLOWED_ON_ROOT_SERVER,
            0x8007255B => WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DELEGATION,
            0x8007255C => WIN32::DNS_ERROR_CANNOT_FIND_ROOT_HINTS,
            0x8007255D => WIN32::DNS_ERROR_INCONSISTENT_ROOT_HINTS,
            0x8007255E => WIN32::DNS_ERROR_DWORD_VALUE_TOO_SMALL,
            0x8007255F => WIN32::DNS_ERROR_DWORD_VALUE_TOO_LARGE,
            0x80072560 => WIN32::DNS_ERROR_BACKGROUND_LOADING,
            0x80072561 => WIN32::DNS_ERROR_NOT_ALLOWED_ON_RODC,
            0x80072562 => WIN32::DNS_ERROR_NOT_ALLOWED_UNDER_DNAME,
            0x80072563 => WIN32::DNS_ERROR_DELEGATION_REQUIRED,
            0x80072564 => WIN32::DNS_ERROR_INVALID_POLICY_TABLE,
            0x80072565 => WIN32::DNS_ERROR_ADDRESS_REQUIRED,
            0x80072581 => WIN32::DNS_ERROR_ZONE_DOES_NOT_EXIST,
            0x80072582 => WIN32::DNS_ERROR_NO_ZONE_INFO,
            0x80072583 => WIN32::DNS_ERROR_INVALID_ZONE_OPERATION,
            0x80072584 => WIN32::DNS_ERROR_ZONE_CONFIGURATION_ERROR,
            0x80072585 => WIN32::DNS_ERROR_ZONE_HAS_NO_SOA_RECORD,
            0x80072586 => WIN32::DNS_ERROR_ZONE_HAS_NO_NS_RECORDS,
            0x80072587 => WIN32::DNS_ERROR_ZONE_LOCKED,
            0x80072588 => WIN32::DNS_ERROR_ZONE_CREATION_FAILED,
            0x80072589 => WIN32::DNS_ERROR_ZONE_ALREADY_EXISTS,
            0x8007258A => WIN32::DNS_ERROR_AUTOZONE_ALREADY_EXISTS,
            0x8007258B => WIN32::DNS_ERROR_INVALID_ZONE_TYPE,
            0x8007258C => WIN32::DNS_ERROR_SECONDARY_REQUIRES_MASTER_IP,
            0x8007258D => WIN32::DNS_ERROR_ZONE_NOT_SECONDARY,
            0x8007258E => WIN32::DNS_ERROR_NEED_SECONDARY_ADDRESSES,
            0x8007258F => WIN32::DNS_ERROR_WINS_INIT_FAILED,
            0x80072590 => WIN32::DNS_ERROR_NEED_WINS_SERVERS,
            0x80072591 => WIN32::DNS_ERROR_NBSTAT_INIT_FAILED,
            0x80072592 => WIN32::DNS_ERROR_SOA_DELETE_INVALID,
            0x80072593 => WIN32::DNS_ERROR_FORWARDER_ALREADY_EXISTS,
            0x80072594 => WIN32::DNS_ERROR_ZONE_REQUIRES_MASTER_IP,
            0x80072595 => WIN32::DNS_ERROR_ZONE_IS_SHUTDOWN,
            0x80072596 => WIN32::DNS_ERROR_ZONE_LOCKED_FOR_SIGNING,
            0x800725B3 => WIN32::DNS_ERROR_PRIMARY_REQUIRES_DATAFILE,
            0x800725B4 => WIN32::DNS_ERROR_INVALID_DATAFILE_NAME,
            0x800725B5 => WIN32::DNS_ERROR_DATAFILE_OPEN_FAILURE,
            0x800725B6 => WIN32::DNS_ERROR_FILE_WRITEBACK_FAILED,
            0x800725B7 => WIN32::DNS_ERROR_DATAFILE_PARSING,
            0x800725E5 => WIN32::DNS_ERROR_RECORD_DOES_NOT_EXIST,
            0x800725E6 => WIN32::DNS_ERROR_RECORD_FORMAT,
            0x800725E7 => WIN32::DNS_ERROR_NODE_CREATION_FAILED,
            0x800725E8 => WIN32::DNS_ERROR_UNKNOWN_RECORD_TYPE,
            0x800725E9 => WIN32::DNS_ERROR_RECORD_TIMED_OUT,
            0x800725EA => WIN32::DNS_ERROR_NAME_NOT_IN_ZONE,
            0x800725EB => WIN32::DNS_ERROR_CNAME_LOOP,
            0x800725EC => WIN32::DNS_ERROR_NODE_IS_CNAME,
            0x800725ED => WIN32::DNS_ERROR_CNAME_COLLISION,
            0x800725EE => WIN32::DNS_ERROR_RECORD_ONLY_AT_ZONE_ROOT,
            0x800725EF => WIN32::DNS_ERROR_RECORD_ALREADY_EXISTS,
            0x800725F0 => WIN32::DNS_ERROR_SECONDARY_DATA,
            0x800725F1 => WIN32::DNS_ERROR_NO_CREATE_CACHE_DATA,
            0x800725F2 => WIN32::DNS_ERROR_NAME_DOES_NOT_EXIST,
            0x800725F3 => WIN32::DNS_WARNING_PTR_CREATE_FAILED,
            0x800725F4 => WIN32::DNS_WARNING_DOMAIN_UNDELETED,
            0x800725F5 => WIN32::DNS_ERROR_DS_UNAVAILABLE,
            0x800725F6 => WIN32::DNS_ERROR_DS_ZONE_ALREADY_EXISTS,
            0x800725F7 => WIN32::DNS_ERROR_NO_BOOTFILE_IF_DS_ZONE,
            0x800725F8 => WIN32::DNS_ERROR_NODE_IS_DNAME,
            0x800725F9 => WIN32::DNS_ERROR_DNAME_COLLISION,
            0x800725FA => WIN32::DNS_ERROR_ALIAS_LOOP,
            0x80072617 => WIN32::DNS_INFO_AXFR_COMPLETE,
            0x80072618 => WIN32::DNS_ERROR_AXFR,
            0x80072619 => WIN32::DNS_INFO_ADDED_LOCAL_WINS,
            0x80072649 => WIN32::DNS_STATUS_CONTINUE_NEEDED,
            0x8007267B => WIN32::DNS_ERROR_NO_TCPIP,
            0x8007267C => WIN32::DNS_ERROR_NO_DNS_SERVERS,
            0x800726AD => WIN32::DNS_ERROR_DP_DOES_NOT_EXIST,
            0x800726AE => WIN32::DNS_ERROR_DP_ALREADY_EXISTS,
            0x800726AF => WIN32::DNS_ERROR_DP_NOT_ENLISTED,
            0x800726B0 => WIN32::DNS_ERROR_DP_ALREADY_ENLISTED,
            0x800726B1 => WIN32::DNS_ERROR_DP_NOT_AVAILABLE,
            0x800726B2 => WIN32::DNS_ERROR_DP_FSMO_ERROR,
            0x800726B7 => WIN32::DNS_ERROR_RRL_NOT_ENABLED,
            0x800726B8 => WIN32::DNS_ERROR_RRL_INVALID_WINDOW_SIZE,
            0x800726B9 => WIN32::DNS_ERROR_RRL_INVALID_IPV4_PREFIX,
            0x800726BA => WIN32::DNS_ERROR_RRL_INVALID_IPV6_PREFIX,
            0x800726BB => WIN32::DNS_ERROR_RRL_INVALID_TC_RATE,
            0x800726BC => WIN32::DNS_ERROR_RRL_INVALID_LEAK_RATE,
            0x800726BD => WIN32::DNS_ERROR_RRL_LEAK_RATE_LESSTHAN_TC_RATE,
            0x800726C1 => WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_ALREADY_EXISTS,
            0x800726C2 => WIN32::DNS_ERROR_VIRTUALIZATION_INSTANCE_DOES_NOT_EXIST,
            0x800726C3 => WIN32::DNS_ERROR_VIRTUALIZATION_TREE_LOCKED,
            0x800726C4 => WIN32::DNS_ERROR_INVAILD_VIRTUALIZATION_INSTANCE_NAME,
            0x800726C5 => WIN32::DNS_ERROR_DEFAULT_VIRTUALIZATION_INSTANCE,
            0x800726DF => WIN32::DNS_ERROR_ZONESCOPE_ALREADY_EXISTS,
            0x800726E0 => WIN32::DNS_ERROR_ZONESCOPE_DOES_NOT_EXIST,
            0x800726E1 => WIN32::DNS_ERROR_DEFAULT_ZONESCOPE,
            0x800726E2 => WIN32::DNS_ERROR_INVALID_ZONESCOPE_NAME,
            0x800726E3 => WIN32::DNS_ERROR_NOT_ALLOWED_WITH_ZONESCOPES,
            0x800726E4 => WIN32::DNS_ERROR_LOAD_ZONESCOPE_FAILED,
            0x800726E5 => WIN32::DNS_ERROR_ZONESCOPE_FILE_WRITEBACK_FAILED,
            0x800726E6 => WIN32::DNS_ERROR_INVALID_SCOPE_NAME,
            0x800726E7 => WIN32::DNS_ERROR_SCOPE_DOES_NOT_EXIST,
            0x800726E8 => WIN32::DNS_ERROR_DEFAULT_SCOPE,
            0x800726E9 => WIN32::DNS_ERROR_INVALID_SCOPE_OPERATION,
            0x800726EA => WIN32::DNS_ERROR_SCOPE_LOCKED,
            0x800726EB => WIN32::DNS_ERROR_SCOPE_ALREADY_EXISTS,
            0x800726F3 => WIN32::DNS_ERROR_POLICY_ALREADY_EXISTS,
            0x800726F4 => WIN32::DNS_ERROR_POLICY_DOES_NOT_EXIST,
            0x800726F5 => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA,
            0x800726F6 => WIN32::DNS_ERROR_POLICY_INVALID_SETTINGS,
            0x800726F7 => WIN32::DNS_ERROR_CLIENT_SUBNET_IS_ACCESSED,
            0x800726F8 => WIN32::DNS_ERROR_CLIENT_SUBNET_DOES_NOT_EXIST,
            0x800726F9 => WIN32::DNS_ERROR_CLIENT_SUBNET_ALREADY_EXISTS,
            0x800726FA => WIN32::DNS_ERROR_SUBNET_DOES_NOT_EXIST,
            0x800726FB => WIN32::DNS_ERROR_SUBNET_ALREADY_EXISTS,
            0x800726FC => WIN32::DNS_ERROR_POLICY_LOCKED,
            0x800726FD => WIN32::DNS_ERROR_POLICY_INVALID_WEIGHT,
            0x800726FE => WIN32::DNS_ERROR_POLICY_INVALID_NAME,
            0x800726FF => WIN32::DNS_ERROR_POLICY_MISSING_CRITERIA,
            0x80072700 => WIN32::DNS_ERROR_INVALID_CLIENT_SUBNET_NAME,
            0x80072701 => WIN32::DNS_ERROR_POLICY_PROCESSING_ORDER_INVALID,
            0x80072702 => WIN32::DNS_ERROR_POLICY_SCOPE_MISSING,
            0x80072703 => WIN32::DNS_ERROR_POLICY_SCOPE_NOT_ALLOWED,
            0x80072704 => WIN32::DNS_ERROR_SERVERSCOPE_IS_REFERENCED,
            0x80072705 => WIN32::DNS_ERROR_ZONESCOPE_IS_REFERENCED,
            0x80072706 => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_CLIENT_SUBNET,
            0x80072707 => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TRANSPORT_PROTOCOL,
            0x80072708 => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_NETWORK_PROTOCOL,
            0x80072709 => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_INTERFACE,
            0x8007270A => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_FQDN,
            0x8007270B => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_QUERY_TYPE,
            0x8007270C => WIN32::DNS_ERROR_POLICY_INVALID_CRITERIA_TIME_OF_DAY,
            0x80072714 => WIN32::WSAEINTR,
            0x80072719 => WIN32::WSAEBADF,
            0x8007271D => WIN32::WSAEACCES,
            0x8007271E => WIN32::WSAEFAULT,
            0x80072726 => WIN32::WSAEINVAL,
            0x80072728 => WIN32::WSAEMFILE,
            0x80072733 => WIN32::WSAEWOULDBLOCK,
            0x80072734 => WIN32::WSAEINPROGRESS,
            0x80072735 => WIN32::WSAEALREADY,
            0x80072736 => WIN32::WSAENOTSOCK,
            0x80072737 => WIN32::WSAEDESTADDRREQ,
            0x80072738 => WIN32::WSAEMSGSIZE,
            0x80072739 => WIN32::WSAEPROTOTYPE,
            0x8007273A => WIN32::WSAENOPROTOOPT,
            0x8007273B => WIN32::WSAEPROTONOSUPPORT,
            0x8007273C => WIN32::WSAESOCKTNOSUPPORT,
            0x8007273D => WIN32::WSAEOPNOTSUPP,
            0x8007273E => WIN32::WSAEPFNOSUPPORT,
            0x8007273F => WIN32::WSAEAFNOSUPPORT,
            0x80072740 => WIN32::WSAEADDRINUSE,
            0x80072741 => WIN32::WSAEADDRNOTAVAIL,
            0x80072742 => WIN32::WSAENETDOWN,
            0x80072743 => WIN32::WSAENETUNREACH,
            0x80072744 => WIN32::WSAENETRESET,
            0x80072745 => WIN32::WSAECONNABORTED,
            0x80072746 => WIN32::WSAECONNRESET,
            0x80072747 => WIN32::WSAENOBUFS,
            0x80072748 => WIN32::WSAEISCONN,
            0x80072749 => WIN32::WSAENOTCONN,
            0x8007274A => WIN32::WSAESHUTDOWN,
            0x8007274B => WIN32::WSAETOOMANYREFS,
            0x8007274C => WIN32::WSAETIMEDOUT,
            0x8007274D => WIN32::WSAECONNREFUSED,
            0x8007274E => WIN32::WSAELOOP,
            0x8007274F => WIN32::WSAENAMETOOLONG,
            0x80072750 => WIN32::WSAEHOSTDOWN,
            0x80072751 => WIN32::WSAEHOSTUNREACH,
            0x80072752 => WIN32::WSAENOTEMPTY,
            0x80072753 => WIN32::WSAEPROCLIM,
            0x80072754 => WIN32::WSAEUSERS,
            0x80072755 => WIN32::WSAEDQUOT,
            0x80072756 => WIN32::WSAESTALE,
            0x80072757 => WIN32::WSAEREMOTE,
            0x8007276B => WIN32::WSASYSNOTREADY,
            0x8007276C => WIN32::WSAVERNOTSUPPORTED,
            0x8007276D => WIN32::WSANOTINITIALISED,
            0x80072775 => WIN32::WSAEDISCON,
            0x80072776 => WIN32::WSAENOMORE,
            0x80072777 => WIN32::WSAECANCELLED,
            0x80072778 => WIN32::WSAEINVALIDPROCTABLE,
            0x80072779 => WIN32::WSAEINVALIDPROVIDER,
            0x8007277A => WIN32::WSAEPROVIDERFAILEDINIT,
            0x8007277B => WIN32::WSASYSCALLFAILURE,
            0x8007277C => WIN32::WSASERVICE_NOT_FOUND,
            0x8007277D => WIN32::WSATYPE_NOT_FOUND,
            0x8007277E => WIN32::WSA_E_NO_MORE,
            0x8007277F => WIN32::WSA_E_CANCELLED,
            0x80072780 => WIN32::WSAEREFUSED,
            0x80072AF9 => WIN32::WSAHOST_NOT_FOUND,
            0x80072AFA => WIN32::WSATRY_AGAIN,
            0x80072AFB => WIN32::WSANO_RECOVERY,
            0x80072AFC => WIN32::WSANO_DATA,
            0x80072AFD => WIN32::WSA_QOS_RECEIVERS,
            0x80072AFE => WIN32::WSA_QOS_SENDERS,
            0x80072AFF => WIN32::WSA_QOS_NO_SENDERS,
            0x80072B00 => WIN32::WSA_QOS_NO_RECEIVERS,
            0x80072B01 => WIN32::WSA_QOS_REQUEST_CONFIRMED,
            0x80072B02 => WIN32::WSA_QOS_ADMISSION_FAILURE,
            0x80072B03 => WIN32::WSA_QOS_POLICY_FAILURE,
            0x80072B04 => WIN32::WSA_QOS_BAD_STYLE,
            0x80072B05 => WIN32::WSA_QOS_BAD_OBJECT,
            0x80072B06 => WIN32::WSA_QOS_TRAFFIC_CTRL_ERROR,
            0x80072B07 => WIN32::WSA_QOS_GENERIC_ERROR,
            0x80072B08 => WIN32::WSA_QOS_ESERVICETYPE,
            0x80072B09 => WIN32::WSA_QOS_EFLOWSPEC,
            0x80072B0A => WIN32::WSA_QOS_EPROVSPECBUF,
            0x80072B0B => WIN32::WSA_QOS_EFILTERSTYLE,
            0x80072B0C => WIN32::WSA_QOS_EFILTERTYPE,
            0x80072B0D => WIN32::WSA_QOS_EFILTERCOUNT,
            0x80072B0E => WIN32::WSA_QOS_EOBJLENGTH,
            0x80072B0F => WIN32::WSA_QOS_EFLOWCOUNT,
            0x80072B10 => WIN32::WSA_QOS_EUNKOWNPSOBJ,
            0x80072B11 => WIN32::WSA_QOS_EPOLICYOBJ,
            0x80072B12 => WIN32::WSA_QOS_EFLOWDESC,
            0x80072B13 => WIN32::WSA_QOS_EPSFLOWSPEC,
            0x80072B14 => WIN32::WSA_QOS_EPSFILTERSPEC,
            0x80072B15 => WIN32::WSA_QOS_ESDMODEOBJ,
            0x80072B16 => WIN32::WSA_QOS_ESHAPERATEOBJ,
            0x80072B17 => WIN32::WSA_QOS_RESERVED_PETYPE,
            0x80072B18 => WIN32::WSA_SECURE_HOST_NOT_FOUND,
            0x80072B19 => WIN32::WSA_IPSEC_NAME_POLICY_ERROR,
            0x80072CF1 => WIN32::PEER_E_CLOUD_NOT_FOUND,
            0x80072CF2 => WIN32::PEER_E_CLOUD_DISABLED,
            0x80072CF3 => WIN32::PEER_E_INVALID_IDENTITY,
            0x80072CF4 => WIN32::PEER_E_TOO_MUCH_LOAD,
            0x80072CF5 => WIN32::PEER_E_CLOUD_IS_SEARCH_ONLY,
            0x80072CF6 => WIN32::PEER_E_CLIENT_INVALID_COMPARTMENT_ID,
            0x80072CF8 => WIN32::PEER_E_DUPLICATE_PEER_NAME,
            0x80072CF9 => WIN32::PEER_E_CLOUD_IS_DEAD,
            0x80072EE0 => WIN32::ERROR_INTERNET_,
            0x80072EE1 => WIN32::WININET_E_OUT_OF_HANDLES,
            0x80072EE1 => WIN32::ERROR_INTERNET_OUT_OF_HANDLES,
            0x80072EE2 => WIN32::WININET_E_TIMEOUT,
            0x80072EE2 => WIN32::ERROR_INTERNET_TIMEOUT,
            0x80072EE2 => WIN32::ERROR_WINHTTP_TIMEOUT,
            0x80072EE3 => WIN32::WININET_E_EXTENDED_ERROR,
            0x80072EE3 => WIN32::ERROR_INTERNET_EXTENDED_ERROR,
            0x80072EE4 => WIN32::WININET_E_INTERNAL_ERROR,
            0x80072EE4 => WIN32::ERROR_INTERNET_INTERNAL_ERROR,
            0x80072EE4 => WIN32::ERROR_WINHTTP_INTERNAL_ERROR,
            0x80072EE5 => WIN32::WININET_E_INVALID_URL,
            0x80072EE5 => WIN32::ERROR_INTERNET_INVALID_URL,
            0x80072EE5 => WIN32::ERROR_WINHTTP_INVALID_URL,
            0x80072EE6 => WIN32::WININET_E_UNRECOGNIZED_SCHEME,
            0x80072EE6 => WIN32::ERROR_INTERNET_UNRECOGNIZED_SCHEME,
            0x80072EE6 => WIN32::ERROR_WINHTTP_UNRECOGNIZED_SCHEME,
            0x80072EE7 => WIN32::WININET_E_NAME_NOT_RESOLVED,
            0x80072EE7 => WIN32::ERROR_INTERNET_NAME_NOT_RESOLVED,
            0x80072EE7 => WIN32::ERROR_WINHTTP_NAME_NOT_RESOLVED,
            0x80072EE8 => WIN32::WININET_E_PROTOCOL_NOT_FOUND,
            0x80072EE8 => WIN32::ERROR_INTERNET_PROTOCOL_NOT_FOUND,
            0x80072EE9 => WIN32::WININET_E_INVALID_OPTION,
            0x80072EE9 => WIN32::ERROR_INTERNET_INVALID_OPTION,
            0x80072EE9 => WIN32::ERROR_WINHTTP_INVALID_OPTION,
            0x80072EEA => WIN32::WININET_E_BAD_OPTION_LENGTH,
            0x80072EEA => WIN32::ERROR_INTERNET_BAD_OPTION_LENGTH,
            0x80072EEB => WIN32::WININET_E_OPTION_NOT_SETTABLE,
            0x80072EEB => WIN32::ERROR_INTERNET_OPTION_NOT_SETTABLE,
            0x80072EEC => WIN32::WININET_E_SHUTDOWN,
            0x80072EEC => WIN32::ERROR_INTERNET_SHUTDOWN,
            0x80072EEC => WIN32::ERROR_WINHTTP_SHUTDOWN,
            0x80072EED => WIN32::WININET_E_INCORRECT_USER_NAME,
            0x80072EED => WIN32::ERROR_INTERNET_INCORRECT_USER_NAME,
            0x80072EEE => WIN32::WININET_E_INCORRECT_PASSWORD,
            0x80072EEE => WIN32::ERROR_INTERNET_INCORRECT_PASSWORD,
            0x80072EEF => WIN32::WININET_E_LOGIN_FAILURE,
            0x80072EEF => WIN32::ERROR_INTERNET_LOGIN_FAILURE,
            0x80072EEF => WIN32::ERROR_WINHTTP_LOGIN_FAILURE,
            0x80072EF0 => WIN32::WININET_E_INVALID_OPERATION,
            0x80072EF0 => WIN32::ERROR_INTERNET_INVALID_OPERATION,
            0x80072EF1 => WIN32::WININET_E_OPERATION_CANCELLED,
            0x80072EF1 => WIN32::ERROR_INTERNET_OPERATION_CANCELLED,
            0x80072EF1 => WIN32::ERROR_WINHTTP_OPERATION_CANCELLED,
            0x80072EF2 => WIN32::WININET_E_INCORRECT_HANDLE_TYPE,
            0x80072EF2 => WIN32::ERROR_INTERNET_INCORRECT_HANDLE_TYPE,
            0x80072EF3 => WIN32::WININET_E_INCORRECT_HANDLE_STATE,
            0x80072EF3 => WIN32::ERROR_INTERNET_INCORRECT_HANDLE_STATE,
            0x80072EF3 => WIN32::ERROR_WINHTTP_INCORRECT_HANDLE_STATE,
            0x80072EF4 => WIN32::WININET_E_NOT_PROXY_REQUEST,
            0x80072EF4 => WIN32::ERROR_INTERNET_NOT_PROXY_REQUEST,
            0x80072EF5 => WIN32::WININET_E_REGISTRY_VALUE_NOT_FOUND,
            0x80072EF5 => WIN32::ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND,
            0x80072EF6 => WIN32::WININET_E_BAD_REGISTRY_PARAMETER,
            0x80072EF6 => WIN32::ERROR_INTERNET_BAD_REGISTRY_PARAMETER,
            0x80072EF7 => WIN32::WININET_E_NO_DIRECT_ACCESS,
            0x80072EF7 => WIN32::ERROR_INTERNET_NO_DIRECT_ACCESS,
            0x80072EF8 => WIN32::WININET_E_NO_CONTEXT,
            0x80072EF8 => WIN32::ERROR_INTERNET_NO_CONTEXT,
            0x80072EF9 => WIN32::WININET_E_NO_CALLBACK,
            0x80072EF9 => WIN32::ERROR_INTERNET_NO_CALLBACK,
            0x80072EFA => WIN32::WININET_E_REQUEST_PENDING,
            0x80072EFA => WIN32::ERROR_INTERNET_REQUEST_PENDING,
            0x80072EFB => WIN32::WININET_E_INCORRECT_FORMAT,
            0x80072EFB => WIN32::ERROR_INTERNET_INCORRECT_FORMAT,
            0x80072EFC => WIN32::WININET_E_ITEM_NOT_FOUND,
            0x80072EFC => WIN32::ERROR_INTERNET_ITEM_NOT_FOUND,
            0x80072EFD => WIN32::WININET_E_CANNOT_CONNECT,
            0x80072EFD => WIN32::ERROR_INTERNET_CANNOT_CONNECT,
            0x80072EFD => WIN32::ERROR_WINHTTP_CANNOT_CONNECT,
            0x80072EFE => WIN32::WININET_E_CONNECTION_ABORTED,
            0x80072EFE => WIN32::ERROR_INTERNET_CONNECTION_ABORTED,
            0x80072EFE => WIN32::ERROR_WINHTTP_CONNECTION_ABORTED,
            0x80072EFF => WIN32::WININET_E_CONNECTION_RESET,
            0x80072EFF => WIN32::ERROR_INTERNET_CONNECTION_RESET,
            0x80072EFF => WIN32::ERROR_WINHTTP_CONNECTION_RESET,
            0x80072F00 => WIN32::WININET_E_FORCE_RETRY,
            0x80072F00 => WIN32::ERROR_INTERNET_FORCE_RETRY,
            0x80072F01 => WIN32::WININET_E_INVALID_PROXY_REQUEST,
            0x80072F01 => WIN32::ERROR_INTERNET_INVALID_PROXY_REQUEST,
            0x80072F02 => WIN32::WININET_E_NEED_UI,
            0x80072F02 => WIN32::ERROR_INTERNET_NEED_UI,
            0x80072F04 => WIN32::WININET_E_HANDLE_EXISTS,
            0x80072F04 => WIN32::ERROR_INTERNET_HANDLE_EXISTS,
            0x80072F05 => WIN32::WININET_E_SEC_CERT_DATE_INVALID,
            0x80072F05 => WIN32::ERROR_INTERNET_SEC_CERT_DATE_INVALID,
            0x80072F05 => WIN32::ERROR_WINHTTP_SEC_CERT_DATE_INVALID,
            0x80072F06 => WIN32::WININET_E_SEC_CERT_CN_INVALID,
            0x80072F06 => WIN32::ERROR_INTERNET_SEC_CERT_CN_INVALID,
            0x80072F06 => WIN32::ERROR_WINHTTP_SEC_CERT_CN_INVALID,
            0x80072F07 => WIN32::WININET_E_HTTP_TO_HTTPS_ON_REDIR,
            0x80072F07 => WIN32::ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR,
            0x80072F08 => WIN32::WININET_E_HTTPS_TO_HTTP_ON_REDIR,
            0x80072F08 => WIN32::ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR,
            0x80072F09 => WIN32::WININET_E_MIXED_SECURITY,
            0x80072F09 => WIN32::ERROR_INTERNET_MIXED_SECURITY,
            0x80072F0A => WIN32::WININET_E_CHG_POST_IS_NON_SECURE,
            0x80072F0A => WIN32::ERROR_INTERNET_CHG_POST_IS_NON_SECURE,
            0x80072F0B => WIN32::WININET_E_POST_IS_NON_SECURE,
            0x80072F0B => WIN32::ERROR_INTERNET_POST_IS_NON_SECURE,
            0x80072F0C => WIN32::WININET_E_CLIENT_AUTH_CERT_NEEDED,
            0x80072F0C => WIN32::ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED,
            0x80072F0C => WIN32::ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED,
            0x80072F0D => WIN32::WININET_E_INVALID_CA,
            0x80072F0D => WIN32::ERROR_INTERNET_INVALID_CA,
            0x80072F0D => WIN32::ERROR_WINHTTP_INVALID_CA,
            0x80072F0E => WIN32::WININET_E_CLIENT_AUTH_NOT_SETUP,
            0x80072F0E => WIN32::ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP,
            0x80072F0F => WIN32::WININET_E_ASYNC_THREAD_FAILED,
            0x80072F0F => WIN32::ERROR_INTERNET_ASYNC_THREAD_FAILED,
            0x80072F10 => WIN32::WININET_E_REDIRECT_SCHEME_CHANGE,
            0x80072F10 => WIN32::ERROR_INTERNET_REDIRECT_SCHEME_CHANGE,
            0x80072F11 => WIN32::WININET_E_DIALOG_PENDING,
            0x80072F11 => WIN32::ERROR_INTERNET_DIALOG_PENDING,
            0x80072F12 => WIN32::WININET_E_RETRY_DIALOG,
            0x80072F12 => WIN32::ERROR_INTERNET_RETRY_DIALOG,
            0x80072F13 => WIN32::WININET_E_NO_NEW_CONTAINERS,
            0x80072F14 => WIN32::WININET_E_HTTPS_HTTP_SUBMIT_REDIR,
            0x80072F14 => WIN32::ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR,
            0x80072F15 => WIN32::ERROR_INTERNET_INSERT_CDROM,
            0x80072F16 => WIN32::ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED,
            0x80072F17 => WIN32::WININET_E_SEC_CERT_ERRORS,
            0x80072F17 => WIN32::ERROR_INTERNET_SEC_CERT_ERRORS,
            0x80072F18 => WIN32::ERROR_INTERNET_SEC_CERT_NO_REV,
            0x80072F19 => WIN32::WININET_E_SEC_CERT_REV_FAILED,
            0x80072F19 => WIN32::ERROR_INTERNET_SEC_CERT_REV_FAILED,
            0x80072F30 => WIN32::ERROR_WINHTTP_NO_CM_CONNECTION,
            0x80072F4E => WIN32::ERROR_FTP_TRANSFER_IN_PROGRESS,
            0x80072F4F => WIN32::ERROR_FTP_DROPPED,
            0x80072F50 => WIN32::ERROR_FTP_NO_PASSIVE_MODE,
            0x80072F62 => WIN32::ERROR_GOPHER_PROTOCOL_ERROR,
            0x80072F63 => WIN32::ERROR_GOPHER_NOT_FILE,
            0x80072F64 => WIN32::ERROR_GOPHER_DATA_ERROR,
            0x80072F65 => WIN32::ERROR_GOPHER_END_OF_DATA,
            0x80072F66 => WIN32::ERROR_GOPHER_INVALID_LOCATOR,
            0x80072F67 => WIN32::ERROR_GOPHER_INCORRECT_LOCATOR_TYPE,
            0x80072F68 => WIN32::ERROR_GOPHER_NOT_GOPHER_PLUS,
            0x80072F69 => WIN32::ERROR_GOPHER_ATTRIBUTE_NOT_FOUND,
            0x80072F6A => WIN32::ERROR_GOPHER_UNKNOWN_LOCATOR,
            0x80072F76 => WIN32::WININET_E_HEADER_NOT_FOUND,
            0x80072F76 => WIN32::ERROR_HTTP_HEADER_NOT_FOUND,
            0x80072F76 => WIN32::ERROR_WINHTTP_HEADER_NOT_FOUND,
            0x80072F77 => WIN32::WININET_E_DOWNLEVEL_SERVER,
            0x80072F77 => WIN32::ERROR_HTTP_DOWNLEVEL_SERVER,
            0x80072F78 => WIN32::WININET_E_INVALID_SERVER_RESPONSE,
            0x80072F78 => WIN32::ERROR_HTTP_INVALID_SERVER_RESPONSE,
            0x80072F78 => WIN32::ERROR_WINHTTP_INVALID_SERVER_RESPONSE,
            0x80072F79 => WIN32::WININET_E_INVALID_HEADER,
            0x80072F79 => WIN32::ERROR_HTTP_INVALID_HEADER,
            0x80072F7A => WIN32::WININET_E_INVALID_QUERY_REQUEST,
            0x80072F7A => WIN32::ERROR_HTTP_INVALID_QUERY_REQUEST,
            0x80072F7A => WIN32::ERROR_WINHTTP_INVALID_QUERY_REQUEST,
            0x80072F7B => WIN32::WININET_E_HEADER_ALREADY_EXISTS,
            0x80072F7B => WIN32::ERROR_HTTP_HEADER_ALREADY_EXISTS,
            0x80072F7C => WIN32::WININET_E_REDIRECT_FAILED,
            0x80072F7C => WIN32::ERROR_HTTP_REDIRECT_FAILED,
            0x80072F7C => WIN32::ERROR_WINHTTP_REDIRECT_FAILED,
            0x80072F7D => WIN32::WININET_E_SECURITY_CHANNEL_ERROR,
            0x80072F7D => WIN32::ERROR_INTERNET_SECURITY_CHANNEL_ERROR,
            0x80072F7D => WIN32::ERROR_WINHTTP_SECURE_CHANNEL_ERROR,
            0x80072F7E => WIN32::WININET_E_UNABLE_TO_CACHE_FILE,
            0x80072F7E => WIN32::ERROR_INTERNET_UNABLE_TO_CACHE_FILE,
            0x80072F7F => WIN32::WININET_E_TCPIP_NOT_INSTALLED,
            0x80072F7F => WIN32::ERROR_INTERNET_TCPIP_NOT_INSTALLED,
            0x80072F80 => WIN32::WININET_E_NOT_REDIRECTED,
            0x80072F80 => WIN32::ERROR_HTTP_NOT_REDIRECTED,
            0x80072F81 => WIN32::WININET_E_COOKIE_NEEDS_CONFIRMATION,
            0x80072F81 => WIN32::ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION,
            0x80072F82 => WIN32::WININET_E_COOKIE_DECLINED,
            0x80072F82 => WIN32::ERROR_HTTP_COOKIE_DECLINED,
            0x80072F83 => WIN32::WININET_E_DISCONNECTED,
            0x80072F83 => WIN32::ERROR_INTERNET_DISCONNECTED,
            0x80072F84 => WIN32::WININET_E_SERVER_UNREACHABLE,
            0x80072F84 => WIN32::ERROR_INTERNET_SERVER_UNREACHABLE,
            0x80072F85 => WIN32::WININET_E_PROXY_SERVER_UNREACHABLE,
            0x80072F85 => WIN32::ERROR_INTERNET_PROXY_SERVER_UNREACHABLE,
            0x80072F86 => WIN32::WININET_E_BAD_AUTO_PROXY_SCRIPT,
            0x80072F86 => WIN32::ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT,
            0x80072F87 => WIN32::WININET_E_UNABLE_TO_DOWNLOAD_SCRIPT,
            0x80072F87 => WIN32::ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT,
            0x80072F88 => WIN32::WININET_E_REDIRECT_NEEDS_CONFIRMATION,
            0x80072F88 => WIN32::ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION,
            0x80072F89 => WIN32::WININET_E_SEC_INVALID_CERT,
            0x80072F89 => WIN32::ERROR_INTERNET_SEC_INVALID_CERT,
            0x80072F89 => WIN32::ERROR_WINHTTP_SECURE_INVALID_CERT,
            0x80072F8A => WIN32::WININET_E_SEC_CERT_REVOKED,
            0x80072F8A => WIN32::ERROR_INTERNET_SEC_CERT_REVOKED,
            0x80072F8B => WIN32::WININET_E_FAILED_DUETOSECURITYCHECK,
            0x80072F8B => WIN32::ERROR_INTERNET_FAILED_DUETOSECURITYCHECK,
            0x80072F8C => WIN32::WININET_E_NOT_INITIALIZED,
            0x80072F8C => WIN32::ERROR_INTERNET_NOT_INITIALIZED,
            0x80072F8D => WIN32::ERROR_INTERNET_NEED_MSN_SSPI_PKG,
            0x80072F8E => WIN32::WININET_E_LOGIN_FAILURE_DISPLAY_ENTITY_BODY,
            0x80072F8E => WIN32::ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY,
            0x80072F8F => WIN32::WININET_E_DECODING_FAILED,
            0x80072F8F => WIN32::ERROR_INTERNET_DECODING_FAILED,
            0x80072F8F => WIN32::ERROR_WINHTTP_SECURE_FAILURE,
            0x80072F98 => WIN32::ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW,
            0x800732C8 => WIN32::ERROR_IPSEC_QM_POLICY_EXISTS,
            0x800732C9 => WIN32::ERROR_IPSEC_QM_POLICY_NOT_FOUND,
            0x800732CA => WIN32::ERROR_IPSEC_QM_POLICY_IN_USE,
            0x800732CB => WIN32::ERROR_IPSEC_MM_POLICY_EXISTS,
            0x800732CC => WIN32::ERROR_IPSEC_MM_POLICY_NOT_FOUND,
            0x800732CD => WIN32::ERROR_IPSEC_MM_POLICY_IN_USE,
            0x800732CE => WIN32::ERROR_IPSEC_MM_FILTER_EXISTS,
            0x800732CF => WIN32::ERROR_IPSEC_MM_FILTER_NOT_FOUND,
            0x800732D0 => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_EXISTS,
            0x800732D1 => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_NOT_FOUND,
            0x800732D2 => WIN32::ERROR_IPSEC_MM_AUTH_EXISTS,
            0x800732D3 => WIN32::ERROR_IPSEC_MM_AUTH_NOT_FOUND,
            0x800732D4 => WIN32::ERROR_IPSEC_MM_AUTH_IN_USE,
            0x800732D5 => WIN32::ERROR_IPSEC_DEFAULT_MM_POLICY_NOT_FOUND,
            0x800732D6 => WIN32::ERROR_IPSEC_DEFAULT_MM_AUTH_NOT_FOUND,
            0x800732D7 => WIN32::ERROR_IPSEC_DEFAULT_QM_POLICY_NOT_FOUND,
            0x800732D8 => WIN32::ERROR_IPSEC_TUNNEL_FILTER_EXISTS,
            0x800732D9 => WIN32::ERROR_IPSEC_TUNNEL_FILTER_NOT_FOUND,
            0x800732DA => WIN32::ERROR_IPSEC_MM_FILTER_PENDING_DELETION,
            0x800732DB => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_PENDING_DELETION,
            0x800732DB => WIN32::ERROR_IPSEC_TRANSPORT_FILTER_ENDING_DELETION,
            0x800732DC => WIN32::ERROR_IPSEC_TUNNEL_FILTER_PENDING_DELETION,
            0x800732DD => WIN32::ERROR_IPSEC_MM_POLICY_PENDING_DELETION,
            0x800732DD => WIN32::ERROR_IPSEC_MM_POLICY_PENDING_ELETION,
            0x800732DE => WIN32::ERROR_IPSEC_MM_AUTH_PENDING_DELETION,
            0x800732DF => WIN32::ERROR_IPSEC_QM_POLICY_PENDING_DELETION,
            0x800732E0 => WIN32::WARNING_IPSEC_MM_POLICY_PRUNED,
            0x800732E1 => WIN32::WARNING_IPSEC_QM_POLICY_PRUNED,
            0x800735E8 => WIN32::ERROR_IPSEC_IKE_NEG_STATUS_BEGIN,
            0x800735E9 => WIN32::ERROR_IPSEC_IKE_AUTH_FAIL,
            0x800735EA => WIN32::ERROR_IPSEC_IKE_ATTRIB_FAIL,
            0x800735EB => WIN32::ERROR_IPSEC_IKE_NEGOTIATION_PENDING,
            0x800735EC => WIN32::ERROR_IPSEC_IKE_GENERAL_PROCESSING_ERROR,
            0x800735ED => WIN32::ERROR_IPSEC_IKE_TIMED_OUT,
            0x800735EE => WIN32::ERROR_IPSEC_IKE_NO_CERT,
            0x800735EF => WIN32::ERROR_IPSEC_IKE_SA_DELETED,
            0x800735F0 => WIN32::ERROR_IPSEC_IKE_SA_REAPED,
            0x800735F1 => WIN32::ERROR_IPSEC_IKE_MM_ACQUIRE_DROP,
            0x800735F2 => WIN32::ERROR_IPSEC_IKE_QM_ACQUIRE_DROP,
            0x800735F3 => WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_MM,
            0x800735F4 => WIN32::ERROR_IPSEC_IKE_QUEUE_DROP_NO_MM,
            0x800735F5 => WIN32::ERROR_IPSEC_IKE_DROP_NO_RESPONSE,
            0x800735F6 => WIN32::ERROR_IPSEC_IKE_MM_DELAY_DROP,
            0x800735F7 => WIN32::ERROR_IPSEC_IKE_QM_DELAY_DROP,
            0x800735F8 => WIN32::ERROR_IPSEC_IKE_ERROR,
            0x800735F9 => WIN32::ERROR_IPSEC_IKE_CRL_FAILED,
            0x800735FA => WIN32::ERROR_IPSEC_IKE_INVALID_KEY_USAGE,
            0x800735FB => WIN32::ERROR_IPSEC_IKE_INVALID_CERT_TYPE,
            0x800735FC => WIN32::ERROR_IPSEC_IKE_NO_PRIVATE_KEY,
            0x800735FD => WIN32::ERROR_IPSEC_IKE_SIMULTANEOUS_REKEY,
            0x800735FE => WIN32::ERROR_IPSEC_IKE_DH_FAIL,
            0x800735FF => WIN32::ERROR_IPSEC_IKE_CRITICAL_PAYLOAD_NOT_RECOGNIZED,
            0x80073600 => WIN32::ERROR_IPSEC_IKE_INVALID_HEADER,
            0x80073601 => WIN32::ERROR_IPSEC_IKE_NO_POLICY,
            0x80073602 => WIN32::ERROR_IPSEC_IKE_INVALID_SIGNATURE,
            0x80073603 => WIN32::ERROR_IPSEC_IKE_KERBEROS_ERROR,
            0x80073604 => WIN32::ERROR_IPSEC_IKE_NO_PUBLIC_KEY,
            0x80073605 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR,
            0x80073606 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SA,
            0x80073607 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_PROP,
            0x80073608 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_TRANS,
            0x80073609 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_KE,
            0x8007360A => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_ID,
            0x8007360B => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT,
            0x8007360C => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_CERT_REQ,
            0x8007360D => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_HASH,
            0x8007360E => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_SIG,
            0x8007360F => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NONCE,
            0x80073610 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NOTIFY,
            0x80073611 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_DELETE,
            0x80073612 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_VENDOR,
            0x80073613 => WIN32::ERROR_IPSEC_IKE_INVALID_PAYLOAD,
            0x80073614 => WIN32::ERROR_IPSEC_IKE_LOAD_SOFT_SA,
            0x80073615 => WIN32::ERROR_IPSEC_IKE_SOFT_SA_TORN_DOWN,
            0x80073616 => WIN32::ERROR_IPSEC_IKE_INVALID_COOKIE,
            0x80073617 => WIN32::ERROR_IPSEC_IKE_NO_PEER_CERT,
            0x80073618 => WIN32::ERROR_IPSEC_IKE_PEER_CRL_FAILED,
            0x80073619 => WIN32::ERROR_IPSEC_IKE_POLICY_CHANGE,
            0x8007361A => WIN32::ERROR_IPSEC_IKE_NO_MM_POLICY,
            0x8007361B => WIN32::ERROR_IPSEC_IKE_NOTCBPRIV,
            0x8007361C => WIN32::ERROR_IPSEC_IKE_SECLOADFAIL,
            0x8007361D => WIN32::ERROR_IPSEC_IKE_FAILSSPINIT,
            0x8007361E => WIN32::ERROR_IPSEC_IKE_FAILQUERYSSP,
            0x8007361F => WIN32::ERROR_IPSEC_IKE_SRVACQFAIL,
            0x80073620 => WIN32::ERROR_IPSEC_IKE_SRVQUERYCRED,
            0x80073621 => WIN32::ERROR_IPSEC_IKE_GETSPIFAIL,
            0x80073622 => WIN32::ERROR_IPSEC_IKE_INVALID_FILTER,
            0x80073623 => WIN32::ERROR_IPSEC_IKE_OUT_OF_MEMORY,
            0x80073624 => WIN32::ERROR_IPSEC_IKE_ADD_UPDATE_KEY_FAILED,
            0x80073625 => WIN32::ERROR_IPSEC_IKE_INVALID_POLICY,
            0x80073626 => WIN32::ERROR_IPSEC_IKE_UNKNOWN_DOI,
            0x80073627 => WIN32::ERROR_IPSEC_IKE_INVALID_SITUATION,
            0x80073628 => WIN32::ERROR_IPSEC_IKE_DH_FAILURE,
            0x80073629 => WIN32::ERROR_IPSEC_IKE_INVALID_GROUP,
            0x8007362A => WIN32::ERROR_IPSEC_IKE_ENCRYPT,
            0x8007362B => WIN32::ERROR_IPSEC_IKE_DECRYPT,
            0x8007362C => WIN32::ERROR_IPSEC_IKE_POLICY_MATCH,
            0x8007362D => WIN32::ERROR_IPSEC_IKE_UNSUPPORTED_ID,
            0x8007362E => WIN32::ERROR_IPSEC_IKE_INVALID_HASH,
            0x8007362F => WIN32::ERROR_IPSEC_IKE_INVALID_HASH_ALG,
            0x80073630 => WIN32::ERROR_IPSEC_IKE_INVALID_HASH_SIZE,
            0x80073631 => WIN32::ERROR_IPSEC_IKE_INVALID_ENCRYPT_ALG,
            0x80073632 => WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_ALG,
            0x80073633 => WIN32::ERROR_IPSEC_IKE_INVALID_SIG,
            0x80073634 => WIN32::ERROR_IPSEC_IKE_LOAD_FAILED,
            0x80073635 => WIN32::ERROR_IPSEC_IKE_RPC_DELETE,
            0x80073636 => WIN32::ERROR_IPSEC_IKE_BENIGN_REINIT,
            0x80073637 => WIN32::ERROR_IPSEC_IKE_INVALID_RESPONDER_LIFETIME_NOTIFY,
            0x80073638 => WIN32::ERROR_IPSEC_IKE_INVALID_MAJOR_VERSION,
            0x80073639 => WIN32::ERROR_IPSEC_IKE_INVALID_CERT_KEYLEN,
            0x8007363A => WIN32::ERROR_IPSEC_IKE_MM_LIMIT,
            0x8007363B => WIN32::ERROR_IPSEC_IKE_NEGOTIATION_DISABLED,
            0x8007363C => WIN32::ERROR_IPSEC_IKE_QM_LIMIT,
            0x8007363D => WIN32::ERROR_IPSEC_IKE_MM_EXPIRED,
            0x8007363E => WIN32::ERROR_IPSEC_IKE_PEER_MM_ASSUMED_INVALID,
            0x8007363F => WIN32::ERROR_IPSEC_IKE_CERT_CHAIN_POLICY_MISMATCH,
            0x80073640 => WIN32::ERROR_IPSEC_IKE_UNEXPECTED_MESSAGE_ID,
            0x80073641 => WIN32::ERROR_IPSEC_IKE_INVALID_AUTH_PAYLOAD,
            0x80073641 => WIN32::ERROR_IPSEC_IKE_INVALID_UMATTS,
            0x80073642 => WIN32::ERROR_IPSEC_IKE_DOS_COOKIE_SENT,
            0x80073643 => WIN32::ERROR_IPSEC_IKE_SHUTTING_DOWN,
            0x80073644 => WIN32::ERROR_IPSEC_IKE_CGA_AUTH_FAILED,
            0x80073645 => WIN32::ERROR_IPSEC_IKE_PROCESS_ERR_NATOA,
            0x80073646 => WIN32::ERROR_IPSEC_IKE_INVALID_MM_FOR_QM,
            0x80073647 => WIN32::ERROR_IPSEC_IKE_QM_EXPIRED,
            0x80073648 => WIN32::ERROR_IPSEC_IKE_TOO_MANY_FILTERS,
            0x80073649 => WIN32::ERROR_IPSEC_IKE_NEG_STATUS_END,
            0x8007364A => WIN32::ERROR_IPSEC_IKE_KILL_DUMMY_NAP_TUNNEL,
            0x8007364B => WIN32::ERROR_IPSEC_IKE_INNER_IP_ASSIGNMENT_FAILURE,
            0x8007364C => WIN32::ERROR_IPSEC_IKE_REQUIRE_CP_PAYLOAD_MISSING,
            0x8007364D => WIN32::ERROR_IPSEC_KEY_MODULE_IMPERSONATION_NEGOTIATION_PENDING,
            0x8007364E => WIN32::ERROR_IPSEC_IKE_COEXISTENCE_SUPPRESS,
            0x8007364F => WIN32::ERROR_IPSEC_IKE_RATELIMIT_DROP,
            0x80073650 => WIN32::ERROR_IPSEC_IKE_PEER_DOESNT_SUPPORT_MOBIKE,
            0x80073651 => WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE,
            0x80073652 => WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_FAILURE,
            0x80073653 => WIN32::ERROR_IPSEC_IKE_AUTHORIZATION_FAILURE_WITH_OPTIONAL_RETRY,
            0x80073654 => WIN32::ERROR_IPSEC_IKE_STRONG_CRED_AUTHORIZATION_AND_CERTMAP_FAILURE,
            0x80073655 => WIN32::ERROR_IPSEC_IKE_NEG_STATUS_EXTENDED_END,
            0x80073656 => WIN32::ERROR_IPSEC_BAD_SPI,
            0x80073657 => WIN32::ERROR_IPSEC_SA_LIFETIME_EXPIRED,
            0x80073658 => WIN32::ERROR_IPSEC_WRONG_SA,
            0x80073659 => WIN32::ERROR_IPSEC_REPLAY_CHECK_FAILED,
            0x8007365A => WIN32::ERROR_IPSEC_INVALID_PACKET,
            0x8007365B => WIN32::ERROR_IPSEC_INTEGRITY_CHECK_FAILED,
            0x8007365C => WIN32::ERROR_IPSEC_CLEAR_TEXT_DROP,
            0x8007365D => WIN32::ERROR_IPSEC_AUTH_FIREWALL_DROP,
            0x8007365E => WIN32::ERROR_IPSEC_THROTTLE_DROP,
            0x80073665 => WIN32::ERROR_IPSEC_DOSP_BLOCK,
            0x80073666 => WIN32::ERROR_IPSEC_DOSP_RECEIVED_MULTICAST,
            0x80073667 => WIN32::ERROR_IPSEC_DOSP_INVALID_PACKET,
            0x80073668 => WIN32::ERROR_IPSEC_DOSP_STATE_LOOKUP_FAILED,
            0x80073669 => WIN32::ERROR_IPSEC_DOSP_MAX_ENTRIES,
            0x8007366A => WIN32::ERROR_IPSEC_DOSP_KEYMOD_NOT_ALLOWED,
            0x8007366B => WIN32::ERROR_IPSEC_DOSP_NOT_INSTALLED,
            0x8007366C => WIN32::ERROR_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES,
            0x800736B0 => WIN32::ERROR_SXS_SECTION_NOT_FOUND,
            0x800736B1 => WIN32::ERROR_SXS_CANT_GEN_ACTCTX,
            0x800736B2 => WIN32::ERROR_SXS_INVALID_ACTCTXDATA_FORMAT,
            0x800736B3 => WIN32::ERROR_SXS_ASSEMBLY_NOT_FOUND,
            0x800736B4 => WIN32::ERROR_SXS_MANIFEST_FORMAT_ERROR,
            0x800736B5 => WIN32::ERROR_SXS_MANIFEST_PARSE_ERROR,
            0x800736B6 => WIN32::ERROR_SXS_ACTIVATION_CONTEXT_DISABLED,
            0x800736B7 => WIN32::ERROR_SXS_KEY_NOT_FOUND,
            0x800736B8 => WIN32::ERROR_SXS_VERSION_CONFLICT,
            0x800736B9 => WIN32::ERROR_SXS_WRONG_SECTION_TYPE,
            0x800736BA => WIN32::ERROR_SXS_THREAD_QUERIES_DISABLED,
            0x800736BB => WIN32::ERROR_SXS_PROCESS_DEFAULT_ALREADY_SET,
            0x800736BC => WIN32::ERROR_SXS_UNKNOWN_ENCODING_GROUP,
            0x800736BD => WIN32::ERROR_SXS_UNKNOWN_ENCODING,
            0x800736BE => WIN32::ERROR_SXS_INVALID_XML_NAMESPACE_URI,
            0x800736BF => WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_NOT_INSTALLED,
            0x800736BF => WIN32::ERROR_SXS_ROOT_MANIFEST_DEPENDENCY_OT_INSTALLED,
            0x800736C0 => WIN32::ERROR_SXS_LEAF_MANIFEST_DEPENDENCY_NOT_INSTALLED,
            0x800736C1 => WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE,
            0x800736C2 => WIN32::ERROR_SXS_MANIFEST_MISSING_REQUIRED_DEFAULT_NAMESPACE,
            0x800736C3 => WIN32::ERROR_SXS_MANIFEST_INVALID_REQUIRED_DEFAULT_NAMESPACE,
            0x800736C4 => WIN32::ERROR_SXS_PRIVATE_MANIFEST_CROSS_PATH_WITH_REPARSE_POINT,
            0x800736C5 => WIN32::ERROR_SXS_DUPLICATE_DLL_NAME,
            0x800736C6 => WIN32::ERROR_SXS_DUPLICATE_WINDOWCLASS_NAME,
            0x800736C7 => WIN32::ERROR_SXS_DUPLICATE_CLSID,
            0x800736C8 => WIN32::ERROR_SXS_DUPLICATE_IID,
            0x800736C9 => WIN32::ERROR_SXS_DUPLICATE_TLBID,
            0x800736CA => WIN32::ERROR_SXS_DUPLICATE_PROGID,
            0x800736CB => WIN32::ERROR_SXS_DUPLICATE_ASSEMBLY_NAME,
            0x800736CC => WIN32::ERROR_SXS_FILE_HASH_MISMATCH,
            0x800736CD => WIN32::ERROR_SXS_POLICY_PARSE_ERROR,
            0x800736CE => WIN32::ERROR_SXS_XML_E_MISSINGQUOTE,
            0x800736CF => WIN32::ERROR_SXS_XML_E_COMMENTSYNTAX,
            0x800736D0 => WIN32::ERROR_SXS_XML_E_BADSTARTNAMECHAR,
            0x800736D1 => WIN32::ERROR_SXS_XML_E_BADNAMECHAR,
            0x800736D2 => WIN32::ERROR_SXS_XML_E_BADCHARINSTRING,
            0x800736D3 => WIN32::ERROR_SXS_XML_E_XMLDECLSYNTAX,
            0x800736D4 => WIN32::ERROR_SXS_XML_E_BADCHARDATA,
            0x800736D5 => WIN32::ERROR_SXS_XML_E_MISSINGWHITESPACE,
            0x800736D6 => WIN32::ERROR_SXS_XML_E_EXPECTINGTAGEND,
            0x800736D7 => WIN32::ERROR_SXS_XML_E_MISSINGSEMICOLON,
            0x800736D8 => WIN32::ERROR_SXS_XML_E_UNBALANCEDPAREN,
            0x800736D9 => WIN32::ERROR_SXS_XML_E_INTERNALERROR,
            0x800736DA => WIN32::ERROR_SXS_XML_E_UNEXPECTED_WHITESPACE,
            0x800736DB => WIN32::ERROR_SXS_XML_E_INCOMPLETE_ENCODING,
            0x800736DC => WIN32::ERROR_SXS_XML_E_MISSING_PAREN,
            0x800736DD => WIN32::ERROR_SXS_XML_E_EXPECTINGCLOSEQUOTE,
            0x800736DE => WIN32::ERROR_SXS_XML_E_MULTIPLE_COLONS,
            0x800736DF => WIN32::ERROR_SXS_XML_E_INVALID_DECIMAL,
            0x800736E0 => WIN32::ERROR_SXS_XML_E_INVALID_HEXIDECIMAL,
            0x800736E1 => WIN32::ERROR_SXS_XML_E_INVALID_UNICODE,
            0x800736E2 => WIN32::ERROR_SXS_XML_E_WHITESPACEORQUESTIONMARK,
            0x800736E3 => WIN32::ERROR_SXS_XML_E_UNEXPECTEDENDTAG,
            0x800736E4 => WIN32::ERROR_SXS_XML_E_UNCLOSEDTAG,
            0x800736E5 => WIN32::ERROR_SXS_XML_E_DUPLICATEATTRIBUTE,
            0x800736E6 => WIN32::ERROR_SXS_XML_E_MULTIPLEROOTS,
            0x800736E7 => WIN32::ERROR_SXS_XML_E_INVALIDATROOTLEVEL,
            0x800736E8 => WIN32::ERROR_SXS_XML_E_BADXMLDECL,
            0x800736E9 => WIN32::ERROR_SXS_XML_E_MISSINGROOT,
            0x800736EA => WIN32::ERROR_SXS_XML_E_UNEXPECTEDEOF,
            0x800736EB => WIN32::ERROR_SXS_XML_E_BADPEREFINSUBSET,
            0x800736EC => WIN32::ERROR_SXS_XML_E_UNCLOSEDSTARTTAG,
            0x800736ED => WIN32::ERROR_SXS_XML_E_UNCLOSEDENDTAG,
            0x800736EE => WIN32::ERROR_SXS_XML_E_UNCLOSEDSTRING,
            0x800736EF => WIN32::ERROR_SXS_XML_E_UNCLOSEDCOMMENT,
            0x800736F0 => WIN32::ERROR_SXS_XML_E_UNCLOSEDDECL,
            0x800736F1 => WIN32::ERROR_SXS_XML_E_UNCLOSEDCDATA,
            0x800736F2 => WIN32::ERROR_SXS_XML_E_RESERVEDNAMESPACE,
            0x800736F3 => WIN32::ERROR_SXS_XML_E_INVALIDENCODING,
            0x800736F4 => WIN32::ERROR_SXS_XML_E_INVALIDSWITCH,
            0x800736F5 => WIN32::ERROR_SXS_XML_E_BADXMLCASE,
            0x800736F6 => WIN32::ERROR_SXS_XML_E_INVALID_STANDALONE,
            0x800736F7 => WIN32::ERROR_SXS_XML_E_UNEXPECTED_STANDALONE,
            0x800736F8 => WIN32::ERROR_SXS_XML_E_INVALID_VERSION,
            0x800736F9 => WIN32::ERROR_SXS_XML_E_MISSINGEQUALS,
            0x800736FA => WIN32::ERROR_SXS_PROTECTION_RECOVERY_FAILED,
            0x800736FB => WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_TOO_SHORT,
            0x800736FB => WIN32::ERROR_SXS_PROTECTION_PUBLIC_KEY_OO_SHORT,
            0x800736FC => WIN32::ERROR_SXS_PROTECTION_CATALOG_NOT_VALID,
            0x800736FD => WIN32::ERROR_SXS_UNTRANSLATABLE_HRESULT,
            0x800736FE => WIN32::ERROR_SXS_PROTECTION_CATALOG_FILE_MISSING,
            0x800736FF => WIN32::ERROR_SXS_MISSING_ASSEMBLY_IDENTITY_ATTRIBUTE,
            0x80073700 => WIN32::ERROR_SXS_INVALID_ASSEMBLY_IDENTITY_ATTRIBUTE_NAME,
            0x80073701 => WIN32::ERROR_SXS_ASSEMBLY_MISSING,
            0x80073702 => WIN32::ERROR_SXS_CORRUPT_ACTIVATION_STACK,
            0x80073703 => WIN32::ERROR_SXS_CORRUPTION,
            0x80073704 => WIN32::ERROR_SXS_EARLY_DEACTIVATION,
            0x80073705 => WIN32::ERROR_SXS_INVALID_DEACTIVATION,
            0x80073706 => WIN32::ERROR_SXS_MULTIPLE_DEACTIVATION,
            0x80073707 => WIN32::ERROR_SXS_PROCESS_TERMINATION_REQUESTED,
            0x80073708 => WIN32::ERROR_SXS_RELEASE_ACTIVATION_CONTEXT,
            0x80073708 => WIN32::ERROR_SXS_RELEASE_ACTIVATION_ONTEXT,
            0x80073709 => WIN32::ERROR_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY,
            0x8007370A => WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE,
            0x8007370B => WIN32::ERROR_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME,
            0x8007370C => WIN32::ERROR_SXS_IDENTITY_DUPLICATE_ATTRIBUTE,
            0x8007370D => WIN32::ERROR_SXS_IDENTITY_PARSE_ERROR,
            0x8007370E => WIN32::ERROR_MALFORMED_SUBSTITUTION_STRING,
            0x8007370F => WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_TOKEN,
            0x8007370F => WIN32::ERROR_SXS_INCORRECT_PUBLIC_KEY_OKEN,
            0x80073710 => WIN32::ERROR_UNMAPPED_SUBSTITUTION_STRING,
            0x80073711 => WIN32::ERROR_SXS_ASSEMBLY_NOT_LOCKED,
            0x80073712 => WIN32::ERROR_SXS_COMPONENT_STORE_CORRUPT,
            0x80073713 => WIN32::ERROR_ADVANCED_INSTALLER_FAILED,
            0x80073714 => WIN32::ERROR_XML_ENCODING_MISMATCH,
            0x80073715 => WIN32::ERROR_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT,
            0x80073716 => WIN32::ERROR_SXS_IDENTITIES_DIFFERENT,
            0x80073717 => WIN32::ERROR_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT,
            0x80073718 => WIN32::ERROR_SXS_FILE_NOT_PART_OF_ASSEMBLY,
            0x80073719 => WIN32::ERROR_SXS_MANIFEST_TOO_BIG,
            0x8007371A => WIN32::ERROR_SXS_SETTING_NOT_REGISTERED,
            0x8007371B => WIN32::ERROR_SXS_TRANSACTION_CLOSURE_INCOMPLETE,
            0x8007371C => WIN32::ERROR_SMI_PRIMITIVE_INSTALLER_FAILED,
            0x8007371D => WIN32::ERROR_GENERIC_COMMAND_FAILED,
            0x8007371E => WIN32::ERROR_SXS_FILE_HASH_MISSING,
            0x8007371F => WIN32::ERROR_SXS_DUPLICATE_ACTIVATABLE_CLASS,
            0x80073A98 => WIN32::ERROR_EVT_INVALID_CHANNEL_PATH,
            0x80073A99 => WIN32::ERROR_EVT_INVALID_QUERY,
            0x80073A9A => WIN32::ERROR_EVT_PUBLISHER_METADATA_NOT_FOUND,
            0x80073A9B => WIN32::ERROR_EVT_EVENT_TEMPLATE_NOT_FOUND,
            0x80073A9C => WIN32::ERROR_EVT_INVALID_PUBLISHER_NAME,
            0x80073A9D => WIN32::ERROR_EVT_INVALID_EVENT_DATA,
            0x80073A9F => WIN32::ERROR_EVT_CHANNEL_NOT_FOUND,
            0x80073AA0 => WIN32::ERROR_EVT_MALFORMED_XML_TEXT,
            0x80073AA1 => WIN32::ERROR_EVT_SUBSCRIPTION_TO_DIRECT_CHANNEL,
            0x80073AA2 => WIN32::ERROR_EVT_CONFIGURATION_ERROR,
            0x80073AA3 => WIN32::ERROR_EVT_QUERY_RESULT_STALE,
            0x80073AA4 => WIN32::ERROR_EVT_QUERY_RESULT_INVALID_POSITION,
            0x80073AA5 => WIN32::ERROR_EVT_NON_VALIDATING_MSXML,
            0x80073AA6 => WIN32::ERROR_EVT_FILTER_ALREADYSCOPED,
            0x80073AA7 => WIN32::ERROR_EVT_FILTER_NOTELTSET,
            0x80073AA8 => WIN32::ERROR_EVT_FILTER_INVARG,
            0x80073AA9 => WIN32::ERROR_EVT_FILTER_INVTEST,
            0x80073AAA => WIN32::ERROR_EVT_FILTER_INVTYPE,
            0x80073AAB => WIN32::ERROR_EVT_FILTER_PARSEERR,
            0x80073AAC => WIN32::ERROR_EVT_FILTER_UNSUPPORTEDOP,
            0x80073AAD => WIN32::ERROR_EVT_FILTER_UNEXPECTEDTOKEN,
            0x80073AAE => WIN32::ERROR_EVT_INVALID_OPERATION_OVER_ENABLED_DIRECT_CHANNEL,
            0x80073AAF => WIN32::ERROR_EVT_INVALID_CHANNEL_PROPERTY_VALUE,
            0x80073AB0 => WIN32::ERROR_EVT_INVALID_PUBLISHER_PROPERTY_VALUE,
            0x80073AB1 => WIN32::ERROR_EVT_CHANNEL_CANNOT_ACTIVATE,
            0x80073AB2 => WIN32::ERROR_EVT_FILTER_TOO_COMPLEX,
            0x80073AB3 => WIN32::ERROR_EVT_MESSAGE_NOT_FOUND,
            0x80073AB4 => WIN32::ERROR_EVT_MESSAGE_ID_NOT_FOUND,
            0x80073AB5 => WIN32::ERROR_EVT_UNRESOLVED_VALUE_INSERT,
            0x80073AB6 => WIN32::ERROR_EVT_UNRESOLVED_PARAMETER_INSERT,
            0x80073AB7 => WIN32::ERROR_EVT_MAX_INSERTS_REACHED,
            0x80073AB8 => WIN32::ERROR_EVT_EVENT_DEFINITION_NOT_FOUND,
            0x80073AB9 => WIN32::ERROR_EVT_MESSAGE_LOCALE_NOT_FOUND,
            0x80073ABA => WIN32::ERROR_EVT_VERSION_TOO_OLD,
            0x80073ABB => WIN32::ERROR_EVT_VERSION_TOO_NEW,
            0x80073ABC => WIN32::ERROR_EVT_CANNOT_OPEN_CHANNEL_OF_QUERY,
            0x80073ABD => WIN32::ERROR_EVT_PUBLISHER_DISABLED,
            0x80073ABE => WIN32::ERROR_EVT_FILTER_OUT_OF_RANGE,
            0x80073AE8 => WIN32::ERROR_EC_SUBSCRIPTION_CANNOT_ACTIVATE,
            0x80073AE9 => WIN32::ERROR_EC_LOG_DISABLED,
            0x80073AEA => WIN32::ERROR_EC_CIRCULAR_FORWARDING,
            0x80073AEB => WIN32::ERROR_EC_CREDSTORE_FULL,
            0x80073AEC => WIN32::ERROR_EC_CRED_NOT_FOUND,
            0x80073AED => WIN32::ERROR_EC_NO_ACTIVE_CHANNEL,
            0x80073AFC => WIN32::ERROR_MUI_FILE_NOT_FOUND,
            0x80073AFD => WIN32::ERROR_MUI_INVALID_FILE,
            0x80073AFE => WIN32::ERROR_MUI_INVALID_RC_CONFIG,
            0x80073AFF => WIN32::ERROR_MUI_INVALID_LOCALE_NAME,
            0x80073B00 => WIN32::ERROR_MUI_INVALID_ULTIMATEFALLBACK_NAME,
            0x80073B01 => WIN32::ERROR_MUI_FILE_NOT_LOADED,
            0x80073B02 => WIN32::ERROR_RESOURCE_ENUM_USER_STOP,
            0x80073B03 => WIN32::ERROR_MUI_INTLSETTINGS_UILANG_NOT_INSTALLED,
            0x80073B04 => WIN32::ERROR_MUI_INTLSETTINGS_INVALID_LOCALE_NAME,
            0x80073B06 => WIN32::ERROR_MRM_RUNTIME_NO_DEFAULT_OR_NEUTRAL_RESOURCE,
            0x80073B07 => WIN32::ERROR_MRM_INVALID_PRICONFIG,
            0x80073B08 => WIN32::ERROR_MRM_INVALID_FILE_TYPE,
            0x80073B09 => WIN32::ERROR_MRM_UNKNOWN_QUALIFIER,
            0x80073B0A => WIN32::ERROR_MRM_INVALID_QUALIFIER_VALUE,
            0x80073B0B => WIN32::ERROR_MRM_NO_CANDIDATE,
            0x80073B0C => WIN32::ERROR_MRM_NO_MATCH_OR_DEFAULT_CANDIDATE,
            0x80073B0D => WIN32::ERROR_MRM_RESOURCE_TYPE_MISMATCH,
            0x80073B0E => WIN32::ERROR_MRM_DUPLICATE_MAP_NAME,
            0x80073B0F => WIN32::ERROR_MRM_DUPLICATE_ENTRY,
            0x80073B10 => WIN32::ERROR_MRM_INVALID_RESOURCE_IDENTIFIER,
            0x80073B11 => WIN32::ERROR_MRM_FILEPATH_TOO_LONG,
            0x80073B12 => WIN32::ERROR_MRM_UNSUPPORTED_DIRECTORY_TYPE,
            0x80073B16 => WIN32::ERROR_MRM_INVALID_PRI_FILE,
            0x80073B17 => WIN32::ERROR_MRM_NAMED_RESOURCE_NOT_FOUND,
            0x80073B1F => WIN32::ERROR_MRM_MAP_NOT_FOUND,
            0x80073B20 => WIN32::ERROR_MRM_UNSUPPORTED_PROFILE_TYPE,
            0x80073B21 => WIN32::ERROR_MRM_INVALID_QUALIFIER_OPERATOR,
            0x80073B22 => WIN32::ERROR_MRM_INDETERMINATE_QUALIFIER_VALUE,
            0x80073B23 => WIN32::ERROR_MRM_AUTOMERGE_ENABLED,
            0x80073B24 => WIN32::ERROR_MRM_TOO_MANY_RESOURCES,
            0x80073B25 => WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_MERGE,
            0x80073B26 => WIN32::ERROR_MRM_UNSUPPORTED_FILE_TYPE_FOR_LOAD_UNLOAD_PRI_FILE,
            0x80073B27 => WIN32::ERROR_MRM_NO_CURRENT_VIEW_ON_THREAD,
            0x80073B28 => WIN32::ERROR_DIFFERENT_PROFILE_RESOURCE_MANAGER_EXIST,
            0x80073B29 => WIN32::ERROR_OPERATION_NOT_ALLOWED_FROM_SYSTEM_COMPONENT,
            0x80073B2A => WIN32::ERROR_MRM_DIRECT_REF_TO_NON_DEFAULT_RESOURCE,
            0x80073B2B => WIN32::ERROR_MRM_GENERATION_COUNT_MISMATCH,
            0x80073B2C => WIN32::ERROR_PRI_MERGE_VERSION_MISMATCH,
            0x80073B2D => WIN32::ERROR_PRI_MERGE_MISSING_SCHEMA,
            0x80073B2E => WIN32::ERROR_PRI_MERGE_LOAD_FILE_FAILED,
            0x80073B2F => WIN32::ERROR_PRI_MERGE_ADD_FILE_FAILED,
            0x80073B30 => WIN32::ERROR_PRI_MERGE_WRITE_FILE_FAILED,
            0x80073B31 => WIN32::ERROR_PRI_MERGE_MULTIPLE_PACKAGE_FAMILIES_NOT_ALLOWED,
            0x80073B32 => WIN32::ERROR_PRI_MERGE_MULTIPLE_MAIN_PACKAGES_NOT_ALLOWED,
            0x80073B33 => WIN32::ERROR_PRI_MERGE_BUNDLE_PACKAGES_NOT_ALLOWED,
            0x80073B34 => WIN32::ERROR_PRI_MERGE_MAIN_PACKAGE_REQUIRED,
            0x80073B35 => WIN32::ERROR_PRI_MERGE_RESOURCE_PACKAGE_REQUIRED,
            0x80073B36 => WIN32::ERROR_PRI_MERGE_INVALID_FILE_NAME,
            0x80073B37 => WIN32::ERROR_MRM_PACKAGE_NOT_FOUND,
            0x80073B38 => WIN32::ERROR_MRM_MISSING_DEFAULT_LANGUAGE,
            0x80073B39 => WIN32::ERROR_MRM_SCOPE_ITEM_CONFLICT,
            0x80073B60 => WIN32::ERROR_MCA_INVALID_CAPABILITIES_STRING,
            0x80073B61 => WIN32::ERROR_MCA_INVALID_VCP_VERSION,
            0x80073B62 => WIN32::ERROR_MCA_MONITOR_VIOLATES_MCCS_SPECIFICATION,
            0x80073B63 => WIN32::ERROR_MCA_MCCS_VERSION_MISMATCH,
            0x80073B64 => WIN32::ERROR_MCA_UNSUPPORTED_MCCS_VERSION,
            0x80073B65 => WIN32::ERROR_MCA_INTERNAL_ERROR,
            0x80073B66 => WIN32::ERROR_MCA_INVALID_TECHNOLOGY_TYPE_RETURNED,
            0x80073B67 => WIN32::ERROR_MCA_UNSUPPORTED_COLOR_TEMPERATURE,
            0x80073B92 => WIN32::ERROR_AMBIGUOUS_SYSTEM_DEVICE,
            0x80073BC3 => WIN32::ERROR_SYSTEM_DEVICE_NOT_FOUND,
            0x80073BC4 => WIN32::ERROR_HASH_NOT_SUPPORTED,
            0x80073BC5 => WIN32::ERROR_HASH_NOT_PRESENT,
            0x80073BD9 => WIN32::ERROR_SECONDARY_IC_PROVIDER_NOT_REGISTERED,
            0x80073BDA => WIN32::ERROR_GPIO_CLIENT_INFORMATION_INVALID,
            0x80073BDB => WIN32::ERROR_GPIO_VERSION_NOT_SUPPORTED,
            0x80073BDC => WIN32::ERROR_GPIO_INVALID_REGISTRATION_PACKET,
            0x80073BDD => WIN32::ERROR_GPIO_OPERATION_DENIED,
            0x80073BDE => WIN32::ERROR_GPIO_INCOMPATIBLE_CONNECT_MODE,
            0x80073BDF => WIN32::ERROR_GPIO_INTERRUPT_ALREADY_UNMASKED,
            0x80073C28 => WIN32::ERROR_CANNOT_SWITCH_RUNLEVEL,
            0x80073C29 => WIN32::ERROR_INVALID_RUNLEVEL_SETTING,
            0x80073C2A => WIN32::ERROR_RUNLEVEL_SWITCH_TIMEOUT,
            0x80073C2B => WIN32::ERROR_RUNLEVEL_SWITCH_AGENT_TIMEOUT,
            0x80073C2C => WIN32::ERROR_RUNLEVEL_SWITCH_IN_PROGRESS,
            0x80073C2D => WIN32::ERROR_SERVICES_FAILED_AUTOSTART,
            0x80073C8D => WIN32::ERROR_COM_TASK_STOP_PENDING,
            0x80073CF0 => WIN32::ERROR_INSTALL_OPEN_PACKAGE_FAILED,
            0x80073CF1 => WIN32::ERROR_INSTALL_PACKAGE_NOT_FOUND,
            0x80073CF2 => WIN32::ERROR_INSTALL_INVALID_PACKAGE,
            0x80073CF3 => WIN32::ERROR_INSTALL_RESOLVE_DEPENDENCY_FAILED,
            0x80073CF4 => WIN32::ERROR_INSTALL_OUT_OF_DISK_SPACE,
            0x80073CF5 => WIN32::ERROR_INSTALL_NETWORK_FAILURE,
            0x80073CF6 => WIN32::ERROR_INSTALL_REGISTRATION_FAILURE,
            0x80073CF7 => WIN32::ERROR_INSTALL_DEREGISTRATION_FAILURE,
            0x80073CF8 => WIN32::ERROR_INSTALL_CANCEL,
            0x80073CF9 => WIN32::ERROR_INSTALL_FAILED,
            0x80073CFA => WIN32::ERROR_REMOVE_FAILED,
            0x80073CFB => WIN32::ERROR_PACKAGE_ALREADY_EXISTS,
            0x80073CFC => WIN32::ERROR_NEEDS_REMEDIATION,
            0x80073CFD => WIN32::ERROR_INSTALL_PREREQUISITE_FAILED,
            0x80073CFE => WIN32::ERROR_PACKAGE_REPOSITORY_CORRUPTED,
            0x80073CFF => WIN32::ERROR_INSTALL_POLICY_FAILURE,
            0x80073D00 => WIN32::ERROR_PACKAGE_UPDATING,
            0x80073D01 => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_POLICY,
            0x80073D02 => WIN32::ERROR_PACKAGES_IN_USE,
            0x80073D03 => WIN32::ERROR_RECOVERY_FILE_CORRUPT,
            0x80073D04 => WIN32::ERROR_INVALID_STAGED_SIGNATURE,
            0x80073D05 => WIN32::ERROR_DELETING_EXISTING_APPLICATIONDATA_STORE_FAILED,
            0x80073D06 => WIN32::ERROR_INSTALL_PACKAGE_DOWNGRADE,
            0x80073D07 => WIN32::ERROR_SYSTEM_NEEDS_REMEDIATION,
            0x80073D08 => WIN32::ERROR_APPX_INTEGRITY_FAILURE_CLR_NGEN,
            0x80073D09 => WIN32::ERROR_RESILIENCY_FILE_CORRUPT,
            0x80073D0A => WIN32::ERROR_INSTALL_FIREWALL_SERVICE_NOT_RUNNING,
            0x80073D0B => WIN32::ERROR_PACKAGE_MOVE_FAILED,
            0x80073D0C => WIN32::ERROR_INSTALL_VOLUME_NOT_EMPTY,
            0x80073D0D => WIN32::ERROR_INSTALL_VOLUME_OFFLINE,
            0x80073D0E => WIN32::ERROR_INSTALL_VOLUME_CORRUPT,
            0x80073D0F => WIN32::ERROR_NEEDS_REGISTRATION,
            0x80073D10 => WIN32::ERROR_INSTALL_WRONG_PROCESSOR_ARCHITECTURE,
            0x80073D11 => WIN32::ERROR_DEV_SIDELOAD_LIMIT_EXCEEDED,
            0x80073D12 => WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE,
            0x80073D13 => WIN32::ERROR_PACKAGE_NOT_SUPPORTED_ON_FILESYSTEM,
            0x80073D14 => WIN32::ERROR_PACKAGE_MOVE_BLOCKED_BY_STREAMING,
            0x80073D15 => WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_APPLICATIONID_NOT_UNIQUE,
            0x80073D16 => WIN32::ERROR_PACKAGE_STAGING_ONHOLD,
            0x80073D17 => WIN32::ERROR_INSTALL_INVALID_RELATED_SET_UPDATE,
            0x80073D18 => WIN32::ERROR_INSTALL_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY,
            0x80073D19 => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_USER_LOG_OFF,
            0x80073D1A => WIN32::ERROR_PROVISION_OPTIONAL_PACKAGE_REQUIRES_MAIN_PACKAGE_PROVISIONED,
            0x80073D1B => WIN32::ERROR_PACKAGES_REPUTATION_CHECK_FAILED,
            0x80073D1C => WIN32::ERROR_PACKAGES_REPUTATION_CHECK_TIMEDOUT,
            0x80073D1D => WIN32::ERROR_DEPLOYMENT_OPTION_NOT_SUPPORTED,
            0x80073D1E => WIN32::ERROR_APPINSTALLER_ACTIVATION_BLOCKED,
            0x80073D1F => WIN32::ERROR_REGISTRATION_FROM_REMOTE_DRIVE_NOT_SUPPORTED,
            0x80073D20 => WIN32::ERROR_APPX_RAW_DATA_WRITE_FAILED,
            0x80073D21 => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_PACKAGE,
            0x80073D22 => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_VOLUME_POLICY_MACHINE,
            0x80073D23 => WIN32::ERROR_DEPLOYMENT_BLOCKED_BY_PROFILE_POLICY,
            0x80073D24 => WIN32::ERROR_DEPLOYMENT_FAILED_CONFLICTING_MUTABLE_PACKAGE_DIRECTORY,
            0x80073D25 => WIN32::ERROR_SINGLETON_RESOURCE_INSTALLED_IN_ACTIVE_USER,
            0x80073D26 => WIN32::ERROR_DIFFERENT_VERSION_OF_PACKAGED_SERVICE_INSTALLED,
            0x80073D27 => WIN32::ERROR_SERVICE_EXISTS_AS_NON_PACKAGED_SERVICE,
            0x80073D28 => WIN32::ERROR_PACKAGED_SERVICE_REQUIRES_ADMIN_PRIVILEGES,
            0x80073D29 => WIN32::ERROR_REDIRECTION_TO_DEFAULT_ACCOUNT_NOT_ALLOWED,
            0x80073D2A => WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_TO_DEPLOY_ON_HOST,
            0x80073D2B => WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_CONTENT,
            0x80073D2C => WIN32::ERROR_UNSIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE,
            0x80073D2D => WIN32::ERROR_SIGNED_PACKAGE_INVALID_PUBLISHER_NAMESPACE,
            0x80073D2E => WIN32::ERROR_PACKAGE_EXTERNAL_LOCATION_NOT_ALLOWED,
            0x80073D2F => WIN32::ERROR_INSTALL_FULLTRUST_HOSTRUNTIME_REQUIRES_MAIN_PACKAGE_FULLTRUST_CAPABILITY,
            0x80073D30 => WIN32::ERROR_PACKAGE_LACKS_CAPABILITY_FOR_MANDATORY_STARTUPTASKS,
            0x80073D31 => WIN32::ERROR_INSTALL_RESOLVE_HOSTRUNTIME_DEPENDENCY_FAILED,
            0x80073D32 => WIN32::ERROR_MACHINE_SCOPE_NOT_ALLOWED,
            0x80073D33 => WIN32::ERROR_CLASSIC_COMPAT_MODE_NOT_ALLOWED,
            0x80073D34 => WIN32::ERROR_STAGEFROMUPDATEAGENT_PACKAGE_NOT_APPLICABLE,
            0x80073D35 => WIN32::ERROR_PACKAGE_NOT_REGISTERED_FOR_USER,
            0x80073D36 => WIN32::ERROR_PACKAGE_NAME_MISMATCH,
            0x80073D37 => WIN32::ERROR_APPINSTALLER_URI_IN_USE,
            0x80073D38 => WIN32::ERROR_APPINSTALLER_IS_MANAGED_BY_SYSTEM,
            0x80073D54 => WIN32::APPMODEL_ERROR_NO_PACKAGE,
            0x80073D55 => WIN32::APPMODEL_ERROR_PACKAGE_RUNTIME_CORRUPT,
            0x80073D56 => WIN32::APPMODEL_ERROR_PACKAGE_IDENTITY_CORRUPT,
            0x80073D57 => WIN32::APPMODEL_ERROR_NO_APPLICATION,
            0x80073D58 => WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_READ_FAILED,
            0x80073D59 => WIN32::APPMODEL_ERROR_DYNAMIC_PROPERTY_INVALID,
            0x80073D5A => WIN32::APPMODEL_ERROR_PACKAGE_NOT_AVAILABLE,
            0x80073D5B => WIN32::APPMODEL_ERROR_NO_MUTABLE_DIRECTORY,
            0x80073DB8 => WIN32::ERROR_STATE_LOAD_STORE_FAILED,
            0x80073DB9 => WIN32::ERROR_STATE_GET_VERSION_FAILED,
            0x80073DBA => WIN32::ERROR_STATE_SET_VERSION_FAILED,
            0x80073DBB => WIN32::ERROR_STATE_STRUCTURED_RESET_FAILED,
            0x80073DBC => WIN32::ERROR_STATE_OPEN_CONTAINER_FAILED,
            0x80073DBD => WIN32::ERROR_STATE_CREATE_CONTAINER_FAILED,
            0x80073DBE => WIN32::ERROR_STATE_DELETE_CONTAINER_FAILED,
            0x80073DBF => WIN32::ERROR_STATE_READ_SETTING_FAILED,
            0x80073DC0 => WIN32::ERROR_STATE_WRITE_SETTING_FAILED,
            0x80073DC1 => WIN32::ERROR_STATE_DELETE_SETTING_FAILED,
            0x80073DC2 => WIN32::ERROR_STATE_QUERY_SETTING_FAILED,
            0x80073DC3 => WIN32::ERROR_STATE_READ_COMPOSITE_SETTING_FAILED,
            0x80073DC4 => WIN32::ERROR_STATE_WRITE_COMPOSITE_SETTING_FAILED,
            0x80073DC5 => WIN32::ERROR_STATE_ENUMERATE_CONTAINER_FAILED,
            0x80073DC6 => WIN32::ERROR_STATE_ENUMERATE_SETTINGS_FAILED,
            0x80073DC7 => WIN32::ERROR_STATE_COMPOSITE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED,
            0x80073DC8 => WIN32::ERROR_STATE_SETTING_VALUE_SIZE_LIMIT_EXCEEDED,
            0x80073DC9 => WIN32::ERROR_STATE_SETTING_NAME_SIZE_LIMIT_EXCEEDED,
            0x80073DCA => WIN32::ERROR_STATE_CONTAINER_NAME_SIZE_LIMIT_EXCEEDED,
            0x80073DE1 => WIN32::ERROR_API_UNAVAILABLE,
            0x80073DF5 => WIN32::STORE_ERROR_UNLICENSED,
            0x80073DF6 => WIN32::STORE_ERROR_UNLICENSED_USER,
            0x80073DF7 => WIN32::STORE_ERROR_PENDING_COM_TRANSACTION,
            0x80073DF8 => WIN32::STORE_ERROR_LICENSE_REVOKED,
            0x80078007 => WIN32::ERROR_SUCCESS,
        }
    }
}
