/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Creative Commons Zero v1.0 Universal (CC0) License.
 * You may obtain a copy of the License at
 *
 *     http://creativecommons.org/publicdomain/zero/1.0/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the CC0 license is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// It is strictly forbidden to use the from_code method, respected Microsoft decided to define
// duplicate codes, but by defining different constant names, therefore, when using these codes,
// it is mandatory to use through from_name, and not from_code. Otherwise, it may cause undefined
// behavior or an unknown exception. Because one code corresponds to several constants.

use super::{RawError};

#[derive(Clone, Debug, Copy, Eq, Hash, Ord, PartialEq, PartialOrd)]
pub enum WINRM {
    ERROR_WSMAN_RESOURCE_NOT_FOUND,
    ERROR_WSMAN_INVALID_ACTIONURI,
    ERROR_WSMAN_INVALID_URI,
    ERROR_WSMAN_PROVIDER_FAILURE,
    ERROR_WSMAN_BATCH_COMPLETE,
    ERROR_WSMAN_CONFIG_CORRUPTED,
    ERROR_WSMAN_PULL_IN_PROGRESS,
    ERROR_WSMAN_ENUMERATION_CLOSED,
    ERROR_WSMAN_SUBSCRIPTION_CLOSED,
    ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS,
    ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT,
    ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT,
    ERROR_WSMAN_UNSUPPORTED_TIMEOUT,
    ERROR_WSMAN_SOAP_VERSION_MISMATCH,
    ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN,
    ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER,
    ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND,
    ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED,
    ERROR_WSMAN_DESTINATION_UNREACHABLE,
    ERROR_WSMAN_ACTION_NOT_SUPPORTED,
    ERROR_WSMAN_ENDPOINT_UNAVAILABLE,
    ERROR_WSMAN_INVALID_REPRESENTATION,
    ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME,
    ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME,
    ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED,
    ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE,
    ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER,
    ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT,
    ERROR_WSMAN_ENUMERATE_TIMED_OUT,
    ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW,
    ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE,
    ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME,
    ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE,
    ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED,
    ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE,
    ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS,
    ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW,
    ERROR_WSMAN_EVENTING_INVALID_MESSAGE,
    ERROR_WSMAN_ENVELOPE_TOO_LARGE,
    ERROR_WSMAN_INVALID_SOAP_BODY,
    ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT,
    ERROR_WSMAN_OPERATION_TIMEDOUT,
    ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED,
    ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED,
    ERROR_WSMAN_UNSUPPORTED_ENCODING,
    ERROR_WSMAN_URI_LIMIT,
    ERROR_WSMAN_INVALID_PROPOSED_ID,
    ERROR_WSMAN_INVALID_BATCH_PARAMETER,
    ERROR_WSMAN_NO_ACK,
    ERROR_WSMAN_ACTION_MISMATCH,
    ERROR_WSMAN_CONCURRENCY,
    ERROR_WSMAN_ALREADY_EXISTS,
    ERROR_WSMAN_DELIVERY_REFUSED,
    ERROR_WSMAN_ENCODING_LIMIT,
    ERROR_WSMAN_FAILED_AUTHENTICATION,
    ERROR_WSMAN_INCOMPATIBLE_EPR,
    ERROR_WSMAN_INVALID_BOOKMARK,
    ERROR_WSMAN_INVALID_OPTIONS,
    ERROR_WSMAN_INVALID_PARAMETER,
    ERROR_WSMAN_INVALID_RESOURCE_URI,
    ERROR_WSMAN_INVALID_SYSTEM,
    ERROR_WSMAN_INVALID_SELECTORS,
    ERROR_WSMAN_METADATA_REDIRECT,
    ERROR_WSMAN_QUOTA_LIMIT,
    ERROR_WSMAN_RENAME_FAILURE,
    ERROR_WSMAN_SCHEMA_VALIDATION_ERROR,
    ERROR_WSMAN_UNSUPPORTED_FEATURE,
    ERROR_WSMAN_INVALID_XML,
    ERROR_WSMAN_INVALID_KEY,
    ERROR_WSMAN_DELIVER_IN_PROGRESS,
    ERROR_WSMAN_SYSTEM_NOT_FOUND,
    ERROR_WSMAN_MAX_ENVELOPE_SIZE,
    ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED,
    ERROR_WSMAN_SERVER_ENVELOPE_LIMIT,
    ERROR_WSMAN_SELECTOR_LIMIT,
    ERROR_WSMAN_OPTION_LIMIT,
    ERROR_WSMAN_CHARACTER_SET,
    ERROR_WSMAN_UNREPORTABLE_SUCCESS,
    ERROR_WSMAN_WHITESPACE,
    ERROR_WSMAN_FILTERING_REQUIRED,
    ERROR_WSMAN_BOOKMARK_EXPIRED,
    ERROR_WSMAN_OPTIONS_NOT_SUPPORTED,
    ERROR_WSMAN_OPTIONS_INVALID_NAME,
    ERROR_WSMAN_OPTIONS_INVALID_VALUE,
    ERROR_WSMAN_PARAMETER_TYPE_MISMATCH,
    ERROR_WSMAN_INVALID_PARAMETER_NAME,
    ERROR_WSMAN_INVALID_XML_VALUES,
    ERROR_WSMAN_INVALID_XML_MISSING_VALUES,
    ERROR_WSMAN_INVALID_XML_NAMESPACE,
    ERROR_WSMAN_INVALID_XML_FRAGMENT,
    ERROR_WSMAN_INSUFFCIENT_SELECTORS,
    ERROR_WSMAN_UNEXPECTED_SELECTORS,
    ERROR_WSMAN_SELECTOR_TYPEMISMATCH,
    ERROR_WSMAN_INVALID_SELECTOR_VALUE,
    ERROR_WSMAN_AMBIGUOUS_SELECTORS,
    ERROR_WSMAN_DUPLICATE_SELECTORS,
    ERROR_WSMAN_INVALID_TARGET_SELECTORS,
    ERROR_WSMAN_INVALID_TARGET_RESOURCEURI,
    ERROR_WSMAN_INVALID_TARGET_SYSTEM,
    ERROR_WSMAN_TARGET_ALREADY_EXISTS,
    ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED,
    ERROR_WSMAN_ACK_NOT_SUPPORTED,
    ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED,
    ERROR_WSMAN_LOCALE_NOT_SUPPORTED,
    ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED,
    ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED,
    ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED,
    ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED,
    ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED,
    ERROR_WSMAN_MAXTIME_NOT_SUPPORTED,
    ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED,
    ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED,
    ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED,
    ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED,
    ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED,
    ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED,
    ERROR_WSMAN_BAD_METHOD,
    ERROR_WSMAN_UNSUPPORTED_MEDIA,
    ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE,
    ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED,
    ERROR_WSMAN_ENUMERATION_INITIALIZING,
    ERROR_WSMAN_CONNECTOR_GET,
    ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR,
    ERROR_WSMAN_INEXISTENT_MAC_ADDRESS,
    ERROR_WSMAN_NO_UNICAST_ADDRESSES,
    ERROR_WSMAN_NO_DHCP_ADDRESSES,
    ERROR_WSMAN_MIN_ENVELOPE_SIZE,
    ERROR_WSMAN_EPR_NESTING_EXCEEDED,
    ERROR_WSMAN_REQUEST_INIT_ERROR,
    ERROR_WSMAN_INVALID_TIMEOUT_HEADER,
    ERROR_WSMAN_CERT_NOT_FOUND,
    ERROR_WSMAN_PLUGIN_FAILED,
    ERROR_WSMAN_ENUMERATION_INVALID,
    ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL,
    ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED,
    ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED,
    ERROR_WSMAN_POLICY_CORRUPTED,
    ERROR_WSMAN_LISTENER_ADDRESS_INVALID,
    ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING,
    ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE,
    ERROR_WSMAN_EVENTING_FAST_SENDER,
    ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION,
    ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE,
    ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER,
    ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE,
    ERROR_WSMAN_MISSING_FRAGMENT_PATH,
    ERROR_WSMAN_INVALID_FRAGMENT_DIALECT,
    ERROR_WSMAN_INVALID_FRAGMENT_PATH,
    ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE,
    ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED,
    ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS,
    ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER,
    ERROR_WSMAN_SESSION_ALREADY_CLOSED,
    ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID,
    ERROR_WSMAN_PROVIDER_LOAD_FAILED,
    ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE,
    ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE,
    ERROR_WSMAN_SECURITY_UNMAPPED,
    ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE,
    ERROR_WSMAN_INVALID_HOSTNAME_PATTERN,
    ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO,
    ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS,
    ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS,
    ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY,
    ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT,
    ERROR_WSMAN_MACHINE_OPTION_REQUIRED,
    ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS,
    ERROR_WSMAN_BATCHSIZE_TOO_SMALL,
    ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID,
    ERROR_WSMAN_PROVSYS_NOT_SUPPORTED,
    ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID,
    ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG,
    ERROR_WSMAN_CLIENT_INVALID_FLAG,
    ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS,
    ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH,
    ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS,
    ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED,
    ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME,
    ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED,
    ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED,
    ERROR_WSMAN_CLIENT_CERT_NEEDED,
    ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE,
    ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION,
    ERROR_WSMAN_CLIENT_INVALID_CERT,
    ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS,
    ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS,
    ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM,
    ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM,
    ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM,
    ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM,
    ERROR_WSMAN_CLIENT_NO_HANDLE,
    ERROR_WSMAN_CLIENT_BLANK_URI,
    ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR,
    ERROR_WSMAN_CLIENT_BLANK_INPUT_XML,
    ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL,
    ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL,
    ERROR_WSMAN_CLIENT_BLANK_ACTION_URI,
    ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT,
    ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES,
    ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES,
    ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE,
    ERROR_WSMAN_CLIENT_MISSING_EXPIRATION,
    ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS,
    ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT,
    ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG,
    ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION,
    ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM,
    ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM,
    ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM,
    ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM,
    ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM,
    ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM,
    ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM,
    ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM,
    ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM,
    ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY,
    ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP,
    ERROR_WSMAN_CONNECTIONSTR_INVALID,
    ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED,
    ERROR_WSMAN_PORT_INVALID,
    ERROR_WSMAN_CONFIG_PORT_INVALID,
    ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR,
    ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED,
    ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED,
    ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED,
    ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED,
    ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED,
    ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED,
    ERROR_WSMAN_SERVER_NOT_TRUSTED,
    ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED,
    ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK,
    ERROR_WSMAN_CERT_THUMBPRINT_BLANK,
    ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG,
    ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME,
    ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT,
    ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY,
    ERROR_WSMAN_INVALID_IPFILTER,
    ERROR_WSMAN_CANNOT_CHANGE_KEYS,
    ERROR_WSMAN_CERT_INVALID_USAGE,
    ERROR_WSMAN_RESPONSE_NO_RESULTS,
    ERROR_WSMAN_CREATE_RESPONSE_NO_EPR,
    ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT,
    ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER,
    ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER,
    ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY,
    ERROR_WSMAN_HTTP_NO_RESPONSE_DATA,
    ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT,
    ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA,
    ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA,
    ERROR_WSMAN_CANNOT_DECRYPT,
    ERROR_WSMAN_INVALID_URI_WMI_SINGLETON,
    ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL,
    ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION,
    ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION,
    ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER,
    ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED,
    ERROR_WSMAN_WMI_MAX_NESTED,
    ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED,
    ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE,
    ERROR_WSMAN_WMI_INVALID_VALUE,
    ERROR_WSMAN_WMI_SVC_ACCESS_DENIED,
    ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED,
    ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED,
    ERROR_WSMAN_INVALID_FILTER_XML,
    ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY,
    ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK,
    ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE,
    ERROR_WSMAN_KERBEROS_IPADDRESS,
    ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS,
    ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER,
    ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST,
    ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED,
    ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT,
    ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS,
    ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS,
    ERROR_WSMAN_HTTP_NOT_FOUND_STATUS,
    ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY,
    ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED,
    ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED,
    ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED,
    ERROR_WSMAN_INVALID_SELECTOR_NAME,
    ERROR_WSMAN_ENCODING_TYPE,
    ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE,
    ERROR_WSMAN_INVALID_HEADER,
    ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE,
    ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED,
    ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER,
    ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS,
    ERROR_WINRS_CLIENT_INVALID_FLAG,
    ERROR_WINRS_CLIENT_NULL_PARAM,
    ERROR_WSMAN_CANNOT_PROCESS_FILTER,
    ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM,
    ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT,
    ERROR_WSMAN_ADDOBJECT_MISSING_EPR,
    ERROR_WSMAN_NETWORK_TIMEDOUT,
    ERROR_WINRS_RECEIVE_IN_PROGRESS,
    ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA,
    ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM,
    ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM,
    ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM,
    ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM,
    ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM,
    ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM,
    ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM,
    ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM,
    ERROR_WINRS_CLIENT_PULL_NULL_PARAM,
    ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM,
    ERROR_WINRS_CLIENT_SEND_NULL_PARAM,
    ERROR_WINRS_CLIENT_PUSH_NULL_PARAM,
    ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM,
    ERROR_WINRS_CLIENT_GET_NULL_PARAM,
    ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED,
    ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE,
    ERROR_WSMAN_URI_NON_DMTF_CLASS,
    ERROR_WSMAN_URI_WRONG_DMTF_VERSION,
    ERROR_WSMAN_DIFFERENT_CIM_SELECTOR,
    ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT,
    ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER,
    ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR,
    ERROR_WSMAN_CONFIG_READONLY_PROPERTY,
    ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED,
    ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS,
    ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK,
    ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS,
    ERROR_WSMAN_MULTIPLE_CREDENTIALS,
    ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG,
    ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION,
    ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED,
    ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN,
    ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME,
    ERROR_WSMAN_SHELL_ALREADY_CLOSED,
    ERROR_WSMAN_CREATESHELL_NULL_STREAMID,
    ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE,
    ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE,
    ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT,
    ERROR_WSMAN_COMMAND_ALREADY_CLOSED,
    ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX,
    ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED,
    ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION,
    ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED,
    ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS,
    ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT,
    ERROR_WSMAN_CERT_MISSING_AUTH_FLAG,
    ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG,
    ERROR_WSMAN_CONFIG_SHELL_URI_INVALID,
    ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED,
    ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH,
    ERROR_WINRS_SHELL_URI_INVALID,
    ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR,
    ERROR_WSMAN_POLICY_TOO_COMPLEX,
    ERROR_WSMAN_POLICY_CANNOT_COMPLY,
    ERROR_WSMAN_INVALID_CONNECTIONRETRY,
    ERROR_WSMAN_URISECURITY_INVALIDURIKEY,
    ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY,
    ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY,
    ERROR_WSMAN_INVALID_PUBLISHERS_TYPE,
    ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY,
    ERROR_WSMAN_CLIENT_NULL_PUBLISHERS,
    ERROR_WSMAN_CLIENT_NULL_ISSUERS,
    ERROR_WSMAN_CLIENT_NO_SOURCES,
    ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT,
    ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE,
    ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG,
    ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK,
    ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE,
    ERROR_WSMAN_INVALID_PROVIDER_RESPONSE,
    ERROR_WSMAN_SHELL_NOT_INITIALIZED,
    ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY,
    ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR,
    ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST,
    ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS,
    ERROR_WSMAN_HTML_ERROR,
    ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM,
    ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG,
    ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG,
    ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM,
    ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM,
    ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM,
    ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM,
    ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG,
    ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG,
    ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG,
    ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM,
    ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM,
    ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM,
    ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG,
    ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED,
    ERROR_WSMAN_NO_COMMAND_RESPONSE,
    ERROR_WSMAN_INVALID_OPTIONSET,
    ERROR_WSMAN_NO_COMMANDID,
    ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM,
    ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG,
    ERROR_WSMAN_CLIENT_SEND_NULL_PARAM,
    ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG,
    ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER,
    ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM,
    ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM,
    ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS,
    ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG,
    ERROR_WSMAN_NO_RECEIVE_RESPONSE,
    ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED,
    ERROR_WSMAN_INVALID_FILEPATH,
    ERROR_WSMAN_FILE_NOT_PRESENT,
    ERROR_WSMAN_IISCONFIGURATION_READ_FAILED,
    ERROR_WSMAN_CLIENT_INVALID_LOCALE,
    ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE,
    ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM,
    ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE,
    ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG,
    ERROR_WSMAN_REDIRECT_REQUESTED,
    ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG,
    ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION,
    ERROR_WSMAN_PROXY_ACCESS_TYPE,
    ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER,
    ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM,
    ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM,
    ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM,
    ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED,
    ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED,
    ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS,
    ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY,
    ERROR_WSMAN_QUOTA_MAX_SHELLS,
    ERROR_WSMAN_QUOTA_MAX_OPERATIONS,
    ERROR_WSMAN_QUOTA_USER,
    ERROR_WSMAN_QUOTA_SYSTEM,
    ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN,
    ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE,
    ERROR_WSMAN_QUOTA_MAX_SHELLUSERS,
    ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED,
    ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM,
    ERROR_WSMAN_DEPRECATED_CONFIG_SETTING,
    ERROR_WSMAN_URI_SECURITY_URI,
    ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP,
    ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP,
    ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS,
    ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP,
    ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS,
    ERROR_WSMAN_INVALID_REDIRECT_ERROR,
    ERROR_REDIRECT_LOCATION_TOO_LONG,
    ERROR_REDIRECT_LOCATION_INVALID,
    ERROR_SERVICE_CBT_HARDENING_INVALID,
    ERROR_WSMAN_NAME_NOT_RESOLVED,
    ERROR_WSMAN_SSL_CONNECTION_ABORTED,
    ERROR_WSMAN_DEFAULTAUTH_IPADDRESS,
    ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED,
    ERROR_WSMAN_FEATURE_DEPRECATED,
    ERROR_WSMAN_INVALID_USESSL_PARAM,
    ERROR_WSMAN_INVALID_CONFIGSDDL_URL,
    ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED,
    ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED,
    ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID,
    ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS,
    ERROR_WINRS_SHELL_DISCONNECTED,
    ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED,
    ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH,
    ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM,
    ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM,
    ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM,
    ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM,
    ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY,
    ERROR_WSMAN_COMMAND_TERMINATED,
    ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT,
    ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL,
    ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID,
    ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID,
    ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED,
    ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM,
    ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID,
    ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID,
    ERROR_WINRS_SHELL_CLIENTID_NOT_VALID,
    ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT,
    ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT,
    ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID,
    ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY,
    ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG,
    ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR,
    ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT,
    ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED,
    ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED,
    ERROR_WSMAN_CREATESHELL_RUNAS_FAILED,
    ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED,
    ERROR_WSMAN_WRONG_METADATA,
    ERROR_WSMAN_UNSUPPORTED_TYPE,
    ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED,
    ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ,
    ERROR_WSMAN_QUOTA_MAX_USERS_PPQ,
    ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ,
    ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ,
    ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ,
    ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ,
    ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ,
    ERROR_WSMAN_NEW_DESERIALIZER,
    ERROR_WSMAN_DESERIALIZE_CLASS,
    ERROR_WSMAN_GETCLASS,
    ERROR_WSMAN_NEW_SESSION,
    ERROR_WSMAN_NULL_KEY,
    ERROR_WSMAN_MUTUAL_AUTH_FAILED,
    ERROR_WSMAN_UNSUPPORTED_OCTETTYPE,
    ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS,
    ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC,
    ERROR_WSMAN_INVALID_LITERAL_URI,
    ERROR_WSMAN_OBJECTONLY_INVALID,
    ERROR_WSMAN_MISSING_CLASSNAME,
    ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY,
    ERROR_WSMAN_DESTINATION_INVALID,
    ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY,
    ERROR_WSMAN_CLIENT_SESSION_UNUSABLE,
}

impl WINRM {
    pub fn code(&self) -> u32 {
        return match self {
            WINRM::ERROR_WSMAN_RESOURCE_NOT_FOUND => 0x80338000 as u32,
            WINRM::ERROR_WSMAN_INVALID_ACTIONURI => 0x80338001 as u32,
            WINRM::ERROR_WSMAN_INVALID_URI => 0x80338002 as u32,
            WINRM::ERROR_WSMAN_PROVIDER_FAILURE => 0x80338003 as u32,
            WINRM::ERROR_WSMAN_BATCH_COMPLETE => 0x80338004 as u32,
            WINRM::ERROR_WSMAN_CONFIG_CORRUPTED => 0x80338005 as u32,
            WINRM::ERROR_WSMAN_PULL_IN_PROGRESS => 0x80338006 as u32,
            WINRM::ERROR_WSMAN_ENUMERATION_CLOSED => 0x80338007 as u32,
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSED => 0x80338008 as u32,
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS => 0x80338009 as u32,
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT => 0x8033800A as u32,
            WINRM::ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT => 0x8033800B as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_TIMEOUT => 0x8033800C as u32,
            WINRM::ERROR_WSMAN_SOAP_VERSION_MISMATCH => 0x8033800D as u32,
            WINRM::ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN => 0x8033800E as u32,
            WINRM::ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER => 0x8033800F as u32,
            WINRM::ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND => 0x80338010 as u32,
            WINRM::ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED => 0x80338011 as u32,
            WINRM::ERROR_WSMAN_DESTINATION_UNREACHABLE => 0x80338012 as u32,
            WINRM::ERROR_WSMAN_ACTION_NOT_SUPPORTED => 0x80338013 as u32,
            WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE => 0x80338014 as u32,
            WINRM::ERROR_WSMAN_INVALID_REPRESENTATION => 0x80338015 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME => 0x80338016 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME => 0x80338017 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED => 0x80338018 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE => 0x80338019 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER => 0x8033801A as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT => 0x8033801B as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_TIMED_OUT => 0x8033801C as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW => 0x8033801D as u32,
            WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE => 0x8033801E as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME => 0x8033801F as u32,
            WINRM::ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE => 0x80338020 as u32,
            WINRM::ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED => 0x80338021 as u32,
            WINRM::ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE => 0x80338022 as u32,
            WINRM::ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS => 0x80338023 as u32,
            WINRM::ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW => 0x80338024 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_MESSAGE => 0x80338025 as u32,
            WINRM::ERROR_WSMAN_ENVELOPE_TOO_LARGE => 0x80338026 as u32,
            WINRM::ERROR_WSMAN_INVALID_SOAP_BODY => 0x80338027 as u32,
            WINRM::ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT => 0x80338028 as u32,
            WINRM::ERROR_WSMAN_OPERATION_TIMEDOUT => 0x80338029 as u32,
            WINRM::ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED => 0x8033802A as u32,
            WINRM::ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED => 0x8033802B as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_ENCODING => 0x8033802C as u32,
            WINRM::ERROR_WSMAN_URI_LIMIT => 0x8033802D as u32,
            WINRM::ERROR_WSMAN_INVALID_PROPOSED_ID => 0x8033802E as u32,
            WINRM::ERROR_WSMAN_INVALID_BATCH_PARAMETER => 0x8033802F as u32,
            WINRM::ERROR_WSMAN_NO_ACK => 0x80338030 as u32,
            WINRM::ERROR_WSMAN_ACTION_MISMATCH => 0x80338031 as u32,
            WINRM::ERROR_WSMAN_CONCURRENCY => 0x80338032 as u32,
            WINRM::ERROR_WSMAN_ALREADY_EXISTS => 0x80338033 as u32,
            WINRM::ERROR_WSMAN_DELIVERY_REFUSED => 0x80338034 as u32,
            WINRM::ERROR_WSMAN_ENCODING_LIMIT => 0x80338035 as u32,
            WINRM::ERROR_WSMAN_FAILED_AUTHENTICATION => 0x80338036 as u32,
            WINRM::ERROR_WSMAN_INCOMPATIBLE_EPR => 0x80338037 as u32,
            WINRM::ERROR_WSMAN_INVALID_BOOKMARK => 0x80338038 as u32,
            WINRM::ERROR_WSMAN_INVALID_OPTIONS => 0x80338039 as u32,
            WINRM::ERROR_WSMAN_INVALID_PARAMETER => 0x8033803A as u32,
            WINRM::ERROR_WSMAN_INVALID_RESOURCE_URI => 0x8033803B as u32,
            WINRM::ERROR_WSMAN_INVALID_SYSTEM => 0x8033803C as u32,
            WINRM::ERROR_WSMAN_INVALID_SELECTORS => 0x8033803D as u32,
            WINRM::ERROR_WSMAN_METADATA_REDIRECT => 0x8033803E as u32,
            WINRM::ERROR_WSMAN_QUOTA_LIMIT => 0x8033803F as u32,
            WINRM::ERROR_WSMAN_RENAME_FAILURE => 0x80338040 as u32,
            WINRM::ERROR_WSMAN_SCHEMA_VALIDATION_ERROR => 0x80338041 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE => 0x80338042 as u32,
            WINRM::ERROR_WSMAN_INVALID_XML => 0x80338043 as u32,
            WINRM::ERROR_WSMAN_INVALID_KEY => 0x80338044 as u32,
            WINRM::ERROR_WSMAN_DELIVER_IN_PROGRESS => 0x80338045 as u32,
            WINRM::ERROR_WSMAN_SYSTEM_NOT_FOUND => 0x80338046 as u32,
            WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE => 0x80338047 as u32,
            WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED => 0x80338048 as u32,
            WINRM::ERROR_WSMAN_SERVER_ENVELOPE_LIMIT => 0x80338049 as u32,
            WINRM::ERROR_WSMAN_SELECTOR_LIMIT => 0x8033804A as u32,
            WINRM::ERROR_WSMAN_OPTION_LIMIT => 0x8033804B as u32,
            WINRM::ERROR_WSMAN_CHARACTER_SET => 0x8033804C as u32,
            WINRM::ERROR_WSMAN_UNREPORTABLE_SUCCESS => 0x8033804D as u32,
            WINRM::ERROR_WSMAN_WHITESPACE => 0x8033804E as u32,
            WINRM::ERROR_WSMAN_FILTERING_REQUIRED => 0x8033804F as u32,
            WINRM::ERROR_WSMAN_BOOKMARK_EXPIRED => 0x80338050 as u32,
            WINRM::ERROR_WSMAN_OPTIONS_NOT_SUPPORTED => 0x80338051 as u32,
            WINRM::ERROR_WSMAN_OPTIONS_INVALID_NAME => 0x80338052 as u32,
            WINRM::ERROR_WSMAN_OPTIONS_INVALID_VALUE => 0x80338053 as u32,
            WINRM::ERROR_WSMAN_PARAMETER_TYPE_MISMATCH => 0x80338054 as u32,
            WINRM::ERROR_WSMAN_INVALID_PARAMETER_NAME => 0x80338055 as u32,
            WINRM::ERROR_WSMAN_INVALID_XML_VALUES => 0x80338056 as u32,
            WINRM::ERROR_WSMAN_INVALID_XML_MISSING_VALUES => 0x80338057 as u32,
            WINRM::ERROR_WSMAN_INVALID_XML_NAMESPACE => 0x80338058 as u32,
            WINRM::ERROR_WSMAN_INVALID_XML_FRAGMENT => 0x80338059 as u32,
            WINRM::ERROR_WSMAN_INSUFFCIENT_SELECTORS => 0x8033805A as u32,
            WINRM::ERROR_WSMAN_UNEXPECTED_SELECTORS => 0x8033805B as u32,
            WINRM::ERROR_WSMAN_SELECTOR_TYPEMISMATCH => 0x8033805C as u32,
            WINRM::ERROR_WSMAN_INVALID_SELECTOR_VALUE => 0x8033805D as u32,
            WINRM::ERROR_WSMAN_AMBIGUOUS_SELECTORS => 0x8033805E as u32,
            WINRM::ERROR_WSMAN_DUPLICATE_SELECTORS => 0x8033805F as u32,
            WINRM::ERROR_WSMAN_INVALID_TARGET_SELECTORS => 0x80338060 as u32,
            WINRM::ERROR_WSMAN_INVALID_TARGET_RESOURCEURI => 0x80338061 as u32,
            WINRM::ERROR_WSMAN_INVALID_TARGET_SYSTEM => 0x80338062 as u32,
            WINRM::ERROR_WSMAN_TARGET_ALREADY_EXISTS => 0x80338063 as u32,
            WINRM::ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED => 0x80338064 as u32,
            WINRM::ERROR_WSMAN_ACK_NOT_SUPPORTED => 0x80338065 as u32,
            WINRM::ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED => 0x80338066 as u32,
            WINRM::ERROR_WSMAN_LOCALE_NOT_SUPPORTED => 0x80338067 as u32,
            WINRM::ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED => 0x80338068 as u32,
            WINRM::ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED => 0x80338069 as u32,
            WINRM::ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED => 0x8033806A as u32,
            WINRM::ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED => 0x8033806B as u32,
            WINRM::ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED => 0x8033806C as u32,
            WINRM::ERROR_WSMAN_MAXTIME_NOT_SUPPORTED => 0x8033806D as u32,
            WINRM::ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED => 0x8033806E as u32,
            WINRM::ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED => 0x8033806F as u32,
            WINRM::ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED => 0x80338070 as u32,
            WINRM::ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED => 0x80338071 as u32,
            WINRM::ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED => 0x80338072 as u32,
            WINRM::ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED => 0x80338073 as u32,
            WINRM::ERROR_WSMAN_BAD_METHOD => 0x80338074 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_MEDIA => 0x80338075 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE => 0x80338076 as u32,
            WINRM::ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED => 0x80338077 as u32,
            WINRM::ERROR_WSMAN_ENUMERATION_INITIALIZING => 0x80338078 as u32,
            WINRM::ERROR_WSMAN_CONNECTOR_GET => 0x80338079 as u32,
            WINRM::ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR => 0x8033807A as u32,
            WINRM::ERROR_WSMAN_INEXISTENT_MAC_ADDRESS => 0x8033807B as u32,
            WINRM::ERROR_WSMAN_NO_UNICAST_ADDRESSES => 0x8033807C as u32,
            WINRM::ERROR_WSMAN_NO_DHCP_ADDRESSES => 0x8033807D as u32,
            WINRM::ERROR_WSMAN_MIN_ENVELOPE_SIZE => 0x8033807E as u32,
            WINRM::ERROR_WSMAN_EPR_NESTING_EXCEEDED => 0x8033807F as u32,
            WINRM::ERROR_WSMAN_REQUEST_INIT_ERROR => 0x80338080 as u32,
            WINRM::ERROR_WSMAN_INVALID_TIMEOUT_HEADER => 0x80338081 as u32,
            WINRM::ERROR_WSMAN_CERT_NOT_FOUND => 0x80338082 as u32,
            WINRM::ERROR_WSMAN_PLUGIN_FAILED => 0x80338083 as u32,
            WINRM::ERROR_WSMAN_ENUMERATION_INVALID => 0x80338084 as u32,
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL => 0x80338085 as u32,
            WINRM::ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED => 0x80338086 as u32,
            WINRM::ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED => 0x80338087 as u32,
            WINRM::ERROR_WSMAN_POLICY_CORRUPTED => 0x80338088 as u32,
            WINRM::ERROR_WSMAN_LISTENER_ADDRESS_INVALID => 0x80338089 as u32,
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING => 0x8033808A as u32,
            WINRM::ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE => 0x8033808B as u32,
            WINRM::ERROR_WSMAN_EVENTING_FAST_SENDER => 0x8033808C as u32,
            WINRM::ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION => 0x8033808D as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE => 0x8033808E as u32,
            WINRM::ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER => 0x8033808F as u32,
            WINRM::ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE => 0x80338090 as u32,
            WINRM::ERROR_WSMAN_MISSING_FRAGMENT_PATH => 0x80338091 as u32,
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_DIALECT => 0x80338092 as u32,
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH => 0x80338093 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE => 0x80338094 as u32,
            WINRM::ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED => 0x80338095 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS => 0x80338096 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER => 0x80338097 as u32,
            WINRM::ERROR_WSMAN_SESSION_ALREADY_CLOSED => 0x80338098 as u32,
            WINRM::ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID => 0x80338099 as u32,
            WINRM::ERROR_WSMAN_PROVIDER_LOAD_FAILED => 0x8033809A as u32,
            WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE => 0x8033809B as u32,
            WINRM::ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE => 0x8033809C as u32,
            WINRM::ERROR_WSMAN_SECURITY_UNMAPPED => 0x8033809D as u32,
            WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE => 0x8033809E as u32,
            WINRM::ERROR_WSMAN_INVALID_HOSTNAME_PATTERN => 0x8033809F as u32,
            WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO => 0x803380A0 as u32,
            WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS => 0x803380A1 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS => 0x803380A2 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY => 0x803380A3 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT => 0x803380A4 as u32,
            WINRM::ERROR_WSMAN_MACHINE_OPTION_REQUIRED => 0x803380A5 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS => 0x803380A6 as u32,
            WINRM::ERROR_WSMAN_BATCHSIZE_TOO_SMALL => 0x803380A7 as u32,
            WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID => 0x803380A8 as u32,
            WINRM::ERROR_WSMAN_PROVSYS_NOT_SUPPORTED => 0x803380A9 as u32,
            WINRM::ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID => 0x803380AA as u32,
            WINRM::ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG => 0x803380AB as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_FLAG => 0x803380AC as u32,
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS => 0x803380AD as u32,
            WINRM::ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH => 0x803380AE as u32,
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS => 0x803380AF as u32,
            WINRM::ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED => 0x803380B0 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME => 0x803380B1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED => 0x803380B2 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED => 0x803380B3 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CERT_NEEDED => 0x803380B4 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE => 0x803380B5 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION => 0x803380B6 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT => 0x803380B7 as u32,
            WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS => 0x803380B8 as u32,
            WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS => 0x803380B9 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM => 0x803380BA as u32,
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM => 0x803380BB as u32,
            WINRM::ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM => 0x803380BC as u32,
            WINRM::ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM => 0x803380BD as u32,
            WINRM::ERROR_WSMAN_CLIENT_NO_HANDLE => 0x803380BE as u32,
            WINRM::ERROR_WSMAN_CLIENT_BLANK_URI => 0x803380BF as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR => 0x803380C0 as u32,
            WINRM::ERROR_WSMAN_CLIENT_BLANK_INPUT_XML => 0x803380C1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL => 0x803380C2 as u32,
            WINRM::ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL => 0x803380C3 as u32,
            WINRM::ERROR_WSMAN_CLIENT_BLANK_ACTION_URI => 0x803380C4 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT => 0x803380C5 as u32,
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES => 0x803380C6 as u32,
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES => 0x803380C7 as u32,
            WINRM::ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE => 0x803380C8 as u32,
            WINRM::ERROR_WSMAN_CLIENT_MISSING_EXPIRATION => 0x803380C9 as u32,
            WINRM::ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS => 0x803380CA as u32,
            WINRM::ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT => 0x803380CB as u32,
            WINRM::ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG => 0x803380CC as u32,
            WINRM::ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION => 0x803380CD as u32,
            WINRM::ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM => 0x803380CE as u32,
            WINRM::ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM => 0x803380CF as u32,
            WINRM::ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM => 0x803380D0 as u32,
            WINRM::ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM => 0x803380D1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM => 0x803380D2 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM => 0x803380D3 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM => 0x803380D4 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM => 0x803380D5 as u32,
            WINRM::ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM => 0x803380D6 as u32,
            WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY => 0x803380D7 as u32,
            WINRM::ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP => 0x803380D8 as u32,
            WINRM::ERROR_WSMAN_CONNECTIONSTR_INVALID => 0x803380D9 as u32,
            WINRM::ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED => 0x803380DA as u32,
            WINRM::ERROR_WSMAN_PORT_INVALID => 0x803380DB as u32,
            WINRM::ERROR_WSMAN_CONFIG_PORT_INVALID => 0x803380DC as u32,
            WINRM::ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR => 0x803380DD as u32,
            WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED => 0x803380DE as u32,
            WINRM::ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED => 0x803380DF as u32,
            WINRM::ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED => 0x803380E0 as u32,
            WINRM::ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED => 0x803380E1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED => 0x803380E2 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED => 0x803380E3 as u32,
            WINRM::ERROR_WSMAN_SERVER_NOT_TRUSTED => 0x803380E4 as u32,
            WINRM::ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED => 0x803380E5 as u32,
            WINRM::ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK => 0x803380E6 as u32,
            WINRM::ERROR_WSMAN_CERT_THUMBPRINT_BLANK => 0x803380E7 as u32,
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG => 0x803380E8 as u32,
            WINRM::ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME => 0x803380E9 as u32,
            WINRM::ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT => 0x803380EA as u32,
            WINRM::ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY => 0x803380EB as u32,
            WINRM::ERROR_WSMAN_INVALID_IPFILTER => 0x803380EC as u32,
            WINRM::ERROR_WSMAN_CANNOT_CHANGE_KEYS => 0x803380ED as u32,
            WINRM::ERROR_WSMAN_CERT_INVALID_USAGE => 0x803380EE as u32,
            WINRM::ERROR_WSMAN_RESPONSE_NO_RESULTS => 0x803380EF as u32,
            WINRM::ERROR_WSMAN_CREATE_RESPONSE_NO_EPR => 0x803380F0 as u32,
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT => 0x803380F1 as u32,
            WINRM::ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER => 0x803380F2 as u32,
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER => 0x803380F3 as u32,
            WINRM::ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY => 0x803380F4 as u32,
            WINRM::ERROR_WSMAN_HTTP_NO_RESPONSE_DATA => 0x803380F5 as u32,
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT => 0x803380F6 as u32,
            WINRM::ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA => 0x803380F7 as u32,
            WINRM::ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA => 0x803380F8 as u32,
            WINRM::ERROR_WSMAN_CANNOT_DECRYPT => 0x803380F9 as u32,
            WINRM::ERROR_WSMAN_INVALID_URI_WMI_SINGLETON => 0x803380FA as u32,
            WINRM::ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL => 0x803380FB as u32,
            WINRM::ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION => 0x803380FC as u32,
            WINRM::ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION => 0x803380FD as u32,
            WINRM::ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER => 0x803380FE as u32,
            WINRM::ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED => 0x803380FF as u32,
            WINRM::ERROR_WSMAN_WMI_MAX_NESTED => 0x80338100 as u32,
            WINRM::ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED => 0x80338101 as u32,
            WINRM::ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE => 0x80338102 as u32,
            WINRM::ERROR_WSMAN_WMI_INVALID_VALUE => 0x80338103 as u32,
            WINRM::ERROR_WSMAN_WMI_SVC_ACCESS_DENIED => 0x80338104 as u32,
            WINRM::ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED => 0x80338105 as u32,
            WINRM::ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED => 0x80338106 as u32,
            WINRM::ERROR_WSMAN_INVALID_FILTER_XML => 0x80338107 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY => 0x80338108 as u32,
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK => 0x80338109 as u32,
            WINRM::ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE => 0x8033810A as u32,
            WINRM::ERROR_WSMAN_KERBEROS_IPADDRESS => 0x8033810B as u32,
            WINRM::ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS => 0x8033810C as u32,
            WINRM::ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER => 0x8033810D as u32,
            WINRM::ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST => 0x8033810E as u32,
            WINRM::ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED => 0x8033810F as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT => 0x80338110 as u32,
            WINRM::ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS => 0x80338111 as u32,
            WINRM::ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS => 0x80338112 as u32,
            WINRM::ERROR_WSMAN_HTTP_NOT_FOUND_STATUS => 0x80338113 as u32,
            WINRM::ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY => 0x80338114 as u32,
            WINRM::ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED => 0x80338115 as u32,
            WINRM::ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED => 0x80338116 as u32,
            WINRM::ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED => 0x80338117 as u32,
            WINRM::ERROR_WSMAN_INVALID_SELECTOR_NAME => 0x80338118 as u32,
            WINRM::ERROR_WSMAN_ENCODING_TYPE => 0x80338119 as u32,
            WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE => 0x8033811A as u32,
            WINRM::ERROR_WSMAN_INVALID_HEADER => 0x8033811B as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE => 0x8033811C as u32,
            WINRM::ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED => 0x8033811D as u32,
            WINRM::ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER => 0x8033811E as u32,
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS => 0x8033811F as u32,
            WINRM::ERROR_WINRS_CLIENT_INVALID_FLAG => 0x80338120 as u32,
            WINRM::ERROR_WINRS_CLIENT_NULL_PARAM => 0x80338121 as u32,
            WINRM::ERROR_WSMAN_CANNOT_PROCESS_FILTER => 0x80338122 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM => 0x80338123 as u32,
            WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT => 0x80338124 as u32,
            WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_EPR => 0x80338125 as u32,
            WINRM::ERROR_WSMAN_NETWORK_TIMEDOUT => 0x80338126 as u32,
            WINRM::ERROR_WINRS_RECEIVE_IN_PROGRESS => 0x80338127 as u32,
            WINRM::ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA => 0x80338128 as u32,
            WINRM::ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM => 0x80338129 as u32,
            WINRM::ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM => 0x8033812A as u32,
            WINRM::ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM => 0x8033812B as u32,
            WINRM::ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM => 0x8033812C as u32,
            WINRM::ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM => 0x8033812D as u32,
            WINRM::ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM => 0x8033812E as u32,
            WINRM::ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM => 0x8033812F as u32,
            WINRM::ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM => 0x80338130 as u32,
            WINRM::ERROR_WINRS_CLIENT_PULL_NULL_PARAM => 0x80338131 as u32,
            WINRM::ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM => 0x80338132 as u32,
            WINRM::ERROR_WINRS_CLIENT_SEND_NULL_PARAM => 0x80338133 as u32,
            WINRM::ERROR_WINRS_CLIENT_PUSH_NULL_PARAM => 0x80338134 as u32,
            WINRM::ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM => 0x80338135 as u32,
            WINRM::ERROR_WINRS_CLIENT_GET_NULL_PARAM => 0x80338136 as u32,
            WINRM::ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED => 0x80338137 as u32,
            WINRM::ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE => 0x80338138 as u32,
            WINRM::ERROR_WSMAN_URI_NON_DMTF_CLASS => 0x80338139 as u32,
            WINRM::ERROR_WSMAN_URI_WRONG_DMTF_VERSION => 0x8033813A as u32,
            WINRM::ERROR_WSMAN_DIFFERENT_CIM_SELECTOR => 0x8033813B as u32,
            WINRM::ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT => 0x8033813C as u32,
            WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER => 0x8033813D as u32,
            WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR => 0x8033813E as u32,
            WINRM::ERROR_WSMAN_CONFIG_READONLY_PROPERTY => 0x8033813F as u32,
            WINRM::ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED => 0x80338140 as u32,
            WINRM::ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS => 0x80338141 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK => 0x80338142 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS => 0x80338143 as u32,
            WINRM::ERROR_WSMAN_MULTIPLE_CREDENTIALS => 0x80338144 as u32,
            WINRM::ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG => 0x80338145 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION => 0x80338146 as u32,
            WINRM::ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED => 0x80338147 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN => 0x80338148 as u32,
            WINRM::ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME => 0x80338149 as u32,
            WINRM::ERROR_WSMAN_SHELL_ALREADY_CLOSED => 0x8033814A as u32,
            WINRM::ERROR_WSMAN_CREATESHELL_NULL_STREAMID => 0x8033814B as u32,
            WINRM::ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE => 0x8033814C as u32,
            WINRM::ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE => 0x8033814D as u32,
            WINRM::ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT => 0x8033814E as u32,
            WINRM::ERROR_WSMAN_COMMAND_ALREADY_CLOSED => 0x8033814F as u32,
            WINRM::ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX => 0x80338150 as u32,
            WINRM::ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED => 0x80338151 as u32,
            WINRM::ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION => 0x80338152 as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED => 0x80338153 as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS => 0x80338154 as u32,
            WINRM::ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT => 0x80338155 as u32,
            WINRM::ERROR_WSMAN_CERT_MISSING_AUTH_FLAG => 0x80338156 as u32,
            WINRM::ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG => 0x80338157 as u32,
            WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_INVALID => 0x80338158 as u32,
            WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED => 0x80338159 as u32,
            WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH => 0x8033815A as u32,
            WINRM::ERROR_WINRS_SHELL_URI_INVALID => 0x8033815B as u32,
            WINRM::ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR => 0x8033815C as u32,
            WINRM::ERROR_WSMAN_POLICY_TOO_COMPLEX => 0x8033815D as u32,
            WINRM::ERROR_WSMAN_POLICY_CANNOT_COMPLY => 0x8033815E as u32,
            WINRM::ERROR_WSMAN_INVALID_CONNECTIONRETRY => 0x8033815F as u32,
            WINRM::ERROR_WSMAN_URISECURITY_INVALIDURIKEY => 0x80338160 as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY => 0x80338161 as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY => 0x80338162 as u32,
            WINRM::ERROR_WSMAN_INVALID_PUBLISHERS_TYPE => 0x80338163 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY => 0x80338164 as u32,
            WINRM::ERROR_WSMAN_CLIENT_NULL_PUBLISHERS => 0x80338165 as u32,
            WINRM::ERROR_WSMAN_CLIENT_NULL_ISSUERS => 0x80338166 as u32,
            WINRM::ERROR_WSMAN_CLIENT_NO_SOURCES => 0x80338167 as u32,
            WINRM::ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT => 0x80338168 as u32,
            WINRM::ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE => 0x80338169 as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG => 0x8033816A as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK => 0x8033816B as u32,
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE => 0x8033816C as u32,
            WINRM::ERROR_WSMAN_INVALID_PROVIDER_RESPONSE => 0x8033816D as u32,
            WINRM::ERROR_WSMAN_SHELL_NOT_INITIALIZED => 0x8033816E as u32,
            WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY => 0x8033816F as u32,
            WINRM::ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR => 0x80338170 as u32,
            WINRM::ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST => 0x80338171 as u32,
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS => 0x80338172 as u32,
            WINRM::ERROR_WSMAN_HTML_ERROR => 0x80338173 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM => 0x80338174 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG => 0x80338175 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG => 0x80338176 as u32,
            WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM => 0x80338177 as u32,
            WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM => 0x80338178 as u32,
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM => 0x80338179 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM => 0x8033817A as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG => 0x8033817B as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG => 0x8033817C as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG => 0x8033817D as u32,
            WINRM::ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM => 0x8033817E as u32,
            WINRM::ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM => 0x8033817F as u32,
            WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM => 0x80338180 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG => 0x80338181 as u32,
            WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED => 0x80338182 as u32,
            WINRM::ERROR_WSMAN_NO_COMMAND_RESPONSE => 0x80338183 as u32,
            WINRM::ERROR_WSMAN_INVALID_OPTIONSET => 0x80338184 as u32,
            WINRM::ERROR_WSMAN_NO_COMMANDID => 0x80338185 as u32,
            WINRM::ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM => 0x80338186 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG => 0x80338187 as u32,
            WINRM::ERROR_WSMAN_CLIENT_SEND_NULL_PARAM => 0x80338188 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG => 0x80338189 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER => 0x8033818A as u32,
            WINRM::ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM => 0x8033818B as u32,
            WINRM::ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM => 0x8033818C as u32,
            WINRM::ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS => 0x8033818D as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG => 0x8033818E as u32,
            WINRM::ERROR_WSMAN_NO_RECEIVE_RESPONSE => 0x8033818F as u32,
            WINRM::ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED => 0x80338190 as u32,
            WINRM::ERROR_WSMAN_INVALID_FILEPATH => 0x80338191 as u32,
            WINRM::ERROR_WSMAN_FILE_NOT_PRESENT => 0x80338192 as u32,
            WINRM::ERROR_WSMAN_IISCONFIGURATION_READ_FAILED => 0x80338193 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_LOCALE => 0x80338194 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE => 0x80338195 as u32,
            WINRM::ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM => 0x80338196 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE => 0x80338197 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG => 0x80338198 as u32,
            WINRM::ERROR_WSMAN_REDIRECT_REQUESTED => 0x80338199 as u32,
            WINRM::ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG => 0x8033819A as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION => 0x8033819B as u32,
            WINRM::ERROR_WSMAN_PROXY_ACCESS_TYPE => 0x8033819C as u32,
            WINRM::ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER => 0x8033819D as u32,
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM => 0x8033819E as u32,
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM => 0x8033819F as u32,
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM => 0x803381A0 as u32,
            WINRM::ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED => 0x803381A1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED => 0x803381A2 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS => 0x803381A3 as u32,
            WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY => 0x803381A4 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS => 0x803381A5 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS => 0x803381A6 as u32,
            WINRM::ERROR_WSMAN_QUOTA_USER => 0x803381A7 as u32,
            WINRM::ERROR_WSMAN_QUOTA_SYSTEM => 0x803381A8 as u32,
            WINRM::ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN => 0x803381A9 as u32,
            WINRM::ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE => 0x803381AA as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLUSERS => 0x803381AB as u32,
            WINRM::ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED => 0x803381AC as u32,
            WINRM::ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM => 0x803381AD as u32,
            WINRM::ERROR_WSMAN_DEPRECATED_CONFIG_SETTING => 0x803381AE as u32,
            WINRM::ERROR_WSMAN_URI_SECURITY_URI => 0x803381AF as u32,
            WINRM::ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP => 0x803381B0 as u32,
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP => 0x803381B1 as u32,
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS => 0x803381B2 as u32,
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP => 0x803381B3 as u32,
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS => 0x803381B4 as u32,
            WINRM::ERROR_WSMAN_INVALID_REDIRECT_ERROR => 0x803381B5 as u32,
            WINRM::ERROR_REDIRECT_LOCATION_TOO_LONG => 0x803381B6 as u32,
            WINRM::ERROR_REDIRECT_LOCATION_INVALID => 0x803381B7 as u32,
            WINRM::ERROR_SERVICE_CBT_HARDENING_INVALID => 0x803381B8 as u32,
            WINRM::ERROR_WSMAN_NAME_NOT_RESOLVED => 0x803381B9 as u32,
            WINRM::ERROR_WSMAN_SSL_CONNECTION_ABORTED => 0x803381BA as u32,
            WINRM::ERROR_WSMAN_DEFAULTAUTH_IPADDRESS => 0x803381BB as u32,
            WINRM::ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED => 0x803381BC as u32,
            WINRM::ERROR_WSMAN_FEATURE_DEPRECATED => 0x803381BD as u32,
            WINRM::ERROR_WSMAN_INVALID_USESSL_PARAM => 0x803381BE as u32,
            WINRM::ERROR_WSMAN_INVALID_CONFIGSDDL_URL => 0x803381BF as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED => 0x803381C0 as u32,
            WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED => 0x803381C1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID => 0x803381C2 as u32,
            WINRM::ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS => 0x803381C3 as u32,
            WINRM::ERROR_WINRS_SHELL_DISCONNECTED => 0x803381C4 as u32,
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED => 0x803381C5 as u32,
            WINRM::ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH => 0x803381C6 as u32,
            WINRM::ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM => 0x803381C7 as u32,
            WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM => 0x803381C8 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM => 0x803381C9 as u32,
            WINRM::ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM => 0x803381CA as u32,
            WINRM::ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY => 0x803381CB as u32,
            WINRM::ERROR_WSMAN_COMMAND_TERMINATED => 0x803381CC as u32,
            WINRM::ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT => 0x803381CD as u32,
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL => 0x803381CE as u32,
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID => 0x803381CF as u32,
            WINRM::ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID => 0x803381D0 as u32,
            WINRM::ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED => 0x803381D1 as u32,
            WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM => 0x803381D2 as u32,
            WINRM::ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID => 0x803381D3 as u32,
            WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID => 0x803381D4 as u32,
            WINRM::ERROR_WINRS_SHELL_CLIENTID_NOT_VALID => 0x803381D5 as u32,
            WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT => 0x803381D6 as u32,
            WINRM::ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT => 0x803381D7 as u32,
            WINRM::ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID => 0x803381D8 as u32,
            WINRM::ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY => 0x803381D9 as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG => 0x803381DA as u32,
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR => 0x803381DB as u32,
            WINRM::ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT => 0x803381DC as u32,
            WINRM::ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED => 0x803381DD as u32,
            WINRM::ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED => 0x803381DE as u32,
            WINRM::ERROR_WSMAN_CREATESHELL_RUNAS_FAILED => 0x803381DF as u32,
            WINRM::ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED => 0x803381E0 as u32,
            WINRM::ERROR_WSMAN_WRONG_METADATA => 0x803381E1 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_TYPE => 0x803381E2 as u32,
            WINRM::ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED => 0x803381E3 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ => 0x803381E4 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_USERS_PPQ => 0x803381E5 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ => 0x803381E6 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ => 0x803381E7 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ => 0x803381E8 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ => 0x803381E9 as u32,
            WINRM::ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ => 0x803381EA as u32,
            WINRM::ERROR_WSMAN_NEW_DESERIALIZER => 0x803381EB as u32,
            WINRM::ERROR_WSMAN_DESERIALIZE_CLASS => 0x803381EC as u32,
            WINRM::ERROR_WSMAN_GETCLASS => 0x803381ED as u32,
            WINRM::ERROR_WSMAN_NEW_SESSION => 0x803381EE as u32,
            WINRM::ERROR_WSMAN_NULL_KEY => 0x803381EF as u32,
            WINRM::ERROR_WSMAN_MUTUAL_AUTH_FAILED => 0x803381F0 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_OCTETTYPE => 0x803381F1 as u32,
            WINRM::ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS => 0x803381F2 as u32,
            WINRM::ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC => 0x803381F3 as u32,
            WINRM::ERROR_WSMAN_INVALID_LITERAL_URI => 0x803381F4 as u32,
            WINRM::ERROR_WSMAN_OBJECTONLY_INVALID => 0x803381F5 as u32,
            WINRM::ERROR_WSMAN_MISSING_CLASSNAME => 0x803381F6 as u32,
            WINRM::ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY => 0x803381F7 as u32,
            WINRM::ERROR_WSMAN_DESTINATION_INVALID => 0x803381F8 as u32,
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY => 0x803381F9 as u32,
            WINRM::ERROR_WSMAN_CLIENT_SESSION_UNUSABLE => 0x803381FA as u32,
        }
    }

    pub fn error(&self) -> RawError {
        return match self {
            WINRM::ERROR_WSMAN_RESOURCE_NOT_FOUND => RawError::Kind(WINRM::ERROR_WSMAN_RESOURCE_NOT_FOUND),
            WINRM::ERROR_WSMAN_INVALID_ACTIONURI => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_ACTIONURI),
            WINRM::ERROR_WSMAN_INVALID_URI => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_URI),
            WINRM::ERROR_WSMAN_PROVIDER_FAILURE => RawError::Kind(WINRM::ERROR_WSMAN_PROVIDER_FAILURE),
            WINRM::ERROR_WSMAN_BATCH_COMPLETE => RawError::Kind(WINRM::ERROR_WSMAN_BATCH_COMPLETE),
            WINRM::ERROR_WSMAN_CONFIG_CORRUPTED => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_CORRUPTED),
            WINRM::ERROR_WSMAN_PULL_IN_PROGRESS => RawError::Kind(WINRM::ERROR_WSMAN_PULL_IN_PROGRESS),
            WINRM::ERROR_WSMAN_ENUMERATION_CLOSED => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATION_CLOSED),
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSED => RawError::Kind(WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSED),
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS => RawError::Kind(WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS),
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT => RawError::Kind(WINRM::ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT),
            WINRM::ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT => RawError::Kind(WINRM::ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT),
            WINRM::ERROR_WSMAN_UNSUPPORTED_TIMEOUT => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_TIMEOUT),
            WINRM::ERROR_WSMAN_SOAP_VERSION_MISMATCH => RawError::Kind(WINRM::ERROR_WSMAN_SOAP_VERSION_MISMATCH),
            WINRM::ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN => RawError::Kind(WINRM::ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN),
            WINRM::ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER),
            WINRM::ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND => RawError::Kind(WINRM::ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND),
            WINRM::ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED => RawError::Kind(WINRM::ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED),
            WINRM::ERROR_WSMAN_DESTINATION_UNREACHABLE => RawError::Kind(WINRM::ERROR_WSMAN_DESTINATION_UNREACHABLE),
            WINRM::ERROR_WSMAN_ACTION_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_ACTION_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE => RawError::Kind(WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE),
            WINRM::ERROR_WSMAN_INVALID_REPRESENTATION => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_REPRESENTATION),
            WINRM::ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME),
            WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME),
            WINRM::ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE),
            WINRM::ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER),
            WINRM::ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT),
            WINRM::ERROR_WSMAN_ENUMERATE_TIMED_OUT => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_TIMED_OUT),
            WINRM::ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW),
            WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME),
            WINRM::ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE),
            WINRM::ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE),
            WINRM::ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS),
            WINRM::ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_MESSAGE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_MESSAGE),
            WINRM::ERROR_WSMAN_ENVELOPE_TOO_LARGE => RawError::Kind(WINRM::ERROR_WSMAN_ENVELOPE_TOO_LARGE),
            WINRM::ERROR_WSMAN_INVALID_SOAP_BODY => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SOAP_BODY),
            WINRM::ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT),
            WINRM::ERROR_WSMAN_OPERATION_TIMEDOUT => RawError::Kind(WINRM::ERROR_WSMAN_OPERATION_TIMEDOUT),
            WINRM::ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_UNSUPPORTED_ENCODING => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_ENCODING),
            WINRM::ERROR_WSMAN_URI_LIMIT => RawError::Kind(WINRM::ERROR_WSMAN_URI_LIMIT),
            WINRM::ERROR_WSMAN_INVALID_PROPOSED_ID => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_PROPOSED_ID),
            WINRM::ERROR_WSMAN_INVALID_BATCH_PARAMETER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_BATCH_PARAMETER),
            WINRM::ERROR_WSMAN_NO_ACK => RawError::Kind(WINRM::ERROR_WSMAN_NO_ACK),
            WINRM::ERROR_WSMAN_ACTION_MISMATCH => RawError::Kind(WINRM::ERROR_WSMAN_ACTION_MISMATCH),
            WINRM::ERROR_WSMAN_CONCURRENCY => RawError::Kind(WINRM::ERROR_WSMAN_CONCURRENCY),
            WINRM::ERROR_WSMAN_ALREADY_EXISTS => RawError::Kind(WINRM::ERROR_WSMAN_ALREADY_EXISTS),
            WINRM::ERROR_WSMAN_DELIVERY_REFUSED => RawError::Kind(WINRM::ERROR_WSMAN_DELIVERY_REFUSED),
            WINRM::ERROR_WSMAN_ENCODING_LIMIT => RawError::Kind(WINRM::ERROR_WSMAN_ENCODING_LIMIT),
            WINRM::ERROR_WSMAN_FAILED_AUTHENTICATION => RawError::Kind(WINRM::ERROR_WSMAN_FAILED_AUTHENTICATION),
            WINRM::ERROR_WSMAN_INCOMPATIBLE_EPR => RawError::Kind(WINRM::ERROR_WSMAN_INCOMPATIBLE_EPR),
            WINRM::ERROR_WSMAN_INVALID_BOOKMARK => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_BOOKMARK),
            WINRM::ERROR_WSMAN_INVALID_OPTIONS => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_OPTIONS),
            WINRM::ERROR_WSMAN_INVALID_PARAMETER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_PARAMETER),
            WINRM::ERROR_WSMAN_INVALID_RESOURCE_URI => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_RESOURCE_URI),
            WINRM::ERROR_WSMAN_INVALID_SYSTEM => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SYSTEM),
            WINRM::ERROR_WSMAN_INVALID_SELECTORS => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SELECTORS),
            WINRM::ERROR_WSMAN_METADATA_REDIRECT => RawError::Kind(WINRM::ERROR_WSMAN_METADATA_REDIRECT),
            WINRM::ERROR_WSMAN_QUOTA_LIMIT => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_LIMIT),
            WINRM::ERROR_WSMAN_RENAME_FAILURE => RawError::Kind(WINRM::ERROR_WSMAN_RENAME_FAILURE),
            WINRM::ERROR_WSMAN_SCHEMA_VALIDATION_ERROR => RawError::Kind(WINRM::ERROR_WSMAN_SCHEMA_VALIDATION_ERROR),
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE),
            WINRM::ERROR_WSMAN_INVALID_XML => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_XML),
            WINRM::ERROR_WSMAN_INVALID_KEY => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_KEY),
            WINRM::ERROR_WSMAN_DELIVER_IN_PROGRESS => RawError::Kind(WINRM::ERROR_WSMAN_DELIVER_IN_PROGRESS),
            WINRM::ERROR_WSMAN_SYSTEM_NOT_FOUND => RawError::Kind(WINRM::ERROR_WSMAN_SYSTEM_NOT_FOUND),
            WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE => RawError::Kind(WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE),
            WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED => RawError::Kind(WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED),
            WINRM::ERROR_WSMAN_SERVER_ENVELOPE_LIMIT => RawError::Kind(WINRM::ERROR_WSMAN_SERVER_ENVELOPE_LIMIT),
            WINRM::ERROR_WSMAN_SELECTOR_LIMIT => RawError::Kind(WINRM::ERROR_WSMAN_SELECTOR_LIMIT),
            WINRM::ERROR_WSMAN_OPTION_LIMIT => RawError::Kind(WINRM::ERROR_WSMAN_OPTION_LIMIT),
            WINRM::ERROR_WSMAN_CHARACTER_SET => RawError::Kind(WINRM::ERROR_WSMAN_CHARACTER_SET),
            WINRM::ERROR_WSMAN_UNREPORTABLE_SUCCESS => RawError::Kind(WINRM::ERROR_WSMAN_UNREPORTABLE_SUCCESS),
            WINRM::ERROR_WSMAN_WHITESPACE => RawError::Kind(WINRM::ERROR_WSMAN_WHITESPACE),
            WINRM::ERROR_WSMAN_FILTERING_REQUIRED => RawError::Kind(WINRM::ERROR_WSMAN_FILTERING_REQUIRED),
            WINRM::ERROR_WSMAN_BOOKMARK_EXPIRED => RawError::Kind(WINRM::ERROR_WSMAN_BOOKMARK_EXPIRED),
            WINRM::ERROR_WSMAN_OPTIONS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_OPTIONS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_OPTIONS_INVALID_NAME => RawError::Kind(WINRM::ERROR_WSMAN_OPTIONS_INVALID_NAME),
            WINRM::ERROR_WSMAN_OPTIONS_INVALID_VALUE => RawError::Kind(WINRM::ERROR_WSMAN_OPTIONS_INVALID_VALUE),
            WINRM::ERROR_WSMAN_PARAMETER_TYPE_MISMATCH => RawError::Kind(WINRM::ERROR_WSMAN_PARAMETER_TYPE_MISMATCH),
            WINRM::ERROR_WSMAN_INVALID_PARAMETER_NAME => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_PARAMETER_NAME),
            WINRM::ERROR_WSMAN_INVALID_XML_VALUES => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_XML_VALUES),
            WINRM::ERROR_WSMAN_INVALID_XML_MISSING_VALUES => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_XML_MISSING_VALUES),
            WINRM::ERROR_WSMAN_INVALID_XML_NAMESPACE => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_XML_NAMESPACE),
            WINRM::ERROR_WSMAN_INVALID_XML_FRAGMENT => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_XML_FRAGMENT),
            WINRM::ERROR_WSMAN_INSUFFCIENT_SELECTORS => RawError::Kind(WINRM::ERROR_WSMAN_INSUFFCIENT_SELECTORS),
            WINRM::ERROR_WSMAN_UNEXPECTED_SELECTORS => RawError::Kind(WINRM::ERROR_WSMAN_UNEXPECTED_SELECTORS),
            WINRM::ERROR_WSMAN_SELECTOR_TYPEMISMATCH => RawError::Kind(WINRM::ERROR_WSMAN_SELECTOR_TYPEMISMATCH),
            WINRM::ERROR_WSMAN_INVALID_SELECTOR_VALUE => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SELECTOR_VALUE),
            WINRM::ERROR_WSMAN_AMBIGUOUS_SELECTORS => RawError::Kind(WINRM::ERROR_WSMAN_AMBIGUOUS_SELECTORS),
            WINRM::ERROR_WSMAN_DUPLICATE_SELECTORS => RawError::Kind(WINRM::ERROR_WSMAN_DUPLICATE_SELECTORS),
            WINRM::ERROR_WSMAN_INVALID_TARGET_SELECTORS => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_TARGET_SELECTORS),
            WINRM::ERROR_WSMAN_INVALID_TARGET_RESOURCEURI => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_TARGET_RESOURCEURI),
            WINRM::ERROR_WSMAN_INVALID_TARGET_SYSTEM => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_TARGET_SYSTEM),
            WINRM::ERROR_WSMAN_TARGET_ALREADY_EXISTS => RawError::Kind(WINRM::ERROR_WSMAN_TARGET_ALREADY_EXISTS),
            WINRM::ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_ACK_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_ACK_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_LOCALE_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_LOCALE_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_MAXTIME_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_MAXTIME_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_BAD_METHOD => RawError::Kind(WINRM::ERROR_WSMAN_BAD_METHOD),
            WINRM::ERROR_WSMAN_UNSUPPORTED_MEDIA => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_MEDIA),
            WINRM::ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE),
            WINRM::ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_ENUMERATION_INITIALIZING => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATION_INITIALIZING),
            WINRM::ERROR_WSMAN_CONNECTOR_GET => RawError::Kind(WINRM::ERROR_WSMAN_CONNECTOR_GET),
            WINRM::ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR => RawError::Kind(WINRM::ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR),
            WINRM::ERROR_WSMAN_INEXISTENT_MAC_ADDRESS => RawError::Kind(WINRM::ERROR_WSMAN_INEXISTENT_MAC_ADDRESS),
            WINRM::ERROR_WSMAN_NO_UNICAST_ADDRESSES => RawError::Kind(WINRM::ERROR_WSMAN_NO_UNICAST_ADDRESSES),
            WINRM::ERROR_WSMAN_NO_DHCP_ADDRESSES => RawError::Kind(WINRM::ERROR_WSMAN_NO_DHCP_ADDRESSES),
            WINRM::ERROR_WSMAN_MIN_ENVELOPE_SIZE => RawError::Kind(WINRM::ERROR_WSMAN_MIN_ENVELOPE_SIZE),
            WINRM::ERROR_WSMAN_EPR_NESTING_EXCEEDED => RawError::Kind(WINRM::ERROR_WSMAN_EPR_NESTING_EXCEEDED),
            WINRM::ERROR_WSMAN_REQUEST_INIT_ERROR => RawError::Kind(WINRM::ERROR_WSMAN_REQUEST_INIT_ERROR),
            WINRM::ERROR_WSMAN_INVALID_TIMEOUT_HEADER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_TIMEOUT_HEADER),
            WINRM::ERROR_WSMAN_CERT_NOT_FOUND => RawError::Kind(WINRM::ERROR_WSMAN_CERT_NOT_FOUND),
            WINRM::ERROR_WSMAN_PLUGIN_FAILED => RawError::Kind(WINRM::ERROR_WSMAN_PLUGIN_FAILED),
            WINRM::ERROR_WSMAN_ENUMERATION_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATION_INVALID),
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL),
            WINRM::ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED),
            WINRM::ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED),
            WINRM::ERROR_WSMAN_POLICY_CORRUPTED => RawError::Kind(WINRM::ERROR_WSMAN_POLICY_CORRUPTED),
            WINRM::ERROR_WSMAN_LISTENER_ADDRESS_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_LISTENER_ADDRESS_INVALID),
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING),
            WINRM::ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE),
            WINRM::ERROR_WSMAN_EVENTING_FAST_SENDER => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_FAST_SENDER),
            WINRM::ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE),
            WINRM::ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER),
            WINRM::ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE => RawError::Kind(WINRM::ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE),
            WINRM::ERROR_WSMAN_MISSING_FRAGMENT_PATH => RawError::Kind(WINRM::ERROR_WSMAN_MISSING_FRAGMENT_PATH),
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_DIALECT => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_FRAGMENT_DIALECT),
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH),
            WINRM::ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE),
            WINRM::ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER),
            WINRM::ERROR_WSMAN_SESSION_ALREADY_CLOSED => RawError::Kind(WINRM::ERROR_WSMAN_SESSION_ALREADY_CLOSED),
            WINRM::ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID => RawError::Kind(WINRM::ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID),
            WINRM::ERROR_WSMAN_PROVIDER_LOAD_FAILED => RawError::Kind(WINRM::ERROR_WSMAN_PROVIDER_LOAD_FAILED),
            WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE),
            WINRM::ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE),
            WINRM::ERROR_WSMAN_SECURITY_UNMAPPED => RawError::Kind(WINRM::ERROR_WSMAN_SECURITY_UNMAPPED),
            WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE),
            WINRM::ERROR_WSMAN_INVALID_HOSTNAME_PATTERN => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_HOSTNAME_PATTERN),
            WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO),
            WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT),
            WINRM::ERROR_WSMAN_MACHINE_OPTION_REQUIRED => RawError::Kind(WINRM::ERROR_WSMAN_MACHINE_OPTION_REQUIRED),
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS),
            WINRM::ERROR_WSMAN_BATCHSIZE_TOO_SMALL => RawError::Kind(WINRM::ERROR_WSMAN_BATCHSIZE_TOO_SMALL),
            WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID),
            WINRM::ERROR_WSMAN_PROVSYS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_PROVSYS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID),
            WINRM::ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS),
            WINRM::ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH),
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS),
            WINRM::ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED),
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME),
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED),
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED),
            WINRM::ERROR_WSMAN_CLIENT_CERT_NEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CERT_NEEDED),
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE),
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT),
            WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS),
            WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS),
            WINRM::ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_NO_HANDLE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_NO_HANDLE),
            WINRM::ERROR_WSMAN_CLIENT_BLANK_URI => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_BLANK_URI),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR),
            WINRM::ERROR_WSMAN_CLIENT_BLANK_INPUT_XML => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_BLANK_INPUT_XML),
            WINRM::ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL),
            WINRM::ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL),
            WINRM::ERROR_WSMAN_CLIENT_BLANK_ACTION_URI => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_BLANK_ACTION_URI),
            WINRM::ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT),
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES),
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES),
            WINRM::ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE),
            WINRM::ERROR_WSMAN_CLIENT_MISSING_EXPIRATION => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MISSING_EXPIRATION),
            WINRM::ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS),
            WINRM::ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT),
            WINRM::ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG),
            WINRM::ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION),
            WINRM::ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM),
            WINRM::ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY),
            WINRM::ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP),
            WINRM::ERROR_WSMAN_CONNECTIONSTR_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_CONNECTIONSTR_INVALID),
            WINRM::ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_PORT_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_PORT_INVALID),
            WINRM::ERROR_WSMAN_CONFIG_PORT_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_PORT_INVALID),
            WINRM::ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR => RawError::Kind(WINRM::ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR),
            WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED),
            WINRM::ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED),
            WINRM::ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED),
            WINRM::ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED),
            WINRM::ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED),
            WINRM::ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED),
            WINRM::ERROR_WSMAN_SERVER_NOT_TRUSTED => RawError::Kind(WINRM::ERROR_WSMAN_SERVER_NOT_TRUSTED),
            WINRM::ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED => RawError::Kind(WINRM::ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED),
            WINRM::ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK => RawError::Kind(WINRM::ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK),
            WINRM::ERROR_WSMAN_CERT_THUMBPRINT_BLANK => RawError::Kind(WINRM::ERROR_WSMAN_CERT_THUMBPRINT_BLANK),
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG),
            WINRM::ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME),
            WINRM::ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT),
            WINRM::ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY),
            WINRM::ERROR_WSMAN_INVALID_IPFILTER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_IPFILTER),
            WINRM::ERROR_WSMAN_CANNOT_CHANGE_KEYS => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_CHANGE_KEYS),
            WINRM::ERROR_WSMAN_CERT_INVALID_USAGE => RawError::Kind(WINRM::ERROR_WSMAN_CERT_INVALID_USAGE),
            WINRM::ERROR_WSMAN_RESPONSE_NO_RESULTS => RawError::Kind(WINRM::ERROR_WSMAN_RESPONSE_NO_RESULTS),
            WINRM::ERROR_WSMAN_CREATE_RESPONSE_NO_EPR => RawError::Kind(WINRM::ERROR_WSMAN_CREATE_RESPONSE_NO_EPR),
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT => RawError::Kind(WINRM::ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT),
            WINRM::ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER => RawError::Kind(WINRM::ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER),
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER => RawError::Kind(WINRM::ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER),
            WINRM::ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY => RawError::Kind(WINRM::ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY),
            WINRM::ERROR_WSMAN_HTTP_NO_RESPONSE_DATA => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_NO_RESPONSE_DATA),
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT => RawError::Kind(WINRM::ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT),
            WINRM::ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA),
            WINRM::ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA),
            WINRM::ERROR_WSMAN_CANNOT_DECRYPT => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_DECRYPT),
            WINRM::ERROR_WSMAN_INVALID_URI_WMI_SINGLETON => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_URI_WMI_SINGLETON),
            WINRM::ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL),
            WINRM::ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION => RawError::Kind(WINRM::ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION),
            WINRM::ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION => RawError::Kind(WINRM::ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION),
            WINRM::ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER),
            WINRM::ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_WMI_MAX_NESTED => RawError::Kind(WINRM::ERROR_WSMAN_WMI_MAX_NESTED),
            WINRM::ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE => RawError::Kind(WINRM::ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE),
            WINRM::ERROR_WSMAN_WMI_INVALID_VALUE => RawError::Kind(WINRM::ERROR_WSMAN_WMI_INVALID_VALUE),
            WINRM::ERROR_WSMAN_WMI_SVC_ACCESS_DENIED => RawError::Kind(WINRM::ERROR_WSMAN_WMI_SVC_ACCESS_DENIED),
            WINRM::ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED => RawError::Kind(WINRM::ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED),
            WINRM::ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED => RawError::Kind(WINRM::ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED),
            WINRM::ERROR_WSMAN_INVALID_FILTER_XML => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_FILTER_XML),
            WINRM::ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY),
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK),
            WINRM::ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE),
            WINRM::ERROR_WSMAN_KERBEROS_IPADDRESS => RawError::Kind(WINRM::ERROR_WSMAN_KERBEROS_IPADDRESS),
            WINRM::ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS),
            WINRM::ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER),
            WINRM::ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST => RawError::Kind(WINRM::ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST),
            WINRM::ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED => RawError::Kind(WINRM::ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED),
            WINRM::ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT),
            WINRM::ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS),
            WINRM::ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS),
            WINRM::ERROR_WSMAN_HTTP_NOT_FOUND_STATUS => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_NOT_FOUND_STATUS),
            WINRM::ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY),
            WINRM::ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED => RawError::Kind(WINRM::ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED),
            WINRM::ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED => RawError::Kind(WINRM::ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED),
            WINRM::ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED => RawError::Kind(WINRM::ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED),
            WINRM::ERROR_WSMAN_INVALID_SELECTOR_NAME => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SELECTOR_NAME),
            WINRM::ERROR_WSMAN_ENCODING_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_ENCODING_TYPE),
            WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE => RawError::Kind(WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE),
            WINRM::ERROR_WSMAN_INVALID_HEADER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_HEADER),
            WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE),
            WINRM::ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER => RawError::Kind(WINRM::ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER),
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS),
            WINRM::ERROR_WINRS_CLIENT_INVALID_FLAG => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_INVALID_FLAG),
            WINRM::ERROR_WINRS_CLIENT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_NULL_PARAM),
            WINRM::ERROR_WSMAN_CANNOT_PROCESS_FILTER => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_PROCESS_FILTER),
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM),
            WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT => RawError::Kind(WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT),
            WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_EPR => RawError::Kind(WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_EPR),
            WINRM::ERROR_WSMAN_NETWORK_TIMEDOUT => RawError::Kind(WINRM::ERROR_WSMAN_NETWORK_TIMEDOUT),
            WINRM::ERROR_WINRS_RECEIVE_IN_PROGRESS => RawError::Kind(WINRM::ERROR_WINRS_RECEIVE_IN_PROGRESS),
            WINRM::ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA => RawError::Kind(WINRM::ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA),
            WINRM::ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_PULL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_PULL_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_SEND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_SEND_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_PUSH_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_PUSH_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM),
            WINRM::ERROR_WINRS_CLIENT_GET_NULL_PARAM => RawError::Kind(WINRM::ERROR_WINRS_CLIENT_GET_NULL_PARAM),
            WINRM::ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED),
            WINRM::ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE => RawError::Kind(WINRM::ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE),
            WINRM::ERROR_WSMAN_URI_NON_DMTF_CLASS => RawError::Kind(WINRM::ERROR_WSMAN_URI_NON_DMTF_CLASS),
            WINRM::ERROR_WSMAN_URI_WRONG_DMTF_VERSION => RawError::Kind(WINRM::ERROR_WSMAN_URI_WRONG_DMTF_VERSION),
            WINRM::ERROR_WSMAN_DIFFERENT_CIM_SELECTOR => RawError::Kind(WINRM::ERROR_WSMAN_DIFFERENT_CIM_SELECTOR),
            WINRM::ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT => RawError::Kind(WINRM::ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT),
            WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER),
            WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR),
            WINRM::ERROR_WSMAN_CONFIG_READONLY_PROPERTY => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_READONLY_PROPERTY),
            WINRM::ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK),
            WINRM::ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS),
            WINRM::ERROR_WSMAN_MULTIPLE_CREDENTIALS => RawError::Kind(WINRM::ERROR_WSMAN_MULTIPLE_CREDENTIALS),
            WINRM::ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION),
            WINRM::ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN),
            WINRM::ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME => RawError::Kind(WINRM::ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME),
            WINRM::ERROR_WSMAN_SHELL_ALREADY_CLOSED => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_ALREADY_CLOSED),
            WINRM::ERROR_WSMAN_CREATESHELL_NULL_STREAMID => RawError::Kind(WINRM::ERROR_WSMAN_CREATESHELL_NULL_STREAMID),
            WINRM::ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE),
            WINRM::ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE),
            WINRM::ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT => RawError::Kind(WINRM::ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT),
            WINRM::ERROR_WSMAN_COMMAND_ALREADY_CLOSED => RawError::Kind(WINRM::ERROR_WSMAN_COMMAND_ALREADY_CLOSED),
            WINRM::ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX => RawError::Kind(WINRM::ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX),
            WINRM::ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED),
            WINRM::ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION => RawError::Kind(WINRM::ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION),
            WINRM::ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED),
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS),
            WINRM::ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT => RawError::Kind(WINRM::ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT),
            WINRM::ERROR_WSMAN_CERT_MISSING_AUTH_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CERT_MISSING_AUTH_FLAG),
            WINRM::ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG),
            WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_INVALID),
            WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED),
            WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH),
            WINRM::ERROR_WINRS_SHELL_URI_INVALID => RawError::Kind(WINRM::ERROR_WINRS_SHELL_URI_INVALID),
            WINRM::ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR),
            WINRM::ERROR_WSMAN_POLICY_TOO_COMPLEX => RawError::Kind(WINRM::ERROR_WSMAN_POLICY_TOO_COMPLEX),
            WINRM::ERROR_WSMAN_POLICY_CANNOT_COMPLY => RawError::Kind(WINRM::ERROR_WSMAN_POLICY_CANNOT_COMPLY),
            WINRM::ERROR_WSMAN_INVALID_CONNECTIONRETRY => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_CONNECTIONRETRY),
            WINRM::ERROR_WSMAN_URISECURITY_INVALIDURIKEY => RawError::Kind(WINRM::ERROR_WSMAN_URISECURITY_INVALIDURIKEY),
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY),
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY),
            WINRM::ERROR_WSMAN_INVALID_PUBLISHERS_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_PUBLISHERS_TYPE),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY),
            WINRM::ERROR_WSMAN_CLIENT_NULL_PUBLISHERS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_NULL_PUBLISHERS),
            WINRM::ERROR_WSMAN_CLIENT_NULL_ISSUERS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_NULL_ISSUERS),
            WINRM::ERROR_WSMAN_CLIENT_NO_SOURCES => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_NO_SOURCES),
            WINRM::ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT),
            WINRM::ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE => RawError::Kind(WINRM::ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE),
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG),
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK),
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE => RawError::Kind(WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE),
            WINRM::ERROR_WSMAN_INVALID_PROVIDER_RESPONSE => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_PROVIDER_RESPONSE),
            WINRM::ERROR_WSMAN_SHELL_NOT_INITIALIZED => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_NOT_INITIALIZED),
            WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY),
            WINRM::ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR),
            WINRM::ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST => RawError::Kind(WINRM::ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST),
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS),
            WINRM::ERROR_WSMAN_HTML_ERROR => RawError::Kind(WINRM::ERROR_WSMAN_HTML_ERROR),
            WINRM::ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED),
            WINRM::ERROR_WSMAN_NO_COMMAND_RESPONSE => RawError::Kind(WINRM::ERROR_WSMAN_NO_COMMAND_RESPONSE),
            WINRM::ERROR_WSMAN_INVALID_OPTIONSET => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_OPTIONSET),
            WINRM::ERROR_WSMAN_NO_COMMANDID => RawError::Kind(WINRM::ERROR_WSMAN_NO_COMMANDID),
            WINRM::ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_SEND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SEND_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER),
            WINRM::ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM),
            WINRM::ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM),
            WINRM::ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS => RawError::Kind(WINRM::ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG),
            WINRM::ERROR_WSMAN_NO_RECEIVE_RESPONSE => RawError::Kind(WINRM::ERROR_WSMAN_NO_RECEIVE_RESPONSE),
            WINRM::ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED => RawError::Kind(WINRM::ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED),
            WINRM::ERROR_WSMAN_INVALID_FILEPATH => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_FILEPATH),
            WINRM::ERROR_WSMAN_FILE_NOT_PRESENT => RawError::Kind(WINRM::ERROR_WSMAN_FILE_NOT_PRESENT),
            WINRM::ERROR_WSMAN_IISCONFIGURATION_READ_FAILED => RawError::Kind(WINRM::ERROR_WSMAN_IISCONFIGURATION_READ_FAILED),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_LOCALE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_LOCALE),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE),
            WINRM::ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG),
            WINRM::ERROR_WSMAN_REDIRECT_REQUESTED => RawError::Kind(WINRM::ERROR_WSMAN_REDIRECT_REQUESTED),
            WINRM::ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION),
            WINRM::ERROR_WSMAN_PROXY_ACCESS_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_PROXY_ACCESS_TYPE),
            WINRM::ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER),
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM),
            WINRM::ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED => RawError::Kind(WINRM::ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED),
            WINRM::ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED),
            WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS),
            WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY),
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS),
            WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS),
            WINRM::ERROR_WSMAN_QUOTA_USER => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_USER),
            WINRM::ERROR_WSMAN_QUOTA_SYSTEM => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_SYSTEM),
            WINRM::ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN => RawError::Kind(WINRM::ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN),
            WINRM::ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE => RawError::Kind(WINRM::ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE),
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLUSERS => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLUSERS),
            WINRM::ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED => RawError::Kind(WINRM::ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED),
            WINRM::ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM => RawError::Kind(WINRM::ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM),
            WINRM::ERROR_WSMAN_DEPRECATED_CONFIG_SETTING => RawError::Kind(WINRM::ERROR_WSMAN_DEPRECATED_CONFIG_SETTING),
            WINRM::ERROR_WSMAN_URI_SECURITY_URI => RawError::Kind(WINRM::ERROR_WSMAN_URI_SECURITY_URI),
            WINRM::ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP),
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP),
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS),
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP => RawError::Kind(WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP),
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS),
            WINRM::ERROR_WSMAN_INVALID_REDIRECT_ERROR => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_REDIRECT_ERROR),
            WINRM::ERROR_REDIRECT_LOCATION_TOO_LONG => RawError::Kind(WINRM::ERROR_REDIRECT_LOCATION_TOO_LONG),
            WINRM::ERROR_REDIRECT_LOCATION_INVALID => RawError::Kind(WINRM::ERROR_REDIRECT_LOCATION_INVALID),
            WINRM::ERROR_SERVICE_CBT_HARDENING_INVALID => RawError::Kind(WINRM::ERROR_SERVICE_CBT_HARDENING_INVALID),
            WINRM::ERROR_WSMAN_NAME_NOT_RESOLVED => RawError::Kind(WINRM::ERROR_WSMAN_NAME_NOT_RESOLVED),
            WINRM::ERROR_WSMAN_SSL_CONNECTION_ABORTED => RawError::Kind(WINRM::ERROR_WSMAN_SSL_CONNECTION_ABORTED),
            WINRM::ERROR_WSMAN_DEFAULTAUTH_IPADDRESS => RawError::Kind(WINRM::ERROR_WSMAN_DEFAULTAUTH_IPADDRESS),
            WINRM::ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED => RawError::Kind(WINRM::ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED),
            WINRM::ERROR_WSMAN_FEATURE_DEPRECATED => RawError::Kind(WINRM::ERROR_WSMAN_FEATURE_DEPRECATED),
            WINRM::ERROR_WSMAN_INVALID_USESSL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_USESSL_PARAM),
            WINRM::ERROR_WSMAN_INVALID_CONFIGSDDL_URL => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_CONFIGSDDL_URL),
            WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED),
            WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED => RawError::Kind(WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED),
            WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID),
            WINRM::ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS => RawError::Kind(WINRM::ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS),
            WINRM::ERROR_WINRS_SHELL_DISCONNECTED => RawError::Kind(WINRM::ERROR_WINRS_SHELL_DISCONNECTED),
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED => RawError::Kind(WINRM::ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED),
            WINRM::ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH => RawError::Kind(WINRM::ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH),
            WINRM::ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM),
            WINRM::ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM),
            WINRM::ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY => RawError::Kind(WINRM::ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY),
            WINRM::ERROR_WSMAN_COMMAND_TERMINATED => RawError::Kind(WINRM::ERROR_WSMAN_COMMAND_TERMINATED),
            WINRM::ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT => RawError::Kind(WINRM::ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT),
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL => RawError::Kind(WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL),
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID => RawError::Kind(WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID),
            WINRM::ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID => RawError::Kind(WINRM::ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID),
            WINRM::ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED => RawError::Kind(WINRM::ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED),
            WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM),
            WINRM::ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID => RawError::Kind(WINRM::ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID),
            WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID => RawError::Kind(WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID),
            WINRM::ERROR_WINRS_SHELL_CLIENTID_NOT_VALID => RawError::Kind(WINRM::ERROR_WINRS_SHELL_CLIENTID_NOT_VALID),
            WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT => RawError::Kind(WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT),
            WINRM::ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT => RawError::Kind(WINRM::ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT),
            WINRM::ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID => RawError::Kind(WINRM::ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID),
            WINRM::ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY => RawError::Kind(WINRM::ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG),
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR),
            WINRM::ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT => RawError::Kind(WINRM::ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT),
            WINRM::ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED),
            WINRM::ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED => RawError::Kind(WINRM::ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED),
            WINRM::ERROR_WSMAN_CREATESHELL_RUNAS_FAILED => RawError::Kind(WINRM::ERROR_WSMAN_CREATESHELL_RUNAS_FAILED),
            WINRM::ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED),
            WINRM::ERROR_WSMAN_WRONG_METADATA => RawError::Kind(WINRM::ERROR_WSMAN_WRONG_METADATA),
            WINRM::ERROR_WSMAN_UNSUPPORTED_TYPE => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_TYPE),
            WINRM::ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED => RawError::Kind(WINRM::ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED),
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ),
            WINRM::ERROR_WSMAN_QUOTA_MAX_USERS_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_USERS_PPQ),
            WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ),
            WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ),
            WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ),
            WINRM::ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ),
            WINRM::ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ => RawError::Kind(WINRM::ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ),
            WINRM::ERROR_WSMAN_NEW_DESERIALIZER => RawError::Kind(WINRM::ERROR_WSMAN_NEW_DESERIALIZER),
            WINRM::ERROR_WSMAN_DESERIALIZE_CLASS => RawError::Kind(WINRM::ERROR_WSMAN_DESERIALIZE_CLASS),
            WINRM::ERROR_WSMAN_GETCLASS => RawError::Kind(WINRM::ERROR_WSMAN_GETCLASS),
            WINRM::ERROR_WSMAN_NEW_SESSION => RawError::Kind(WINRM::ERROR_WSMAN_NEW_SESSION),
            WINRM::ERROR_WSMAN_NULL_KEY => RawError::Kind(WINRM::ERROR_WSMAN_NULL_KEY),
            WINRM::ERROR_WSMAN_MUTUAL_AUTH_FAILED => RawError::Kind(WINRM::ERROR_WSMAN_MUTUAL_AUTH_FAILED),
            WINRM::ERROR_WSMAN_UNSUPPORTED_OCTETTYPE => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_OCTETTYPE),
            WINRM::ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS => RawError::Kind(WINRM::ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS),
            WINRM::ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC => RawError::Kind(WINRM::ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC),
            WINRM::ERROR_WSMAN_INVALID_LITERAL_URI => RawError::Kind(WINRM::ERROR_WSMAN_INVALID_LITERAL_URI),
            WINRM::ERROR_WSMAN_OBJECTONLY_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_OBJECTONLY_INVALID),
            WINRM::ERROR_WSMAN_MISSING_CLASSNAME => RawError::Kind(WINRM::ERROR_WSMAN_MISSING_CLASSNAME),
            WINRM::ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY => RawError::Kind(WINRM::ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY),
            WINRM::ERROR_WSMAN_DESTINATION_INVALID => RawError::Kind(WINRM::ERROR_WSMAN_DESTINATION_INVALID),
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY => RawError::Kind(WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY),
            WINRM::ERROR_WSMAN_CLIENT_SESSION_UNUSABLE => RawError::Kind(WINRM::ERROR_WSMAN_CLIENT_SESSION_UNUSABLE),
        }
    }

    pub fn description(&self) -> &'static str {
        return match self {
            WINRM::ERROR_WSMAN_RESOURCE_NOT_FOUND => "The WS-Management service cannot process the request. The service cannot find the resource identified by the resource URI and selectors.",
            WINRM::ERROR_WSMAN_INVALID_ACTIONURI => "The WS-Management service cannot process the request. The WS-Addressing action URI is invalid. Check the documentation for information on how to construct an action URI.",
            WINRM::ERROR_WSMAN_INVALID_URI => "The WS-Management service cannot process the request. The resource URI is missing or it has an incorrect format. Check the documentation or use the following command for information on how to construct a resource URI: 'winrm help uris'.",
            WINRM::ERROR_WSMAN_PROVIDER_FAILURE => "An error was encountered inside the plugin.",
            WINRM::ERROR_WSMAN_BATCH_COMPLETE => "The WS-Management service cannot complete the request. The WSManEnumerator object is full and no more items can be added.",
            WINRM::ERROR_WSMAN_CONFIG_CORRUPTED => "The WS-Management configuration is corrupted. Use the following command to restore defaults: %n%n winrm invoke Restore http://schemas.microsoft.com/wbem/wsman/1/config @{} %n%n Then add any custom configuration settings.",
            WINRM::ERROR_WSMAN_PULL_IN_PROGRESS => "The WS-Management service cannot process a pull request because a pull operation is already in progress.",
            WINRM::ERROR_WSMAN_ENUMERATION_CLOSED => "The WS-Management enumeration session is finished or cancelled and cannot be used. Start a new enumeration.",
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSED => "The event subscription is already closed and cannot be used. Start a new subscription.",
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS => "The event subscription session is closing and cannot be used. Start a new subscription.",
            WINRM::ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT => "The application or script that has an event subscription did not request a pull operation within the heartbeat interval. The subscription session was closed. Start a new subscription.",
            WINRM::ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT => "The event source did not return events within the heartbeat interval. The subscription session was closed. Start a new subscription.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_TIMEOUT => "The WS-Management service does not support the specified timeout. The value specified is smaller than the minimum allowed value for this setting. Change the timeout value and try the request again.",
            WINRM::ERROR_WSMAN_SOAP_VERSION_MISMATCH => "The WS-Management service does not support the SOAP version specified in the request.",
            WINRM::ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN => "The WS-Management service does not support the encoding specified in the request.",
            WINRM::ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER => "The WS-Management service cannot process the request. The request contains one or more invalid SOAP headers.",
            WINRM::ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND => "The WS-Management service cannot process a SOAP header in the request that is marked as mustUnderstand by the client. This could be caused by the use of a version of the protocol which is not supported, or may be an incompatibility between the client and server implementations.",
            WINRM::ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED => "The WS-Management service cannot process the request. The request does not have all the expected SOAP headers.",
            WINRM::ERROR_WSMAN_DESTINATION_UNREACHABLE => "The client cannot connect to the destination specified in the request. Verify that the service on the destination is running and is accepting requests. Consult the logs and documentation for the WS-Management service running on the destination, most commonly IIS or WinRM. If the destination is the WinRM service, run the following command on the destination to analyze and configure the WinRM service: 'winrm quickconfig'.",
            WINRM::ERROR_WSMAN_ACTION_NOT_SUPPORTED => "The WS-Management service does not support the action specified in the request.",
            WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE => "The WS-Management service cannot process the request because the resource is offline. Retry the request later when the resource is online.",
            WINRM::ERROR_WSMAN_INVALID_REPRESENTATION => "The WS-Management service cannot identify the format of the object passed to a Put or Create method. The input XML may not be appropriate for the resource or uses the wrong schema for the resource. Change the input XML in the request.",
            WINRM::ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME => "The expiration time passed to the WS-Management Enumerate method is not valid. The time value may be zero or refer to a time in the past. Change the expiration time and try the request again.",
            WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME => "The data source does not support expiration time. Remove the expiration time from the request and try the request again.",
            WINRM::ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED => "The data source does not support filtering. Remove the filter from the request and try the request again.",
            WINRM::ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE => "The filter dialect (the type associated with the filter) was not supported for this resource. Change the filter dialect or remove it from the request and try the request again.",
            WINRM::ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER => "The data source could not process the filter. The filter might be missing or it might be invalid. Change the filter and try the request again.",
            WINRM::ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT => "The WS-Enumeration context in the enumeration is not valid. Enumeration may have been completed or canceled. You cannot use this enumeration context anymore. Start a new enumeration.",
            WINRM::ERROR_WSMAN_ENUMERATE_TIMED_OUT => "The pull operation did not get any data in the MaxTime duration. But the enumeration is still valid. The client can attempt to do another pull request to retrieve data.",
            WINRM::ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW => "The WS-Management service cannot renew the enumeration. Start a new enumeration.",
            WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE => "The WS-Management service does not support the delivery mode for the specified resource. The client should change the subscription to use one of the supported delivery modes.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME => "The expiration time of the subscription is invalid. The time is either not supported, zero or a time that happened in the past. Change the expiration time and try the request again.",
            WINRM::ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE => "The expiration time specified for subscription was invalid. Specify the expiration time as a duration.",
            WINRM::ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED => "The event source does not support filtering. Remove the filter from the request and try the request again.",
            WINRM::ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE => "The event source cannot process the specified filter. Change the filter or remove it from the request and try the request again.",
            WINRM::ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS => "The event source cannot process the subscription.",
            WINRM::ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW => "The WS-Management service cannot renew the event subscription. Create a new subscription.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_MESSAGE => "The WS-Management service cannot complete the WS-Eventing request because the request had some unknown or invalid content and could not be processed.",
            WINRM::ERROR_WSMAN_ENVELOPE_TOO_LARGE => "The WS-Management service cannot process the response because it is larger than the maximum size allowed.",
            WINRM::ERROR_WSMAN_INVALID_SOAP_BODY => "The WS-Management service cannot process the request because the request packet does not have a valid SOAP body.",
            WINRM::ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT => "The resumption context specified in the subscription is invalid. It may have expired, or be in the wrong format.",
            WINRM::ERROR_WSMAN_OPERATION_TIMEDOUT => "The WS-Management service cannot complete the operation within the time specified in OperationTimeout.",
            WINRM::ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED => "The event source does not support subscriptions that can be resumed.",
            WINRM::ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED => "The WS-Management service does not support the type of resumption requested by the subscription.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_ENCODING => "The request contains character encoding that is unsupported. WS-Management only supports requests that are encoded in UTF-8 or UTF-16. Change the character encoding in the request and try the request again.",
            WINRM::ERROR_WSMAN_URI_LIMIT => "The URI is longer than the maximum length allowed.",
            WINRM::ERROR_WSMAN_INVALID_PROPOSED_ID => "The WS-Management service cannot process the request because the subscription ID is invalid.",
            WINRM::ERROR_WSMAN_INVALID_BATCH_PARAMETER => "The WS-Management service cannot process the batch request. The request must specify either MaxItems, MaxCharacters, or MaxTime.",
            WINRM::ERROR_WSMAN_NO_ACK => "The receiver of the event did not acknowledge the event delivery. Submit the subscription again without the acknowledgement option.",
            WINRM::ERROR_WSMAN_ACTION_MISMATCH => "The WS-Management service cannot process the request because the WS-Addressing Action URI in the request is not compatible with the resource.",
            WINRM::ERROR_WSMAN_CONCURRENCY => "The WS-Management service cannot complete the WS-Addressing Action URI in the request because the resource was already in use.",
            WINRM::ERROR_WSMAN_ALREADY_EXISTS => "The WS-Management service cannot create the resource because it already exists.",
            WINRM::ERROR_WSMAN_DELIVERY_REFUSED => "The WS-Management service cannot complete the request because the receiver does not accept the delivery of events. The receiver requests that the subscription be cancelled. Event receivers return this message to force the cancellation of a subscription.",
            WINRM::ERROR_WSMAN_ENCODING_LIMIT => "The WS-Management service cannot process the request because the encoding of the request exceeds an internal encoding limit. Reconfigure the client to send messages which fit the encoding limits of the service.",
            WINRM::ERROR_WSMAN_FAILED_AUTHENTICATION => "The WS-Management service cannot authenticate the sender.",
            WINRM::ERROR_WSMAN_INCOMPATIBLE_EPR => "The WS-Management service does not support the format of the WS-Addressing Endpoint Reference.",
            WINRM::ERROR_WSMAN_INVALID_BOOKMARK => "The bookmark in the subscription is invalid. The bookmark may be expired or corrupted. Issue a new subscription without any bookmarks or locate the correct bookmark.",
            WINRM::ERROR_WSMAN_INVALID_OPTIONS => "The WS-Management service cannot process the request because one or more options are not valid. The option names or values may not be valid or they are used in incorrect combinations. Retrieve the catalog entry for the resource and determine how to correct the invalid option values.",
            WINRM::ERROR_WSMAN_INVALID_PARAMETER => "The WS-Management service cannot process the request because a parameter for the operation is not valid.",
            WINRM::ERROR_WSMAN_INVALID_RESOURCE_URI => "The WS-Management service cannot process the request. The resource URI is missing or it has an incorrect format. Check the documentation or use the following command for information on how to construct a resource URI: 'winrm help uris'.",
            WINRM::ERROR_WSMAN_INVALID_SYSTEM => "The WS-Management service requires a valid System URI to process the request.",
            WINRM::ERROR_WSMAN_INVALID_SELECTORS => "The WS-Management service cannot process the request because the selectors for the resource are not valid.",
            WINRM::ERROR_WSMAN_METADATA_REDIRECT => "The requested metadata is not available at the current address. Retry the request with a new address.",
            WINRM::ERROR_WSMAN_QUOTA_LIMIT => "The WS-Management service is busy servicing other requests. Retry later.",
            WINRM::ERROR_WSMAN_RENAME_FAILURE => "The WS-Management service cannot rename the resource. The selectors for the resource are not correct. The resource may exist already, the address may be incorrect, or the resource URI may be invalid. Change the request and retry.",
            WINRM::ERROR_WSMAN_SCHEMA_VALIDATION_ERROR => "The SOAP XML in the message does not match the corresponding XML schema definition. Change the XML and retry.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE => "The WS-Management service does not support the specified feature. Remove the unsupported feature from the request and retry.",
            WINRM::ERROR_WSMAN_INVALID_XML => "The WS-Management service cannot process the request because the XML is invalid.",
            WINRM::ERROR_WSMAN_INVALID_KEY => "The WS-Management service cannot process the request because the URI contains an unexpected selector.",
            WINRM::ERROR_WSMAN_DELIVER_IN_PROGRESS => "The event source is attempting to deliver an event when a delivery is in progress already.",
            WINRM::ERROR_WSMAN_SYSTEM_NOT_FOUND => "The WS-Management service cannot locate the system.",
            WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE => "The maximum envelope size in the request is too large. Change the maximum envelope size and try the request again.",
            WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED => "The response that the WS-Management service computed exceeds the maximum envelope size in the request.",
            WINRM::ERROR_WSMAN_SERVER_ENVELOPE_LIMIT => "The response that the WS-Management service computed exceed the internal limit for envelope size.",
            WINRM::ERROR_WSMAN_SELECTOR_LIMIT => "The WS-Management service cannot process the request because the URI contains too many selectors.",
            WINRM::ERROR_WSMAN_OPTION_LIMIT => "The WS-Management service cannot process the request because it contains too many options.",
            WINRM::ERROR_WSMAN_CHARACTER_SET => "The WS-Management service does not support the character set used in the request. Change the request to use UTF-8 or UTF-16.",
            WINRM::ERROR_WSMAN_UNREPORTABLE_SUCCESS => "The operation succeeded and cannot be reversed but the result is too large to send.",
            WINRM::ERROR_WSMAN_WHITESPACE => "The WS-Management service does not support white space in the request XML.",
            WINRM::ERROR_WSMAN_FILTERING_REQUIRED => "The WS-Management service does not support the filter dialect in the request. The filter dialect is the type of filter, such as XPath or WQL.",
            WINRM::ERROR_WSMAN_BOOKMARK_EXPIRED => "The WS-Management service cannot process the request because it contains a bookmark that is expired.",
            WINRM::ERROR_WSMAN_OPTIONS_NOT_SUPPORTED => "The WS-Management provider does not support the specified option set because mustComply for one of the options is set to true. Change mustComply for one of the options to false.",
            WINRM::ERROR_WSMAN_OPTIONS_INVALID_NAME => "The WS-Management service cannot process the request because one or more of the options has an invalid name.",
            WINRM::ERROR_WSMAN_OPTIONS_INVALID_VALUE => "The WS-Management service cannot process the request because one or more of the options has an invalid value.",
            WINRM::ERROR_WSMAN_PARAMETER_TYPE_MISMATCH => "The WS-Management service cannot process the request. A parameter that is required for the operation is not the correct type.",
            WINRM::ERROR_WSMAN_INVALID_PARAMETER_NAME => "The WS-Management service cannot process the request. A parameter name is invalid.",
            WINRM::ERROR_WSMAN_INVALID_XML_VALUES => "The WS-Management service cannot process the request because the XML content has invalid values.",
            WINRM::ERROR_WSMAN_INVALID_XML_MISSING_VALUES => "The WS-Management service cannot process the request because the XML content has missing values.",
            WINRM::ERROR_WSMAN_INVALID_XML_NAMESPACE => "The WS-Management service cannot identify the format of the object passed to a Put or Create method. The XML namespace for the input XML is invalid. Change the XML namespace for the input XML in the request.",
            WINRM::ERROR_WSMAN_INVALID_XML_FRAGMENT => "The WS-Management service cannot process the request because an XML fragment in the URI is invalid.",
            WINRM::ERROR_WSMAN_INSUFFCIENT_SELECTORS => "The WS-Management service cannot process the request because the request did not contain all required selectors.",
            WINRM::ERROR_WSMAN_UNEXPECTED_SELECTORS => "The WS-Management service cannot process the request because the request contained invalid selectors for the resource.",
            WINRM::ERROR_WSMAN_SELECTOR_TYPEMISMATCH => "The WS-Management service cannot process the request because a value for a selector is of the wrong type.",
            WINRM::ERROR_WSMAN_INVALID_SELECTOR_VALUE => "The WS-Management service cannot process the request because a value for the selector is invalid.",
            WINRM::ERROR_WSMAN_AMBIGUOUS_SELECTORS => "The WS-Management service cannot process the request because the selectors for the resource are ambiguous.",
            WINRM::ERROR_WSMAN_DUPLICATE_SELECTORS => "The WS-Management service cannot process the request because the request contains duplicate selectors.",
            WINRM::ERROR_WSMAN_INVALID_TARGET_SELECTORS => "The WS-Management service cannot process the request because the request contains invalid selectors for the target resource.",
            WINRM::ERROR_WSMAN_INVALID_TARGET_RESOURCEURI => "The WS-Management service cannot process the request because the request contains an invalid URI for the target resource.",
            WINRM::ERROR_WSMAN_INVALID_TARGET_SYSTEM => "The WS-Management service cannot process the request because the request contains an invalid target system.",
            WINRM::ERROR_WSMAN_TARGET_ALREADY_EXISTS => "The WS-Management service cannot process a Create request because the target already exists.",
            WINRM::ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED => "The WS-Management service does not support the mode of authorization.",
            WINRM::ERROR_WSMAN_ACK_NOT_SUPPORTED => "The client does not support acknowledgment.",
            WINRM::ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED => "The data source does not support timeouts for the operation.",
            WINRM::ERROR_WSMAN_LOCALE_NOT_SUPPORTED => "The WS-Management service does not support the locale.",
            WINRM::ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED => "The WS-Management service does not support the expiration time.",
            WINRM::ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED => "The WS-Management service does not retry deliveries.",
            WINRM::ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED => "The event source does not support heartbeats.",
            WINRM::ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED => "The event source does not support bookmarks.",
            WINRM::ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED => "The WS-Management service does not support the configuration for MaxItems.",
            WINRM::ERROR_WSMAN_MAXTIME_NOT_SUPPORTED => "The WS-Management service does not support the configuration for MaxTime.",
            WINRM::ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED => "The WS-Management service does not support the value in the configuration for MaxEnvelopeSize.",
            WINRM::ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED => "The event source does not support the MaxEnvelopePolicy.",
            WINRM::ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED => "The WS-Management service does not support unfiltered enumeration.",
            WINRM::ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED => "The WS-Management service does not support insecure addresses.",
            WINRM::ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED => "The WS-Management service does not support format mismatch.",
            WINRM::ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED => "The WS-Management service does not support the format of the security token.",
            WINRM::ERROR_WSMAN_BAD_METHOD => "The service returned a response that indicates that the method is unsupported.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_MEDIA => "The WS-Management service does not support the specified media type.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE => "The WS-Management service does not support the addressing mode.",
            WINRM::ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED => "The WS-Management service does not support fragment transfer.",
            WINRM::ERROR_WSMAN_ENUMERATION_INITIALIZING => "The client sent a request before the enumeration was initialized.",
            WINRM::ERROR_WSMAN_CONNECTOR_GET => "The WS-Management service failed to locate the component that can process the request.",
            WINRM::ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR => "A syntax error occurred in the query string for the resource URI.",
            WINRM::ERROR_WSMAN_INEXISTENT_MAC_ADDRESS => "The MAC that is configured is not in the list of enabled DHCP adapters on the computer.",
            WINRM::ERROR_WSMAN_NO_UNICAST_ADDRESSES => "The MAC address that is configured does not have any unicast addresses.",
            WINRM::ERROR_WSMAN_NO_DHCP_ADDRESSES => "The WS-Management service cannot find the dynamic IP address on the adapter with the configured MAC address.",
            WINRM::ERROR_WSMAN_MIN_ENVELOPE_SIZE => "The WS-Management service cannot process the request because the envelope size in the request is too small.",
            WINRM::ERROR_WSMAN_EPR_NESTING_EXCEEDED => "The WS-Management service cannot process the request. The EndPointReference contains more nested EndPointReferences than WS-Management supports.",
            WINRM::ERROR_WSMAN_REQUEST_INIT_ERROR => "The WS-Management service cannot initialize the request.",
            WINRM::ERROR_WSMAN_INVALID_TIMEOUT_HEADER => "The WS-Management service cannot process the request because the timeout header in the request is invalid.",
            WINRM::ERROR_WSMAN_CERT_NOT_FOUND => "The WS-Management service cannot find the certificate that was requested.",
            WINRM::ERROR_WSMAN_PLUGIN_FAILED => "The WS-Management service cannot process the request. The data source failed to return results for the request.",
            WINRM::ERROR_WSMAN_ENUMERATION_INVALID => "The enumeration is invalid because previous Pull request failed.",
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL => "The WS-Management service cannot change a mutual configuration.",
            WINRM::ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED => "The WS-Management service does not support the specified enumeration mode.",
            WINRM::ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED => "The WS-Management service cannot guarantee that all data is returned in the requested locale as some data sources may not be able to comply. Resend the remote request with locale as a hint (the SOAP header should have mustUnderstand='false')",
            WINRM::ERROR_WSMAN_POLICY_CORRUPTED => "The WSMan group policy configuration is corrupted.",
            WINRM::ERROR_WSMAN_LISTENER_ADDRESS_INVALID => "The listener address specified is invalid. The address can be specified in one of the following formats: *, IP:<ip_address>, MAC:<mac_address>. Change the listener address and try the request again.",
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING => "Cannot change GPO controlled setting.",
            WINRM::ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE => "The client is attempting to concurrently receive events from a single subscription session.This is not supported.",
            WINRM::ERROR_WSMAN_EVENTING_FAST_SENDER => "The source is sending event batches faster than the subscriber can consume. This can happen if acknowledgments are not specified for the subscription and new events are arriving from the source before the client has consumed them.",
            WINRM::ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION => "The source is sending events in a connection that did not match the security restrictions imposed by the client.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE => "The WS-Management client cannot process the request. The event source identity does not match the identity of the machine that the client subscribed to.",
            WINRM::ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER => "The client could not start a valid listener to receive subscription events based on the specified input settings.",
            WINRM::ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE => "The fragment path dialect is not supported for this resource.",
            WINRM::ERROR_WSMAN_MISSING_FRAGMENT_PATH => "Cannot execute the Fragment-Level operation. The fragment path cannot be missing if the fragment dialect is specified.",
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_DIALECT => "Cannot execute the Fragment-Level operation because of invalid value for the fragment dialect.",
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH => "Cannot execute the Fragment-Level operation because the fragment path is invalid. Check the syntax of the fragment path string. Also check the spelling and the case of the property names in the fragment path string: they have to match the spelling and the case of the resource properties.",
            WINRM::ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE => "The specified batch parameter is incompatible with the specified event delivery mode. This can happen if batchSettings for a specific mode are passed for a different mode. For example, batchSettings like 'MaxItems' and 'MaxLatency' are not compatible with single event push mode or pull mode.",
            WINRM::ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED => "The connectivity test from the push subscription source to the client failed. This can happen if the client machine initiating the push subscription is unreachable from the server machine where the event source is located. Possible reasons include firewall or some other network boundary. Modify subscription to use Pull based subscription.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS => "The subscribe packet had an EndTo element address that does not match the NotifyTo element address or it was invalid. For subscription the EndTo element need not be present in the subscription request. If it exists then it's address should match the address specified in NotifyTo element.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER => "The event source sent an event packet whose header could not be processed by the client. This can happen if it was malformed or if the header had a mustUnderstand attribute that could not be understood by the client.",
            WINRM::ERROR_WSMAN_SESSION_ALREADY_CLOSED => "An operation is being attempted on a session that is being closed.This can happen if the session that is being used is also being closed by another thread.",
            WINRM::ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID => "The listener on which the subscription session was established is no longer valid. This can happen if the WSMAN service listener configuration has been changed and a subscription was already active and using one of the configurations that was deleted.",
            WINRM::ERROR_WSMAN_PROVIDER_LOAD_FAILED => "The system failed to load the plugin.",
            WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE => "The WS-Management service on the remote machine with which this subscription had been set up has requested that the subscription be closed. This can happen if the WS-Management service on the remote machine was being shutdown. To correct this problem restart the WS-Management service on the remote machine and re-create the subscription.",
            WINRM::ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE => "The event source was unable to deliver events to the client.This can happen due to network issues preventing the source from connecting to the client.",
            WINRM::ERROR_WSMAN_SECURITY_UNMAPPED => "An unknown security error occurred.",
            WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE => "The event source cancelled the subscription session.",
            WINRM::ERROR_WSMAN_INVALID_HOSTNAME_PATTERN => "TrustedHosts list contains an invalid hostname or hostname pattern.",
            WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO => "The subscribe packet does not have NotifyTo element in the delivery section.",
            WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS => "The subscribe packet does not have Address element in the NotifyTo section.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS => "The subscribe packet contains invalid Address in the NotifyTo section.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY => "The subscribe packet contains invalid Locale value in the delivery section.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT => "The subscribe packet contains invalid heartbeat value.",
            WINRM::ERROR_WSMAN_MACHINE_OPTION_REQUIRED => "The WS-Management service cannot process the request. This request is valid only when the -remote option is specified.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS => "The WS-Management service does not support the options feature for the specified resource. Remove the options from the request and retry.",
            WINRM::ERROR_WSMAN_BATCHSIZE_TOO_SMALL => "The subscribe packet contains batch size value which is smaller than supported value.",
            WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID => "The WS-Management service cannot process the subscribe request. The delivery mode is either invalid or missing.",
            WINRM::ERROR_WSMAN_PROVSYS_NOT_SUPPORTED => "The WS-Management service cannot process the request. The provider method was not found.",
            WINRM::ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID => "The WinRM client could not create a push subscription because there are no listeners configured that match the specified hostname and transport, or because there is no enabled firewall exception on the port used by the selected listener. Change the hostname and transport, create an appropriate firewall exception, or run winrm quickconfig.",
            WINRM::ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG => "The WinRM client could not process the request because credentials were specified along with the 'no authentication' flag. No user name, password or client certificate should be specified with the 'no authentication' option.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for this request. Remove or change the invalid flag and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS => "The WinRM client cannot process the request. The request must specify only one authentication mechanism. If the No Authentication flag is set, no authentication mechanism should be specified. Change the request to specify only one authentication mechanism or 'no authentication' and try again.",
            WINRM::ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH => "The WinRM client cannot process the request. The SPN Server Port can only be used when the authentication mechanism is Negotiate or Kerberos. Remove the SPN Server Port or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS => "The WinRM client cannot process the request. The request must not include credentials when using a smart card or default certificate. Remove the credentials or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED => "The WinRM client cannot process the request. Requests must include user name and password when Basic or Digest authentication mechanism is used. Add the user name and password or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME => "The WinRM client cannot process the request. Requests must not include user name and password when a certificate is used for authentication. Remove the user name and password or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED => "The WinRM client cannot process the request. Requests must include credentials if they specify the following flag: WSManFlagCredUsernamePassword. Add the credentials or remove the WSManFlagCredUsernamePassword flag and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED => "The WinRM client cannot process the request. Requests with credentials must include the following flag: WSManFlagCredUsernamePassword. Add the flag or remove the credentials and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CERT_NEEDED => "The WinRM client cannot process the request. Requests must include the certificate thumbprint when a certificate is used for authentication. Change the request to include the certificate thumbprint and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE => "The WinRM client cannot process the request. Requests must include the type of certificate to use for authentication. Change the request to include the type of the certificate and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION => "The WinRM client cannot process the request. Requests must include the location (machine or user certificate store) of the certificate used for authentication. Change the request to include the location of the certificate and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT => "The WinRM client cannot process the request. The certificate structure was incomplete. Change the certificate structure and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS => "The WinRM client cannot process the request. Credentials must not be provided for local requests. Remove the credentials and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS => "The WinRM client cannot process the request. Connection options must not be provided for local requests. Remove the connection options and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManCreateSession function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManEnumerate function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManSubscribe function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM => "The WinRM client cannot process the request. The parameter that should contain the result of the request is null. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_NO_HANDLE => "The WinRM client cannot process the request. The request is missing the session or enumeration handle. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_BLANK_URI => "The WinRM client cannot process the request. The resource URI must not be '' (blank or empty string) or NULL. Change the resource URI and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR => "The WinRM client cannot process the request. The resource locator was invalid. Change the resource locator and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_BLANK_INPUT_XML => "The WinRM client cannot process the request. The input XML must not be '' (blank or empty string) or NULL. Change the input XML and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL => "The WinRM client cannot process the request. The maximum number of elements to be retrieved in a batch is too small. Change the value for the maximum number of elements in a batch and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL => "The WinRM client cannot process the request. The maximum number of characters to be retrieved in a batch is too small. Change the value for the maximum number of characters in a batch and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_BLANK_ACTION_URI => "The WinRM client cannot process the request. The action URI must not be '' (blank or empty string) or NULL. Change the action URI and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT => "The WinRM client cannot process the request. The heartbeat interval must be greater than 0. Change the heartbeat interval and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES => "The WinRM client cannot process the request. The request must contain one and only one delivery mode. Change the request to contain only one delivery mode and try again.",
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES => "The WinRM client cannot process the request. The request contained multiple settings for the policy regarding the maximum envelope size. Change the request to contain only one setting for the policy and try again.",
            WINRM::ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE => "The WinRM client cannot process the request. The request contained an expiration time, but did not specify if it was absolute or relative. Change the request to specify the type of the expiration time (absolute or relative) and try again.",
            WINRM::ERROR_WSMAN_CLIENT_MISSING_EXPIRATION => "The WinRM client cannot process the request. The request specified the type of the expiration time (absolute or relative) but it did not contain an expiration time. Change the request to include the expiration time and try again.",
            WINRM::ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS => "The WinRM client cannot process the request. The pull subscription request contained flags related to a push subscription. Change the flags and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT => "The WinRM client cannot process the request because the push subscription request contained an unsupported delivery transport. HTTP and HTTPS are the only currently supported transports. Change the delivery transport and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG => "The WinRM client cannot process the request. The delivery address for push subscriptions was too long. Change the delivery address and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION => "The WinRM client cannot process the request. The request contained the compression option but contained an unrecognized value. Change the value for the compression option and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManDeliverEndSubscriptionNotification function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManDeliverEvents function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManGetBookmark function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManDecodeObject function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManEncodeObject(Ex) function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManEnumeratorAddObject function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManEnumeratorNextObject function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManConstructError function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM => "The WinRM service cannot process the request. Push subscriptions are not supported for local session. Change subscription type to Pull and try again.",
            WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY => "The WinRM client cannot process the request. The unencrypted flag only applies to the HTTP transport. Remove the unencrypted flag or change the transport and try again the request.",
            WINRM::ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP => "The WinRM client cannot process the request. Certificate parameters are not valid when the HTTP transport is also specified. Remove the certificate parameters or change the transport and try again the request.",
            WINRM::ERROR_WSMAN_CONNECTIONSTR_INVALID => "The WinRM client cannot process the request. The connection string should be of the form [<transport>://]<host>[:<port>][/<suffix>] where transport is one of 'http' or 'https'. Transport, port and suffix are optional. The host may be a hostname or an IP address. For IPv6 addresses, enclose the address in brackets - e.g. 'http://[1::2]:80/wsman'. Change the connection string and try the request again.",
            WINRM::ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED => "The WinRM client cannot process the request. The connection string contains an unsupported transport. Valid transports are 'http' or 'https'. Change the connection string and try the request again.",
            WINRM::ERROR_WSMAN_PORT_INVALID => "The WinRM client cannot process the request because the port specified in the connection string is not valid. Verify the port and retry the request. Valid values are between 1 and 65535. Change the value for port and try the request again.",
            WINRM::ERROR_WSMAN_CONFIG_PORT_INVALID => "The WinRM client cannot process the request. The port specified in the configuration is invalid. Valid values are between 1 and 65535. Change the value for port and try the request again.",
            WINRM::ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR => "The WinRM service cannot process the request. WSMAN_FLAG_SEND_HEARTBEAT flag requires the event enumerator to be empty. Change the flag or change the event enumerator and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED => "The WinRM client cannot process the request. Unencrypted traffic is currently disabled in the client configuration. Change the client configuration and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED => "The WinRM client cannot process the request. Basic authentication is currently disabled in the client configuration. Change the client configuration and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED => "The WinRM client cannot process the request. Digest authentication is currently disabled in the client configuration. Change the client configuration and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED => "The WinRM client cannot process the request. Negotiate authentication is currently disabled in the client configuration. Change the client configuration and try the request again. If this is a request for the local configuration, use one of the enabled authentication mechanisms still enabled. To use Kerberos, specify the local computer name as the remote destination. To use Basic, specify the local computer name as the remote destination, specify Basic authentication and provide user name and password.",
            WINRM::ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED => "The WinRM client cannot process the request. Kerberos authentication is currently disabled in the client configuration. Change the client configuration and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED => "The WinRM client cannot process the request. Certificate authentication is currently disabled in the client configuration. Change the client configuration and try the request again.",
            WINRM::ERROR_WSMAN_SERVER_NOT_TRUSTED => "The WinRM client cannot process the request. If the authentication scheme is different from Kerberos, or if the client computer is not joined to a domain, then HTTPS transport must be used or the destination machine must be added to the TrustedHosts configuration setting. Use winrm.cmd to configure TrustedHosts. Note that computers in the TrustedHosts list might not be authenticated. You can get more information about that by running the following command: winrm help config.",
            WINRM::ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED => "The WinRM client cannot process the request. Default credentials with Negotiate over HTTP can be used only if the target machine is part of the TrustedHosts list or the Allow implicit credentials for Negotiate option is specified.",
            WINRM::ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK => "The WinRM client cannot process the request. The CertificateThumbprint property must be empty when the SSL configuration will be shared with another service.",
            WINRM::ERROR_WSMAN_CERT_THUMBPRINT_BLANK => "The WinRM client cannot process the request. The CertificateThumbprint property must not be '' (blank or empty string) or NULL.",
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG => "The WinRM client cannot process the request. The WinRM client tried to create an SSL configuration for a pair of IP address and port according to the request, but the SSL configuration for that pair is owned by another service and cannot be shared. Use a different IP address and port combination and try the request again.",
            WINRM::ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME => "The WinRM client cannot process the request. The certificate CN and the hostname that were provided do not match.",
            WINRM::ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT => "<not used>",
            WINRM::ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY => "The WinRM client cannot process the request. When HTTP is the transport, the Certificate thumbprint must be blank. HTTP does not use the Certificate thumbprint.",
            WINRM::ERROR_WSMAN_INVALID_IPFILTER => "The WinRM client cannot process the request. The IP Filter is invalid. Ranges are specified using the syntax IP1-IP2. Multiple ranges are separated using , as delimiter. * is used to indicate that the service should listen on all available IPs on the machine. When * is used, other ranges in the filter are ignored. If filter is blank, the service doesn't listen on any address. For example, if service should be restricted to listen on only IPv4 addresses, IPv6 filter should be left empty. %nExample IPv4 filters: 2.0.0.1-2.0.0.20, 24.0.0.1-24.0.0.22 %n Example IPv6 filters: 3FFE:FFFF:7654:FEDA:1245:BA98:0000:0000-3FFE:FFFF:7654:FEDA:1245:BA98:3210:4562",
            WINRM::ERROR_WSMAN_CANNOT_CHANGE_KEYS => "The WinRM client cannot process the request. The input XML modifies selectors or keys for the instance. You cannot create a new instance or change the identity of an instance by changing the keys. Change the input XML and try the request again.",
            WINRM::ERROR_WSMAN_CERT_INVALID_USAGE => "The WinRM client cannot process the request. The Enhanced Key Usage (EKU) field of the certificate is not set to 'Server Authentication'. Retry the request with a certificate that has the correct EKU.",
            WINRM::ERROR_WSMAN_RESPONSE_NO_RESULTS => "The WinRM client cannot process the request. The response from the destination computer does not include any results.",
            WINRM::ERROR_WSMAN_CREATE_RESPONSE_NO_EPR => "The WinRM client cannot process the request. The response to a create request did not contain a valid end point reference. The ResourceCreated element was not found or did not contain valid content.",
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT => "The WinRM client cannot process the request. The response from the destination computer does not contain a valid SOAP enumeration context.",
            WINRM::ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER => "The WinRM client cannot process the request. The response from the destination computer contains a WS-Management FragmentTransfer header but the content of the body is not wrapped by the WS-Management XmlFragment wrapper.",
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER => "The WinRM client cannot process the request. The response from the destination computer contains one or more invalid SOAP headers.",
            WINRM::ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY => "The WinRM client cannot process the request. It cannot find any SOAP Headers or Body elements in the response from the destination computer.",
            WINRM::ERROR_WSMAN_HTTP_NO_RESPONSE_DATA => "The WinRM client cannot process the request. The destination computer returned an empty response to the request.",
            WINRM::ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT => "The WinRM client cannot process the request. The destination computer returned an invalid SOAP fault.",
            WINRM::ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA => "The WinRM client cannot process the request. It cannot determine the content type of the HTTP response from the destination computer. The content type is absent or invalid.",
            WINRM::ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA => "The WinRM client cannot process the request. The HTTP response from the destination computer was not in the same format as the request. A Unicode request packet may have been sent and an ANSI packet received.",
            WINRM::ERROR_WSMAN_CANNOT_DECRYPT => "The WinRM client cannot process the request. The encrypted message body has an invalid format and cannot be decrypted. Ensure that the service is encrypting the message body according to the specifications.",
            WINRM::ERROR_WSMAN_INVALID_URI_WMI_SINGLETON => "The WinRM client cannot process the request. The resource URI is not valid: it does not contain keys, but the class selected is not a singleton. To access an instance which is not a singleton, keys must be provided. Use the following command to get more information in how to construct a resource URI: 'winrm help uris'.",
            WINRM::ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL => "The WinRM client cannot process the request. The resource URI for an enumeration operation with WQL filter must not contain keys and the class name must be '*' (star). Use the following command to get more information in how to construct a resource URI: 'winrm help uris'.",
            WINRM::ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION => "The WS-Management identification operation is only available on remote sessions.",
            WINRM::ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION => "Subscribe operation with Push delivery mode is only available on remote sessions.",
            WINRM::ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER => "The subscription manager address is invalid. The response was not received from the address to which the subscription request was sent.",
            WINRM::ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED => "Only subscriptions with Pull delivery mode are supported by the plugin.",
            WINRM::ERROR_WSMAN_WMI_MAX_NESTED => "WinRM cannot process the request because the WMI object contains too many levels of nested embedded objects.",
            WINRM::ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED => "The WS-Management service cannot process the request. It does not support retrieving a WMI object that contains a property of type CIM_REFERENCE and the value of that property contains a remote machine name.",
            WINRM::ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE => "The WS-Management service cannot process the request. The WMI service reported that the WMI provider could not perform the requested operation.",
            WINRM::ERROR_WSMAN_WMI_INVALID_VALUE => "The WS-Management service cannot process the request. A value retrieved from the WMI service or the WMI provider is invalid.",
            WINRM::ERROR_WSMAN_WMI_SVC_ACCESS_DENIED => "The WS-Management service cannot process the request. The WMI service returned an 'access denied' error.",
            WINRM::ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED => "The WS-Management service cannot process the request. The WMI provider returned an 'access denied' error.",
            WINRM::ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED => "The WS-Management service cannot process the request. An 'access denied' error was received when connecting to the WMI service on the computer specified.",
            WINRM::ERROR_WSMAN_INVALID_FILTER_XML => "The WS-Management service cannot process the request because the filter XML is invalid.",
            WINRM::ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY => "The WS-Management service cannot process the request. The resource URI for an Enumerate operation must not contain keys.",
            WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK => "Cannot execute the Fragment-Level operation because the fragment path contains either '' (blank or empty string) or NULL. Change the value of the fragment path and try the request again.",
            WINRM::ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE => "The WinRM client cannot process the request. The response received from the destination machine contains invalid characters and cannot be processed.",
            WINRM::ERROR_WSMAN_KERBEROS_IPADDRESS => "The WinRM client cannot process the request. Kerberos authentication cannot be used when the destination is an IP address. Specify a DNS or NetBIOS destination or specify Basic or Negotiate authentication.",
            WINRM::ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS => "The WinRM client cannot process the request. Kerberos authentication cannot be used with implicit credentials if the client computer is not joined to a domain. Use explicit credentials or specify a different authentication mechanism than Kerberos.",
            WINRM::ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER => "The WinRM client cannot process the request. The batch settings parameter is invalid.",
            WINRM::ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST => "The WinRM client cannot process the request. If you do not specify an authentication mechanism or you specify Kerberos, then you cannot use 'localhost' or '127.0.0.1' or '[::1]' for the remote host name. You can explicitly specify a different authentication mechanism than Kerberos or specify the remote host as a DNS name or NetBIOS name.",
            WINRM::ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED => "The WinRM client received an unknown HTTP status code from the remote WS-Management service.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT => "The WinRM client received a HTTP redirect status code from the remote WS-Management service. WinRM does not support redirects.",
            WINRM::ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS => "The WinRM client sent a request to the remote WS-Management service and was notified that the request size exceeded the configured MaxEnvelopeSize quota.",
            WINRM::ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS => "The connection to the specified remote host was refused. Verify that the WS-Management service is running on the remote host and configured to listen for requests on the correct port and HTTP URL.",
            WINRM::ERROR_WSMAN_HTTP_NOT_FOUND_STATUS => "The WinRM client sent a request to an HTTP server and got a response saying the requested HTTP URL was not available. This is usually returned by a HTTP server that does not support the WS-Management protocol.",
            WINRM::ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY => "The subscribe packet had a Locale element with missing lang attribute. The lang attribute is required for the Locale element.",
            WINRM::ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED => "Cannot create a WinRM listener on HTTPS because this machine does not have an appropriate certificate. To be used for SSL, a certificate must have a CN matching the hostname, be appropriate for Server Authentication, and not be expired, revoked, or self-signed.",
            WINRM::ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED => "Firewall does not allow exceptions; WinRM cannot be setup for remote access.",
            WINRM::ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED => "The Windows Remote Management (WinRM) service cannot be configured for remote access because Group Policy does not allow local firewall changes. Check the Group Policy settings to allow local firewall exceptions and add WinRM to the firewall exceptions.",
            WINRM::ERROR_WSMAN_INVALID_SELECTOR_NAME => "The WinRM client cannot process the request because the selector name is not valid. Change the selector name and retry the request.",
            WINRM::ERROR_WSMAN_ENCODING_TYPE => "The WS-Management service does not support the encoding type specified.",
            WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE => "The WS-Management service cannot process the request because the selector values do not match a known resource, or the resource is offline. Retry the request later when the resource is online, or try a different selector.",
            WINRM::ERROR_WSMAN_INVALID_HEADER => "The WS-Management service cannot process the request because the a header in the request is invalid.",
            WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE => "The expiration time specified for enumeration was invalid. Specify the expiration time as a duration.",
            WINRM::ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED => "The WS-Management service received a request which specified a maximum number of elements, but the service does not support this feature. Retry the request without this element specified.",
            WINRM::ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER => "The WS-Management service cannot process the request. The WMI provider returned an 'invalid parameter' error.",
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS => "The WinRM client cannot process the request. The request must contain one and only one enumeration mode. Change the request to contain only one enumeration mode and try again.",
            WINRM::ERROR_WINRS_CLIENT_INVALID_FLAG => "The WinRS client cannot process the request. An invalid flag was specified for this request. Remove or change the invalid flag and try the request again.",
            WINRM::ERROR_WINRS_CLIENT_NULL_PARAM => "The WinRS client cannot process the request. One of the parameters required is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CANNOT_PROCESS_FILTER => "The data source could not process the filter. The filter might be missing, invalid or too complex to process. If a service only supports a subset of a filter dialect (such as XPath level 1), it may return this fault for valid filter expressions outside of the supported subset. Change the filter and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManEnumeratorAddEvent function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT => "The WinRM client cannot process the request. The object parameter for the WSManEnumeratorAddObject function is null or zero, but the enumeration mode is Object or ObjectAndEPR.",
            WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_EPR => "The WinRM client cannot process the request. The EPR parameter for the WSManEnumeratorAddObject function is null or zero, but the enumeration mode is EPR or ObjectAndEPR.",
            WINRM::ERROR_WSMAN_NETWORK_TIMEDOUT => "WinRM cannot complete the operation. Verify that the specified computer name is valid, that the computer is accessible over the network, and that a firewall exception for the WinRM service is enabled and allows access from this computer. By default, the WinRM firewall exception for public profiles limits access to remote computers within the same local subnet.",
            WINRM::ERROR_WINRS_RECEIVE_IN_PROGRESS => "Not used. To be removed.",
            WINRM::ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA => "The WinRS client cannot process the Receive request because the shell plugin returned an empty response to the request.",
            WINRM::ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManCreateShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WinrsCloseShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM => "The WinRS client cannot process the request. The parameter required for the WinrsFreeCreateShellResult function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManRunShellCommand function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM => "The WinRS client cannot process the request. The parameter required for the WinrsFreeRunCommandResult function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManSignalShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSMansReceiveShellOutput function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM => "The WinRS client cannot process the request. The parameter required for the WinrsFreePullResult function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_PULL_NULL_PARAM => "The WinRS client cannot process the request. One of the parameters required for the WinrsPull function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM => "The WinRS client cannot process the request. The parameter required for the WinrsCloseReceiveHandle function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_SEND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManSendShellInput function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_PUSH_NULL_PARAM => "The WinRS client cannot process the request. One of the parameters required for the WinrsPush function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM => "The WinRS client cannot process the request. The parameter required for the WinrsCloseSendHandle function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CLIENT_GET_NULL_PARAM => "The WinRS client cannot process the request. One of the parameters required for the WinrsGet function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED => "The WS-Management service does not support the specified polymorphism mode. Try changing the polymorphism mode specified, and try again.",
            WINRM::ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE => "The WS-Management service cannot process the request because the specified URI is not supported on the service side. Retry the request with local session.",
            WINRM::ERROR_WSMAN_URI_NON_DMTF_CLASS => "The WS-Management service cannot process the request. A DMTF resource URI was used to access a non-DMTF class. Try again using a non-DMTF resource URI.",
            WINRM::ERROR_WSMAN_URI_WRONG_DMTF_VERSION => "The WS-Management service cannot process the request. The DMTF class in the repository uses a different major version number from the requested class. This class can be accessed using a non-DMTF resource URI.",
            WINRM::ERROR_WSMAN_DIFFERENT_CIM_SELECTOR => "The WS-Management service cannot process the request. The resource URI and __cimnamespace selector attempted to use different namespaces. Try removing the __cimnamespace selector or using a DMTF resource URI. If a non-DMTF resource URI is used with a __cimnamespace selector, the namespaces must match.",
            WINRM::ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT => "The WS-Management client cannot process the request. To use the WSManSubscribe API the user has to be running under Network Service account. No other account is supported currently for push subscriptions.",
            WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER => "The WS-Management client cannot process the request. The event source machine is not joined to a domain. To set up a push subscription session to an event source the source has to be connected to a domain. To fix this problem either join the event source machine to a domain or use PULL as the delivery mode for the subscription.",
            WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR => "The WS-Management client cannot process the request. The subscriber machine is not joined to a domain. To set up a push subscription session to an event source, the subscriber machine has to be connected to a domain. To fix this problem either join the subscriber machine to a domain or use PULL as the delivery mode for the subscription.",
            WINRM::ERROR_WSMAN_CONFIG_READONLY_PROPERTY => "The WinRM client cannot process the request because it is trying to update a read-only setting. Remove this setting from the command and try again.",
            WINRM::ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED => "The WinRS client cannot process the request. The server cannot set Code Page. You may want to use the CHCP command to change the client Code Page to 437 and receive the results in English.",
            WINRM::ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS => "Not used. To be removed.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK => "Not used. To be removed.",
            WINRM::ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS => "The WS-Management client received too many results from the server. The server implementation should never return more items than are specified by the client.",
            WINRM::ERROR_WSMAN_MULTIPLE_CREDENTIALS => "The WinRM client cannot process the request. A certificate thumbprint was specified together with a user name or password. Only one credentials type can be specified. Remove the credentials type that does not correspond to the intended authentication mechanism and retry the request.",
            WINRM::ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG => "The WinRM client cannot process the request. The flag that specifies the authentication mechanism to use is incorrect. Remove or change the invalid flag and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION => "The WinRM client cannot process the request. When an authentication mechanism is not specified, only user name and password credentials are allowed. If you want to use a different type of credentials then you need to specify the authentication mechanism. Specify the authentication mechanism or the correct credentials and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED => "The WinRM client cannot process the request. For authentication mechanisms that require the credentials of an user account, both user name and password must be specified. Specify the missing user name or password and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN => "The WinRM client cannot process the request. If you are using a machine certificate, it must contain a DNS name in the Subject Alternative Name extension or in the Subject Name field, and no UPN name. If you are using a user certificate, the Subject Alternative Name extension must contain a UPN name and must not contain a DNS name. Change the certificate structure and try the request again.",
            WINRM::ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME => "The WinRM Shell client cannot process the request. One of the environment variable name passed to the WSManCreateShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_SHELL_ALREADY_CLOSED => "An operation is being attempted on a shell that is being closed. This can happen if the shell that is being used is also being closed by another thread.",
            WINRM::ERROR_WSMAN_CREATESHELL_NULL_STREAMID => "The WinRM Shell client cannot process the request. One of the stream id name passed to the WSManCreateShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE => "The WinRM Shell client cannot process the request. The shell handle passed to the WSMan Shell function is not valid. The shell handle is valid only when WSManCreateShell function completes successfully. Change the request including a valid shell handle and try again.",
            WINRM::ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE => "The WinRM Shell client cannot process the request. The command handle passed to the WSMan Shell function is not valid. The command handle is valid only when WSManRunShellCommand function completes successfully. Change the request including a valid shell handle and try again.",
            WINRM::ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT => "The WinRM Shell client cannot process the request. One of the argument value passed to the WSManRunShellCommand function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_COMMAND_ALREADY_CLOSED => "An operation is being attempted on a command that is being closed. This can happen if the command handle that is being used is also being freed by another thread.",
            WINRM::ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX => "The WinRM Shell client cannot process the request. The stream id index from within WSMAN_STREAM_ELEMENT passed to the WSManSendShellInput function is invalid. The stream id index should be an index from within inputStreamSet array passed to the WSManCreateShell function. Change the request with a valid index and try again.",
            WINRM::ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED => "Not used. To be removed.",
            WINRM::ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION => "The WS-Management operations to update the certificate mapping store of the WINRM service config can only be done remotely.",
            WINRM::ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED => "The WINRM certificate mapping configuration store has reached an internal limit and cannot create any more entries. Remove some entries and try again.",
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS => "The WINRM certificate mapping configuration operation cannot be completed because the user credentials could not be verified. Please check the username and password used for mapping this certificate and verify that it is a non-domain account and try again.",
            WINRM::ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT => "The WinRM client cannot process the request. The Enhanced Key Usage (EKU) field of the certificate is not set to 'Client Authentication'. Retry the request with a certificate that has the correct EKU.",
            WINRM::ERROR_WSMAN_CERT_MISSING_AUTH_FLAG => "The WinRM client cannot process the request. A certificate thumbprint was specified, but the following flag is missing: WSManFlagUseClientCertificate. Add the flag and try the request again.",
            WINRM::ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG => "The WinRM client cannot process the request. The following flags cannot be specified together: WSManFlagUseClientCertificate and WSManFlagCredUsernamePassword. Remove one of the flags and try the request again.",
            WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_INVALID => "The WinRM client cannot process the request because the CustomRemoteShell URI specified is invalid. CustomRemoteShell URI should start with WinRM shell resource URI prefix: 'http://schemas.microsoft.com/wbem/wsman/1/windows/shell'. The URI should not contain invalid characters including '*', '?', white spaces and tabs. The CustomRemoteShell URI cannot be longer than 1023 characters.",
            WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED => "The WinRM client cannot process the request because the CustomRemoteShell URI specified is invalid. Windows command shell URI ('http://schemas.microsoft.com/wbem/wsman/1/windows/shell/cmd') cannot be a CustomRemoteShell URI.",
            WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH => "The WinRM client cannot process the request because the process path specified for the CustomRemoteShell table entry is invalid. The process path should be absolute and should point to an existing executable.",
            WINRM::ERROR_WINRS_SHELL_URI_INVALID => "Not used. To be removed.",
            WINRM::ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR => "The WinRM client cannot process the request because the provided security descriptor is invalid.",
            WINRM::ERROR_WSMAN_POLICY_TOO_COMPLEX => "The WinRM service cannot process the request because the WS-Policy contained in the DeliverTo is too complex or uses a structure not understood by the service. The WinRM service supports a single layer of policy assertions underneath a wsp:ExactlyOne element.",
            WINRM::ERROR_WSMAN_POLICY_CANNOT_COMPLY => "The WinRM service cannot process the request because the WS-Policy contained in the DeliverTo does not contain any options that the service can comply with. The WinRM service supports the following profiles: Negotiate or Kerberos over HTTP, Negotiate or Kerberos over HTTPS, and mutual certificate authentication over HTTPS using issuer thumbprints.",
            WINRM::ERROR_WSMAN_INVALID_CONNECTIONRETRY => "The WinRM service cannot process the request because the wsman:ConnectionRetry element in the DeliverTo is invalid.",
            WINRM::ERROR_WSMAN_URISECURITY_INVALIDURIKEY => "WinRM cannot make the configuration change. The URI supplied for the certificate mapping operation is not valid. It must contain at least one character. It must not contain internal whitespace. It must not contain '?' character. A prefix may be specified by using '*' as the last character. The URI cannot be longer than 1023 characters.",
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY => "WinRM cannot make the configuration change. The Subject used for the certificate mapping operation is not valid. It must contain at least one character. It must contain at most one '*' character which should be the first character. (This may be the only character in which case it matches all subjects). The Subject cannot be longer than 1023 characters.",
            WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY => "WinRM cannot make the configuration change because the Issuer used for the certificate mapping operation is not valid. The certificate identified by the issuer thumbprint must be present in the machine 'Trusted Root Certification Authorities' or 'Intermediate Certification Authorities' store. The certificate must have key usage that allows it to sign other certificates.",
            WINRM::ERROR_WSMAN_INVALID_PUBLISHERS_TYPE => "The WinRM client cannot process the request because the type field in the WSMAN_ALLOWED_PUBLISHERS argument is invalid. Collector-initiated subscriptions must use WSMAN_SINGLE_PUBLISHER and Source-initiated subscriptions must use WSMAN_MULTIPLE_PUBLISHERS.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY => "The WinRM client cannot process the request because the delivery retry parameters are invalid. If delivery retry is requested, the deliveryRetryInterval and deliveryRetryAttempts fields must both be nonzero.",
            WINRM::ERROR_WSMAN_CLIENT_NULL_PUBLISHERS => "The WinRM client cannot process the request. The required WSMAN_ALLOWED_PUBLISHERS settings is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_NULL_ISSUERS => "The WinRM client cannot process the request because client certificate subject filters were specified without any issuers. When using client certificate authentication, specify at least one issuer thumbprint.",
            WINRM::ERROR_WSMAN_CLIENT_NO_SOURCES => "The WinRM client cannot process the request because the subscription contains no domain or non-domain sources. Subscriptions using WSMAN_MULTIPLE_PUBLISHERS must specify either a security descriptor or an issuer list or both.",
            WINRM::ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT => "The WinRM service cannot process the request because the subscription manager returned invalid enumeration results. The m:Subscription XML object or m:Version element is missing or invalid.",
            WINRM::ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE => "WinRM firewall exception will not work since one of the network connection types on this machine is set to Public. Change the network connection type to either Domain or Private and try again.",
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG => "WinRM cannot make the configuration change. The Password used for updating the certificate mapping configuration is not valid. It cannot be longer than 255 characters.",
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK => "WinRM cannot make the configuration change. The Password used for updating the certificate mapping configuration is not valid. A user account used for configuring a certificate mapping cannot have a blank password.",
            WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE => "WinRM cannot make the configuration change. The credential used for updating or creating the certificate mapping configuration is not valid. The credential consists of both Password and UserName being supplied together in a pair.",
            WINRM::ERROR_WSMAN_INVALID_PROVIDER_RESPONSE => "The WinRM service executed an operation and the provider returned inconclusive information regarding success or failure of the operation. The status was marked as failed, but no error code was given.",
            WINRM::ERROR_WSMAN_SHELL_NOT_INITIALIZED => "The WS-Management service on the remote machine cannot process the shell request. This can happen if the WS-Management service on the remote machine was being shutdown. To correct this problem restart the WS-Management service on the remote machine and re-send the shell request.",
            WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY => "The WinRM service cannot process the request. The URI parameter is the key to CustomRemoteShell table and cannot be modified.",
            WINRM::ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR => "The WinRM client received an HTTP server error status (500), but the remote service did not include any other information about the cause of the failure.",
            WINRM::ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST => "The WinRM client received an HTTP bad request status (400), but the remote service did not include any other information about the cause of the failure.",
            WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS => "The WinRM service cannot make the configuration change. The selector keys of Subject, URI or Issuer cannot be changed by overriding the selector key value in the body.",
            WINRM::ERROR_WSMAN_HTML_ERROR => "The WinRM client cannot process the request because it received an HTML error packet.",
            WINRM::ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManInitialize function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManInitialize API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManDeinitialize API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManSetSessionOption function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManSetSessionOption function is invalid. Change the invalid parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM => "The WinRM client cannot process the request. One of the parameters required to get a session option is invalid. Change the invalid parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManCreateShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManCreateShell API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManCloseShell API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManCloseCommand API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManCloseShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManCloseCommand function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManRunShellCommand function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManRunShellCommand API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED => "The WinRM client cannot process the request. You must wait for the WSManRunShellCommand API call to complete before calling WSManCloseShellOperationEx API.",
            WINRM::ERROR_WSMAN_NO_COMMAND_RESPONSE => "The WinRM client cannot process the request. The response to a Command request did not contain a valid CommandResponse element. The CommandResponse element was not found or did not contain valid content.",
            WINRM::ERROR_WSMAN_INVALID_OPTIONSET => "The WinRM client cannot process the request. The OptionSet element is invalid. Change the request to include a valid OptionSet element and try again.",
            WINRM::ERROR_WSMAN_NO_COMMANDID => "The WinRM client cannot process the request. The response to a Command request did not contain a valid CommandResponse element. The CommandId element was not found or did not contain valid content.",
            WINRM::ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManSignalShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManSignalShell API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_SEND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManSendShellInput function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManSendShellInput API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER => "The WinRM client cannot process the request. An invalid parameter was specified for the WSManSendShellInput API call. streamData parameter should be specified in binary format using WSMAN_DATA_TYPE_BINARY type. Change the invalid parameter and try the call again.",
            WINRM::ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM => "The WinRM Shell client cannot process the request. The stream name passed to the WSManSendShellInput function is not valid. The input stream name should be specified as part of the input streams during shell creation using WSManCreateShell function. Change the request including a valid input stream name and try again.",
            WINRM::ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManReceiveShellOutput function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS => "The WinRM Shell client cannot process the request. The stream or list of streams passed to the WSManReceiveShellOutput function is not valid. The desired stream names should be specified as part of the output streams during shell creation using WSManCreateShell function. Change the request including valid desired streams and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManReceiveShellOutput API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_NO_RECEIVE_RESPONSE => "The WinRM client cannot process the request. The response to a Receive request did not contain a valid ReceiveResponse element. The ReceiveResponse element was not found or did not contain valid content.",
            WINRM::ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED => "The WSMan plugin configuration is corrupted.",
            WINRM::ERROR_WSMAN_INVALID_FILEPATH => "The file path specified is either not absolute, not in the system32 directory, or not valid.",
            WINRM::ERROR_WSMAN_FILE_NOT_PRESENT => "The file specified does not exist.",
            WINRM::ERROR_WSMAN_IISCONFIGURATION_READ_FAILED => "The WSMan extension failed to read IIS configuration.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_LOCALE => "The WinRM client cannot process the request. The locale option is invalid. Change the locale and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE => "The WinRM client cannot process the request. The UI language option is invalid. Change the UI language and try again.",
            WINRM::ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManGetErrorMessage function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE => "The WinRM client cannot process the request. The language code parameter is invalid. The language code parameter should be either NULL or a valid RFC 3066 language code. Change the language code and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG => "The WinRM client cannot process the request. An invalid flag was specified for the WSManGetErrorMessage API call. Remove or change the invalid flag and try the call again.",
            WINRM::ERROR_WSMAN_REDIRECT_REQUESTED => "The WinRM service cannot process the request because the request needs to be sent to a different machine. Use the redirect information to send the request to a new machine.",
            WINRM::ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG => "The WinRM client cannot process the request. The flag that specifies the proxy authentication mechanism to use is incorrect. Remove or change the invalid flag and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION => "The WinRM client cannot process the request. The credentials for proxy authentication are not specified correctly. Both user name and password credentials must be valid. Specify the correct credentials and try the request again.",
            WINRM::ERROR_WSMAN_PROXY_ACCESS_TYPE => "The WinRM client cannot process the request. The proxy access type is incorrect. Use one of the proxy access type flags; the flags cannot be combined. Change the invalid proxy access type and try the request again.",
            WINRM::ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER => "The WinRM client cannot process the request. The direct connection to the server option cannot be used with non empty proxy authentication data. Change the invalid proxy access type or use empty proxy authentication data and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManGetSessionOptionAsDword function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManGetSessionOptionAsDword function is invalid. Change the invalid parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM => "The WinRM client cannot process the request. One of the parameters required for the WSManGetSessionOptionAsString function is invalid. Change the invalid parameter and try again.",
            WINRM::ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED => "The WinRM client cannot process the request. Requests must include user name and password when CredSSP authentication mechanism is used. Add the user name and password or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED => "The WinRM client cannot process the request. CredSSP authentication is currently disabled in the client configuration. Change the client configuration and try the request again. CredSSP authentication must also be enabled in the server configuration. Also, Group Policy must be edited to allow credential delegation to the target computer. Use gpedit.msc and look at the following policy: Computer Configuration -> Administrative Templates -> System -> Credentials Delegation -> Allow Delegating Fresh Credentials. Verify that it is enabled and configured with an SPN appropriate for the target computer. For example, for a target computer name 'myserver.domain.com', the SPN can be one of the following: WSMAN/myserver.domain.com or WSMAN/*.domain.com",
            WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS => "The WinRM client cannot process the request. A computer policy does not allow the delegation of the user credentials to the target computer. Use gpedit.msc and look at the following policy: Computer Configuration -> Administrative Templates -> System -> Credentials Delegation -> Allow Delegating Fresh Credentials. Verify that it is enabled and configured with an SPN appropriate for the target computer. For example, for a target computer name 'myserver.domain.com', the SPN can be one of the following: WSMAN/myserver.domain.com or WSMAN/*.domain.com.",
            WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY => "The WinRM client cannot process the request. A computer policy does not allow the delegation of the user credentials to the target computer because the computer is not trusted. The identity of the target computer can be verified if you configure the WSMAN service to use a valid certificate using the following command: winrm set winrm/config/service @{CertificateThumbprint='<thumbprint>'} Or you can check the Event Viewer for an event that specifies that the following SPN could not be created: WSMAN/<computerFQDN>. If you find this event, you can manually create the SPN using setspn.exe . If the SPN exists, but CredSSP cannot use Kerberos to validate the identity of the target computer and you still want to allow the delegation of the user credentials to the target computer, use gpedit.msc and look at the following policy: Computer Configuration -> Administrative Templates -> System -> Credentials Delegation -> Allow Fresh Credentials with NTLM-only Server Authentication. Verify that it is enabled and configured with an SPN appropriate for the target computer. For example, for a target computer name 'myserver.domain.com', the SPN can be one of the following: WSMAN/myserver.domain.com or WSMAN/*.domain.com. Try the request again after these changes.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS => "The WS-Management service cannot process the request. The maximum number of concurrent shells for this user has been exceeded. Close existing shells or raise the quota for this user.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS => "The WS-Management service cannot process the request. The maximum number of concurrent operations for this user has been exceeded. Close existing operations for this user, or raise the quota for this user.",
            WINRM::ERROR_WSMAN_QUOTA_USER => "The WS-Management service cannot process the request. The load quota for this user has been exceeded. Send future requests at a slower rate or raise the quota for this user.",
            WINRM::ERROR_WSMAN_QUOTA_SYSTEM => "The WS-Management service cannot process the request. The load quota for the system has been exceeded. Send future requests at a slower rate or raise the system quota.",
            WINRM::ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN => "The WS-Management service cannot complete the authorization under the given token. A previous authorization attempt for the same user resulted in a different token. The user record will be revoked and the next request will reauthorize.",
            WINRM::ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE => "An application tried to retrieve the HTTP Redirect location from the session when no redirect error (ERROR_WSMAN_REDIRECT_REQUESTED) was returned. The application needs to be updated so as to only retrieve the location after this error is returned.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLUSERS => "The WS-Management service cannot process the request. The maximum number of users executing shell operations has been exceeded. Retry after some time or raise the quota for concurrent shell users.",
            WINRM::ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED => "The WS-Management service cannot process the request. The service is configured to not accept any remote shell requests.",
            WINRM::ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM => "The WS-Management service cannot complete the Pull operation for the enumeration because the wsman:MaxEnvelopeSize, wsen:MaxCharacters or wsen:MaxElements parameters differ from those specified to the enumeration. The application needs to specify the same parameters for Pull as were specified for the enumeration.",
            WINRM::ERROR_WSMAN_DEPRECATED_CONFIG_SETTING => "The WinRM service cannot process the request because it is trying to update a deprecated setting. Remove this setting from the command and try again.",
            WINRM::ERROR_WSMAN_URI_SECURITY_URI => "The WS-Management service cannot process the configuration settings. A Security element contains a URI that does not match its parent Resource element.",
            WINRM::ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP => "The WinRM client cannot process the request. Allow implicit credentials for Negotiate authentication option is only valid for HTTPS transport. Remove the allow implicit credentials for Negotiate authentication option and try the request again.",
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP => "The WinRM client cannot process the request. Setting proxy information is not valid when the HTTP transport is specified. Remove the proxy information or change the transport and try the request again.",
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS => "The WinRM client cannot process the request. Setting proxy information is not valid when the authentication mechanism with the remote machine is Kerberos. Remove the proxy information or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP => "The WinRM client cannot process the request. Setting proxy information is not valid when the authentication mechanism with the remote machine is CredSSP. Remove the proxy information or change the authentication mechanism and try the request again.",
            WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS => "The WinRM client cannot process the request. The request must specify only one authentication mechanism for proxy. Change the request to specify only one authentication mechanism and try again.",
            WINRM::ERROR_WSMAN_INVALID_REDIRECT_ERROR => "The WinRM client received a redirect error from the server when it is not appropriate. The only time a redirect error can be reported correctly is during the authorization of a user. This would result in a properly formatted redirect response from the server that includes the redirect endpoint.",
            WINRM::ERROR_REDIRECT_LOCATION_TOO_LONG => "The WinRM service received a redirect error from an authorization plug-in where the redirect location was too long.",
            WINRM::ERROR_REDIRECT_LOCATION_INVALID => "The WinRM service received a HTTP redirect message redirecting the client but the location URL is invalid.",
            WINRM::ERROR_SERVICE_CBT_HARDENING_INVALID => "The WinRM service cannot process the request. The Channel Binding Token Hardening Level (CbtHardeningLevel) value is invalid. The valid values are 'None', 'Relaxed' and 'Strict'. Change the CbtHardeningLevel value and try again.",
            WINRM::ERROR_WSMAN_NAME_NOT_RESOLVED => "The WinRM client cannot process the request because the server name cannot be resolved.",
            WINRM::ERROR_WSMAN_SSL_CONNECTION_ABORTED => "The SSL connection cannot be established. Verify that the service on the remote host is properly configured to listen for HTTPS requests. Consult the logs and documentation for the WS-Management service running on the destination, most commonly IIS or WinRM. If the destination is the WinRM service, run the following command on the destination to analyze and configure the WinRM service: 'winrm quickconfig -transport:https'.",
            WINRM::ERROR_WSMAN_DEFAULTAUTH_IPADDRESS => "The WinRM client cannot process the request. Default authentication may be used with an IP address under the following conditions: the transport is HTTPS or the destination is in the TrustedHosts list, and explicit credentials are provided. Use winrm.cmd to configure TrustedHosts. Note that computers in the TrustedHosts list might not be authenticated. For more information on how to set TrustedHosts run the following command: winrm help config.",
            WINRM::ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED => "The WinRM client cannot process the request. Custom Remote Shell has been deprecated and cannot be used.",
            WINRM::ERROR_WSMAN_FEATURE_DEPRECATED => "The WinRM client cannot process the request. The feature in use has been deprecated and cannot be used.",
            WINRM::ERROR_WSMAN_INVALID_USESSL_PARAM => "The WinRM client used a parameter to specify the use of SSL while specifying http in the connection string.",
            WINRM::ERROR_WSMAN_INVALID_CONFIGSDDL_URL => "The WinRM service cannot process the request because the security for this resource URI cannot be changed.",
            WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED => "The WinRM service cannot process the request. The enumeration request expects a selector based filter to specify the shell identifier.",
            WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED => "The WinRM service cannot process the request. The enumeration of end point resources for shell commands is not supported.",
            WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID => "The WinRM Shell client cannot process the request because the shell name has exceeded 255 characters in length.",
            WINRM::ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS => "The WinRM runAs configuration operation cannot be completed because the user credentials could not be verified. Verify that the username and password used for configuration are valid and retry the operation.",
            WINRM::ERROR_WINRS_SHELL_DISCONNECTED => "The WinRM service cannot process the request because the WinRS shell instance is currently disconnected.",
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED => "The WinRM service cannot process the request. This WinRS shell instance does not support disconnect and reconnect operations because it was created by an older WinRS client or its provider does not support the disconnect operation.",
            WINRM::ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH => "The WinRM service cannot process the request because the WinRS shell instance is connected to a different client.",
            WINRM::ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManDisconnectShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManReconnectShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManConnectShell function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManConnectShellCommand function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY => "The WinRM client cannot process the request. The body response is not a valid connect request response.",
            WINRM::ERROR_WSMAN_COMMAND_TERMINATED => "The WinRM Shell client cannot process the request. The command is currently terminating or was terminated.",
            WINRM::ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT => "The WinRM service cannot process the request. The WinRS shell instance is currently connected to a different client.",
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL => "The WinRM client encountered an error while communicating with the WinRM service during the disconnect operation. The shell has been disconnected and the streams were possibly suspended abruptly.",
            WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID => "The WinRM client cannot process the request. A disconnect operation cannot be performed on a WinRS shell instance that is already disconnected.",
            WINRM::ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID => "The WinRM client cannot process the request. A reconnect operation cannot be performed on a WinRS shell instance that is currently connected.",
            WINRM::ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED => "An error was encountered while subscribing to the Group Policy change notification.",
            WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM => "The WinRM Shell client cannot process the request. One of the parameters required for the WSManReconnectShellCommand function is null or zero. Change the request to include the missing parameter and try again.",
            WINRM::ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID => "The WinRM client cannot process the request. A reconnect operation cannot be performed on a WinRS shell command instance that is currently connected.",
            WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID => "The WinRM service cannot process the request because the command ID specified by the client is not a valid GUID. Modify the request and retry the request.",
            WINRM::ERROR_WINRS_SHELL_CLIENTID_NOT_VALID => "The WinRM service cannot process the request because the shell ID specified by the client is not a valid GUID. Provide a valid ID and try again.",
            WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT => "The WinRM service cannot process the request. A command already exists with the command ID specified by the client.",
            WINRM::ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT => "The WinRM service cannot process the request. A resource already exists with the shell ID specified by the client.",
            WINRM::ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID => "The WinRM client cannot process the request. A disconnect operation cannot be performed on a WinRS shell command instance that is disconnected.",
            WINRM::ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY => "The WS-Management service cannot process the request. The resource URI for the Subscribe operation must not contain keys.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG => "The WinRM client cannot process the request. A flag that is not valid was specified for the WSManDisconnectShell method. Remove or change the flag and retry the operation.",
            WINRM::ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR => "The WinRM client cannot process the request because the command handle is not associated with the provided shell handle.",
            WINRM::ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT => "The WS-Management service did not receive a response for an extended semantics operation within the timeframe specified in the OperationTimeout setting.",
            WINRM::ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED => "The WS-Management service is configured to not allow remote requests.",
            WINRM::ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED => "The WS-Management service cannot process the request because the stream is currently disconnected.",
            WINRM::ERROR_WSMAN_CREATESHELL_RUNAS_FAILED => "The creation of a new Shell failed. Verify that the RunAsPassword value is correctly configured and that the Group Policy setting 'Disallow WinRM from storing RunAs credentials' is Disabled or Not Configured. To enable WinRM to store RunAs credentials, change this Group Policy setting to Disabled.",
            WINRM::ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED => "The supplied plugin configuration XML is not valid. To enable WinRM to store RunAs credentials, change the 'Disallow WinRM from storing RunAs credentials' Group Policy setting to Disabled.",
            WINRM::ERROR_WSMAN_WRONG_METADATA => "The WinRM client cannot process the request because the XML instance does not match the class schema provided by the server.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_TYPE => "The WinRM client cannot process the request because the XML contains an unsupported type. Verify the XML and retry the operation.",
            WINRM::ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED => "The WS-Management service cannot process the request. The service is configured to reject remote connection requests for this plugin.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ => "The WS-Management service cannot process the request. This user has exceeded the maximum number of concurrent shells allowed for this plugin. Close at least one open shell or raise the plugin quota for this user.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_USERS_PPQ => "The WS-Management service cannot process the request. The maximum number of users executing remote operations has been exceeded for this plugin. Retry the request later or raise the quota for concurrent users.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ => "The WS-Management service cannot process the request. The maximum number of concurrent shells allowed for this plugin has been exceeded. Retry the request later or raise the Maximum Shells per Plugin quota.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ => "The WS-Management service cannot process the request. The maximum number of concurrent operations allowed for this plugin has been exceeded. Retry the request later or raise the Maximum Operations per Plugin quota.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ => "The WS-Management service cannot process the request. This user has exceeded the maximum number of allowed concurrent operations. Retry the request later or raise the Maximum Operations per User quota.",
            WINRM::ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ => "The WS-Management service cannot process the request. The maximum number of concurrent commands per shell has been exceeded. Retry the request later or raise the Maximum Commands per Shell quota.",
            WINRM::ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ => "The WS-Management service cannot process the request. There are not enough resources available to process this operation. Retry the operation later or close one or more of the currently running operations.",
            WINRM::ERROR_WSMAN_NEW_DESERIALIZER => "The WinRM client cannot process the request because the MI Deserializer cannot be created.",
            WINRM::ERROR_WSMAN_DESERIALIZE_CLASS => "The WinRM client cannot process the request because the metadata could not be deserialized.",
            WINRM::ERROR_WSMAN_GETCLASS => "The WinRM client cannot process the request because the metadata failed to be retrieved from the server.",
            WINRM::ERROR_WSMAN_NEW_SESSION => "The WinRM client cannot process the request because a WinRM session could not be created.",
            WINRM::ERROR_WSMAN_NULL_KEY => "The WinRM client cannot process the request because the target object has a key property set to NULL. Incomplete objects cannot be used as the target of an operation.",
            WINRM::ERROR_WSMAN_MUTUAL_AUTH_FAILED => "The WinRM client cannot process the request as the server identity could not be verified. If the identity of the server is trusted, add it to the TrustedHosts list and retry the request. Use winrm.cmd to configure TrustedHosts. Note that computers in the TrustedHosts list might not be authenticated. For more information on how to set TrustedHosts, run the following command: winrm help config",
            WINRM::ERROR_WSMAN_UNSUPPORTED_OCTETTYPE => "The WinRM client cannot process the request because the octet string array type is not supported.",
            WINRM::ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS => "The WS-Management service cannot process the request. The requested IdleTimeout is outside the allowed range.",
            WINRM::ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC => "The WinRM client cannot process the request because insufficient metadata is available. The application does not allow all properties to be returned as strings, but the server does not support correctly typing the properties. Change the request to allow all properties to be returned as strings and retry the request.",
            WINRM::ERROR_WSMAN_INVALID_LITERAL_URI => "The WinRM client cannot process the request because the MI_OperationOptions contained both a Resource URI and a Resource URI Prefix. Specify only one of these two options and try again.",
            WINRM::ERROR_WSMAN_OBJECTONLY_INVALID => "The WinRM client cannot process the request because keysOnly and WSMAN_ENUMERATIONMODE_OBJECTONLY were specified at the same time. These two settings are incompatible. Remove the WSMAN_ENUMERATIONMODE_OBJECTONLY option, or set keysOnly to MI_FALSE, and retry the request.",
            WINRM::ERROR_WSMAN_MISSING_CLASSNAME => "The WinRM client cannot process the request because the class name is not valid. Supply a valid class name or set the Resource URI option and retry the request.",
            WINRM::ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY => "The subscribe packet contains an Encoding value that is not valid in the delivery section.",
            WINRM::ERROR_WSMAN_DESTINATION_INVALID => "The WinRM client cannot process the request. The destination computer name must be a hostname or an IP address, and must not be a URL. To use an IPv6 address, enclose the address in brackets, like the following: '[::1]'. The transport, port number, and URL prefix may be controlled by setting the appropriate destination options. Change the destination computer name string and retry the operation.",
            WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY => "The server does not support WS-Management Identify operations. Skip the TestConnection part of the request and try again.",
            WINRM::ERROR_WSMAN_CLIENT_SESSION_UNUSABLE => "The WS-Management service cannot process the operation. The operation is being attempted on a client session that is unusable. This may be related to a recent restart of the WS-Management service. Please create a new client session and retry the operation if re-executing the operation does not have undesired behavior.",
        }
    }

    pub fn from_name(name: &str) -> WINRM {
        return match name {
            "ERROR_WSMAN_RESOURCE_NOT_FOUND" => WINRM::ERROR_WSMAN_RESOURCE_NOT_FOUND,
            "ERROR_WSMAN_INVALID_ACTIONURI" => WINRM::ERROR_WSMAN_INVALID_ACTIONURI,
            "ERROR_WSMAN_INVALID_URI" => WINRM::ERROR_WSMAN_INVALID_URI,
            "ERROR_WSMAN_PROVIDER_FAILURE" => WINRM::ERROR_WSMAN_PROVIDER_FAILURE,
            "ERROR_WSMAN_BATCH_COMPLETE" => WINRM::ERROR_WSMAN_BATCH_COMPLETE,
            "ERROR_WSMAN_CONFIG_CORRUPTED" => WINRM::ERROR_WSMAN_CONFIG_CORRUPTED,
            "ERROR_WSMAN_PULL_IN_PROGRESS" => WINRM::ERROR_WSMAN_PULL_IN_PROGRESS,
            "ERROR_WSMAN_ENUMERATION_CLOSED" => WINRM::ERROR_WSMAN_ENUMERATION_CLOSED,
            "ERROR_WSMAN_SUBSCRIPTION_CLOSED" => WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSED,
            "ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS" => WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS,
            "ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT" => WINRM::ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT,
            "ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT" => WINRM::ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT,
            "ERROR_WSMAN_UNSUPPORTED_TIMEOUT" => WINRM::ERROR_WSMAN_UNSUPPORTED_TIMEOUT,
            "ERROR_WSMAN_SOAP_VERSION_MISMATCH" => WINRM::ERROR_WSMAN_SOAP_VERSION_MISMATCH,
            "ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN" => WINRM::ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN,
            "ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER" => WINRM::ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER,
            "ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND" => WINRM::ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND,
            "ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED" => WINRM::ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED,
            "ERROR_WSMAN_DESTINATION_UNREACHABLE" => WINRM::ERROR_WSMAN_DESTINATION_UNREACHABLE,
            "ERROR_WSMAN_ACTION_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_ACTION_NOT_SUPPORTED,
            "ERROR_WSMAN_ENDPOINT_UNAVAILABLE" => WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE,
            "ERROR_WSMAN_INVALID_REPRESENTATION" => WINRM::ERROR_WSMAN_INVALID_REPRESENTATION,
            "ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME" => WINRM::ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME,
            "ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME" => WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME,
            "ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED,
            "ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE" => WINRM::ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE,
            "ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER" => WINRM::ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER,
            "ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT" => WINRM::ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT,
            "ERROR_WSMAN_ENUMERATE_TIMED_OUT" => WINRM::ERROR_WSMAN_ENUMERATE_TIMED_OUT,
            "ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW" => WINRM::ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW,
            "ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE" => WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE,
            "ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME" => WINRM::ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME,
            "ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE" => WINRM::ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE,
            "ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED,
            "ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE" => WINRM::ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE,
            "ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS" => WINRM::ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS,
            "ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW" => WINRM::ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW,
            "ERROR_WSMAN_EVENTING_INVALID_MESSAGE" => WINRM::ERROR_WSMAN_EVENTING_INVALID_MESSAGE,
            "ERROR_WSMAN_ENVELOPE_TOO_LARGE" => WINRM::ERROR_WSMAN_ENVELOPE_TOO_LARGE,
            "ERROR_WSMAN_INVALID_SOAP_BODY" => WINRM::ERROR_WSMAN_INVALID_SOAP_BODY,
            "ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT" => WINRM::ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT,
            "ERROR_WSMAN_OPERATION_TIMEDOUT" => WINRM::ERROR_WSMAN_OPERATION_TIMEDOUT,
            "ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED,
            "ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED,
            "ERROR_WSMAN_UNSUPPORTED_ENCODING" => WINRM::ERROR_WSMAN_UNSUPPORTED_ENCODING,
            "ERROR_WSMAN_URI_LIMIT" => WINRM::ERROR_WSMAN_URI_LIMIT,
            "ERROR_WSMAN_INVALID_PROPOSED_ID" => WINRM::ERROR_WSMAN_INVALID_PROPOSED_ID,
            "ERROR_WSMAN_INVALID_BATCH_PARAMETER" => WINRM::ERROR_WSMAN_INVALID_BATCH_PARAMETER,
            "ERROR_WSMAN_NO_ACK" => WINRM::ERROR_WSMAN_NO_ACK,
            "ERROR_WSMAN_ACTION_MISMATCH" => WINRM::ERROR_WSMAN_ACTION_MISMATCH,
            "ERROR_WSMAN_CONCURRENCY" => WINRM::ERROR_WSMAN_CONCURRENCY,
            "ERROR_WSMAN_ALREADY_EXISTS" => WINRM::ERROR_WSMAN_ALREADY_EXISTS,
            "ERROR_WSMAN_DELIVERY_REFUSED" => WINRM::ERROR_WSMAN_DELIVERY_REFUSED,
            "ERROR_WSMAN_ENCODING_LIMIT" => WINRM::ERROR_WSMAN_ENCODING_LIMIT,
            "ERROR_WSMAN_FAILED_AUTHENTICATION" => WINRM::ERROR_WSMAN_FAILED_AUTHENTICATION,
            "ERROR_WSMAN_INCOMPATIBLE_EPR" => WINRM::ERROR_WSMAN_INCOMPATIBLE_EPR,
            "ERROR_WSMAN_INVALID_BOOKMARK" => WINRM::ERROR_WSMAN_INVALID_BOOKMARK,
            "ERROR_WSMAN_INVALID_OPTIONS" => WINRM::ERROR_WSMAN_INVALID_OPTIONS,
            "ERROR_WSMAN_INVALID_PARAMETER" => WINRM::ERROR_WSMAN_INVALID_PARAMETER,
            "ERROR_WSMAN_INVALID_RESOURCE_URI" => WINRM::ERROR_WSMAN_INVALID_RESOURCE_URI,
            "ERROR_WSMAN_INVALID_SYSTEM" => WINRM::ERROR_WSMAN_INVALID_SYSTEM,
            "ERROR_WSMAN_INVALID_SELECTORS" => WINRM::ERROR_WSMAN_INVALID_SELECTORS,
            "ERROR_WSMAN_METADATA_REDIRECT" => WINRM::ERROR_WSMAN_METADATA_REDIRECT,
            "ERROR_WSMAN_QUOTA_LIMIT" => WINRM::ERROR_WSMAN_QUOTA_LIMIT,
            "ERROR_WSMAN_RENAME_FAILURE" => WINRM::ERROR_WSMAN_RENAME_FAILURE,
            "ERROR_WSMAN_SCHEMA_VALIDATION_ERROR" => WINRM::ERROR_WSMAN_SCHEMA_VALIDATION_ERROR,
            "ERROR_WSMAN_UNSUPPORTED_FEATURE" => WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE,
            "ERROR_WSMAN_INVALID_XML" => WINRM::ERROR_WSMAN_INVALID_XML,
            "ERROR_WSMAN_INVALID_KEY" => WINRM::ERROR_WSMAN_INVALID_KEY,
            "ERROR_WSMAN_DELIVER_IN_PROGRESS" => WINRM::ERROR_WSMAN_DELIVER_IN_PROGRESS,
            "ERROR_WSMAN_SYSTEM_NOT_FOUND" => WINRM::ERROR_WSMAN_SYSTEM_NOT_FOUND,
            "ERROR_WSMAN_MAX_ENVELOPE_SIZE" => WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE,
            "ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED" => WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED,
            "ERROR_WSMAN_SERVER_ENVELOPE_LIMIT" => WINRM::ERROR_WSMAN_SERVER_ENVELOPE_LIMIT,
            "ERROR_WSMAN_SELECTOR_LIMIT" => WINRM::ERROR_WSMAN_SELECTOR_LIMIT,
            "ERROR_WSMAN_OPTION_LIMIT" => WINRM::ERROR_WSMAN_OPTION_LIMIT,
            "ERROR_WSMAN_CHARACTER_SET" => WINRM::ERROR_WSMAN_CHARACTER_SET,
            "ERROR_WSMAN_UNREPORTABLE_SUCCESS" => WINRM::ERROR_WSMAN_UNREPORTABLE_SUCCESS,
            "ERROR_WSMAN_WHITESPACE" => WINRM::ERROR_WSMAN_WHITESPACE,
            "ERROR_WSMAN_FILTERING_REQUIRED" => WINRM::ERROR_WSMAN_FILTERING_REQUIRED,
            "ERROR_WSMAN_BOOKMARK_EXPIRED" => WINRM::ERROR_WSMAN_BOOKMARK_EXPIRED,
            "ERROR_WSMAN_OPTIONS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_OPTIONS_NOT_SUPPORTED,
            "ERROR_WSMAN_OPTIONS_INVALID_NAME" => WINRM::ERROR_WSMAN_OPTIONS_INVALID_NAME,
            "ERROR_WSMAN_OPTIONS_INVALID_VALUE" => WINRM::ERROR_WSMAN_OPTIONS_INVALID_VALUE,
            "ERROR_WSMAN_PARAMETER_TYPE_MISMATCH" => WINRM::ERROR_WSMAN_PARAMETER_TYPE_MISMATCH,
            "ERROR_WSMAN_INVALID_PARAMETER_NAME" => WINRM::ERROR_WSMAN_INVALID_PARAMETER_NAME,
            "ERROR_WSMAN_INVALID_XML_VALUES" => WINRM::ERROR_WSMAN_INVALID_XML_VALUES,
            "ERROR_WSMAN_INVALID_XML_MISSING_VALUES" => WINRM::ERROR_WSMAN_INVALID_XML_MISSING_VALUES,
            "ERROR_WSMAN_INVALID_XML_NAMESPACE" => WINRM::ERROR_WSMAN_INVALID_XML_NAMESPACE,
            "ERROR_WSMAN_INVALID_XML_FRAGMENT" => WINRM::ERROR_WSMAN_INVALID_XML_FRAGMENT,
            "ERROR_WSMAN_INSUFFCIENT_SELECTORS" => WINRM::ERROR_WSMAN_INSUFFCIENT_SELECTORS,
            "ERROR_WSMAN_UNEXPECTED_SELECTORS" => WINRM::ERROR_WSMAN_UNEXPECTED_SELECTORS,
            "ERROR_WSMAN_SELECTOR_TYPEMISMATCH" => WINRM::ERROR_WSMAN_SELECTOR_TYPEMISMATCH,
            "ERROR_WSMAN_INVALID_SELECTOR_VALUE" => WINRM::ERROR_WSMAN_INVALID_SELECTOR_VALUE,
            "ERROR_WSMAN_AMBIGUOUS_SELECTORS" => WINRM::ERROR_WSMAN_AMBIGUOUS_SELECTORS,
            "ERROR_WSMAN_DUPLICATE_SELECTORS" => WINRM::ERROR_WSMAN_DUPLICATE_SELECTORS,
            "ERROR_WSMAN_INVALID_TARGET_SELECTORS" => WINRM::ERROR_WSMAN_INVALID_TARGET_SELECTORS,
            "ERROR_WSMAN_INVALID_TARGET_RESOURCEURI" => WINRM::ERROR_WSMAN_INVALID_TARGET_RESOURCEURI,
            "ERROR_WSMAN_INVALID_TARGET_SYSTEM" => WINRM::ERROR_WSMAN_INVALID_TARGET_SYSTEM,
            "ERROR_WSMAN_TARGET_ALREADY_EXISTS" => WINRM::ERROR_WSMAN_TARGET_ALREADY_EXISTS,
            "ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED,
            "ERROR_WSMAN_ACK_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_ACK_NOT_SUPPORTED,
            "ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED,
            "ERROR_WSMAN_LOCALE_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_LOCALE_NOT_SUPPORTED,
            "ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED,
            "ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED,
            "ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED,
            "ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED,
            "ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED,
            "ERROR_WSMAN_MAXTIME_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_MAXTIME_NOT_SUPPORTED,
            "ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED,
            "ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED,
            "ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED,
            "ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED,
            "ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED,
            "ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED,
            "ERROR_WSMAN_BAD_METHOD" => WINRM::ERROR_WSMAN_BAD_METHOD,
            "ERROR_WSMAN_UNSUPPORTED_MEDIA" => WINRM::ERROR_WSMAN_UNSUPPORTED_MEDIA,
            "ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE" => WINRM::ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE,
            "ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED,
            "ERROR_WSMAN_ENUMERATION_INITIALIZING" => WINRM::ERROR_WSMAN_ENUMERATION_INITIALIZING,
            "ERROR_WSMAN_CONNECTOR_GET" => WINRM::ERROR_WSMAN_CONNECTOR_GET,
            "ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR" => WINRM::ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR,
            "ERROR_WSMAN_INEXISTENT_MAC_ADDRESS" => WINRM::ERROR_WSMAN_INEXISTENT_MAC_ADDRESS,
            "ERROR_WSMAN_NO_UNICAST_ADDRESSES" => WINRM::ERROR_WSMAN_NO_UNICAST_ADDRESSES,
            "ERROR_WSMAN_NO_DHCP_ADDRESSES" => WINRM::ERROR_WSMAN_NO_DHCP_ADDRESSES,
            "ERROR_WSMAN_MIN_ENVELOPE_SIZE" => WINRM::ERROR_WSMAN_MIN_ENVELOPE_SIZE,
            "ERROR_WSMAN_EPR_NESTING_EXCEEDED" => WINRM::ERROR_WSMAN_EPR_NESTING_EXCEEDED,
            "ERROR_WSMAN_REQUEST_INIT_ERROR" => WINRM::ERROR_WSMAN_REQUEST_INIT_ERROR,
            "ERROR_WSMAN_INVALID_TIMEOUT_HEADER" => WINRM::ERROR_WSMAN_INVALID_TIMEOUT_HEADER,
            "ERROR_WSMAN_CERT_NOT_FOUND" => WINRM::ERROR_WSMAN_CERT_NOT_FOUND,
            "ERROR_WSMAN_PLUGIN_FAILED" => WINRM::ERROR_WSMAN_PLUGIN_FAILED,
            "ERROR_WSMAN_ENUMERATION_INVALID" => WINRM::ERROR_WSMAN_ENUMERATION_INVALID,
            "ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL" => WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL,
            "ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED" => WINRM::ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED,
            "ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED" => WINRM::ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED,
            "ERROR_WSMAN_POLICY_CORRUPTED" => WINRM::ERROR_WSMAN_POLICY_CORRUPTED,
            "ERROR_WSMAN_LISTENER_ADDRESS_INVALID" => WINRM::ERROR_WSMAN_LISTENER_ADDRESS_INVALID,
            "ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING" => WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING,
            "ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE" => WINRM::ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE,
            "ERROR_WSMAN_EVENTING_FAST_SENDER" => WINRM::ERROR_WSMAN_EVENTING_FAST_SENDER,
            "ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION" => WINRM::ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION,
            "ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE" => WINRM::ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE,
            "ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER" => WINRM::ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER,
            "ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE" => WINRM::ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE,
            "ERROR_WSMAN_MISSING_FRAGMENT_PATH" => WINRM::ERROR_WSMAN_MISSING_FRAGMENT_PATH,
            "ERROR_WSMAN_INVALID_FRAGMENT_DIALECT" => WINRM::ERROR_WSMAN_INVALID_FRAGMENT_DIALECT,
            "ERROR_WSMAN_INVALID_FRAGMENT_PATH" => WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH,
            "ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE" => WINRM::ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE,
            "ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED" => WINRM::ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED,
            "ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS" => WINRM::ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS,
            "ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER" => WINRM::ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER,
            "ERROR_WSMAN_SESSION_ALREADY_CLOSED" => WINRM::ERROR_WSMAN_SESSION_ALREADY_CLOSED,
            "ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID" => WINRM::ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID,
            "ERROR_WSMAN_PROVIDER_LOAD_FAILED" => WINRM::ERROR_WSMAN_PROVIDER_LOAD_FAILED,
            "ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE" => WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE,
            "ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE" => WINRM::ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE,
            "ERROR_WSMAN_SECURITY_UNMAPPED" => WINRM::ERROR_WSMAN_SECURITY_UNMAPPED,
            "ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE" => WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE,
            "ERROR_WSMAN_INVALID_HOSTNAME_PATTERN" => WINRM::ERROR_WSMAN_INVALID_HOSTNAME_PATTERN,
            "ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO" => WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO,
            "ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS" => WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS,
            "ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS" => WINRM::ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS,
            "ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY" => WINRM::ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY,
            "ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT" => WINRM::ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT,
            "ERROR_WSMAN_MACHINE_OPTION_REQUIRED" => WINRM::ERROR_WSMAN_MACHINE_OPTION_REQUIRED,
            "ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS" => WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS,
            "ERROR_WSMAN_BATCHSIZE_TOO_SMALL" => WINRM::ERROR_WSMAN_BATCHSIZE_TOO_SMALL,
            "ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID" => WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID,
            "ERROR_WSMAN_PROVSYS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_PROVSYS_NOT_SUPPORTED,
            "ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID" => WINRM::ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID,
            "ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG" => WINRM::ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG,
            "ERROR_WSMAN_CLIENT_INVALID_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_FLAG,
            "ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS" => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS,
            "ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH" => WINRM::ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH,
            "ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS" => WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS,
            "ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED" => WINRM::ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED,
            "ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME" => WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME,
            "ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED" => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED,
            "ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED" => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED,
            "ERROR_WSMAN_CLIENT_CERT_NEEDED" => WINRM::ERROR_WSMAN_CLIENT_CERT_NEEDED,
            "ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE" => WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE,
            "ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION" => WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION,
            "ERROR_WSMAN_CLIENT_INVALID_CERT" => WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT,
            "ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS" => WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS,
            "ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS" => WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS,
            "ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM" => WINRM::ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM,
            "ERROR_WSMAN_CLIENT_NO_HANDLE" => WINRM::ERROR_WSMAN_CLIENT_NO_HANDLE,
            "ERROR_WSMAN_CLIENT_BLANK_URI" => WINRM::ERROR_WSMAN_CLIENT_BLANK_URI,
            "ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR" => WINRM::ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR,
            "ERROR_WSMAN_CLIENT_BLANK_INPUT_XML" => WINRM::ERROR_WSMAN_CLIENT_BLANK_INPUT_XML,
            "ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL" => WINRM::ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL,
            "ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL" => WINRM::ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL,
            "ERROR_WSMAN_CLIENT_BLANK_ACTION_URI" => WINRM::ERROR_WSMAN_CLIENT_BLANK_ACTION_URI,
            "ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT" => WINRM::ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT,
            "ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES" => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES,
            "ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES" => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES,
            "ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE" => WINRM::ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE,
            "ERROR_WSMAN_CLIENT_MISSING_EXPIRATION" => WINRM::ERROR_WSMAN_CLIENT_MISSING_EXPIRATION,
            "ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS" => WINRM::ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS,
            "ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT" => WINRM::ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT,
            "ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG" => WINRM::ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG,
            "ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION" => WINRM::ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION,
            "ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM,
            "ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM" => WINRM::ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY" => WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY,
            "ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP" => WINRM::ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP,
            "ERROR_WSMAN_CONNECTIONSTR_INVALID" => WINRM::ERROR_WSMAN_CONNECTIONSTR_INVALID,
            "ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED,
            "ERROR_WSMAN_PORT_INVALID" => WINRM::ERROR_WSMAN_PORT_INVALID,
            "ERROR_WSMAN_CONFIG_PORT_INVALID" => WINRM::ERROR_WSMAN_CONFIG_PORT_INVALID,
            "ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR" => WINRM::ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR,
            "ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED,
            "ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED,
            "ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED,
            "ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED,
            "ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED,
            "ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED,
            "ERROR_WSMAN_SERVER_NOT_TRUSTED" => WINRM::ERROR_WSMAN_SERVER_NOT_TRUSTED,
            "ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED" => WINRM::ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED,
            "ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK" => WINRM::ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK,
            "ERROR_WSMAN_CERT_THUMBPRINT_BLANK" => WINRM::ERROR_WSMAN_CERT_THUMBPRINT_BLANK,
            "ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG" => WINRM::ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG,
            "ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME" => WINRM::ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME,
            "ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT" => WINRM::ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT,
            "ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY" => WINRM::ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY,
            "ERROR_WSMAN_INVALID_IPFILTER" => WINRM::ERROR_WSMAN_INVALID_IPFILTER,
            "ERROR_WSMAN_CANNOT_CHANGE_KEYS" => WINRM::ERROR_WSMAN_CANNOT_CHANGE_KEYS,
            "ERROR_WSMAN_CERT_INVALID_USAGE" => WINRM::ERROR_WSMAN_CERT_INVALID_USAGE,
            "ERROR_WSMAN_RESPONSE_NO_RESULTS" => WINRM::ERROR_WSMAN_RESPONSE_NO_RESULTS,
            "ERROR_WSMAN_CREATE_RESPONSE_NO_EPR" => WINRM::ERROR_WSMAN_CREATE_RESPONSE_NO_EPR,
            "ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT" => WINRM::ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT,
            "ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER" => WINRM::ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER,
            "ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER" => WINRM::ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER,
            "ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY" => WINRM::ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY,
            "ERROR_WSMAN_HTTP_NO_RESPONSE_DATA" => WINRM::ERROR_WSMAN_HTTP_NO_RESPONSE_DATA,
            "ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT" => WINRM::ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT,
            "ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA" => WINRM::ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA,
            "ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA" => WINRM::ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA,
            "ERROR_WSMAN_CANNOT_DECRYPT" => WINRM::ERROR_WSMAN_CANNOT_DECRYPT,
            "ERROR_WSMAN_INVALID_URI_WMI_SINGLETON" => WINRM::ERROR_WSMAN_INVALID_URI_WMI_SINGLETON,
            "ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL" => WINRM::ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL,
            "ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION" => WINRM::ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION,
            "ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION" => WINRM::ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION,
            "ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER" => WINRM::ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER,
            "ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED,
            "ERROR_WSMAN_WMI_MAX_NESTED" => WINRM::ERROR_WSMAN_WMI_MAX_NESTED,
            "ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED,
            "ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE" => WINRM::ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE,
            "ERROR_WSMAN_WMI_INVALID_VALUE" => WINRM::ERROR_WSMAN_WMI_INVALID_VALUE,
            "ERROR_WSMAN_WMI_SVC_ACCESS_DENIED" => WINRM::ERROR_WSMAN_WMI_SVC_ACCESS_DENIED,
            "ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED" => WINRM::ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED,
            "ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED" => WINRM::ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED,
            "ERROR_WSMAN_INVALID_FILTER_XML" => WINRM::ERROR_WSMAN_INVALID_FILTER_XML,
            "ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY" => WINRM::ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY,
            "ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK" => WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK,
            "ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE" => WINRM::ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE,
            "ERROR_WSMAN_KERBEROS_IPADDRESS" => WINRM::ERROR_WSMAN_KERBEROS_IPADDRESS,
            "ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS" => WINRM::ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS,
            "ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER" => WINRM::ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER,
            "ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST" => WINRM::ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST,
            "ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED" => WINRM::ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED,
            "ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT" => WINRM::ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT,
            "ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS" => WINRM::ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS,
            "ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS" => WINRM::ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS,
            "ERROR_WSMAN_HTTP_NOT_FOUND_STATUS" => WINRM::ERROR_WSMAN_HTTP_NOT_FOUND_STATUS,
            "ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY" => WINRM::ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY,
            "ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED" => WINRM::ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED,
            "ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED" => WINRM::ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED,
            "ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED" => WINRM::ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED,
            "ERROR_WSMAN_INVALID_SELECTOR_NAME" => WINRM::ERROR_WSMAN_INVALID_SELECTOR_NAME,
            "ERROR_WSMAN_ENCODING_TYPE" => WINRM::ERROR_WSMAN_ENCODING_TYPE,
            "ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE" => WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE,
            "ERROR_WSMAN_INVALID_HEADER" => WINRM::ERROR_WSMAN_INVALID_HEADER,
            "ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE" => WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE,
            "ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED,
            "ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER" => WINRM::ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER,
            "ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS" => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS,
            "ERROR_WINRS_CLIENT_INVALID_FLAG" => WINRM::ERROR_WINRS_CLIENT_INVALID_FLAG,
            "ERROR_WINRS_CLIENT_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_NULL_PARAM,
            "ERROR_WSMAN_CANNOT_PROCESS_FILTER" => WINRM::ERROR_WSMAN_CANNOT_PROCESS_FILTER,
            "ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM,
            "ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT" => WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT,
            "ERROR_WSMAN_ADDOBJECT_MISSING_EPR" => WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_EPR,
            "ERROR_WSMAN_NETWORK_TIMEDOUT" => WINRM::ERROR_WSMAN_NETWORK_TIMEDOUT,
            "ERROR_WINRS_RECEIVE_IN_PROGRESS" => WINRM::ERROR_WINRS_RECEIVE_IN_PROGRESS,
            "ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA" => WINRM::ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA,
            "ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM,
            "ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM,
            "ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM,
            "ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM,
            "ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM,
            "ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM,
            "ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM,
            "ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM,
            "ERROR_WINRS_CLIENT_PULL_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_PULL_NULL_PARAM,
            "ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM,
            "ERROR_WINRS_CLIENT_SEND_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_SEND_NULL_PARAM,
            "ERROR_WINRS_CLIENT_PUSH_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_PUSH_NULL_PARAM,
            "ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM,
            "ERROR_WINRS_CLIENT_GET_NULL_PARAM" => WINRM::ERROR_WINRS_CLIENT_GET_NULL_PARAM,
            "ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED" => WINRM::ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED,
            "ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE" => WINRM::ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE,
            "ERROR_WSMAN_URI_NON_DMTF_CLASS" => WINRM::ERROR_WSMAN_URI_NON_DMTF_CLASS,
            "ERROR_WSMAN_URI_WRONG_DMTF_VERSION" => WINRM::ERROR_WSMAN_URI_WRONG_DMTF_VERSION,
            "ERROR_WSMAN_DIFFERENT_CIM_SELECTOR" => WINRM::ERROR_WSMAN_DIFFERENT_CIM_SELECTOR,
            "ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT" => WINRM::ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT,
            "ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER" => WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER,
            "ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR" => WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR,
            "ERROR_WSMAN_CONFIG_READONLY_PROPERTY" => WINRM::ERROR_WSMAN_CONFIG_READONLY_PROPERTY,
            "ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED" => WINRM::ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED,
            "ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS" => WINRM::ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS,
            "ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK" => WINRM::ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK,
            "ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS" => WINRM::ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS,
            "ERROR_WSMAN_MULTIPLE_CREDENTIALS" => WINRM::ERROR_WSMAN_MULTIPLE_CREDENTIALS,
            "ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG" => WINRM::ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG,
            "ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION" => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION,
            "ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED" => WINRM::ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED,
            "ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN" => WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN,
            "ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME" => WINRM::ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME,
            "ERROR_WSMAN_SHELL_ALREADY_CLOSED" => WINRM::ERROR_WSMAN_SHELL_ALREADY_CLOSED,
            "ERROR_WSMAN_CREATESHELL_NULL_STREAMID" => WINRM::ERROR_WSMAN_CREATESHELL_NULL_STREAMID,
            "ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE" => WINRM::ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE,
            "ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE" => WINRM::ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE,
            "ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT" => WINRM::ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT,
            "ERROR_WSMAN_COMMAND_ALREADY_CLOSED" => WINRM::ERROR_WSMAN_COMMAND_ALREADY_CLOSED,
            "ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX" => WINRM::ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX,
            "ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED" => WINRM::ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED,
            "ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION" => WINRM::ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION,
            "ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED" => WINRM::ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED,
            "ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS" => WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS,
            "ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT" => WINRM::ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT,
            "ERROR_WSMAN_CERT_MISSING_AUTH_FLAG" => WINRM::ERROR_WSMAN_CERT_MISSING_AUTH_FLAG,
            "ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG" => WINRM::ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG,
            "ERROR_WSMAN_CONFIG_SHELL_URI_INVALID" => WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_INVALID,
            "ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED" => WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED,
            "ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH" => WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH,
            "ERROR_WINRS_SHELL_URI_INVALID" => WINRM::ERROR_WINRS_SHELL_URI_INVALID,
            "ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR" => WINRM::ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR,
            "ERROR_WSMAN_POLICY_TOO_COMPLEX" => WINRM::ERROR_WSMAN_POLICY_TOO_COMPLEX,
            "ERROR_WSMAN_POLICY_CANNOT_COMPLY" => WINRM::ERROR_WSMAN_POLICY_CANNOT_COMPLY,
            "ERROR_WSMAN_INVALID_CONNECTIONRETRY" => WINRM::ERROR_WSMAN_INVALID_CONNECTIONRETRY,
            "ERROR_WSMAN_URISECURITY_INVALIDURIKEY" => WINRM::ERROR_WSMAN_URISECURITY_INVALIDURIKEY,
            "ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY" => WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY,
            "ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY" => WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY,
            "ERROR_WSMAN_INVALID_PUBLISHERS_TYPE" => WINRM::ERROR_WSMAN_INVALID_PUBLISHERS_TYPE,
            "ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY" => WINRM::ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY,
            "ERROR_WSMAN_CLIENT_NULL_PUBLISHERS" => WINRM::ERROR_WSMAN_CLIENT_NULL_PUBLISHERS,
            "ERROR_WSMAN_CLIENT_NULL_ISSUERS" => WINRM::ERROR_WSMAN_CLIENT_NULL_ISSUERS,
            "ERROR_WSMAN_CLIENT_NO_SOURCES" => WINRM::ERROR_WSMAN_CLIENT_NO_SOURCES,
            "ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT" => WINRM::ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT,
            "ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE" => WINRM::ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE,
            "ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG" => WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG,
            "ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK" => WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK,
            "ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE" => WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE,
            "ERROR_WSMAN_INVALID_PROVIDER_RESPONSE" => WINRM::ERROR_WSMAN_INVALID_PROVIDER_RESPONSE,
            "ERROR_WSMAN_SHELL_NOT_INITIALIZED" => WINRM::ERROR_WSMAN_SHELL_NOT_INITIALIZED,
            "ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY" => WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY,
            "ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR" => WINRM::ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR,
            "ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST" => WINRM::ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST,
            "ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS" => WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS,
            "ERROR_WSMAN_HTML_ERROR" => WINRM::ERROR_WSMAN_HTML_ERROR,
            "ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG,
            "ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG,
            "ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM" => WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM,
            "ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM" => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM,
            "ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG,
            "ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG,
            "ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG,
            "ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG,
            "ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED" => WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED,
            "ERROR_WSMAN_NO_COMMAND_RESPONSE" => WINRM::ERROR_WSMAN_NO_COMMAND_RESPONSE,
            "ERROR_WSMAN_INVALID_OPTIONSET" => WINRM::ERROR_WSMAN_INVALID_OPTIONSET,
            "ERROR_WSMAN_NO_COMMANDID" => WINRM::ERROR_WSMAN_NO_COMMANDID,
            "ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG,
            "ERROR_WSMAN_CLIENT_SEND_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_SEND_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG,
            "ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER" => WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER,
            "ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM" => WINRM::ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM,
            "ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM,
            "ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS" => WINRM::ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS,
            "ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG,
            "ERROR_WSMAN_NO_RECEIVE_RESPONSE" => WINRM::ERROR_WSMAN_NO_RECEIVE_RESPONSE,
            "ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED" => WINRM::ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED,
            "ERROR_WSMAN_INVALID_FILEPATH" => WINRM::ERROR_WSMAN_INVALID_FILEPATH,
            "ERROR_WSMAN_FILE_NOT_PRESENT" => WINRM::ERROR_WSMAN_FILE_NOT_PRESENT,
            "ERROR_WSMAN_IISCONFIGURATION_READ_FAILED" => WINRM::ERROR_WSMAN_IISCONFIGURATION_READ_FAILED,
            "ERROR_WSMAN_CLIENT_INVALID_LOCALE" => WINRM::ERROR_WSMAN_CLIENT_INVALID_LOCALE,
            "ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE" => WINRM::ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE,
            "ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE" => WINRM::ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE,
            "ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG,
            "ERROR_WSMAN_REDIRECT_REQUESTED" => WINRM::ERROR_WSMAN_REDIRECT_REQUESTED,
            "ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG" => WINRM::ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG,
            "ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION" => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION,
            "ERROR_WSMAN_PROXY_ACCESS_TYPE" => WINRM::ERROR_WSMAN_PROXY_ACCESS_TYPE,
            "ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER" => WINRM::ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER,
            "ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM" => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM,
            "ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM" => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM,
            "ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED" => WINRM::ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED,
            "ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED" => WINRM::ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED,
            "ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS" => WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS,
            "ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY" => WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY,
            "ERROR_WSMAN_QUOTA_MAX_SHELLS" => WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS,
            "ERROR_WSMAN_QUOTA_MAX_OPERATIONS" => WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS,
            "ERROR_WSMAN_QUOTA_USER" => WINRM::ERROR_WSMAN_QUOTA_USER,
            "ERROR_WSMAN_QUOTA_SYSTEM" => WINRM::ERROR_WSMAN_QUOTA_SYSTEM,
            "ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN" => WINRM::ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN,
            "ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE" => WINRM::ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE,
            "ERROR_WSMAN_QUOTA_MAX_SHELLUSERS" => WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLUSERS,
            "ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED" => WINRM::ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED,
            "ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM" => WINRM::ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM,
            "ERROR_WSMAN_DEPRECATED_CONFIG_SETTING" => WINRM::ERROR_WSMAN_DEPRECATED_CONFIG_SETTING,
            "ERROR_WSMAN_URI_SECURITY_URI" => WINRM::ERROR_WSMAN_URI_SECURITY_URI,
            "ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP" => WINRM::ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP,
            "ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP" => WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP,
            "ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS" => WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS,
            "ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP" => WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP,
            "ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS" => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS,
            "ERROR_WSMAN_INVALID_REDIRECT_ERROR" => WINRM::ERROR_WSMAN_INVALID_REDIRECT_ERROR,
            "ERROR_REDIRECT_LOCATION_TOO_LONG" => WINRM::ERROR_REDIRECT_LOCATION_TOO_LONG,
            "ERROR_REDIRECT_LOCATION_INVALID" => WINRM::ERROR_REDIRECT_LOCATION_INVALID,
            "ERROR_SERVICE_CBT_HARDENING_INVALID" => WINRM::ERROR_SERVICE_CBT_HARDENING_INVALID,
            "ERROR_WSMAN_NAME_NOT_RESOLVED" => WINRM::ERROR_WSMAN_NAME_NOT_RESOLVED,
            "ERROR_WSMAN_SSL_CONNECTION_ABORTED" => WINRM::ERROR_WSMAN_SSL_CONNECTION_ABORTED,
            "ERROR_WSMAN_DEFAULTAUTH_IPADDRESS" => WINRM::ERROR_WSMAN_DEFAULTAUTH_IPADDRESS,
            "ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED" => WINRM::ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED,
            "ERROR_WSMAN_FEATURE_DEPRECATED" => WINRM::ERROR_WSMAN_FEATURE_DEPRECATED,
            "ERROR_WSMAN_INVALID_USESSL_PARAM" => WINRM::ERROR_WSMAN_INVALID_USESSL_PARAM,
            "ERROR_WSMAN_INVALID_CONFIGSDDL_URL" => WINRM::ERROR_WSMAN_INVALID_CONFIGSDDL_URL,
            "ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED" => WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED,
            "ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED" => WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED,
            "ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID" => WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID,
            "ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS" => WINRM::ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS,
            "ERROR_WINRS_SHELL_DISCONNECTED" => WINRM::ERROR_WINRS_SHELL_DISCONNECTED,
            "ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED" => WINRM::ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED,
            "ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH" => WINRM::ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH,
            "ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM,
            "ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM,
            "ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY" => WINRM::ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY,
            "ERROR_WSMAN_COMMAND_TERMINATED" => WINRM::ERROR_WSMAN_COMMAND_TERMINATED,
            "ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT" => WINRM::ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT,
            "ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL" => WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL,
            "ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID" => WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID,
            "ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID" => WINRM::ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID,
            "ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED" => WINRM::ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED,
            "ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM" => WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM,
            "ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID" => WINRM::ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID,
            "ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID" => WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID,
            "ERROR_WINRS_SHELL_CLIENTID_NOT_VALID" => WINRM::ERROR_WINRS_SHELL_CLIENTID_NOT_VALID,
            "ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT" => WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT,
            "ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT" => WINRM::ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT,
            "ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID" => WINRM::ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID,
            "ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY" => WINRM::ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY,
            "ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG" => WINRM::ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG,
            "ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR" => WINRM::ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR,
            "ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT" => WINRM::ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT,
            "ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED" => WINRM::ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED,
            "ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED" => WINRM::ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED,
            "ERROR_WSMAN_CREATESHELL_RUNAS_FAILED" => WINRM::ERROR_WSMAN_CREATESHELL_RUNAS_FAILED,
            "ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED" => WINRM::ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED,
            "ERROR_WSMAN_WRONG_METADATA" => WINRM::ERROR_WSMAN_WRONG_METADATA,
            "ERROR_WSMAN_UNSUPPORTED_TYPE" => WINRM::ERROR_WSMAN_UNSUPPORTED_TYPE,
            "ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED" => WINRM::ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED,
            "ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ,
            "ERROR_WSMAN_QUOTA_MAX_USERS_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MAX_USERS_PPQ,
            "ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ,
            "ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ,
            "ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ,
            "ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ,
            "ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ" => WINRM::ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ,
            "ERROR_WSMAN_NEW_DESERIALIZER" => WINRM::ERROR_WSMAN_NEW_DESERIALIZER,
            "ERROR_WSMAN_DESERIALIZE_CLASS" => WINRM::ERROR_WSMAN_DESERIALIZE_CLASS,
            "ERROR_WSMAN_GETCLASS" => WINRM::ERROR_WSMAN_GETCLASS,
            "ERROR_WSMAN_NEW_SESSION" => WINRM::ERROR_WSMAN_NEW_SESSION,
            "ERROR_WSMAN_NULL_KEY" => WINRM::ERROR_WSMAN_NULL_KEY,
            "ERROR_WSMAN_MUTUAL_AUTH_FAILED" => WINRM::ERROR_WSMAN_MUTUAL_AUTH_FAILED,
            "ERROR_WSMAN_UNSUPPORTED_OCTETTYPE" => WINRM::ERROR_WSMAN_UNSUPPORTED_OCTETTYPE,
            "ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS" => WINRM::ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS,
            "ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC" => WINRM::ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC,
            "ERROR_WSMAN_INVALID_LITERAL_URI" => WINRM::ERROR_WSMAN_INVALID_LITERAL_URI,
            "ERROR_WSMAN_OBJECTONLY_INVALID" => WINRM::ERROR_WSMAN_OBJECTONLY_INVALID,
            "ERROR_WSMAN_MISSING_CLASSNAME" => WINRM::ERROR_WSMAN_MISSING_CLASSNAME,
            "ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY" => WINRM::ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY,
            "ERROR_WSMAN_DESTINATION_INVALID" => WINRM::ERROR_WSMAN_DESTINATION_INVALID,
            "ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY" => WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY,
            "ERROR_WSMAN_CLIENT_SESSION_UNUSABLE" => WINRM::ERROR_WSMAN_CLIENT_SESSION_UNUSABLE,
        }
    }
    pub fn from_code(code: u32) -> WINRM {
        return match code {
            0x80338000 => WINRM::ERROR_WSMAN_RESOURCE_NOT_FOUND,
            0x80338001 => WINRM::ERROR_WSMAN_INVALID_ACTIONURI,
            0x80338002 => WINRM::ERROR_WSMAN_INVALID_URI,
            0x80338003 => WINRM::ERROR_WSMAN_PROVIDER_FAILURE,
            0x80338004 => WINRM::ERROR_WSMAN_BATCH_COMPLETE,
            0x80338005 => WINRM::ERROR_WSMAN_CONFIG_CORRUPTED,
            0x80338006 => WINRM::ERROR_WSMAN_PULL_IN_PROGRESS,
            0x80338007 => WINRM::ERROR_WSMAN_ENUMERATION_CLOSED,
            0x80338008 => WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSED,
            0x80338009 => WINRM::ERROR_WSMAN_SUBSCRIPTION_CLOSE_IN_PROGRESS,
            0x8033800A => WINRM::ERROR_WSMAN_SUBSCRIPTION_CLIENT_DID_NOT_CALL_WITHIN_HEARTBEAT,
            0x8033800B => WINRM::ERROR_WSMAN_SUBSCRIPTION_NO_HEARTBEAT,
            0x8033800C => WINRM::ERROR_WSMAN_UNSUPPORTED_TIMEOUT,
            0x8033800D => WINRM::ERROR_WSMAN_SOAP_VERSION_MISMATCH,
            0x8033800E => WINRM::ERROR_WSMAN_SOAP_DATA_ENCODING_UNKNOWN,
            0x8033800F => WINRM::ERROR_WSMAN_INVALID_MESSAGE_INFORMATION_HEADER,
            0x80338010 => WINRM::ERROR_WSMAN_SOAP_FAULT_MUST_UNDERSTAND,
            0x80338011 => WINRM::ERROR_WSMAN_MESSAGE_INFORMATION_HEADER_REQUIRED,
            0x80338012 => WINRM::ERROR_WSMAN_DESTINATION_UNREACHABLE,
            0x80338013 => WINRM::ERROR_WSMAN_ACTION_NOT_SUPPORTED,
            0x80338014 => WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE,
            0x80338015 => WINRM::ERROR_WSMAN_INVALID_REPRESENTATION,
            0x80338016 => WINRM::ERROR_WSMAN_ENUMERATE_INVALID_EXPIRATION_TIME,
            0x80338017 => WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TIME,
            0x80338018 => WINRM::ERROR_WSMAN_ENUMERATE_FILTERING_NOT_SUPPORTED,
            0x80338019 => WINRM::ERROR_WSMAN_ENUMERATE_FILTER_DIALECT_REQUESTED_UNAVAILABLE,
            0x8033801A => WINRM::ERROR_WSMAN_ENUMERATE_CANNOT_PROCESS_FILTER,
            0x8033801B => WINRM::ERROR_WSMAN_ENUMERATE_INVALID_ENUMERATION_CONTEXT,
            0x8033801C => WINRM::ERROR_WSMAN_ENUMERATE_TIMED_OUT,
            0x8033801D => WINRM::ERROR_WSMAN_ENUMERATE_UNABLE_TO_RENEW,
            0x8033801E => WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_UNAVAILABLE,
            0x8033801F => WINRM::ERROR_WSMAN_EVENTING_INVALID_EXPIRATION_TIME,
            0x80338020 => WINRM::ERROR_WSMAN_EVENTING_UNSUPPORTED_EXPIRATION_TYPE,
            0x80338021 => WINRM::ERROR_WSMAN_EVENTING_FILTERING_NOT_SUPPORTED,
            0x80338022 => WINRM::ERROR_WSMAN_EVENTING_FILTERING_REQUESTED_UNAVAILABLE,
            0x80338023 => WINRM::ERROR_WSMAN_EVENTING_SOURCE_UNABLE_TO_PROCESS,
            0x80338024 => WINRM::ERROR_WSMAN_EVENTING_UNABLE_TO_RENEW,
            0x80338025 => WINRM::ERROR_WSMAN_EVENTING_INVALID_MESSAGE,
            0x80338026 => WINRM::ERROR_WSMAN_ENVELOPE_TOO_LARGE,
            0x80338027 => WINRM::ERROR_WSMAN_INVALID_SOAP_BODY,
            0x80338028 => WINRM::ERROR_WSMAN_INVALID_RESUMPTION_CONTEXT,
            0x80338029 => WINRM::ERROR_WSMAN_OPERATION_TIMEDOUT,
            0x8033802A => WINRM::ERROR_WSMAN_RESUMPTION_NOT_SUPPORTED,
            0x8033802B => WINRM::ERROR_WSMAN_RESUMPTION_TYPE_NOT_SUPPORTED,
            0x8033802C => WINRM::ERROR_WSMAN_UNSUPPORTED_ENCODING,
            0x8033802D => WINRM::ERROR_WSMAN_URI_LIMIT,
            0x8033802E => WINRM::ERROR_WSMAN_INVALID_PROPOSED_ID,
            0x8033802F => WINRM::ERROR_WSMAN_INVALID_BATCH_PARAMETER,
            0x80338030 => WINRM::ERROR_WSMAN_NO_ACK,
            0x80338031 => WINRM::ERROR_WSMAN_ACTION_MISMATCH,
            0x80338032 => WINRM::ERROR_WSMAN_CONCURRENCY,
            0x80338033 => WINRM::ERROR_WSMAN_ALREADY_EXISTS,
            0x80338034 => WINRM::ERROR_WSMAN_DELIVERY_REFUSED,
            0x80338035 => WINRM::ERROR_WSMAN_ENCODING_LIMIT,
            0x80338036 => WINRM::ERROR_WSMAN_FAILED_AUTHENTICATION,
            0x80338037 => WINRM::ERROR_WSMAN_INCOMPATIBLE_EPR,
            0x80338038 => WINRM::ERROR_WSMAN_INVALID_BOOKMARK,
            0x80338039 => WINRM::ERROR_WSMAN_INVALID_OPTIONS,
            0x8033803A => WINRM::ERROR_WSMAN_INVALID_PARAMETER,
            0x8033803B => WINRM::ERROR_WSMAN_INVALID_RESOURCE_URI,
            0x8033803C => WINRM::ERROR_WSMAN_INVALID_SYSTEM,
            0x8033803D => WINRM::ERROR_WSMAN_INVALID_SELECTORS,
            0x8033803E => WINRM::ERROR_WSMAN_METADATA_REDIRECT,
            0x8033803F => WINRM::ERROR_WSMAN_QUOTA_LIMIT,
            0x80338040 => WINRM::ERROR_WSMAN_RENAME_FAILURE,
            0x80338041 => WINRM::ERROR_WSMAN_SCHEMA_VALIDATION_ERROR,
            0x80338042 => WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE,
            0x80338043 => WINRM::ERROR_WSMAN_INVALID_XML,
            0x80338044 => WINRM::ERROR_WSMAN_INVALID_KEY,
            0x80338045 => WINRM::ERROR_WSMAN_DELIVER_IN_PROGRESS,
            0x80338046 => WINRM::ERROR_WSMAN_SYSTEM_NOT_FOUND,
            0x80338047 => WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE,
            0x80338048 => WINRM::ERROR_WSMAN_MAX_ENVELOPE_SIZE_EXCEEDED,
            0x80338049 => WINRM::ERROR_WSMAN_SERVER_ENVELOPE_LIMIT,
            0x8033804A => WINRM::ERROR_WSMAN_SELECTOR_LIMIT,
            0x8033804B => WINRM::ERROR_WSMAN_OPTION_LIMIT,
            0x8033804C => WINRM::ERROR_WSMAN_CHARACTER_SET,
            0x8033804D => WINRM::ERROR_WSMAN_UNREPORTABLE_SUCCESS,
            0x8033804E => WINRM::ERROR_WSMAN_WHITESPACE,
            0x8033804F => WINRM::ERROR_WSMAN_FILTERING_REQUIRED,
            0x80338050 => WINRM::ERROR_WSMAN_BOOKMARK_EXPIRED,
            0x80338051 => WINRM::ERROR_WSMAN_OPTIONS_NOT_SUPPORTED,
            0x80338052 => WINRM::ERROR_WSMAN_OPTIONS_INVALID_NAME,
            0x80338053 => WINRM::ERROR_WSMAN_OPTIONS_INVALID_VALUE,
            0x80338054 => WINRM::ERROR_WSMAN_PARAMETER_TYPE_MISMATCH,
            0x80338055 => WINRM::ERROR_WSMAN_INVALID_PARAMETER_NAME,
            0x80338056 => WINRM::ERROR_WSMAN_INVALID_XML_VALUES,
            0x80338057 => WINRM::ERROR_WSMAN_INVALID_XML_MISSING_VALUES,
            0x80338058 => WINRM::ERROR_WSMAN_INVALID_XML_NAMESPACE,
            0x80338059 => WINRM::ERROR_WSMAN_INVALID_XML_FRAGMENT,
            0x8033805A => WINRM::ERROR_WSMAN_INSUFFCIENT_SELECTORS,
            0x8033805B => WINRM::ERROR_WSMAN_UNEXPECTED_SELECTORS,
            0x8033805C => WINRM::ERROR_WSMAN_SELECTOR_TYPEMISMATCH,
            0x8033805D => WINRM::ERROR_WSMAN_INVALID_SELECTOR_VALUE,
            0x8033805E => WINRM::ERROR_WSMAN_AMBIGUOUS_SELECTORS,
            0x8033805F => WINRM::ERROR_WSMAN_DUPLICATE_SELECTORS,
            0x80338060 => WINRM::ERROR_WSMAN_INVALID_TARGET_SELECTORS,
            0x80338061 => WINRM::ERROR_WSMAN_INVALID_TARGET_RESOURCEURI,
            0x80338062 => WINRM::ERROR_WSMAN_INVALID_TARGET_SYSTEM,
            0x80338063 => WINRM::ERROR_WSMAN_TARGET_ALREADY_EXISTS,
            0x80338064 => WINRM::ERROR_WSMAN_AUTHORIZATION_MODE_NOT_SUPPORTED,
            0x80338065 => WINRM::ERROR_WSMAN_ACK_NOT_SUPPORTED,
            0x80338066 => WINRM::ERROR_WSMAN_OPERATION_TIMEOUT_NOT_SUPPORTED,
            0x80338067 => WINRM::ERROR_WSMAN_LOCALE_NOT_SUPPORTED,
            0x80338068 => WINRM::ERROR_WSMAN_EXPIRATION_TIME_NOT_SUPPORTED,
            0x80338069 => WINRM::ERROR_WSMAN_DELIVERY_RETRIES_NOT_SUPPORTED,
            0x8033806A => WINRM::ERROR_WSMAN_HEARTBEATS_NOT_SUPPORTED,
            0x8033806B => WINRM::ERROR_WSMAN_BOOKMARKS_NOT_SUPPORTED,
            0x8033806C => WINRM::ERROR_WSMAN_MAXITEMS_NOT_SUPPORTED,
            0x8033806D => WINRM::ERROR_WSMAN_MAXTIME_NOT_SUPPORTED,
            0x8033806E => WINRM::ERROR_WSMAN_MAXENVELOPE_SIZE_NOT_SUPPORTED,
            0x8033806F => WINRM::ERROR_WSMAN_MAXENVELOPE_POLICY_NOT_SUPPORTED,
            0x80338070 => WINRM::ERROR_WSMAN_FILTERING_REQUIRED_NOT_SUPPORTED,
            0x80338071 => WINRM::ERROR_WSMAN_INSECURE_ADDRESS_NOT_SUPPORTED,
            0x80338072 => WINRM::ERROR_WSMAN_FORMAT_MISMATCH_NOT_SUPPORTED,
            0x80338073 => WINRM::ERROR_WSMAN_FORMAT_SECURITY_TOKEN_NOT_SUPPORTED,
            0x80338074 => WINRM::ERROR_WSMAN_BAD_METHOD,
            0x80338075 => WINRM::ERROR_WSMAN_UNSUPPORTED_MEDIA,
            0x80338076 => WINRM::ERROR_WSMAN_UNSUPPORTED_ADDRESSING_MODE,
            0x80338077 => WINRM::ERROR_WSMAN_FRAGMENT_TRANSFER_NOT_SUPPORTED,
            0x80338078 => WINRM::ERROR_WSMAN_ENUMERATION_INITIALIZING,
            0x80338079 => WINRM::ERROR_WSMAN_CONNECTOR_GET,
            0x8033807A => WINRM::ERROR_WSMAN_URI_QUERY_STRING_SYNTAX_ERROR,
            0x8033807B => WINRM::ERROR_WSMAN_INEXISTENT_MAC_ADDRESS,
            0x8033807C => WINRM::ERROR_WSMAN_NO_UNICAST_ADDRESSES,
            0x8033807D => WINRM::ERROR_WSMAN_NO_DHCP_ADDRESSES,
            0x8033807E => WINRM::ERROR_WSMAN_MIN_ENVELOPE_SIZE,
            0x8033807F => WINRM::ERROR_WSMAN_EPR_NESTING_EXCEEDED,
            0x80338080 => WINRM::ERROR_WSMAN_REQUEST_INIT_ERROR,
            0x80338081 => WINRM::ERROR_WSMAN_INVALID_TIMEOUT_HEADER,
            0x80338082 => WINRM::ERROR_WSMAN_CERT_NOT_FOUND,
            0x80338083 => WINRM::ERROR_WSMAN_PLUGIN_FAILED,
            0x80338084 => WINRM::ERROR_WSMAN_ENUMERATION_INVALID,
            0x80338085 => WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_MUTUAL,
            0x80338086 => WINRM::ERROR_WSMAN_ENUMERATION_MODE_UNSUPPORTED,
            0x80338087 => WINRM::ERROR_WSMAN_MUSTUNDERSTAND_ON_LOCALE_UNSUPPORTED,
            0x80338088 => WINRM::ERROR_WSMAN_POLICY_CORRUPTED,
            0x80338089 => WINRM::ERROR_WSMAN_LISTENER_ADDRESS_INVALID,
            0x8033808A => WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_GPO_CONTROLLED_SETTING,
            0x8033808B => WINRM::ERROR_WSMAN_EVENTING_CONCURRENT_CLIENT_RECEIVE,
            0x8033808C => WINRM::ERROR_WSMAN_EVENTING_FAST_SENDER,
            0x8033808D => WINRM::ERROR_WSMAN_EVENTING_INSECURE_PUSHSUBSCRIPTION_CONNECTION,
            0x8033808E => WINRM::ERROR_WSMAN_EVENTING_INVALID_EVENTSOURCE,
            0x8033808F => WINRM::ERROR_WSMAN_EVENTING_NOMATCHING_LISTENER,
            0x80338090 => WINRM::ERROR_WSMAN_FRAGMENT_DIALECT_REQUESTED_UNAVAILABLE,
            0x80338091 => WINRM::ERROR_WSMAN_MISSING_FRAGMENT_PATH,
            0x80338092 => WINRM::ERROR_WSMAN_INVALID_FRAGMENT_DIALECT,
            0x80338093 => WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH,
            0x80338094 => WINRM::ERROR_WSMAN_EVENTING_INCOMPATIBLE_BATCHPARAMS_AND_DELIVERYMODE,
            0x80338095 => WINRM::ERROR_WSMAN_EVENTING_LOOPBACK_TESTFAILED,
            0x80338096 => WINRM::ERROR_WSMAN_EVENTING_INVALID_ENDTO_ADDRESSS,
            0x80338097 => WINRM::ERROR_WSMAN_EVENTING_INVALID_INCOMING_EVENT_PACKET_HEADER,
            0x80338098 => WINRM::ERROR_WSMAN_SESSION_ALREADY_CLOSED,
            0x80338099 => WINRM::ERROR_WSMAN_SUBSCRIPTION_LISTENER_NOLONGERVALID,
            0x8033809A => WINRM::ERROR_WSMAN_PROVIDER_LOAD_FAILED,
            0x8033809B => WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTIONCLOSED_BYREMOTESERVICE,
            0x8033809C => WINRM::ERROR_WSMAN_EVENTING_DELIVERYFAILED_FROMSOURCE,
            0x8033809D => WINRM::ERROR_WSMAN_SECURITY_UNMAPPED,
            0x8033809E => WINRM::ERROR_WSMAN_EVENTING_SUBSCRIPTION_CANCELLED_BYSOURCE,
            0x8033809F => WINRM::ERROR_WSMAN_INVALID_HOSTNAME_PATTERN,
            0x803380A0 => WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO,
            0x803380A1 => WINRM::ERROR_WSMAN_EVENTING_MISSING_NOTIFYTO_ADDRESSS,
            0x803380A2 => WINRM::ERROR_WSMAN_EVENTING_INVALID_NOTIFYTO_ADDRESSS,
            0x803380A3 => WINRM::ERROR_WSMAN_EVENTING_INVALID_LOCALE_IN_DELIVERY,
            0x803380A4 => WINRM::ERROR_WSMAN_EVENTING_INVALID_HEARTBEAT,
            0x803380A5 => WINRM::ERROR_WSMAN_MACHINE_OPTION_REQUIRED,
            0x803380A6 => WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_OPTIONS,
            0x803380A7 => WINRM::ERROR_WSMAN_BATCHSIZE_TOO_SMALL,
            0x803380A8 => WINRM::ERROR_WSMAN_EVENTING_DELIVERY_MODE_REQUESTED_INVALID,
            0x803380A9 => WINRM::ERROR_WSMAN_PROVSYS_NOT_SUPPORTED,
            0x803380AA => WINRM::ERROR_WSMAN_PUSH_SUBSCRIPTION_CONFIG_INVALID,
            0x803380AB => WINRM::ERROR_WSMAN_CREDS_PASSED_WITH_NO_AUTH_FLAG,
            0x803380AC => WINRM::ERROR_WSMAN_CLIENT_INVALID_FLAG,
            0x803380AD => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_AUTH_FLAGS,
            0x803380AE => WINRM::ERROR_WSMAN_CLIENT_SPN_WRONG_AUTH,
            0x803380AF => WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_CREDS,
            0x803380B0 => WINRM::ERROR_WSMAN_CLIENT_USERNAME_PASSWORD_NEEDED,
            0x803380B1 => WINRM::ERROR_WSMAN_CLIENT_CERT_UNNEEDED_USERNAME,
            0x803380B2 => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_NEEDED,
            0x803380B3 => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FLAG_NEEDED,
            0x803380B4 => WINRM::ERROR_WSMAN_CLIENT_CERT_NEEDED,
            0x803380B5 => WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_TYPE,
            0x803380B6 => WINRM::ERROR_WSMAN_CLIENT_CERT_UNKNOWN_LOCATION,
            0x803380B7 => WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT,
            0x803380B8 => WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CREDS,
            0x803380B9 => WINRM::ERROR_WSMAN_CLIENT_LOCAL_INVALID_CONNECTION_OPTIONS,
            0x803380BA => WINRM::ERROR_WSMAN_CLIENT_CREATESESSION_NULL_PARAM,
            0x803380BB => WINRM::ERROR_WSMAN_CLIENT_ENUMERATE_NULL_PARAM,
            0x803380BC => WINRM::ERROR_WSMAN_CLIENT_SUBSCRIBE_NULL_PARAM,
            0x803380BD => WINRM::ERROR_WSMAN_CLIENT_NULL_RESULT_PARAM,
            0x803380BE => WINRM::ERROR_WSMAN_CLIENT_NO_HANDLE,
            0x803380BF => WINRM::ERROR_WSMAN_CLIENT_BLANK_URI,
            0x803380C0 => WINRM::ERROR_WSMAN_CLIENT_INVALID_RESOURCE_LOCATOR,
            0x803380C1 => WINRM::ERROR_WSMAN_CLIENT_BLANK_INPUT_XML,
            0x803380C2 => WINRM::ERROR_WSMAN_CLIENT_BATCH_ITEMS_TOO_SMALL,
            0x803380C3 => WINRM::ERROR_WSMAN_CLIENT_MAX_CHARS_TOO_SMALL,
            0x803380C4 => WINRM::ERROR_WSMAN_CLIENT_BLANK_ACTION_URI,
            0x803380C5 => WINRM::ERROR_WSMAN_CLIENT_ZERO_HEARTBEAT,
            0x803380C6 => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_DELIVERY_MODES,
            0x803380C7 => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENVELOPE_POLICIES,
            0x803380C8 => WINRM::ERROR_WSMAN_CLIENT_UNKNOWN_EXPIRATION_TYPE,
            0x803380C9 => WINRM::ERROR_WSMAN_CLIENT_MISSING_EXPIRATION,
            0x803380CA => WINRM::ERROR_WSMAN_CLIENT_PULL_INVALID_FLAGS,
            0x803380CB => WINRM::ERROR_WSMAN_CLIENT_PUSH_UNSUPPORTED_TRANSPORT,
            0x803380CC => WINRM::ERROR_WSMAN_CLIENT_PUSH_HOST_TOO_LONG,
            0x803380CD => WINRM::ERROR_WSMAN_CLIENT_COMPRESSION_INVALID_OPTION,
            0x803380CE => WINRM::ERROR_WSMAN_CLIENT_DELIVERENDSUBSCRIPTION_NULL_PARAM,
            0x803380CF => WINRM::ERROR_WSMAN_CLIENT_DELIVEREVENTS_NULL_PARAM,
            0x803380D0 => WINRM::ERROR_WSMAN_CLIENT_GETBOOKMARK_NULL_PARAM,
            0x803380D1 => WINRM::ERROR_WSMAN_CLIENT_DECODEOBJECT_NULL_PARAM,
            0x803380D2 => WINRM::ERROR_WSMAN_CLIENT_ENCODEOBJECT_NULL_PARAM,
            0x803380D3 => WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDOBJECT_NULL_PARAM,
            0x803380D4 => WINRM::ERROR_WSMAN_CLIENT_ENUMERATORNEXTOBJECT_NULL_PARAM,
            0x803380D5 => WINRM::ERROR_WSMAN_CLIENT_CONSTRUCTERROR_NULL_PARAM,
            0x803380D6 => WINRM::ERROR_WSMAN_SERVER_NONPULLSUBSCRIBE_NULL_PARAM,
            0x803380D7 => WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_HTTP_ONLY,
            0x803380D8 => WINRM::ERROR_WSMAN_CANNOT_USE_CERTIFICATES_FOR_HTTP,
            0x803380D9 => WINRM::ERROR_WSMAN_CONNECTIONSTR_INVALID,
            0x803380DA => WINRM::ERROR_WSMAN_TRANSPORT_NOT_SUPPORTED,
            0x803380DB => WINRM::ERROR_WSMAN_PORT_INVALID,
            0x803380DC => WINRM::ERROR_WSMAN_CONFIG_PORT_INVALID,
            0x803380DD => WINRM::ERROR_WSMAN_SENDHEARBEAT_EMPTY_ENUMERATOR,
            0x803380DE => WINRM::ERROR_WSMAN_CLIENT_UNENCRYPTED_DISABLED,
            0x803380DF => WINRM::ERROR_WSMAN_CLIENT_BASIC_AUTHENTICATION_DISABLED,
            0x803380E0 => WINRM::ERROR_WSMAN_CLIENT_DIGEST_AUTHENTICATION_DISABLED,
            0x803380E1 => WINRM::ERROR_WSMAN_CLIENT_NEGOTIATE_AUTHENTICATION_DISABLED,
            0x803380E2 => WINRM::ERROR_WSMAN_CLIENT_KERBEROS_AUTHENTICATION_DISABLED,
            0x803380E3 => WINRM::ERROR_WSMAN_CLIENT_CERTIFICATES_AUTHENTICATION_DISABLED,
            0x803380E4 => WINRM::ERROR_WSMAN_SERVER_NOT_TRUSTED,
            0x803380E5 => WINRM::ERROR_WSMAN_EXPLICIT_CREDENTIALS_REQUIRED,
            0x803380E6 => WINRM::ERROR_WSMAN_CERT_THUMBPRINT_NOT_BLANK,
            0x803380E7 => WINRM::ERROR_WSMAN_CERT_THUMBPRINT_BLANK,
            0x803380E8 => WINRM::ERROR_WSMAN_CONFIG_CANNOT_SHARE_SSL_CONFIG,
            0x803380E9 => WINRM::ERROR_WSMAN_CONFIG_CERT_CN_DOES_NOT_MATCH_HOSTNAME,
            0x803380EA => WINRM::ERROR_WSMAN_CONFIG_HOSTNAME_CHANGE_WITHOUT_CERT,
            0x803380EB => WINRM::ERROR_WSMAN_CONFIG_THUMBPRINT_SHOULD_BE_EMPTY,
            0x803380EC => WINRM::ERROR_WSMAN_INVALID_IPFILTER,
            0x803380ED => WINRM::ERROR_WSMAN_CANNOT_CHANGE_KEYS,
            0x803380EE => WINRM::ERROR_WSMAN_CERT_INVALID_USAGE,
            0x803380EF => WINRM::ERROR_WSMAN_RESPONSE_NO_RESULTS,
            0x803380F0 => WINRM::ERROR_WSMAN_CREATE_RESPONSE_NO_EPR,
            0x803380F1 => WINRM::ERROR_WSMAN_RESPONSE_INVALID_ENUMERATION_CONTEXT,
            0x803380F2 => WINRM::ERROR_WSMAN_RESPONSE_NO_XML_FRAGMENT_WRAPPER,
            0x803380F3 => WINRM::ERROR_WSMAN_RESPONSE_INVALID_MESSAGE_INFORMATION_HEADER,
            0x803380F4 => WINRM::ERROR_WSMAN_RESPONSE_NO_SOAP_HEADER_BODY,
            0x803380F5 => WINRM::ERROR_WSMAN_HTTP_NO_RESPONSE_DATA,
            0x803380F6 => WINRM::ERROR_WSMAN_RESPONSE_INVALID_SOAP_FAULT,
            0x803380F7 => WINRM::ERROR_WSMAN_HTTP_INVALID_CONTENT_TYPE_IN_RESPONSE_DATA,
            0x803380F8 => WINRM::ERROR_WSMAN_HTTP_CONTENT_TYPE_MISSMATCH_RESPONSE_DATA,
            0x803380F9 => WINRM::ERROR_WSMAN_CANNOT_DECRYPT,
            0x803380FA => WINRM::ERROR_WSMAN_INVALID_URI_WMI_SINGLETON,
            0x803380FB => WINRM::ERROR_WSMAN_INVALID_URI_WMI_ENUM_WQL,
            0x803380FC => WINRM::ERROR_WSMAN_NO_IDENTIFY_FOR_LOCAL_SESSION,
            0x803380FD => WINRM::ERROR_WSMAN_NO_PUSH_SUBSCRIPTION_FOR_LOCAL_SESSION,
            0x803380FE => WINRM::ERROR_WSMAN_INVALID_SUBSCRIPTION_MANAGER,
            0x803380FF => WINRM::ERROR_WSMAN_NON_PULL_SUBSCRIPTION_NOT_SUPPORTED,
            0x80338100 => WINRM::ERROR_WSMAN_WMI_MAX_NESTED,
            0x80338101 => WINRM::ERROR_WSMAN_REMOTE_CIMPATH_NOT_SUPPORTED,
            0x80338102 => WINRM::ERROR_WSMAN_WMI_PROVIDER_NOT_CAPABLE,
            0x80338103 => WINRM::ERROR_WSMAN_WMI_INVALID_VALUE,
            0x80338104 => WINRM::ERROR_WSMAN_WMI_SVC_ACCESS_DENIED,
            0x80338105 => WINRM::ERROR_WSMAN_WMI_PROVIDER_ACCESS_DENIED,
            0x80338106 => WINRM::ERROR_WSMAN_WMI_CANNOT_CONNECT_ACCESS_DENIED,
            0x80338107 => WINRM::ERROR_WSMAN_INVALID_FILTER_XML,
            0x80338108 => WINRM::ERROR_WSMAN_ENUMERATE_WMI_INVALID_KEY,
            0x80338109 => WINRM::ERROR_WSMAN_INVALID_FRAGMENT_PATH_BLANK,
            0x8033810A => WINRM::ERROR_WSMAN_INVALID_CHARACTERS_IN_RESPONSE,
            0x8033810B => WINRM::ERROR_WSMAN_KERBEROS_IPADDRESS,
            0x8033810C => WINRM::ERROR_WSMAN_CLIENT_WORKGROUP_NO_KERBEROS,
            0x8033810D => WINRM::ERROR_WSMAN_INVALID_BATCH_SETTINGS_PARAMETER,
            0x8033810E => WINRM::ERROR_WSMAN_SERVER_DESTINATION_LOCALHOST,
            0x8033810F => WINRM::ERROR_WSMAN_UNKNOWN_HTTP_STATUS_RETURNED,
            0x80338110 => WINRM::ERROR_WSMAN_UNSUPPORTED_HTTP_STATUS_REDIRECT,
            0x80338111 => WINRM::ERROR_WSMAN_HTTP_REQUEST_TOO_LARGE_STATUS,
            0x80338112 => WINRM::ERROR_WSMAN_HTTP_SERVICE_UNAVAILABLE_STATUS,
            0x80338113 => WINRM::ERROR_WSMAN_HTTP_NOT_FOUND_STATUS,
            0x80338114 => WINRM::ERROR_WSMAN_EVENTING_MISSING_LOCALE_IN_DELIVERY,
            0x80338115 => WINRM::ERROR_WSMAN_QUICK_CONFIG_FAILED_CERT_REQUIRED,
            0x80338116 => WINRM::ERROR_WSMAN_QUICK_CONFIG_FIREWALL_EXCEPTIONS_DISALLOWED,
            0x80338117 => WINRM::ERROR_WSMAN_QUICK_CONFIG_LOCAL_POLICY_CHANGE_DISALLOWED,
            0x80338118 => WINRM::ERROR_WSMAN_INVALID_SELECTOR_NAME,
            0x80338119 => WINRM::ERROR_WSMAN_ENCODING_TYPE,
            0x8033811A => WINRM::ERROR_WSMAN_ENDPOINT_UNAVAILABLE_INVALID_VALUE,
            0x8033811B => WINRM::ERROR_WSMAN_INVALID_HEADER,
            0x8033811C => WINRM::ERROR_WSMAN_ENUMERATE_UNSUPPORTED_EXPIRATION_TYPE,
            0x8033811D => WINRM::ERROR_WSMAN_MAX_ELEMENTS_NOT_SUPPORTED,
            0x8033811E => WINRM::ERROR_WSMAN_WMI_PROVIDER_INVALID_PARAMETER,
            0x8033811F => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_ENUM_MODE_FLAGS,
            0x80338120 => WINRM::ERROR_WINRS_CLIENT_INVALID_FLAG,
            0x80338121 => WINRM::ERROR_WINRS_CLIENT_NULL_PARAM,
            0x80338122 => WINRM::ERROR_WSMAN_CANNOT_PROCESS_FILTER,
            0x80338123 => WINRM::ERROR_WSMAN_CLIENT_ENUMERATORADDEVENT_NULL_PARAM,
            0x80338124 => WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_OBJECT,
            0x80338125 => WINRM::ERROR_WSMAN_ADDOBJECT_MISSING_EPR,
            0x80338126 => WINRM::ERROR_WSMAN_NETWORK_TIMEDOUT,
            0x80338127 => WINRM::ERROR_WINRS_RECEIVE_IN_PROGRESS,
            0x80338128 => WINRM::ERROR_WINRS_RECEIVE_NO_RESPONSE_DATA,
            0x80338129 => WINRM::ERROR_WINRS_CLIENT_CREATESHELL_NULL_PARAM,
            0x8033812A => WINRM::ERROR_WINRS_CLIENT_CLOSESHELL_NULL_PARAM,
            0x8033812B => WINRM::ERROR_WINRS_CLIENT_FREECREATESHELLRESULT_NULL_PARAM,
            0x8033812C => WINRM::ERROR_WINRS_CLIENT_RUNCOMMAND_NULL_PARAM,
            0x8033812D => WINRM::ERROR_WINRS_CLIENT_FREERUNCOMMANDRESULT_NULL_PARAM,
            0x8033812E => WINRM::ERROR_WINRS_CLIENT_SIGNAL_NULL_PARAM,
            0x8033812F => WINRM::ERROR_WINRS_CLIENT_RECEIVE_NULL_PARAM,
            0x80338130 => WINRM::ERROR_WINRS_CLIENT_FREEPULLRESULT_NULL_PARAM,
            0x80338131 => WINRM::ERROR_WINRS_CLIENT_PULL_NULL_PARAM,
            0x80338132 => WINRM::ERROR_WINRS_CLIENT_CLOSERECEIVEHANDLE_NULL_PARAM,
            0x80338133 => WINRM::ERROR_WINRS_CLIENT_SEND_NULL_PARAM,
            0x80338134 => WINRM::ERROR_WINRS_CLIENT_PUSH_NULL_PARAM,
            0x80338135 => WINRM::ERROR_WINRS_CLIENT_CLOSESENDHANDLE_NULL_PARAM,
            0x80338136 => WINRM::ERROR_WINRS_CLIENT_GET_NULL_PARAM,
            0x80338137 => WINRM::ERROR_WSMAN_POLYMORPHISM_MODE_UNSUPPORTED,
            0x80338138 => WINRM::ERROR_WSMAN_REQUEST_NOT_SUPPORTED_AT_SERVICE,
            0x80338139 => WINRM::ERROR_WSMAN_URI_NON_DMTF_CLASS,
            0x8033813A => WINRM::ERROR_WSMAN_URI_WRONG_DMTF_VERSION,
            0x8033813B => WINRM::ERROR_WSMAN_DIFFERENT_CIM_SELECTOR,
            0x8033813C => WINRM::ERROR_WSMAN_PUSHSUBSCRIPTION_INVALIDUSERACCOUNT,
            0x8033813D => WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_PUBLISHER,
            0x8033813E => WINRM::ERROR_WSMAN_EVENTING_NONDOMAINJOINED_COLLECTOR,
            0x8033813F => WINRM::ERROR_WSMAN_CONFIG_READONLY_PROPERTY,
            0x80338140 => WINRM::ERROR_WINRS_CODE_PAGE_NOT_SUPPORTED,
            0x80338141 => WINRM::ERROR_WSMAN_CLIENT_DISABLE_LOOPBACK_WITH_EXPLICIT_CREDENTIALS,
            0x80338142 => WINRM::ERROR_WSMAN_CLIENT_INVALID_DISABLE_LOOPBACK,
            0x80338143 => WINRM::ERROR_WSMAN_CLIENT_ENUM_RECEIVED_TOO_MANY_ITEMS,
            0x80338144 => WINRM::ERROR_WSMAN_MULTIPLE_CREDENTIALS,
            0x80338145 => WINRM::ERROR_WSMAN_AUTHENTICATION_INVALID_FLAG,
            0x80338146 => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_DEFAULT_AUTHENTICATION,
            0x80338147 => WINRM::ERROR_WSMAN_CLIENT_USERNAME_AND_PASSWORD_NEEDED,
            0x80338148 => WINRM::ERROR_WSMAN_CLIENT_INVALID_CERT_DNS_OR_UPN,
            0x80338149 => WINRM::ERROR_WSMAN_CREATESHELL_NULL_ENVIRONMENT_VARIABLE_NAME,
            0x8033814A => WINRM::ERROR_WSMAN_SHELL_ALREADY_CLOSED,
            0x8033814B => WINRM::ERROR_WSMAN_CREATESHELL_NULL_STREAMID,
            0x8033814C => WINRM::ERROR_WSMAN_SHELL_INVALID_SHELL_HANDLE,
            0x8033814D => WINRM::ERROR_WSMAN_SHELL_INVALID_COMMAND_HANDLE,
            0x8033814E => WINRM::ERROR_WSMAN_RUNSHELLCOMMAND_NULL_ARGUMENT,
            0x8033814F => WINRM::ERROR_WSMAN_COMMAND_ALREADY_CLOSED,
            0x80338150 => WINRM::ERROR_WSMAN_SENDSHELLINPUT_INVALID_STREAMID_INDEX,
            0x80338151 => WINRM::ERROR_WSMAN_SHELL_SYNCHRONOUS_NOT_SUPPORTED,
            0x80338152 => WINRM::ERROR_WSMAN_NO_CERTMAPPING_OPERATION_FOR_LOCAL_SESSION,
            0x80338153 => WINRM::ERROR_WSMAN_CERTMAPPING_CONFIGLIMIT_EXCEEDED,
            0x80338154 => WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDUSERCREDENTIALS,
            0x80338155 => WINRM::ERROR_WSMAN_CERT_INVALID_USAGE_CLIENT,
            0x80338156 => WINRM::ERROR_WSMAN_CERT_MISSING_AUTH_FLAG,
            0x80338157 => WINRM::ERROR_WSMAN_CERT_MULTIPLE_CREDENTIALS_FLAG,
            0x80338158 => WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_INVALID,
            0x80338159 => WINRM::ERROR_WSMAN_CONFIG_SHELL_URI_CMDSHELLURI_NOTPERMITTED,
            0x8033815A => WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_PROCESSPATH,
            0x8033815B => WINRM::ERROR_WINRS_SHELL_URI_INVALID,
            0x8033815C => WINRM::ERROR_WSMAN_INVALID_SECURITY_DESCRIPTOR,
            0x8033815D => WINRM::ERROR_WSMAN_POLICY_TOO_COMPLEX,
            0x8033815E => WINRM::ERROR_WSMAN_POLICY_CANNOT_COMPLY,
            0x8033815F => WINRM::ERROR_WSMAN_INVALID_CONNECTIONRETRY,
            0x80338160 => WINRM::ERROR_WSMAN_URISECURITY_INVALIDURIKEY,
            0x80338161 => WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDSUBJECTKEY,
            0x80338162 => WINRM::ERROR_WSMAN_CERTMAPPING_INVALIDISSUERKEY,
            0x80338163 => WINRM::ERROR_WSMAN_INVALID_PUBLISHERS_TYPE,
            0x80338164 => WINRM::ERROR_WSMAN_CLIENT_INVALID_DELIVERY_RETRY,
            0x80338165 => WINRM::ERROR_WSMAN_CLIENT_NULL_PUBLISHERS,
            0x80338166 => WINRM::ERROR_WSMAN_CLIENT_NULL_ISSUERS,
            0x80338167 => WINRM::ERROR_WSMAN_CLIENT_NO_SOURCES,
            0x80338168 => WINRM::ERROR_WSMAN_INVALID_SUBSCRIBE_OBJECT,
            0x80338169 => WINRM::ERROR_WSMAN_PUBLIC_FIREWALL_PROFILE_ACTIVE,
            0x8033816A => WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDTOOLONG,
            0x8033816B => WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDBLANK,
            0x8033816C => WINRM::ERROR_WSMAN_CERTMAPPING_PASSWORDUSERTUPLE,
            0x8033816D => WINRM::ERROR_WSMAN_INVALID_PROVIDER_RESPONSE,
            0x8033816E => WINRM::ERROR_WSMAN_SHELL_NOT_INITIALIZED,
            0x8033816F => WINRM::ERROR_WSMAN_CONFIG_SHELLURI_INVALID_OPERATION_ON_KEY,
            0x80338170 => WINRM::ERROR_WSMAN_HTTP_STATUS_SERVER_ERROR,
            0x80338171 => WINRM::ERROR_WSMAN_HTTP_STATUS_BAD_REQUEST,
            0x80338172 => WINRM::ERROR_WSMAN_CONFIG_CANNOT_CHANGE_CERTMAPPING_KEYS,
            0x80338173 => WINRM::ERROR_WSMAN_HTML_ERROR,
            0x80338174 => WINRM::ERROR_WSMAN_CLIENT_INITIALIZE_NULL_PARAM,
            0x80338175 => WINRM::ERROR_WSMAN_CLIENT_INVALID_INIT_APPLICATION_FLAG,
            0x80338176 => WINRM::ERROR_WSMAN_CLIENT_INVALID_DEINIT_APPLICATION_FLAG,
            0x80338177 => WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_NULL_PARAM,
            0x80338178 => WINRM::ERROR_WSMAN_CLIENT_SETSESSIONOPTION_INVALID_PARAM,
            0x80338179 => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_INVALID_PARAM,
            0x8033817A => WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NULL_PARAM,
            0x8033817B => WINRM::ERROR_WSMAN_CLIENT_INVALID_CREATE_SHELL_FLAG,
            0x8033817C => WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_SHELL_FLAG,
            0x8033817D => WINRM::ERROR_WSMAN_CLIENT_INVALID_CLOSE_COMMAND_FLAG,
            0x8033817E => WINRM::ERROR_WSMAN_CLIENT_CLOSESHELL_NULL_PARAM,
            0x8033817F => WINRM::ERROR_WSMAN_CLIENT_CLOSECOMMAND_NULL_PARAM,
            0x80338180 => WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NULL_PARAM,
            0x80338181 => WINRM::ERROR_WSMAN_CLIENT_INVALID_RUNCOMMAND_FLAG,
            0x80338182 => WINRM::ERROR_WSMAN_CLIENT_RUNCOMMAND_NOTCOMPLETED,
            0x80338183 => WINRM::ERROR_WSMAN_NO_COMMAND_RESPONSE,
            0x80338184 => WINRM::ERROR_WSMAN_INVALID_OPTIONSET,
            0x80338185 => WINRM::ERROR_WSMAN_NO_COMMANDID,
            0x80338186 => WINRM::ERROR_WSMAN_CLIENT_SIGNAL_NULL_PARAM,
            0x80338187 => WINRM::ERROR_WSMAN_CLIENT_INVALID_SIGNAL_SHELL_FLAG,
            0x80338188 => WINRM::ERROR_WSMAN_CLIENT_SEND_NULL_PARAM,
            0x80338189 => WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_FLAG,
            0x8033818A => WINRM::ERROR_WSMAN_CLIENT_INVALID_SEND_SHELL_PARAMETER,
            0x8033818B => WINRM::ERROR_WSMAN_SHELL_INVALID_INPUT_STREAM,
            0x8033818C => WINRM::ERROR_WSMAN_CLIENT_RECEIVE_NULL_PARAM,
            0x8033818D => WINRM::ERROR_WSMAN_SHELL_INVALID_DESIRED_STREAMS,
            0x8033818E => WINRM::ERROR_WSMAN_CLIENT_INVALID_RECEIVE_SHELL_FLAG,
            0x8033818F => WINRM::ERROR_WSMAN_NO_RECEIVE_RESPONSE,
            0x80338190 => WINRM::ERROR_WSMAN_PLUGIN_CONFIGURATION_CORRUPTED,
            0x80338191 => WINRM::ERROR_WSMAN_INVALID_FILEPATH,
            0x80338192 => WINRM::ERROR_WSMAN_FILE_NOT_PRESENT,
            0x80338193 => WINRM::ERROR_WSMAN_IISCONFIGURATION_READ_FAILED,
            0x80338194 => WINRM::ERROR_WSMAN_CLIENT_INVALID_LOCALE,
            0x80338195 => WINRM::ERROR_WSMAN_CLIENT_INVALID_UI_LANGUAGE,
            0x80338196 => WINRM::ERROR_WSMAN_CLIENT_GETERRORMESSAGE_NULL_PARAM,
            0x80338197 => WINRM::ERROR_WSMAN_CLIENT_INVALID_LANGUAGE_CODE,
            0x80338198 => WINRM::ERROR_WSMAN_CLIENT_INVALID_GETERRORMESSAGE_FLAG,
            0x80338199 => WINRM::ERROR_WSMAN_REDIRECT_REQUESTED,
            0x8033819A => WINRM::ERROR_WSMAN_PROXY_AUTHENTICATION_INVALID_FLAG,
            0x8033819B => WINRM::ERROR_WSMAN_CLIENT_CREDENTIALS_FOR_PROXY_AUTHENTICATION,
            0x8033819C => WINRM::ERROR_WSMAN_PROXY_ACCESS_TYPE,
            0x8033819D => WINRM::ERROR_WSMAN_INVALID_OPTION_NO_PROXY_SERVER,
            0x8033819E => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_NULL_PARAM,
            0x8033819F => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_DWORD_INVALID_PARAM,
            0x803381A0 => WINRM::ERROR_WSMAN_CLIENT_GETSESSIONOPTION_STRING_INVALID_PARAM,
            0x803381A1 => WINRM::ERROR_WSMAN_CREDSSP_USERNAME_PASSWORD_NEEDED,
            0x803381A2 => WINRM::ERROR_WSMAN_CLIENT_CREDSSP_AUTHENTICATION_DISABLED,
            0x803381A3 => WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS,
            0x803381A4 => WINRM::ERROR_WSMAN_CLIENT_ALLOWFRESHCREDENTIALS_NTLMONLY,
            0x803381A5 => WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS,
            0x803381A6 => WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS,
            0x803381A7 => WINRM::ERROR_WSMAN_QUOTA_USER,
            0x803381A8 => WINRM::ERROR_WSMAN_QUOTA_SYSTEM,
            0x803381A9 => WINRM::ERROR_WSMAN_DIFFERENT_AUTHZ_TOKEN,
            0x803381AA => WINRM::ERROR_WSMAN_REDIRECT_LOCATION_NOT_AVAILABLE,
            0x803381AB => WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLUSERS,
            0x803381AC => WINRM::ERROR_WSMAN_REMOTESHELLS_NOT_ALLOWED,
            0x803381AD => WINRM::ERROR_WSMAN_PULL_PARAMS_NOT_SAME_AS_ENUM,
            0x803381AE => WINRM::ERROR_WSMAN_DEPRECATED_CONFIG_SETTING,
            0x803381AF => WINRM::ERROR_WSMAN_URI_SECURITY_URI,
            0x803381B0 => WINRM::ERROR_WSMAN_CANNOT_USE_ALLOW_NEGOTIATE_IMPLICIT_CREDENTIALS_FOR_HTTP,
            0x803381B1 => WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_HTTP,
            0x803381B2 => WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_KERBEROS,
            0x803381B3 => WINRM::ERROR_WSMAN_CANNOT_USE_PROXY_SETTINGS_FOR_CREDSSP,
            0x803381B4 => WINRM::ERROR_WSMAN_CLIENT_MULTIPLE_PROXY_AUTH_FLAGS,
            0x803381B5 => WINRM::ERROR_WSMAN_INVALID_REDIRECT_ERROR,
            0x803381B6 => WINRM::ERROR_REDIRECT_LOCATION_TOO_LONG,
            0x803381B7 => WINRM::ERROR_REDIRECT_LOCATION_INVALID,
            0x803381B8 => WINRM::ERROR_SERVICE_CBT_HARDENING_INVALID,
            0x803381B9 => WINRM::ERROR_WSMAN_NAME_NOT_RESOLVED,
            0x803381BA => WINRM::ERROR_WSMAN_SSL_CONNECTION_ABORTED,
            0x803381BB => WINRM::ERROR_WSMAN_DEFAULTAUTH_IPADDRESS,
            0x803381BC => WINRM::ERROR_WSMAN_CUSTOMREMOTESHELL_DEPRECATED,
            0x803381BD => WINRM::ERROR_WSMAN_FEATURE_DEPRECATED,
            0x803381BE => WINRM::ERROR_WSMAN_INVALID_USESSL_PARAM,
            0x803381BF => WINRM::ERROR_WSMAN_INVALID_CONFIGSDDL_URL,
            0x803381C0 => WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMAMNDS_FILTER_EXPECTED,
            0x803381C1 => WINRM::ERROR_WSMAN_ENUMERATE_SHELLCOMMANDS_EPRS_NOTSUPPORTED,
            0x803381C2 => WINRM::ERROR_WSMAN_CLIENT_CREATESHELL_NAME_INVALID,
            0x803381C3 => WINRM::ERROR_WSMAN_RUNAS_INVALIDUSERCREDENTIALS,
            0x803381C4 => WINRM::ERROR_WINRS_SHELL_DISCONNECTED,
            0x803381C5 => WINRM::ERROR_WINRS_SHELL_DISCONNECT_NOT_SUPPORTED,
            0x803381C6 => WINRM::ERROR_WINRS_SHELL_CLIENTSESSIONID_MISMATCH,
            0x803381C7 => WINRM::ERROR_WSMAN_CLIENT_DISCONNECTSHELL_NULL_PARAM,
            0x803381C8 => WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELL_NULL_PARAM,
            0x803381C9 => WINRM::ERROR_WSMAN_CLIENT_CONNECTSHELL_NULL_PARAM,
            0x803381CA => WINRM::ERROR_WSMAN_CLIENT_CONNECTCOMMAND_NULL_PARAM,
            0x803381CB => WINRM::ERROR_WINRS_CONNECT_RESPONSE_BAD_BODY,
            0x803381CC => WINRM::ERROR_WSMAN_COMMAND_TERMINATED,
            0x803381CD => WINRM::ERROR_WINRS_SHELL_CONNECTED_TO_DIFFERENT_CLIENT,
            0x803381CE => WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_GRACEFUL,
            0x803381CF => WINRM::ERROR_WINRS_SHELL_DISCONNECT_OPERATION_NOT_VALID,
            0x803381D0 => WINRM::ERROR_WINRS_SHELL_RECONNECT_OPERATION_NOT_VALID,
            0x803381D1 => WINRM::ERROR_WSMAN_CONFIG_GROUP_POLICY_CHANGE_NOTIFICATION_SUBSCRIPTION_FAILED,
            0x803381D2 => WINRM::ERROR_WSMAN_CLIENT_RECONNECTSHELLCOMMAND_NULL_PARAM,
            0x803381D3 => WINRM::ERROR_WINRS_SHELLCOMMAND_RECONNECT_OPERATION_NOT_VALID,
            0x803381D4 => WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_NOT_VALID,
            0x803381D5 => WINRM::ERROR_WINRS_SHELL_CLIENTID_NOT_VALID,
            0x803381D6 => WINRM::ERROR_WINRS_SHELLCOMMAND_CLIENTID_RESOURCE_CONFLICT,
            0x803381D7 => WINRM::ERROR_WINRS_SHELL_CLIENTID_RESOURCE_CONFLICT,
            0x803381D8 => WINRM::ERROR_WINRS_SHELLCOMMAND_DISCONNECT_OPERATION_NOT_VALID,
            0x803381D9 => WINRM::ERROR_WSMAN_SUBSCRIBE_WMI_INVALID_KEY,
            0x803381DA => WINRM::ERROR_WSMAN_CLIENT_INVALID_DISCONNECT_SHELL_FLAG,
            0x803381DB => WINRM::ERROR_WSMAN_CLIENT_INVALID_SHELL_COMMAND_PAIR,
            0x803381DC => WINRM::ERROR_WSMAN_SEMANTICCALLBACK_TIMEDOUT,
            0x803381DD => WINRM::ERROR_WSMAN_SERVICE_REMOTE_ACCESS_DISABLED,
            0x803381DE => WINRM::ERROR_WSMAN_SERVICE_STREAM_DISCONNECTED,
            0x803381DF => WINRM::ERROR_WSMAN_CREATESHELL_RUNAS_FAILED,
            0x803381E0 => WINRM::ERROR_WSMAN_INVALID_XML_RUNAS_DISABLED,
            0x803381E1 => WINRM::ERROR_WSMAN_WRONG_METADATA,
            0x803381E2 => WINRM::ERROR_WSMAN_UNSUPPORTED_TYPE,
            0x803381E3 => WINRM::ERROR_WSMAN_REMOTE_CONNECTION_NOT_ALLOWED,
            0x803381E4 => WINRM::ERROR_WSMAN_QUOTA_MAX_SHELLS_PPQ,
            0x803381E5 => WINRM::ERROR_WSMAN_QUOTA_MAX_USERS_PPQ,
            0x803381E6 => WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINSHELLS_PPQ,
            0x803381E7 => WINRM::ERROR_WSMAN_QUOTA_MAX_PLUGINOPERATIONS_PPQ,
            0x803381E8 => WINRM::ERROR_WSMAN_QUOTA_MAX_OPERATIONS_USER_PPQ,
            0x803381E9 => WINRM::ERROR_WSMAN_QUOTA_MAX_COMMANDS_PER_SHELL_PPQ,
            0x803381EA => WINRM::ERROR_WSMAN_QUOTA_MIN_REQUIREMENT_NOT_AVAILABLE_PPQ,
            0x803381EB => WINRM::ERROR_WSMAN_NEW_DESERIALIZER,
            0x803381EC => WINRM::ERROR_WSMAN_DESERIALIZE_CLASS,
            0x803381ED => WINRM::ERROR_WSMAN_GETCLASS,
            0x803381EE => WINRM::ERROR_WSMAN_NEW_SESSION,
            0x803381EF => WINRM::ERROR_WSMAN_NULL_KEY,
            0x803381F0 => WINRM::ERROR_WSMAN_MUTUAL_AUTH_FAILED,
            0x803381F1 => WINRM::ERROR_WSMAN_UNSUPPORTED_OCTETTYPE,
            0x803381F2 => WINRM::ERROR_WINRS_IDLETIMEOUT_OUTOFBOUNDS,
            0x803381F3 => WINRM::ERROR_WSMAN_INSUFFICIENT_METADATA_FOR_BASIC,
            0x803381F4 => WINRM::ERROR_WSMAN_INVALID_LITERAL_URI,
            0x803381F5 => WINRM::ERROR_WSMAN_OBJECTONLY_INVALID,
            0x803381F6 => WINRM::ERROR_WSMAN_MISSING_CLASSNAME,
            0x803381F7 => WINRM::ERROR_WSMAN_EVENTING_INVALID_ENCODING_IN_DELIVERY,
            0x803381F8 => WINRM::ERROR_WSMAN_DESTINATION_INVALID,
            0x803381F9 => WINRM::ERROR_WSMAN_UNSUPPORTED_FEATURE_IDENTIFY,
            0x803381FA => WINRM::ERROR_WSMAN_CLIENT_SESSION_UNUSABLE,
        }
    }
}
